from . import com_arguments, unwrap
from .office import *

import win32com.client

class Account:

    def __init__(self, account=None):
        self.com_object= account

    @property
    def AccountType(self):
        return OlAccountType(self.com_object.AccountType)

    @property
    def accounttype(self):
        """Alias for AccountType"""
        return self.AccountType

    @property
    def account_type(self):
        """Alias for AccountType"""
        return self.AccountType

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoDiscoverConnectionMode(self):
        return OlAutoDiscoverConnectionMode(self.com_object.AutoDiscoverConnectionMode)

    @property
    def autodiscoverconnectionmode(self):
        """Alias for AutoDiscoverConnectionMode"""
        return self.AutoDiscoverConnectionMode

    @property
    def auto_discover_connection_mode(self):
        """Alias for AutoDiscoverConnectionMode"""
        return self.AutoDiscoverConnectionMode

    @property
    def AutoDiscoverXml(self):
        return self.com_object.AutoDiscoverXml

    @property
    def autodiscoverxml(self):
        """Alias for AutoDiscoverXml"""
        return self.AutoDiscoverXml

    @property
    def auto_discover_xml(self):
        """Alias for AutoDiscoverXml"""
        return self.AutoDiscoverXml

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def CurrentUser(self):
        return Recipient(self.com_object.CurrentUser)

    @property
    def currentuser(self):
        """Alias for CurrentUser"""
        return self.CurrentUser

    @property
    def current_user(self):
        """Alias for CurrentUser"""
        return self.CurrentUser

    @property
    def DeliveryStore(self):
        return Store(self.com_object.DeliveryStore)

    @property
    def deliverystore(self):
        """Alias for DeliveryStore"""
        return self.DeliveryStore

    @property
    def delivery_store(self):
        """Alias for DeliveryStore"""
        return self.DeliveryStore

    @property
    def DisplayName(self):
        return Account(self.com_object.DisplayName)

    @property
    def displayname(self):
        """Alias for DisplayName"""
        return self.DisplayName

    @property
    def display_name(self):
        """Alias for DisplayName"""
        return self.DisplayName

    @property
    def ExchangeConnectionMode(self):
        return OlExchangeConnectionMode(self.com_object.ExchangeConnectionMode)

    @property
    def exchangeconnectionmode(self):
        """Alias for ExchangeConnectionMode"""
        return self.ExchangeConnectionMode

    @property
    def exchange_connection_mode(self):
        """Alias for ExchangeConnectionMode"""
        return self.ExchangeConnectionMode

    @property
    def ExchangeMailboxServerName(self):
        return self.com_object.ExchangeMailboxServerName

    @property
    def exchangemailboxservername(self):
        """Alias for ExchangeMailboxServerName"""
        return self.ExchangeMailboxServerName

    @property
    def exchange_mailbox_server_name(self):
        """Alias for ExchangeMailboxServerName"""
        return self.ExchangeMailboxServerName

    @property
    def ExchangeMailboxServerVersion(self):
        return self.com_object.ExchangeMailboxServerVersion

    @property
    def exchangemailboxserverversion(self):
        """Alias for ExchangeMailboxServerVersion"""
        return self.ExchangeMailboxServerVersion

    @property
    def exchange_mailbox_server_version(self):
        """Alias for ExchangeMailboxServerVersion"""
        return self.ExchangeMailboxServerVersion

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def SmtpAddress(self):
        return Account(self.com_object.SmtpAddress)

    @property
    def smtpaddress(self):
        """Alias for SmtpAddress"""
        return self.SmtpAddress

    @property
    def smtp_address(self):
        """Alias for SmtpAddress"""
        return self.SmtpAddress

    @property
    def UserName(self):
        return Account(self.com_object.UserName)

    @property
    def username(self):
        """Alias for UserName"""
        return self.UserName

    @property
    def user_name(self):
        """Alias for UserName"""
        return self.UserName

    def GetAddressEntryFromID(self, ID=None):
        arguments = com_arguments([unwrap(a) for a in [ID]])
        return self.com_object.GetAddressEntryFromID(*arguments)

    def getaddressentryfromid(self, ID=None):
        """Alias for GetAddressEntryFromID"""
        arguments = [ID]
        return self.GetAddressEntryFromID(*arguments)

    def get_address_entry_from_i_d(self, ID=None):
        """Alias for GetAddressEntryFromID"""
        arguments = [ID]
        return self.GetAddressEntryFromID(*arguments)

    def GetRecipientFromID(self, EntryID=None):
        arguments = com_arguments([unwrap(a) for a in [EntryID]])
        return Recipient(self.com_object.GetRecipientFromID(*arguments))

    def getrecipientfromid(self, EntryID=None):
        """Alias for GetRecipientFromID"""
        arguments = [EntryID]
        return self.GetRecipientFromID(*arguments)

    def get_recipient_from_i_d(self, EntryID=None):
        """Alias for GetRecipientFromID"""
        arguments = [EntryID]
        return self.GetRecipientFromID(*arguments)


class AccountRuleCondition:

    def __init__(self, accountrulecondition=None):
        self.com_object= accountrulecondition

    @property
    def Account(self):
        return Account(self.com_object.Account)

    @Account.setter
    def Account(self, value):
        self.com_object.Account = value

    @property
    def account(self):
        """Alias for Account"""
        return self.Account

    @account.setter
    def account(self, value):
        """Alias for Account.setter"""
        self.Account = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def ConditionType(self):
        return OlRuleConditionType(self.com_object.ConditionType)

    @property
    def conditiontype(self):
        """Alias for ConditionType"""
        return self.ConditionType

    @property
    def condition_type(self):
        """Alias for ConditionType"""
        return self.ConditionType

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session


class Accounts:

    def __init__(self, accounts=None):
        self.com_object= accounts

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Account(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class AccountSelector:

    def __init__(self, accountselector=None):
        self.com_object= accountselector

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SelectedAccount(self):
        return Account(self.com_object.SelectedAccount)

    @property
    def selectedaccount(self):
        """Alias for SelectedAccount"""
        return self.SelectedAccount

    @property
    def selected_account(self):
        """Alias for SelectedAccount"""
        return self.SelectedAccount

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session


class Action:

    def __init__(self, action=None):
        self.com_object= action

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def CopyLike(self):
        return OlActionCopyLike(self.com_object.CopyLike)

    @CopyLike.setter
    def CopyLike(self, value):
        self.com_object.CopyLike = value

    @property
    def copylike(self):
        """Alias for CopyLike"""
        return self.CopyLike

    @copylike.setter
    def copylike(self, value):
        """Alias for CopyLike.setter"""
        self.CopyLike = value

    @property
    def copy_like(self):
        """Alias for CopyLike"""
        return self.CopyLike

    @copy_like.setter
    def copy_like(self, value):
        """Alias for CopyLike.setter"""
        self.CopyLike = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def MessageClass(self):
        return Action(self.com_object.MessageClass)

    @MessageClass.setter
    def MessageClass(self, value):
        self.com_object.MessageClass = value

    @property
    def messageclass(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @messageclass.setter
    def messageclass(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def message_class(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @message_class.setter
    def message_class(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Prefix(self):
        return self.com_object.Prefix

    @Prefix.setter
    def Prefix(self, value):
        self.com_object.Prefix = value

    @property
    def prefix(self):
        """Alias for Prefix"""
        return self.Prefix

    @prefix.setter
    def prefix(self, value):
        """Alias for Prefix.setter"""
        self.Prefix = value

    @property
    def ReplyStyle(self):
        return OlActionReplyStyle(self.com_object.ReplyStyle)

    @ReplyStyle.setter
    def ReplyStyle(self, value):
        self.com_object.ReplyStyle = value

    @property
    def replystyle(self):
        """Alias for ReplyStyle"""
        return self.ReplyStyle

    @replystyle.setter
    def replystyle(self, value):
        """Alias for ReplyStyle.setter"""
        self.ReplyStyle = value

    @property
    def reply_style(self):
        """Alias for ReplyStyle"""
        return self.ReplyStyle

    @reply_style.setter
    def reply_style(self, value):
        """Alias for ReplyStyle.setter"""
        self.ReplyStyle = value

    @property
    def ResponseStyle(self):
        return OlActionResponseStyle(self.com_object.ResponseStyle)

    @ResponseStyle.setter
    def ResponseStyle(self, value):
        self.com_object.ResponseStyle = value

    @property
    def responsestyle(self):
        """Alias for ResponseStyle"""
        return self.ResponseStyle

    @responsestyle.setter
    def responsestyle(self, value):
        """Alias for ResponseStyle.setter"""
        self.ResponseStyle = value

    @property
    def response_style(self):
        """Alias for ResponseStyle"""
        return self.ResponseStyle

    @response_style.setter
    def response_style(self, value):
        """Alias for ResponseStyle.setter"""
        self.ResponseStyle = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def ShowOn(self):
        return OlActionShowOn(self.com_object.ShowOn)

    @ShowOn.setter
    def ShowOn(self, value):
        self.com_object.ShowOn = value

    @property
    def showon(self):
        """Alias for ShowOn"""
        return self.ShowOn

    @showon.setter
    def showon(self, value):
        """Alias for ShowOn.setter"""
        self.ShowOn = value

    @property
    def show_on(self):
        """Alias for ShowOn"""
        return self.ShowOn

    @show_on.setter
    def show_on(self, value):
        """Alias for ShowOn.setter"""
        self.ShowOn = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Execute(self):
        return self.com_object.Execute()

    def execute(self):
        """Alias for Execute"""
        return self.Execute()


class Actions:

    def __init__(self, actions=None):
        self.com_object= actions

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Add(self):
        return Action(self.com_object.Add())

    def add(self):
        """Alias for Add"""
        return self.Add()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Action(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Remove(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Remove(*arguments)

    def remove(self, Index=None):
        """Alias for Remove"""
        arguments = [Index]
        return self.Remove(*arguments)


class AddressEntries:

    def __init__(self, addressentries=None):
        self.com_object= addressentries

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Add(self, Type=None, Name=None, Address=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Name, Address]])
        return AddressEntry(self.com_object.Add(*arguments))

    def add(self, Type=None, Name=None, Address=None):
        """Alias for Add"""
        arguments = [Type, Name, Address]
        return self.Add(*arguments)

    def GetFirst(self):
        return AddressEntry(self.com_object.GetFirst())

    def getfirst(self):
        """Alias for GetFirst"""
        return self.GetFirst()

    def get_first(self):
        """Alias for GetFirst"""
        return self.GetFirst()

    def GetLast(self):
        return AddressEntry(self.com_object.GetLast())

    def getlast(self):
        """Alias for GetLast"""
        return self.GetLast()

    def get_last(self):
        """Alias for GetLast"""
        return self.GetLast()

    def GetNext(self):
        return AddressEntry(self.com_object.GetNext())

    def getnext(self):
        """Alias for GetNext"""
        return self.GetNext()

    def get_next(self):
        """Alias for GetNext"""
        return self.GetNext()

    def GetPrevious(self):
        return AddressEntry(self.com_object.GetPrevious())

    def getprevious(self):
        """Alias for GetPrevious"""
        return self.GetPrevious()

    def get_previous(self):
        """Alias for GetPrevious"""
        return self.GetPrevious()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return AddressEntry(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Sort(self, Property=None, Order=None):
        arguments = com_arguments([unwrap(a) for a in [Property, Order]])
        self.com_object.Sort(*arguments)

    def sort(self, Property=None, Order=None):
        """Alias for Sort"""
        arguments = [Property, Order]
        return self.Sort(*arguments)


class AddressEntry:

    def __init__(self, addressentry=None):
        self.com_object= addressentry

    @property
    def Address(self):
        return AddressEntry(self.com_object.Address)

    @Address.setter
    def Address(self, value):
        self.com_object.Address = value

    @property
    def address(self):
        """Alias for Address"""
        return self.Address

    @address.setter
    def address(self, value):
        """Alias for Address.setter"""
        self.Address = value

    @property
    def AddressEntryUserType(self):
        return OlAddressEntryUserType(self.com_object.AddressEntryUserType)

    @property
    def addressentryusertype(self):
        """Alias for AddressEntryUserType"""
        return self.AddressEntryUserType

    @property
    def address_entry_user_type(self):
        """Alias for AddressEntryUserType"""
        return self.AddressEntryUserType

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def DisplayType(self):
        return OlDisplayType(self.com_object.DisplayType)

    @property
    def displaytype(self):
        """Alias for DisplayType"""
        return self.DisplayType

    @property
    def display_type(self):
        """Alias for DisplayType"""
        return self.DisplayType

    @property
    def ID(self):
        return self.com_object.ID

    @property
    def id(self):
        """Alias for ID"""
        return self.ID

    @property
    def i_d(self):
        """Alias for ID"""
        return self.ID

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Details(self, HWnd=None):
        arguments = com_arguments([unwrap(a) for a in [HWnd]])
        self.com_object.Details(*arguments)

    def details(self, HWnd=None):
        """Alias for Details"""
        arguments = [HWnd]
        return self.Details(*arguments)

    def GetContact(self):
        return self.com_object.GetContact()

    def getcontact(self):
        """Alias for GetContact"""
        return self.GetContact()

    def get_contact(self):
        """Alias for GetContact"""
        return self.GetContact()

    def GetExchangeDistributionList(self):
        return self.com_object.GetExchangeDistributionList()

    def getexchangedistributionlist(self):
        """Alias for GetExchangeDistributionList"""
        return self.GetExchangeDistributionList()

    def get_exchange_distribution_list(self):
        """Alias for GetExchangeDistributionList"""
        return self.GetExchangeDistributionList()

    def GetExchangeUser(self):
        return self.com_object.GetExchangeUser()

    def getexchangeuser(self):
        """Alias for GetExchangeUser"""
        return self.GetExchangeUser()

    def get_exchange_user(self):
        """Alias for GetExchangeUser"""
        return self.GetExchangeUser()

    def GetFreeBusy(self, Start=None, MinPerChar=None, CompleteFormat=None):
        arguments = com_arguments([unwrap(a) for a in [Start, MinPerChar, CompleteFormat]])
        return self.com_object.GetFreeBusy(*arguments)

    def getfreebusy(self, Start=None, MinPerChar=None, CompleteFormat=None):
        """Alias for GetFreeBusy"""
        arguments = [Start, MinPerChar, CompleteFormat]
        return self.GetFreeBusy(*arguments)

    def get_free_busy(self, Start=None, MinPerChar=None, CompleteFormat=None):
        """Alias for GetFreeBusy"""
        arguments = [Start, MinPerChar, CompleteFormat]
        return self.GetFreeBusy(*arguments)

    def Update(self, MakePermanent=None, Refresh=None):
        arguments = com_arguments([unwrap(a) for a in [MakePermanent, Refresh]])
        self.com_object.Update(*arguments)

    def update(self, MakePermanent=None, Refresh=None):
        """Alias for Update"""
        arguments = [MakePermanent, Refresh]
        return self.Update(*arguments)


class AddressList:

    def __init__(self, addresslist=None):
        self.com_object= addresslist

    @property
    def AddressEntries(self):
        return AddressEntries(self.com_object.AddressEntries)

    @property
    def addressentries(self):
        """Alias for AddressEntries"""
        return self.AddressEntries

    @property
    def address_entries(self):
        """Alias for AddressEntries"""
        return self.AddressEntries

    @property
    def AddressListType(self):
        return OlAddressListType(self.com_object.AddressListType)

    @property
    def addresslisttype(self):
        """Alias for AddressListType"""
        return self.AddressListType

    @property
    def address_list_type(self):
        """Alias for AddressListType"""
        return self.AddressListType

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def ID(self):
        return self.com_object.ID

    @property
    def id(self):
        """Alias for ID"""
        return self.ID

    @property
    def i_d(self):
        """Alias for ID"""
        return self.ID

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def IsInitialAddressList(self):
        return AddressList(self.com_object.IsInitialAddressList)

    @property
    def isinitialaddresslist(self):
        """Alias for IsInitialAddressList"""
        return self.IsInitialAddressList

    @property
    def is_initial_address_list(self):
        """Alias for IsInitialAddressList"""
        return self.IsInitialAddressList

    @property
    def IsReadOnly(self):
        return AddressList(self.com_object.IsReadOnly)

    @property
    def isreadonly(self):
        """Alias for IsReadOnly"""
        return self.IsReadOnly

    @property
    def is_read_only(self):
        """Alias for IsReadOnly"""
        return self.IsReadOnly

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def ResolutionOrder(self):
        return AddressList(self.com_object.ResolutionOrder)

    @property
    def resolutionorder(self):
        """Alias for ResolutionOrder"""
        return self.ResolutionOrder

    @property
    def resolution_order(self):
        """Alias for ResolutionOrder"""
        return self.ResolutionOrder

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def GetContactsFolder(self):
        return self.com_object.GetContactsFolder()

    def getcontactsfolder(self):
        """Alias for GetContactsFolder"""
        return self.GetContactsFolder()

    def get_contacts_folder(self):
        """Alias for GetContactsFolder"""
        return self.GetContactsFolder()


class AddressLists:

    def __init__(self, addresslists=None):
        self.com_object= addresslists

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return AddressList(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class AddressRuleCondition:

    def __init__(self, addressrulecondition=None):
        self.com_object= addressrulecondition

    @property
    def Address(self):
        return self.com_object.Address

    @Address.setter
    def Address(self, value):
        self.com_object.Address = value

    @property
    def address(self):
        """Alias for Address"""
        return self.Address

    @address.setter
    def address(self, value):
        """Alias for Address.setter"""
        self.Address = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def ConditionType(self):
        return OlRuleConditionType(self.com_object.ConditionType)

    @property
    def conditiontype(self):
        """Alias for ConditionType"""
        return self.ConditionType

    @property
    def condition_type(self):
        """Alias for ConditionType"""
        return self.ConditionType

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session


class Application:

    def __init__(self, application=None):
        if application is None:
            self.com_object = win32com.client.gencache.EnsureDispatch("Outlook.Application")
        else:
            self.com_object = application

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Assistance(self):
        return self.com_object.Assistance

    @property
    def assistance(self):
        """Alias for Assistance"""
        return self.Assistance

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def COMAddIns(self):
        return self.com_object.COMAddIns

    @property
    def comaddins(self):
        """Alias for COMAddIns"""
        return self.COMAddIns

    @property
    def c_o_m_add_ins(self):
        """Alias for COMAddIns"""
        return self.COMAddIns

    @property
    def DefaultProfileName(self):
        return self.com_object.DefaultProfileName

    @property
    def defaultprofilename(self):
        """Alias for DefaultProfileName"""
        return self.DefaultProfileName

    @property
    def default_profile_name(self):
        """Alias for DefaultProfileName"""
        return self.DefaultProfileName

    @property
    def Explorers(self):
        return Explorers(self.com_object.Explorers)

    @property
    def explorers(self):
        """Alias for Explorers"""
        return self.Explorers

    @property
    def Inspectors(self):
        return Inspectors(self.com_object.Inspectors)

    @property
    def inspectors(self):
        """Alias for Inspectors"""
        return self.Inspectors

    @property
    def IsTrusted(self):
        return self.com_object.IsTrusted

    @property
    def istrusted(self):
        """Alias for IsTrusted"""
        return self.IsTrusted

    @property
    def is_trusted(self):
        """Alias for IsTrusted"""
        return self.IsTrusted

    @property
    def LanguageSettings(self):
        return self.com_object.LanguageSettings

    @property
    def languagesettings(self):
        """Alias for LanguageSettings"""
        return self.LanguageSettings

    @property
    def language_settings(self):
        """Alias for LanguageSettings"""
        return self.LanguageSettings

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PickerDialog(self):
        return self.com_object.PickerDialog

    @property
    def pickerdialog(self):
        """Alias for PickerDialog"""
        return self.PickerDialog

    @property
    def picker_dialog(self):
        """Alias for PickerDialog"""
        return self.PickerDialog

    @property
    def ProductCode(self):
        return self.com_object.ProductCode

    @property
    def productcode(self):
        """Alias for ProductCode"""
        return self.ProductCode

    @property
    def product_code(self):
        """Alias for ProductCode"""
        return self.ProductCode

    @property
    def Reminders(self):
        return Reminders(self.com_object.Reminders)

    @property
    def reminders(self):
        """Alias for Reminders"""
        return self.Reminders

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def TimeZones(self):
        return TimeZones(self.com_object.TimeZones)

    @property
    def timezones(self):
        """Alias for TimeZones"""
        return self.TimeZones

    @property
    def time_zones(self):
        """Alias for TimeZones"""
        return self.TimeZones

    @property
    def Version(self):
        return self.com_object.Version

    @Version.setter
    def Version(self, value):
        self.com_object.Version = value

    @property
    def version(self):
        """Alias for Version"""
        return self.Version

    @version.setter
    def version(self, value):
        """Alias for Version.setter"""
        self.Version = value

    def ActiveExplorer(self):
        return self.com_object.ActiveExplorer()

    def activeexplorer(self):
        """Alias for ActiveExplorer"""
        return self.ActiveExplorer()

    def active_explorer(self):
        """Alias for ActiveExplorer"""
        return self.ActiveExplorer()

    def ActiveInspector(self):
        return Inspector(self.com_object.ActiveInspector())

    def activeinspector(self):
        """Alias for ActiveInspector"""
        return self.ActiveInspector()

    def active_inspector(self):
        """Alias for ActiveInspector"""
        return self.ActiveInspector()

    def ActiveWindow(self):
        return self.com_object.ActiveWindow()

    def activewindow(self):
        """Alias for ActiveWindow"""
        return self.ActiveWindow()

    def active_window(self):
        """Alias for ActiveWindow"""
        return self.ActiveWindow()

    def AdvancedSearch(self, Scope=None, Filter=None, SearchSubFolders=None, Tag=None):
        arguments = com_arguments([unwrap(a) for a in [Scope, Filter, SearchSubFolders, Tag]])
        return Search(self.com_object.AdvancedSearch(*arguments))

    def advancedsearch(self, Scope=None, Filter=None, SearchSubFolders=None, Tag=None):
        """Alias for AdvancedSearch"""
        arguments = [Scope, Filter, SearchSubFolders, Tag]
        return self.AdvancedSearch(*arguments)

    def advanced_search(self, Scope=None, Filter=None, SearchSubFolders=None, Tag=None):
        """Alias for AdvancedSearch"""
        arguments = [Scope, Filter, SearchSubFolders, Tag]
        return self.AdvancedSearch(*arguments)

    def CopyFile(self, FilePath=None, DestFolderPath=None):
        arguments = com_arguments([unwrap(a) for a in [FilePath, DestFolderPath]])
        return self.com_object.CopyFile(*arguments)

    def copyfile(self, FilePath=None, DestFolderPath=None):
        """Alias for CopyFile"""
        arguments = [FilePath, DestFolderPath]
        return self.CopyFile(*arguments)

    def copy_file(self, FilePath=None, DestFolderPath=None):
        """Alias for CopyFile"""
        arguments = [FilePath, DestFolderPath]
        return self.CopyFile(*arguments)

    def CreateItem(self, ItemType=None):
        arguments = com_arguments([unwrap(a) for a in [ItemType]])
        return self.com_object.CreateItem(*arguments)

    def createitem(self, ItemType=None):
        """Alias for CreateItem"""
        arguments = [ItemType]
        return self.CreateItem(*arguments)

    def create_item(self, ItemType=None):
        """Alias for CreateItem"""
        arguments = [ItemType]
        return self.CreateItem(*arguments)

    def CreateItemFromTemplate(self, TemplatePath=None, InFolder=None):
        arguments = com_arguments([unwrap(a) for a in [TemplatePath, InFolder]])
        return self.com_object.CreateItemFromTemplate(*arguments)

    def createitemfromtemplate(self, TemplatePath=None, InFolder=None):
        """Alias for CreateItemFromTemplate"""
        arguments = [TemplatePath, InFolder]
        return self.CreateItemFromTemplate(*arguments)

    def create_item_from_template(self, TemplatePath=None, InFolder=None):
        """Alias for CreateItemFromTemplate"""
        arguments = [TemplatePath, InFolder]
        return self.CreateItemFromTemplate(*arguments)

    def CreateObject(self, ObjectName=None):
        arguments = com_arguments([unwrap(a) for a in [ObjectName]])
        return self.com_object.CreateObject(*arguments)

    def createobject(self, ObjectName=None):
        """Alias for CreateObject"""
        arguments = [ObjectName]
        return self.CreateObject(*arguments)

    def create_object(self, ObjectName=None):
        """Alias for CreateObject"""
        arguments = [ObjectName]
        return self.CreateObject(*arguments)

    def GetNamespace(self, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Type]])
        return NameSpace(self.com_object.GetNamespace(*arguments))

    def getnamespace(self, Type=None):
        """Alias for GetNamespace"""
        arguments = [Type]
        return self.GetNamespace(*arguments)

    def get_namespace(self, Type=None):
        """Alias for GetNamespace"""
        arguments = [Type]
        return self.GetNamespace(*arguments)

    def GetObjectReference(self, Item=None, ReferenceType=None):
        arguments = com_arguments([unwrap(a) for a in [Item, ReferenceType]])
        return self.com_object.GetObjectReference(*arguments)

    def getobjectreference(self, Item=None, ReferenceType=None):
        """Alias for GetObjectReference"""
        arguments = [Item, ReferenceType]
        return self.GetObjectReference(*arguments)

    def get_object_reference(self, Item=None, ReferenceType=None):
        """Alias for GetObjectReference"""
        arguments = [Item, ReferenceType]
        return self.GetObjectReference(*arguments)

    def IsSearchSynchronous(self, LookInFolders=None):
        arguments = com_arguments([unwrap(a) for a in [LookInFolders]])
        return self.com_object.IsSearchSynchronous(*arguments)

    def issearchsynchronous(self, LookInFolders=None):
        """Alias for IsSearchSynchronous"""
        arguments = [LookInFolders]
        return self.IsSearchSynchronous(*arguments)

    def is_search_synchronous(self, LookInFolders=None):
        """Alias for IsSearchSynchronous"""
        arguments = [LookInFolders]
        return self.IsSearchSynchronous(*arguments)

    def Quit(self):
        self.com_object.Quit()

    def quit(self):
        """Alias for Quit"""
        return self.Quit()

    def RefreshFormRegionDefinition(self, RegionName=None):
        arguments = com_arguments([unwrap(a) for a in [RegionName]])
        self.com_object.RefreshFormRegionDefinition(*arguments)

    def refreshformregiondefinition(self, RegionName=None):
        """Alias for RefreshFormRegionDefinition"""
        arguments = [RegionName]
        return self.RefreshFormRegionDefinition(*arguments)

    def refresh_form_region_definition(self, RegionName=None):
        """Alias for RefreshFormRegionDefinition"""
        arguments = [RegionName]
        return self.RefreshFormRegionDefinition(*arguments)


class AppointmentItem:

    def __init__(self, appointmentitem=None):
        self.com_object= appointmentitem

    @property
    def Actions(self):
        return Actions(self.com_object.Actions)

    @property
    def actions(self):
        """Alias for Actions"""
        return self.Actions

    @property
    def AllDayEvent(self):
        return self.com_object.AllDayEvent

    @AllDayEvent.setter
    def AllDayEvent(self, value):
        self.com_object.AllDayEvent = value

    @property
    def alldayevent(self):
        """Alias for AllDayEvent"""
        return self.AllDayEvent

    @alldayevent.setter
    def alldayevent(self, value):
        """Alias for AllDayEvent.setter"""
        self.AllDayEvent = value

    @property
    def all_day_event(self):
        """Alias for AllDayEvent"""
        return self.AllDayEvent

    @all_day_event.setter
    def all_day_event(self, value):
        """Alias for AllDayEvent.setter"""
        self.AllDayEvent = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Attachments(self):
        return Attachments(self.com_object.Attachments)

    @property
    def attachments(self):
        """Alias for Attachments"""
        return self.Attachments

    @property
    def AutoResolvedWinner(self):
        return self.com_object.AutoResolvedWinner

    @property
    def autoresolvedwinner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def auto_resolved_winner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def BillingInformation(self):
        return self.com_object.BillingInformation

    @BillingInformation.setter
    def BillingInformation(self, value):
        self.com_object.BillingInformation = value

    @property
    def billinginformation(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billinginformation.setter
    def billinginformation(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def billing_information(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billing_information.setter
    def billing_information(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def Body(self):
        return self.com_object.Body

    @Body.setter
    def Body(self, value):
        self.com_object.Body = value

    @property
    def body(self):
        """Alias for Body"""
        return self.Body

    @body.setter
    def body(self, value):
        """Alias for Body.setter"""
        self.Body = value

    @property
    def BusyStatus(self):
        return OlBusyStatus(self.com_object.BusyStatus)

    @BusyStatus.setter
    def BusyStatus(self, value):
        self.com_object.BusyStatus = value

    @property
    def busystatus(self):
        """Alias for BusyStatus"""
        return self.BusyStatus

    @busystatus.setter
    def busystatus(self, value):
        """Alias for BusyStatus.setter"""
        self.BusyStatus = value

    @property
    def busy_status(self):
        """Alias for BusyStatus"""
        return self.BusyStatus

    @busy_status.setter
    def busy_status(self, value):
        """Alias for BusyStatus.setter"""
        self.BusyStatus = value

    @property
    def Categories(self):
        return self.com_object.Categories

    @Categories.setter
    def Categories(self, value):
        self.com_object.Categories = value

    @property
    def categories(self):
        """Alias for Categories"""
        return self.Categories

    @categories.setter
    def categories(self, value):
        """Alias for Categories.setter"""
        self.Categories = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Companies(self):
        return self.com_object.Companies

    @Companies.setter
    def Companies(self, value):
        self.com_object.Companies = value

    @property
    def companies(self):
        """Alias for Companies"""
        return self.Companies

    @companies.setter
    def companies(self, value):
        """Alias for Companies.setter"""
        self.Companies = value

    @property
    def Conflicts(self):
        return self.com_object.Conflicts

    @property
    def conflicts(self):
        """Alias for Conflicts"""
        return self.Conflicts

    @property
    def ConversationID(self):
        return Conversation(self.com_object.ConversationID)

    @property
    def conversationid(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def conversation_i_d(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def ConversationIndex(self):
        return self.com_object.ConversationIndex

    @property
    def conversationindex(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def conversation_index(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def ConversationTopic(self):
        return self.com_object.ConversationTopic

    @property
    def conversationtopic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def conversation_topic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def CreationTime(self):
        return self.com_object.CreationTime

    @property
    def creationtime(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def creation_time(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def DownloadState(self):
        return OlDownloadState(self.com_object.DownloadState)

    @property
    def downloadstate(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def download_state(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def Duration(self):
        return AppointmentItem(self.com_object.Duration)

    @Duration.setter
    def Duration(self, value):
        self.com_object.Duration = value

    @property
    def duration(self):
        """Alias for Duration"""
        return self.Duration

    @duration.setter
    def duration(self, value):
        """Alias for Duration.setter"""
        self.Duration = value

    @property
    def End(self):
        return AppointmentItem(self.com_object.End)

    @End.setter
    def End(self, value):
        self.com_object.End = value

    @property
    def end(self):
        """Alias for End"""
        return self.End

    @end.setter
    def end(self, value):
        """Alias for End.setter"""
        self.End = value

    @property
    def EndInEndTimeZone(self):
        return AppointmentItem.EndTimeZone(self.com_object.EndInEndTimeZone)

    @EndInEndTimeZone.setter
    def EndInEndTimeZone(self, value):
        self.com_object.EndInEndTimeZone = value

    @property
    def endinendtimezone(self):
        """Alias for EndInEndTimeZone"""
        return self.EndInEndTimeZone

    @endinendtimezone.setter
    def endinendtimezone(self, value):
        """Alias for EndInEndTimeZone.setter"""
        self.EndInEndTimeZone = value

    @property
    def end_in_end_time_zone(self):
        """Alias for EndInEndTimeZone"""
        return self.EndInEndTimeZone

    @end_in_end_time_zone.setter
    def end_in_end_time_zone(self, value):
        """Alias for EndInEndTimeZone.setter"""
        self.EndInEndTimeZone = value

    @property
    def EndTimeZone(self):
        return TimeZone(self.com_object.EndTimeZone)

    @EndTimeZone.setter
    def EndTimeZone(self, value):
        self.com_object.EndTimeZone = value

    @property
    def endtimezone(self):
        """Alias for EndTimeZone"""
        return self.EndTimeZone

    @endtimezone.setter
    def endtimezone(self, value):
        """Alias for EndTimeZone.setter"""
        self.EndTimeZone = value

    @property
    def end_time_zone(self):
        """Alias for EndTimeZone"""
        return self.EndTimeZone

    @end_time_zone.setter
    def end_time_zone(self, value):
        """Alias for EndTimeZone.setter"""
        self.EndTimeZone = value

    @property
    def EndUTC(self):
        return self.com_object.EndUTC

    @EndUTC.setter
    def EndUTC(self, value):
        self.com_object.EndUTC = value

    @property
    def endutc(self):
        """Alias for EndUTC"""
        return self.EndUTC

    @endutc.setter
    def endutc(self, value):
        """Alias for EndUTC.setter"""
        self.EndUTC = value

    @property
    def end_u_t_c(self):
        """Alias for EndUTC"""
        return self.EndUTC

    @end_u_t_c.setter
    def end_u_t_c(self, value):
        """Alias for EndUTC.setter"""
        self.EndUTC = value

    @property
    def EntryID(self):
        return self.com_object.EntryID

    @property
    def entryid(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def entry_i_d(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def ForceUpdateToAllAttendees(self):
        return self.com_object.ForceUpdateToAllAttendees

    @ForceUpdateToAllAttendees.setter
    def ForceUpdateToAllAttendees(self, value):
        self.com_object.ForceUpdateToAllAttendees = value

    @property
    def forceupdatetoallattendees(self):
        """Alias for ForceUpdateToAllAttendees"""
        return self.ForceUpdateToAllAttendees

    @forceupdatetoallattendees.setter
    def forceupdatetoallattendees(self, value):
        """Alias for ForceUpdateToAllAttendees.setter"""
        self.ForceUpdateToAllAttendees = value

    @property
    def force_update_to_all_attendees(self):
        """Alias for ForceUpdateToAllAttendees"""
        return self.ForceUpdateToAllAttendees

    @force_update_to_all_attendees.setter
    def force_update_to_all_attendees(self, value):
        """Alias for ForceUpdateToAllAttendees.setter"""
        self.ForceUpdateToAllAttendees = value

    @property
    def FormDescription(self):
        return FormDescription(self.com_object.FormDescription)

    @property
    def formdescription(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def form_description(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def GetInspector(self):
        return Inspector(self.com_object.GetInspector)

    @property
    def getinspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def get_inspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def GlobalAppointmentID(self):
        return AppointmentItem(self.com_object.GlobalAppointmentID)

    @property
    def globalappointmentid(self):
        """Alias for GlobalAppointmentID"""
        return self.GlobalAppointmentID

    @property
    def global_appointment_i_d(self):
        """Alias for GlobalAppointmentID"""
        return self.GlobalAppointmentID

    @property
    def Importance(self):
        return OlImportance(self.com_object.Importance)

    @Importance.setter
    def Importance(self, value):
        self.com_object.Importance = value

    @property
    def importance(self):
        """Alias for Importance"""
        return self.Importance

    @importance.setter
    def importance(self, value):
        """Alias for Importance.setter"""
        self.Importance = value

    @property
    def InternetCodepage(self):
        return self.com_object.InternetCodepage

    @InternetCodepage.setter
    def InternetCodepage(self, value):
        self.com_object.InternetCodepage = value

    @property
    def internetcodepage(self):
        """Alias for InternetCodepage"""
        return self.InternetCodepage

    @internetcodepage.setter
    def internetcodepage(self, value):
        """Alias for InternetCodepage.setter"""
        self.InternetCodepage = value

    @property
    def internet_codepage(self):
        """Alias for InternetCodepage"""
        return self.InternetCodepage

    @internet_codepage.setter
    def internet_codepage(self, value):
        """Alias for InternetCodepage.setter"""
        self.InternetCodepage = value

    @property
    def IsConflict(self):
        return self.com_object.IsConflict

    @property
    def isconflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def is_conflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def IsRecurring(self):
        return self.com_object.IsRecurring

    @property
    def isrecurring(self):
        """Alias for IsRecurring"""
        return self.IsRecurring

    @property
    def is_recurring(self):
        """Alias for IsRecurring"""
        return self.IsRecurring

    @property
    def ItemProperties(self):
        return ItemProperties(self.com_object.ItemProperties)

    @property
    def itemproperties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def item_properties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def LastModificationTime(self):
        return self.com_object.LastModificationTime

    @property
    def lastmodificationtime(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def last_modification_time(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def Location(self):
        return self.com_object.Location

    @Location.setter
    def Location(self, value):
        self.com_object.Location = value

    @property
    def location(self):
        """Alias for Location"""
        return self.Location

    @location.setter
    def location(self, value):
        """Alias for Location.setter"""
        self.Location = value

    @property
    def MarkForDownload(self):
        return OlRemoteStatus(self.com_object.MarkForDownload)

    @MarkForDownload.setter
    def MarkForDownload(self, value):
        self.com_object.MarkForDownload = value

    @property
    def markfordownload(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @markfordownload.setter
    def markfordownload(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def mark_for_download(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @mark_for_download.setter
    def mark_for_download(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def MeetingStatus(self):
        return OlMeetingStatus(self.com_object.MeetingStatus)

    @MeetingStatus.setter
    def MeetingStatus(self, value):
        self.com_object.MeetingStatus = value

    @property
    def meetingstatus(self):
        """Alias for MeetingStatus"""
        return self.MeetingStatus

    @meetingstatus.setter
    def meetingstatus(self, value):
        """Alias for MeetingStatus.setter"""
        self.MeetingStatus = value

    @property
    def meeting_status(self):
        """Alias for MeetingStatus"""
        return self.MeetingStatus

    @meeting_status.setter
    def meeting_status(self, value):
        """Alias for MeetingStatus.setter"""
        self.MeetingStatus = value

    @property
    def MeetingWorkspaceURL(self):
        return self.com_object.MeetingWorkspaceURL

    @property
    def meetingworkspaceurl(self):
        """Alias for MeetingWorkspaceURL"""
        return self.MeetingWorkspaceURL

    @property
    def meeting_workspace_u_r_l(self):
        """Alias for MeetingWorkspaceURL"""
        return self.MeetingWorkspaceURL

    @property
    def MessageClass(self):
        return self.com_object.MessageClass

    @MessageClass.setter
    def MessageClass(self, value):
        self.com_object.MessageClass = value

    @property
    def messageclass(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @messageclass.setter
    def messageclass(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def message_class(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @message_class.setter
    def message_class(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def Mileage(self):
        return self.com_object.Mileage

    @Mileage.setter
    def Mileage(self, value):
        self.com_object.Mileage = value

    @property
    def mileage(self):
        """Alias for Mileage"""
        return self.Mileage

    @mileage.setter
    def mileage(self, value):
        """Alias for Mileage.setter"""
        self.Mileage = value

    @property
    def NoAging(self):
        return self.com_object.NoAging

    @NoAging.setter
    def NoAging(self, value):
        self.com_object.NoAging = value

    @property
    def noaging(self):
        """Alias for NoAging"""
        return self.NoAging

    @noaging.setter
    def noaging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def no_aging(self):
        """Alias for NoAging"""
        return self.NoAging

    @no_aging.setter
    def no_aging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def OptionalAttendees(self):
        return self.com_object.OptionalAttendees

    @OptionalAttendees.setter
    def OptionalAttendees(self, value):
        self.com_object.OptionalAttendees = value

    @property
    def optionalattendees(self):
        """Alias for OptionalAttendees"""
        return self.OptionalAttendees

    @optionalattendees.setter
    def optionalattendees(self, value):
        """Alias for OptionalAttendees.setter"""
        self.OptionalAttendees = value

    @property
    def optional_attendees(self):
        """Alias for OptionalAttendees"""
        return self.OptionalAttendees

    @optional_attendees.setter
    def optional_attendees(self, value):
        """Alias for OptionalAttendees.setter"""
        self.OptionalAttendees = value

    @property
    def Organizer(self):
        return self.com_object.Organizer

    @property
    def organizer(self):
        """Alias for Organizer"""
        return self.Organizer

    @property
    def OutlookInternalVersion(self):
        return self.com_object.OutlookInternalVersion

    @property
    def outlookinternalversion(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def outlook_internal_version(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def OutlookVersion(self):
        return self.com_object.OutlookVersion

    @property
    def outlookversion(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def outlook_version(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def Recipients(self):
        return Recipients(self.com_object.Recipients)

    @property
    def recipients(self):
        """Alias for Recipients"""
        return self.Recipients

    @property
    def RecurrenceState(self):
        return OlRecurrenceState(self.com_object.RecurrenceState)

    @property
    def recurrencestate(self):
        """Alias for RecurrenceState"""
        return self.RecurrenceState

    @property
    def recurrence_state(self):
        """Alias for RecurrenceState"""
        return self.RecurrenceState

    @property
    def ReminderMinutesBeforeStart(self):
        return self.com_object.ReminderMinutesBeforeStart

    @ReminderMinutesBeforeStart.setter
    def ReminderMinutesBeforeStart(self, value):
        self.com_object.ReminderMinutesBeforeStart = value

    @property
    def reminderminutesbeforestart(self):
        """Alias for ReminderMinutesBeforeStart"""
        return self.ReminderMinutesBeforeStart

    @reminderminutesbeforestart.setter
    def reminderminutesbeforestart(self, value):
        """Alias for ReminderMinutesBeforeStart.setter"""
        self.ReminderMinutesBeforeStart = value

    @property
    def reminder_minutes_before_start(self):
        """Alias for ReminderMinutesBeforeStart"""
        return self.ReminderMinutesBeforeStart

    @reminder_minutes_before_start.setter
    def reminder_minutes_before_start(self, value):
        """Alias for ReminderMinutesBeforeStart.setter"""
        self.ReminderMinutesBeforeStart = value

    @property
    def ReminderOverrideDefault(self):
        return self.com_object.ReminderOverrideDefault

    @ReminderOverrideDefault.setter
    def ReminderOverrideDefault(self, value):
        self.com_object.ReminderOverrideDefault = value

    @property
    def reminderoverridedefault(self):
        """Alias for ReminderOverrideDefault"""
        return self.ReminderOverrideDefault

    @reminderoverridedefault.setter
    def reminderoverridedefault(self, value):
        """Alias for ReminderOverrideDefault.setter"""
        self.ReminderOverrideDefault = value

    @property
    def reminder_override_default(self):
        """Alias for ReminderOverrideDefault"""
        return self.ReminderOverrideDefault

    @reminder_override_default.setter
    def reminder_override_default(self, value):
        """Alias for ReminderOverrideDefault.setter"""
        self.ReminderOverrideDefault = value

    @property
    def ReminderPlaySound(self):
        return self.com_object.ReminderPlaySound

    @ReminderPlaySound.setter
    def ReminderPlaySound(self, value):
        self.com_object.ReminderPlaySound = value

    @property
    def reminderplaysound(self):
        """Alias for ReminderPlaySound"""
        return self.ReminderPlaySound

    @reminderplaysound.setter
    def reminderplaysound(self, value):
        """Alias for ReminderPlaySound.setter"""
        self.ReminderPlaySound = value

    @property
    def reminder_play_sound(self):
        """Alias for ReminderPlaySound"""
        return self.ReminderPlaySound

    @reminder_play_sound.setter
    def reminder_play_sound(self, value):
        """Alias for ReminderPlaySound.setter"""
        self.ReminderPlaySound = value

    @property
    def ReminderSet(self):
        return self.com_object.ReminderSet

    @ReminderSet.setter
    def ReminderSet(self, value):
        self.com_object.ReminderSet = value

    @property
    def reminderset(self):
        """Alias for ReminderSet"""
        return self.ReminderSet

    @reminderset.setter
    def reminderset(self, value):
        """Alias for ReminderSet.setter"""
        self.ReminderSet = value

    @property
    def reminder_set(self):
        """Alias for ReminderSet"""
        return self.ReminderSet

    @reminder_set.setter
    def reminder_set(self, value):
        """Alias for ReminderSet.setter"""
        self.ReminderSet = value

    @property
    def ReminderSoundFile(self):
        return self.com_object.ReminderSoundFile

    @ReminderSoundFile.setter
    def ReminderSoundFile(self, value):
        self.com_object.ReminderSoundFile = value

    @property
    def remindersoundfile(self):
        """Alias for ReminderSoundFile"""
        return self.ReminderSoundFile

    @remindersoundfile.setter
    def remindersoundfile(self, value):
        """Alias for ReminderSoundFile.setter"""
        self.ReminderSoundFile = value

    @property
    def reminder_sound_file(self):
        """Alias for ReminderSoundFile"""
        return self.ReminderSoundFile

    @reminder_sound_file.setter
    def reminder_sound_file(self, value):
        """Alias for ReminderSoundFile.setter"""
        self.ReminderSoundFile = value

    @property
    def ReplyTime(self):
        return self.com_object.ReplyTime

    @ReplyTime.setter
    def ReplyTime(self, value):
        self.com_object.ReplyTime = value

    @property
    def replytime(self):
        """Alias for ReplyTime"""
        return self.ReplyTime

    @replytime.setter
    def replytime(self, value):
        """Alias for ReplyTime.setter"""
        self.ReplyTime = value

    @property
    def reply_time(self):
        """Alias for ReplyTime"""
        return self.ReplyTime

    @reply_time.setter
    def reply_time(self, value):
        """Alias for ReplyTime.setter"""
        self.ReplyTime = value

    @property
    def RequiredAttendees(self):
        return self.com_object.RequiredAttendees

    @RequiredAttendees.setter
    def RequiredAttendees(self, value):
        self.com_object.RequiredAttendees = value

    @property
    def requiredattendees(self):
        """Alias for RequiredAttendees"""
        return self.RequiredAttendees

    @requiredattendees.setter
    def requiredattendees(self, value):
        """Alias for RequiredAttendees.setter"""
        self.RequiredAttendees = value

    @property
    def required_attendees(self):
        """Alias for RequiredAttendees"""
        return self.RequiredAttendees

    @required_attendees.setter
    def required_attendees(self, value):
        """Alias for RequiredAttendees.setter"""
        self.RequiredAttendees = value

    @property
    def Resources(self):
        return self.com_object.Resources

    @Resources.setter
    def Resources(self, value):
        self.com_object.Resources = value

    @property
    def resources(self):
        """Alias for Resources"""
        return self.Resources

    @resources.setter
    def resources(self, value):
        """Alias for Resources.setter"""
        self.Resources = value

    @property
    def ResponseRequested(self):
        return self.com_object.ResponseRequested

    @ResponseRequested.setter
    def ResponseRequested(self, value):
        self.com_object.ResponseRequested = value

    @property
    def responserequested(self):
        """Alias for ResponseRequested"""
        return self.ResponseRequested

    @responserequested.setter
    def responserequested(self, value):
        """Alias for ResponseRequested.setter"""
        self.ResponseRequested = value

    @property
    def response_requested(self):
        """Alias for ResponseRequested"""
        return self.ResponseRequested

    @response_requested.setter
    def response_requested(self, value):
        """Alias for ResponseRequested.setter"""
        self.ResponseRequested = value

    @property
    def ResponseStatus(self):
        return OlResponseStatus(self.com_object.ResponseStatus)

    @property
    def responsestatus(self):
        """Alias for ResponseStatus"""
        return self.ResponseStatus

    @property
    def response_status(self):
        """Alias for ResponseStatus"""
        return self.ResponseStatus

    @property
    def RTFBody(self):
        return self.com_object.RTFBody

    @RTFBody.setter
    def RTFBody(self, value):
        self.com_object.RTFBody = value

    @property
    def rtfbody(self):
        """Alias for RTFBody"""
        return self.RTFBody

    @rtfbody.setter
    def rtfbody(self, value):
        """Alias for RTFBody.setter"""
        self.RTFBody = value

    @property
    def r_t_f_body(self):
        """Alias for RTFBody"""
        return self.RTFBody

    @r_t_f_body.setter
    def r_t_f_body(self, value):
        """Alias for RTFBody.setter"""
        self.RTFBody = value

    @property
    def Saved(self):
        return self.com_object.Saved

    @property
    def saved(self):
        """Alias for Saved"""
        return self.Saved

    @property
    def SendUsingAccount(self):
        return Account(self.com_object.SendUsingAccount)

    @SendUsingAccount.setter
    def SendUsingAccount(self, value):
        self.com_object.SendUsingAccount = value

    @property
    def sendusingaccount(self):
        """Alias for SendUsingAccount"""
        return self.SendUsingAccount

    @sendusingaccount.setter
    def sendusingaccount(self, value):
        """Alias for SendUsingAccount.setter"""
        self.SendUsingAccount = value

    @property
    def send_using_account(self):
        """Alias for SendUsingAccount"""
        return self.SendUsingAccount

    @send_using_account.setter
    def send_using_account(self, value):
        """Alias for SendUsingAccount.setter"""
        self.SendUsingAccount = value

    @property
    def Sensitivity(self):
        return OlSensitivity(self.com_object.Sensitivity)

    @Sensitivity.setter
    def Sensitivity(self, value):
        self.com_object.Sensitivity = value

    @property
    def sensitivity(self):
        """Alias for Sensitivity"""
        return self.Sensitivity

    @sensitivity.setter
    def sensitivity(self, value):
        """Alias for Sensitivity.setter"""
        self.Sensitivity = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Size(self):
        return self.com_object.Size

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @property
    def Start(self):
        return self.com_object.Start

    @Start.setter
    def Start(self, value):
        self.com_object.Start = value

    @property
    def start(self):
        """Alias for Start"""
        return self.Start

    @start.setter
    def start(self, value):
        """Alias for Start.setter"""
        self.Start = value

    @property
    def StartInStartTimeZone(self):
        return AppointmentItem.StartTimeZone(self.com_object.StartInStartTimeZone)

    @StartInStartTimeZone.setter
    def StartInStartTimeZone(self, value):
        self.com_object.StartInStartTimeZone = value

    @property
    def startinstarttimezone(self):
        """Alias for StartInStartTimeZone"""
        return self.StartInStartTimeZone

    @startinstarttimezone.setter
    def startinstarttimezone(self, value):
        """Alias for StartInStartTimeZone.setter"""
        self.StartInStartTimeZone = value

    @property
    def start_in_start_time_zone(self):
        """Alias for StartInStartTimeZone"""
        return self.StartInStartTimeZone

    @start_in_start_time_zone.setter
    def start_in_start_time_zone(self, value):
        """Alias for StartInStartTimeZone.setter"""
        self.StartInStartTimeZone = value

    @property
    def StartTimeZone(self):
        return TimeZone(self.com_object.StartTimeZone)

    @StartTimeZone.setter
    def StartTimeZone(self, value):
        self.com_object.StartTimeZone = value

    @property
    def starttimezone(self):
        """Alias for StartTimeZone"""
        return self.StartTimeZone

    @starttimezone.setter
    def starttimezone(self, value):
        """Alias for StartTimeZone.setter"""
        self.StartTimeZone = value

    @property
    def start_time_zone(self):
        """Alias for StartTimeZone"""
        return self.StartTimeZone

    @start_time_zone.setter
    def start_time_zone(self, value):
        """Alias for StartTimeZone.setter"""
        self.StartTimeZone = value

    @property
    def StartUTC(self):
        return self.com_object.StartUTC

    @StartUTC.setter
    def StartUTC(self, value):
        self.com_object.StartUTC = value

    @property
    def startutc(self):
        """Alias for StartUTC"""
        return self.StartUTC

    @startutc.setter
    def startutc(self, value):
        """Alias for StartUTC.setter"""
        self.StartUTC = value

    @property
    def start_u_t_c(self):
        """Alias for StartUTC"""
        return self.StartUTC

    @start_u_t_c.setter
    def start_u_t_c(self, value):
        """Alias for StartUTC.setter"""
        self.StartUTC = value

    @property
    def Subject(self):
        return self.com_object.Subject

    @Subject.setter
    def Subject(self, value):
        self.com_object.Subject = value

    @property
    def subject(self):
        """Alias for Subject"""
        return self.Subject

    @subject.setter
    def subject(self, value):
        """Alias for Subject.setter"""
        self.Subject = value

    @property
    def UnRead(self):
        return self.com_object.UnRead

    @UnRead.setter
    def UnRead(self, value):
        self.com_object.UnRead = value

    @property
    def unread(self):
        """Alias for UnRead"""
        return self.UnRead

    @unread.setter
    def unread(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def un_read(self):
        """Alias for UnRead"""
        return self.UnRead

    @un_read.setter
    def un_read(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def UserProperties(self):
        return UserProperties(self.com_object.UserProperties)

    @property
    def userproperties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    @property
    def user_properties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    def ClearRecurrencePattern(self):
        self.com_object.ClearRecurrencePattern()

    def clearrecurrencepattern(self):
        """Alias for ClearRecurrencePattern"""
        return self.ClearRecurrencePattern()

    def clear_recurrence_pattern(self):
        """Alias for ClearRecurrencePattern"""
        return self.ClearRecurrencePattern()

    def Close(self, SaveMode=None):
        arguments = com_arguments([unwrap(a) for a in [SaveMode]])
        self.com_object.Close(*arguments)

    def close(self, SaveMode=None):
        """Alias for Close"""
        arguments = [SaveMode]
        return self.Close(*arguments)

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def CopyTo(self, DestinationFolder=None, CopyOptions=None):
        arguments = com_arguments([unwrap(a) for a in [DestinationFolder, CopyOptions]])
        return AppointmentItem(self.com_object.CopyTo(*arguments))

    def copyto(self, DestinationFolder=None, CopyOptions=None):
        """Alias for CopyTo"""
        arguments = [DestinationFolder, CopyOptions]
        return self.CopyTo(*arguments)

    def copy_to(self, DestinationFolder=None, CopyOptions=None):
        """Alias for CopyTo"""
        arguments = [DestinationFolder, CopyOptions]
        return self.CopyTo(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Display(self, Modal=None):
        arguments = com_arguments([unwrap(a) for a in [Modal]])
        self.com_object.Display(*arguments)

    def display(self, Modal=None):
        """Alias for Display"""
        arguments = [Modal]
        return self.Display(*arguments)

    def ForwardAsVcal(self):
        return MailItem(self.com_object.ForwardAsVcal())

    def forwardasvcal(self):
        """Alias for ForwardAsVcal"""
        return self.ForwardAsVcal()

    def forward_as_vcal(self):
        """Alias for ForwardAsVcal"""
        return self.ForwardAsVcal()

    def GetConversation(self):
        return Conversation(self.com_object.GetConversation())

    def getconversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def get_conversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def GetOrganizer(self):
        return AddressEntry(self.com_object.GetOrganizer())

    def getorganizer(self):
        """Alias for GetOrganizer"""
        return self.GetOrganizer()

    def get_organizer(self):
        """Alias for GetOrganizer"""
        return self.GetOrganizer()

    def GetRecurrencePattern(self):
        return RecurrencePattern(self.com_object.GetRecurrencePattern())

    def getrecurrencepattern(self):
        """Alias for GetRecurrencePattern"""
        return self.GetRecurrencePattern()

    def get_recurrence_pattern(self):
        """Alias for GetRecurrencePattern"""
        return self.GetRecurrencePattern()

    def Move(self, DestFldr=None):
        arguments = com_arguments([unwrap(a) for a in [DestFldr]])
        return self.com_object.Move(*arguments)

    def move(self, DestFldr=None):
        """Alias for Move"""
        arguments = [DestFldr]
        return self.Move(*arguments)

    def PrintOut(self):
        self.com_object.PrintOut()

    def printout(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def print_out(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def Respond(self, Response=None, fNoUI=None, fAdditionalTextDialog=None):
        arguments = com_arguments([unwrap(a) for a in [Response, fNoUI, fAdditionalTextDialog]])
        return MeetingItem(self.com_object.Respond(*arguments))

    def respond(self, Response=None, fNoUI=None, fAdditionalTextDialog=None):
        """Alias for Respond"""
        arguments = [Response, fNoUI, fAdditionalTextDialog]
        return self.Respond(*arguments)

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()

    def SaveAs(self, Path=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Path, Type]])
        self.com_object.SaveAs(*arguments)

    def saveas(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def save_as(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def Send(self):
        self.com_object.Send()

    def send(self):
        """Alias for Send"""
        return self.Send()

    def ShowCategoriesDialog(self):
        self.com_object.ShowCategoriesDialog()

    def showcategoriesdialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()

    def show_categories_dialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()


class AssignToCategoryRuleAction:

    def __init__(self, assigntocategoryruleaction=None):
        self.com_object= assigntocategoryruleaction

    @property
    def ActionType(self):
        return OlRuleActionType(self.com_object.ActionType)

    @property
    def actiontype(self):
        """Alias for ActionType"""
        return self.ActionType

    @property
    def action_type(self):
        """Alias for ActionType"""
        return self.ActionType

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Categories(self):
        return self.com_object.Categories

    @Categories.setter
    def Categories(self, value):
        self.com_object.Categories = value

    @property
    def categories(self):
        """Alias for Categories"""
        return self.Categories

    @categories.setter
    def categories(self, value):
        """Alias for Categories.setter"""
        self.Categories = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session


class Attachment:

    def __init__(self, attachment=None):
        self.com_object= attachment

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BlockLevel(self):
        return OlAttachmentBlockLevel(self.com_object.BlockLevel)

    @property
    def blocklevel(self):
        """Alias for BlockLevel"""
        return self.BlockLevel

    @property
    def block_level(self):
        """Alias for BlockLevel"""
        return self.BlockLevel

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def DisplayName(self):
        return self.com_object.DisplayName

    @DisplayName.setter
    def DisplayName(self, value):
        self.com_object.DisplayName = value

    @property
    def displayname(self):
        """Alias for DisplayName"""
        return self.DisplayName

    @displayname.setter
    def displayname(self, value):
        """Alias for DisplayName.setter"""
        self.DisplayName = value

    @property
    def display_name(self):
        """Alias for DisplayName"""
        return self.DisplayName

    @display_name.setter
    def display_name(self, value):
        """Alias for DisplayName.setter"""
        self.DisplayName = value

    @property
    def FileName(self):
        return self.com_object.FileName

    @property
    def filename(self):
        """Alias for FileName"""
        return self.FileName

    @property
    def file_name(self):
        """Alias for FileName"""
        return self.FileName

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PathName(self):
        return self.com_object.PathName

    @property
    def pathname(self):
        """Alias for PathName"""
        return self.PathName

    @property
    def path_name(self):
        """Alias for PathName"""
        return self.PathName

    @property
    def Position(self):
        return self.com_object.Position

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Size(self):
        return self.com_object.Size

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @property
    def Type(self):
        return OlAttachmentType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def GetTemporaryFilePath(self):
        return self.com_object.GetTemporaryFilePath()

    def gettemporaryfilepath(self):
        """Alias for GetTemporaryFilePath"""
        return self.GetTemporaryFilePath()

    def get_temporary_file_path(self):
        """Alias for GetTemporaryFilePath"""
        return self.GetTemporaryFilePath()

    def SaveAsFile(self, Path=None):
        arguments = com_arguments([unwrap(a) for a in [Path]])
        self.com_object.SaveAsFile(*arguments)

    def saveasfile(self, Path=None):
        """Alias for SaveAsFile"""
        arguments = [Path]
        return self.SaveAsFile(*arguments)

    def save_as_file(self, Path=None):
        """Alias for SaveAsFile"""
        arguments = [Path]
        return self.SaveAsFile(*arguments)


class Attachments:

    def __init__(self, attachments=None):
        self.com_object= attachments

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Add(self, Source=None, Type=None, Position=None, DisplayName=None):
        arguments = com_arguments([unwrap(a) for a in [Source, Type, Position, DisplayName]])
        return Attachment(self.com_object.Add(*arguments))

    def add(self, Source=None, Type=None, Position=None, DisplayName=None):
        """Alias for Add"""
        arguments = [Source, Type, Position, DisplayName]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Attachment(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Remove(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Remove(*arguments)

    def remove(self, Index=None):
        """Alias for Remove"""
        arguments = [Index]
        return self.Remove(*arguments)


class AttachmentSelection:

    def __init__(self, attachmentselection=None):
        self.com_object= attachmentselection

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Location(self):
        return OlSelectionLocation(self.com_object.Location)

    @property
    def location(self):
        """Alias for Location"""
        return self.Location

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def GetSelection(self, SelectionContents=None):
        arguments = com_arguments([unwrap(a) for a in [SelectionContents]])
        return Selection(self.com_object.GetSelection(*arguments))

    def getselection(self, SelectionContents=None):
        """Alias for GetSelection"""
        arguments = [SelectionContents]
        return self.GetSelection(*arguments)

    def get_selection(self, SelectionContents=None):
        """Alias for GetSelection"""
        arguments = [SelectionContents]
        return self.GetSelection(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Attachment(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class AutoFormatRule:

    def __init__(self, autoformatrule=None):
        self.com_object= autoformatrule

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Enabled(self):
        return AutoFormatRule(self.com_object.Enabled)

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Filter(self):
        return self.com_object.Filter

    @Filter.setter
    def Filter(self, value):
        self.com_object.Filter = value

    @property
    def filter(self):
        """Alias for Filter"""
        return self.Filter

    @filter.setter
    def filter(self, value):
        """Alias for Filter.setter"""
        self.Filter = value

    @property
    def Font(self):
        return ViewFont(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Standard(self):
        return AutoFormatRule(self.com_object.Standard)

    @property
    def standard(self):
        """Alias for Standard"""
        return self.Standard


class AutoFormatRules:

    def __init__(self, autoformatrules=None):
        self.com_object= autoformatrules

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return AutoFormatRule(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Add(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        return AutoFormatRule(self.com_object.Add(*arguments))

    def add(self, Name=None):
        """Alias for Add"""
        arguments = [Name]
        return self.Add(*arguments)

    def Insert(self, Name=None, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Index]])
        return AutoFormatRule(self.com_object.Insert(*arguments))

    def insert(self, Name=None, Index=None):
        """Alias for Insert"""
        arguments = [Name, Index]
        return self.Insert(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return AutoFormatRule(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Remove(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Remove(*arguments)

    def remove(self, Index=None):
        """Alias for Remove"""
        arguments = [Index]
        return self.Remove(*arguments)

    def RemoveAll(self):
        self.com_object.RemoveAll()

    def removeall(self):
        """Alias for RemoveAll"""
        return self.RemoveAll()

    def remove_all(self):
        """Alias for RemoveAll"""
        return self.RemoveAll()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()


class BusinessCardView:

    def __init__(self, businesscardview=None):
        self.com_object= businesscardview

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def CardSize(self):
        return self.com_object.CardSize

    @CardSize.setter
    def CardSize(self, value):
        self.com_object.CardSize = value

    @property
    def cardsize(self):
        """Alias for CardSize"""
        return self.CardSize

    @cardsize.setter
    def cardsize(self, value):
        """Alias for CardSize.setter"""
        self.CardSize = value

    @property
    def card_size(self):
        """Alias for CardSize"""
        return self.CardSize

    @card_size.setter
    def card_size(self, value):
        """Alias for CardSize.setter"""
        self.CardSize = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Filter(self):
        return self.com_object.Filter

    @Filter.setter
    def Filter(self, value):
        self.com_object.Filter = value

    @property
    def filter(self):
        """Alias for Filter"""
        return self.Filter

    @filter.setter
    def filter(self, value):
        """Alias for Filter.setter"""
        self.Filter = value

    @property
    def HeadingsFont(self):
        return ViewFont(self.com_object.HeadingsFont)

    @property
    def headingsfont(self):
        """Alias for HeadingsFont"""
        return self.HeadingsFont

    @property
    def headings_font(self):
        """Alias for HeadingsFont"""
        return self.HeadingsFont

    @property
    def Language(self):
        return self.com_object.Language

    @Language.setter
    def Language(self, value):
        self.com_object.Language = value

    @property
    def language(self):
        """Alias for Language"""
        return self.Language

    @language.setter
    def language(self, value):
        """Alias for Language.setter"""
        self.Language = value

    @property
    def LockUserChanges(self):
        return self.com_object.LockUserChanges

    @LockUserChanges.setter
    def LockUserChanges(self, value):
        self.com_object.LockUserChanges = value

    @property
    def lockuserchanges(self):
        """Alias for LockUserChanges"""
        return self.LockUserChanges

    @lockuserchanges.setter
    def lockuserchanges(self, value):
        """Alias for LockUserChanges.setter"""
        self.LockUserChanges = value

    @property
    def lock_user_changes(self):
        """Alias for LockUserChanges"""
        return self.LockUserChanges

    @lock_user_changes.setter
    def lock_user_changes(self, value):
        """Alias for LockUserChanges.setter"""
        self.LockUserChanges = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SaveOption(self):
        return OlViewSaveOption(self.com_object.SaveOption)

    @property
    def saveoption(self):
        """Alias for SaveOption"""
        return self.SaveOption

    @property
    def save_option(self):
        """Alias for SaveOption"""
        return self.SaveOption

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def SortFields(self):
        return OrderFields(self.com_object.SortFields)

    @property
    def sortfields(self):
        """Alias for SortFields"""
        return self.SortFields

    @property
    def sort_fields(self):
        """Alias for SortFields"""
        return self.SortFields

    @property
    def Standard(self):
        return BusinessCardView(self.com_object.Standard)

    @property
    def standard(self):
        """Alias for Standard"""
        return self.Standard

    @property
    def ViewType(self):
        return OlViewType(self.com_object.ViewType)

    @property
    def viewtype(self):
        """Alias for ViewType"""
        return self.ViewType

    @property
    def view_type(self):
        """Alias for ViewType"""
        return self.ViewType

    @property
    def XML(self):
        return self.com_object.XML

    @XML.setter
    def XML(self, value):
        self.com_object.XML = value

    @property
    def xml(self):
        """Alias for XML"""
        return self.XML

    @xml.setter
    def xml(self, value):
        """Alias for XML.setter"""
        self.XML = value

    @property
    def x_m_l(self):
        """Alias for XML"""
        return self.XML

    @x_m_l.setter
    def x_m_l(self, value):
        """Alias for XML.setter"""
        self.XML = value

    def Apply(self):
        self.com_object.Apply()

    def apply(self):
        """Alias for Apply"""
        return self.Apply()

    def Copy(self, Name=None, SaveOption=None):
        arguments = com_arguments([unwrap(a) for a in [Name, SaveOption]])
        return View(self.com_object.Copy(*arguments))

    def copy(self, Name=None, SaveOption=None):
        """Alias for Copy"""
        arguments = [Name, SaveOption]
        return self.Copy(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def GoToDate(self, Date=None):
        arguments = com_arguments([unwrap(a) for a in [Date]])
        self.com_object.GoToDate(*arguments)

    def gotodate(self, Date=None):
        """Alias for GoToDate"""
        arguments = [Date]
        return self.GoToDate(*arguments)

    def go_to_date(self, Date=None):
        """Alias for GoToDate"""
        arguments = [Date]
        return self.GoToDate(*arguments)

    def Reset(self):
        self.com_object.Reset()

    def reset(self):
        """Alias for Reset"""
        return self.Reset()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()


class CalendarModule:

    def __init__(self, calendarmodule=None):
        self.com_object= calendarmodule

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Name(self):
        return CalendarModule(self.com_object.Name)

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NavigationGroups(self):
        return NavigationGroups(self.com_object.NavigationGroups)

    @property
    def navigationgroups(self):
        """Alias for NavigationGroups"""
        return self.NavigationGroups

    @property
    def navigation_groups(self):
        """Alias for NavigationGroups"""
        return self.NavigationGroups

    @property
    def NavigationModuleType(self):
        return OlNavigationModuleType(self.com_object.NavigationModuleType)

    @property
    def navigationmoduletype(self):
        """Alias for NavigationModuleType"""
        return self.NavigationModuleType

    @property
    def navigation_module_type(self):
        """Alias for NavigationModuleType"""
        return self.NavigationModuleType

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return CalendarModule(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Visible(self):
        return CalendarModule(self.com_object.Visible)

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value


class CalendarSharing:

    def __init__(self, calendarsharing=None):
        self.com_object= calendarsharing

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def CalendarDetail(self):
        return OlCalendarDetail(self.com_object.CalendarDetail)

    @CalendarDetail.setter
    def CalendarDetail(self, value):
        self.com_object.CalendarDetail = value

    @property
    def calendardetail(self):
        """Alias for CalendarDetail"""
        return self.CalendarDetail

    @calendardetail.setter
    def calendardetail(self, value):
        """Alias for CalendarDetail.setter"""
        self.CalendarDetail = value

    @property
    def calendar_detail(self):
        """Alias for CalendarDetail"""
        return self.CalendarDetail

    @calendar_detail.setter
    def calendar_detail(self, value):
        """Alias for CalendarDetail.setter"""
        self.CalendarDetail = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def EndDate(self):
        return CalendarSharing(self.com_object.EndDate)

    @EndDate.setter
    def EndDate(self, value):
        self.com_object.EndDate = value

    @property
    def enddate(self):
        """Alias for EndDate"""
        return self.EndDate

    @enddate.setter
    def enddate(self, value):
        """Alias for EndDate.setter"""
        self.EndDate = value

    @property
    def end_date(self):
        """Alias for EndDate"""
        return self.EndDate

    @end_date.setter
    def end_date(self, value):
        """Alias for EndDate.setter"""
        self.EndDate = value

    @property
    def Folder(self):
        return Folder(self.com_object.Folder)

    @property
    def folder(self):
        """Alias for Folder"""
        return self.Folder

    @property
    def IncludeAttachments(self):
        return self.com_object.IncludeAttachments

    @IncludeAttachments.setter
    def IncludeAttachments(self, value):
        self.com_object.IncludeAttachments = value

    @property
    def includeattachments(self):
        """Alias for IncludeAttachments"""
        return self.IncludeAttachments

    @includeattachments.setter
    def includeattachments(self, value):
        """Alias for IncludeAttachments.setter"""
        self.IncludeAttachments = value

    @property
    def include_attachments(self):
        """Alias for IncludeAttachments"""
        return self.IncludeAttachments

    @include_attachments.setter
    def include_attachments(self, value):
        """Alias for IncludeAttachments.setter"""
        self.IncludeAttachments = value

    @property
    def IncludePrivateDetails(self):
        return self.com_object.IncludePrivateDetails

    @IncludePrivateDetails.setter
    def IncludePrivateDetails(self, value):
        self.com_object.IncludePrivateDetails = value

    @property
    def includeprivatedetails(self):
        """Alias for IncludePrivateDetails"""
        return self.IncludePrivateDetails

    @includeprivatedetails.setter
    def includeprivatedetails(self, value):
        """Alias for IncludePrivateDetails.setter"""
        self.IncludePrivateDetails = value

    @property
    def include_private_details(self):
        """Alias for IncludePrivateDetails"""
        return self.IncludePrivateDetails

    @include_private_details.setter
    def include_private_details(self, value):
        """Alias for IncludePrivateDetails.setter"""
        self.IncludePrivateDetails = value

    @property
    def IncludeWholeCalendar(self):
        return self.com_object.IncludeWholeCalendar

    @IncludeWholeCalendar.setter
    def IncludeWholeCalendar(self, value):
        self.com_object.IncludeWholeCalendar = value

    @property
    def includewholecalendar(self):
        """Alias for IncludeWholeCalendar"""
        return self.IncludeWholeCalendar

    @includewholecalendar.setter
    def includewholecalendar(self, value):
        """Alias for IncludeWholeCalendar.setter"""
        self.IncludeWholeCalendar = value

    @property
    def include_whole_calendar(self):
        """Alias for IncludeWholeCalendar"""
        return self.IncludeWholeCalendar

    @include_whole_calendar.setter
    def include_whole_calendar(self, value):
        """Alias for IncludeWholeCalendar.setter"""
        self.IncludeWholeCalendar = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RestrictToWorkingHours(self):
        return self.com_object.RestrictToWorkingHours

    @RestrictToWorkingHours.setter
    def RestrictToWorkingHours(self, value):
        self.com_object.RestrictToWorkingHours = value

    @property
    def restricttoworkinghours(self):
        """Alias for RestrictToWorkingHours"""
        return self.RestrictToWorkingHours

    @restricttoworkinghours.setter
    def restricttoworkinghours(self, value):
        """Alias for RestrictToWorkingHours.setter"""
        self.RestrictToWorkingHours = value

    @property
    def restrict_to_working_hours(self):
        """Alias for RestrictToWorkingHours"""
        return self.RestrictToWorkingHours

    @restrict_to_working_hours.setter
    def restrict_to_working_hours(self, value):
        """Alias for RestrictToWorkingHours.setter"""
        self.RestrictToWorkingHours = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def StartDate(self):
        return CalendarSharing(self.com_object.StartDate)

    @StartDate.setter
    def StartDate(self, value):
        self.com_object.StartDate = value

    @property
    def startdate(self):
        """Alias for StartDate"""
        return self.StartDate

    @startdate.setter
    def startdate(self, value):
        """Alias for StartDate.setter"""
        self.StartDate = value

    @property
    def start_date(self):
        """Alias for StartDate"""
        return self.StartDate

    @start_date.setter
    def start_date(self, value):
        """Alias for StartDate.setter"""
        self.StartDate = value

    def ForwardAsICal(self, MailFormat=None):
        arguments = com_arguments([unwrap(a) for a in [MailFormat]])
        return MailItem(self.com_object.ForwardAsICal(*arguments))

    def forwardasical(self, MailFormat=None):
        """Alias for ForwardAsICal"""
        arguments = [MailFormat]
        return self.ForwardAsICal(*arguments)

    def forward_as_i_cal(self, MailFormat=None):
        """Alias for ForwardAsICal"""
        arguments = [MailFormat]
        return self.ForwardAsICal(*arguments)

    def SaveAsICal(self, Path=None):
        arguments = com_arguments([unwrap(a) for a in [Path]])
        self.com_object.SaveAsICal(*arguments)

    def saveasical(self, Path=None):
        """Alias for SaveAsICal"""
        arguments = [Path]
        return self.SaveAsICal(*arguments)

    def save_as_i_cal(self, Path=None):
        """Alias for SaveAsICal"""
        arguments = [Path]
        return self.SaveAsICal(*arguments)


class CalendarView:

    def __init__(self, calendarview=None):
        self.com_object= calendarview

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoFormatRules(self):
        return AutoFormatRules(self.com_object.AutoFormatRules)

    @property
    def autoformatrules(self):
        """Alias for AutoFormatRules"""
        return self.AutoFormatRules

    @property
    def auto_format_rules(self):
        """Alias for AutoFormatRules"""
        return self.AutoFormatRules

    @property
    def BoldDatesWithItems(self):
        return CalendarView(self.com_object.BoldDatesWithItems)

    @BoldDatesWithItems.setter
    def BoldDatesWithItems(self, value):
        self.com_object.BoldDatesWithItems = value

    @property
    def bolddateswithitems(self):
        """Alias for BoldDatesWithItems"""
        return self.BoldDatesWithItems

    @bolddateswithitems.setter
    def bolddateswithitems(self, value):
        """Alias for BoldDatesWithItems.setter"""
        self.BoldDatesWithItems = value

    @property
    def bold_dates_with_items(self):
        """Alias for BoldDatesWithItems"""
        return self.BoldDatesWithItems

    @bold_dates_with_items.setter
    def bold_dates_with_items(self, value):
        """Alias for BoldDatesWithItems.setter"""
        self.BoldDatesWithItems = value

    @property
    def BoldSubjects(self):
        return CalendarView(self.com_object.BoldSubjects)

    @BoldSubjects.setter
    def BoldSubjects(self, value):
        self.com_object.BoldSubjects = value

    @property
    def boldsubjects(self):
        """Alias for BoldSubjects"""
        return self.BoldSubjects

    @boldsubjects.setter
    def boldsubjects(self, value):
        """Alias for BoldSubjects.setter"""
        self.BoldSubjects = value

    @property
    def bold_subjects(self):
        """Alias for BoldSubjects"""
        return self.BoldSubjects

    @bold_subjects.setter
    def bold_subjects(self, value):
        """Alias for BoldSubjects.setter"""
        self.BoldSubjects = value

    @property
    def CalendarViewMode(self):
        return OlCalendarViewMode(self.com_object.CalendarViewMode)

    @CalendarViewMode.setter
    def CalendarViewMode(self, value):
        self.com_object.CalendarViewMode = value

    @property
    def calendarviewmode(self):
        """Alias for CalendarViewMode"""
        return self.CalendarViewMode

    @calendarviewmode.setter
    def calendarviewmode(self, value):
        """Alias for CalendarViewMode.setter"""
        self.CalendarViewMode = value

    @property
    def calendar_view_mode(self):
        """Alias for CalendarViewMode"""
        return self.CalendarViewMode

    @calendar_view_mode.setter
    def calendar_view_mode(self, value):
        """Alias for CalendarViewMode.setter"""
        self.CalendarViewMode = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def DaysInMultiDayMode(self):
        return CalendarView(self.com_object.DaysInMultiDayMode)

    @DaysInMultiDayMode.setter
    def DaysInMultiDayMode(self, value):
        self.com_object.DaysInMultiDayMode = value

    @property
    def daysinmultidaymode(self):
        """Alias for DaysInMultiDayMode"""
        return self.DaysInMultiDayMode

    @daysinmultidaymode.setter
    def daysinmultidaymode(self, value):
        """Alias for DaysInMultiDayMode.setter"""
        self.DaysInMultiDayMode = value

    @property
    def days_in_multi_day_mode(self):
        """Alias for DaysInMultiDayMode"""
        return self.DaysInMultiDayMode

    @days_in_multi_day_mode.setter
    def days_in_multi_day_mode(self, value):
        """Alias for DaysInMultiDayMode.setter"""
        self.DaysInMultiDayMode = value

    @property
    def DayWeekTimeScale(self):
        return OlDayWeekTimeScale(self.com_object.DayWeekTimeScale)

    @DayWeekTimeScale.setter
    def DayWeekTimeScale(self, value):
        self.com_object.DayWeekTimeScale = value

    @property
    def dayweektimescale(self):
        """Alias for DayWeekTimeScale"""
        return self.DayWeekTimeScale

    @dayweektimescale.setter
    def dayweektimescale(self, value):
        """Alias for DayWeekTimeScale.setter"""
        self.DayWeekTimeScale = value

    @property
    def day_week_time_scale(self):
        """Alias for DayWeekTimeScale"""
        return self.DayWeekTimeScale

    @day_week_time_scale.setter
    def day_week_time_scale(self, value):
        """Alias for DayWeekTimeScale.setter"""
        self.DayWeekTimeScale = value

    @property
    def DisplayedDates(self):
        return CalendarView(self.com_object.DisplayedDates)

    @property
    def displayeddates(self):
        """Alias for DisplayedDates"""
        return self.DisplayedDates

    @property
    def displayed_dates(self):
        """Alias for DisplayedDates"""
        return self.DisplayedDates

    @property
    def EndField(self):
        return CalendarView(self.com_object.EndField)

    @EndField.setter
    def EndField(self, value):
        self.com_object.EndField = value

    @property
    def endfield(self):
        """Alias for EndField"""
        return self.EndField

    @endfield.setter
    def endfield(self, value):
        """Alias for EndField.setter"""
        self.EndField = value

    @property
    def end_field(self):
        """Alias for EndField"""
        return self.EndField

    @end_field.setter
    def end_field(self, value):
        """Alias for EndField.setter"""
        self.EndField = value

    @property
    def Filter(self):
        return self.com_object.Filter

    @Filter.setter
    def Filter(self, value):
        self.com_object.Filter = value

    @property
    def filter(self):
        """Alias for Filter"""
        return self.Filter

    @filter.setter
    def filter(self, value):
        """Alias for Filter.setter"""
        self.Filter = value

    @property
    def Language(self):
        return self.com_object.Language

    @Language.setter
    def Language(self, value):
        self.com_object.Language = value

    @property
    def language(self):
        """Alias for Language"""
        return self.Language

    @language.setter
    def language(self, value):
        """Alias for Language.setter"""
        self.Language = value

    @property
    def LockUserChanges(self):
        return self.com_object.LockUserChanges

    @LockUserChanges.setter
    def LockUserChanges(self, value):
        self.com_object.LockUserChanges = value

    @property
    def lockuserchanges(self):
        """Alias for LockUserChanges"""
        return self.LockUserChanges

    @lockuserchanges.setter
    def lockuserchanges(self, value):
        """Alias for LockUserChanges.setter"""
        self.LockUserChanges = value

    @property
    def lock_user_changes(self):
        """Alias for LockUserChanges"""
        return self.LockUserChanges

    @lock_user_changes.setter
    def lock_user_changes(self, value):
        """Alias for LockUserChanges.setter"""
        self.LockUserChanges = value

    @property
    def MonthShowEndTime(self):
        return CalendarView(self.com_object.MonthShowEndTime)

    @MonthShowEndTime.setter
    def MonthShowEndTime(self, value):
        self.com_object.MonthShowEndTime = value

    @property
    def monthshowendtime(self):
        """Alias for MonthShowEndTime"""
        return self.MonthShowEndTime

    @monthshowendtime.setter
    def monthshowendtime(self, value):
        """Alias for MonthShowEndTime.setter"""
        self.MonthShowEndTime = value

    @property
    def month_show_end_time(self):
        """Alias for MonthShowEndTime"""
        return self.MonthShowEndTime

    @month_show_end_time.setter
    def month_show_end_time(self, value):
        """Alias for MonthShowEndTime.setter"""
        self.MonthShowEndTime = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SaveOption(self):
        return OlViewSaveOption(self.com_object.SaveOption)

    @property
    def saveoption(self):
        """Alias for SaveOption"""
        return self.SaveOption

    @property
    def save_option(self):
        """Alias for SaveOption"""
        return self.SaveOption

    @property
    def SelectedEndTime(self):
        return CalendarView(self.com_object.SelectedEndTime)

    @property
    def selectedendtime(self):
        """Alias for SelectedEndTime"""
        return self.SelectedEndTime

    @property
    def selected_end_time(self):
        """Alias for SelectedEndTime"""
        return self.SelectedEndTime

    @property
    def SelectedStartTime(self):
        return CalendarView(self.com_object.SelectedStartTime)

    @property
    def selectedstarttime(self):
        """Alias for SelectedStartTime"""
        return self.SelectedStartTime

    @property
    def selected_start_time(self):
        """Alias for SelectedStartTime"""
        return self.SelectedStartTime

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Standard(self):
        return CalendarView(self.com_object.Standard)

    @property
    def standard(self):
        """Alias for Standard"""
        return self.Standard

    @property
    def StartField(self):
        return CalendarView(self.com_object.StartField)

    @StartField.setter
    def StartField(self, value):
        self.com_object.StartField = value

    @property
    def startfield(self):
        """Alias for StartField"""
        return self.StartField

    @startfield.setter
    def startfield(self, value):
        """Alias for StartField.setter"""
        self.StartField = value

    @property
    def start_field(self):
        """Alias for StartField"""
        return self.StartField

    @start_field.setter
    def start_field(self, value):
        """Alias for StartField.setter"""
        self.StartField = value

    @property
    def ViewType(self):
        return OlViewType(self.com_object.ViewType)

    @property
    def viewtype(self):
        """Alias for ViewType"""
        return self.ViewType

    @property
    def view_type(self):
        """Alias for ViewType"""
        return self.ViewType

    @property
    def XML(self):
        return self.com_object.XML

    @XML.setter
    def XML(self, value):
        self.com_object.XML = value

    @property
    def xml(self):
        """Alias for XML"""
        return self.XML

    @xml.setter
    def xml(self, value):
        """Alias for XML.setter"""
        self.XML = value

    @property
    def x_m_l(self):
        """Alias for XML"""
        return self.XML

    @x_m_l.setter
    def x_m_l(self, value):
        """Alias for XML.setter"""
        self.XML = value

    def Apply(self):
        self.com_object.Apply()

    def apply(self):
        """Alias for Apply"""
        return self.Apply()

    def Copy(self, Name=None, SaveOption=None):
        arguments = com_arguments([unwrap(a) for a in [Name, SaveOption]])
        return View(self.com_object.Copy(*arguments))

    def copy(self, Name=None, SaveOption=None):
        """Alias for Copy"""
        arguments = [Name, SaveOption]
        return self.Copy(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def GoToDate(self, Date=None):
        arguments = com_arguments([unwrap(a) for a in [Date]])
        self.com_object.GoToDate(*arguments)

    def gotodate(self, Date=None):
        """Alias for GoToDate"""
        arguments = [Date]
        return self.GoToDate(*arguments)

    def go_to_date(self, Date=None):
        """Alias for GoToDate"""
        arguments = [Date]
        return self.GoToDate(*arguments)

    def Reset(self):
        self.com_object.Reset()

    def reset(self):
        """Alias for Reset"""
        return self.Reset()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()


class CardView:

    def __init__(self, cardview=None):
        self.com_object= cardview

    @property
    def AllowInCellEditing(self):
        return CardView(self.com_object.AllowInCellEditing)

    @AllowInCellEditing.setter
    def AllowInCellEditing(self, value):
        self.com_object.AllowInCellEditing = value

    @property
    def allowincellediting(self):
        """Alias for AllowInCellEditing"""
        return self.AllowInCellEditing

    @allowincellediting.setter
    def allowincellediting(self, value):
        """Alias for AllowInCellEditing.setter"""
        self.AllowInCellEditing = value

    @property
    def allow_in_cell_editing(self):
        """Alias for AllowInCellEditing"""
        return self.AllowInCellEditing

    @allow_in_cell_editing.setter
    def allow_in_cell_editing(self, value):
        """Alias for AllowInCellEditing.setter"""
        self.AllowInCellEditing = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoFormatRules(self):
        return AutoFormatRules(self.com_object.AutoFormatRules)

    @property
    def autoformatrules(self):
        """Alias for AutoFormatRules"""
        return self.AutoFormatRules

    @property
    def auto_format_rules(self):
        """Alias for AutoFormatRules"""
        return self.AutoFormatRules

    @property
    def BodyFont(self):
        return ViewFont(self.com_object.BodyFont)

    @property
    def bodyfont(self):
        """Alias for BodyFont"""
        return self.BodyFont

    @property
    def body_font(self):
        """Alias for BodyFont"""
        return self.BodyFont

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Filter(self):
        return self.com_object.Filter

    @Filter.setter
    def Filter(self, value):
        self.com_object.Filter = value

    @property
    def filter(self):
        """Alias for Filter"""
        return self.Filter

    @filter.setter
    def filter(self, value):
        """Alias for Filter.setter"""
        self.Filter = value

    @property
    def HeadingsFont(self):
        return ViewFont(self.com_object.HeadingsFont)

    @property
    def headingsfont(self):
        """Alias for HeadingsFont"""
        return self.HeadingsFont

    @property
    def headings_font(self):
        """Alias for HeadingsFont"""
        return self.HeadingsFont

    @property
    def Language(self):
        return self.com_object.Language

    @Language.setter
    def Language(self, value):
        self.com_object.Language = value

    @property
    def language(self):
        """Alias for Language"""
        return self.Language

    @language.setter
    def language(self, value):
        """Alias for Language.setter"""
        self.Language = value

    @property
    def LockUserChanges(self):
        return self.com_object.LockUserChanges

    @LockUserChanges.setter
    def LockUserChanges(self, value):
        self.com_object.LockUserChanges = value

    @property
    def lockuserchanges(self):
        """Alias for LockUserChanges"""
        return self.LockUserChanges

    @lockuserchanges.setter
    def lockuserchanges(self, value):
        """Alias for LockUserChanges.setter"""
        self.LockUserChanges = value

    @property
    def lock_user_changes(self):
        """Alias for LockUserChanges"""
        return self.LockUserChanges

    @lock_user_changes.setter
    def lock_user_changes(self, value):
        """Alias for LockUserChanges.setter"""
        self.LockUserChanges = value

    @property
    def MultiLineFieldHeight(self):
        return CardView(self.com_object.MultiLineFieldHeight)

    @MultiLineFieldHeight.setter
    def MultiLineFieldHeight(self, value):
        self.com_object.MultiLineFieldHeight = value

    @property
    def multilinefieldheight(self):
        """Alias for MultiLineFieldHeight"""
        return self.MultiLineFieldHeight

    @multilinefieldheight.setter
    def multilinefieldheight(self, value):
        """Alias for MultiLineFieldHeight.setter"""
        self.MultiLineFieldHeight = value

    @property
    def multi_line_field_height(self):
        """Alias for MultiLineFieldHeight"""
        return self.MultiLineFieldHeight

    @multi_line_field_height.setter
    def multi_line_field_height(self, value):
        """Alias for MultiLineFieldHeight.setter"""
        self.MultiLineFieldHeight = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SaveOption(self):
        return OlViewSaveOption(self.com_object.SaveOption)

    @property
    def saveoption(self):
        """Alias for SaveOption"""
        return self.SaveOption

    @property
    def save_option(self):
        """Alias for SaveOption"""
        return self.SaveOption

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def ShowEmptyFields(self):
        return CardView(self.com_object.ShowEmptyFields)

    @ShowEmptyFields.setter
    def ShowEmptyFields(self, value):
        self.com_object.ShowEmptyFields = value

    @property
    def showemptyfields(self):
        """Alias for ShowEmptyFields"""
        return self.ShowEmptyFields

    @showemptyfields.setter
    def showemptyfields(self, value):
        """Alias for ShowEmptyFields.setter"""
        self.ShowEmptyFields = value

    @property
    def show_empty_fields(self):
        """Alias for ShowEmptyFields"""
        return self.ShowEmptyFields

    @show_empty_fields.setter
    def show_empty_fields(self, value):
        """Alias for ShowEmptyFields.setter"""
        self.ShowEmptyFields = value

    @property
    def SortFields(self):
        return OrderFields(self.com_object.SortFields)

    @property
    def sortfields(self):
        """Alias for SortFields"""
        return self.SortFields

    @property
    def sort_fields(self):
        """Alias for SortFields"""
        return self.SortFields

    @property
    def Standard(self):
        return CardView(self.com_object.Standard)

    @property
    def standard(self):
        """Alias for Standard"""
        return self.Standard

    @property
    def ViewFields(self):
        return ViewFields(self.com_object.ViewFields)

    @property
    def viewfields(self):
        """Alias for ViewFields"""
        return self.ViewFields

    @property
    def view_fields(self):
        """Alias for ViewFields"""
        return self.ViewFields

    @property
    def ViewType(self):
        return OlViewType(self.com_object.ViewType)

    @property
    def viewtype(self):
        """Alias for ViewType"""
        return self.ViewType

    @property
    def view_type(self):
        """Alias for ViewType"""
        return self.ViewType

    @property
    def Width(self):
        return CardView(self.com_object.Width)

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def XML(self):
        return self.com_object.XML

    @XML.setter
    def XML(self, value):
        self.com_object.XML = value

    @property
    def xml(self):
        """Alias for XML"""
        return self.XML

    @xml.setter
    def xml(self, value):
        """Alias for XML.setter"""
        self.XML = value

    @property
    def x_m_l(self):
        """Alias for XML"""
        return self.XML

    @x_m_l.setter
    def x_m_l(self, value):
        """Alias for XML.setter"""
        self.XML = value

    def Apply(self):
        self.com_object.Apply()

    def apply(self):
        """Alias for Apply"""
        return self.Apply()

    def Copy(self, Name=None, SaveOption=None):
        arguments = com_arguments([unwrap(a) for a in [Name, SaveOption]])
        return View(self.com_object.Copy(*arguments))

    def copy(self, Name=None, SaveOption=None):
        """Alias for Copy"""
        arguments = [Name, SaveOption]
        return self.Copy(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def GoToDate(self, Date=None):
        arguments = com_arguments([unwrap(a) for a in [Date]])
        self.com_object.GoToDate(*arguments)

    def gotodate(self, Date=None):
        """Alias for GoToDate"""
        arguments = [Date]
        return self.GoToDate(*arguments)

    def go_to_date(self, Date=None):
        """Alias for GoToDate"""
        arguments = [Date]
        return self.GoToDate(*arguments)

    def Reset(self):
        self.com_object.Reset()

    def reset(self):
        """Alias for Reset"""
        return self.Reset()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()


class Categories:

    def __init__(self, categories=None):
        self.com_object= categories

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return Category(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Add(self, Name=None, Color=None, ShortcutKey=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Color, ShortcutKey]])
        return Category(self.com_object.Add(*arguments))

    def add(self, Name=None, Color=None, ShortcutKey=None):
        """Alias for Add"""
        arguments = [Name, Color, ShortcutKey]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Category(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Remove(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Remove(*arguments)

    def remove(self, Index=None):
        """Alias for Remove"""
        arguments = [Index]
        return self.Remove(*arguments)


class Category:

    def __init__(self, category=None):
        self.com_object= category

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def CategoryBorderColor(self):
        return Category(self.com_object.CategoryBorderColor)

    @property
    def categorybordercolor(self):
        """Alias for CategoryBorderColor"""
        return self.CategoryBorderColor

    @property
    def category_border_color(self):
        """Alias for CategoryBorderColor"""
        return self.CategoryBorderColor

    @property
    def CategoryGradientBottomColor(self):
        return Category(self.com_object.CategoryGradientBottomColor)

    @property
    def categorygradientbottomcolor(self):
        """Alias for CategoryGradientBottomColor"""
        return self.CategoryGradientBottomColor

    @property
    def category_gradient_bottom_color(self):
        """Alias for CategoryGradientBottomColor"""
        return self.CategoryGradientBottomColor

    @property
    def CategoryGradientTopColor(self):
        return Category(self.com_object.CategoryGradientTopColor)

    @property
    def categorygradienttopcolor(self):
        """Alias for CategoryGradientTopColor"""
        return self.CategoryGradientTopColor

    @property
    def category_gradient_top_color(self):
        """Alias for CategoryGradientTopColor"""
        return self.CategoryGradientTopColor

    @property
    def CategoryID(self):
        return Category(self.com_object.CategoryID)

    @property
    def categoryid(self):
        """Alias for CategoryID"""
        return self.CategoryID

    @property
    def category_i_d(self):
        """Alias for CategoryID"""
        return self.CategoryID

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Color(self):
        return OlCategoryColor(self.com_object.Color)

    @Color.setter
    def Color(self, value):
        self.com_object.Color = value

    @property
    def color(self):
        """Alias for Color"""
        return self.Color

    @color.setter
    def color(self, value):
        """Alias for Color.setter"""
        self.Color = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def ShortcutKey(self):
        return OlCategoryShortcutKey(self.com_object.ShortcutKey)

    @ShortcutKey.setter
    def ShortcutKey(self, value):
        self.com_object.ShortcutKey = value

    @property
    def shortcutkey(self):
        """Alias for ShortcutKey"""
        return self.ShortcutKey

    @shortcutkey.setter
    def shortcutkey(self, value):
        """Alias for ShortcutKey.setter"""
        self.ShortcutKey = value

    @property
    def shortcut_key(self):
        """Alias for ShortcutKey"""
        return self.ShortcutKey

    @shortcut_key.setter
    def shortcut_key(self, value):
        """Alias for ShortcutKey.setter"""
        self.ShortcutKey = value


class CategoryRuleCondition:

    def __init__(self, categoryrulecondition=None):
        self.com_object= categoryrulecondition

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Categories(self):
        return self.com_object.Categories

    @Categories.setter
    def Categories(self, value):
        self.com_object.Categories = value

    @property
    def categories(self):
        """Alias for Categories"""
        return self.Categories

    @categories.setter
    def categories(self, value):
        """Alias for Categories.setter"""
        self.Categories = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def ConditionType(self):
        return OlRuleConditionType(self.com_object.ConditionType)

    @property
    def conditiontype(self):
        """Alias for ConditionType"""
        return self.ConditionType

    @property
    def condition_type(self):
        """Alias for ConditionType"""
        return self.ConditionType

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session


class CheckBox:

    def __init__(self, checkbox=None):
        self.com_object= checkbox


class Column:

    def __init__(self, column=None):
        self.com_object= column

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Name(self):
        return Column(self.com_object.Name)

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return Column(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session


class ColumnFormat:

    def __init__(self, columnformat=None):
        self.com_object= columnformat

    @property
    def Align(self):
        return OlAlign(self.com_object.Align)

    @Align.setter
    def Align(self, value):
        self.com_object.Align = value

    @property
    def align(self):
        """Alias for Align"""
        return self.Align

    @align.setter
    def align(self, value):
        """Alias for Align.setter"""
        self.Align = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def FieldFormat(self):
        return ColumnFormat(self.com_object.FieldFormat)

    @FieldFormat.setter
    def FieldFormat(self, value):
        self.com_object.FieldFormat = value

    @property
    def fieldformat(self):
        """Alias for FieldFormat"""
        return self.FieldFormat

    @fieldformat.setter
    def fieldformat(self, value):
        """Alias for FieldFormat.setter"""
        self.FieldFormat = value

    @property
    def field_format(self):
        """Alias for FieldFormat"""
        return self.FieldFormat

    @field_format.setter
    def field_format(self, value):
        """Alias for FieldFormat.setter"""
        self.FieldFormat = value

    @property
    def FieldType(self):
        return OlUserPropertyType(self.com_object.FieldType)

    @property
    def fieldtype(self):
        """Alias for FieldType"""
        return self.FieldType

    @property
    def field_type(self):
        """Alias for FieldType"""
        return self.FieldType

    @property
    def Label(self):
        return ColumnFormat(self.com_object.Label)

    @Label.setter
    def Label(self, value):
        self.com_object.Label = value

    @property
    def label(self):
        """Alias for Label"""
        return self.Label

    @label.setter
    def label(self, value):
        """Alias for Label.setter"""
        self.Label = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value


class Columns:

    def __init__(self, columns=None):
        self.com_object= columns

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return Column(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return Columns(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Add(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        return Column(self.com_object.Add(*arguments))

    def add(self, Name=None):
        """Alias for Add"""
        arguments = [Name]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Remove(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Remove(*arguments)

    def remove(self, Index=None):
        """Alias for Remove"""
        arguments = [Index]
        return self.Remove(*arguments)

    def RemoveAll(self):
        self.com_object.RemoveAll()

    def removeall(self):
        """Alias for RemoveAll"""
        return self.RemoveAll()

    def remove_all(self):
        """Alias for RemoveAll"""
        return self.RemoveAll()


class ComboBox:

    def __init__(self, combobox=None):
        self.com_object= combobox


class CommandButton:

    def __init__(self, commandbutton=None):
        self.com_object= commandbutton


class Conflict:

    def __init__(self, conflict=None):
        self.com_object= conflict

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Item(self):
        return self.com_object.Item

    @property
    def item(self):
        """Alias for Item"""
        return self.Item

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Type(self):
        return OlObjectClass(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type


class Conflicts:

    def __init__(self, conflicts=None):
        self.com_object= conflicts

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def GetFirst(self):
        return Conflict(self.com_object.GetFirst())

    def getfirst(self):
        """Alias for GetFirst"""
        return self.GetFirst()

    def get_first(self):
        """Alias for GetFirst"""
        return self.GetFirst()

    def GetLast(self):
        return Conflict(self.com_object.GetLast())

    def getlast(self):
        """Alias for GetLast"""
        return self.GetLast()

    def get_last(self):
        """Alias for GetLast"""
        return self.GetLast()

    def GetNext(self):
        return Conflict(self.com_object.GetNext())

    def getnext(self):
        """Alias for GetNext"""
        return self.GetNext()

    def get_next(self):
        """Alias for GetNext"""
        return self.GetNext()

    def GetPrevious(self):
        return Conflict(self.com_object.GetPrevious())

    def getprevious(self):
        """Alias for GetPrevious"""
        return self.GetPrevious()

    def get_previous(self):
        """Alias for GetPrevious"""
        return self.GetPrevious()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Conflict(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ContactItem:

    def __init__(self, contactitem=None):
        self.com_object= contactitem

    @property
    def Account(self):
        return self.com_object.Account

    @Account.setter
    def Account(self, value):
        self.com_object.Account = value

    @property
    def account(self):
        """Alias for Account"""
        return self.Account

    @account.setter
    def account(self, value):
        """Alias for Account.setter"""
        self.Account = value

    @property
    def Actions(self):
        return Actions(self.com_object.Actions)

    @property
    def actions(self):
        """Alias for Actions"""
        return self.Actions

    @property
    def Anniversary(self):
        return self.com_object.Anniversary

    @Anniversary.setter
    def Anniversary(self, value):
        self.com_object.Anniversary = value

    @property
    def anniversary(self):
        """Alias for Anniversary"""
        return self.Anniversary

    @anniversary.setter
    def anniversary(self, value):
        """Alias for Anniversary.setter"""
        self.Anniversary = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AssistantName(self):
        return self.com_object.AssistantName

    @AssistantName.setter
    def AssistantName(self, value):
        self.com_object.AssistantName = value

    @property
    def assistantname(self):
        """Alias for AssistantName"""
        return self.AssistantName

    @assistantname.setter
    def assistantname(self, value):
        """Alias for AssistantName.setter"""
        self.AssistantName = value

    @property
    def assistant_name(self):
        """Alias for AssistantName"""
        return self.AssistantName

    @assistant_name.setter
    def assistant_name(self, value):
        """Alias for AssistantName.setter"""
        self.AssistantName = value

    @property
    def AssistantTelephoneNumber(self):
        return self.com_object.AssistantTelephoneNumber

    @AssistantTelephoneNumber.setter
    def AssistantTelephoneNumber(self, value):
        self.com_object.AssistantTelephoneNumber = value

    @property
    def assistanttelephonenumber(self):
        """Alias for AssistantTelephoneNumber"""
        return self.AssistantTelephoneNumber

    @assistanttelephonenumber.setter
    def assistanttelephonenumber(self, value):
        """Alias for AssistantTelephoneNumber.setter"""
        self.AssistantTelephoneNumber = value

    @property
    def assistant_telephone_number(self):
        """Alias for AssistantTelephoneNumber"""
        return self.AssistantTelephoneNumber

    @assistant_telephone_number.setter
    def assistant_telephone_number(self, value):
        """Alias for AssistantTelephoneNumber.setter"""
        self.AssistantTelephoneNumber = value

    @property
    def Attachments(self):
        return Attachments(self.com_object.Attachments)

    @property
    def attachments(self):
        """Alias for Attachments"""
        return self.Attachments

    @property
    def AutoResolvedWinner(self):
        return self.com_object.AutoResolvedWinner

    @property
    def autoresolvedwinner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def auto_resolved_winner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def BillingInformation(self):
        return self.com_object.BillingInformation

    @BillingInformation.setter
    def BillingInformation(self, value):
        self.com_object.BillingInformation = value

    @property
    def billinginformation(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billinginformation.setter
    def billinginformation(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def billing_information(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billing_information.setter
    def billing_information(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def Birthday(self):
        return self.com_object.Birthday

    @Birthday.setter
    def Birthday(self, value):
        self.com_object.Birthday = value

    @property
    def birthday(self):
        """Alias for Birthday"""
        return self.Birthday

    @birthday.setter
    def birthday(self, value):
        """Alias for Birthday.setter"""
        self.Birthday = value

    @property
    def Body(self):
        return self.com_object.Body

    @Body.setter
    def Body(self, value):
        self.com_object.Body = value

    @property
    def body(self):
        """Alias for Body"""
        return self.Body

    @body.setter
    def body(self, value):
        """Alias for Body.setter"""
        self.Body = value

    @property
    def Business2TelephoneNumber(self):
        return self.com_object.Business2TelephoneNumber

    @Business2TelephoneNumber.setter
    def Business2TelephoneNumber(self, value):
        self.com_object.Business2TelephoneNumber = value

    @property
    def business2telephonenumber(self):
        """Alias for Business2TelephoneNumber"""
        return self.Business2TelephoneNumber

    @business2telephonenumber.setter
    def business2telephonenumber(self, value):
        """Alias for Business2TelephoneNumber.setter"""
        self.Business2TelephoneNumber = value

    @property
    def business2_telephone_number(self):
        """Alias for Business2TelephoneNumber"""
        return self.Business2TelephoneNumber

    @business2_telephone_number.setter
    def business2_telephone_number(self, value):
        """Alias for Business2TelephoneNumber.setter"""
        self.Business2TelephoneNumber = value

    @property
    def BusinessAddress(self):
        return self.com_object.BusinessAddress

    @BusinessAddress.setter
    def BusinessAddress(self, value):
        self.com_object.BusinessAddress = value

    @property
    def businessaddress(self):
        """Alias for BusinessAddress"""
        return self.BusinessAddress

    @businessaddress.setter
    def businessaddress(self, value):
        """Alias for BusinessAddress.setter"""
        self.BusinessAddress = value

    @property
    def business_address(self):
        """Alias for BusinessAddress"""
        return self.BusinessAddress

    @business_address.setter
    def business_address(self, value):
        """Alias for BusinessAddress.setter"""
        self.BusinessAddress = value

    @property
    def BusinessAddressCity(self):
        return self.com_object.BusinessAddressCity

    @BusinessAddressCity.setter
    def BusinessAddressCity(self, value):
        self.com_object.BusinessAddressCity = value

    @property
    def businessaddresscity(self):
        """Alias for BusinessAddressCity"""
        return self.BusinessAddressCity

    @businessaddresscity.setter
    def businessaddresscity(self, value):
        """Alias for BusinessAddressCity.setter"""
        self.BusinessAddressCity = value

    @property
    def business_address_city(self):
        """Alias for BusinessAddressCity"""
        return self.BusinessAddressCity

    @business_address_city.setter
    def business_address_city(self, value):
        """Alias for BusinessAddressCity.setter"""
        self.BusinessAddressCity = value

    @property
    def BusinessAddressCountry(self):
        return self.com_object.BusinessAddressCountry

    @BusinessAddressCountry.setter
    def BusinessAddressCountry(self, value):
        self.com_object.BusinessAddressCountry = value

    @property
    def businessaddresscountry(self):
        """Alias for BusinessAddressCountry"""
        return self.BusinessAddressCountry

    @businessaddresscountry.setter
    def businessaddresscountry(self, value):
        """Alias for BusinessAddressCountry.setter"""
        self.BusinessAddressCountry = value

    @property
    def business_address_country(self):
        """Alias for BusinessAddressCountry"""
        return self.BusinessAddressCountry

    @business_address_country.setter
    def business_address_country(self, value):
        """Alias for BusinessAddressCountry.setter"""
        self.BusinessAddressCountry = value

    @property
    def BusinessAddressPostalCode(self):
        return self.com_object.BusinessAddressPostalCode

    @BusinessAddressPostalCode.setter
    def BusinessAddressPostalCode(self, value):
        self.com_object.BusinessAddressPostalCode = value

    @property
    def businessaddresspostalcode(self):
        """Alias for BusinessAddressPostalCode"""
        return self.BusinessAddressPostalCode

    @businessaddresspostalcode.setter
    def businessaddresspostalcode(self, value):
        """Alias for BusinessAddressPostalCode.setter"""
        self.BusinessAddressPostalCode = value

    @property
    def business_address_postal_code(self):
        """Alias for BusinessAddressPostalCode"""
        return self.BusinessAddressPostalCode

    @business_address_postal_code.setter
    def business_address_postal_code(self, value):
        """Alias for BusinessAddressPostalCode.setter"""
        self.BusinessAddressPostalCode = value

    @property
    def BusinessAddressPostOfficeBox(self):
        return self.com_object.BusinessAddressPostOfficeBox

    @BusinessAddressPostOfficeBox.setter
    def BusinessAddressPostOfficeBox(self, value):
        self.com_object.BusinessAddressPostOfficeBox = value

    @property
    def businessaddresspostofficebox(self):
        """Alias for BusinessAddressPostOfficeBox"""
        return self.BusinessAddressPostOfficeBox

    @businessaddresspostofficebox.setter
    def businessaddresspostofficebox(self, value):
        """Alias for BusinessAddressPostOfficeBox.setter"""
        self.BusinessAddressPostOfficeBox = value

    @property
    def business_address_post_office_box(self):
        """Alias for BusinessAddressPostOfficeBox"""
        return self.BusinessAddressPostOfficeBox

    @business_address_post_office_box.setter
    def business_address_post_office_box(self, value):
        """Alias for BusinessAddressPostOfficeBox.setter"""
        self.BusinessAddressPostOfficeBox = value

    @property
    def BusinessAddressState(self):
        return self.com_object.BusinessAddressState

    @BusinessAddressState.setter
    def BusinessAddressState(self, value):
        self.com_object.BusinessAddressState = value

    @property
    def businessaddressstate(self):
        """Alias for BusinessAddressState"""
        return self.BusinessAddressState

    @businessaddressstate.setter
    def businessaddressstate(self, value):
        """Alias for BusinessAddressState.setter"""
        self.BusinessAddressState = value

    @property
    def business_address_state(self):
        """Alias for BusinessAddressState"""
        return self.BusinessAddressState

    @business_address_state.setter
    def business_address_state(self, value):
        """Alias for BusinessAddressState.setter"""
        self.BusinessAddressState = value

    @property
    def BusinessAddressStreet(self):
        return self.com_object.BusinessAddressStreet

    @BusinessAddressStreet.setter
    def BusinessAddressStreet(self, value):
        self.com_object.BusinessAddressStreet = value

    @property
    def businessaddressstreet(self):
        """Alias for BusinessAddressStreet"""
        return self.BusinessAddressStreet

    @businessaddressstreet.setter
    def businessaddressstreet(self, value):
        """Alias for BusinessAddressStreet.setter"""
        self.BusinessAddressStreet = value

    @property
    def business_address_street(self):
        """Alias for BusinessAddressStreet"""
        return self.BusinessAddressStreet

    @business_address_street.setter
    def business_address_street(self, value):
        """Alias for BusinessAddressStreet.setter"""
        self.BusinessAddressStreet = value

    @property
    def BusinessCardLayoutXml(self):
        return self.com_object.BusinessCardLayoutXml

    @BusinessCardLayoutXml.setter
    def BusinessCardLayoutXml(self, value):
        self.com_object.BusinessCardLayoutXml = value

    @property
    def businesscardlayoutxml(self):
        """Alias for BusinessCardLayoutXml"""
        return self.BusinessCardLayoutXml

    @businesscardlayoutxml.setter
    def businesscardlayoutxml(self, value):
        """Alias for BusinessCardLayoutXml.setter"""
        self.BusinessCardLayoutXml = value

    @property
    def business_card_layout_xml(self):
        """Alias for BusinessCardLayoutXml"""
        return self.BusinessCardLayoutXml

    @business_card_layout_xml.setter
    def business_card_layout_xml(self, value):
        """Alias for BusinessCardLayoutXml.setter"""
        self.BusinessCardLayoutXml = value

    @property
    def BusinessCardType(self):
        return OlBusinessCardType(self.com_object.BusinessCardType)

    @property
    def businesscardtype(self):
        """Alias for BusinessCardType"""
        return self.BusinessCardType

    @property
    def business_card_type(self):
        """Alias for BusinessCardType"""
        return self.BusinessCardType

    @property
    def BusinessFaxNumber(self):
        return self.com_object.BusinessFaxNumber

    @BusinessFaxNumber.setter
    def BusinessFaxNumber(self, value):
        self.com_object.BusinessFaxNumber = value

    @property
    def businessfaxnumber(self):
        """Alias for BusinessFaxNumber"""
        return self.BusinessFaxNumber

    @businessfaxnumber.setter
    def businessfaxnumber(self, value):
        """Alias for BusinessFaxNumber.setter"""
        self.BusinessFaxNumber = value

    @property
    def business_fax_number(self):
        """Alias for BusinessFaxNumber"""
        return self.BusinessFaxNumber

    @business_fax_number.setter
    def business_fax_number(self, value):
        """Alias for BusinessFaxNumber.setter"""
        self.BusinessFaxNumber = value

    @property
    def BusinessHomePage(self):
        return self.com_object.BusinessHomePage

    @BusinessHomePage.setter
    def BusinessHomePage(self, value):
        self.com_object.BusinessHomePage = value

    @property
    def businesshomepage(self):
        """Alias for BusinessHomePage"""
        return self.BusinessHomePage

    @businesshomepage.setter
    def businesshomepage(self, value):
        """Alias for BusinessHomePage.setter"""
        self.BusinessHomePage = value

    @property
    def business_home_page(self):
        """Alias for BusinessHomePage"""
        return self.BusinessHomePage

    @business_home_page.setter
    def business_home_page(self, value):
        """Alias for BusinessHomePage.setter"""
        self.BusinessHomePage = value

    @property
    def BusinessTelephoneNumber(self):
        return self.com_object.BusinessTelephoneNumber

    @BusinessTelephoneNumber.setter
    def BusinessTelephoneNumber(self, value):
        self.com_object.BusinessTelephoneNumber = value

    @property
    def businesstelephonenumber(self):
        """Alias for BusinessTelephoneNumber"""
        return self.BusinessTelephoneNumber

    @businesstelephonenumber.setter
    def businesstelephonenumber(self, value):
        """Alias for BusinessTelephoneNumber.setter"""
        self.BusinessTelephoneNumber = value

    @property
    def business_telephone_number(self):
        """Alias for BusinessTelephoneNumber"""
        return self.BusinessTelephoneNumber

    @business_telephone_number.setter
    def business_telephone_number(self, value):
        """Alias for BusinessTelephoneNumber.setter"""
        self.BusinessTelephoneNumber = value

    @property
    def CallbackTelephoneNumber(self):
        return self.com_object.CallbackTelephoneNumber

    @CallbackTelephoneNumber.setter
    def CallbackTelephoneNumber(self, value):
        self.com_object.CallbackTelephoneNumber = value

    @property
    def callbacktelephonenumber(self):
        """Alias for CallbackTelephoneNumber"""
        return self.CallbackTelephoneNumber

    @callbacktelephonenumber.setter
    def callbacktelephonenumber(self, value):
        """Alias for CallbackTelephoneNumber.setter"""
        self.CallbackTelephoneNumber = value

    @property
    def callback_telephone_number(self):
        """Alias for CallbackTelephoneNumber"""
        return self.CallbackTelephoneNumber

    @callback_telephone_number.setter
    def callback_telephone_number(self, value):
        """Alias for CallbackTelephoneNumber.setter"""
        self.CallbackTelephoneNumber = value

    @property
    def CarTelephoneNumber(self):
        return self.com_object.CarTelephoneNumber

    @CarTelephoneNumber.setter
    def CarTelephoneNumber(self, value):
        self.com_object.CarTelephoneNumber = value

    @property
    def cartelephonenumber(self):
        """Alias for CarTelephoneNumber"""
        return self.CarTelephoneNumber

    @cartelephonenumber.setter
    def cartelephonenumber(self, value):
        """Alias for CarTelephoneNumber.setter"""
        self.CarTelephoneNumber = value

    @property
    def car_telephone_number(self):
        """Alias for CarTelephoneNumber"""
        return self.CarTelephoneNumber

    @car_telephone_number.setter
    def car_telephone_number(self, value):
        """Alias for CarTelephoneNumber.setter"""
        self.CarTelephoneNumber = value

    @property
    def Categories(self):
        return self.com_object.Categories

    @Categories.setter
    def Categories(self, value):
        self.com_object.Categories = value

    @property
    def categories(self):
        """Alias for Categories"""
        return self.Categories

    @categories.setter
    def categories(self, value):
        """Alias for Categories.setter"""
        self.Categories = value

    @property
    def Children(self):
        return self.com_object.Children

    @Children.setter
    def Children(self, value):
        self.com_object.Children = value

    @property
    def children(self):
        """Alias for Children"""
        return self.Children

    @children.setter
    def children(self, value):
        """Alias for Children.setter"""
        self.Children = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Companies(self):
        return self.com_object.Companies

    @Companies.setter
    def Companies(self, value):
        self.com_object.Companies = value

    @property
    def companies(self):
        """Alias for Companies"""
        return self.Companies

    @companies.setter
    def companies(self, value):
        """Alias for Companies.setter"""
        self.Companies = value

    @property
    def CompanyAndFullName(self):
        return self.com_object.CompanyAndFullName

    @property
    def companyandfullname(self):
        """Alias for CompanyAndFullName"""
        return self.CompanyAndFullName

    @property
    def company_and_full_name(self):
        """Alias for CompanyAndFullName"""
        return self.CompanyAndFullName

    @property
    def CompanyLastFirstNoSpace(self):
        return self.com_object.CompanyLastFirstNoSpace

    @property
    def companylastfirstnospace(self):
        """Alias for CompanyLastFirstNoSpace"""
        return self.CompanyLastFirstNoSpace

    @property
    def company_last_first_no_space(self):
        """Alias for CompanyLastFirstNoSpace"""
        return self.CompanyLastFirstNoSpace

    @property
    def CompanyLastFirstSpaceOnly(self):
        return self.com_object.CompanyLastFirstSpaceOnly

    @property
    def companylastfirstspaceonly(self):
        """Alias for CompanyLastFirstSpaceOnly"""
        return self.CompanyLastFirstSpaceOnly

    @property
    def company_last_first_space_only(self):
        """Alias for CompanyLastFirstSpaceOnly"""
        return self.CompanyLastFirstSpaceOnly

    @property
    def CompanyMainTelephoneNumber(self):
        return self.com_object.CompanyMainTelephoneNumber

    @CompanyMainTelephoneNumber.setter
    def CompanyMainTelephoneNumber(self, value):
        self.com_object.CompanyMainTelephoneNumber = value

    @property
    def companymaintelephonenumber(self):
        """Alias for CompanyMainTelephoneNumber"""
        return self.CompanyMainTelephoneNumber

    @companymaintelephonenumber.setter
    def companymaintelephonenumber(self, value):
        """Alias for CompanyMainTelephoneNumber.setter"""
        self.CompanyMainTelephoneNumber = value

    @property
    def company_main_telephone_number(self):
        """Alias for CompanyMainTelephoneNumber"""
        return self.CompanyMainTelephoneNumber

    @company_main_telephone_number.setter
    def company_main_telephone_number(self, value):
        """Alias for CompanyMainTelephoneNumber.setter"""
        self.CompanyMainTelephoneNumber = value

    @property
    def CompanyName(self):
        return self.com_object.CompanyName

    @CompanyName.setter
    def CompanyName(self, value):
        self.com_object.CompanyName = value

    @property
    def companyname(self):
        """Alias for CompanyName"""
        return self.CompanyName

    @companyname.setter
    def companyname(self, value):
        """Alias for CompanyName.setter"""
        self.CompanyName = value

    @property
    def company_name(self):
        """Alias for CompanyName"""
        return self.CompanyName

    @company_name.setter
    def company_name(self, value):
        """Alias for CompanyName.setter"""
        self.CompanyName = value

    @property
    def ComputerNetworkName(self):
        return self.com_object.ComputerNetworkName

    @ComputerNetworkName.setter
    def ComputerNetworkName(self, value):
        self.com_object.ComputerNetworkName = value

    @property
    def computernetworkname(self):
        """Alias for ComputerNetworkName"""
        return self.ComputerNetworkName

    @computernetworkname.setter
    def computernetworkname(self, value):
        """Alias for ComputerNetworkName.setter"""
        self.ComputerNetworkName = value

    @property
    def computer_network_name(self):
        """Alias for ComputerNetworkName"""
        return self.ComputerNetworkName

    @computer_network_name.setter
    def computer_network_name(self, value):
        """Alias for ComputerNetworkName.setter"""
        self.ComputerNetworkName = value

    @property
    def Conflicts(self):
        return self.com_object.Conflicts

    @property
    def conflicts(self):
        """Alias for Conflicts"""
        return self.Conflicts

    @property
    def ConversationID(self):
        return Conversation(self.com_object.ConversationID)

    @property
    def conversationid(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def conversation_i_d(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def ConversationIndex(self):
        return self.com_object.ConversationIndex

    @property
    def conversationindex(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def conversation_index(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def ConversationTopic(self):
        return self.com_object.ConversationTopic

    @property
    def conversationtopic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def conversation_topic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def CreationTime(self):
        return self.com_object.CreationTime

    @property
    def creationtime(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def creation_time(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def CustomerID(self):
        return self.com_object.CustomerID

    @CustomerID.setter
    def CustomerID(self, value):
        self.com_object.CustomerID = value

    @property
    def customerid(self):
        """Alias for CustomerID"""
        return self.CustomerID

    @customerid.setter
    def customerid(self, value):
        """Alias for CustomerID.setter"""
        self.CustomerID = value

    @property
    def customer_i_d(self):
        """Alias for CustomerID"""
        return self.CustomerID

    @customer_i_d.setter
    def customer_i_d(self, value):
        """Alias for CustomerID.setter"""
        self.CustomerID = value

    @property
    def Department(self):
        return self.com_object.Department

    @Department.setter
    def Department(self, value):
        self.com_object.Department = value

    @property
    def department(self):
        """Alias for Department"""
        return self.Department

    @department.setter
    def department(self, value):
        """Alias for Department.setter"""
        self.Department = value

    @property
    def DownloadState(self):
        return OlDownloadState(self.com_object.DownloadState)

    @property
    def downloadstate(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def download_state(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def Email1Address(self):
        return self.com_object.Email1Address

    @Email1Address.setter
    def Email1Address(self, value):
        self.com_object.Email1Address = value

    @property
    def email1address(self):
        """Alias for Email1Address"""
        return self.Email1Address

    @email1address.setter
    def email1address(self, value):
        """Alias for Email1Address.setter"""
        self.Email1Address = value

    @property
    def email1_address(self):
        """Alias for Email1Address"""
        return self.Email1Address

    @email1_address.setter
    def email1_address(self, value):
        """Alias for Email1Address.setter"""
        self.Email1Address = value

    @property
    def Email1AddressType(self):
        return self.com_object.Email1AddressType

    @Email1AddressType.setter
    def Email1AddressType(self, value):
        self.com_object.Email1AddressType = value

    @property
    def email1addresstype(self):
        """Alias for Email1AddressType"""
        return self.Email1AddressType

    @email1addresstype.setter
    def email1addresstype(self, value):
        """Alias for Email1AddressType.setter"""
        self.Email1AddressType = value

    @property
    def email1_address_type(self):
        """Alias for Email1AddressType"""
        return self.Email1AddressType

    @email1_address_type.setter
    def email1_address_type(self, value):
        """Alias for Email1AddressType.setter"""
        self.Email1AddressType = value

    @property
    def Email1DisplayName(self):
        return self.com_object.Email1DisplayName

    @Email1DisplayName.setter
    def Email1DisplayName(self, value):
        self.com_object.Email1DisplayName = value

    @property
    def email1displayname(self):
        """Alias for Email1DisplayName"""
        return self.Email1DisplayName

    @email1displayname.setter
    def email1displayname(self, value):
        """Alias for Email1DisplayName.setter"""
        self.Email1DisplayName = value

    @property
    def email1_display_name(self):
        """Alias for Email1DisplayName"""
        return self.Email1DisplayName

    @email1_display_name.setter
    def email1_display_name(self, value):
        """Alias for Email1DisplayName.setter"""
        self.Email1DisplayName = value

    @property
    def Email1EntryID(self):
        return self.com_object.Email1EntryID

    @property
    def email1entryid(self):
        """Alias for Email1EntryID"""
        return self.Email1EntryID

    @property
    def email1_entry_i_d(self):
        """Alias for Email1EntryID"""
        return self.Email1EntryID

    @property
    def Email2Address(self):
        return self.com_object.Email2Address

    @Email2Address.setter
    def Email2Address(self, value):
        self.com_object.Email2Address = value

    @property
    def email2address(self):
        """Alias for Email2Address"""
        return self.Email2Address

    @email2address.setter
    def email2address(self, value):
        """Alias for Email2Address.setter"""
        self.Email2Address = value

    @property
    def email2_address(self):
        """Alias for Email2Address"""
        return self.Email2Address

    @email2_address.setter
    def email2_address(self, value):
        """Alias for Email2Address.setter"""
        self.Email2Address = value

    @property
    def Email2AddressType(self):
        return self.com_object.Email2AddressType

    @Email2AddressType.setter
    def Email2AddressType(self, value):
        self.com_object.Email2AddressType = value

    @property
    def email2addresstype(self):
        """Alias for Email2AddressType"""
        return self.Email2AddressType

    @email2addresstype.setter
    def email2addresstype(self, value):
        """Alias for Email2AddressType.setter"""
        self.Email2AddressType = value

    @property
    def email2_address_type(self):
        """Alias for Email2AddressType"""
        return self.Email2AddressType

    @email2_address_type.setter
    def email2_address_type(self, value):
        """Alias for Email2AddressType.setter"""
        self.Email2AddressType = value

    @property
    def Email2DisplayName(self):
        return self.com_object.Email2DisplayName

    @Email2DisplayName.setter
    def Email2DisplayName(self, value):
        self.com_object.Email2DisplayName = value

    @property
    def email2displayname(self):
        """Alias for Email2DisplayName"""
        return self.Email2DisplayName

    @email2displayname.setter
    def email2displayname(self, value):
        """Alias for Email2DisplayName.setter"""
        self.Email2DisplayName = value

    @property
    def email2_display_name(self):
        """Alias for Email2DisplayName"""
        return self.Email2DisplayName

    @email2_display_name.setter
    def email2_display_name(self, value):
        """Alias for Email2DisplayName.setter"""
        self.Email2DisplayName = value

    @property
    def Email2EntryID(self):
        return self.com_object.Email2EntryID

    @property
    def email2entryid(self):
        """Alias for Email2EntryID"""
        return self.Email2EntryID

    @property
    def email2_entry_i_d(self):
        """Alias for Email2EntryID"""
        return self.Email2EntryID

    @property
    def Email3Address(self):
        return self.com_object.Email3Address

    @Email3Address.setter
    def Email3Address(self, value):
        self.com_object.Email3Address = value

    @property
    def email3address(self):
        """Alias for Email3Address"""
        return self.Email3Address

    @email3address.setter
    def email3address(self, value):
        """Alias for Email3Address.setter"""
        self.Email3Address = value

    @property
    def email3_address(self):
        """Alias for Email3Address"""
        return self.Email3Address

    @email3_address.setter
    def email3_address(self, value):
        """Alias for Email3Address.setter"""
        self.Email3Address = value

    @property
    def Email3AddressType(self):
        return self.com_object.Email3AddressType

    @Email3AddressType.setter
    def Email3AddressType(self, value):
        self.com_object.Email3AddressType = value

    @property
    def email3addresstype(self):
        """Alias for Email3AddressType"""
        return self.Email3AddressType

    @email3addresstype.setter
    def email3addresstype(self, value):
        """Alias for Email3AddressType.setter"""
        self.Email3AddressType = value

    @property
    def email3_address_type(self):
        """Alias for Email3AddressType"""
        return self.Email3AddressType

    @email3_address_type.setter
    def email3_address_type(self, value):
        """Alias for Email3AddressType.setter"""
        self.Email3AddressType = value

    @property
    def Email3DisplayName(self):
        return self.com_object.Email3DisplayName

    @Email3DisplayName.setter
    def Email3DisplayName(self, value):
        self.com_object.Email3DisplayName = value

    @property
    def email3displayname(self):
        """Alias for Email3DisplayName"""
        return self.Email3DisplayName

    @email3displayname.setter
    def email3displayname(self, value):
        """Alias for Email3DisplayName.setter"""
        self.Email3DisplayName = value

    @property
    def email3_display_name(self):
        """Alias for Email3DisplayName"""
        return self.Email3DisplayName

    @email3_display_name.setter
    def email3_display_name(self, value):
        """Alias for Email3DisplayName.setter"""
        self.Email3DisplayName = value

    @property
    def Email3EntryID(self):
        return self.com_object.Email3EntryID

    @property
    def email3entryid(self):
        """Alias for Email3EntryID"""
        return self.Email3EntryID

    @property
    def email3_entry_i_d(self):
        """Alias for Email3EntryID"""
        return self.Email3EntryID

    @property
    def EntryID(self):
        return self.com_object.EntryID

    @property
    def entryid(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def entry_i_d(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def FileAs(self):
        return self.com_object.FileAs

    @FileAs.setter
    def FileAs(self, value):
        self.com_object.FileAs = value

    @property
    def fileas(self):
        """Alias for FileAs"""
        return self.FileAs

    @fileas.setter
    def fileas(self, value):
        """Alias for FileAs.setter"""
        self.FileAs = value

    @property
    def file_as(self):
        """Alias for FileAs"""
        return self.FileAs

    @file_as.setter
    def file_as(self, value):
        """Alias for FileAs.setter"""
        self.FileAs = value

    @property
    def FirstName(self):
        return self.com_object.FirstName

    @FirstName.setter
    def FirstName(self, value):
        self.com_object.FirstName = value

    @property
    def firstname(self):
        """Alias for FirstName"""
        return self.FirstName

    @firstname.setter
    def firstname(self, value):
        """Alias for FirstName.setter"""
        self.FirstName = value

    @property
    def first_name(self):
        """Alias for FirstName"""
        return self.FirstName

    @first_name.setter
    def first_name(self, value):
        """Alias for FirstName.setter"""
        self.FirstName = value

    @property
    def FormDescription(self):
        return FormDescription(self.com_object.FormDescription)

    @property
    def formdescription(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def form_description(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def FTPSite(self):
        return self.com_object.FTPSite

    @FTPSite.setter
    def FTPSite(self, value):
        self.com_object.FTPSite = value

    @property
    def ftpsite(self):
        """Alias for FTPSite"""
        return self.FTPSite

    @ftpsite.setter
    def ftpsite(self, value):
        """Alias for FTPSite.setter"""
        self.FTPSite = value

    @property
    def f_t_p_site(self):
        """Alias for FTPSite"""
        return self.FTPSite

    @f_t_p_site.setter
    def f_t_p_site(self, value):
        """Alias for FTPSite.setter"""
        self.FTPSite = value

    @property
    def FullName(self):
        return self.com_object.FullName

    @FullName.setter
    def FullName(self, value):
        self.com_object.FullName = value

    @property
    def fullname(self):
        """Alias for FullName"""
        return self.FullName

    @fullname.setter
    def fullname(self, value):
        """Alias for FullName.setter"""
        self.FullName = value

    @property
    def full_name(self):
        """Alias for FullName"""
        return self.FullName

    @full_name.setter
    def full_name(self, value):
        """Alias for FullName.setter"""
        self.FullName = value

    @property
    def FullNameAndCompany(self):
        return self.com_object.FullNameAndCompany

    @property
    def fullnameandcompany(self):
        """Alias for FullNameAndCompany"""
        return self.FullNameAndCompany

    @property
    def full_name_and_company(self):
        """Alias for FullNameAndCompany"""
        return self.FullNameAndCompany

    @property
    def Gender(self):
        return OlGender(self.com_object.Gender)

    @Gender.setter
    def Gender(self, value):
        self.com_object.Gender = value

    @property
    def gender(self):
        """Alias for Gender"""
        return self.Gender

    @gender.setter
    def gender(self, value):
        """Alias for Gender.setter"""
        self.Gender = value

    @property
    def GetInspector(self):
        return Inspector(self.com_object.GetInspector)

    @property
    def getinspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def get_inspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def GovernmentIDNumber(self):
        return self.com_object.GovernmentIDNumber

    @GovernmentIDNumber.setter
    def GovernmentIDNumber(self, value):
        self.com_object.GovernmentIDNumber = value

    @property
    def governmentidnumber(self):
        """Alias for GovernmentIDNumber"""
        return self.GovernmentIDNumber

    @governmentidnumber.setter
    def governmentidnumber(self, value):
        """Alias for GovernmentIDNumber.setter"""
        self.GovernmentIDNumber = value

    @property
    def government_i_d_number(self):
        """Alias for GovernmentIDNumber"""
        return self.GovernmentIDNumber

    @government_i_d_number.setter
    def government_i_d_number(self, value):
        """Alias for GovernmentIDNumber.setter"""
        self.GovernmentIDNumber = value

    @property
    def HasPicture(self):
        return self.com_object.HasPicture

    @property
    def haspicture(self):
        """Alias for HasPicture"""
        return self.HasPicture

    @property
    def has_picture(self):
        """Alias for HasPicture"""
        return self.HasPicture

    @property
    def Hobby(self):
        return self.com_object.Hobby

    @Hobby.setter
    def Hobby(self, value):
        self.com_object.Hobby = value

    @property
    def hobby(self):
        """Alias for Hobby"""
        return self.Hobby

    @hobby.setter
    def hobby(self, value):
        """Alias for Hobby.setter"""
        self.Hobby = value

    @property
    def Home2TelephoneNumber(self):
        return self.com_object.Home2TelephoneNumber

    @Home2TelephoneNumber.setter
    def Home2TelephoneNumber(self, value):
        self.com_object.Home2TelephoneNumber = value

    @property
    def home2telephonenumber(self):
        """Alias for Home2TelephoneNumber"""
        return self.Home2TelephoneNumber

    @home2telephonenumber.setter
    def home2telephonenumber(self, value):
        """Alias for Home2TelephoneNumber.setter"""
        self.Home2TelephoneNumber = value

    @property
    def home2_telephone_number(self):
        """Alias for Home2TelephoneNumber"""
        return self.Home2TelephoneNumber

    @home2_telephone_number.setter
    def home2_telephone_number(self, value):
        """Alias for Home2TelephoneNumber.setter"""
        self.Home2TelephoneNumber = value

    @property
    def HomeAddress(self):
        return self.com_object.HomeAddress

    @HomeAddress.setter
    def HomeAddress(self, value):
        self.com_object.HomeAddress = value

    @property
    def homeaddress(self):
        """Alias for HomeAddress"""
        return self.HomeAddress

    @homeaddress.setter
    def homeaddress(self, value):
        """Alias for HomeAddress.setter"""
        self.HomeAddress = value

    @property
    def home_address(self):
        """Alias for HomeAddress"""
        return self.HomeAddress

    @home_address.setter
    def home_address(self, value):
        """Alias for HomeAddress.setter"""
        self.HomeAddress = value

    @property
    def HomeAddressCity(self):
        return self.com_object.HomeAddressCity

    @HomeAddressCity.setter
    def HomeAddressCity(self, value):
        self.com_object.HomeAddressCity = value

    @property
    def homeaddresscity(self):
        """Alias for HomeAddressCity"""
        return self.HomeAddressCity

    @homeaddresscity.setter
    def homeaddresscity(self, value):
        """Alias for HomeAddressCity.setter"""
        self.HomeAddressCity = value

    @property
    def home_address_city(self):
        """Alias for HomeAddressCity"""
        return self.HomeAddressCity

    @home_address_city.setter
    def home_address_city(self, value):
        """Alias for HomeAddressCity.setter"""
        self.HomeAddressCity = value

    @property
    def HomeAddressCountry(self):
        return self.com_object.HomeAddressCountry

    @HomeAddressCountry.setter
    def HomeAddressCountry(self, value):
        self.com_object.HomeAddressCountry = value

    @property
    def homeaddresscountry(self):
        """Alias for HomeAddressCountry"""
        return self.HomeAddressCountry

    @homeaddresscountry.setter
    def homeaddresscountry(self, value):
        """Alias for HomeAddressCountry.setter"""
        self.HomeAddressCountry = value

    @property
    def home_address_country(self):
        """Alias for HomeAddressCountry"""
        return self.HomeAddressCountry

    @home_address_country.setter
    def home_address_country(self, value):
        """Alias for HomeAddressCountry.setter"""
        self.HomeAddressCountry = value

    @property
    def HomeAddressPostalCode(self):
        return self.com_object.HomeAddressPostalCode

    @HomeAddressPostalCode.setter
    def HomeAddressPostalCode(self, value):
        self.com_object.HomeAddressPostalCode = value

    @property
    def homeaddresspostalcode(self):
        """Alias for HomeAddressPostalCode"""
        return self.HomeAddressPostalCode

    @homeaddresspostalcode.setter
    def homeaddresspostalcode(self, value):
        """Alias for HomeAddressPostalCode.setter"""
        self.HomeAddressPostalCode = value

    @property
    def home_address_postal_code(self):
        """Alias for HomeAddressPostalCode"""
        return self.HomeAddressPostalCode

    @home_address_postal_code.setter
    def home_address_postal_code(self, value):
        """Alias for HomeAddressPostalCode.setter"""
        self.HomeAddressPostalCode = value

    @property
    def HomeAddressPostOfficeBox(self):
        return self.com_object.HomeAddressPostOfficeBox

    @HomeAddressPostOfficeBox.setter
    def HomeAddressPostOfficeBox(self, value):
        self.com_object.HomeAddressPostOfficeBox = value

    @property
    def homeaddresspostofficebox(self):
        """Alias for HomeAddressPostOfficeBox"""
        return self.HomeAddressPostOfficeBox

    @homeaddresspostofficebox.setter
    def homeaddresspostofficebox(self, value):
        """Alias for HomeAddressPostOfficeBox.setter"""
        self.HomeAddressPostOfficeBox = value

    @property
    def home_address_post_office_box(self):
        """Alias for HomeAddressPostOfficeBox"""
        return self.HomeAddressPostOfficeBox

    @home_address_post_office_box.setter
    def home_address_post_office_box(self, value):
        """Alias for HomeAddressPostOfficeBox.setter"""
        self.HomeAddressPostOfficeBox = value

    @property
    def HomeAddressState(self):
        return self.com_object.HomeAddressState

    @HomeAddressState.setter
    def HomeAddressState(self, value):
        self.com_object.HomeAddressState = value

    @property
    def homeaddressstate(self):
        """Alias for HomeAddressState"""
        return self.HomeAddressState

    @homeaddressstate.setter
    def homeaddressstate(self, value):
        """Alias for HomeAddressState.setter"""
        self.HomeAddressState = value

    @property
    def home_address_state(self):
        """Alias for HomeAddressState"""
        return self.HomeAddressState

    @home_address_state.setter
    def home_address_state(self, value):
        """Alias for HomeAddressState.setter"""
        self.HomeAddressState = value

    @property
    def HomeAddressStreet(self):
        return self.com_object.HomeAddressStreet

    @HomeAddressStreet.setter
    def HomeAddressStreet(self, value):
        self.com_object.HomeAddressStreet = value

    @property
    def homeaddressstreet(self):
        """Alias for HomeAddressStreet"""
        return self.HomeAddressStreet

    @homeaddressstreet.setter
    def homeaddressstreet(self, value):
        """Alias for HomeAddressStreet.setter"""
        self.HomeAddressStreet = value

    @property
    def home_address_street(self):
        """Alias for HomeAddressStreet"""
        return self.HomeAddressStreet

    @home_address_street.setter
    def home_address_street(self, value):
        """Alias for HomeAddressStreet.setter"""
        self.HomeAddressStreet = value

    @property
    def HomeFaxNumber(self):
        return self.com_object.HomeFaxNumber

    @HomeFaxNumber.setter
    def HomeFaxNumber(self, value):
        self.com_object.HomeFaxNumber = value

    @property
    def homefaxnumber(self):
        """Alias for HomeFaxNumber"""
        return self.HomeFaxNumber

    @homefaxnumber.setter
    def homefaxnumber(self, value):
        """Alias for HomeFaxNumber.setter"""
        self.HomeFaxNumber = value

    @property
    def home_fax_number(self):
        """Alias for HomeFaxNumber"""
        return self.HomeFaxNumber

    @home_fax_number.setter
    def home_fax_number(self, value):
        """Alias for HomeFaxNumber.setter"""
        self.HomeFaxNumber = value

    @property
    def HomeTelephoneNumber(self):
        return self.com_object.HomeTelephoneNumber

    @HomeTelephoneNumber.setter
    def HomeTelephoneNumber(self, value):
        self.com_object.HomeTelephoneNumber = value

    @property
    def hometelephonenumber(self):
        """Alias for HomeTelephoneNumber"""
        return self.HomeTelephoneNumber

    @hometelephonenumber.setter
    def hometelephonenumber(self, value):
        """Alias for HomeTelephoneNumber.setter"""
        self.HomeTelephoneNumber = value

    @property
    def home_telephone_number(self):
        """Alias for HomeTelephoneNumber"""
        return self.HomeTelephoneNumber

    @home_telephone_number.setter
    def home_telephone_number(self, value):
        """Alias for HomeTelephoneNumber.setter"""
        self.HomeTelephoneNumber = value

    @property
    def IMAddress(self):
        return self.com_object.IMAddress

    @IMAddress.setter
    def IMAddress(self, value):
        self.com_object.IMAddress = value

    @property
    def imaddress(self):
        """Alias for IMAddress"""
        return self.IMAddress

    @imaddress.setter
    def imaddress(self, value):
        """Alias for IMAddress.setter"""
        self.IMAddress = value

    @property
    def i_m_address(self):
        """Alias for IMAddress"""
        return self.IMAddress

    @i_m_address.setter
    def i_m_address(self, value):
        """Alias for IMAddress.setter"""
        self.IMAddress = value

    @property
    def Importance(self):
        return OlImportance(self.com_object.Importance)

    @Importance.setter
    def Importance(self, value):
        self.com_object.Importance = value

    @property
    def importance(self):
        """Alias for Importance"""
        return self.Importance

    @importance.setter
    def importance(self, value):
        """Alias for Importance.setter"""
        self.Importance = value

    @property
    def Initials(self):
        return self.com_object.Initials

    @Initials.setter
    def Initials(self, value):
        self.com_object.Initials = value

    @property
    def initials(self):
        """Alias for Initials"""
        return self.Initials

    @initials.setter
    def initials(self, value):
        """Alias for Initials.setter"""
        self.Initials = value

    @property
    def InternetFreeBusyAddress(self):
        return self.com_object.InternetFreeBusyAddress

    @InternetFreeBusyAddress.setter
    def InternetFreeBusyAddress(self, value):
        self.com_object.InternetFreeBusyAddress = value

    @property
    def internetfreebusyaddress(self):
        """Alias for InternetFreeBusyAddress"""
        return self.InternetFreeBusyAddress

    @internetfreebusyaddress.setter
    def internetfreebusyaddress(self, value):
        """Alias for InternetFreeBusyAddress.setter"""
        self.InternetFreeBusyAddress = value

    @property
    def internet_free_busy_address(self):
        """Alias for InternetFreeBusyAddress"""
        return self.InternetFreeBusyAddress

    @internet_free_busy_address.setter
    def internet_free_busy_address(self, value):
        """Alias for InternetFreeBusyAddress.setter"""
        self.InternetFreeBusyAddress = value

    @property
    def IsConflict(self):
        return self.com_object.IsConflict

    @property
    def isconflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def is_conflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def ISDNNumber(self):
        return self.com_object.ISDNNumber

    @ISDNNumber.setter
    def ISDNNumber(self, value):
        self.com_object.ISDNNumber = value

    @property
    def isdnnumber(self):
        """Alias for ISDNNumber"""
        return self.ISDNNumber

    @isdnnumber.setter
    def isdnnumber(self, value):
        """Alias for ISDNNumber.setter"""
        self.ISDNNumber = value

    @property
    def i_s_d_n_number(self):
        """Alias for ISDNNumber"""
        return self.ISDNNumber

    @i_s_d_n_number.setter
    def i_s_d_n_number(self, value):
        """Alias for ISDNNumber.setter"""
        self.ISDNNumber = value

    @property
    def IsMarkedAsTask(self):
        return ContactItem(self.com_object.IsMarkedAsTask)

    @property
    def ismarkedastask(self):
        """Alias for IsMarkedAsTask"""
        return self.IsMarkedAsTask

    @property
    def is_marked_as_task(self):
        """Alias for IsMarkedAsTask"""
        return self.IsMarkedAsTask

    @property
    def ItemProperties(self):
        return ItemProperties(self.com_object.ItemProperties)

    @property
    def itemproperties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def item_properties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def JobTitle(self):
        return self.com_object.JobTitle

    @JobTitle.setter
    def JobTitle(self, value):
        self.com_object.JobTitle = value

    @property
    def jobtitle(self):
        """Alias for JobTitle"""
        return self.JobTitle

    @jobtitle.setter
    def jobtitle(self, value):
        """Alias for JobTitle.setter"""
        self.JobTitle = value

    @property
    def job_title(self):
        """Alias for JobTitle"""
        return self.JobTitle

    @job_title.setter
    def job_title(self, value):
        """Alias for JobTitle.setter"""
        self.JobTitle = value

    @property
    def Journal(self):
        return self.com_object.Journal

    @Journal.setter
    def Journal(self, value):
        self.com_object.Journal = value

    @property
    def journal(self):
        """Alias for Journal"""
        return self.Journal

    @journal.setter
    def journal(self, value):
        """Alias for Journal.setter"""
        self.Journal = value

    @property
    def Language(self):
        return self.com_object.Language

    @Language.setter
    def Language(self, value):
        self.com_object.Language = value

    @property
    def language(self):
        """Alias for Language"""
        return self.Language

    @language.setter
    def language(self, value):
        """Alias for Language.setter"""
        self.Language = value

    @property
    def LastFirstAndSuffix(self):
        return self.com_object.LastFirstAndSuffix

    @property
    def lastfirstandsuffix(self):
        """Alias for LastFirstAndSuffix"""
        return self.LastFirstAndSuffix

    @property
    def last_first_and_suffix(self):
        """Alias for LastFirstAndSuffix"""
        return self.LastFirstAndSuffix

    @property
    def LastFirstNoSpace(self):
        return self.com_object.LastFirstNoSpace

    @property
    def lastfirstnospace(self):
        """Alias for LastFirstNoSpace"""
        return self.LastFirstNoSpace

    @property
    def last_first_no_space(self):
        """Alias for LastFirstNoSpace"""
        return self.LastFirstNoSpace

    @property
    def LastFirstNoSpaceAndSuffix(self):
        return self.com_object.LastFirstNoSpaceAndSuffix

    @property
    def lastfirstnospaceandsuffix(self):
        """Alias for LastFirstNoSpaceAndSuffix"""
        return self.LastFirstNoSpaceAndSuffix

    @property
    def last_first_no_space_and_suffix(self):
        """Alias for LastFirstNoSpaceAndSuffix"""
        return self.LastFirstNoSpaceAndSuffix

    @property
    def LastFirstNoSpaceCompany(self):
        return self.com_object.LastFirstNoSpaceCompany

    @property
    def lastfirstnospacecompany(self):
        """Alias for LastFirstNoSpaceCompany"""
        return self.LastFirstNoSpaceCompany

    @property
    def last_first_no_space_company(self):
        """Alias for LastFirstNoSpaceCompany"""
        return self.LastFirstNoSpaceCompany

    @property
    def LastFirstSpaceOnly(self):
        return self.com_object.LastFirstSpaceOnly

    @property
    def lastfirstspaceonly(self):
        """Alias for LastFirstSpaceOnly"""
        return self.LastFirstSpaceOnly

    @property
    def last_first_space_only(self):
        """Alias for LastFirstSpaceOnly"""
        return self.LastFirstSpaceOnly

    @property
    def LastFirstSpaceOnlyCompany(self):
        return self.com_object.LastFirstSpaceOnlyCompany

    @property
    def lastfirstspaceonlycompany(self):
        """Alias for LastFirstSpaceOnlyCompany"""
        return self.LastFirstSpaceOnlyCompany

    @property
    def last_first_space_only_company(self):
        """Alias for LastFirstSpaceOnlyCompany"""
        return self.LastFirstSpaceOnlyCompany

    @property
    def LastModificationTime(self):
        return self.com_object.LastModificationTime

    @property
    def lastmodificationtime(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def last_modification_time(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def LastName(self):
        return self.com_object.LastName

    @LastName.setter
    def LastName(self, value):
        self.com_object.LastName = value

    @property
    def lastname(self):
        """Alias for LastName"""
        return self.LastName

    @lastname.setter
    def lastname(self, value):
        """Alias for LastName.setter"""
        self.LastName = value

    @property
    def last_name(self):
        """Alias for LastName"""
        return self.LastName

    @last_name.setter
    def last_name(self, value):
        """Alias for LastName.setter"""
        self.LastName = value

    @property
    def LastNameAndFirstName(self):
        return self.com_object.LastNameAndFirstName

    @property
    def lastnameandfirstname(self):
        """Alias for LastNameAndFirstName"""
        return self.LastNameAndFirstName

    @property
    def last_name_and_first_name(self):
        """Alias for LastNameAndFirstName"""
        return self.LastNameAndFirstName

    @property
    def MailingAddress(self):
        return self.com_object.MailingAddress

    @MailingAddress.setter
    def MailingAddress(self, value):
        self.com_object.MailingAddress = value

    @property
    def mailingaddress(self):
        """Alias for MailingAddress"""
        return self.MailingAddress

    @mailingaddress.setter
    def mailingaddress(self, value):
        """Alias for MailingAddress.setter"""
        self.MailingAddress = value

    @property
    def mailing_address(self):
        """Alias for MailingAddress"""
        return self.MailingAddress

    @mailing_address.setter
    def mailing_address(self, value):
        """Alias for MailingAddress.setter"""
        self.MailingAddress = value

    @property
    def MailingAddressCity(self):
        return self.com_object.MailingAddressCity

    @MailingAddressCity.setter
    def MailingAddressCity(self, value):
        self.com_object.MailingAddressCity = value

    @property
    def mailingaddresscity(self):
        """Alias for MailingAddressCity"""
        return self.MailingAddressCity

    @mailingaddresscity.setter
    def mailingaddresscity(self, value):
        """Alias for MailingAddressCity.setter"""
        self.MailingAddressCity = value

    @property
    def mailing_address_city(self):
        """Alias for MailingAddressCity"""
        return self.MailingAddressCity

    @mailing_address_city.setter
    def mailing_address_city(self, value):
        """Alias for MailingAddressCity.setter"""
        self.MailingAddressCity = value

    @property
    def MailingAddressCountry(self):
        return self.com_object.MailingAddressCountry

    @MailingAddressCountry.setter
    def MailingAddressCountry(self, value):
        self.com_object.MailingAddressCountry = value

    @property
    def mailingaddresscountry(self):
        """Alias for MailingAddressCountry"""
        return self.MailingAddressCountry

    @mailingaddresscountry.setter
    def mailingaddresscountry(self, value):
        """Alias for MailingAddressCountry.setter"""
        self.MailingAddressCountry = value

    @property
    def mailing_address_country(self):
        """Alias for MailingAddressCountry"""
        return self.MailingAddressCountry

    @mailing_address_country.setter
    def mailing_address_country(self, value):
        """Alias for MailingAddressCountry.setter"""
        self.MailingAddressCountry = value

    @property
    def MailingAddressPostalCode(self):
        return self.com_object.MailingAddressPostalCode

    @MailingAddressPostalCode.setter
    def MailingAddressPostalCode(self, value):
        self.com_object.MailingAddressPostalCode = value

    @property
    def mailingaddresspostalcode(self):
        """Alias for MailingAddressPostalCode"""
        return self.MailingAddressPostalCode

    @mailingaddresspostalcode.setter
    def mailingaddresspostalcode(self, value):
        """Alias for MailingAddressPostalCode.setter"""
        self.MailingAddressPostalCode = value

    @property
    def mailing_address_postal_code(self):
        """Alias for MailingAddressPostalCode"""
        return self.MailingAddressPostalCode

    @mailing_address_postal_code.setter
    def mailing_address_postal_code(self, value):
        """Alias for MailingAddressPostalCode.setter"""
        self.MailingAddressPostalCode = value

    @property
    def MailingAddressPostOfficeBox(self):
        return self.com_object.MailingAddressPostOfficeBox

    @MailingAddressPostOfficeBox.setter
    def MailingAddressPostOfficeBox(self, value):
        self.com_object.MailingAddressPostOfficeBox = value

    @property
    def mailingaddresspostofficebox(self):
        """Alias for MailingAddressPostOfficeBox"""
        return self.MailingAddressPostOfficeBox

    @mailingaddresspostofficebox.setter
    def mailingaddresspostofficebox(self, value):
        """Alias for MailingAddressPostOfficeBox.setter"""
        self.MailingAddressPostOfficeBox = value

    @property
    def mailing_address_post_office_box(self):
        """Alias for MailingAddressPostOfficeBox"""
        return self.MailingAddressPostOfficeBox

    @mailing_address_post_office_box.setter
    def mailing_address_post_office_box(self, value):
        """Alias for MailingAddressPostOfficeBox.setter"""
        self.MailingAddressPostOfficeBox = value

    @property
    def MailingAddressState(self):
        return self.com_object.MailingAddressState

    @MailingAddressState.setter
    def MailingAddressState(self, value):
        self.com_object.MailingAddressState = value

    @property
    def mailingaddressstate(self):
        """Alias for MailingAddressState"""
        return self.MailingAddressState

    @mailingaddressstate.setter
    def mailingaddressstate(self, value):
        """Alias for MailingAddressState.setter"""
        self.MailingAddressState = value

    @property
    def mailing_address_state(self):
        """Alias for MailingAddressState"""
        return self.MailingAddressState

    @mailing_address_state.setter
    def mailing_address_state(self, value):
        """Alias for MailingAddressState.setter"""
        self.MailingAddressState = value

    @property
    def MailingAddressStreet(self):
        return self.com_object.MailingAddressStreet

    @MailingAddressStreet.setter
    def MailingAddressStreet(self, value):
        self.com_object.MailingAddressStreet = value

    @property
    def mailingaddressstreet(self):
        """Alias for MailingAddressStreet"""
        return self.MailingAddressStreet

    @mailingaddressstreet.setter
    def mailingaddressstreet(self, value):
        """Alias for MailingAddressStreet.setter"""
        self.MailingAddressStreet = value

    @property
    def mailing_address_street(self):
        """Alias for MailingAddressStreet"""
        return self.MailingAddressStreet

    @mailing_address_street.setter
    def mailing_address_street(self, value):
        """Alias for MailingAddressStreet.setter"""
        self.MailingAddressStreet = value

    @property
    def ManagerName(self):
        return self.com_object.ManagerName

    @ManagerName.setter
    def ManagerName(self, value):
        self.com_object.ManagerName = value

    @property
    def managername(self):
        """Alias for ManagerName"""
        return self.ManagerName

    @managername.setter
    def managername(self, value):
        """Alias for ManagerName.setter"""
        self.ManagerName = value

    @property
    def manager_name(self):
        """Alias for ManagerName"""
        return self.ManagerName

    @manager_name.setter
    def manager_name(self, value):
        """Alias for ManagerName.setter"""
        self.ManagerName = value

    @property
    def MarkForDownload(self):
        return OlRemoteStatus(self.com_object.MarkForDownload)

    @MarkForDownload.setter
    def MarkForDownload(self, value):
        self.com_object.MarkForDownload = value

    @property
    def markfordownload(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @markfordownload.setter
    def markfordownload(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def mark_for_download(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @mark_for_download.setter
    def mark_for_download(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def MessageClass(self):
        return self.com_object.MessageClass

    @MessageClass.setter
    def MessageClass(self, value):
        self.com_object.MessageClass = value

    @property
    def messageclass(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @messageclass.setter
    def messageclass(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def message_class(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @message_class.setter
    def message_class(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def MiddleName(self):
        return self.com_object.MiddleName

    @MiddleName.setter
    def MiddleName(self, value):
        self.com_object.MiddleName = value

    @property
    def middlename(self):
        """Alias for MiddleName"""
        return self.MiddleName

    @middlename.setter
    def middlename(self, value):
        """Alias for MiddleName.setter"""
        self.MiddleName = value

    @property
    def middle_name(self):
        """Alias for MiddleName"""
        return self.MiddleName

    @middle_name.setter
    def middle_name(self, value):
        """Alias for MiddleName.setter"""
        self.MiddleName = value

    @property
    def Mileage(self):
        return self.com_object.Mileage

    @Mileage.setter
    def Mileage(self, value):
        self.com_object.Mileage = value

    @property
    def mileage(self):
        """Alias for Mileage"""
        return self.Mileage

    @mileage.setter
    def mileage(self, value):
        """Alias for Mileage.setter"""
        self.Mileage = value

    @property
    def MobileTelephoneNumber(self):
        return self.com_object.MobileTelephoneNumber

    @MobileTelephoneNumber.setter
    def MobileTelephoneNumber(self, value):
        self.com_object.MobileTelephoneNumber = value

    @property
    def mobiletelephonenumber(self):
        """Alias for MobileTelephoneNumber"""
        return self.MobileTelephoneNumber

    @mobiletelephonenumber.setter
    def mobiletelephonenumber(self, value):
        """Alias for MobileTelephoneNumber.setter"""
        self.MobileTelephoneNumber = value

    @property
    def mobile_telephone_number(self):
        """Alias for MobileTelephoneNumber"""
        return self.MobileTelephoneNumber

    @mobile_telephone_number.setter
    def mobile_telephone_number(self, value):
        """Alias for MobileTelephoneNumber.setter"""
        self.MobileTelephoneNumber = value

    @property
    def NetMeetingAlias(self):
        return self.com_object.NetMeetingAlias

    @NetMeetingAlias.setter
    def NetMeetingAlias(self, value):
        self.com_object.NetMeetingAlias = value

    @property
    def netmeetingalias(self):
        """Alias for NetMeetingAlias"""
        return self.NetMeetingAlias

    @netmeetingalias.setter
    def netmeetingalias(self, value):
        """Alias for NetMeetingAlias.setter"""
        self.NetMeetingAlias = value

    @property
    def net_meeting_alias(self):
        """Alias for NetMeetingAlias"""
        return self.NetMeetingAlias

    @net_meeting_alias.setter
    def net_meeting_alias(self, value):
        """Alias for NetMeetingAlias.setter"""
        self.NetMeetingAlias = value

    @property
    def NetMeetingServer(self):
        return self.com_object.NetMeetingServer

    @NetMeetingServer.setter
    def NetMeetingServer(self, value):
        self.com_object.NetMeetingServer = value

    @property
    def netmeetingserver(self):
        """Alias for NetMeetingServer"""
        return self.NetMeetingServer

    @netmeetingserver.setter
    def netmeetingserver(self, value):
        """Alias for NetMeetingServer.setter"""
        self.NetMeetingServer = value

    @property
    def net_meeting_server(self):
        """Alias for NetMeetingServer"""
        return self.NetMeetingServer

    @net_meeting_server.setter
    def net_meeting_server(self, value):
        """Alias for NetMeetingServer.setter"""
        self.NetMeetingServer = value

    @property
    def NickName(self):
        return self.com_object.NickName

    @NickName.setter
    def NickName(self, value):
        self.com_object.NickName = value

    @property
    def nickname(self):
        """Alias for NickName"""
        return self.NickName

    @nickname.setter
    def nickname(self, value):
        """Alias for NickName.setter"""
        self.NickName = value

    @property
    def nick_name(self):
        """Alias for NickName"""
        return self.NickName

    @nick_name.setter
    def nick_name(self, value):
        """Alias for NickName.setter"""
        self.NickName = value

    @property
    def NoAging(self):
        return self.com_object.NoAging

    @NoAging.setter
    def NoAging(self, value):
        self.com_object.NoAging = value

    @property
    def noaging(self):
        """Alias for NoAging"""
        return self.NoAging

    @noaging.setter
    def noaging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def no_aging(self):
        """Alias for NoAging"""
        return self.NoAging

    @no_aging.setter
    def no_aging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def OfficeLocation(self):
        return self.com_object.OfficeLocation

    @OfficeLocation.setter
    def OfficeLocation(self, value):
        self.com_object.OfficeLocation = value

    @property
    def officelocation(self):
        """Alias for OfficeLocation"""
        return self.OfficeLocation

    @officelocation.setter
    def officelocation(self, value):
        """Alias for OfficeLocation.setter"""
        self.OfficeLocation = value

    @property
    def office_location(self):
        """Alias for OfficeLocation"""
        return self.OfficeLocation

    @office_location.setter
    def office_location(self, value):
        """Alias for OfficeLocation.setter"""
        self.OfficeLocation = value

    @property
    def OrganizationalIDNumber(self):
        return self.com_object.OrganizationalIDNumber

    @OrganizationalIDNumber.setter
    def OrganizationalIDNumber(self, value):
        self.com_object.OrganizationalIDNumber = value

    @property
    def organizationalidnumber(self):
        """Alias for OrganizationalIDNumber"""
        return self.OrganizationalIDNumber

    @organizationalidnumber.setter
    def organizationalidnumber(self, value):
        """Alias for OrganizationalIDNumber.setter"""
        self.OrganizationalIDNumber = value

    @property
    def organizational_i_d_number(self):
        """Alias for OrganizationalIDNumber"""
        return self.OrganizationalIDNumber

    @organizational_i_d_number.setter
    def organizational_i_d_number(self, value):
        """Alias for OrganizationalIDNumber.setter"""
        self.OrganizationalIDNumber = value

    @property
    def OtherAddress(self):
        return self.com_object.OtherAddress

    @OtherAddress.setter
    def OtherAddress(self, value):
        self.com_object.OtherAddress = value

    @property
    def otheraddress(self):
        """Alias for OtherAddress"""
        return self.OtherAddress

    @otheraddress.setter
    def otheraddress(self, value):
        """Alias for OtherAddress.setter"""
        self.OtherAddress = value

    @property
    def other_address(self):
        """Alias for OtherAddress"""
        return self.OtherAddress

    @other_address.setter
    def other_address(self, value):
        """Alias for OtherAddress.setter"""
        self.OtherAddress = value

    @property
    def OtherAddressCity(self):
        return self.com_object.OtherAddressCity

    @OtherAddressCity.setter
    def OtherAddressCity(self, value):
        self.com_object.OtherAddressCity = value

    @property
    def otheraddresscity(self):
        """Alias for OtherAddressCity"""
        return self.OtherAddressCity

    @otheraddresscity.setter
    def otheraddresscity(self, value):
        """Alias for OtherAddressCity.setter"""
        self.OtherAddressCity = value

    @property
    def other_address_city(self):
        """Alias for OtherAddressCity"""
        return self.OtherAddressCity

    @other_address_city.setter
    def other_address_city(self, value):
        """Alias for OtherAddressCity.setter"""
        self.OtherAddressCity = value

    @property
    def OtherAddressCountry(self):
        return self.com_object.OtherAddressCountry

    @OtherAddressCountry.setter
    def OtherAddressCountry(self, value):
        self.com_object.OtherAddressCountry = value

    @property
    def otheraddresscountry(self):
        """Alias for OtherAddressCountry"""
        return self.OtherAddressCountry

    @otheraddresscountry.setter
    def otheraddresscountry(self, value):
        """Alias for OtherAddressCountry.setter"""
        self.OtherAddressCountry = value

    @property
    def other_address_country(self):
        """Alias for OtherAddressCountry"""
        return self.OtherAddressCountry

    @other_address_country.setter
    def other_address_country(self, value):
        """Alias for OtherAddressCountry.setter"""
        self.OtherAddressCountry = value

    @property
    def OtherAddressPostalCode(self):
        return self.com_object.OtherAddressPostalCode

    @OtherAddressPostalCode.setter
    def OtherAddressPostalCode(self, value):
        self.com_object.OtherAddressPostalCode = value

    @property
    def otheraddresspostalcode(self):
        """Alias for OtherAddressPostalCode"""
        return self.OtherAddressPostalCode

    @otheraddresspostalcode.setter
    def otheraddresspostalcode(self, value):
        """Alias for OtherAddressPostalCode.setter"""
        self.OtherAddressPostalCode = value

    @property
    def other_address_postal_code(self):
        """Alias for OtherAddressPostalCode"""
        return self.OtherAddressPostalCode

    @other_address_postal_code.setter
    def other_address_postal_code(self, value):
        """Alias for OtherAddressPostalCode.setter"""
        self.OtherAddressPostalCode = value

    @property
    def OtherAddressPostOfficeBox(self):
        return self.com_object.OtherAddressPostOfficeBox

    @OtherAddressPostOfficeBox.setter
    def OtherAddressPostOfficeBox(self, value):
        self.com_object.OtherAddressPostOfficeBox = value

    @property
    def otheraddresspostofficebox(self):
        """Alias for OtherAddressPostOfficeBox"""
        return self.OtherAddressPostOfficeBox

    @otheraddresspostofficebox.setter
    def otheraddresspostofficebox(self, value):
        """Alias for OtherAddressPostOfficeBox.setter"""
        self.OtherAddressPostOfficeBox = value

    @property
    def other_address_post_office_box(self):
        """Alias for OtherAddressPostOfficeBox"""
        return self.OtherAddressPostOfficeBox

    @other_address_post_office_box.setter
    def other_address_post_office_box(self, value):
        """Alias for OtherAddressPostOfficeBox.setter"""
        self.OtherAddressPostOfficeBox = value

    @property
    def OtherAddressState(self):
        return self.com_object.OtherAddressState

    @OtherAddressState.setter
    def OtherAddressState(self, value):
        self.com_object.OtherAddressState = value

    @property
    def otheraddressstate(self):
        """Alias for OtherAddressState"""
        return self.OtherAddressState

    @otheraddressstate.setter
    def otheraddressstate(self, value):
        """Alias for OtherAddressState.setter"""
        self.OtherAddressState = value

    @property
    def other_address_state(self):
        """Alias for OtherAddressState"""
        return self.OtherAddressState

    @other_address_state.setter
    def other_address_state(self, value):
        """Alias for OtherAddressState.setter"""
        self.OtherAddressState = value

    @property
    def OtherAddressStreet(self):
        return self.com_object.OtherAddressStreet

    @OtherAddressStreet.setter
    def OtherAddressStreet(self, value):
        self.com_object.OtherAddressStreet = value

    @property
    def otheraddressstreet(self):
        """Alias for OtherAddressStreet"""
        return self.OtherAddressStreet

    @otheraddressstreet.setter
    def otheraddressstreet(self, value):
        """Alias for OtherAddressStreet.setter"""
        self.OtherAddressStreet = value

    @property
    def other_address_street(self):
        """Alias for OtherAddressStreet"""
        return self.OtherAddressStreet

    @other_address_street.setter
    def other_address_street(self, value):
        """Alias for OtherAddressStreet.setter"""
        self.OtherAddressStreet = value

    @property
    def OtherFaxNumber(self):
        return self.com_object.OtherFaxNumber

    @OtherFaxNumber.setter
    def OtherFaxNumber(self, value):
        self.com_object.OtherFaxNumber = value

    @property
    def otherfaxnumber(self):
        """Alias for OtherFaxNumber"""
        return self.OtherFaxNumber

    @otherfaxnumber.setter
    def otherfaxnumber(self, value):
        """Alias for OtherFaxNumber.setter"""
        self.OtherFaxNumber = value

    @property
    def other_fax_number(self):
        """Alias for OtherFaxNumber"""
        return self.OtherFaxNumber

    @other_fax_number.setter
    def other_fax_number(self, value):
        """Alias for OtherFaxNumber.setter"""
        self.OtherFaxNumber = value

    @property
    def OtherTelephoneNumber(self):
        return self.com_object.OtherTelephoneNumber

    @OtherTelephoneNumber.setter
    def OtherTelephoneNumber(self, value):
        self.com_object.OtherTelephoneNumber = value

    @property
    def othertelephonenumber(self):
        """Alias for OtherTelephoneNumber"""
        return self.OtherTelephoneNumber

    @othertelephonenumber.setter
    def othertelephonenumber(self, value):
        """Alias for OtherTelephoneNumber.setter"""
        self.OtherTelephoneNumber = value

    @property
    def other_telephone_number(self):
        """Alias for OtherTelephoneNumber"""
        return self.OtherTelephoneNumber

    @other_telephone_number.setter
    def other_telephone_number(self, value):
        """Alias for OtherTelephoneNumber.setter"""
        self.OtherTelephoneNumber = value

    @property
    def OutlookInternalVersion(self):
        return self.com_object.OutlookInternalVersion

    @property
    def outlookinternalversion(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def outlook_internal_version(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def OutlookVersion(self):
        return self.com_object.OutlookVersion

    @property
    def outlookversion(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def outlook_version(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def PagerNumber(self):
        return self.com_object.PagerNumber

    @PagerNumber.setter
    def PagerNumber(self, value):
        self.com_object.PagerNumber = value

    @property
    def pagernumber(self):
        """Alias for PagerNumber"""
        return self.PagerNumber

    @pagernumber.setter
    def pagernumber(self, value):
        """Alias for PagerNumber.setter"""
        self.PagerNumber = value

    @property
    def pager_number(self):
        """Alias for PagerNumber"""
        return self.PagerNumber

    @pager_number.setter
    def pager_number(self, value):
        """Alias for PagerNumber.setter"""
        self.PagerNumber = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PersonalHomePage(self):
        return self.com_object.PersonalHomePage

    @PersonalHomePage.setter
    def PersonalHomePage(self, value):
        self.com_object.PersonalHomePage = value

    @property
    def personalhomepage(self):
        """Alias for PersonalHomePage"""
        return self.PersonalHomePage

    @personalhomepage.setter
    def personalhomepage(self, value):
        """Alias for PersonalHomePage.setter"""
        self.PersonalHomePage = value

    @property
    def personal_home_page(self):
        """Alias for PersonalHomePage"""
        return self.PersonalHomePage

    @personal_home_page.setter
    def personal_home_page(self, value):
        """Alias for PersonalHomePage.setter"""
        self.PersonalHomePage = value

    @property
    def PrimaryTelephoneNumber(self):
        return self.com_object.PrimaryTelephoneNumber

    @PrimaryTelephoneNumber.setter
    def PrimaryTelephoneNumber(self, value):
        self.com_object.PrimaryTelephoneNumber = value

    @property
    def primarytelephonenumber(self):
        """Alias for PrimaryTelephoneNumber"""
        return self.PrimaryTelephoneNumber

    @primarytelephonenumber.setter
    def primarytelephonenumber(self, value):
        """Alias for PrimaryTelephoneNumber.setter"""
        self.PrimaryTelephoneNumber = value

    @property
    def primary_telephone_number(self):
        """Alias for PrimaryTelephoneNumber"""
        return self.PrimaryTelephoneNumber

    @primary_telephone_number.setter
    def primary_telephone_number(self, value):
        """Alias for PrimaryTelephoneNumber.setter"""
        self.PrimaryTelephoneNumber = value

    @property
    def Profession(self):
        return self.com_object.Profession

    @Profession.setter
    def Profession(self, value):
        self.com_object.Profession = value

    @property
    def profession(self):
        """Alias for Profession"""
        return self.Profession

    @profession.setter
    def profession(self, value):
        """Alias for Profession.setter"""
        self.Profession = value

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def RadioTelephoneNumber(self):
        return self.com_object.RadioTelephoneNumber

    @RadioTelephoneNumber.setter
    def RadioTelephoneNumber(self, value):
        self.com_object.RadioTelephoneNumber = value

    @property
    def radiotelephonenumber(self):
        """Alias for RadioTelephoneNumber"""
        return self.RadioTelephoneNumber

    @radiotelephonenumber.setter
    def radiotelephonenumber(self, value):
        """Alias for RadioTelephoneNumber.setter"""
        self.RadioTelephoneNumber = value

    @property
    def radio_telephone_number(self):
        """Alias for RadioTelephoneNumber"""
        return self.RadioTelephoneNumber

    @radio_telephone_number.setter
    def radio_telephone_number(self, value):
        """Alias for RadioTelephoneNumber.setter"""
        self.RadioTelephoneNumber = value

    @property
    def ReferredBy(self):
        return self.com_object.ReferredBy

    @ReferredBy.setter
    def ReferredBy(self, value):
        self.com_object.ReferredBy = value

    @property
    def referredby(self):
        """Alias for ReferredBy"""
        return self.ReferredBy

    @referredby.setter
    def referredby(self, value):
        """Alias for ReferredBy.setter"""
        self.ReferredBy = value

    @property
    def referred_by(self):
        """Alias for ReferredBy"""
        return self.ReferredBy

    @referred_by.setter
    def referred_by(self, value):
        """Alias for ReferredBy.setter"""
        self.ReferredBy = value

    @property
    def ReminderOverrideDefault(self):
        return self.com_object.ReminderOverrideDefault

    @ReminderOverrideDefault.setter
    def ReminderOverrideDefault(self, value):
        self.com_object.ReminderOverrideDefault = value

    @property
    def reminderoverridedefault(self):
        """Alias for ReminderOverrideDefault"""
        return self.ReminderOverrideDefault

    @reminderoverridedefault.setter
    def reminderoverridedefault(self, value):
        """Alias for ReminderOverrideDefault.setter"""
        self.ReminderOverrideDefault = value

    @property
    def reminder_override_default(self):
        """Alias for ReminderOverrideDefault"""
        return self.ReminderOverrideDefault

    @reminder_override_default.setter
    def reminder_override_default(self, value):
        """Alias for ReminderOverrideDefault.setter"""
        self.ReminderOverrideDefault = value

    @property
    def ReminderPlaySound(self):
        return self.com_object.ReminderPlaySound

    @ReminderPlaySound.setter
    def ReminderPlaySound(self, value):
        self.com_object.ReminderPlaySound = value

    @property
    def reminderplaysound(self):
        """Alias for ReminderPlaySound"""
        return self.ReminderPlaySound

    @reminderplaysound.setter
    def reminderplaysound(self, value):
        """Alias for ReminderPlaySound.setter"""
        self.ReminderPlaySound = value

    @property
    def reminder_play_sound(self):
        """Alias for ReminderPlaySound"""
        return self.ReminderPlaySound

    @reminder_play_sound.setter
    def reminder_play_sound(self, value):
        """Alias for ReminderPlaySound.setter"""
        self.ReminderPlaySound = value

    @property
    def ReminderSet(self):
        return self.com_object.ReminderSet

    @ReminderSet.setter
    def ReminderSet(self, value):
        self.com_object.ReminderSet = value

    @property
    def reminderset(self):
        """Alias for ReminderSet"""
        return self.ReminderSet

    @reminderset.setter
    def reminderset(self, value):
        """Alias for ReminderSet.setter"""
        self.ReminderSet = value

    @property
    def reminder_set(self):
        """Alias for ReminderSet"""
        return self.ReminderSet

    @reminder_set.setter
    def reminder_set(self, value):
        """Alias for ReminderSet.setter"""
        self.ReminderSet = value

    @property
    def ReminderSoundFile(self):
        return self.com_object.ReminderSoundFile

    @ReminderSoundFile.setter
    def ReminderSoundFile(self, value):
        self.com_object.ReminderSoundFile = value

    @property
    def remindersoundfile(self):
        """Alias for ReminderSoundFile"""
        return self.ReminderSoundFile

    @remindersoundfile.setter
    def remindersoundfile(self, value):
        """Alias for ReminderSoundFile.setter"""
        self.ReminderSoundFile = value

    @property
    def reminder_sound_file(self):
        """Alias for ReminderSoundFile"""
        return self.ReminderSoundFile

    @reminder_sound_file.setter
    def reminder_sound_file(self, value):
        """Alias for ReminderSoundFile.setter"""
        self.ReminderSoundFile = value

    @property
    def ReminderTime(self):
        return self.com_object.ReminderTime

    @ReminderTime.setter
    def ReminderTime(self, value):
        self.com_object.ReminderTime = value

    @property
    def remindertime(self):
        """Alias for ReminderTime"""
        return self.ReminderTime

    @remindertime.setter
    def remindertime(self, value):
        """Alias for ReminderTime.setter"""
        self.ReminderTime = value

    @property
    def reminder_time(self):
        """Alias for ReminderTime"""
        return self.ReminderTime

    @reminder_time.setter
    def reminder_time(self, value):
        """Alias for ReminderTime.setter"""
        self.ReminderTime = value

    @property
    def RTFBody(self):
        return self.com_object.RTFBody

    @RTFBody.setter
    def RTFBody(self, value):
        self.com_object.RTFBody = value

    @property
    def rtfbody(self):
        """Alias for RTFBody"""
        return self.RTFBody

    @rtfbody.setter
    def rtfbody(self, value):
        """Alias for RTFBody.setter"""
        self.RTFBody = value

    @property
    def r_t_f_body(self):
        """Alias for RTFBody"""
        return self.RTFBody

    @r_t_f_body.setter
    def r_t_f_body(self, value):
        """Alias for RTFBody.setter"""
        self.RTFBody = value

    @property
    def Saved(self):
        return self.com_object.Saved

    @property
    def saved(self):
        """Alias for Saved"""
        return self.Saved

    @property
    def SelectedMailingAddress(self):
        return OlMailingAddress(self.com_object.SelectedMailingAddress)

    @SelectedMailingAddress.setter
    def SelectedMailingAddress(self, value):
        self.com_object.SelectedMailingAddress = value

    @property
    def selectedmailingaddress(self):
        """Alias for SelectedMailingAddress"""
        return self.SelectedMailingAddress

    @selectedmailingaddress.setter
    def selectedmailingaddress(self, value):
        """Alias for SelectedMailingAddress.setter"""
        self.SelectedMailingAddress = value

    @property
    def selected_mailing_address(self):
        """Alias for SelectedMailingAddress"""
        return self.SelectedMailingAddress

    @selected_mailing_address.setter
    def selected_mailing_address(self, value):
        """Alias for SelectedMailingAddress.setter"""
        self.SelectedMailingAddress = value

    @property
    def Sensitivity(self):
        return OlSensitivity(self.com_object.Sensitivity)

    @Sensitivity.setter
    def Sensitivity(self, value):
        self.com_object.Sensitivity = value

    @property
    def sensitivity(self):
        """Alias for Sensitivity"""
        return self.Sensitivity

    @sensitivity.setter
    def sensitivity(self, value):
        """Alias for Sensitivity.setter"""
        self.Sensitivity = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Size(self):
        return self.com_object.Size

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @property
    def Spouse(self):
        return self.com_object.Spouse

    @Spouse.setter
    def Spouse(self, value):
        self.com_object.Spouse = value

    @property
    def spouse(self):
        """Alias for Spouse"""
        return self.Spouse

    @spouse.setter
    def spouse(self, value):
        """Alias for Spouse.setter"""
        self.Spouse = value

    @property
    def Subject(self):
        return self.com_object.Subject

    @Subject.setter
    def Subject(self, value):
        self.com_object.Subject = value

    @property
    def subject(self):
        """Alias for Subject"""
        return self.Subject

    @subject.setter
    def subject(self, value):
        """Alias for Subject.setter"""
        self.Subject = value

    @property
    def Suffix(self):
        return self.com_object.Suffix

    @Suffix.setter
    def Suffix(self, value):
        self.com_object.Suffix = value

    @property
    def suffix(self):
        """Alias for Suffix"""
        return self.Suffix

    @suffix.setter
    def suffix(self, value):
        """Alias for Suffix.setter"""
        self.Suffix = value

    @property
    def TaskCompletedDate(self):
        return ContactItem(self.com_object.TaskCompletedDate)

    @TaskCompletedDate.setter
    def TaskCompletedDate(self, value):
        self.com_object.TaskCompletedDate = value

    @property
    def taskcompleteddate(self):
        """Alias for TaskCompletedDate"""
        return self.TaskCompletedDate

    @taskcompleteddate.setter
    def taskcompleteddate(self, value):
        """Alias for TaskCompletedDate.setter"""
        self.TaskCompletedDate = value

    @property
    def task_completed_date(self):
        """Alias for TaskCompletedDate"""
        return self.TaskCompletedDate

    @task_completed_date.setter
    def task_completed_date(self, value):
        """Alias for TaskCompletedDate.setter"""
        self.TaskCompletedDate = value

    @property
    def TaskDueDate(self):
        return ContactItem(self.com_object.TaskDueDate)

    @TaskDueDate.setter
    def TaskDueDate(self, value):
        self.com_object.TaskDueDate = value

    @property
    def taskduedate(self):
        """Alias for TaskDueDate"""
        return self.TaskDueDate

    @taskduedate.setter
    def taskduedate(self, value):
        """Alias for TaskDueDate.setter"""
        self.TaskDueDate = value

    @property
    def task_due_date(self):
        """Alias for TaskDueDate"""
        return self.TaskDueDate

    @task_due_date.setter
    def task_due_date(self, value):
        """Alias for TaskDueDate.setter"""
        self.TaskDueDate = value

    @property
    def TaskStartDate(self):
        return ContactItem(self.com_object.TaskStartDate)

    @TaskStartDate.setter
    def TaskStartDate(self, value):
        self.com_object.TaskStartDate = value

    @property
    def taskstartdate(self):
        """Alias for TaskStartDate"""
        return self.TaskStartDate

    @taskstartdate.setter
    def taskstartdate(self, value):
        """Alias for TaskStartDate.setter"""
        self.TaskStartDate = value

    @property
    def task_start_date(self):
        """Alias for TaskStartDate"""
        return self.TaskStartDate

    @task_start_date.setter
    def task_start_date(self, value):
        """Alias for TaskStartDate.setter"""
        self.TaskStartDate = value

    @property
    def TaskSubject(self):
        return ContactItem(self.com_object.TaskSubject)

    @TaskSubject.setter
    def TaskSubject(self, value):
        self.com_object.TaskSubject = value

    @property
    def tasksubject(self):
        """Alias for TaskSubject"""
        return self.TaskSubject

    @tasksubject.setter
    def tasksubject(self, value):
        """Alias for TaskSubject.setter"""
        self.TaskSubject = value

    @property
    def task_subject(self):
        """Alias for TaskSubject"""
        return self.TaskSubject

    @task_subject.setter
    def task_subject(self, value):
        """Alias for TaskSubject.setter"""
        self.TaskSubject = value

    @property
    def TelexNumber(self):
        return self.com_object.TelexNumber

    @TelexNumber.setter
    def TelexNumber(self, value):
        self.com_object.TelexNumber = value

    @property
    def telexnumber(self):
        """Alias for TelexNumber"""
        return self.TelexNumber

    @telexnumber.setter
    def telexnumber(self, value):
        """Alias for TelexNumber.setter"""
        self.TelexNumber = value

    @property
    def telex_number(self):
        """Alias for TelexNumber"""
        return self.TelexNumber

    @telex_number.setter
    def telex_number(self, value):
        """Alias for TelexNumber.setter"""
        self.TelexNumber = value

    @property
    def Title(self):
        return self.com_object.Title

    @Title.setter
    def Title(self, value):
        self.com_object.Title = value

    @property
    def title(self):
        """Alias for Title"""
        return self.Title

    @title.setter
    def title(self, value):
        """Alias for Title.setter"""
        self.Title = value

    @property
    def ToDoTaskOrdinal(self):
        return ContactItem(self.com_object.ToDoTaskOrdinal)

    @ToDoTaskOrdinal.setter
    def ToDoTaskOrdinal(self, value):
        self.com_object.ToDoTaskOrdinal = value

    @property
    def todotaskordinal(self):
        """Alias for ToDoTaskOrdinal"""
        return self.ToDoTaskOrdinal

    @todotaskordinal.setter
    def todotaskordinal(self, value):
        """Alias for ToDoTaskOrdinal.setter"""
        self.ToDoTaskOrdinal = value

    @property
    def to_do_task_ordinal(self):
        """Alias for ToDoTaskOrdinal"""
        return self.ToDoTaskOrdinal

    @to_do_task_ordinal.setter
    def to_do_task_ordinal(self, value):
        """Alias for ToDoTaskOrdinal.setter"""
        self.ToDoTaskOrdinal = value

    @property
    def TTYTDDTelephoneNumber(self):
        return self.com_object.TTYTDDTelephoneNumber

    @TTYTDDTelephoneNumber.setter
    def TTYTDDTelephoneNumber(self, value):
        self.com_object.TTYTDDTelephoneNumber = value

    @property
    def ttytddtelephonenumber(self):
        """Alias for TTYTDDTelephoneNumber"""
        return self.TTYTDDTelephoneNumber

    @ttytddtelephonenumber.setter
    def ttytddtelephonenumber(self, value):
        """Alias for TTYTDDTelephoneNumber.setter"""
        self.TTYTDDTelephoneNumber = value

    @property
    def t_t_y_t_d_d_telephone_number(self):
        """Alias for TTYTDDTelephoneNumber"""
        return self.TTYTDDTelephoneNumber

    @t_t_y_t_d_d_telephone_number.setter
    def t_t_y_t_d_d_telephone_number(self, value):
        """Alias for TTYTDDTelephoneNumber.setter"""
        self.TTYTDDTelephoneNumber = value

    @property
    def UnRead(self):
        return self.com_object.UnRead

    @UnRead.setter
    def UnRead(self, value):
        self.com_object.UnRead = value

    @property
    def unread(self):
        """Alias for UnRead"""
        return self.UnRead

    @unread.setter
    def unread(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def un_read(self):
        """Alias for UnRead"""
        return self.UnRead

    @un_read.setter
    def un_read(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def User1(self):
        return self.com_object.User1

    @User1.setter
    def User1(self, value):
        self.com_object.User1 = value

    @property
    def user1(self):
        """Alias for User1"""
        return self.User1

    @user1.setter
    def user1(self, value):
        """Alias for User1.setter"""
        self.User1 = value

    @property
    def User2(self):
        return self.com_object.User2

    @User2.setter
    def User2(self, value):
        self.com_object.User2 = value

    @property
    def user2(self):
        """Alias for User2"""
        return self.User2

    @user2.setter
    def user2(self, value):
        """Alias for User2.setter"""
        self.User2 = value

    @property
    def User3(self):
        return self.com_object.User3

    @User3.setter
    def User3(self, value):
        self.com_object.User3 = value

    @property
    def user3(self):
        """Alias for User3"""
        return self.User3

    @user3.setter
    def user3(self, value):
        """Alias for User3.setter"""
        self.User3 = value

    @property
    def User4(self):
        return self.com_object.User4

    @User4.setter
    def User4(self, value):
        self.com_object.User4 = value

    @property
    def user4(self):
        """Alias for User4"""
        return self.User4

    @user4.setter
    def user4(self, value):
        """Alias for User4.setter"""
        self.User4 = value

    @property
    def UserProperties(self):
        return UserProperties(self.com_object.UserProperties)

    @property
    def userproperties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    @property
    def user_properties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    @property
    def WebPage(self):
        return self.com_object.WebPage

    @WebPage.setter
    def WebPage(self, value):
        self.com_object.WebPage = value

    @property
    def webpage(self):
        """Alias for WebPage"""
        return self.WebPage

    @webpage.setter
    def webpage(self, value):
        """Alias for WebPage.setter"""
        self.WebPage = value

    @property
    def web_page(self):
        """Alias for WebPage"""
        return self.WebPage

    @web_page.setter
    def web_page(self, value):
        """Alias for WebPage.setter"""
        self.WebPage = value

    @property
    def YomiCompanyName(self):
        return self.com_object.YomiCompanyName

    @YomiCompanyName.setter
    def YomiCompanyName(self, value):
        self.com_object.YomiCompanyName = value

    @property
    def yomicompanyname(self):
        """Alias for YomiCompanyName"""
        return self.YomiCompanyName

    @yomicompanyname.setter
    def yomicompanyname(self, value):
        """Alias for YomiCompanyName.setter"""
        self.YomiCompanyName = value

    @property
    def yomi_company_name(self):
        """Alias for YomiCompanyName"""
        return self.YomiCompanyName

    @yomi_company_name.setter
    def yomi_company_name(self, value):
        """Alias for YomiCompanyName.setter"""
        self.YomiCompanyName = value

    @property
    def YomiFirstName(self):
        return self.com_object.YomiFirstName

    @YomiFirstName.setter
    def YomiFirstName(self, value):
        self.com_object.YomiFirstName = value

    @property
    def yomifirstname(self):
        """Alias for YomiFirstName"""
        return self.YomiFirstName

    @yomifirstname.setter
    def yomifirstname(self, value):
        """Alias for YomiFirstName.setter"""
        self.YomiFirstName = value

    @property
    def yomi_first_name(self):
        """Alias for YomiFirstName"""
        return self.YomiFirstName

    @yomi_first_name.setter
    def yomi_first_name(self, value):
        """Alias for YomiFirstName.setter"""
        self.YomiFirstName = value

    @property
    def YomiLastName(self):
        return self.com_object.YomiLastName

    @YomiLastName.setter
    def YomiLastName(self, value):
        self.com_object.YomiLastName = value

    @property
    def yomilastname(self):
        """Alias for YomiLastName"""
        return self.YomiLastName

    @yomilastname.setter
    def yomilastname(self, value):
        """Alias for YomiLastName.setter"""
        self.YomiLastName = value

    @property
    def yomi_last_name(self):
        """Alias for YomiLastName"""
        return self.YomiLastName

    @yomi_last_name.setter
    def yomi_last_name(self, value):
        """Alias for YomiLastName.setter"""
        self.YomiLastName = value

    def AddBusinessCardLogoPicture(self, Path=None):
        arguments = com_arguments([unwrap(a) for a in [Path]])
        self.com_object.AddBusinessCardLogoPicture(*arguments)

    def addbusinesscardlogopicture(self, Path=None):
        """Alias for AddBusinessCardLogoPicture"""
        arguments = [Path]
        return self.AddBusinessCardLogoPicture(*arguments)

    def add_business_card_logo_picture(self, Path=None):
        """Alias for AddBusinessCardLogoPicture"""
        arguments = [Path]
        return self.AddBusinessCardLogoPicture(*arguments)

    def AddPicture(self, Path=None):
        arguments = com_arguments([unwrap(a) for a in [Path]])
        self.com_object.AddPicture(*arguments)

    def addpicture(self, Path=None):
        """Alias for AddPicture"""
        arguments = [Path]
        return self.AddPicture(*arguments)

    def add_picture(self, Path=None):
        """Alias for AddPicture"""
        arguments = [Path]
        return self.AddPicture(*arguments)

    def ClearTaskFlag(self):
        self.com_object.ClearTaskFlag()

    def cleartaskflag(self):
        """Alias for ClearTaskFlag"""
        return self.ClearTaskFlag()

    def clear_task_flag(self):
        """Alias for ClearTaskFlag"""
        return self.ClearTaskFlag()

    def Close(self, SaveMode=None):
        arguments = com_arguments([unwrap(a) for a in [SaveMode]])
        self.com_object.Close(*arguments)

    def close(self, SaveMode=None):
        """Alias for Close"""
        arguments = [SaveMode]
        return self.Close(*arguments)

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Display(self, Modal=None):
        arguments = com_arguments([unwrap(a) for a in [Modal]])
        self.com_object.Display(*arguments)

    def display(self, Modal=None):
        """Alias for Display"""
        arguments = [Modal]
        return self.Display(*arguments)

    def ForwardAsBusinessCard(self):
        return MailItem(self.com_object.ForwardAsBusinessCard())

    def forwardasbusinesscard(self):
        """Alias for ForwardAsBusinessCard"""
        return self.ForwardAsBusinessCard()

    def forward_as_business_card(self):
        """Alias for ForwardAsBusinessCard"""
        return self.ForwardAsBusinessCard()

    def ForwardAsVcard(self):
        return MailItem(self.com_object.ForwardAsVcard())

    def forwardasvcard(self):
        """Alias for ForwardAsVcard"""
        return self.ForwardAsVcard()

    def forward_as_vcard(self):
        """Alias for ForwardAsVcard"""
        return self.ForwardAsVcard()

    def GetConversation(self):
        return Conversation(self.com_object.GetConversation())

    def getconversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def get_conversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def MarkAsTask(self, MarkInterval=None):
        arguments = com_arguments([unwrap(a) for a in [MarkInterval]])
        self.com_object.MarkAsTask(*arguments)

    def markastask(self, MarkInterval=None):
        """Alias for MarkAsTask"""
        arguments = [MarkInterval]
        return self.MarkAsTask(*arguments)

    def mark_as_task(self, MarkInterval=None):
        """Alias for MarkAsTask"""
        arguments = [MarkInterval]
        return self.MarkAsTask(*arguments)

    def Move(self, DestFldr=None):
        arguments = com_arguments([unwrap(a) for a in [DestFldr]])
        return self.com_object.Move(*arguments)

    def move(self, DestFldr=None):
        """Alias for Move"""
        arguments = [DestFldr]
        return self.Move(*arguments)

    def PrintOut(self):
        self.com_object.PrintOut()

    def printout(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def print_out(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def RemovePicture(self):
        self.com_object.RemovePicture()

    def removepicture(self):
        """Alias for RemovePicture"""
        return self.RemovePicture()

    def remove_picture(self):
        """Alias for RemovePicture"""
        return self.RemovePicture()

    def ResetBusinessCard(self):
        self.com_object.ResetBusinessCard()

    def resetbusinesscard(self):
        """Alias for ResetBusinessCard"""
        return self.ResetBusinessCard()

    def reset_business_card(self):
        """Alias for ResetBusinessCard"""
        return self.ResetBusinessCard()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()

    def SaveAs(self, Path=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Path, Type]])
        self.com_object.SaveAs(*arguments)

    def saveas(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def save_as(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def SaveBusinessCardImage(self, Path=None):
        arguments = com_arguments([unwrap(a) for a in [Path]])
        self.com_object.SaveBusinessCardImage(*arguments)

    def savebusinesscardimage(self, Path=None):
        """Alias for SaveBusinessCardImage"""
        arguments = [Path]
        return self.SaveBusinessCardImage(*arguments)

    def save_business_card_image(self, Path=None):
        """Alias for SaveBusinessCardImage"""
        arguments = [Path]
        return self.SaveBusinessCardImage(*arguments)

    def ShowBusinessCardEditor(self):
        self.com_object.ShowBusinessCardEditor()

    def showbusinesscardeditor(self):
        """Alias for ShowBusinessCardEditor"""
        return self.ShowBusinessCardEditor()

    def show_business_card_editor(self):
        """Alias for ShowBusinessCardEditor"""
        return self.ShowBusinessCardEditor()

    def ShowCategoriesDialog(self):
        self.com_object.ShowCategoriesDialog()

    def showcategoriesdialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()

    def show_categories_dialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()

    def ShowCheckAddressDialog(self, MailingAddress=None):
        arguments = com_arguments([unwrap(a) for a in [MailingAddress]])
        self.com_object.ShowCheckAddressDialog(*arguments)

    def showcheckaddressdialog(self, MailingAddress=None):
        """Alias for ShowCheckAddressDialog"""
        arguments = [MailingAddress]
        return self.ShowCheckAddressDialog(*arguments)

    def show_check_address_dialog(self, MailingAddress=None):
        """Alias for ShowCheckAddressDialog"""
        arguments = [MailingAddress]
        return self.ShowCheckAddressDialog(*arguments)

    def ShowCheckFullNameDialog(self):
        self.com_object.ShowCheckFullNameDialog()

    def showcheckfullnamedialog(self):
        """Alias for ShowCheckFullNameDialog"""
        return self.ShowCheckFullNameDialog()

    def show_check_full_name_dialog(self):
        """Alias for ShowCheckFullNameDialog"""
        return self.ShowCheckFullNameDialog()

    def ShowCheckPhoneDialog(self, PhoneNumber=None):
        arguments = com_arguments([unwrap(a) for a in [PhoneNumber]])
        self.com_object.ShowCheckPhoneDialog(*arguments)

    def showcheckphonedialog(self, PhoneNumber=None):
        """Alias for ShowCheckPhoneDialog"""
        arguments = [PhoneNumber]
        return self.ShowCheckPhoneDialog(*arguments)

    def show_check_phone_dialog(self, PhoneNumber=None):
        """Alias for ShowCheckPhoneDialog"""
        arguments = [PhoneNumber]
        return self.ShowCheckPhoneDialog(*arguments)


class ContactsModule:

    def __init__(self, contactsmodule=None):
        self.com_object= contactsmodule

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Name(self):
        return ContactsModule(self.com_object.Name)

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NavigationGroups(self):
        return NavigationGroups(self.com_object.NavigationGroups)

    @property
    def navigationgroups(self):
        """Alias for NavigationGroups"""
        return self.NavigationGroups

    @property
    def navigation_groups(self):
        """Alias for NavigationGroups"""
        return self.NavigationGroups

    @property
    def NavigationModuleType(self):
        return olNavigationModuleType(self.com_object.NavigationModuleType)

    @property
    def navigationmoduletype(self):
        """Alias for NavigationModuleType"""
        return self.NavigationModuleType

    @property
    def navigation_module_type(self):
        """Alias for NavigationModuleType"""
        return self.NavigationModuleType

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return ContactsModule(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Visible(self):
        return ContactsModule(self.com_object.Visible)

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value


class Conversation:

    def __init__(self, conversation=None):
        self.com_object= conversation

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def ConversationID(self):
        return Conversation(self.com_object.ConversationID)

    @property
    def conversationid(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def conversation_i_d(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def Parent(self):
        return Conversation(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def ClearAlwaysAssignCategories(self, Store=None):
        arguments = com_arguments([unwrap(a) for a in [Store]])
        self.com_object.ClearAlwaysAssignCategories(*arguments)

    def clearalwaysassigncategories(self, Store=None):
        """Alias for ClearAlwaysAssignCategories"""
        arguments = [Store]
        return self.ClearAlwaysAssignCategories(*arguments)

    def clear_always_assign_categories(self, Store=None):
        """Alias for ClearAlwaysAssignCategories"""
        arguments = [Store]
        return self.ClearAlwaysAssignCategories(*arguments)

    def GetAlwaysAssignCategories(self, Store=None):
        arguments = com_arguments([unwrap(a) for a in [Store]])
        return self.com_object.GetAlwaysAssignCategories(*arguments)

    def getalwaysassigncategories(self, Store=None):
        """Alias for GetAlwaysAssignCategories"""
        arguments = [Store]
        return self.GetAlwaysAssignCategories(*arguments)

    def get_always_assign_categories(self, Store=None):
        """Alias for GetAlwaysAssignCategories"""
        arguments = [Store]
        return self.GetAlwaysAssignCategories(*arguments)

    def GetAlwaysDelete(self, Store=None):
        arguments = com_arguments([unwrap(a) for a in [Store]])
        return OlAlwaysDeleteConversation(self.com_object.GetAlwaysDelete(*arguments))

    def getalwaysdelete(self, Store=None):
        """Alias for GetAlwaysDelete"""
        arguments = [Store]
        return self.GetAlwaysDelete(*arguments)

    def get_always_delete(self, Store=None):
        """Alias for GetAlwaysDelete"""
        arguments = [Store]
        return self.GetAlwaysDelete(*arguments)

    def GetAlwaysMoveToFolder(self, Store=None):
        arguments = com_arguments([unwrap(a) for a in [Store]])
        return Folder(self.com_object.GetAlwaysMoveToFolder(*arguments))

    def getalwaysmovetofolder(self, Store=None):
        """Alias for GetAlwaysMoveToFolder"""
        arguments = [Store]
        return self.GetAlwaysMoveToFolder(*arguments)

    def get_always_move_to_folder(self, Store=None):
        """Alias for GetAlwaysMoveToFolder"""
        arguments = [Store]
        return self.GetAlwaysMoveToFolder(*arguments)

    def GetChildren(self, Item=None):
        arguments = com_arguments([unwrap(a) for a in [Item]])
        return SimpleItems(self.com_object.GetChildren(*arguments))

    def getchildren(self, Item=None):
        """Alias for GetChildren"""
        arguments = [Item]
        return self.GetChildren(*arguments)

    def get_children(self, Item=None):
        """Alias for GetChildren"""
        arguments = [Item]
        return self.GetChildren(*arguments)

    def GetParent(self, Item=None):
        arguments = com_arguments([unwrap(a) for a in [Item]])
        return self.com_object.GetParent(*arguments)

    def getparent(self, Item=None):
        """Alias for GetParent"""
        arguments = [Item]
        return self.GetParent(*arguments)

    def get_parent(self, Item=None):
        """Alias for GetParent"""
        arguments = [Item]
        return self.GetParent(*arguments)

    def GetRootItems(self):
        return SimpleItems(self.com_object.GetRootItems())

    def getrootitems(self):
        """Alias for GetRootItems"""
        return self.GetRootItems()

    def get_root_items(self):
        """Alias for GetRootItems"""
        return self.GetRootItems()

    def GetTable(self):
        return Table(self.com_object.GetTable())

    def gettable(self):
        """Alias for GetTable"""
        return self.GetTable()

    def get_table(self):
        """Alias for GetTable"""
        return self.GetTable()

    def MarkAsRead(self):
        self.com_object.MarkAsRead()

    def markasread(self):
        """Alias for MarkAsRead"""
        return self.MarkAsRead()

    def mark_as_read(self):
        """Alias for MarkAsRead"""
        return self.MarkAsRead()

    def MarkAsUnread(self):
        self.com_object.MarkAsUnread()

    def markasunread(self):
        """Alias for MarkAsUnread"""
        return self.MarkAsUnread()

    def mark_as_unread(self):
        """Alias for MarkAsUnread"""
        return self.MarkAsUnread()

    def SetAlwaysAssignCategories(self, Categories=None, Store=None):
        arguments = com_arguments([unwrap(a) for a in [Categories, Store]])
        self.com_object.SetAlwaysAssignCategories(*arguments)

    def setalwaysassigncategories(self, Categories=None, Store=None):
        """Alias for SetAlwaysAssignCategories"""
        arguments = [Categories, Store]
        return self.SetAlwaysAssignCategories(*arguments)

    def set_always_assign_categories(self, Categories=None, Store=None):
        """Alias for SetAlwaysAssignCategories"""
        arguments = [Categories, Store]
        return self.SetAlwaysAssignCategories(*arguments)

    def SetAlwaysDelete(self, AlwaysDelete=None, Store=None):
        arguments = com_arguments([unwrap(a) for a in [AlwaysDelete, Store]])
        self.com_object.SetAlwaysDelete(*arguments)

    def setalwaysdelete(self, AlwaysDelete=None, Store=None):
        """Alias for SetAlwaysDelete"""
        arguments = [AlwaysDelete, Store]
        return self.SetAlwaysDelete(*arguments)

    def set_always_delete(self, AlwaysDelete=None, Store=None):
        """Alias for SetAlwaysDelete"""
        arguments = [AlwaysDelete, Store]
        return self.SetAlwaysDelete(*arguments)

    def SetAlwaysMoveToFolder(self, MoveToFolder=None, Store=None):
        arguments = com_arguments([unwrap(a) for a in [MoveToFolder, Store]])
        self.com_object.SetAlwaysMoveToFolder(*arguments)

    def setalwaysmovetofolder(self, MoveToFolder=None, Store=None):
        """Alias for SetAlwaysMoveToFolder"""
        arguments = [MoveToFolder, Store]
        return self.SetAlwaysMoveToFolder(*arguments)

    def set_always_move_to_folder(self, MoveToFolder=None, Store=None):
        """Alias for SetAlwaysMoveToFolder"""
        arguments = [MoveToFolder, Store]
        return self.SetAlwaysMoveToFolder(*arguments)

    def StopAlwaysDelete(self, Store=None):
        arguments = com_arguments([unwrap(a) for a in [Store]])
        self.com_object.StopAlwaysDelete(*arguments)

    def stopalwaysdelete(self, Store=None):
        """Alias for StopAlwaysDelete"""
        arguments = [Store]
        return self.StopAlwaysDelete(*arguments)

    def stop_always_delete(self, Store=None):
        """Alias for StopAlwaysDelete"""
        arguments = [Store]
        return self.StopAlwaysDelete(*arguments)

    def StopAlwaysMoveToFolder(self, Store=None):
        arguments = com_arguments([unwrap(a) for a in [Store]])
        self.com_object.StopAlwaysMoveToFolder(*arguments)

    def stopalwaysmovetofolder(self, Store=None):
        """Alias for StopAlwaysMoveToFolder"""
        arguments = [Store]
        return self.StopAlwaysMoveToFolder(*arguments)

    def stop_always_move_to_folder(self, Store=None):
        """Alias for StopAlwaysMoveToFolder"""
        arguments = [Store]
        return self.StopAlwaysMoveToFolder(*arguments)


class ConversationHeader:

    def __init__(self, conversationheader=None):
        self.com_object= conversationheader

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def ConversationID(self):
        return Conversation(self.com_object.ConversationID)

    @property
    def conversationid(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def conversation_i_d(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def ConversationTopic(self):
        return self.com_object.ConversationTopic

    @property
    def conversationtopic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def conversation_topic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def GetConversation(self):
        return Conversation(self.com_object.GetConversation())

    def getconversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def get_conversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def GetItems(self):
        return SimpleItems(self.com_object.GetItems())

    def getitems(self):
        """Alias for GetItems"""
        return self.GetItems()

    def get_items(self):
        """Alias for GetItems"""
        return self.GetItems()


class DistListItem:

    def __init__(self, distlistitem=None):
        self.com_object= distlistitem

    @property
    def Actions(self):
        return Actions(self.com_object.Actions)

    @property
    def actions(self):
        """Alias for Actions"""
        return self.Actions

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Attachments(self):
        return Attachments(self.com_object.Attachments)

    @property
    def attachments(self):
        """Alias for Attachments"""
        return self.Attachments

    @property
    def AutoResolvedWinner(self):
        return self.com_object.AutoResolvedWinner

    @property
    def autoresolvedwinner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def auto_resolved_winner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def BillingInformation(self):
        return self.com_object.BillingInformation

    @BillingInformation.setter
    def BillingInformation(self, value):
        self.com_object.BillingInformation = value

    @property
    def billinginformation(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billinginformation.setter
    def billinginformation(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def billing_information(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billing_information.setter
    def billing_information(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def Body(self):
        return self.com_object.Body

    @Body.setter
    def Body(self, value):
        self.com_object.Body = value

    @property
    def body(self):
        """Alias for Body"""
        return self.Body

    @body.setter
    def body(self, value):
        """Alias for Body.setter"""
        self.Body = value

    @property
    def Categories(self):
        return self.com_object.Categories

    @Categories.setter
    def Categories(self, value):
        self.com_object.Categories = value

    @property
    def categories(self):
        """Alias for Categories"""
        return self.Categories

    @categories.setter
    def categories(self, value):
        """Alias for Categories.setter"""
        self.Categories = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Companies(self):
        return self.com_object.Companies

    @Companies.setter
    def Companies(self, value):
        self.com_object.Companies = value

    @property
    def companies(self):
        """Alias for Companies"""
        return self.Companies

    @companies.setter
    def companies(self, value):
        """Alias for Companies.setter"""
        self.Companies = value

    @property
    def Conflicts(self):
        return self.com_object.Conflicts

    @property
    def conflicts(self):
        """Alias for Conflicts"""
        return self.Conflicts

    @property
    def ConversationID(self):
        return Conversation(self.com_object.ConversationID)

    @property
    def conversationid(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def conversation_i_d(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def ConversationIndex(self):
        return self.com_object.ConversationIndex

    @property
    def conversationindex(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def conversation_index(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def ConversationTopic(self):
        return self.com_object.ConversationTopic

    @property
    def conversationtopic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def conversation_topic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def CreationTime(self):
        return self.com_object.CreationTime

    @property
    def creationtime(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def creation_time(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def DLName(self):
        return self.com_object.DLName

    @DLName.setter
    def DLName(self, value):
        self.com_object.DLName = value

    @property
    def dlname(self):
        """Alias for DLName"""
        return self.DLName

    @dlname.setter
    def dlname(self, value):
        """Alias for DLName.setter"""
        self.DLName = value

    @property
    def d_l_name(self):
        """Alias for DLName"""
        return self.DLName

    @d_l_name.setter
    def d_l_name(self, value):
        """Alias for DLName.setter"""
        self.DLName = value

    @property
    def DownloadState(self):
        return OlDownloadState(self.com_object.DownloadState)

    @property
    def downloadstate(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def download_state(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def EntryID(self):
        return self.com_object.EntryID

    @property
    def entryid(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def entry_i_d(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def FormDescription(self):
        return FormDescription(self.com_object.FormDescription)

    @property
    def formdescription(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def form_description(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def GetInspector(self):
        return Inspector(self.com_object.GetInspector)

    @property
    def getinspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def get_inspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def Importance(self):
        return OlImportance(self.com_object.Importance)

    @Importance.setter
    def Importance(self, value):
        self.com_object.Importance = value

    @property
    def importance(self):
        """Alias for Importance"""
        return self.Importance

    @importance.setter
    def importance(self, value):
        """Alias for Importance.setter"""
        self.Importance = value

    @property
    def IsConflict(self):
        return self.com_object.IsConflict

    @property
    def isconflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def is_conflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def IsMarkedAsTask(self):
        return DistListItem(self.com_object.IsMarkedAsTask)

    @property
    def ismarkedastask(self):
        """Alias for IsMarkedAsTask"""
        return self.IsMarkedAsTask

    @property
    def is_marked_as_task(self):
        """Alias for IsMarkedAsTask"""
        return self.IsMarkedAsTask

    @property
    def ItemProperties(self):
        return ItemProperties(self.com_object.ItemProperties)

    @property
    def itemproperties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def item_properties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def LastModificationTime(self):
        return self.com_object.LastModificationTime

    @property
    def lastmodificationtime(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def last_modification_time(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def MarkForDownload(self):
        return OlRemoteStatus(self.com_object.MarkForDownload)

    @MarkForDownload.setter
    def MarkForDownload(self, value):
        self.com_object.MarkForDownload = value

    @property
    def markfordownload(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @markfordownload.setter
    def markfordownload(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def mark_for_download(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @mark_for_download.setter
    def mark_for_download(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def MemberCount(self):
        return self.com_object.MemberCount

    @property
    def membercount(self):
        """Alias for MemberCount"""
        return self.MemberCount

    @property
    def member_count(self):
        """Alias for MemberCount"""
        return self.MemberCount

    @property
    def MessageClass(self):
        return self.com_object.MessageClass

    @MessageClass.setter
    def MessageClass(self, value):
        self.com_object.MessageClass = value

    @property
    def messageclass(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @messageclass.setter
    def messageclass(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def message_class(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @message_class.setter
    def message_class(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def Mileage(self):
        return self.com_object.Mileage

    @Mileage.setter
    def Mileage(self, value):
        self.com_object.Mileage = value

    @property
    def mileage(self):
        """Alias for Mileage"""
        return self.Mileage

    @mileage.setter
    def mileage(self, value):
        """Alias for Mileage.setter"""
        self.Mileage = value

    @property
    def NoAging(self):
        return self.com_object.NoAging

    @NoAging.setter
    def NoAging(self, value):
        self.com_object.NoAging = value

    @property
    def noaging(self):
        """Alias for NoAging"""
        return self.NoAging

    @noaging.setter
    def noaging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def no_aging(self):
        """Alias for NoAging"""
        return self.NoAging

    @no_aging.setter
    def no_aging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def OutlookInternalVersion(self):
        return self.com_object.OutlookInternalVersion

    @property
    def outlookinternalversion(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def outlook_internal_version(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def OutlookVersion(self):
        return self.com_object.OutlookVersion

    @property
    def outlookversion(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def outlook_version(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def ReminderOverrideDefault(self):
        return self.com_object.ReminderOverrideDefault

    @ReminderOverrideDefault.setter
    def ReminderOverrideDefault(self, value):
        self.com_object.ReminderOverrideDefault = value

    @property
    def reminderoverridedefault(self):
        """Alias for ReminderOverrideDefault"""
        return self.ReminderOverrideDefault

    @reminderoverridedefault.setter
    def reminderoverridedefault(self, value):
        """Alias for ReminderOverrideDefault.setter"""
        self.ReminderOverrideDefault = value

    @property
    def reminder_override_default(self):
        """Alias for ReminderOverrideDefault"""
        return self.ReminderOverrideDefault

    @reminder_override_default.setter
    def reminder_override_default(self, value):
        """Alias for ReminderOverrideDefault.setter"""
        self.ReminderOverrideDefault = value

    @property
    def ReminderPlaySound(self):
        return self.com_object.ReminderPlaySound

    @ReminderPlaySound.setter
    def ReminderPlaySound(self, value):
        self.com_object.ReminderPlaySound = value

    @property
    def reminderplaysound(self):
        """Alias for ReminderPlaySound"""
        return self.ReminderPlaySound

    @reminderplaysound.setter
    def reminderplaysound(self, value):
        """Alias for ReminderPlaySound.setter"""
        self.ReminderPlaySound = value

    @property
    def reminder_play_sound(self):
        """Alias for ReminderPlaySound"""
        return self.ReminderPlaySound

    @reminder_play_sound.setter
    def reminder_play_sound(self, value):
        """Alias for ReminderPlaySound.setter"""
        self.ReminderPlaySound = value

    @property
    def ReminderSet(self):
        return self.com_object.ReminderSet

    @ReminderSet.setter
    def ReminderSet(self, value):
        self.com_object.ReminderSet = value

    @property
    def reminderset(self):
        """Alias for ReminderSet"""
        return self.ReminderSet

    @reminderset.setter
    def reminderset(self, value):
        """Alias for ReminderSet.setter"""
        self.ReminderSet = value

    @property
    def reminder_set(self):
        """Alias for ReminderSet"""
        return self.ReminderSet

    @reminder_set.setter
    def reminder_set(self, value):
        """Alias for ReminderSet.setter"""
        self.ReminderSet = value

    @property
    def ReminderSoundFile(self):
        return self.com_object.ReminderSoundFile

    @ReminderSoundFile.setter
    def ReminderSoundFile(self, value):
        self.com_object.ReminderSoundFile = value

    @property
    def remindersoundfile(self):
        """Alias for ReminderSoundFile"""
        return self.ReminderSoundFile

    @remindersoundfile.setter
    def remindersoundfile(self, value):
        """Alias for ReminderSoundFile.setter"""
        self.ReminderSoundFile = value

    @property
    def reminder_sound_file(self):
        """Alias for ReminderSoundFile"""
        return self.ReminderSoundFile

    @reminder_sound_file.setter
    def reminder_sound_file(self, value):
        """Alias for ReminderSoundFile.setter"""
        self.ReminderSoundFile = value

    @property
    def ReminderTime(self):
        return self.com_object.ReminderTime

    @ReminderTime.setter
    def ReminderTime(self, value):
        self.com_object.ReminderTime = value

    @property
    def remindertime(self):
        """Alias for ReminderTime"""
        return self.ReminderTime

    @remindertime.setter
    def remindertime(self, value):
        """Alias for ReminderTime.setter"""
        self.ReminderTime = value

    @property
    def reminder_time(self):
        """Alias for ReminderTime"""
        return self.ReminderTime

    @reminder_time.setter
    def reminder_time(self, value):
        """Alias for ReminderTime.setter"""
        self.ReminderTime = value

    @property
    def RTFBody(self):
        return self.com_object.RTFBody

    @RTFBody.setter
    def RTFBody(self, value):
        self.com_object.RTFBody = value

    @property
    def rtfbody(self):
        """Alias for RTFBody"""
        return self.RTFBody

    @rtfbody.setter
    def rtfbody(self, value):
        """Alias for RTFBody.setter"""
        self.RTFBody = value

    @property
    def r_t_f_body(self):
        """Alias for RTFBody"""
        return self.RTFBody

    @r_t_f_body.setter
    def r_t_f_body(self, value):
        """Alias for RTFBody.setter"""
        self.RTFBody = value

    @property
    def Saved(self):
        return self.com_object.Saved

    @property
    def saved(self):
        """Alias for Saved"""
        return self.Saved

    @property
    def Sensitivity(self):
        return OlSensitivity(self.com_object.Sensitivity)

    @Sensitivity.setter
    def Sensitivity(self, value):
        self.com_object.Sensitivity = value

    @property
    def sensitivity(self):
        """Alias for Sensitivity"""
        return self.Sensitivity

    @sensitivity.setter
    def sensitivity(self, value):
        """Alias for Sensitivity.setter"""
        self.Sensitivity = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Size(self):
        return self.com_object.Size

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @property
    def Subject(self):
        return self.com_object.Subject

    @Subject.setter
    def Subject(self, value):
        self.com_object.Subject = value

    @property
    def subject(self):
        """Alias for Subject"""
        return self.Subject

    @subject.setter
    def subject(self, value):
        """Alias for Subject.setter"""
        self.Subject = value

    @property
    def TaskCompletedDate(self):
        return DistListItem(self.com_object.TaskCompletedDate)

    @TaskCompletedDate.setter
    def TaskCompletedDate(self, value):
        self.com_object.TaskCompletedDate = value

    @property
    def taskcompleteddate(self):
        """Alias for TaskCompletedDate"""
        return self.TaskCompletedDate

    @taskcompleteddate.setter
    def taskcompleteddate(self, value):
        """Alias for TaskCompletedDate.setter"""
        self.TaskCompletedDate = value

    @property
    def task_completed_date(self):
        """Alias for TaskCompletedDate"""
        return self.TaskCompletedDate

    @task_completed_date.setter
    def task_completed_date(self, value):
        """Alias for TaskCompletedDate.setter"""
        self.TaskCompletedDate = value

    @property
    def TaskDueDate(self):
        return DistListItem(self.com_object.TaskDueDate)

    @TaskDueDate.setter
    def TaskDueDate(self, value):
        self.com_object.TaskDueDate = value

    @property
    def taskduedate(self):
        """Alias for TaskDueDate"""
        return self.TaskDueDate

    @taskduedate.setter
    def taskduedate(self, value):
        """Alias for TaskDueDate.setter"""
        self.TaskDueDate = value

    @property
    def task_due_date(self):
        """Alias for TaskDueDate"""
        return self.TaskDueDate

    @task_due_date.setter
    def task_due_date(self, value):
        """Alias for TaskDueDate.setter"""
        self.TaskDueDate = value

    @property
    def TaskStartDate(self):
        return DistListItem(self.com_object.TaskStartDate)

    @TaskStartDate.setter
    def TaskStartDate(self, value):
        self.com_object.TaskStartDate = value

    @property
    def taskstartdate(self):
        """Alias for TaskStartDate"""
        return self.TaskStartDate

    @taskstartdate.setter
    def taskstartdate(self, value):
        """Alias for TaskStartDate.setter"""
        self.TaskStartDate = value

    @property
    def task_start_date(self):
        """Alias for TaskStartDate"""
        return self.TaskStartDate

    @task_start_date.setter
    def task_start_date(self, value):
        """Alias for TaskStartDate.setter"""
        self.TaskStartDate = value

    @property
    def TaskSubject(self):
        return DistListItem(self.com_object.TaskSubject)

    @TaskSubject.setter
    def TaskSubject(self, value):
        self.com_object.TaskSubject = value

    @property
    def tasksubject(self):
        """Alias for TaskSubject"""
        return self.TaskSubject

    @tasksubject.setter
    def tasksubject(self, value):
        """Alias for TaskSubject.setter"""
        self.TaskSubject = value

    @property
    def task_subject(self):
        """Alias for TaskSubject"""
        return self.TaskSubject

    @task_subject.setter
    def task_subject(self, value):
        """Alias for TaskSubject.setter"""
        self.TaskSubject = value

    @property
    def ToDoTaskOrdinal(self):
        return DistListItem(self.com_object.ToDoTaskOrdinal)

    @ToDoTaskOrdinal.setter
    def ToDoTaskOrdinal(self, value):
        self.com_object.ToDoTaskOrdinal = value

    @property
    def todotaskordinal(self):
        """Alias for ToDoTaskOrdinal"""
        return self.ToDoTaskOrdinal

    @todotaskordinal.setter
    def todotaskordinal(self, value):
        """Alias for ToDoTaskOrdinal.setter"""
        self.ToDoTaskOrdinal = value

    @property
    def to_do_task_ordinal(self):
        """Alias for ToDoTaskOrdinal"""
        return self.ToDoTaskOrdinal

    @to_do_task_ordinal.setter
    def to_do_task_ordinal(self, value):
        """Alias for ToDoTaskOrdinal.setter"""
        self.ToDoTaskOrdinal = value

    @property
    def UnRead(self):
        return self.com_object.UnRead

    @UnRead.setter
    def UnRead(self, value):
        self.com_object.UnRead = value

    @property
    def unread(self):
        """Alias for UnRead"""
        return self.UnRead

    @unread.setter
    def unread(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def un_read(self):
        """Alias for UnRead"""
        return self.UnRead

    @un_read.setter
    def un_read(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def UserProperties(self):
        return UserProperties(self.com_object.UserProperties)

    @property
    def userproperties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    @property
    def user_properties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    def AddMember(self, Recipient=None):
        arguments = com_arguments([unwrap(a) for a in [Recipient]])
        self.com_object.AddMember(*arguments)

    def addmember(self, Recipient=None):
        """Alias for AddMember"""
        arguments = [Recipient]
        return self.AddMember(*arguments)

    def add_member(self, Recipient=None):
        """Alias for AddMember"""
        arguments = [Recipient]
        return self.AddMember(*arguments)

    def AddMembers(self, Recipients=None):
        arguments = com_arguments([unwrap(a) for a in [Recipients]])
        self.com_object.AddMembers(*arguments)

    def addmembers(self, Recipients=None):
        """Alias for AddMembers"""
        arguments = [Recipients]
        return self.AddMembers(*arguments)

    def add_members(self, Recipients=None):
        """Alias for AddMembers"""
        arguments = [Recipients]
        return self.AddMembers(*arguments)

    def ClearTaskFlag(self):
        self.com_object.ClearTaskFlag()

    def cleartaskflag(self):
        """Alias for ClearTaskFlag"""
        return self.ClearTaskFlag()

    def clear_task_flag(self):
        """Alias for ClearTaskFlag"""
        return self.ClearTaskFlag()

    def Close(self, SaveMode=None):
        arguments = com_arguments([unwrap(a) for a in [SaveMode]])
        self.com_object.Close(*arguments)

    def close(self, SaveMode=None):
        """Alias for Close"""
        arguments = [SaveMode]
        return self.Close(*arguments)

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Display(self, Modal=None):
        arguments = com_arguments([unwrap(a) for a in [Modal]])
        self.com_object.Display(*arguments)

    def display(self, Modal=None):
        """Alias for Display"""
        arguments = [Modal]
        return self.Display(*arguments)

    def GetConversation(self):
        return Conversation(self.com_object.GetConversation())

    def getconversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def get_conversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def GetMember(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Recipient(self.com_object.GetMember(*arguments))

    def getmember(self, Index=None):
        """Alias for GetMember"""
        arguments = [Index]
        return self.GetMember(*arguments)

    def get_member(self, Index=None):
        """Alias for GetMember"""
        arguments = [Index]
        return self.GetMember(*arguments)

    def MarkAsTask(self, MarkInterval=None):
        arguments = com_arguments([unwrap(a) for a in [MarkInterval]])
        self.com_object.MarkAsTask(*arguments)

    def markastask(self, MarkInterval=None):
        """Alias for MarkAsTask"""
        arguments = [MarkInterval]
        return self.MarkAsTask(*arguments)

    def mark_as_task(self, MarkInterval=None):
        """Alias for MarkAsTask"""
        arguments = [MarkInterval]
        return self.MarkAsTask(*arguments)

    def Move(self, DestFldr=None):
        arguments = com_arguments([unwrap(a) for a in [DestFldr]])
        return self.com_object.Move(*arguments)

    def move(self, DestFldr=None):
        """Alias for Move"""
        arguments = [DestFldr]
        return self.Move(*arguments)

    def PrintOut(self):
        self.com_object.PrintOut()

    def printout(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def print_out(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def RemoveMember(self, Recipient=None):
        arguments = com_arguments([unwrap(a) for a in [Recipient]])
        self.com_object.RemoveMember(*arguments)

    def removemember(self, Recipient=None):
        """Alias for RemoveMember"""
        arguments = [Recipient]
        return self.RemoveMember(*arguments)

    def remove_member(self, Recipient=None):
        """Alias for RemoveMember"""
        arguments = [Recipient]
        return self.RemoveMember(*arguments)

    def RemoveMembers(self, Recipients=None):
        arguments = com_arguments([unwrap(a) for a in [Recipients]])
        self.com_object.RemoveMembers(*arguments)

    def removemembers(self, Recipients=None):
        """Alias for RemoveMembers"""
        arguments = [Recipients]
        return self.RemoveMembers(*arguments)

    def remove_members(self, Recipients=None):
        """Alias for RemoveMembers"""
        arguments = [Recipients]
        return self.RemoveMembers(*arguments)

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()

    def SaveAs(self, Path=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Path, Type]])
        self.com_object.SaveAs(*arguments)

    def saveas(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def save_as(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def ShowCategoriesDialog(self):
        self.com_object.ShowCategoriesDialog()

    def showcategoriesdialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()

    def show_categories_dialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()


class DocumentItem:

    def __init__(self, documentitem=None):
        self.com_object= documentitem

    @property
    def Actions(self):
        return Actions(self.com_object.Actions)

    @property
    def actions(self):
        """Alias for Actions"""
        return self.Actions

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Attachments(self):
        return Attachments(self.com_object.Attachments)

    @property
    def attachments(self):
        """Alias for Attachments"""
        return self.Attachments

    @property
    def AutoResolvedWinner(self):
        return self.com_object.AutoResolvedWinner

    @property
    def autoresolvedwinner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def auto_resolved_winner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def BillingInformation(self):
        return self.com_object.BillingInformation

    @BillingInformation.setter
    def BillingInformation(self, value):
        self.com_object.BillingInformation = value

    @property
    def billinginformation(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billinginformation.setter
    def billinginformation(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def billing_information(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billing_information.setter
    def billing_information(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def Body(self):
        return self.com_object.Body

    @property
    def body(self):
        """Alias for Body"""
        return self.Body

    @property
    def Categories(self):
        return self.com_object.Categories

    @Categories.setter
    def Categories(self, value):
        self.com_object.Categories = value

    @property
    def categories(self):
        """Alias for Categories"""
        return self.Categories

    @categories.setter
    def categories(self, value):
        """Alias for Categories.setter"""
        self.Categories = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Companies(self):
        return self.com_object.Companies

    @Companies.setter
    def Companies(self, value):
        self.com_object.Companies = value

    @property
    def companies(self):
        """Alias for Companies"""
        return self.Companies

    @companies.setter
    def companies(self, value):
        """Alias for Companies.setter"""
        self.Companies = value

    @property
    def Conflicts(self):
        return self.com_object.Conflicts

    @property
    def conflicts(self):
        """Alias for Conflicts"""
        return self.Conflicts

    @property
    def ConversationIndex(self):
        return self.com_object.ConversationIndex

    @property
    def conversationindex(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def conversation_index(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def ConversationTopic(self):
        return self.com_object.ConversationTopic

    @property
    def conversationtopic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def conversation_topic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def CreationTime(self):
        return self.com_object.CreationTime

    @property
    def creationtime(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def creation_time(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def DownloadState(self):
        return OlDownloadState(self.com_object.DownloadState)

    @property
    def downloadstate(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def download_state(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def EntryID(self):
        return self.com_object.EntryID

    @property
    def entryid(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def entry_i_d(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def FormDescription(self):
        return FormDescription(self.com_object.FormDescription)

    @property
    def formdescription(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def form_description(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def GetInspector(self):
        return self.com_object.GetInspector

    @property
    def getinspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def get_inspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def Importance(self):
        return OlImportance(self.com_object.Importance)

    @Importance.setter
    def Importance(self, value):
        self.com_object.Importance = value

    @property
    def importance(self):
        """Alias for Importance"""
        return self.Importance

    @importance.setter
    def importance(self, value):
        """Alias for Importance.setter"""
        self.Importance = value

    @property
    def IsConflict(self):
        return self.com_object.IsConflict

    @property
    def isconflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def is_conflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def ItemProperties(self):
        return ItemProperties(self.com_object.ItemProperties)

    @property
    def itemproperties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def item_properties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def LastModificationTime(self):
        return self.com_object.LastModificationTime

    @property
    def lastmodificationtime(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def last_modification_time(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def MarkForDownload(self):
        return self.com_object.MarkForDownload

    @property
    def markfordownload(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @property
    def mark_for_download(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @property
    def MessageClass(self):
        return self.com_object.MessageClass

    @MessageClass.setter
    def MessageClass(self, value):
        self.com_object.MessageClass = value

    @property
    def messageclass(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @messageclass.setter
    def messageclass(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def message_class(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @message_class.setter
    def message_class(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def Mileage(self):
        return self.com_object.Mileage

    @Mileage.setter
    def Mileage(self, value):
        self.com_object.Mileage = value

    @property
    def mileage(self):
        """Alias for Mileage"""
        return self.Mileage

    @mileage.setter
    def mileage(self, value):
        """Alias for Mileage.setter"""
        self.Mileage = value

    @property
    def NoAging(self):
        return self.com_object.NoAging

    @NoAging.setter
    def NoAging(self, value):
        self.com_object.NoAging = value

    @property
    def noaging(self):
        """Alias for NoAging"""
        return self.NoAging

    @noaging.setter
    def noaging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def no_aging(self):
        """Alias for NoAging"""
        return self.NoAging

    @no_aging.setter
    def no_aging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def OutlookInternalVersion(self):
        return self.com_object.OutlookInternalVersion

    @property
    def outlookinternalversion(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def outlook_internal_version(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def OutlookVersion(self):
        return self.com_object.OutlookVersion

    @property
    def outlookversion(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def outlook_version(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def Saved(self):
        return self.com_object.Saved

    @property
    def saved(self):
        """Alias for Saved"""
        return self.Saved

    @property
    def Sensitivity(self):
        return OlSensitivity(self.com_object.Sensitivity)

    @Sensitivity.setter
    def Sensitivity(self, value):
        self.com_object.Sensitivity = value

    @property
    def sensitivity(self):
        """Alias for Sensitivity"""
        return self.Sensitivity

    @sensitivity.setter
    def sensitivity(self, value):
        """Alias for Sensitivity.setter"""
        self.Sensitivity = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Size(self):
        return self.com_object.Size

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @property
    def Subject(self):
        return self.com_object.Subject

    @Subject.setter
    def Subject(self, value):
        self.com_object.Subject = value

    @property
    def subject(self):
        """Alias for Subject"""
        return self.Subject

    @subject.setter
    def subject(self, value):
        """Alias for Subject.setter"""
        self.Subject = value

    @property
    def UnRead(self):
        return self.com_object.UnRead

    @UnRead.setter
    def UnRead(self, value):
        self.com_object.UnRead = value

    @property
    def unread(self):
        """Alias for UnRead"""
        return self.UnRead

    @unread.setter
    def unread(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def un_read(self):
        """Alias for UnRead"""
        return self.UnRead

    @un_read.setter
    def un_read(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def UserProperties(self):
        return UserProperties(self.com_object.UserProperties)

    @property
    def userproperties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    @property
    def user_properties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    def Close(self, SaveMode=None):
        arguments = com_arguments([unwrap(a) for a in [SaveMode]])
        self.com_object.Close(*arguments)

    def close(self, SaveMode=None):
        """Alias for Close"""
        arguments = [SaveMode]
        return self.Close(*arguments)

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Display(self, Modal=None):
        arguments = com_arguments([unwrap(a) for a in [Modal]])
        self.com_object.Display(*arguments)

    def display(self, Modal=None):
        """Alias for Display"""
        arguments = [Modal]
        return self.Display(*arguments)

    def Move(self, DestFldr=None):
        arguments = com_arguments([unwrap(a) for a in [DestFldr]])
        return self.com_object.Move(*arguments)

    def move(self, DestFldr=None):
        """Alias for Move"""
        arguments = [DestFldr]
        return self.Move(*arguments)

    def PrintOut(self):
        self.com_object.PrintOut()

    def printout(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def print_out(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()

    def SaveAs(self, Path=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Path, Type]])
        self.com_object.SaveAs(*arguments)

    def saveas(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def save_as(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def ShowCategoriesDialog(self):
        self.com_object.ShowCategoriesDialog()

    def showcategoriesdialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()

    def show_categories_dialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()


class Exception:

    def __init__(self, exception=None):
        self.com_object= exception

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AppointmentItem(self):
        return AppointmentItem(self.com_object.AppointmentItem)

    @property
    def appointmentitem(self):
        """Alias for AppointmentItem"""
        return self.AppointmentItem

    @property
    def appointment_item(self):
        """Alias for AppointmentItem"""
        return self.AppointmentItem

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Deleted(self):
        return AppointmentItem(self.com_object.Deleted)

    @property
    def deleted(self):
        """Alias for Deleted"""
        return self.Deleted

    @property
    def OriginalDate(self):
        return AppointmentItem(self.com_object.OriginalDate)

    @property
    def originaldate(self):
        """Alias for OriginalDate"""
        return self.OriginalDate

    @property
    def original_date(self):
        """Alias for OriginalDate"""
        return self.OriginalDate

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session


class Exceptions:

    def __init__(self, exceptions=None):
        self.com_object= exceptions

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Exception(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ExchangeDistributionList:

    def __init__(self, exchangedistributionlist=None):
        self.com_object= exchangedistributionlist

    @property
    def Address(self):
        return ExchangeDistributionList(self.com_object.Address)

    @Address.setter
    def Address(self, value):
        self.com_object.Address = value

    @property
    def address(self):
        """Alias for Address"""
        return self.Address

    @address.setter
    def address(self, value):
        """Alias for Address.setter"""
        self.Address = value

    @property
    def AddressEntryUserType(self):
        return OlAddressEntryUserType(self.com_object.AddressEntryUserType)

    @property
    def addressentryusertype(self):
        """Alias for AddressEntryUserType"""
        return self.AddressEntryUserType

    @property
    def address_entry_user_type(self):
        """Alias for AddressEntryUserType"""
        return self.AddressEntryUserType

    @property
    def Alias(self):
        return ExchangeDistributionList(self.com_object.Alias)

    @property
    def alias(self):
        """Alias for Alias"""
        return self.Alias

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Comments(self):
        return self.com_object.Comments

    @Comments.setter
    def Comments(self, value):
        self.com_object.Comments = value

    @property
    def comments(self):
        """Alias for Comments"""
        return self.Comments

    @comments.setter
    def comments(self, value):
        """Alias for Comments.setter"""
        self.Comments = value

    @property
    def DisplayType(self):
        return OlDisplayType(self.com_object.DisplayType)

    @property
    def displaytype(self):
        """Alias for DisplayType"""
        return self.DisplayType

    @property
    def display_type(self):
        """Alias for DisplayType"""
        return self.DisplayType

    @property
    def ID(self):
        return ExchangeDistributionList(self.com_object.ID)

    @property
    def id(self):
        """Alias for ID"""
        return self.ID

    @property
    def i_d(self):
        """Alias for ID"""
        return self.ID

    @property
    def Name(self):
        return ExchangeDistributionList(self.com_object.Name)

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return ExchangeDistributionList(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PrimarySmtpAddress(self):
        return ExchangeDistributionList(self.com_object.PrimarySmtpAddress)

    @property
    def primarysmtpaddress(self):
        """Alias for PrimarySmtpAddress"""
        return self.PrimarySmtpAddress

    @property
    def primary_smtp_address(self):
        """Alias for PrimarySmtpAddress"""
        return self.PrimarySmtpAddress

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Type(self):
        return ExchangeDistributionList(self.com_object.Type)

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Details(self, HWnd=None):
        arguments = com_arguments([unwrap(a) for a in [HWnd]])
        self.com_object.Details(*arguments)

    def details(self, HWnd=None):
        """Alias for Details"""
        arguments = [HWnd]
        return self.Details(*arguments)

    def GetContact(self):
        return self.com_object.GetContact()

    def getcontact(self):
        """Alias for GetContact"""
        return self.GetContact()

    def get_contact(self):
        """Alias for GetContact"""
        return self.GetContact()

    def GetExchangeDistributionList(self):
        return ExchangeDistributionList(self.com_object.GetExchangeDistributionList())

    def getexchangedistributionlist(self):
        """Alias for GetExchangeDistributionList"""
        return self.GetExchangeDistributionList()

    def get_exchange_distribution_list(self):
        """Alias for GetExchangeDistributionList"""
        return self.GetExchangeDistributionList()

    def GetExchangeDistributionListMembers(self):
        return AddressEntry(self.com_object.GetExchangeDistributionListMembers())

    def getexchangedistributionlistmembers(self):
        """Alias for GetExchangeDistributionListMembers"""
        return self.GetExchangeDistributionListMembers()

    def get_exchange_distribution_list_members(self):
        """Alias for GetExchangeDistributionListMembers"""
        return self.GetExchangeDistributionListMembers()

    def GetExchangeUser(self):
        return self.com_object.GetExchangeUser()

    def getexchangeuser(self):
        """Alias for GetExchangeUser"""
        return self.GetExchangeUser()

    def get_exchange_user(self):
        """Alias for GetExchangeUser"""
        return self.GetExchangeUser()

    def GetFreeBusy(self, Start=None, MinPerChar=None, CompleteFormat=None):
        arguments = com_arguments([unwrap(a) for a in [Start, MinPerChar, CompleteFormat]])
        self.com_object.GetFreeBusy(*arguments)

    def getfreebusy(self, Start=None, MinPerChar=None, CompleteFormat=None):
        """Alias for GetFreeBusy"""
        arguments = [Start, MinPerChar, CompleteFormat]
        return self.GetFreeBusy(*arguments)

    def get_free_busy(self, Start=None, MinPerChar=None, CompleteFormat=None):
        """Alias for GetFreeBusy"""
        arguments = [Start, MinPerChar, CompleteFormat]
        return self.GetFreeBusy(*arguments)

    def GetMemberOfList(self):
        return AddressEntries(self.com_object.GetMemberOfList())

    def getmemberoflist(self):
        """Alias for GetMemberOfList"""
        return self.GetMemberOfList()

    def get_member_of_list(self):
        """Alias for GetMemberOfList"""
        return self.GetMemberOfList()

    def GetOwners(self):
        return AddressEntry(self.com_object.GetOwners())

    def getowners(self):
        """Alias for GetOwners"""
        return self.GetOwners()

    def get_owners(self):
        """Alias for GetOwners"""
        return self.GetOwners()

    def GetUnifiedGroup(self):
        return self.com_object.GetUnifiedGroup()

    def getunifiedgroup(self):
        """Alias for GetUnifiedGroup"""
        return self.GetUnifiedGroup()

    def get_unified_group(self):
        """Alias for GetUnifiedGroup"""
        return self.GetUnifiedGroup()

    def GetUnifiedGroupFromStore(self):
        return self.com_object.GetUnifiedGroupFromStore()

    def getunifiedgroupfromstore(self):
        """Alias for GetUnifiedGroupFromStore"""
        return self.GetUnifiedGroupFromStore()

    def get_unified_group_from_store(self):
        """Alias for GetUnifiedGroupFromStore"""
        return self.GetUnifiedGroupFromStore()

    def IsUnifiedGroup(self):
        return self.com_object.IsUnifiedGroup()

    def isunifiedgroup(self):
        """Alias for IsUnifiedGroup"""
        return self.IsUnifiedGroup()

    def is_unified_group(self):
        """Alias for IsUnifiedGroup"""
        return self.IsUnifiedGroup()

    def Update(self, MakePermanent=None, Refresh=None):
        arguments = com_arguments([unwrap(a) for a in [MakePermanent, Refresh]])
        self.com_object.Update(*arguments)

    def update(self, MakePermanent=None, Refresh=None):
        """Alias for Update"""
        arguments = [MakePermanent, Refresh]
        return self.Update(*arguments)


class ExchangeUser:

    def __init__(self, exchangeuser=None):
        self.com_object= exchangeuser

    @property
    def Address(self):
        return ExchangeUser(self.com_object.Address)

    @Address.setter
    def Address(self, value):
        self.com_object.Address = value

    @property
    def address(self):
        """Alias for Address"""
        return self.Address

    @address.setter
    def address(self, value):
        """Alias for Address.setter"""
        self.Address = value

    @property
    def AddressEntryUserType(self):
        return OlAddressEntryUserType(self.com_object.AddressEntryUserType)

    @property
    def addressentryusertype(self):
        """Alias for AddressEntryUserType"""
        return self.AddressEntryUserType

    @property
    def address_entry_user_type(self):
        """Alias for AddressEntryUserType"""
        return self.AddressEntryUserType

    @property
    def Alias(self):
        return ExchangeUser(self.com_object.Alias)

    @property
    def alias(self):
        """Alias for Alias"""
        return self.Alias

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AssistantName(self):
        return ExchangeUser(self.com_object.AssistantName)

    @AssistantName.setter
    def AssistantName(self, value):
        self.com_object.AssistantName = value

    @property
    def assistantname(self):
        """Alias for AssistantName"""
        return self.AssistantName

    @assistantname.setter
    def assistantname(self, value):
        """Alias for AssistantName.setter"""
        self.AssistantName = value

    @property
    def assistant_name(self):
        """Alias for AssistantName"""
        return self.AssistantName

    @assistant_name.setter
    def assistant_name(self, value):
        """Alias for AssistantName.setter"""
        self.AssistantName = value

    @property
    def BusinessTelephoneNumber(self):
        return ExchangeUser(self.com_object.BusinessTelephoneNumber)

    @BusinessTelephoneNumber.setter
    def BusinessTelephoneNumber(self, value):
        self.com_object.BusinessTelephoneNumber = value

    @property
    def businesstelephonenumber(self):
        """Alias for BusinessTelephoneNumber"""
        return self.BusinessTelephoneNumber

    @businesstelephonenumber.setter
    def businesstelephonenumber(self, value):
        """Alias for BusinessTelephoneNumber.setter"""
        self.BusinessTelephoneNumber = value

    @property
    def business_telephone_number(self):
        """Alias for BusinessTelephoneNumber"""
        return self.BusinessTelephoneNumber

    @business_telephone_number.setter
    def business_telephone_number(self, value):
        """Alias for BusinessTelephoneNumber.setter"""
        self.BusinessTelephoneNumber = value

    @property
    def City(self):
        return ExchangeUser(self.com_object.City)

    @City.setter
    def City(self, value):
        self.com_object.City = value

    @property
    def city(self):
        """Alias for City"""
        return self.City

    @city.setter
    def city(self, value):
        """Alias for City.setter"""
        self.City = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Comments(self):
        return self.com_object.Comments

    @Comments.setter
    def Comments(self, value):
        self.com_object.Comments = value

    @property
    def comments(self):
        """Alias for Comments"""
        return self.Comments

    @comments.setter
    def comments(self, value):
        """Alias for Comments.setter"""
        self.Comments = value

    @property
    def CompanyName(self):
        return ExchangeUser(self.com_object.CompanyName)

    @CompanyName.setter
    def CompanyName(self, value):
        self.com_object.CompanyName = value

    @property
    def companyname(self):
        """Alias for CompanyName"""
        return self.CompanyName

    @companyname.setter
    def companyname(self, value):
        """Alias for CompanyName.setter"""
        self.CompanyName = value

    @property
    def company_name(self):
        """Alias for CompanyName"""
        return self.CompanyName

    @company_name.setter
    def company_name(self, value):
        """Alias for CompanyName.setter"""
        self.CompanyName = value

    @property
    def Department(self):
        return ExchangeUser(self.com_object.Department)

    @Department.setter
    def Department(self, value):
        self.com_object.Department = value

    @property
    def department(self):
        """Alias for Department"""
        return self.Department

    @department.setter
    def department(self, value):
        """Alias for Department.setter"""
        self.Department = value

    @property
    def DisplayType(self):
        return OlDisplayType(self.com_object.DisplayType)

    @property
    def displaytype(self):
        """Alias for DisplayType"""
        return self.DisplayType

    @property
    def display_type(self):
        """Alias for DisplayType"""
        return self.DisplayType

    @property
    def FirstName(self):
        return ExchangeUser(self.com_object.FirstName)

    @FirstName.setter
    def FirstName(self, value):
        self.com_object.FirstName = value

    @property
    def firstname(self):
        """Alias for FirstName"""
        return self.FirstName

    @firstname.setter
    def firstname(self, value):
        """Alias for FirstName.setter"""
        self.FirstName = value

    @property
    def first_name(self):
        """Alias for FirstName"""
        return self.FirstName

    @first_name.setter
    def first_name(self, value):
        """Alias for FirstName.setter"""
        self.FirstName = value

    @property
    def ID(self):
        return ExchangeUser(self.com_object.ID)

    @property
    def id(self):
        """Alias for ID"""
        return self.ID

    @property
    def i_d(self):
        """Alias for ID"""
        return self.ID

    @property
    def JobTitle(self):
        return ExchangeUser(self.com_object.JobTitle)

    @JobTitle.setter
    def JobTitle(self, value):
        self.com_object.JobTitle = value

    @property
    def jobtitle(self):
        """Alias for JobTitle"""
        return self.JobTitle

    @jobtitle.setter
    def jobtitle(self, value):
        """Alias for JobTitle.setter"""
        self.JobTitle = value

    @property
    def job_title(self):
        """Alias for JobTitle"""
        return self.JobTitle

    @job_title.setter
    def job_title(self, value):
        """Alias for JobTitle.setter"""
        self.JobTitle = value

    @property
    def LastName(self):
        return ExchangeUser(self.com_object.LastName)

    @LastName.setter
    def LastName(self, value):
        self.com_object.LastName = value

    @property
    def lastname(self):
        """Alias for LastName"""
        return self.LastName

    @lastname.setter
    def lastname(self, value):
        """Alias for LastName.setter"""
        self.LastName = value

    @property
    def last_name(self):
        """Alias for LastName"""
        return self.LastName

    @last_name.setter
    def last_name(self, value):
        """Alias for LastName.setter"""
        self.LastName = value

    @property
    def MobileTelephoneNumber(self):
        return ExchangeUser(self.com_object.MobileTelephoneNumber)

    @MobileTelephoneNumber.setter
    def MobileTelephoneNumber(self, value):
        self.com_object.MobileTelephoneNumber = value

    @property
    def mobiletelephonenumber(self):
        """Alias for MobileTelephoneNumber"""
        return self.MobileTelephoneNumber

    @mobiletelephonenumber.setter
    def mobiletelephonenumber(self, value):
        """Alias for MobileTelephoneNumber.setter"""
        self.MobileTelephoneNumber = value

    @property
    def mobile_telephone_number(self):
        """Alias for MobileTelephoneNumber"""
        return self.MobileTelephoneNumber

    @mobile_telephone_number.setter
    def mobile_telephone_number(self, value):
        """Alias for MobileTelephoneNumber.setter"""
        self.MobileTelephoneNumber = value

    @property
    def Name(self):
        return ExchangeUser(self.com_object.Name)

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def OfficeLocation(self):
        return ExchangeUser(self.com_object.OfficeLocation)

    @OfficeLocation.setter
    def OfficeLocation(self, value):
        self.com_object.OfficeLocation = value

    @property
    def officelocation(self):
        """Alias for OfficeLocation"""
        return self.OfficeLocation

    @officelocation.setter
    def officelocation(self, value):
        """Alias for OfficeLocation.setter"""
        self.OfficeLocation = value

    @property
    def office_location(self):
        """Alias for OfficeLocation"""
        return self.OfficeLocation

    @office_location.setter
    def office_location(self, value):
        """Alias for OfficeLocation.setter"""
        self.OfficeLocation = value

    @property
    def Parent(self):
        return ExchangeUser(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PostalCode(self):
        return ExchangeUser(self.com_object.PostalCode)

    @PostalCode.setter
    def PostalCode(self, value):
        self.com_object.PostalCode = value

    @property
    def postalcode(self):
        """Alias for PostalCode"""
        return self.PostalCode

    @postalcode.setter
    def postalcode(self, value):
        """Alias for PostalCode.setter"""
        self.PostalCode = value

    @property
    def postal_code(self):
        """Alias for PostalCode"""
        return self.PostalCode

    @postal_code.setter
    def postal_code(self, value):
        """Alias for PostalCode.setter"""
        self.PostalCode = value

    @property
    def PrimarySmtpAddress(self):
        return ExchangeUser(self.com_object.PrimarySmtpAddress)

    @property
    def primarysmtpaddress(self):
        """Alias for PrimarySmtpAddress"""
        return self.PrimarySmtpAddress

    @property
    def primary_smtp_address(self):
        """Alias for PrimarySmtpAddress"""
        return self.PrimarySmtpAddress

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def StateOrProvince(self):
        return ExchangeUser(self.com_object.StateOrProvince)

    @StateOrProvince.setter
    def StateOrProvince(self, value):
        self.com_object.StateOrProvince = value

    @property
    def stateorprovince(self):
        """Alias for StateOrProvince"""
        return self.StateOrProvince

    @stateorprovince.setter
    def stateorprovince(self, value):
        """Alias for StateOrProvince.setter"""
        self.StateOrProvince = value

    @property
    def state_or_province(self):
        """Alias for StateOrProvince"""
        return self.StateOrProvince

    @state_or_province.setter
    def state_or_province(self, value):
        """Alias for StateOrProvince.setter"""
        self.StateOrProvince = value

    @property
    def StreetAddress(self):
        return ExchangeUser(self.com_object.StreetAddress)

    @StreetAddress.setter
    def StreetAddress(self, value):
        self.com_object.StreetAddress = value

    @property
    def streetaddress(self):
        """Alias for StreetAddress"""
        return self.StreetAddress

    @streetaddress.setter
    def streetaddress(self, value):
        """Alias for StreetAddress.setter"""
        self.StreetAddress = value

    @property
    def street_address(self):
        """Alias for StreetAddress"""
        return self.StreetAddress

    @street_address.setter
    def street_address(self, value):
        """Alias for StreetAddress.setter"""
        self.StreetAddress = value

    @property
    def Type(self):
        return ExchangeUser(self.com_object.Type)

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    @property
    def YomiCompanyName(self):
        return ExchangeUser(self.com_object.YomiCompanyName)

    @YomiCompanyName.setter
    def YomiCompanyName(self, value):
        self.com_object.YomiCompanyName = value

    @property
    def yomicompanyname(self):
        """Alias for YomiCompanyName"""
        return self.YomiCompanyName

    @yomicompanyname.setter
    def yomicompanyname(self, value):
        """Alias for YomiCompanyName.setter"""
        self.YomiCompanyName = value

    @property
    def yomi_company_name(self):
        """Alias for YomiCompanyName"""
        return self.YomiCompanyName

    @yomi_company_name.setter
    def yomi_company_name(self, value):
        """Alias for YomiCompanyName.setter"""
        self.YomiCompanyName = value

    @property
    def YomiDepartment(self):
        return ExchangeUser(self.com_object.YomiDepartment)

    @YomiDepartment.setter
    def YomiDepartment(self, value):
        self.com_object.YomiDepartment = value

    @property
    def yomidepartment(self):
        """Alias for YomiDepartment"""
        return self.YomiDepartment

    @yomidepartment.setter
    def yomidepartment(self, value):
        """Alias for YomiDepartment.setter"""
        self.YomiDepartment = value

    @property
    def yomi_department(self):
        """Alias for YomiDepartment"""
        return self.YomiDepartment

    @yomi_department.setter
    def yomi_department(self, value):
        """Alias for YomiDepartment.setter"""
        self.YomiDepartment = value

    @property
    def YomiDisplayName(self):
        return ExchangeUser(self.com_object.YomiDisplayName)

    @YomiDisplayName.setter
    def YomiDisplayName(self, value):
        self.com_object.YomiDisplayName = value

    @property
    def yomidisplayname(self):
        """Alias for YomiDisplayName"""
        return self.YomiDisplayName

    @yomidisplayname.setter
    def yomidisplayname(self, value):
        """Alias for YomiDisplayName.setter"""
        self.YomiDisplayName = value

    @property
    def yomi_display_name(self):
        """Alias for YomiDisplayName"""
        return self.YomiDisplayName

    @yomi_display_name.setter
    def yomi_display_name(self, value):
        """Alias for YomiDisplayName.setter"""
        self.YomiDisplayName = value

    @property
    def YomiFirstName(self):
        return ExchangeUser(self.com_object.YomiFirstName)

    @YomiFirstName.setter
    def YomiFirstName(self, value):
        self.com_object.YomiFirstName = value

    @property
    def yomifirstname(self):
        """Alias for YomiFirstName"""
        return self.YomiFirstName

    @yomifirstname.setter
    def yomifirstname(self, value):
        """Alias for YomiFirstName.setter"""
        self.YomiFirstName = value

    @property
    def yomi_first_name(self):
        """Alias for YomiFirstName"""
        return self.YomiFirstName

    @yomi_first_name.setter
    def yomi_first_name(self, value):
        """Alias for YomiFirstName.setter"""
        self.YomiFirstName = value

    @property
    def YomiLastName(self):
        return ExchangeUser(self.com_object.YomiLastName)

    @YomiLastName.setter
    def YomiLastName(self, value):
        self.com_object.YomiLastName = value

    @property
    def yomilastname(self):
        """Alias for YomiLastName"""
        return self.YomiLastName

    @yomilastname.setter
    def yomilastname(self, value):
        """Alias for YomiLastName.setter"""
        self.YomiLastName = value

    @property
    def yomi_last_name(self):
        """Alias for YomiLastName"""
        return self.YomiLastName

    @yomi_last_name.setter
    def yomi_last_name(self, value):
        """Alias for YomiLastName.setter"""
        self.YomiLastName = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Details(self, HWnd=None):
        arguments = com_arguments([unwrap(a) for a in [HWnd]])
        self.com_object.Details(*arguments)

    def details(self, HWnd=None):
        """Alias for Details"""
        arguments = [HWnd]
        return self.Details(*arguments)

    def GetContact(self):
        return self.com_object.GetContact()

    def getcontact(self):
        """Alias for GetContact"""
        return self.GetContact()

    def get_contact(self):
        """Alias for GetContact"""
        return self.GetContact()

    def GetDirectReports(self):
        return AddressEntry(self.com_object.GetDirectReports())

    def getdirectreports(self):
        """Alias for GetDirectReports"""
        return self.GetDirectReports()

    def get_direct_reports(self):
        """Alias for GetDirectReports"""
        return self.GetDirectReports()

    def GetExchangeDistributionList(self):
        return self.com_object.GetExchangeDistributionList()

    def getexchangedistributionlist(self):
        """Alias for GetExchangeDistributionList"""
        return self.GetExchangeDistributionList()

    def get_exchange_distribution_list(self):
        """Alias for GetExchangeDistributionList"""
        return self.GetExchangeDistributionList()

    def GetExchangeUser(self):
        return ExchangeUser(self.com_object.GetExchangeUser())

    def getexchangeuser(self):
        """Alias for GetExchangeUser"""
        return self.GetExchangeUser()

    def get_exchange_user(self):
        """Alias for GetExchangeUser"""
        return self.GetExchangeUser()

    def GetExchangeUserManager(self):
        return ExchangeUser(self.com_object.GetExchangeUserManager())

    def getexchangeusermanager(self):
        """Alias for GetExchangeUserManager"""
        return self.GetExchangeUserManager()

    def get_exchange_user_manager(self):
        """Alias for GetExchangeUserManager"""
        return self.GetExchangeUserManager()

    def GetFreeBusy(self, Start=None, MinPerChar=None, CompleteFormat=None):
        arguments = com_arguments([unwrap(a) for a in [Start, MinPerChar, CompleteFormat]])
        return self.com_object.GetFreeBusy(*arguments)

    def getfreebusy(self, Start=None, MinPerChar=None, CompleteFormat=None):
        """Alias for GetFreeBusy"""
        arguments = [Start, MinPerChar, CompleteFormat]
        return self.GetFreeBusy(*arguments)

    def get_free_busy(self, Start=None, MinPerChar=None, CompleteFormat=None):
        """Alias for GetFreeBusy"""
        arguments = [Start, MinPerChar, CompleteFormat]
        return self.GetFreeBusy(*arguments)

    def GetMemberOfList(self):
        return ExchangeUser(self.com_object.GetMemberOfList())

    def getmemberoflist(self):
        """Alias for GetMemberOfList"""
        return self.GetMemberOfList()

    def get_member_of_list(self):
        """Alias for GetMemberOfList"""
        return self.GetMemberOfList()

    def GetPicture(self):
        return self.com_object.GetPicture()

    def getpicture(self):
        """Alias for GetPicture"""
        return self.GetPicture()

    def get_picture(self):
        """Alias for GetPicture"""
        return self.GetPicture()

    def GetUnifiedGroup(self):
        return self.com_object.GetUnifiedGroup()

    def getunifiedgroup(self):
        """Alias for GetUnifiedGroup"""
        return self.GetUnifiedGroup()

    def get_unified_group(self):
        """Alias for GetUnifiedGroup"""
        return self.GetUnifiedGroup()

    def GetUnifiedGroupFromStore(self):
        return self.com_object.GetUnifiedGroupFromStore()

    def getunifiedgroupfromstore(self):
        """Alias for GetUnifiedGroupFromStore"""
        return self.GetUnifiedGroupFromStore()

    def get_unified_group_from_store(self):
        """Alias for GetUnifiedGroupFromStore"""
        return self.GetUnifiedGroupFromStore()

    def IsUnifiedGroup(self):
        return self.com_object.IsUnifiedGroup()

    def isunifiedgroup(self):
        """Alias for IsUnifiedGroup"""
        return self.IsUnifiedGroup()

    def is_unified_group(self):
        """Alias for IsUnifiedGroup"""
        return self.IsUnifiedGroup()

    def Update(self, MakePermanent=None, Refresh=None):
        arguments = com_arguments([unwrap(a) for a in [MakePermanent, Refresh]])
        self.com_object.Update(*arguments)

    def update(self, MakePermanent=None, Refresh=None):
        """Alias for Update"""
        arguments = [MakePermanent, Refresh]
        return self.Update(*arguments)


class Explorer:

    def __init__(self, explorer=None):
        self.com_object= explorer

    @property
    def AccountSelector(self):
        return AccountSelector(self.com_object.AccountSelector)

    @property
    def accountselector(self):
        """Alias for AccountSelector"""
        return self.AccountSelector

    @property
    def account_selector(self):
        """Alias for AccountSelector"""
        return self.AccountSelector

    @property
    def ActiveInlineResponse(self):
        return self.com_object.ActiveInlineResponse

    @property
    def activeinlineresponse(self):
        """Alias for ActiveInlineResponse"""
        return self.ActiveInlineResponse

    @property
    def active_inline_response(self):
        """Alias for ActiveInlineResponse"""
        return self.ActiveInlineResponse

    @property
    def ActiveInlineResponseWordEditor(self):
        return self.com_object.ActiveInlineResponseWordEditor

    @property
    def activeinlineresponsewordeditor(self):
        """Alias for ActiveInlineResponseWordEditor"""
        return self.ActiveInlineResponseWordEditor

    @property
    def active_inline_response_word_editor(self):
        """Alias for ActiveInlineResponseWordEditor"""
        return self.ActiveInlineResponseWordEditor

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AttachmentSelection(self):
        return AttachmentSelection(self.com_object.AttachmentSelection)

    @property
    def attachmentselection(self):
        """Alias for AttachmentSelection"""
        return self.AttachmentSelection

    @property
    def attachment_selection(self):
        """Alias for AttachmentSelection"""
        return self.AttachmentSelection

    @property
    def Caption(self):
        return self.com_object.Caption

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def CurrentFolder(self):
        return Folder(self.com_object.CurrentFolder)

    @CurrentFolder.setter
    def CurrentFolder(self, value):
        self.com_object.CurrentFolder = value

    @property
    def currentfolder(self):
        """Alias for CurrentFolder"""
        return self.CurrentFolder

    @currentfolder.setter
    def currentfolder(self, value):
        """Alias for CurrentFolder.setter"""
        self.CurrentFolder = value

    @property
    def current_folder(self):
        """Alias for CurrentFolder"""
        return self.CurrentFolder

    @current_folder.setter
    def current_folder(self, value):
        """Alias for CurrentFolder.setter"""
        self.CurrentFolder = value

    @property
    def CurrentView(self):
        return self.com_object.CurrentView

    @CurrentView.setter
    def CurrentView(self, value):
        self.com_object.CurrentView = value

    @property
    def currentview(self):
        """Alias for CurrentView"""
        return self.CurrentView

    @currentview.setter
    def currentview(self, value):
        """Alias for CurrentView.setter"""
        self.CurrentView = value

    @property
    def current_view(self):
        """Alias for CurrentView"""
        return self.CurrentView

    @current_view.setter
    def current_view(self, value):
        """Alias for CurrentView.setter"""
        self.CurrentView = value

    @property
    def DisplayMode(self):
        return self.com_object.DisplayMode

    @property
    def displaymode(self):
        """Alias for DisplayMode"""
        return self.DisplayMode

    @property
    def display_mode(self):
        """Alias for DisplayMode"""
        return self.DisplayMode

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HTMLDocument(self):
        return self.com_object.HTMLDocument

    @property
    def htmldocument(self):
        """Alias for HTMLDocument"""
        return self.HTMLDocument

    @property
    def h_t_m_l_document(self):
        """Alias for HTMLDocument"""
        return self.HTMLDocument

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def NavigationPane(self):
        return NavigationPane(self.com_object.NavigationPane)

    @property
    def navigationpane(self):
        """Alias for NavigationPane"""
        return self.NavigationPane

    @property
    def navigation_pane(self):
        """Alias for NavigationPane"""
        return self.NavigationPane

    @property
    def Panes(self):
        return Panes(self.com_object.Panes)

    @property
    def panes(self):
        """Alias for Panes"""
        return self.Panes

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PreviewPane(self):
        return self.com_object.PreviewPane

    @property
    def previewpane(self):
        """Alias for PreviewPane"""
        return self.PreviewPane

    @property
    def preview_pane(self):
        """Alias for PreviewPane"""
        return self.PreviewPane

    @property
    def Selection(self):
        return Selection(self.com_object.Selection)

    @property
    def selection(self):
        """Alias for Selection"""
        return self.Selection

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def WindowState(self):
        return OlWindowState(self.com_object.WindowState)

    @WindowState.setter
    def WindowState(self, value):
        self.com_object.WindowState = value

    @property
    def windowstate(self):
        """Alias for WindowState"""
        return self.WindowState

    @windowstate.setter
    def windowstate(self, value):
        """Alias for WindowState.setter"""
        self.WindowState = value

    @property
    def window_state(self):
        """Alias for WindowState"""
        return self.WindowState

    @window_state.setter
    def window_state(self, value):
        """Alias for WindowState.setter"""
        self.WindowState = value

    def Activate(self):
        self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()

    def AddToSelection(self, Item=None):
        arguments = com_arguments([unwrap(a) for a in [Item]])
        self.com_object.AddToSelection(*arguments)

    def addtoselection(self, Item=None):
        """Alias for AddToSelection"""
        arguments = [Item]
        return self.AddToSelection(*arguments)

    def add_to_selection(self, Item=None):
        """Alias for AddToSelection"""
        arguments = [Item]
        return self.AddToSelection(*arguments)

    def ClearSearch(self):
        self.com_object.ClearSearch()

    def clearsearch(self):
        """Alias for ClearSearch"""
        return self.ClearSearch()

    def clear_search(self):
        """Alias for ClearSearch"""
        return self.ClearSearch()

    def ClearSelection(self):
        self.com_object.ClearSelection()

    def clearselection(self):
        """Alias for ClearSelection"""
        return self.ClearSelection()

    def clear_selection(self):
        """Alias for ClearSelection"""
        return self.ClearSelection()

    def Close(self):
        self.com_object.Close()

    def close(self):
        """Alias for Close"""
        return self.Close()

    def Display(self):
        self.com_object.Display()

    def display(self):
        """Alias for Display"""
        return self.Display()

    def IsItemSelectableInView(self, Item=None):
        arguments = com_arguments([unwrap(a) for a in [Item]])
        return self.com_object.IsItemSelectableInView(*arguments)

    def isitemselectableinview(self, Item=None):
        """Alias for IsItemSelectableInView"""
        arguments = [Item]
        return self.IsItemSelectableInView(*arguments)

    def is_item_selectable_in_view(self, Item=None):
        """Alias for IsItemSelectableInView"""
        arguments = [Item]
        return self.IsItemSelectableInView(*arguments)

    def IsPaneVisible(self, Pane=None):
        arguments = com_arguments([unwrap(a) for a in [Pane]])
        return self.com_object.IsPaneVisible(*arguments)

    def ispanevisible(self, Pane=None):
        """Alias for IsPaneVisible"""
        arguments = [Pane]
        return self.IsPaneVisible(*arguments)

    def is_pane_visible(self, Pane=None):
        """Alias for IsPaneVisible"""
        arguments = [Pane]
        return self.IsPaneVisible(*arguments)

    def RemoveFromSelection(self, Item=None):
        arguments = com_arguments([unwrap(a) for a in [Item]])
        self.com_object.RemoveFromSelection(*arguments)

    def removefromselection(self, Item=None):
        """Alias for RemoveFromSelection"""
        arguments = [Item]
        return self.RemoveFromSelection(*arguments)

    def remove_from_selection(self, Item=None):
        """Alias for RemoveFromSelection"""
        arguments = [Item]
        return self.RemoveFromSelection(*arguments)

    def Search(self, Query=None, SearchScope=None):
        arguments = com_arguments([unwrap(a) for a in [Query, SearchScope]])
        self.com_object.Search(*arguments)

    def search(self, Query=None, SearchScope=None):
        """Alias for Search"""
        arguments = [Query, SearchScope]
        return self.Search(*arguments)

    def SelectAllItems(self):
        self.com_object.SelectAllItems()

    def selectallitems(self):
        """Alias for SelectAllItems"""
        return self.SelectAllItems()

    def select_all_items(self):
        """Alias for SelectAllItems"""
        return self.SelectAllItems()

    def ShowPane(self, Pane=None, Visible=None):
        arguments = com_arguments([unwrap(a) for a in [Pane, Visible]])
        self.com_object.ShowPane(*arguments)

    def showpane(self, Pane=None, Visible=None):
        """Alias for ShowPane"""
        arguments = [Pane, Visible]
        return self.ShowPane(*arguments)

    def show_pane(self, Pane=None, Visible=None):
        """Alias for ShowPane"""
        arguments = [Pane, Visible]
        return self.ShowPane(*arguments)


class Explorers:

    def __init__(self, explorers=None):
        self.com_object= explorers

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Add(self, Folder=None, DisplayMode=None):
        arguments = com_arguments([unwrap(a) for a in [Folder, DisplayMode]])
        return Explorer(self.com_object.Add(*arguments))

    def add(self, Folder=None, DisplayMode=None):
        """Alias for Add"""
        arguments = [Folder, DisplayMode]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Explorer(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Folder:

    def __init__(self, folder=None):
        self.com_object= folder

    @property
    def AddressBookName(self):
        return Folder(self.com_object.AddressBookName)

    @AddressBookName.setter
    def AddressBookName(self, value):
        self.com_object.AddressBookName = value

    @property
    def addressbookname(self):
        """Alias for AddressBookName"""
        return self.AddressBookName

    @addressbookname.setter
    def addressbookname(self, value):
        """Alias for AddressBookName.setter"""
        self.AddressBookName = value

    @property
    def address_book_name(self):
        """Alias for AddressBookName"""
        return self.AddressBookName

    @address_book_name.setter
    def address_book_name(self, value):
        """Alias for AddressBookName.setter"""
        self.AddressBookName = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def CurrentView(self):
        return View(self.com_object.CurrentView)

    @property
    def currentview(self):
        """Alias for CurrentView"""
        return self.CurrentView

    @property
    def current_view(self):
        """Alias for CurrentView"""
        return self.CurrentView

    @property
    def CustomViewsOnly(self):
        return self.com_object.CustomViewsOnly

    @CustomViewsOnly.setter
    def CustomViewsOnly(self, value):
        self.com_object.CustomViewsOnly = value

    @property
    def customviewsonly(self):
        """Alias for CustomViewsOnly"""
        return self.CustomViewsOnly

    @customviewsonly.setter
    def customviewsonly(self, value):
        """Alias for CustomViewsOnly.setter"""
        self.CustomViewsOnly = value

    @property
    def custom_views_only(self):
        """Alias for CustomViewsOnly"""
        return self.CustomViewsOnly

    @custom_views_only.setter
    def custom_views_only(self, value):
        """Alias for CustomViewsOnly.setter"""
        self.CustomViewsOnly = value

    @property
    def DefaultItemType(self):
        return OlItemType(self.com_object.DefaultItemType)

    @property
    def defaultitemtype(self):
        """Alias for DefaultItemType"""
        return self.DefaultItemType

    @property
    def default_item_type(self):
        """Alias for DefaultItemType"""
        return self.DefaultItemType

    @property
    def DefaultMessageClass(self):
        return self.com_object.DefaultMessageClass

    @property
    def defaultmessageclass(self):
        """Alias for DefaultMessageClass"""
        return self.DefaultMessageClass

    @property
    def default_message_class(self):
        """Alias for DefaultMessageClass"""
        return self.DefaultMessageClass

    @property
    def Description(self):
        return self.com_object.Description

    @Description.setter
    def Description(self, value):
        self.com_object.Description = value

    @property
    def description(self):
        """Alias for Description"""
        return self.Description

    @description.setter
    def description(self, value):
        """Alias for Description.setter"""
        self.Description = value

    @property
    def EntryID(self):
        return self.com_object.EntryID

    @property
    def entryid(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def entry_i_d(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def FolderPath(self):
        return self.com_object.FolderPath

    @property
    def folderpath(self):
        """Alias for FolderPath"""
        return self.FolderPath

    @property
    def folder_path(self):
        """Alias for FolderPath"""
        return self.FolderPath

    @property
    def Folders(self):
        return Folders(self.com_object.Folders)

    @property
    def folders(self):
        """Alias for Folders"""
        return self.Folders

    @property
    def InAppFolderSyncObject(self):
        return self.com_object.InAppFolderSyncObject

    @InAppFolderSyncObject.setter
    def InAppFolderSyncObject(self, value):
        self.com_object.InAppFolderSyncObject = value

    @property
    def inappfoldersyncobject(self):
        """Alias for InAppFolderSyncObject"""
        return self.InAppFolderSyncObject

    @inappfoldersyncobject.setter
    def inappfoldersyncobject(self, value):
        """Alias for InAppFolderSyncObject.setter"""
        self.InAppFolderSyncObject = value

    @property
    def in_app_folder_sync_object(self):
        """Alias for InAppFolderSyncObject"""
        return self.InAppFolderSyncObject

    @in_app_folder_sync_object.setter
    def in_app_folder_sync_object(self, value):
        """Alias for InAppFolderSyncObject.setter"""
        self.InAppFolderSyncObject = value

    @property
    def IsSharePointFolder(self):
        return self.com_object.IsSharePointFolder

    @property
    def issharepointfolder(self):
        """Alias for IsSharePointFolder"""
        return self.IsSharePointFolder

    @property
    def is_share_point_folder(self):
        """Alias for IsSharePointFolder"""
        return self.IsSharePointFolder

    @property
    def Items(self):
        return Items(self.com_object.Items)

    @property
    def items(self):
        """Alias for Items"""
        return self.Items

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def ShowAsOutlookAB(self):
        return self.com_object.ShowAsOutlookAB

    @ShowAsOutlookAB.setter
    def ShowAsOutlookAB(self, value):
        self.com_object.ShowAsOutlookAB = value

    @property
    def showasoutlookab(self):
        """Alias for ShowAsOutlookAB"""
        return self.ShowAsOutlookAB

    @showasoutlookab.setter
    def showasoutlookab(self, value):
        """Alias for ShowAsOutlookAB.setter"""
        self.ShowAsOutlookAB = value

    @property
    def show_as_outlook_a_b(self):
        """Alias for ShowAsOutlookAB"""
        return self.ShowAsOutlookAB

    @show_as_outlook_a_b.setter
    def show_as_outlook_a_b(self, value):
        """Alias for ShowAsOutlookAB.setter"""
        self.ShowAsOutlookAB = value

    @property
    def ShowItemCount(self):
        return self.com_object.ShowItemCount

    @ShowItemCount.setter
    def ShowItemCount(self, value):
        self.com_object.ShowItemCount = value

    @property
    def showitemcount(self):
        """Alias for ShowItemCount"""
        return self.ShowItemCount

    @showitemcount.setter
    def showitemcount(self, value):
        """Alias for ShowItemCount.setter"""
        self.ShowItemCount = value

    @property
    def show_item_count(self):
        """Alias for ShowItemCount"""
        return self.ShowItemCount

    @show_item_count.setter
    def show_item_count(self, value):
        """Alias for ShowItemCount.setter"""
        self.ShowItemCount = value

    @property
    def Store(self):
        return Store(self.com_object.Store)

    @property
    def store(self):
        """Alias for Store"""
        return self.Store

    @property
    def StoreID(self):
        return self.com_object.StoreID

    @property
    def storeid(self):
        """Alias for StoreID"""
        return self.StoreID

    @property
    def store_i_d(self):
        """Alias for StoreID"""
        return self.StoreID

    @property
    def UnReadItemCount(self):
        return self.com_object.UnReadItemCount

    @property
    def unreaditemcount(self):
        """Alias for UnReadItemCount"""
        return self.UnReadItemCount

    @property
    def un_read_item_count(self):
        """Alias for UnReadItemCount"""
        return self.UnReadItemCount

    @property
    def UserDefinedProperties(self):
        return UserDefinedProperties(self.com_object.UserDefinedProperties)

    @property
    def userdefinedproperties(self):
        """Alias for UserDefinedProperties"""
        return self.UserDefinedProperties

    @property
    def user_defined_properties(self):
        """Alias for UserDefinedProperties"""
        return self.UserDefinedProperties

    @property
    def Views(self):
        return Views(self.com_object.Views)

    @property
    def views(self):
        """Alias for Views"""
        return self.Views

    @property
    def WebViewOn(self):
        return self.com_object.WebViewOn

    @WebViewOn.setter
    def WebViewOn(self, value):
        self.com_object.WebViewOn = value

    @property
    def webviewon(self):
        """Alias for WebViewOn"""
        return self.WebViewOn

    @webviewon.setter
    def webviewon(self, value):
        """Alias for WebViewOn.setter"""
        self.WebViewOn = value

    @property
    def web_view_on(self):
        """Alias for WebViewOn"""
        return self.WebViewOn

    @web_view_on.setter
    def web_view_on(self, value):
        """Alias for WebViewOn.setter"""
        self.WebViewOn = value

    @property
    def WebViewURL(self):
        return self.com_object.WebViewURL

    @WebViewURL.setter
    def WebViewURL(self, value):
        self.com_object.WebViewURL = value

    @property
    def webviewurl(self):
        """Alias for WebViewURL"""
        return self.WebViewURL

    @webviewurl.setter
    def webviewurl(self, value):
        """Alias for WebViewURL.setter"""
        self.WebViewURL = value

    @property
    def web_view_u_r_l(self):
        """Alias for WebViewURL"""
        return self.WebViewURL

    @web_view_u_r_l.setter
    def web_view_u_r_l(self, value):
        """Alias for WebViewURL.setter"""
        self.WebViewURL = value

    def AddToPFFavorites(self):
        self.com_object.AddToPFFavorites()

    def addtopffavorites(self):
        """Alias for AddToPFFavorites"""
        return self.AddToPFFavorites()

    def add_to_p_f_favorites(self):
        """Alias for AddToPFFavorites"""
        return self.AddToPFFavorites()

    def CopyTo(self, DestinationFolder=None):
        arguments = com_arguments([unwrap(a) for a in [DestinationFolder]])
        return Folder(self.com_object.CopyTo(*arguments))

    def copyto(self, DestinationFolder=None):
        """Alias for CopyTo"""
        arguments = [DestinationFolder]
        return self.CopyTo(*arguments)

    def copy_to(self, DestinationFolder=None):
        """Alias for CopyTo"""
        arguments = [DestinationFolder]
        return self.CopyTo(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Display(self):
        self.com_object.Display()

    def display(self):
        """Alias for Display"""
        return self.Display()

    def GetCalendarExporter(self):
        return CalendarSharing(self.com_object.GetCalendarExporter())

    def getcalendarexporter(self):
        """Alias for GetCalendarExporter"""
        return self.GetCalendarExporter()

    def get_calendar_exporter(self):
        """Alias for GetCalendarExporter"""
        return self.GetCalendarExporter()

    def GetCustomIcon(self):
        return self.com_object.GetCustomIcon()

    def getcustomicon(self):
        """Alias for GetCustomIcon"""
        return self.GetCustomIcon()

    def get_custom_icon(self):
        """Alias for GetCustomIcon"""
        return self.GetCustomIcon()

    def GetExplorer(self, DisplayMode=None):
        arguments = com_arguments([unwrap(a) for a in [DisplayMode]])
        return Explorer(self.com_object.GetExplorer(*arguments))

    def getexplorer(self, DisplayMode=None):
        """Alias for GetExplorer"""
        arguments = [DisplayMode]
        return self.GetExplorer(*arguments)

    def get_explorer(self, DisplayMode=None):
        """Alias for GetExplorer"""
        arguments = [DisplayMode]
        return self.GetExplorer(*arguments)

    def GetOwner(self):
        return AddressEntry(self.com_object.GetOwner())

    def getowner(self):
        """Alias for GetOwner"""
        return self.GetOwner()

    def get_owner(self):
        """Alias for GetOwner"""
        return self.GetOwner()

    def GetStorage(self, StorageIdentifier=None, StorageIdentifierType=None):
        arguments = com_arguments([unwrap(a) for a in [StorageIdentifier, StorageIdentifierType]])
        return StorageItem(self.com_object.GetStorage(*arguments))

    def getstorage(self, StorageIdentifier=None, StorageIdentifierType=None):
        """Alias for GetStorage"""
        arguments = [StorageIdentifier, StorageIdentifierType]
        return self.GetStorage(*arguments)

    def get_storage(self, StorageIdentifier=None, StorageIdentifierType=None):
        """Alias for GetStorage"""
        arguments = [StorageIdentifier, StorageIdentifierType]
        return self.GetStorage(*arguments)

    def GetTable(self, Filter=None, TableContents=None):
        arguments = com_arguments([unwrap(a) for a in [Filter, TableContents]])
        return Folder(self.com_object.GetTable(*arguments))

    def gettable(self, Filter=None, TableContents=None):
        """Alias for GetTable"""
        arguments = [Filter, TableContents]
        return self.GetTable(*arguments)

    def get_table(self, Filter=None, TableContents=None):
        """Alias for GetTable"""
        arguments = [Filter, TableContents]
        return self.GetTable(*arguments)

    def MoveTo(self, DestinationFolder=None):
        arguments = com_arguments([unwrap(a) for a in [DestinationFolder]])
        self.com_object.MoveTo(*arguments)

    def moveto(self, DestinationFolder=None):
        """Alias for MoveTo"""
        arguments = [DestinationFolder]
        return self.MoveTo(*arguments)

    def move_to(self, DestinationFolder=None):
        """Alias for MoveTo"""
        arguments = [DestinationFolder]
        return self.MoveTo(*arguments)

    def SetCustomIcon(self, Picture=None):
        arguments = com_arguments([unwrap(a) for a in [Picture]])
        self.com_object.SetCustomIcon(*arguments)

    def setcustomicon(self, Picture=None):
        """Alias for SetCustomIcon"""
        arguments = [Picture]
        return self.SetCustomIcon(*arguments)

    def set_custom_icon(self, Picture=None):
        """Alias for SetCustomIcon"""
        arguments = [Picture]
        return self.SetCustomIcon(*arguments)


class Folders:

    def __init__(self, folders=None):
        self.com_object= folders

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Add(self, Name=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Type]])
        return Folder(self.com_object.Add(*arguments))

    def add(self, Name=None, Type=None):
        """Alias for Add"""
        arguments = [Name, Type]
        return self.Add(*arguments)

    def GetFirst(self):
        return Folder(self.com_object.GetFirst())

    def getfirst(self):
        """Alias for GetFirst"""
        return self.GetFirst()

    def get_first(self):
        """Alias for GetFirst"""
        return self.GetFirst()

    def GetLast(self):
        return Folder(self.com_object.GetLast())

    def getlast(self):
        """Alias for GetLast"""
        return self.GetLast()

    def get_last(self):
        """Alias for GetLast"""
        return self.GetLast()

    def GetNext(self):
        return Folder(self.com_object.GetNext())

    def getnext(self):
        """Alias for GetNext"""
        return self.GetNext()

    def get_next(self):
        """Alias for GetNext"""
        return self.GetNext()

    def GetPrevious(self):
        return Folder(self.com_object.GetPrevious())

    def getprevious(self):
        """Alias for GetPrevious"""
        return self.GetPrevious()

    def get_previous(self):
        """Alias for GetPrevious"""
        return self.GetPrevious()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Folder(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Remove(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Remove(*arguments)

    def remove(self, Index=None):
        """Alias for Remove"""
        arguments = [Index]
        return self.Remove(*arguments)


class Font:

    def __init__(self, font=None):
        self.com_object= font


class FormDescription:

    def __init__(self, formdescription=None):
        self.com_object= formdescription

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Category(self):
        return self.com_object.Category

    @Category.setter
    def Category(self, value):
        self.com_object.Category = value

    @property
    def category(self):
        """Alias for Category"""
        return self.Category

    @category.setter
    def category(self, value):
        """Alias for Category.setter"""
        self.Category = value

    @property
    def CategorySub(self):
        return self.com_object.CategorySub

    @CategorySub.setter
    def CategorySub(self, value):
        self.com_object.CategorySub = value

    @property
    def categorysub(self):
        """Alias for CategorySub"""
        return self.CategorySub

    @categorysub.setter
    def categorysub(self, value):
        """Alias for CategorySub.setter"""
        self.CategorySub = value

    @property
    def category_sub(self):
        """Alias for CategorySub"""
        return self.CategorySub

    @category_sub.setter
    def category_sub(self, value):
        """Alias for CategorySub.setter"""
        self.CategorySub = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Comment(self):
        return self.com_object.Comment

    @Comment.setter
    def Comment(self, value):
        self.com_object.Comment = value

    @property
    def comment(self):
        """Alias for Comment"""
        return self.Comment

    @comment.setter
    def comment(self, value):
        """Alias for Comment.setter"""
        self.Comment = value

    @property
    def ContactName(self):
        return FormDescription(self.com_object.ContactName)

    @ContactName.setter
    def ContactName(self, value):
        self.com_object.ContactName = value

    @property
    def contactname(self):
        """Alias for ContactName"""
        return self.ContactName

    @contactname.setter
    def contactname(self, value):
        """Alias for ContactName.setter"""
        self.ContactName = value

    @property
    def contact_name(self):
        """Alias for ContactName"""
        return self.ContactName

    @contact_name.setter
    def contact_name(self, value):
        """Alias for ContactName.setter"""
        self.ContactName = value

    @property
    def DisplayName(self):
        return self.com_object.DisplayName

    @DisplayName.setter
    def DisplayName(self, value):
        self.com_object.DisplayName = value

    @property
    def displayname(self):
        """Alias for DisplayName"""
        return self.DisplayName

    @displayname.setter
    def displayname(self, value):
        """Alias for DisplayName.setter"""
        self.DisplayName = value

    @property
    def display_name(self):
        """Alias for DisplayName"""
        return self.DisplayName

    @display_name.setter
    def display_name(self, value):
        """Alias for DisplayName.setter"""
        self.DisplayName = value

    @property
    def Hidden(self):
        return self.com_object.Hidden

    @Hidden.setter
    def Hidden(self, value):
        self.com_object.Hidden = value

    @property
    def hidden(self):
        """Alias for Hidden"""
        return self.Hidden

    @hidden.setter
    def hidden(self, value):
        """Alias for Hidden.setter"""
        self.Hidden = value

    @property
    def Icon(self):
        return self.com_object.Icon

    @Icon.setter
    def Icon(self, value):
        self.com_object.Icon = value

    @property
    def icon(self):
        """Alias for Icon"""
        return self.Icon

    @icon.setter
    def icon(self, value):
        """Alias for Icon.setter"""
        self.Icon = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def MessageClass(self):
        return FormDescription(self.com_object.MessageClass)

    @property
    def messageclass(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @property
    def message_class(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @property
    def MiniIcon(self):
        return self.com_object.MiniIcon

    @MiniIcon.setter
    def MiniIcon(self, value):
        self.com_object.MiniIcon = value

    @property
    def miniicon(self):
        """Alias for MiniIcon"""
        return self.MiniIcon

    @miniicon.setter
    def miniicon(self, value):
        """Alias for MiniIcon.setter"""
        self.MiniIcon = value

    @property
    def mini_icon(self):
        """Alias for MiniIcon"""
        return self.MiniIcon

    @mini_icon.setter
    def mini_icon(self, value):
        """Alias for MiniIcon.setter"""
        self.MiniIcon = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Number(self):
        return self.com_object.Number

    @Number.setter
    def Number(self, value):
        self.com_object.Number = value

    @property
    def number(self):
        """Alias for Number"""
        return self.Number

    @number.setter
    def number(self, value):
        """Alias for Number.setter"""
        self.Number = value

    @property
    def OneOff(self):
        return self.com_object.OneOff

    @OneOff.setter
    def OneOff(self, value):
        self.com_object.OneOff = value

    @property
    def oneoff(self):
        """Alias for OneOff"""
        return self.OneOff

    @oneoff.setter
    def oneoff(self, value):
        """Alias for OneOff.setter"""
        self.OneOff = value

    @property
    def one_off(self):
        """Alias for OneOff"""
        return self.OneOff

    @one_off.setter
    def one_off(self, value):
        """Alias for OneOff.setter"""
        self.OneOff = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ScriptText(self):
        return self.com_object.ScriptText

    @property
    def scripttext(self):
        """Alias for ScriptText"""
        return self.ScriptText

    @property
    def script_text(self):
        """Alias for ScriptText"""
        return self.ScriptText

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Template(self):
        return self.com_object.Template

    @Template.setter
    def Template(self, value):
        self.com_object.Template = value

    @property
    def template(self):
        """Alias for Template"""
        return self.Template

    @template.setter
    def template(self, value):
        """Alias for Template.setter"""
        self.Template = value

    @property
    def UseWordMail(self):
        return self.com_object.UseWordMail

    @UseWordMail.setter
    def UseWordMail(self, value):
        self.com_object.UseWordMail = value

    @property
    def usewordmail(self):
        """Alias for UseWordMail"""
        return self.UseWordMail

    @usewordmail.setter
    def usewordmail(self, value):
        """Alias for UseWordMail.setter"""
        self.UseWordMail = value

    @property
    def use_word_mail(self):
        """Alias for UseWordMail"""
        return self.UseWordMail

    @use_word_mail.setter
    def use_word_mail(self, value):
        """Alias for UseWordMail.setter"""
        self.UseWordMail = value

    @property
    def Version(self):
        return self.com_object.Version

    @Version.setter
    def Version(self, value):
        self.com_object.Version = value

    @property
    def version(self):
        """Alias for Version"""
        return self.Version

    @version.setter
    def version(self, value):
        """Alias for Version.setter"""
        self.Version = value

    def PublishForm(self, Registry=None, Folder=None):
        arguments = com_arguments([unwrap(a) for a in [Registry, Folder]])
        self.com_object.PublishForm(*arguments)

    def publishform(self, Registry=None, Folder=None):
        """Alias for PublishForm"""
        arguments = [Registry, Folder]
        return self.PublishForm(*arguments)

    def publish_form(self, Registry=None, Folder=None):
        """Alias for PublishForm"""
        arguments = [Registry, Folder]
        return self.PublishForm(*arguments)


class FormNameRuleCondition:

    def __init__(self, formnamerulecondition=None):
        self.com_object= formnamerulecondition

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def ConditionType(self):
        return OlRuleConditionType(self.com_object.ConditionType)

    @property
    def conditiontype(self):
        """Alias for ConditionType"""
        return self.ConditionType

    @property
    def condition_type(self):
        """Alias for ConditionType"""
        return self.ConditionType

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def FormName(self):
        return self.com_object.FormName

    @FormName.setter
    def FormName(self, value):
        self.com_object.FormName = value

    @property
    def formname(self):
        """Alias for FormName"""
        return self.FormName

    @formname.setter
    def formname(self, value):
        """Alias for FormName.setter"""
        self.FormName = value

    @property
    def form_name(self):
        """Alias for FormName"""
        return self.FormName

    @form_name.setter
    def form_name(self, value):
        """Alias for FormName.setter"""
        self.FormName = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session


class FormRegion:

    def __init__(self, formregion=None):
        self.com_object= formregion

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Detail(self):
        return self.com_object.Detail

    @Detail.setter
    def Detail(self, value):
        self.com_object.Detail = value

    @property
    def detail(self):
        """Alias for Detail"""
        return self.Detail

    @detail.setter
    def detail(self, value):
        """Alias for Detail.setter"""
        self.Detail = value

    @property
    def DisplayName(self):
        return self.com_object.DisplayName

    @property
    def displayname(self):
        """Alias for DisplayName"""
        return self.DisplayName

    @property
    def display_name(self):
        """Alias for DisplayName"""
        return self.DisplayName

    @property
    def EnableAutoLayout(self):
        return self.com_object.EnableAutoLayout

    @EnableAutoLayout.setter
    def EnableAutoLayout(self, value):
        self.com_object.EnableAutoLayout = value

    @property
    def enableautolayout(self):
        """Alias for EnableAutoLayout"""
        return self.EnableAutoLayout

    @enableautolayout.setter
    def enableautolayout(self, value):
        """Alias for EnableAutoLayout.setter"""
        self.EnableAutoLayout = value

    @property
    def enable_auto_layout(self):
        """Alias for EnableAutoLayout"""
        return self.EnableAutoLayout

    @enable_auto_layout.setter
    def enable_auto_layout(self, value):
        """Alias for EnableAutoLayout.setter"""
        self.EnableAutoLayout = value

    @property
    def Form(self):
        return self.com_object.Form

    @property
    def form(self):
        """Alias for Form"""
        return self.Form

    @property
    def FormRegionMode(self):
        return OlFormRegionMode(self.com_object.FormRegionMode)

    @property
    def formregionmode(self):
        """Alias for FormRegionMode"""
        return self.FormRegionMode

    @property
    def form_region_mode(self):
        """Alias for FormRegionMode"""
        return self.FormRegionMode

    @property
    def Inspector(self):
        return Inspector(self.com_object.Inspector)

    @property
    def inspector(self):
        """Alias for Inspector"""
        return self.Inspector

    @property
    def InternalName(self):
        return self.com_object.InternalName

    @property
    def internalname(self):
        """Alias for InternalName"""
        return self.InternalName

    @property
    def internal_name(self):
        """Alias for InternalName"""
        return self.InternalName

    @property
    def IsExpanded(self):
        return self.com_object.IsExpanded

    @property
    def isexpanded(self):
        """Alias for IsExpanded"""
        return self.IsExpanded

    @property
    def is_expanded(self):
        """Alias for IsExpanded"""
        return self.IsExpanded

    @property
    def Item(self):
        return self.com_object.Item

    @property
    def item(self):
        """Alias for Item"""
        return self.Item

    @property
    def Language(self):
        return self.com_object.Language

    @property
    def language(self):
        """Alias for Language"""
        return self.Language

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def SuppressControlReplacement(self):
        return self.com_object.SuppressControlReplacement

    @SuppressControlReplacement.setter
    def SuppressControlReplacement(self, value):
        self.com_object.SuppressControlReplacement = value

    @property
    def suppresscontrolreplacement(self):
        """Alias for SuppressControlReplacement"""
        return self.SuppressControlReplacement

    @suppresscontrolreplacement.setter
    def suppresscontrolreplacement(self, value):
        """Alias for SuppressControlReplacement.setter"""
        self.SuppressControlReplacement = value

    @property
    def suppress_control_replacement(self):
        """Alias for SuppressControlReplacement"""
        return self.SuppressControlReplacement

    @suppress_control_replacement.setter
    def suppress_control_replacement(self, value):
        """Alias for SuppressControlReplacement.setter"""
        self.SuppressControlReplacement = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    def Reflow(self):
        self.com_object.Reflow()

    def reflow(self):
        """Alias for Reflow"""
        return self.Reflow()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()

    def SetControlItemProperty(self, Control=None, PropertyName=None):
        arguments = com_arguments([unwrap(a) for a in [Control, PropertyName]])
        self.com_object.SetControlItemProperty(*arguments)

    def setcontrolitemproperty(self, Control=None, PropertyName=None):
        """Alias for SetControlItemProperty"""
        arguments = [Control, PropertyName]
        return self.SetControlItemProperty(*arguments)

    def set_control_item_property(self, Control=None, PropertyName=None):
        """Alias for SetControlItemProperty"""
        arguments = [Control, PropertyName]
        return self.SetControlItemProperty(*arguments)


class FormRegionStartup:

    def __init__(self, formregionstartup=None):
        self.com_object= formregionstartup

    def BeforeFormRegionShow(self, FormRegion=None):
        arguments = com_arguments([unwrap(a) for a in [FormRegion]])
        self.com_object.BeforeFormRegionShow(*arguments)

    def beforeformregionshow(self, FormRegion=None):
        """Alias for BeforeFormRegionShow"""
        arguments = [FormRegion]
        return self.BeforeFormRegionShow(*arguments)

    def before_form_region_show(self, FormRegion=None):
        """Alias for BeforeFormRegionShow"""
        arguments = [FormRegion]
        return self.BeforeFormRegionShow(*arguments)

    def GetFormRegionIcon(self, FormRegionName=None, LCID=None, Icon=None):
        arguments = com_arguments([unwrap(a) for a in [FormRegionName, LCID, Icon]])
        return self.com_object.GetFormRegionIcon(*arguments)

    def getformregionicon(self, FormRegionName=None, LCID=None, Icon=None):
        """Alias for GetFormRegionIcon"""
        arguments = [FormRegionName, LCID, Icon]
        return self.GetFormRegionIcon(*arguments)

    def get_form_region_icon(self, FormRegionName=None, LCID=None, Icon=None):
        """Alias for GetFormRegionIcon"""
        arguments = [FormRegionName, LCID, Icon]
        return self.GetFormRegionIcon(*arguments)

    def GetFormRegionManifest(self, FormRegionName=None, LCID=None):
        arguments = com_arguments([unwrap(a) for a in [FormRegionName, LCID]])
        return self.com_object.GetFormRegionManifest(*arguments)

    def getformregionmanifest(self, FormRegionName=None, LCID=None):
        """Alias for GetFormRegionManifest"""
        arguments = [FormRegionName, LCID]
        return self.GetFormRegionManifest(*arguments)

    def get_form_region_manifest(self, FormRegionName=None, LCID=None):
        """Alias for GetFormRegionManifest"""
        arguments = [FormRegionName, LCID]
        return self.GetFormRegionManifest(*arguments)

    def GetFormRegionStorage(self, FormRegionName=None, Item=None, LCID=None, FormRegionMode=None, FormRegionSize=None):
        arguments = com_arguments([unwrap(a) for a in [FormRegionName, Item, LCID, FormRegionMode, FormRegionSize]])
        return self.com_object.GetFormRegionStorage(*arguments)

    def getformregionstorage(self, FormRegionName=None, Item=None, LCID=None, FormRegionMode=None, FormRegionSize=None):
        """Alias for GetFormRegionStorage"""
        arguments = [FormRegionName, Item, LCID, FormRegionMode, FormRegionSize]
        return self.GetFormRegionStorage(*arguments)

    def get_form_region_storage(self, FormRegionName=None, Item=None, LCID=None, FormRegionMode=None, FormRegionSize=None):
        """Alias for GetFormRegionStorage"""
        arguments = [FormRegionName, Item, LCID, FormRegionMode, FormRegionSize]
        return self.GetFormRegionStorage(*arguments)


class Frame:

    def __init__(self, frame=None):
        self.com_object= frame


class FromRssFeedRuleCondition:

    def __init__(self, fromrssfeedrulecondition=None):
        self.com_object= fromrssfeedrulecondition

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def ConditionType(self):
        return OlRuleConditionType(self.com_object.ConditionType)

    @property
    def conditiontype(self):
        """Alias for ConditionType"""
        return self.ConditionType

    @property
    def condition_type(self):
        """Alias for ConditionType"""
        return self.ConditionType

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def FromRssFeed(self):
        return self.com_object.FromRssFeed

    @FromRssFeed.setter
    def FromRssFeed(self, value):
        self.com_object.FromRssFeed = value

    @property
    def fromrssfeed(self):
        """Alias for FromRssFeed"""
        return self.FromRssFeed

    @fromrssfeed.setter
    def fromrssfeed(self, value):
        """Alias for FromRssFeed.setter"""
        self.FromRssFeed = value

    @property
    def from_rss_feed(self):
        """Alias for FromRssFeed"""
        return self.FromRssFeed

    @from_rss_feed.setter
    def from_rss_feed(self, value):
        """Alias for FromRssFeed.setter"""
        self.FromRssFeed = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session


class IconView:

    def __init__(self, iconview=None):
        self.com_object= iconview

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Filter(self):
        return self.com_object.Filter

    @Filter.setter
    def Filter(self, value):
        self.com_object.Filter = value

    @property
    def filter(self):
        """Alias for Filter"""
        return self.Filter

    @filter.setter
    def filter(self, value):
        """Alias for Filter.setter"""
        self.Filter = value

    @property
    def IconPlacement(self):
        return OlIconViewPlacement(self.com_object.IconPlacement)

    @IconPlacement.setter
    def IconPlacement(self, value):
        self.com_object.IconPlacement = value

    @property
    def iconplacement(self):
        """Alias for IconPlacement"""
        return self.IconPlacement

    @iconplacement.setter
    def iconplacement(self, value):
        """Alias for IconPlacement.setter"""
        self.IconPlacement = value

    @property
    def icon_placement(self):
        """Alias for IconPlacement"""
        return self.IconPlacement

    @icon_placement.setter
    def icon_placement(self, value):
        """Alias for IconPlacement.setter"""
        self.IconPlacement = value

    @property
    def IconViewType(self):
        return OlIconViewType(self.com_object.IconViewType)

    @IconViewType.setter
    def IconViewType(self, value):
        self.com_object.IconViewType = value

    @property
    def iconviewtype(self):
        """Alias for IconViewType"""
        return self.IconViewType

    @iconviewtype.setter
    def iconviewtype(self, value):
        """Alias for IconViewType.setter"""
        self.IconViewType = value

    @property
    def icon_view_type(self):
        """Alias for IconViewType"""
        return self.IconViewType

    @icon_view_type.setter
    def icon_view_type(self, value):
        """Alias for IconViewType.setter"""
        self.IconViewType = value

    @property
    def Language(self):
        return self.com_object.Language

    @Language.setter
    def Language(self, value):
        self.com_object.Language = value

    @property
    def language(self):
        """Alias for Language"""
        return self.Language

    @language.setter
    def language(self, value):
        """Alias for Language.setter"""
        self.Language = value

    @property
    def LockUserChanges(self):
        return self.com_object.LockUserChanges

    @LockUserChanges.setter
    def LockUserChanges(self, value):
        self.com_object.LockUserChanges = value

    @property
    def lockuserchanges(self):
        """Alias for LockUserChanges"""
        return self.LockUserChanges

    @lockuserchanges.setter
    def lockuserchanges(self, value):
        """Alias for LockUserChanges.setter"""
        self.LockUserChanges = value

    @property
    def lock_user_changes(self):
        """Alias for LockUserChanges"""
        return self.LockUserChanges

    @lock_user_changes.setter
    def lock_user_changes(self, value):
        """Alias for LockUserChanges.setter"""
        self.LockUserChanges = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SaveOption(self):
        return OlViewSaveOption(self.com_object.SaveOption)

    @property
    def saveoption(self):
        """Alias for SaveOption"""
        return self.SaveOption

    @property
    def save_option(self):
        """Alias for SaveOption"""
        return self.SaveOption

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def SortFields(self):
        return OrderFields(self.com_object.SortFields)

    @property
    def sortfields(self):
        """Alias for SortFields"""
        return self.SortFields

    @property
    def sort_fields(self):
        """Alias for SortFields"""
        return self.SortFields

    @property
    def Standard(self):
        return IconView(self.com_object.Standard)

    @property
    def standard(self):
        """Alias for Standard"""
        return self.Standard

    @property
    def ViewType(self):
        return OlViewType(self.com_object.ViewType)

    @property
    def viewtype(self):
        """Alias for ViewType"""
        return self.ViewType

    @property
    def view_type(self):
        """Alias for ViewType"""
        return self.ViewType

    @property
    def XML(self):
        return self.com_object.XML

    @XML.setter
    def XML(self, value):
        self.com_object.XML = value

    @property
    def xml(self):
        """Alias for XML"""
        return self.XML

    @xml.setter
    def xml(self, value):
        """Alias for XML.setter"""
        self.XML = value

    @property
    def x_m_l(self):
        """Alias for XML"""
        return self.XML

    @x_m_l.setter
    def x_m_l(self, value):
        """Alias for XML.setter"""
        self.XML = value

    def Apply(self):
        self.com_object.Apply()

    def apply(self):
        """Alias for Apply"""
        return self.Apply()

    def Copy(self, Name=None, SaveOption=None):
        arguments = com_arguments([unwrap(a) for a in [Name, SaveOption]])
        return View(self.com_object.Copy(*arguments))

    def copy(self, Name=None, SaveOption=None):
        """Alias for Copy"""
        arguments = [Name, SaveOption]
        return self.Copy(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def GoToDate(self, Date=None):
        arguments = com_arguments([unwrap(a) for a in [Date]])
        self.com_object.GoToDate(*arguments)

    def gotodate(self, Date=None):
        """Alias for GoToDate"""
        arguments = [Date]
        return self.GoToDate(*arguments)

    def go_to_date(self, Date=None):
        """Alias for GoToDate"""
        arguments = [Date]
        return self.GoToDate(*arguments)

    def Reset(self):
        self.com_object.Reset()

    def reset(self):
        """Alias for Reset"""
        return self.Reset()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()


class Image:

    def __init__(self, image=None):
        self.com_object= image


class ImportanceRuleCondition:

    def __init__(self, importancerulecondition=None):
        self.com_object= importancerulecondition

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def ConditionType(self):
        return OlRuleConditionType(self.com_object.ConditionType)

    @property
    def conditiontype(self):
        """Alias for ConditionType"""
        return self.ConditionType

    @property
    def condition_type(self):
        """Alias for ConditionType"""
        return self.ConditionType

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Importance(self):
        return OlImportance(self.com_object.Importance)

    @Importance.setter
    def Importance(self, value):
        self.com_object.Importance = value

    @property
    def importance(self):
        """Alias for Importance"""
        return self.Importance

    @importance.setter
    def importance(self, value):
        """Alias for Importance.setter"""
        self.Importance = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session


class Inspector:

    def __init__(self, inspector=None):
        self.com_object= inspector

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AttachmentSelection(self):
        return AttachmentSelection(self.com_object.AttachmentSelection)

    @property
    def attachmentselection(self):
        """Alias for AttachmentSelection"""
        return self.AttachmentSelection

    @property
    def attachment_selection(self):
        """Alias for AttachmentSelection"""
        return self.AttachmentSelection

    @property
    def Caption(self):
        return self.com_object.Caption

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def CurrentItem(self):
        return self.com_object.CurrentItem

    @property
    def currentitem(self):
        """Alias for CurrentItem"""
        return self.CurrentItem

    @property
    def current_item(self):
        """Alias for CurrentItem"""
        return self.CurrentItem

    @property
    def EditorType(self):
        return OlEditorType(self.com_object.EditorType)

    @property
    def editortype(self):
        """Alias for EditorType"""
        return self.EditorType

    @property
    def editor_type(self):
        """Alias for EditorType"""
        return self.EditorType

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def ModifiedFormPages(self):
        return Pages(self.com_object.ModifiedFormPages)

    @property
    def modifiedformpages(self):
        """Alias for ModifiedFormPages"""
        return self.ModifiedFormPages

    @property
    def modified_form_pages(self):
        """Alias for ModifiedFormPages"""
        return self.ModifiedFormPages

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def WindowState(self):
        return OlWindowState(self.com_object.WindowState)

    @WindowState.setter
    def WindowState(self, value):
        self.com_object.WindowState = value

    @property
    def windowstate(self):
        """Alias for WindowState"""
        return self.WindowState

    @windowstate.setter
    def windowstate(self, value):
        """Alias for WindowState.setter"""
        self.WindowState = value

    @property
    def window_state(self):
        """Alias for WindowState"""
        return self.WindowState

    @window_state.setter
    def window_state(self, value):
        """Alias for WindowState.setter"""
        self.WindowState = value

    @property
    def WordEditor(self):
        return self.com_object.WordEditor

    @property
    def wordeditor(self):
        """Alias for WordEditor"""
        return self.WordEditor

    @property
    def word_editor(self):
        """Alias for WordEditor"""
        return self.WordEditor

    def Activate(self):
        self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()

    def Close(self, SaveMode=None):
        arguments = com_arguments([unwrap(a) for a in [SaveMode]])
        self.com_object.Close(*arguments)

    def close(self, SaveMode=None):
        """Alias for Close"""
        arguments = [SaveMode]
        return self.Close(*arguments)

    def Display(self, Modal=None):
        arguments = com_arguments([unwrap(a) for a in [Modal]])
        self.com_object.Display(*arguments)

    def display(self, Modal=None):
        """Alias for Display"""
        arguments = [Modal]
        return self.Display(*arguments)

    def HideFormPage(self, PageName=None):
        arguments = com_arguments([unwrap(a) for a in [PageName]])
        self.com_object.HideFormPage(*arguments)

    def hideformpage(self, PageName=None):
        """Alias for HideFormPage"""
        arguments = [PageName]
        return self.HideFormPage(*arguments)

    def hide_form_page(self, PageName=None):
        """Alias for HideFormPage"""
        arguments = [PageName]
        return self.HideFormPage(*arguments)

    def IsWordMail(self):
        return self.com_object.IsWordMail()

    def iswordmail(self):
        """Alias for IsWordMail"""
        return self.IsWordMail()

    def is_word_mail(self):
        """Alias for IsWordMail"""
        return self.IsWordMail()

    def NewFormRegion(self):
        return self.com_object.NewFormRegion()

    def newformregion(self):
        """Alias for NewFormRegion"""
        return self.NewFormRegion()

    def new_form_region(self):
        """Alias for NewFormRegion"""
        return self.NewFormRegion()

    def OpenFormRegion(self, Path=None):
        arguments = com_arguments([unwrap(a) for a in [Path]])
        return self.com_object.OpenFormRegion(*arguments)

    def openformregion(self, Path=None):
        """Alias for OpenFormRegion"""
        arguments = [Path]
        return self.OpenFormRegion(*arguments)

    def open_form_region(self, Path=None):
        """Alias for OpenFormRegion"""
        arguments = [Path]
        return self.OpenFormRegion(*arguments)

    def SaveFormRegion(self, Page=None, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [Page, FileName]])
        self.com_object.SaveFormRegion(*arguments)

    def saveformregion(self, Page=None, FileName=None):
        """Alias for SaveFormRegion"""
        arguments = [Page, FileName]
        return self.SaveFormRegion(*arguments)

    def save_form_region(self, Page=None, FileName=None):
        """Alias for SaveFormRegion"""
        arguments = [Page, FileName]
        return self.SaveFormRegion(*arguments)

    def SetControlItemProperty(self, Control=None, PropertyName=None):
        arguments = com_arguments([unwrap(a) for a in [Control, PropertyName]])
        self.com_object.SetControlItemProperty(*arguments)

    def setcontrolitemproperty(self, Control=None, PropertyName=None):
        """Alias for SetControlItemProperty"""
        arguments = [Control, PropertyName]
        return self.SetControlItemProperty(*arguments)

    def set_control_item_property(self, Control=None, PropertyName=None):
        """Alias for SetControlItemProperty"""
        arguments = [Control, PropertyName]
        return self.SetControlItemProperty(*arguments)

    def SetCurrentFormPage(self, PageName=None):
        arguments = com_arguments([unwrap(a) for a in [PageName]])
        self.com_object.SetCurrentFormPage(*arguments)

    def setcurrentformpage(self, PageName=None):
        """Alias for SetCurrentFormPage"""
        arguments = [PageName]
        return self.SetCurrentFormPage(*arguments)

    def set_current_form_page(self, PageName=None):
        """Alias for SetCurrentFormPage"""
        arguments = [PageName]
        return self.SetCurrentFormPage(*arguments)

    def SetSchedulingStartTime(self, Start=None):
        arguments = com_arguments([unwrap(a) for a in [Start]])
        self.com_object.SetSchedulingStartTime(*arguments)

    def setschedulingstarttime(self, Start=None):
        """Alias for SetSchedulingStartTime"""
        arguments = [Start]
        return self.SetSchedulingStartTime(*arguments)

    def set_scheduling_start_time(self, Start=None):
        """Alias for SetSchedulingStartTime"""
        arguments = [Start]
        return self.SetSchedulingStartTime(*arguments)

    def ShowFormPage(self, PageName=None):
        arguments = com_arguments([unwrap(a) for a in [PageName]])
        self.com_object.ShowFormPage(*arguments)

    def showformpage(self, PageName=None):
        """Alias for ShowFormPage"""
        arguments = [PageName]
        return self.ShowFormPage(*arguments)

    def show_form_page(self, PageName=None):
        """Alias for ShowFormPage"""
        arguments = [PageName]
        return self.ShowFormPage(*arguments)


class Inspectors:

    def __init__(self, inspectors=None):
        self.com_object= inspectors

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Add(self):
        return Inspector(self.com_object.Add())

    def add(self):
        """Alias for Add"""
        return self.Add()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Inspector(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ItemProperties:

    def __init__(self, itemproperties=None):
        self.com_object= itemproperties

    def __call__(self, item):
        return ItemPropertie(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Add(self, Name=None, Type=None, AddToFolderFields=None, DisplayFormat=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Type, AddToFolderFields, DisplayFormat]])
        self.com_object.Add(*arguments)

    def add(self, Name=None, Type=None, AddToFolderFields=None, DisplayFormat=None):
        """Alias for Add"""
        arguments = [Name, Type, AddToFolderFields, DisplayFormat]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ItemProperty(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Remove(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Remove(*arguments)

    def remove(self, Index=None):
        """Alias for Remove"""
        arguments = [Index]
        return self.Remove(*arguments)


class ItemProperty:

    def __init__(self, itemproperty=None):
        self.com_object= itemproperty

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def IsUserProperty(self):
        return self.com_object.IsUserProperty

    @property
    def isuserproperty(self):
        """Alias for IsUserProperty"""
        return self.IsUserProperty

    @property
    def is_user_property(self):
        """Alias for IsUserProperty"""
        return self.IsUserProperty

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Type(self):
        return OlUserPropertyType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value


class Items:

    def __init__(self, items=None):
        self.com_object= items

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def IncludeRecurrences(self):
        return Items(self.com_object.IncludeRecurrences)

    @IncludeRecurrences.setter
    def IncludeRecurrences(self, value):
        self.com_object.IncludeRecurrences = value

    @property
    def includerecurrences(self):
        """Alias for IncludeRecurrences"""
        return self.IncludeRecurrences

    @includerecurrences.setter
    def includerecurrences(self, value):
        """Alias for IncludeRecurrences.setter"""
        self.IncludeRecurrences = value

    @property
    def include_recurrences(self):
        """Alias for IncludeRecurrences"""
        return self.IncludeRecurrences

    @include_recurrences.setter
    def include_recurrences(self, value):
        """Alias for IncludeRecurrences.setter"""
        self.IncludeRecurrences = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Add(self):
        return self.com_object.Add()

    def add(self):
        """Alias for Add"""
        return self.Add()

    def Find(self, Filter=None):
        arguments = com_arguments([unwrap(a) for a in [Filter]])
        return self.com_object.Find(*arguments)

    def find(self, Filter=None):
        """Alias for Find"""
        arguments = [Filter]
        return self.Find(*arguments)

    def FindNext(self):
        return self.com_object.FindNext()

    def findnext(self):
        """Alias for FindNext"""
        return self.FindNext()

    def find_next(self):
        """Alias for FindNext"""
        return self.FindNext()

    def GetFirst(self):
        return self.com_object.GetFirst()

    def getfirst(self):
        """Alias for GetFirst"""
        return self.GetFirst()

    def get_first(self):
        """Alias for GetFirst"""
        return self.GetFirst()

    def GetLast(self):
        return self.com_object.GetLast()

    def getlast(self):
        """Alias for GetLast"""
        return self.GetLast()

    def get_last(self):
        """Alias for GetLast"""
        return self.GetLast()

    def GetNext(self):
        return self.com_object.GetNext()

    def getnext(self):
        """Alias for GetNext"""
        return self.GetNext()

    def get_next(self):
        """Alias for GetNext"""
        return self.GetNext()

    def GetPrevious(self):
        return self.com_object.GetPrevious()

    def getprevious(self):
        """Alias for GetPrevious"""
        return self.GetPrevious()

    def get_previous(self):
        """Alias for GetPrevious"""
        return self.GetPrevious()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Remove(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Remove(*arguments)

    def remove(self, Index=None):
        """Alias for Remove"""
        arguments = [Index]
        return self.Remove(*arguments)

    def ResetColumns(self):
        self.com_object.ResetColumns()

    def resetcolumns(self):
        """Alias for ResetColumns"""
        return self.ResetColumns()

    def reset_columns(self):
        """Alias for ResetColumns"""
        return self.ResetColumns()

    def Restrict(self, Filter=None):
        arguments = com_arguments([unwrap(a) for a in [Filter]])
        return Items(self.com_object.Restrict(*arguments))

    def restrict(self, Filter=None):
        """Alias for Restrict"""
        arguments = [Filter]
        return self.Restrict(*arguments)

    def SetColumns(self, Columns=None):
        arguments = com_arguments([unwrap(a) for a in [Columns]])
        self.com_object.SetColumns(*arguments)

    def setcolumns(self, Columns=None):
        """Alias for SetColumns"""
        arguments = [Columns]
        return self.SetColumns(*arguments)

    def set_columns(self, Columns=None):
        """Alias for SetColumns"""
        arguments = [Columns]
        return self.SetColumns(*arguments)

    def Sort(self, Property=None, Descending=None):
        arguments = com_arguments([unwrap(a) for a in [Property, Descending]])
        self.com_object.Sort(*arguments)

    def sort(self, Property=None, Descending=None):
        """Alias for Sort"""
        arguments = [Property, Descending]
        return self.Sort(*arguments)


class JournalItem:

    def __init__(self, journalitem=None):
        self.com_object= journalitem

    @property
    def Actions(self):
        return Actions(self.com_object.Actions)

    @property
    def actions(self):
        """Alias for Actions"""
        return self.Actions

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Attachments(self):
        return Attachments(self.com_object.Attachments)

    @property
    def attachments(self):
        """Alias for Attachments"""
        return self.Attachments

    @property
    def AutoResolvedWinner(self):
        return self.com_object.AutoResolvedWinner

    @property
    def autoresolvedwinner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def auto_resolved_winner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def BillingInformation(self):
        return self.com_object.BillingInformation

    @BillingInformation.setter
    def BillingInformation(self, value):
        self.com_object.BillingInformation = value

    @property
    def billinginformation(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billinginformation.setter
    def billinginformation(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def billing_information(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billing_information.setter
    def billing_information(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def Body(self):
        return self.com_object.Body

    @Body.setter
    def Body(self, value):
        self.com_object.Body = value

    @property
    def body(self):
        """Alias for Body"""
        return self.Body

    @body.setter
    def body(self, value):
        """Alias for Body.setter"""
        self.Body = value

    @property
    def Categories(self):
        return self.com_object.Categories

    @Categories.setter
    def Categories(self, value):
        self.com_object.Categories = value

    @property
    def categories(self):
        """Alias for Categories"""
        return self.Categories

    @categories.setter
    def categories(self, value):
        """Alias for Categories.setter"""
        self.Categories = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Companies(self):
        return self.com_object.Companies

    @Companies.setter
    def Companies(self, value):
        self.com_object.Companies = value

    @property
    def companies(self):
        """Alias for Companies"""
        return self.Companies

    @companies.setter
    def companies(self, value):
        """Alias for Companies.setter"""
        self.Companies = value

    @property
    def Conflicts(self):
        return Conflicts(self.com_object.Conflicts)

    @property
    def conflicts(self):
        """Alias for Conflicts"""
        return self.Conflicts

    @property
    def ContactNames(self):
        return self.com_object.ContactNames

    @ContactNames.setter
    def ContactNames(self, value):
        self.com_object.ContactNames = value

    @property
    def contactnames(self):
        """Alias for ContactNames"""
        return self.ContactNames

    @contactnames.setter
    def contactnames(self, value):
        """Alias for ContactNames.setter"""
        self.ContactNames = value

    @property
    def contact_names(self):
        """Alias for ContactNames"""
        return self.ContactNames

    @contact_names.setter
    def contact_names(self, value):
        """Alias for ContactNames.setter"""
        self.ContactNames = value

    @property
    def ConversationID(self):
        return Conversation(self.com_object.ConversationID)

    @property
    def conversationid(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def conversation_i_d(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def ConversationIndex(self):
        return self.com_object.ConversationIndex

    @property
    def conversationindex(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def conversation_index(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def ConversationTopic(self):
        return self.com_object.ConversationTopic

    @property
    def conversationtopic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def conversation_topic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def CreationTime(self):
        return self.com_object.CreationTime

    @property
    def creationtime(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def creation_time(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def DocPosted(self):
        return self.com_object.DocPosted

    @DocPosted.setter
    def DocPosted(self, value):
        self.com_object.DocPosted = value

    @property
    def docposted(self):
        """Alias for DocPosted"""
        return self.DocPosted

    @docposted.setter
    def docposted(self, value):
        """Alias for DocPosted.setter"""
        self.DocPosted = value

    @property
    def doc_posted(self):
        """Alias for DocPosted"""
        return self.DocPosted

    @doc_posted.setter
    def doc_posted(self, value):
        """Alias for DocPosted.setter"""
        self.DocPosted = value

    @property
    def DocPrinted(self):
        return self.com_object.DocPrinted

    @DocPrinted.setter
    def DocPrinted(self, value):
        self.com_object.DocPrinted = value

    @property
    def docprinted(self):
        """Alias for DocPrinted"""
        return self.DocPrinted

    @docprinted.setter
    def docprinted(self, value):
        """Alias for DocPrinted.setter"""
        self.DocPrinted = value

    @property
    def doc_printed(self):
        """Alias for DocPrinted"""
        return self.DocPrinted

    @doc_printed.setter
    def doc_printed(self, value):
        """Alias for DocPrinted.setter"""
        self.DocPrinted = value

    @property
    def DocRouted(self):
        return self.com_object.DocRouted

    @DocRouted.setter
    def DocRouted(self, value):
        self.com_object.DocRouted = value

    @property
    def docrouted(self):
        """Alias for DocRouted"""
        return self.DocRouted

    @docrouted.setter
    def docrouted(self, value):
        """Alias for DocRouted.setter"""
        self.DocRouted = value

    @property
    def doc_routed(self):
        """Alias for DocRouted"""
        return self.DocRouted

    @doc_routed.setter
    def doc_routed(self, value):
        """Alias for DocRouted.setter"""
        self.DocRouted = value

    @property
    def DocSaved(self):
        return self.com_object.DocSaved

    @DocSaved.setter
    def DocSaved(self, value):
        self.com_object.DocSaved = value

    @property
    def docsaved(self):
        """Alias for DocSaved"""
        return self.DocSaved

    @docsaved.setter
    def docsaved(self, value):
        """Alias for DocSaved.setter"""
        self.DocSaved = value

    @property
    def doc_saved(self):
        """Alias for DocSaved"""
        return self.DocSaved

    @doc_saved.setter
    def doc_saved(self, value):
        """Alias for DocSaved.setter"""
        self.DocSaved = value

    @property
    def DownloadState(self):
        return OlDownloadState(self.com_object.DownloadState)

    @property
    def downloadstate(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def download_state(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def Duration(self):
        return JournalItem(self.com_object.Duration)

    @Duration.setter
    def Duration(self, value):
        self.com_object.Duration = value

    @property
    def duration(self):
        """Alias for Duration"""
        return self.Duration

    @duration.setter
    def duration(self, value):
        """Alias for Duration.setter"""
        self.Duration = value

    @property
    def End(self):
        return self.com_object.End

    @End.setter
    def End(self, value):
        self.com_object.End = value

    @property
    def end(self):
        """Alias for End"""
        return self.End

    @end.setter
    def end(self, value):
        """Alias for End.setter"""
        self.End = value

    @property
    def EntryID(self):
        return self.com_object.EntryID

    @property
    def entryid(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def entry_i_d(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def FormDescription(self):
        return FormDescription(self.com_object.FormDescription)

    @property
    def formdescription(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def form_description(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def GetInspector(self):
        return Inspector(self.com_object.GetInspector)

    @property
    def getinspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def get_inspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def Importance(self):
        return OlImportance(self.com_object.Importance)

    @Importance.setter
    def Importance(self, value):
        self.com_object.Importance = value

    @property
    def importance(self):
        """Alias for Importance"""
        return self.Importance

    @importance.setter
    def importance(self, value):
        """Alias for Importance.setter"""
        self.Importance = value

    @property
    def IsConflict(self):
        return self.com_object.IsConflict

    @property
    def isconflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def is_conflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def ItemProperties(self):
        return ItemProperties(self.com_object.ItemProperties)

    @property
    def itemproperties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def item_properties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def LastModificationTime(self):
        return self.com_object.LastModificationTime

    @property
    def lastmodificationtime(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def last_modification_time(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def MarkForDownload(self):
        return OlRemoteStatus(self.com_object.MarkForDownload)

    @MarkForDownload.setter
    def MarkForDownload(self, value):
        self.com_object.MarkForDownload = value

    @property
    def markfordownload(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @markfordownload.setter
    def markfordownload(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def mark_for_download(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @mark_for_download.setter
    def mark_for_download(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def MessageClass(self):
        return self.com_object.MessageClass

    @MessageClass.setter
    def MessageClass(self, value):
        self.com_object.MessageClass = value

    @property
    def messageclass(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @messageclass.setter
    def messageclass(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def message_class(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @message_class.setter
    def message_class(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def Mileage(self):
        return self.com_object.Mileage

    @Mileage.setter
    def Mileage(self, value):
        self.com_object.Mileage = value

    @property
    def mileage(self):
        """Alias for Mileage"""
        return self.Mileage

    @mileage.setter
    def mileage(self, value):
        """Alias for Mileage.setter"""
        self.Mileage = value

    @property
    def NoAging(self):
        return self.com_object.NoAging

    @NoAging.setter
    def NoAging(self, value):
        self.com_object.NoAging = value

    @property
    def noaging(self):
        """Alias for NoAging"""
        return self.NoAging

    @noaging.setter
    def noaging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def no_aging(self):
        """Alias for NoAging"""
        return self.NoAging

    @no_aging.setter
    def no_aging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def OutlookInternalVersion(self):
        return self.com_object.OutlookInternalVersion

    @property
    def outlookinternalversion(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def outlook_internal_version(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def OutlookVersion(self):
        return self.com_object.OutlookVersion

    @property
    def outlookversion(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def outlook_version(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def Recipients(self):
        return Recipients(self.com_object.Recipients)

    @property
    def recipients(self):
        """Alias for Recipients"""
        return self.Recipients

    @property
    def Saved(self):
        return self.com_object.Saved

    @property
    def saved(self):
        """Alias for Saved"""
        return self.Saved

    @property
    def Sensitivity(self):
        return OlSensitivity(self.com_object.Sensitivity)

    @Sensitivity.setter
    def Sensitivity(self, value):
        self.com_object.Sensitivity = value

    @property
    def sensitivity(self):
        """Alias for Sensitivity"""
        return self.Sensitivity

    @sensitivity.setter
    def sensitivity(self, value):
        """Alias for Sensitivity.setter"""
        self.Sensitivity = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Size(self):
        return self.com_object.Size

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @property
    def Start(self):
        return self.com_object.Start

    @Start.setter
    def Start(self, value):
        self.com_object.Start = value

    @property
    def start(self):
        """Alias for Start"""
        return self.Start

    @start.setter
    def start(self, value):
        """Alias for Start.setter"""
        self.Start = value

    @property
    def Subject(self):
        return self.com_object.Subject

    @Subject.setter
    def Subject(self, value):
        self.com_object.Subject = value

    @property
    def subject(self):
        """Alias for Subject"""
        return self.Subject

    @subject.setter
    def subject(self, value):
        """Alias for Subject.setter"""
        self.Subject = value

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    @property
    def UnRead(self):
        return self.com_object.UnRead

    @UnRead.setter
    def UnRead(self, value):
        self.com_object.UnRead = value

    @property
    def unread(self):
        """Alias for UnRead"""
        return self.UnRead

    @unread.setter
    def unread(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def un_read(self):
        """Alias for UnRead"""
        return self.UnRead

    @un_read.setter
    def un_read(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def UserProperties(self):
        return UserProperties(self.com_object.UserProperties)

    @property
    def userproperties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    @property
    def user_properties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    def Close(self, SaveMode=None):
        arguments = com_arguments([unwrap(a) for a in [SaveMode]])
        self.com_object.Close(*arguments)

    def close(self, SaveMode=None):
        """Alias for Close"""
        arguments = [SaveMode]
        return self.Close(*arguments)

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Display(self, Modal=None):
        arguments = com_arguments([unwrap(a) for a in [Modal]])
        self.com_object.Display(*arguments)

    def display(self, Modal=None):
        """Alias for Display"""
        arguments = [Modal]
        return self.Display(*arguments)

    def Forward(self):
        return MailItem(self.com_object.Forward())

    def forward(self):
        """Alias for Forward"""
        return self.Forward()

    def GetConversation(self):
        return Conversation(self.com_object.GetConversation())

    def getconversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def get_conversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def Move(self, DestFldr=None):
        arguments = com_arguments([unwrap(a) for a in [DestFldr]])
        return self.com_object.Move(*arguments)

    def move(self, DestFldr=None):
        """Alias for Move"""
        arguments = [DestFldr]
        return self.Move(*arguments)

    def PrintOut(self):
        self.com_object.PrintOut()

    def printout(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def print_out(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def Reply(self):
        return MailItem(self.com_object.Reply())

    def reply(self):
        """Alias for Reply"""
        return self.Reply()

    def ReplyAll(self):
        return MailItem(self.com_object.ReplyAll())

    def replyall(self):
        """Alias for ReplyAll"""
        return self.ReplyAll()

    def reply_all(self):
        """Alias for ReplyAll"""
        return self.ReplyAll()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()

    def SaveAs(self, Path=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Path, Type]])
        self.com_object.SaveAs(*arguments)

    def saveas(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def save_as(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def ShowCategoriesDialog(self):
        self.com_object.ShowCategoriesDialog()

    def showcategoriesdialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()

    def show_categories_dialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()

    def StartTimer(self):
        self.com_object.StartTimer()

    def starttimer(self):
        """Alias for StartTimer"""
        return self.StartTimer()

    def start_timer(self):
        """Alias for StartTimer"""
        return self.StartTimer()

    def StopTimer(self):
        self.com_object.StopTimer()

    def stoptimer(self):
        """Alias for StopTimer"""
        return self.StopTimer()

    def stop_timer(self):
        """Alias for StopTimer"""
        return self.StopTimer()


class JournalModule:

    def __init__(self, journalmodule=None):
        self.com_object= journalmodule

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Name(self):
        return JournalModule(self.com_object.Name)

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NavigationGroups(self):
        return NavigationGroups(self.com_object.NavigationGroups)

    @property
    def navigationgroups(self):
        """Alias for NavigationGroups"""
        return self.NavigationGroups

    @property
    def navigation_groups(self):
        """Alias for NavigationGroups"""
        return self.NavigationGroups

    @property
    def NavigationModuleType(self):
        return olNavigationModuleType(self.com_object.NavigationModuleType)

    @property
    def navigationmoduletype(self):
        """Alias for NavigationModuleType"""
        return self.NavigationModuleType

    @property
    def navigation_module_type(self):
        """Alias for NavigationModuleType"""
        return self.NavigationModuleType

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return JournalModule(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Visible(self):
        return JournalModule(self.com_object.Visible)

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value


class Label:

    def __init__(self, label=None):
        self.com_object= label


class ListBox:

    def __init__(self, listbox=None):
        self.com_object= listbox


class MailItem:

    def __init__(self, mailitem=None):
        self.com_object= mailitem

    @property
    def Actions(self):
        return Actions(self.com_object.Actions)

    @property
    def actions(self):
        """Alias for Actions"""
        return self.Actions

    @property
    def AlternateRecipientAllowed(self):
        return self.com_object.AlternateRecipientAllowed

    @AlternateRecipientAllowed.setter
    def AlternateRecipientAllowed(self, value):
        self.com_object.AlternateRecipientAllowed = value

    @property
    def alternaterecipientallowed(self):
        """Alias for AlternateRecipientAllowed"""
        return self.AlternateRecipientAllowed

    @alternaterecipientallowed.setter
    def alternaterecipientallowed(self, value):
        """Alias for AlternateRecipientAllowed.setter"""
        self.AlternateRecipientAllowed = value

    @property
    def alternate_recipient_allowed(self):
        """Alias for AlternateRecipientAllowed"""
        return self.AlternateRecipientAllowed

    @alternate_recipient_allowed.setter
    def alternate_recipient_allowed(self, value):
        """Alias for AlternateRecipientAllowed.setter"""
        self.AlternateRecipientAllowed = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Attachments(self):
        return Attachments(self.com_object.Attachments)

    @property
    def attachments(self):
        """Alias for Attachments"""
        return self.Attachments

    @property
    def AutoForwarded(self):
        return self.com_object.AutoForwarded

    @AutoForwarded.setter
    def AutoForwarded(self, value):
        self.com_object.AutoForwarded = value

    @property
    def autoforwarded(self):
        """Alias for AutoForwarded"""
        return self.AutoForwarded

    @autoforwarded.setter
    def autoforwarded(self, value):
        """Alias for AutoForwarded.setter"""
        self.AutoForwarded = value

    @property
    def auto_forwarded(self):
        """Alias for AutoForwarded"""
        return self.AutoForwarded

    @auto_forwarded.setter
    def auto_forwarded(self, value):
        """Alias for AutoForwarded.setter"""
        self.AutoForwarded = value

    @property
    def AutoResolvedWinner(self):
        return self.com_object.AutoResolvedWinner

    @property
    def autoresolvedwinner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def auto_resolved_winner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def BCC(self):
        return MailItem(self.com_object.BCC)

    @BCC.setter
    def BCC(self, value):
        self.com_object.BCC = value

    @property
    def bcc(self):
        """Alias for BCC"""
        return self.BCC

    @bcc.setter
    def bcc(self, value):
        """Alias for BCC.setter"""
        self.BCC = value

    @property
    def b_c_c(self):
        """Alias for BCC"""
        return self.BCC

    @b_c_c.setter
    def b_c_c(self, value):
        """Alias for BCC.setter"""
        self.BCC = value

    @property
    def BillingInformation(self):
        return self.com_object.BillingInformation

    @BillingInformation.setter
    def BillingInformation(self, value):
        self.com_object.BillingInformation = value

    @property
    def billinginformation(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billinginformation.setter
    def billinginformation(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def billing_information(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billing_information.setter
    def billing_information(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def Body(self):
        return self.com_object.Body

    @Body.setter
    def Body(self, value):
        self.com_object.Body = value

    @property
    def body(self):
        """Alias for Body"""
        return self.Body

    @body.setter
    def body(self, value):
        """Alias for Body.setter"""
        self.Body = value

    @property
    def BodyFormat(self):
        return OlBodyFormat(self.com_object.BodyFormat)

    @BodyFormat.setter
    def BodyFormat(self, value):
        self.com_object.BodyFormat = value

    @property
    def bodyformat(self):
        """Alias for BodyFormat"""
        return self.BodyFormat

    @bodyformat.setter
    def bodyformat(self, value):
        """Alias for BodyFormat.setter"""
        self.BodyFormat = value

    @property
    def body_format(self):
        """Alias for BodyFormat"""
        return self.BodyFormat

    @body_format.setter
    def body_format(self, value):
        """Alias for BodyFormat.setter"""
        self.BodyFormat = value

    @property
    def Categories(self):
        return self.com_object.Categories

    @Categories.setter
    def Categories(self, value):
        self.com_object.Categories = value

    @property
    def categories(self):
        """Alias for Categories"""
        return self.Categories

    @categories.setter
    def categories(self, value):
        """Alias for Categories.setter"""
        self.Categories = value

    @property
    def CC(self):
        return MailItem(self.com_object.CC)

    @CC.setter
    def CC(self, value):
        self.com_object.CC = value

    @property
    def cc(self):
        """Alias for CC"""
        return self.CC

    @cc.setter
    def cc(self, value):
        """Alias for CC.setter"""
        self.CC = value

    @property
    def c_c(self):
        """Alias for CC"""
        return self.CC

    @c_c.setter
    def c_c(self, value):
        """Alias for CC.setter"""
        self.CC = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Companies(self):
        return self.com_object.Companies

    @Companies.setter
    def Companies(self, value):
        self.com_object.Companies = value

    @property
    def companies(self):
        """Alias for Companies"""
        return self.Companies

    @companies.setter
    def companies(self, value):
        """Alias for Companies.setter"""
        self.Companies = value

    @property
    def Conflicts(self):
        return self.com_object.Conflicts

    @property
    def conflicts(self):
        """Alias for Conflicts"""
        return self.Conflicts

    @property
    def ConversationID(self):
        return Conversation(self.com_object.ConversationID)

    @property
    def conversationid(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def conversation_i_d(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def ConversationIndex(self):
        return self.com_object.ConversationIndex

    @property
    def conversationindex(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def conversation_index(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def ConversationTopic(self):
        return self.com_object.ConversationTopic

    @property
    def conversationtopic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def conversation_topic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def CreationTime(self):
        return self.com_object.CreationTime

    @property
    def creationtime(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def creation_time(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def DeferredDeliveryTime(self):
        return self.com_object.DeferredDeliveryTime

    @DeferredDeliveryTime.setter
    def DeferredDeliveryTime(self, value):
        self.com_object.DeferredDeliveryTime = value

    @property
    def deferreddeliverytime(self):
        """Alias for DeferredDeliveryTime"""
        return self.DeferredDeliveryTime

    @deferreddeliverytime.setter
    def deferreddeliverytime(self, value):
        """Alias for DeferredDeliveryTime.setter"""
        self.DeferredDeliveryTime = value

    @property
    def deferred_delivery_time(self):
        """Alias for DeferredDeliveryTime"""
        return self.DeferredDeliveryTime

    @deferred_delivery_time.setter
    def deferred_delivery_time(self, value):
        """Alias for DeferredDeliveryTime.setter"""
        self.DeferredDeliveryTime = value

    @property
    def DeleteAfterSubmit(self):
        return self.com_object.DeleteAfterSubmit

    @DeleteAfterSubmit.setter
    def DeleteAfterSubmit(self, value):
        self.com_object.DeleteAfterSubmit = value

    @property
    def deleteaftersubmit(self):
        """Alias for DeleteAfterSubmit"""
        return self.DeleteAfterSubmit

    @deleteaftersubmit.setter
    def deleteaftersubmit(self, value):
        """Alias for DeleteAfterSubmit.setter"""
        self.DeleteAfterSubmit = value

    @property
    def delete_after_submit(self):
        """Alias for DeleteAfterSubmit"""
        return self.DeleteAfterSubmit

    @delete_after_submit.setter
    def delete_after_submit(self, value):
        """Alias for DeleteAfterSubmit.setter"""
        self.DeleteAfterSubmit = value

    @property
    def DownloadState(self):
        return OlDownloadState(self.com_object.DownloadState)

    @property
    def downloadstate(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def download_state(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def EntryID(self):
        return self.com_object.EntryID

    @property
    def entryid(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def entry_i_d(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def ExpiryTime(self):
        return self.com_object.ExpiryTime

    @ExpiryTime.setter
    def ExpiryTime(self, value):
        self.com_object.ExpiryTime = value

    @property
    def expirytime(self):
        """Alias for ExpiryTime"""
        return self.ExpiryTime

    @expirytime.setter
    def expirytime(self, value):
        """Alias for ExpiryTime.setter"""
        self.ExpiryTime = value

    @property
    def expiry_time(self):
        """Alias for ExpiryTime"""
        return self.ExpiryTime

    @expiry_time.setter
    def expiry_time(self, value):
        """Alias for ExpiryTime.setter"""
        self.ExpiryTime = value

    @property
    def FlagRequest(self):
        return self.com_object.FlagRequest

    @FlagRequest.setter
    def FlagRequest(self, value):
        self.com_object.FlagRequest = value

    @property
    def flagrequest(self):
        """Alias for FlagRequest"""
        return self.FlagRequest

    @flagrequest.setter
    def flagrequest(self, value):
        """Alias for FlagRequest.setter"""
        self.FlagRequest = value

    @property
    def flag_request(self):
        """Alias for FlagRequest"""
        return self.FlagRequest

    @flag_request.setter
    def flag_request(self, value):
        """Alias for FlagRequest.setter"""
        self.FlagRequest = value

    @property
    def FormDescription(self):
        return FormDescription(self.com_object.FormDescription)

    @property
    def formdescription(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def form_description(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def GetInspector(self):
        return Inspector(self.com_object.GetInspector)

    @property
    def getinspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def get_inspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def HTMLBody(self):
        return self.com_object.HTMLBody

    @HTMLBody.setter
    def HTMLBody(self, value):
        self.com_object.HTMLBody = value

    @property
    def htmlbody(self):
        """Alias for HTMLBody"""
        return self.HTMLBody

    @htmlbody.setter
    def htmlbody(self, value):
        """Alias for HTMLBody.setter"""
        self.HTMLBody = value

    @property
    def h_t_m_l_body(self):
        """Alias for HTMLBody"""
        return self.HTMLBody

    @h_t_m_l_body.setter
    def h_t_m_l_body(self, value):
        """Alias for HTMLBody.setter"""
        self.HTMLBody = value

    @property
    def Importance(self):
        return OlImportance(self.com_object.Importance)

    @Importance.setter
    def Importance(self, value):
        self.com_object.Importance = value

    @property
    def importance(self):
        """Alias for Importance"""
        return self.Importance

    @importance.setter
    def importance(self, value):
        """Alias for Importance.setter"""
        self.Importance = value

    @property
    def InternetCodepage(self):
        return self.com_object.InternetCodepage

    @InternetCodepage.setter
    def InternetCodepage(self, value):
        self.com_object.InternetCodepage = value

    @property
    def internetcodepage(self):
        """Alias for InternetCodepage"""
        return self.InternetCodepage

    @internetcodepage.setter
    def internetcodepage(self, value):
        """Alias for InternetCodepage.setter"""
        self.InternetCodepage = value

    @property
    def internet_codepage(self):
        """Alias for InternetCodepage"""
        return self.InternetCodepage

    @internet_codepage.setter
    def internet_codepage(self, value):
        """Alias for InternetCodepage.setter"""
        self.InternetCodepage = value

    @property
    def IsConflict(self):
        return self.com_object.IsConflict

    @property
    def isconflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def is_conflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def IsMarkedAsTask(self):
        return MailItem(self.com_object.IsMarkedAsTask)

    @property
    def ismarkedastask(self):
        """Alias for IsMarkedAsTask"""
        return self.IsMarkedAsTask

    @property
    def is_marked_as_task(self):
        """Alias for IsMarkedAsTask"""
        return self.IsMarkedAsTask

    @property
    def ItemProperties(self):
        return ItemProperties(self.com_object.ItemProperties)

    @property
    def itemproperties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def item_properties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def LastModificationTime(self):
        return self.com_object.LastModificationTime

    @property
    def lastmodificationtime(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def last_modification_time(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def MarkForDownload(self):
        return OlRemoteStatus(self.com_object.MarkForDownload)

    @MarkForDownload.setter
    def MarkForDownload(self, value):
        self.com_object.MarkForDownload = value

    @property
    def markfordownload(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @markfordownload.setter
    def markfordownload(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def mark_for_download(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @mark_for_download.setter
    def mark_for_download(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def MessageClass(self):
        return self.com_object.MessageClass

    @MessageClass.setter
    def MessageClass(self, value):
        self.com_object.MessageClass = value

    @property
    def messageclass(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @messageclass.setter
    def messageclass(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def message_class(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @message_class.setter
    def message_class(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def Mileage(self):
        return self.com_object.Mileage

    @Mileage.setter
    def Mileage(self, value):
        self.com_object.Mileage = value

    @property
    def mileage(self):
        """Alias for Mileage"""
        return self.Mileage

    @mileage.setter
    def mileage(self, value):
        """Alias for Mileage.setter"""
        self.Mileage = value

    @property
    def NoAging(self):
        return self.com_object.NoAging

    @NoAging.setter
    def NoAging(self, value):
        self.com_object.NoAging = value

    @property
    def noaging(self):
        """Alias for NoAging"""
        return self.NoAging

    @noaging.setter
    def noaging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def no_aging(self):
        """Alias for NoAging"""
        return self.NoAging

    @no_aging.setter
    def no_aging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def OriginatorDeliveryReportRequested(self):
        return self.com_object.OriginatorDeliveryReportRequested

    @OriginatorDeliveryReportRequested.setter
    def OriginatorDeliveryReportRequested(self, value):
        self.com_object.OriginatorDeliveryReportRequested = value

    @property
    def originatordeliveryreportrequested(self):
        """Alias for OriginatorDeliveryReportRequested"""
        return self.OriginatorDeliveryReportRequested

    @originatordeliveryreportrequested.setter
    def originatordeliveryreportrequested(self, value):
        """Alias for OriginatorDeliveryReportRequested.setter"""
        self.OriginatorDeliveryReportRequested = value

    @property
    def originator_delivery_report_requested(self):
        """Alias for OriginatorDeliveryReportRequested"""
        return self.OriginatorDeliveryReportRequested

    @originator_delivery_report_requested.setter
    def originator_delivery_report_requested(self, value):
        """Alias for OriginatorDeliveryReportRequested.setter"""
        self.OriginatorDeliveryReportRequested = value

    @property
    def OutlookInternalVersion(self):
        return self.com_object.OutlookInternalVersion

    @property
    def outlookinternalversion(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def outlook_internal_version(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def OutlookVersion(self):
        return self.com_object.OutlookVersion

    @property
    def outlookversion(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def outlook_version(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Permission(self):
        return self.com_object.Permission

    @Permission.setter
    def Permission(self, value):
        self.com_object.Permission = value

    @property
    def permission(self):
        """Alias for Permission"""
        return self.Permission

    @permission.setter
    def permission(self, value):
        """Alias for Permission.setter"""
        self.Permission = value

    @property
    def PermissionService(self):
        return self.com_object.PermissionService

    @PermissionService.setter
    def PermissionService(self, value):
        self.com_object.PermissionService = value

    @property
    def permissionservice(self):
        """Alias for PermissionService"""
        return self.PermissionService

    @permissionservice.setter
    def permissionservice(self, value):
        """Alias for PermissionService.setter"""
        self.PermissionService = value

    @property
    def permission_service(self):
        """Alias for PermissionService"""
        return self.PermissionService

    @permission_service.setter
    def permission_service(self, value):
        """Alias for PermissionService.setter"""
        self.PermissionService = value

    @property
    def PermissionTemplateGuid(self):
        return MailItem(self.com_object.PermissionTemplateGuid)

    @PermissionTemplateGuid.setter
    def PermissionTemplateGuid(self, value):
        self.com_object.PermissionTemplateGuid = value

    @property
    def permissiontemplateguid(self):
        """Alias for PermissionTemplateGuid"""
        return self.PermissionTemplateGuid

    @permissiontemplateguid.setter
    def permissiontemplateguid(self, value):
        """Alias for PermissionTemplateGuid.setter"""
        self.PermissionTemplateGuid = value

    @property
    def permission_template_guid(self):
        """Alias for PermissionTemplateGuid"""
        return self.PermissionTemplateGuid

    @permission_template_guid.setter
    def permission_template_guid(self, value):
        """Alias for PermissionTemplateGuid.setter"""
        self.PermissionTemplateGuid = value

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def ReadReceiptRequested(self):
        return self.com_object.ReadReceiptRequested

    @property
    def readreceiptrequested(self):
        """Alias for ReadReceiptRequested"""
        return self.ReadReceiptRequested

    @property
    def read_receipt_requested(self):
        """Alias for ReadReceiptRequested"""
        return self.ReadReceiptRequested

    @property
    def ReceivedByEntryID(self):
        return self.com_object.ReceivedByEntryID

    @property
    def receivedbyentryid(self):
        """Alias for ReceivedByEntryID"""
        return self.ReceivedByEntryID

    @property
    def received_by_entry_i_d(self):
        """Alias for ReceivedByEntryID"""
        return self.ReceivedByEntryID

    @property
    def ReceivedByName(self):
        return self.com_object.ReceivedByName

    @property
    def receivedbyname(self):
        """Alias for ReceivedByName"""
        return self.ReceivedByName

    @property
    def received_by_name(self):
        """Alias for ReceivedByName"""
        return self.ReceivedByName

    @property
    def ReceivedOnBehalfOfEntryID(self):
        return self.com_object.ReceivedOnBehalfOfEntryID

    @property
    def receivedonbehalfofentryid(self):
        """Alias for ReceivedOnBehalfOfEntryID"""
        return self.ReceivedOnBehalfOfEntryID

    @property
    def received_on_behalf_of_entry_i_d(self):
        """Alias for ReceivedOnBehalfOfEntryID"""
        return self.ReceivedOnBehalfOfEntryID

    @property
    def ReceivedOnBehalfOfName(self):
        return self.com_object.ReceivedOnBehalfOfName

    @property
    def receivedonbehalfofname(self):
        """Alias for ReceivedOnBehalfOfName"""
        return self.ReceivedOnBehalfOfName

    @property
    def received_on_behalf_of_name(self):
        """Alias for ReceivedOnBehalfOfName"""
        return self.ReceivedOnBehalfOfName

    @property
    def ReceivedTime(self):
        return self.com_object.ReceivedTime

    @property
    def receivedtime(self):
        """Alias for ReceivedTime"""
        return self.ReceivedTime

    @property
    def received_time(self):
        """Alias for ReceivedTime"""
        return self.ReceivedTime

    @property
    def RecipientReassignmentProhibited(self):
        return self.com_object.RecipientReassignmentProhibited

    @RecipientReassignmentProhibited.setter
    def RecipientReassignmentProhibited(self, value):
        self.com_object.RecipientReassignmentProhibited = value

    @property
    def recipientreassignmentprohibited(self):
        """Alias for RecipientReassignmentProhibited"""
        return self.RecipientReassignmentProhibited

    @recipientreassignmentprohibited.setter
    def recipientreassignmentprohibited(self, value):
        """Alias for RecipientReassignmentProhibited.setter"""
        self.RecipientReassignmentProhibited = value

    @property
    def recipient_reassignment_prohibited(self):
        """Alias for RecipientReassignmentProhibited"""
        return self.RecipientReassignmentProhibited

    @recipient_reassignment_prohibited.setter
    def recipient_reassignment_prohibited(self, value):
        """Alias for RecipientReassignmentProhibited.setter"""
        self.RecipientReassignmentProhibited = value

    @property
    def Recipients(self):
        return Recipients(self.com_object.Recipients)

    @property
    def recipients(self):
        """Alias for Recipients"""
        return self.Recipients

    @property
    def ReminderOverrideDefault(self):
        return self.com_object.ReminderOverrideDefault

    @ReminderOverrideDefault.setter
    def ReminderOverrideDefault(self, value):
        self.com_object.ReminderOverrideDefault = value

    @property
    def reminderoverridedefault(self):
        """Alias for ReminderOverrideDefault"""
        return self.ReminderOverrideDefault

    @reminderoverridedefault.setter
    def reminderoverridedefault(self, value):
        """Alias for ReminderOverrideDefault.setter"""
        self.ReminderOverrideDefault = value

    @property
    def reminder_override_default(self):
        """Alias for ReminderOverrideDefault"""
        return self.ReminderOverrideDefault

    @reminder_override_default.setter
    def reminder_override_default(self, value):
        """Alias for ReminderOverrideDefault.setter"""
        self.ReminderOverrideDefault = value

    @property
    def ReminderPlaySound(self):
        return self.com_object.ReminderPlaySound

    @ReminderPlaySound.setter
    def ReminderPlaySound(self, value):
        self.com_object.ReminderPlaySound = value

    @property
    def reminderplaysound(self):
        """Alias for ReminderPlaySound"""
        return self.ReminderPlaySound

    @reminderplaysound.setter
    def reminderplaysound(self, value):
        """Alias for ReminderPlaySound.setter"""
        self.ReminderPlaySound = value

    @property
    def reminder_play_sound(self):
        """Alias for ReminderPlaySound"""
        return self.ReminderPlaySound

    @reminder_play_sound.setter
    def reminder_play_sound(self, value):
        """Alias for ReminderPlaySound.setter"""
        self.ReminderPlaySound = value

    @property
    def ReminderSet(self):
        return self.com_object.ReminderSet

    @ReminderSet.setter
    def ReminderSet(self, value):
        self.com_object.ReminderSet = value

    @property
    def reminderset(self):
        """Alias for ReminderSet"""
        return self.ReminderSet

    @reminderset.setter
    def reminderset(self, value):
        """Alias for ReminderSet.setter"""
        self.ReminderSet = value

    @property
    def reminder_set(self):
        """Alias for ReminderSet"""
        return self.ReminderSet

    @reminder_set.setter
    def reminder_set(self, value):
        """Alias for ReminderSet.setter"""
        self.ReminderSet = value

    @property
    def ReminderSoundFile(self):
        return self.com_object.ReminderSoundFile

    @ReminderSoundFile.setter
    def ReminderSoundFile(self, value):
        self.com_object.ReminderSoundFile = value

    @property
    def remindersoundfile(self):
        """Alias for ReminderSoundFile"""
        return self.ReminderSoundFile

    @remindersoundfile.setter
    def remindersoundfile(self, value):
        """Alias for ReminderSoundFile.setter"""
        self.ReminderSoundFile = value

    @property
    def reminder_sound_file(self):
        """Alias for ReminderSoundFile"""
        return self.ReminderSoundFile

    @reminder_sound_file.setter
    def reminder_sound_file(self, value):
        """Alias for ReminderSoundFile.setter"""
        self.ReminderSoundFile = value

    @property
    def ReminderTime(self):
        return self.com_object.ReminderTime

    @ReminderTime.setter
    def ReminderTime(self, value):
        self.com_object.ReminderTime = value

    @property
    def remindertime(self):
        """Alias for ReminderTime"""
        return self.ReminderTime

    @remindertime.setter
    def remindertime(self, value):
        """Alias for ReminderTime.setter"""
        self.ReminderTime = value

    @property
    def reminder_time(self):
        """Alias for ReminderTime"""
        return self.ReminderTime

    @reminder_time.setter
    def reminder_time(self, value):
        """Alias for ReminderTime.setter"""
        self.ReminderTime = value

    @property
    def RemoteStatus(self):
        return OlRemoteStatus(self.com_object.RemoteStatus)

    @RemoteStatus.setter
    def RemoteStatus(self, value):
        self.com_object.RemoteStatus = value

    @property
    def remotestatus(self):
        """Alias for RemoteStatus"""
        return self.RemoteStatus

    @remotestatus.setter
    def remotestatus(self, value):
        """Alias for RemoteStatus.setter"""
        self.RemoteStatus = value

    @property
    def remote_status(self):
        """Alias for RemoteStatus"""
        return self.RemoteStatus

    @remote_status.setter
    def remote_status(self, value):
        """Alias for RemoteStatus.setter"""
        self.RemoteStatus = value

    @property
    def ReplyRecipientNames(self):
        return self.com_object.ReplyRecipientNames

    @property
    def replyrecipientnames(self):
        """Alias for ReplyRecipientNames"""
        return self.ReplyRecipientNames

    @property
    def reply_recipient_names(self):
        """Alias for ReplyRecipientNames"""
        return self.ReplyRecipientNames

    @property
    def ReplyRecipients(self):
        return Recipients(self.com_object.ReplyRecipients)

    @property
    def replyrecipients(self):
        """Alias for ReplyRecipients"""
        return self.ReplyRecipients

    @property
    def reply_recipients(self):
        """Alias for ReplyRecipients"""
        return self.ReplyRecipients

    @property
    def RetentionExpirationDate(self):
        return MailItem(self.com_object.RetentionExpirationDate)

    @property
    def retentionexpirationdate(self):
        """Alias for RetentionExpirationDate"""
        return self.RetentionExpirationDate

    @property
    def retention_expiration_date(self):
        """Alias for RetentionExpirationDate"""
        return self.RetentionExpirationDate

    @property
    def RetentionPolicyName(self):
        return self.com_object.RetentionPolicyName

    @property
    def retentionpolicyname(self):
        """Alias for RetentionPolicyName"""
        return self.RetentionPolicyName

    @property
    def retention_policy_name(self):
        """Alias for RetentionPolicyName"""
        return self.RetentionPolicyName

    @property
    def RTFBody(self):
        return self.com_object.RTFBody

    @RTFBody.setter
    def RTFBody(self, value):
        self.com_object.RTFBody = value

    @property
    def rtfbody(self):
        """Alias for RTFBody"""
        return self.RTFBody

    @rtfbody.setter
    def rtfbody(self, value):
        """Alias for RTFBody.setter"""
        self.RTFBody = value

    @property
    def r_t_f_body(self):
        """Alias for RTFBody"""
        return self.RTFBody

    @r_t_f_body.setter
    def r_t_f_body(self, value):
        """Alias for RTFBody.setter"""
        self.RTFBody = value

    @property
    def Saved(self):
        return self.com_object.Saved

    @property
    def saved(self):
        """Alias for Saved"""
        return self.Saved

    @property
    def SaveSentMessageFolder(self):
        return Folder(self.com_object.SaveSentMessageFolder)

    @SaveSentMessageFolder.setter
    def SaveSentMessageFolder(self, value):
        self.com_object.SaveSentMessageFolder = value

    @property
    def savesentmessagefolder(self):
        """Alias for SaveSentMessageFolder"""
        return self.SaveSentMessageFolder

    @savesentmessagefolder.setter
    def savesentmessagefolder(self, value):
        """Alias for SaveSentMessageFolder.setter"""
        self.SaveSentMessageFolder = value

    @property
    def save_sent_message_folder(self):
        """Alias for SaveSentMessageFolder"""
        return self.SaveSentMessageFolder

    @save_sent_message_folder.setter
    def save_sent_message_folder(self, value):
        """Alias for SaveSentMessageFolder.setter"""
        self.SaveSentMessageFolder = value

    @property
    def Sender(self):
        return self.com_object.Sender

    @Sender.setter
    def Sender(self, value):
        self.com_object.Sender = value

    @property
    def sender(self):
        """Alias for Sender"""
        return self.Sender

    @sender.setter
    def sender(self, value):
        """Alias for Sender.setter"""
        self.Sender = value

    @property
    def SenderEmailAddress(self):
        return self.com_object.SenderEmailAddress

    @property
    def senderemailaddress(self):
        """Alias for SenderEmailAddress"""
        return self.SenderEmailAddress

    @property
    def sender_email_address(self):
        """Alias for SenderEmailAddress"""
        return self.SenderEmailAddress

    @property
    def SenderEmailType(self):
        return self.com_object.SenderEmailType

    @property
    def senderemailtype(self):
        """Alias for SenderEmailType"""
        return self.SenderEmailType

    @property
    def sender_email_type(self):
        """Alias for SenderEmailType"""
        return self.SenderEmailType

    @property
    def SenderName(self):
        return self.com_object.SenderName

    @property
    def sendername(self):
        """Alias for SenderName"""
        return self.SenderName

    @property
    def sender_name(self):
        """Alias for SenderName"""
        return self.SenderName

    @property
    def SendUsingAccount(self):
        return Account(self.com_object.SendUsingAccount)

    @SendUsingAccount.setter
    def SendUsingAccount(self, value):
        self.com_object.SendUsingAccount = value

    @property
    def sendusingaccount(self):
        """Alias for SendUsingAccount"""
        return self.SendUsingAccount

    @sendusingaccount.setter
    def sendusingaccount(self, value):
        """Alias for SendUsingAccount.setter"""
        self.SendUsingAccount = value

    @property
    def send_using_account(self):
        """Alias for SendUsingAccount"""
        return self.SendUsingAccount

    @send_using_account.setter
    def send_using_account(self, value):
        """Alias for SendUsingAccount.setter"""
        self.SendUsingAccount = value

    @property
    def Sensitivity(self):
        return OlSensitivity(self.com_object.Sensitivity)

    @Sensitivity.setter
    def Sensitivity(self, value):
        self.com_object.Sensitivity = value

    @property
    def sensitivity(self):
        """Alias for Sensitivity"""
        return self.Sensitivity

    @sensitivity.setter
    def sensitivity(self, value):
        """Alias for Sensitivity.setter"""
        self.Sensitivity = value

    @property
    def Sent(self):
        return self.com_object.Sent

    @property
    def sent(self):
        """Alias for Sent"""
        return self.Sent

    @property
    def SentOn(self):
        return self.com_object.SentOn

    @property
    def senton(self):
        """Alias for SentOn"""
        return self.SentOn

    @property
    def sent_on(self):
        """Alias for SentOn"""
        return self.SentOn

    @property
    def SentOnBehalfOfName(self):
        return self.com_object.SentOnBehalfOfName

    @SentOnBehalfOfName.setter
    def SentOnBehalfOfName(self, value):
        self.com_object.SentOnBehalfOfName = value

    @property
    def sentonbehalfofname(self):
        """Alias for SentOnBehalfOfName"""
        return self.SentOnBehalfOfName

    @sentonbehalfofname.setter
    def sentonbehalfofname(self, value):
        """Alias for SentOnBehalfOfName.setter"""
        self.SentOnBehalfOfName = value

    @property
    def sent_on_behalf_of_name(self):
        """Alias for SentOnBehalfOfName"""
        return self.SentOnBehalfOfName

    @sent_on_behalf_of_name.setter
    def sent_on_behalf_of_name(self, value):
        """Alias for SentOnBehalfOfName.setter"""
        self.SentOnBehalfOfName = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Size(self):
        return self.com_object.Size

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @property
    def Subject(self):
        return self.com_object.Subject

    @Subject.setter
    def Subject(self, value):
        self.com_object.Subject = value

    @property
    def subject(self):
        """Alias for Subject"""
        return self.Subject

    @subject.setter
    def subject(self, value):
        """Alias for Subject.setter"""
        self.Subject = value

    @property
    def Submitted(self):
        return self.com_object.Submitted

    @property
    def submitted(self):
        """Alias for Submitted"""
        return self.Submitted

    @property
    def TaskCompletedDate(self):
        return MailItem(self.com_object.TaskCompletedDate)

    @TaskCompletedDate.setter
    def TaskCompletedDate(self, value):
        self.com_object.TaskCompletedDate = value

    @property
    def taskcompleteddate(self):
        """Alias for TaskCompletedDate"""
        return self.TaskCompletedDate

    @taskcompleteddate.setter
    def taskcompleteddate(self, value):
        """Alias for TaskCompletedDate.setter"""
        self.TaskCompletedDate = value

    @property
    def task_completed_date(self):
        """Alias for TaskCompletedDate"""
        return self.TaskCompletedDate

    @task_completed_date.setter
    def task_completed_date(self, value):
        """Alias for TaskCompletedDate.setter"""
        self.TaskCompletedDate = value

    @property
    def TaskDueDate(self):
        return MailItem(self.com_object.TaskDueDate)

    @TaskDueDate.setter
    def TaskDueDate(self, value):
        self.com_object.TaskDueDate = value

    @property
    def taskduedate(self):
        """Alias for TaskDueDate"""
        return self.TaskDueDate

    @taskduedate.setter
    def taskduedate(self, value):
        """Alias for TaskDueDate.setter"""
        self.TaskDueDate = value

    @property
    def task_due_date(self):
        """Alias for TaskDueDate"""
        return self.TaskDueDate

    @task_due_date.setter
    def task_due_date(self, value):
        """Alias for TaskDueDate.setter"""
        self.TaskDueDate = value

    @property
    def TaskStartDate(self):
        return MailItem(self.com_object.TaskStartDate)

    @TaskStartDate.setter
    def TaskStartDate(self, value):
        self.com_object.TaskStartDate = value

    @property
    def taskstartdate(self):
        """Alias for TaskStartDate"""
        return self.TaskStartDate

    @taskstartdate.setter
    def taskstartdate(self, value):
        """Alias for TaskStartDate.setter"""
        self.TaskStartDate = value

    @property
    def task_start_date(self):
        """Alias for TaskStartDate"""
        return self.TaskStartDate

    @task_start_date.setter
    def task_start_date(self, value):
        """Alias for TaskStartDate.setter"""
        self.TaskStartDate = value

    @property
    def TaskSubject(self):
        return MailItem(self.com_object.TaskSubject)

    @TaskSubject.setter
    def TaskSubject(self, value):
        self.com_object.TaskSubject = value

    @property
    def tasksubject(self):
        """Alias for TaskSubject"""
        return self.TaskSubject

    @tasksubject.setter
    def tasksubject(self, value):
        """Alias for TaskSubject.setter"""
        self.TaskSubject = value

    @property
    def task_subject(self):
        """Alias for TaskSubject"""
        return self.TaskSubject

    @task_subject.setter
    def task_subject(self, value):
        """Alias for TaskSubject.setter"""
        self.TaskSubject = value

    @property
    def To(self):
        return self.com_object.To

    @To.setter
    def To(self, value):
        self.com_object.To = value

    @property
    def to(self):
        """Alias for To"""
        return self.To

    @to.setter
    def to(self, value):
        """Alias for To.setter"""
        self.To = value

    @property
    def ToDoTaskOrdinal(self):
        return MailItem(self.com_object.ToDoTaskOrdinal)

    @ToDoTaskOrdinal.setter
    def ToDoTaskOrdinal(self, value):
        self.com_object.ToDoTaskOrdinal = value

    @property
    def todotaskordinal(self):
        """Alias for ToDoTaskOrdinal"""
        return self.ToDoTaskOrdinal

    @todotaskordinal.setter
    def todotaskordinal(self, value):
        """Alias for ToDoTaskOrdinal.setter"""
        self.ToDoTaskOrdinal = value

    @property
    def to_do_task_ordinal(self):
        """Alias for ToDoTaskOrdinal"""
        return self.ToDoTaskOrdinal

    @to_do_task_ordinal.setter
    def to_do_task_ordinal(self, value):
        """Alias for ToDoTaskOrdinal.setter"""
        self.ToDoTaskOrdinal = value

    @property
    def UnRead(self):
        return self.com_object.UnRead

    @UnRead.setter
    def UnRead(self, value):
        self.com_object.UnRead = value

    @property
    def unread(self):
        """Alias for UnRead"""
        return self.UnRead

    @unread.setter
    def unread(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def un_read(self):
        """Alias for UnRead"""
        return self.UnRead

    @un_read.setter
    def un_read(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def UserProperties(self):
        return UserProperties(self.com_object.UserProperties)

    @property
    def userproperties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    @property
    def user_properties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    @property
    def VotingOptions(self):
        return self.com_object.VotingOptions

    @VotingOptions.setter
    def VotingOptions(self, value):
        self.com_object.VotingOptions = value

    @property
    def votingoptions(self):
        """Alias for VotingOptions"""
        return self.VotingOptions

    @votingoptions.setter
    def votingoptions(self, value):
        """Alias for VotingOptions.setter"""
        self.VotingOptions = value

    @property
    def voting_options(self):
        """Alias for VotingOptions"""
        return self.VotingOptions

    @voting_options.setter
    def voting_options(self, value):
        """Alias for VotingOptions.setter"""
        self.VotingOptions = value

    @property
    def VotingResponse(self):
        return self.com_object.VotingResponse

    @VotingResponse.setter
    def VotingResponse(self, value):
        self.com_object.VotingResponse = value

    @property
    def votingresponse(self):
        """Alias for VotingResponse"""
        return self.VotingResponse

    @votingresponse.setter
    def votingresponse(self, value):
        """Alias for VotingResponse.setter"""
        self.VotingResponse = value

    @property
    def voting_response(self):
        """Alias for VotingResponse"""
        return self.VotingResponse

    @voting_response.setter
    def voting_response(self, value):
        """Alias for VotingResponse.setter"""
        self.VotingResponse = value

    def AddBusinessCard(self, contact=None):
        arguments = com_arguments([unwrap(a) for a in [contact]])
        self.com_object.AddBusinessCard(*arguments)

    def addbusinesscard(self, contact=None):
        """Alias for AddBusinessCard"""
        arguments = [contact]
        return self.AddBusinessCard(*arguments)

    def add_business_card(self, contact=None):
        """Alias for AddBusinessCard"""
        arguments = [contact]
        return self.AddBusinessCard(*arguments)

    def ClearConversationIndex(self):
        self.com_object.ClearConversationIndex()

    def clearconversationindex(self):
        """Alias for ClearConversationIndex"""
        return self.ClearConversationIndex()

    def clear_conversation_index(self):
        """Alias for ClearConversationIndex"""
        return self.ClearConversationIndex()

    def ClearTaskFlag(self):
        self.com_object.ClearTaskFlag()

    def cleartaskflag(self):
        """Alias for ClearTaskFlag"""
        return self.ClearTaskFlag()

    def clear_task_flag(self):
        """Alias for ClearTaskFlag"""
        return self.ClearTaskFlag()

    def Close(self, SaveMode=None):
        arguments = com_arguments([unwrap(a) for a in [SaveMode]])
        self.com_object.Close(*arguments)

    def close(self, SaveMode=None):
        """Alias for Close"""
        arguments = [SaveMode]
        return self.Close(*arguments)

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Display(self, Modal=None):
        arguments = com_arguments([unwrap(a) for a in [Modal]])
        self.com_object.Display(*arguments)

    def display(self, Modal=None):
        """Alias for Display"""
        arguments = [Modal]
        return self.Display(*arguments)

    def Forward(self):
        return MailItem(self.com_object.Forward())

    def forward(self):
        """Alias for Forward"""
        return self.Forward()

    def GetConversation(self):
        return Conversation(self.com_object.GetConversation())

    def getconversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def get_conversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def MarkAsTask(self, MarkInterval=None):
        arguments = com_arguments([unwrap(a) for a in [MarkInterval]])
        self.com_object.MarkAsTask(*arguments)

    def markastask(self, MarkInterval=None):
        """Alias for MarkAsTask"""
        arguments = [MarkInterval]
        return self.MarkAsTask(*arguments)

    def mark_as_task(self, MarkInterval=None):
        """Alias for MarkAsTask"""
        arguments = [MarkInterval]
        return self.MarkAsTask(*arguments)

    def Move(self, DestFldr=None):
        arguments = com_arguments([unwrap(a) for a in [DestFldr]])
        return self.com_object.Move(*arguments)

    def move(self, DestFldr=None):
        """Alias for Move"""
        arguments = [DestFldr]
        return self.Move(*arguments)

    def PrintOut(self):
        self.com_object.PrintOut()

    def printout(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def print_out(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def Reply(self):
        return MailItem(self.com_object.Reply())

    def reply(self):
        """Alias for Reply"""
        return self.Reply()

    def ReplyAll(self):
        return MailItem(self.com_object.ReplyAll())

    def replyall(self):
        """Alias for ReplyAll"""
        return self.ReplyAll()

    def reply_all(self):
        """Alias for ReplyAll"""
        return self.ReplyAll()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()

    def SaveAs(self, Path=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Path, Type]])
        self.com_object.SaveAs(*arguments)

    def saveas(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def save_as(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def Send(self):
        self.com_object.Send()

    def send(self):
        """Alias for Send"""
        return self.Send()

    def ShowCategoriesDialog(self):
        self.com_object.ShowCategoriesDialog()

    def showcategoriesdialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()

    def show_categories_dialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()


class MailModule:

    def __init__(self, mailmodule=None):
        self.com_object= mailmodule

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Name(self):
        return MailModule(self.com_object.Name)

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NavigationGroups(self):
        return NavigationGroups(self.com_object.NavigationGroups)

    @property
    def navigationgroups(self):
        """Alias for NavigationGroups"""
        return self.NavigationGroups

    @property
    def navigation_groups(self):
        """Alias for NavigationGroups"""
        return self.NavigationGroups

    @property
    def NavigationModuleType(self):
        return olNavigationModuleType(self.com_object.NavigationModuleType)

    @property
    def navigationmoduletype(self):
        """Alias for NavigationModuleType"""
        return self.NavigationModuleType

    @property
    def navigation_module_type(self):
        """Alias for NavigationModuleType"""
        return self.NavigationModuleType

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return MailModule(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Visible(self):
        return MailModule(self.com_object.Visible)

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value


class MarkAsTaskRuleAction:

    def __init__(self, markastaskruleaction=None):
        self.com_object= markastaskruleaction

    @property
    def ActionType(self):
        return OlRuleActionType(self.com_object.ActionType)

    @property
    def actiontype(self):
        """Alias for ActionType"""
        return self.ActionType

    @property
    def action_type(self):
        """Alias for ActionType"""
        return self.ActionType

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def FlagTo(self):
        return self.com_object.FlagTo

    @FlagTo.setter
    def FlagTo(self, value):
        self.com_object.FlagTo = value

    @property
    def flagto(self):
        """Alias for FlagTo"""
        return self.FlagTo

    @flagto.setter
    def flagto(self, value):
        """Alias for FlagTo.setter"""
        self.FlagTo = value

    @property
    def flag_to(self):
        """Alias for FlagTo"""
        return self.FlagTo

    @flag_to.setter
    def flag_to(self, value):
        """Alias for FlagTo.setter"""
        self.FlagTo = value

    @property
    def MarkInterval(self):
        return OlMarkInterval(self.com_object.MarkInterval)

    @MarkInterval.setter
    def MarkInterval(self, value):
        self.com_object.MarkInterval = value

    @property
    def markinterval(self):
        """Alias for MarkInterval"""
        return self.MarkInterval

    @markinterval.setter
    def markinterval(self, value):
        """Alias for MarkInterval.setter"""
        self.MarkInterval = value

    @property
    def mark_interval(self):
        """Alias for MarkInterval"""
        return self.MarkInterval

    @mark_interval.setter
    def mark_interval(self, value):
        """Alias for MarkInterval.setter"""
        self.MarkInterval = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session


class MeetingItem:

    def __init__(self, meetingitem=None):
        self.com_object= meetingitem

    @property
    def Actions(self):
        return Actions(self.com_object.Actions)

    @property
    def actions(self):
        """Alias for Actions"""
        return self.Actions

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Attachments(self):
        return Attachments(self.com_object.Attachments)

    @property
    def attachments(self):
        """Alias for Attachments"""
        return self.Attachments

    @property
    def AutoForwarded(self):
        return self.com_object.AutoForwarded

    @AutoForwarded.setter
    def AutoForwarded(self, value):
        self.com_object.AutoForwarded = value

    @property
    def autoforwarded(self):
        """Alias for AutoForwarded"""
        return self.AutoForwarded

    @autoforwarded.setter
    def autoforwarded(self, value):
        """Alias for AutoForwarded.setter"""
        self.AutoForwarded = value

    @property
    def auto_forwarded(self):
        """Alias for AutoForwarded"""
        return self.AutoForwarded

    @auto_forwarded.setter
    def auto_forwarded(self, value):
        """Alias for AutoForwarded.setter"""
        self.AutoForwarded = value

    @property
    def AutoResolvedWinner(self):
        return self.com_object.AutoResolvedWinner

    @property
    def autoresolvedwinner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def auto_resolved_winner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def BillingInformation(self):
        return self.com_object.BillingInformation

    @BillingInformation.setter
    def BillingInformation(self, value):
        self.com_object.BillingInformation = value

    @property
    def billinginformation(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billinginformation.setter
    def billinginformation(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def billing_information(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billing_information.setter
    def billing_information(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def Body(self):
        return self.com_object.Body

    @Body.setter
    def Body(self, value):
        self.com_object.Body = value

    @property
    def body(self):
        """Alias for Body"""
        return self.Body

    @body.setter
    def body(self, value):
        """Alias for Body.setter"""
        self.Body = value

    @property
    def Categories(self):
        return self.com_object.Categories

    @Categories.setter
    def Categories(self, value):
        self.com_object.Categories = value

    @property
    def categories(self):
        """Alias for Categories"""
        return self.Categories

    @categories.setter
    def categories(self, value):
        """Alias for Categories.setter"""
        self.Categories = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Companies(self):
        return self.com_object.Companies

    @Companies.setter
    def Companies(self, value):
        self.com_object.Companies = value

    @property
    def companies(self):
        """Alias for Companies"""
        return self.Companies

    @companies.setter
    def companies(self, value):
        """Alias for Companies.setter"""
        self.Companies = value

    @property
    def Conflicts(self):
        return self.com_object.Conflicts

    @property
    def conflicts(self):
        """Alias for Conflicts"""
        return self.Conflicts

    @property
    def ConversationID(self):
        return Conversation(self.com_object.ConversationID)

    @property
    def conversationid(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def conversation_i_d(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def ConversationIndex(self):
        return self.com_object.ConversationIndex

    @property
    def conversationindex(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def conversation_index(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def ConversationTopic(self):
        return self.com_object.ConversationTopic

    @property
    def conversationtopic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def conversation_topic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def CreationTime(self):
        return self.com_object.CreationTime

    @property
    def creationtime(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def creation_time(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def DeferredDeliveryTime(self):
        return self.com_object.DeferredDeliveryTime

    @DeferredDeliveryTime.setter
    def DeferredDeliveryTime(self, value):
        self.com_object.DeferredDeliveryTime = value

    @property
    def deferreddeliverytime(self):
        """Alias for DeferredDeliveryTime"""
        return self.DeferredDeliveryTime

    @deferreddeliverytime.setter
    def deferreddeliverytime(self, value):
        """Alias for DeferredDeliveryTime.setter"""
        self.DeferredDeliveryTime = value

    @property
    def deferred_delivery_time(self):
        """Alias for DeferredDeliveryTime"""
        return self.DeferredDeliveryTime

    @deferred_delivery_time.setter
    def deferred_delivery_time(self, value):
        """Alias for DeferredDeliveryTime.setter"""
        self.DeferredDeliveryTime = value

    @property
    def DeleteAfterSubmit(self):
        return self.com_object.DeleteAfterSubmit

    @DeleteAfterSubmit.setter
    def DeleteAfterSubmit(self, value):
        self.com_object.DeleteAfterSubmit = value

    @property
    def deleteaftersubmit(self):
        """Alias for DeleteAfterSubmit"""
        return self.DeleteAfterSubmit

    @deleteaftersubmit.setter
    def deleteaftersubmit(self, value):
        """Alias for DeleteAfterSubmit.setter"""
        self.DeleteAfterSubmit = value

    @property
    def delete_after_submit(self):
        """Alias for DeleteAfterSubmit"""
        return self.DeleteAfterSubmit

    @delete_after_submit.setter
    def delete_after_submit(self, value):
        """Alias for DeleteAfterSubmit.setter"""
        self.DeleteAfterSubmit = value

    @property
    def DownloadState(self):
        return OlDownloadState(self.com_object.DownloadState)

    @property
    def downloadstate(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def download_state(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def EntryID(self):
        return self.com_object.EntryID

    @property
    def entryid(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def entry_i_d(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def ExpiryTime(self):
        return self.com_object.ExpiryTime

    @ExpiryTime.setter
    def ExpiryTime(self, value):
        self.com_object.ExpiryTime = value

    @property
    def expirytime(self):
        """Alias for ExpiryTime"""
        return self.ExpiryTime

    @expirytime.setter
    def expirytime(self, value):
        """Alias for ExpiryTime.setter"""
        self.ExpiryTime = value

    @property
    def expiry_time(self):
        """Alias for ExpiryTime"""
        return self.ExpiryTime

    @expiry_time.setter
    def expiry_time(self, value):
        """Alias for ExpiryTime.setter"""
        self.ExpiryTime = value

    @property
    def FormDescription(self):
        return FormDescription(self.com_object.FormDescription)

    @property
    def formdescription(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def form_description(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def GetInspector(self):
        return Inspector(self.com_object.GetInspector)

    @property
    def getinspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def get_inspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def Importance(self):
        return OlImportance(self.com_object.Importance)

    @Importance.setter
    def Importance(self, value):
        self.com_object.Importance = value

    @property
    def importance(self):
        """Alias for Importance"""
        return self.Importance

    @importance.setter
    def importance(self, value):
        """Alias for Importance.setter"""
        self.Importance = value

    @property
    def IsConflict(self):
        return self.com_object.IsConflict

    @property
    def isconflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def is_conflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def IsLatestVersion(self):
        return MeetingItem(self.com_object.IsLatestVersion)

    @property
    def islatestversion(self):
        """Alias for IsLatestVersion"""
        return self.IsLatestVersion

    @property
    def is_latest_version(self):
        """Alias for IsLatestVersion"""
        return self.IsLatestVersion

    @property
    def ItemProperties(self):
        return ItemProperties(self.com_object.ItemProperties)

    @property
    def itemproperties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def item_properties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def LastModificationTime(self):
        return self.com_object.LastModificationTime

    @property
    def lastmodificationtime(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def last_modification_time(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def MarkForDownload(self):
        return OlRemoteStatus(self.com_object.MarkForDownload)

    @MarkForDownload.setter
    def MarkForDownload(self, value):
        self.com_object.MarkForDownload = value

    @property
    def markfordownload(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @markfordownload.setter
    def markfordownload(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def mark_for_download(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @mark_for_download.setter
    def mark_for_download(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def MeetingWorkspaceURL(self):
        return self.com_object.MeetingWorkspaceURL

    @property
    def meetingworkspaceurl(self):
        """Alias for MeetingWorkspaceURL"""
        return self.MeetingWorkspaceURL

    @property
    def meeting_workspace_u_r_l(self):
        """Alias for MeetingWorkspaceURL"""
        return self.MeetingWorkspaceURL

    @property
    def MessageClass(self):
        return self.com_object.MessageClass

    @MessageClass.setter
    def MessageClass(self, value):
        self.com_object.MessageClass = value

    @property
    def messageclass(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @messageclass.setter
    def messageclass(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def message_class(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @message_class.setter
    def message_class(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def Mileage(self):
        return self.com_object.Mileage

    @Mileage.setter
    def Mileage(self, value):
        self.com_object.Mileage = value

    @property
    def mileage(self):
        """Alias for Mileage"""
        return self.Mileage

    @mileage.setter
    def mileage(self, value):
        """Alias for Mileage.setter"""
        self.Mileage = value

    @property
    def NoAging(self):
        return self.com_object.NoAging

    @NoAging.setter
    def NoAging(self, value):
        self.com_object.NoAging = value

    @property
    def noaging(self):
        """Alias for NoAging"""
        return self.NoAging

    @noaging.setter
    def noaging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def no_aging(self):
        """Alias for NoAging"""
        return self.NoAging

    @no_aging.setter
    def no_aging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def OriginatorDeliveryReportRequested(self):
        return self.com_object.OriginatorDeliveryReportRequested

    @OriginatorDeliveryReportRequested.setter
    def OriginatorDeliveryReportRequested(self, value):
        self.com_object.OriginatorDeliveryReportRequested = value

    @property
    def originatordeliveryreportrequested(self):
        """Alias for OriginatorDeliveryReportRequested"""
        return self.OriginatorDeliveryReportRequested

    @originatordeliveryreportrequested.setter
    def originatordeliveryreportrequested(self, value):
        """Alias for OriginatorDeliveryReportRequested.setter"""
        self.OriginatorDeliveryReportRequested = value

    @property
    def originator_delivery_report_requested(self):
        """Alias for OriginatorDeliveryReportRequested"""
        return self.OriginatorDeliveryReportRequested

    @originator_delivery_report_requested.setter
    def originator_delivery_report_requested(self, value):
        """Alias for OriginatorDeliveryReportRequested.setter"""
        self.OriginatorDeliveryReportRequested = value

    @property
    def OutlookInternalVersion(self):
        return self.com_object.OutlookInternalVersion

    @property
    def outlookinternalversion(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def outlook_internal_version(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def OutlookVersion(self):
        return self.com_object.OutlookVersion

    @property
    def outlookversion(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def outlook_version(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def ReceivedTime(self):
        return self.com_object.ReceivedTime

    @ReceivedTime.setter
    def ReceivedTime(self, value):
        self.com_object.ReceivedTime = value

    @property
    def receivedtime(self):
        """Alias for ReceivedTime"""
        return self.ReceivedTime

    @receivedtime.setter
    def receivedtime(self, value):
        """Alias for ReceivedTime.setter"""
        self.ReceivedTime = value

    @property
    def received_time(self):
        """Alias for ReceivedTime"""
        return self.ReceivedTime

    @received_time.setter
    def received_time(self, value):
        """Alias for ReceivedTime.setter"""
        self.ReceivedTime = value

    @property
    def Recipients(self):
        return Recipients(self.com_object.Recipients)

    @property
    def recipients(self):
        """Alias for Recipients"""
        return self.Recipients

    @property
    def ReminderSet(self):
        return self.com_object.ReminderSet

    @ReminderSet.setter
    def ReminderSet(self, value):
        self.com_object.ReminderSet = value

    @property
    def reminderset(self):
        """Alias for ReminderSet"""
        return self.ReminderSet

    @reminderset.setter
    def reminderset(self, value):
        """Alias for ReminderSet.setter"""
        self.ReminderSet = value

    @property
    def reminder_set(self):
        """Alias for ReminderSet"""
        return self.ReminderSet

    @reminder_set.setter
    def reminder_set(self, value):
        """Alias for ReminderSet.setter"""
        self.ReminderSet = value

    @property
    def ReminderTime(self):
        return self.com_object.ReminderTime

    @ReminderTime.setter
    def ReminderTime(self, value):
        self.com_object.ReminderTime = value

    @property
    def remindertime(self):
        """Alias for ReminderTime"""
        return self.ReminderTime

    @remindertime.setter
    def remindertime(self, value):
        """Alias for ReminderTime.setter"""
        self.ReminderTime = value

    @property
    def reminder_time(self):
        """Alias for ReminderTime"""
        return self.ReminderTime

    @reminder_time.setter
    def reminder_time(self, value):
        """Alias for ReminderTime.setter"""
        self.ReminderTime = value

    @property
    def ReplyRecipients(self):
        return Recipients(self.com_object.ReplyRecipients)

    @property
    def replyrecipients(self):
        """Alias for ReplyRecipients"""
        return self.ReplyRecipients

    @property
    def reply_recipients(self):
        """Alias for ReplyRecipients"""
        return self.ReplyRecipients

    @property
    def RetentionExpirationDate(self):
        return MeetingItem(self.com_object.RetentionExpirationDate)

    @property
    def retentionexpirationdate(self):
        """Alias for RetentionExpirationDate"""
        return self.RetentionExpirationDate

    @property
    def retention_expiration_date(self):
        """Alias for RetentionExpirationDate"""
        return self.RetentionExpirationDate

    @property
    def RetentionPolicyName(self):
        return self.com_object.RetentionPolicyName

    @property
    def retentionpolicyname(self):
        """Alias for RetentionPolicyName"""
        return self.RetentionPolicyName

    @property
    def retention_policy_name(self):
        """Alias for RetentionPolicyName"""
        return self.RetentionPolicyName

    @property
    def RTFBody(self):
        return self.com_object.RTFBody

    @RTFBody.setter
    def RTFBody(self, value):
        self.com_object.RTFBody = value

    @property
    def rtfbody(self):
        """Alias for RTFBody"""
        return self.RTFBody

    @rtfbody.setter
    def rtfbody(self, value):
        """Alias for RTFBody.setter"""
        self.RTFBody = value

    @property
    def r_t_f_body(self):
        """Alias for RTFBody"""
        return self.RTFBody

    @r_t_f_body.setter
    def r_t_f_body(self, value):
        """Alias for RTFBody.setter"""
        self.RTFBody = value

    @property
    def Saved(self):
        return self.com_object.Saved

    @property
    def saved(self):
        """Alias for Saved"""
        return self.Saved

    @property
    def SaveSentMessageFolder(self):
        return self.com_object.SaveSentMessageFolder

    @property
    def savesentmessagefolder(self):
        """Alias for SaveSentMessageFolder"""
        return self.SaveSentMessageFolder

    @property
    def save_sent_message_folder(self):
        """Alias for SaveSentMessageFolder"""
        return self.SaveSentMessageFolder

    @property
    def SenderEmailAddress(self):
        return self.com_object.SenderEmailAddress

    @property
    def senderemailaddress(self):
        """Alias for SenderEmailAddress"""
        return self.SenderEmailAddress

    @property
    def sender_email_address(self):
        """Alias for SenderEmailAddress"""
        return self.SenderEmailAddress

    @property
    def SenderEmailType(self):
        return self.com_object.SenderEmailType

    @property
    def senderemailtype(self):
        """Alias for SenderEmailType"""
        return self.SenderEmailType

    @property
    def sender_email_type(self):
        """Alias for SenderEmailType"""
        return self.SenderEmailType

    @property
    def SenderName(self):
        return self.com_object.SenderName

    @property
    def sendername(self):
        """Alias for SenderName"""
        return self.SenderName

    @property
    def sender_name(self):
        """Alias for SenderName"""
        return self.SenderName

    @property
    def SendUsingAccount(self):
        return Account(self.com_object.SendUsingAccount)

    @SendUsingAccount.setter
    def SendUsingAccount(self, value):
        self.com_object.SendUsingAccount = value

    @property
    def sendusingaccount(self):
        """Alias for SendUsingAccount"""
        return self.SendUsingAccount

    @sendusingaccount.setter
    def sendusingaccount(self, value):
        """Alias for SendUsingAccount.setter"""
        self.SendUsingAccount = value

    @property
    def send_using_account(self):
        """Alias for SendUsingAccount"""
        return self.SendUsingAccount

    @send_using_account.setter
    def send_using_account(self, value):
        """Alias for SendUsingAccount.setter"""
        self.SendUsingAccount = value

    @property
    def Sensitivity(self):
        return OlSensitivity(self.com_object.Sensitivity)

    @Sensitivity.setter
    def Sensitivity(self, value):
        self.com_object.Sensitivity = value

    @property
    def sensitivity(self):
        """Alias for Sensitivity"""
        return self.Sensitivity

    @sensitivity.setter
    def sensitivity(self, value):
        """Alias for Sensitivity.setter"""
        self.Sensitivity = value

    @property
    def Sent(self):
        return self.com_object.Sent

    @property
    def sent(self):
        """Alias for Sent"""
        return self.Sent

    @property
    def SentOn(self):
        return self.com_object.SentOn

    @property
    def senton(self):
        """Alias for SentOn"""
        return self.SentOn

    @property
    def sent_on(self):
        """Alias for SentOn"""
        return self.SentOn

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Size(self):
        return self.com_object.Size

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @property
    def Subject(self):
        return self.com_object.Subject

    @Subject.setter
    def Subject(self, value):
        self.com_object.Subject = value

    @property
    def subject(self):
        """Alias for Subject"""
        return self.Subject

    @subject.setter
    def subject(self, value):
        """Alias for Subject.setter"""
        self.Subject = value

    @property
    def Submitted(self):
        return self.com_object.Submitted

    @property
    def submitted(self):
        """Alias for Submitted"""
        return self.Submitted

    @property
    def UnRead(self):
        return self.com_object.UnRead

    @UnRead.setter
    def UnRead(self, value):
        self.com_object.UnRead = value

    @property
    def unread(self):
        """Alias for UnRead"""
        return self.UnRead

    @unread.setter
    def unread(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def un_read(self):
        """Alias for UnRead"""
        return self.UnRead

    @un_read.setter
    def un_read(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def UserProperties(self):
        return UserProperties(self.com_object.UserProperties)

    @property
    def userproperties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    @property
    def user_properties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    def Close(self, SaveMode=None):
        arguments = com_arguments([unwrap(a) for a in [SaveMode]])
        self.com_object.Close(*arguments)

    def close(self, SaveMode=None):
        """Alias for Close"""
        arguments = [SaveMode]
        return self.Close(*arguments)

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Display(self, Modal=None):
        arguments = com_arguments([unwrap(a) for a in [Modal]])
        self.com_object.Display(*arguments)

    def display(self, Modal=None):
        """Alias for Display"""
        arguments = [Modal]
        return self.Display(*arguments)

    def Forward(self):
        return MeetingItem(self.com_object.Forward())

    def forward(self):
        """Alias for Forward"""
        return self.Forward()

    def GetAssociatedAppointment(self, AddToCalendar=None):
        arguments = com_arguments([unwrap(a) for a in [AddToCalendar]])
        return AppointmentItem(self.com_object.GetAssociatedAppointment(*arguments))

    def getassociatedappointment(self, AddToCalendar=None):
        """Alias for GetAssociatedAppointment"""
        arguments = [AddToCalendar]
        return self.GetAssociatedAppointment(*arguments)

    def get_associated_appointment(self, AddToCalendar=None):
        """Alias for GetAssociatedAppointment"""
        arguments = [AddToCalendar]
        return self.GetAssociatedAppointment(*arguments)

    def GetConversation(self):
        return Conversation(self.com_object.GetConversation())

    def getconversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def get_conversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def Move(self, DestFldr=None):
        arguments = com_arguments([unwrap(a) for a in [DestFldr]])
        return self.com_object.Move(*arguments)

    def move(self, DestFldr=None):
        """Alias for Move"""
        arguments = [DestFldr]
        return self.Move(*arguments)

    def PrintOut(self):
        self.com_object.PrintOut()

    def printout(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def print_out(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def Reply(self):
        return MailItem(self.com_object.Reply())

    def reply(self):
        """Alias for Reply"""
        return self.Reply()

    def ReplyAll(self):
        return MailItem(self.com_object.ReplyAll())

    def replyall(self):
        """Alias for ReplyAll"""
        return self.ReplyAll()

    def reply_all(self):
        """Alias for ReplyAll"""
        return self.ReplyAll()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()

    def SaveAs(self, Path=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Path, Type]])
        self.com_object.SaveAs(*arguments)

    def saveas(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def save_as(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def Send(self):
        self.com_object.Send()

    def send(self):
        """Alias for Send"""
        return self.Send()

    def ShowCategoriesDialog(self):
        self.com_object.ShowCategoriesDialog()

    def showcategoriesdialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()

    def show_categories_dialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()


class MoveOrCopyRuleAction:

    def __init__(self, moveorcopyruleaction=None):
        self.com_object= moveorcopyruleaction

    @property
    def ActionType(self):
        return OlRuleActionType(self.com_object.ActionType)

    @property
    def actiontype(self):
        """Alias for ActionType"""
        return self.ActionType

    @property
    def action_type(self):
        """Alias for ActionType"""
        return self.ActionType

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Folder(self):
        return Folder(self.com_object.Folder)

    @Folder.setter
    def Folder(self, value):
        self.com_object.Folder = value

    @property
    def folder(self):
        """Alias for Folder"""
        return self.Folder

    @folder.setter
    def folder(self, value):
        """Alias for Folder.setter"""
        self.Folder = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session


class MultiPage:

    def __init__(self, multipage=None):
        self.com_object= multipage


class NameSpace:

    def __init__(self, namespace=None):
        self.com_object= namespace

    @property
    def Accounts(self):
        return Accounts(self.com_object.Accounts)

    @property
    def accounts(self):
        """Alias for Accounts"""
        return self.Accounts

    @property
    def AddressLists(self):
        return AddressLists(self.com_object.AddressLists)

    @property
    def addresslists(self):
        """Alias for AddressLists"""
        return self.AddressLists

    @property
    def address_lists(self):
        """Alias for AddressLists"""
        return self.AddressLists

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoDiscoverConnectionMode(self):
        return OlAutoDiscoverConnectionMode(self.com_object.AutoDiscoverConnectionMode)

    @property
    def autodiscoverconnectionmode(self):
        """Alias for AutoDiscoverConnectionMode"""
        return self.AutoDiscoverConnectionMode

    @property
    def auto_discover_connection_mode(self):
        """Alias for AutoDiscoverConnectionMode"""
        return self.AutoDiscoverConnectionMode

    @property
    def AutoDiscoverXml(self):
        return self.com_object.AutoDiscoverXml

    @property
    def autodiscoverxml(self):
        """Alias for AutoDiscoverXml"""
        return self.AutoDiscoverXml

    @property
    def auto_discover_xml(self):
        """Alias for AutoDiscoverXml"""
        return self.AutoDiscoverXml

    @property
    def Categories(self):
        return Categories(self.com_object.Categories)

    @Categories.setter
    def Categories(self, value):
        self.com_object.Categories = value

    @property
    def categories(self):
        """Alias for Categories"""
        return self.Categories

    @categories.setter
    def categories(self, value):
        """Alias for Categories.setter"""
        self.Categories = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def CurrentProfileName(self):
        return self.com_object.CurrentProfileName

    @property
    def currentprofilename(self):
        """Alias for CurrentProfileName"""
        return self.CurrentProfileName

    @property
    def current_profile_name(self):
        """Alias for CurrentProfileName"""
        return self.CurrentProfileName

    @property
    def CurrentUser(self):
        return Recipient(self.com_object.CurrentUser)

    @property
    def currentuser(self):
        """Alias for CurrentUser"""
        return self.CurrentUser

    @property
    def current_user(self):
        """Alias for CurrentUser"""
        return self.CurrentUser

    @property
    def DefaultStore(self):
        return Store(self.com_object.DefaultStore)

    @property
    def defaultstore(self):
        """Alias for DefaultStore"""
        return self.DefaultStore

    @property
    def default_store(self):
        """Alias for DefaultStore"""
        return self.DefaultStore

    @property
    def ExchangeConnectionMode(self):
        return OlExchangeConnectionMode(self.com_object.ExchangeConnectionMode)

    @property
    def exchangeconnectionmode(self):
        """Alias for ExchangeConnectionMode"""
        return self.ExchangeConnectionMode

    @property
    def exchange_connection_mode(self):
        """Alias for ExchangeConnectionMode"""
        return self.ExchangeConnectionMode

    @property
    def ExchangeMailboxServerName(self):
        return self.com_object.ExchangeMailboxServerName

    @property
    def exchangemailboxservername(self):
        """Alias for ExchangeMailboxServerName"""
        return self.ExchangeMailboxServerName

    @property
    def exchange_mailbox_server_name(self):
        """Alias for ExchangeMailboxServerName"""
        return self.ExchangeMailboxServerName

    @property
    def ExchangeMailboxServerVersion(self):
        return self.com_object.ExchangeMailboxServerVersion

    @property
    def exchangemailboxserverversion(self):
        """Alias for ExchangeMailboxServerVersion"""
        return self.ExchangeMailboxServerVersion

    @property
    def exchange_mailbox_server_version(self):
        """Alias for ExchangeMailboxServerVersion"""
        return self.ExchangeMailboxServerVersion

    @property
    def Folders(self):
        return Folders(self.com_object.Folders)

    @property
    def folders(self):
        """Alias for Folders"""
        return self.Folders

    @property
    def Offline(self):
        return self.com_object.Offline

    @property
    def offline(self):
        """Alias for Offline"""
        return self.Offline

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Stores(self):
        return Stores(self.com_object.Stores)

    @property
    def stores(self):
        """Alias for Stores"""
        return self.Stores

    @property
    def SyncObjects(self):
        return SyncObjects(self.com_object.SyncObjects)

    @property
    def syncobjects(self):
        """Alias for SyncObjects"""
        return self.SyncObjects

    @property
    def sync_objects(self):
        """Alias for SyncObjects"""
        return self.SyncObjects

    @property
    def Type(self):
        return self.com_object.Type

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def AddStore(self, Store=None):
        arguments = com_arguments([unwrap(a) for a in [Store]])
        self.com_object.AddStore(*arguments)

    def addstore(self, Store=None):
        """Alias for AddStore"""
        arguments = [Store]
        return self.AddStore(*arguments)

    def add_store(self, Store=None):
        """Alias for AddStore"""
        arguments = [Store]
        return self.AddStore(*arguments)

    def AddStoreEx(self, Store=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Store, Type]])
        self.com_object.AddStoreEx(*arguments)

    def addstoreex(self, Store=None, Type=None):
        """Alias for AddStoreEx"""
        arguments = [Store, Type]
        return self.AddStoreEx(*arguments)

    def add_store_ex(self, Store=None, Type=None):
        """Alias for AddStoreEx"""
        arguments = [Store, Type]
        return self.AddStoreEx(*arguments)

    def CompareEntryIDs(self, FirstEntryID=None, SecondEntryID=None):
        arguments = com_arguments([unwrap(a) for a in [FirstEntryID, SecondEntryID]])
        return self.com_object.CompareEntryIDs(*arguments)

    def compareentryids(self, FirstEntryID=None, SecondEntryID=None):
        """Alias for CompareEntryIDs"""
        arguments = [FirstEntryID, SecondEntryID]
        return self.CompareEntryIDs(*arguments)

    def compare_entry_i_ds(self, FirstEntryID=None, SecondEntryID=None):
        """Alias for CompareEntryIDs"""
        arguments = [FirstEntryID, SecondEntryID]
        return self.CompareEntryIDs(*arguments)

    def CreateContactCard(self, Address=None):
        arguments = com_arguments([unwrap(a) for a in [Address]])
        return self.com_object.CreateContactCard(*arguments)

    def createcontactcard(self, Address=None):
        """Alias for CreateContactCard"""
        arguments = [Address]
        return self.CreateContactCard(*arguments)

    def create_contact_card(self, Address=None):
        """Alias for CreateContactCard"""
        arguments = [Address]
        return self.CreateContactCard(*arguments)

    def CreateRecipient(self, RecipientName=None):
        arguments = com_arguments([unwrap(a) for a in [RecipientName]])
        return Recipient(self.com_object.CreateRecipient(*arguments))

    def createrecipient(self, RecipientName=None):
        """Alias for CreateRecipient"""
        arguments = [RecipientName]
        return self.CreateRecipient(*arguments)

    def create_recipient(self, RecipientName=None):
        """Alias for CreateRecipient"""
        arguments = [RecipientName]
        return self.CreateRecipient(*arguments)

    def CreateSharingItem(self, Context=None, Provider=None):
        arguments = com_arguments([unwrap(a) for a in [Context, Provider]])
        return SharingItem(self.com_object.CreateSharingItem(*arguments))

    def createsharingitem(self, Context=None, Provider=None):
        """Alias for CreateSharingItem"""
        arguments = [Context, Provider]
        return self.CreateSharingItem(*arguments)

    def create_sharing_item(self, Context=None, Provider=None):
        """Alias for CreateSharingItem"""
        arguments = [Context, Provider]
        return self.CreateSharingItem(*arguments)

    def Dial(self, ContactItem=None):
        arguments = com_arguments([unwrap(a) for a in [ContactItem]])
        self.com_object.Dial(*arguments)

    def dial(self, ContactItem=None):
        """Alias for Dial"""
        arguments = [ContactItem]
        return self.Dial(*arguments)

    def GetAddressEntryFromID(self, ID=None):
        arguments = com_arguments([unwrap(a) for a in [ID]])
        return self.com_object.GetAddressEntryFromID(*arguments)

    def getaddressentryfromid(self, ID=None):
        """Alias for GetAddressEntryFromID"""
        arguments = [ID]
        return self.GetAddressEntryFromID(*arguments)

    def get_address_entry_from_i_d(self, ID=None):
        """Alias for GetAddressEntryFromID"""
        arguments = [ID]
        return self.GetAddressEntryFromID(*arguments)

    def GetDefaultFolder(self, FolderType=None):
        arguments = com_arguments([unwrap(a) for a in [FolderType]])
        return Folder(self.com_object.GetDefaultFolder(*arguments))

    def getdefaultfolder(self, FolderType=None):
        """Alias for GetDefaultFolder"""
        arguments = [FolderType]
        return self.GetDefaultFolder(*arguments)

    def get_default_folder(self, FolderType=None):
        """Alias for GetDefaultFolder"""
        arguments = [FolderType]
        return self.GetDefaultFolder(*arguments)

    def GetFolderFromID(self, EntryIDFolder=None, EntryIDStore=None):
        arguments = com_arguments([unwrap(a) for a in [EntryIDFolder, EntryIDStore]])
        return Folder(self.com_object.GetFolderFromID(*arguments))

    def getfolderfromid(self, EntryIDFolder=None, EntryIDStore=None):
        """Alias for GetFolderFromID"""
        arguments = [EntryIDFolder, EntryIDStore]
        return self.GetFolderFromID(*arguments)

    def get_folder_from_i_d(self, EntryIDFolder=None, EntryIDStore=None):
        """Alias for GetFolderFromID"""
        arguments = [EntryIDFolder, EntryIDStore]
        return self.GetFolderFromID(*arguments)

    def GetGlobalAddressList(self):
        return AddressList(self.com_object.GetGlobalAddressList())

    def getglobaladdresslist(self):
        """Alias for GetGlobalAddressList"""
        return self.GetGlobalAddressList()

    def get_global_address_list(self):
        """Alias for GetGlobalAddressList"""
        return self.GetGlobalAddressList()

    def GetItemFromID(self, EntryIDItem=None, EntryIDStore=None):
        arguments = com_arguments([unwrap(a) for a in [EntryIDItem, EntryIDStore]])
        return self.com_object.GetItemFromID(*arguments)

    def getitemfromid(self, EntryIDItem=None, EntryIDStore=None):
        """Alias for GetItemFromID"""
        arguments = [EntryIDItem, EntryIDStore]
        return self.GetItemFromID(*arguments)

    def get_item_from_i_d(self, EntryIDItem=None, EntryIDStore=None):
        """Alias for GetItemFromID"""
        arguments = [EntryIDItem, EntryIDStore]
        return self.GetItemFromID(*arguments)

    def GetRecipientFromID(self, EntryID=None):
        arguments = com_arguments([unwrap(a) for a in [EntryID]])
        return Recipient(self.com_object.GetRecipientFromID(*arguments))

    def getrecipientfromid(self, EntryID=None):
        """Alias for GetRecipientFromID"""
        arguments = [EntryID]
        return self.GetRecipientFromID(*arguments)

    def get_recipient_from_i_d(self, EntryID=None):
        """Alias for GetRecipientFromID"""
        arguments = [EntryID]
        return self.GetRecipientFromID(*arguments)

    def GetSelectNamesDialog(self):
        return SelectNamesDialog(self.com_object.GetSelectNamesDialog())

    def getselectnamesdialog(self):
        """Alias for GetSelectNamesDialog"""
        return self.GetSelectNamesDialog()

    def get_select_names_dialog(self):
        """Alias for GetSelectNamesDialog"""
        return self.GetSelectNamesDialog()

    def GetSharedDefaultFolder(self, Recipient=None, FolderType=None):
        arguments = com_arguments([unwrap(a) for a in [Recipient, FolderType]])
        return Folder(self.com_object.GetSharedDefaultFolder(*arguments))

    def getshareddefaultfolder(self, Recipient=None, FolderType=None):
        """Alias for GetSharedDefaultFolder"""
        arguments = [Recipient, FolderType]
        return self.GetSharedDefaultFolder(*arguments)

    def get_shared_default_folder(self, Recipient=None, FolderType=None):
        """Alias for GetSharedDefaultFolder"""
        arguments = [Recipient, FolderType]
        return self.GetSharedDefaultFolder(*arguments)

    def GetStoreFromID(self, ID=None):
        arguments = com_arguments([unwrap(a) for a in [ID]])
        return self.com_object.GetStoreFromID(*arguments)

    def getstorefromid(self, ID=None):
        """Alias for GetStoreFromID"""
        arguments = [ID]
        return self.GetStoreFromID(*arguments)

    def get_store_from_i_d(self, ID=None):
        """Alias for GetStoreFromID"""
        arguments = [ID]
        return self.GetStoreFromID(*arguments)

    def Logoff(self):
        self.com_object.Logoff()

    def logoff(self):
        """Alias for Logoff"""
        return self.Logoff()

    def Logon(self, Profile=None, Password=None, ShowDialog=None, NewSession=None):
        arguments = com_arguments([unwrap(a) for a in [Profile, Password, ShowDialog, NewSession]])
        self.com_object.Logon(*arguments)

    def logon(self, Profile=None, Password=None, ShowDialog=None, NewSession=None):
        """Alias for Logon"""
        arguments = [Profile, Password, ShowDialog, NewSession]
        return self.Logon(*arguments)

    def OpenSharedFolder(self, Path=None, Name=None, DownloadAttachments=None, UseTTL=None):
        arguments = com_arguments([unwrap(a) for a in [Path, Name, DownloadAttachments, UseTTL]])
        return Folder(self.com_object.OpenSharedFolder(*arguments))

    def opensharedfolder(self, Path=None, Name=None, DownloadAttachments=None, UseTTL=None):
        """Alias for OpenSharedFolder"""
        arguments = [Path, Name, DownloadAttachments, UseTTL]
        return self.OpenSharedFolder(*arguments)

    def open_shared_folder(self, Path=None, Name=None, DownloadAttachments=None, UseTTL=None):
        """Alias for OpenSharedFolder"""
        arguments = [Path, Name, DownloadAttachments, UseTTL]
        return self.OpenSharedFolder(*arguments)

    def OpenSharedItem(self, Path=None):
        arguments = com_arguments([unwrap(a) for a in [Path]])
        return self.com_object.OpenSharedItem(*arguments)

    def openshareditem(self, Path=None):
        """Alias for OpenSharedItem"""
        arguments = [Path]
        return self.OpenSharedItem(*arguments)

    def open_shared_item(self, Path=None):
        """Alias for OpenSharedItem"""
        arguments = [Path]
        return self.OpenSharedItem(*arguments)

    def PickFolder(self):
        return self.com_object.PickFolder()

    def pickfolder(self):
        """Alias for PickFolder"""
        return self.PickFolder()

    def pick_folder(self):
        """Alias for PickFolder"""
        return self.PickFolder()

    def RemoveStore(self, Folder=None):
        arguments = com_arguments([unwrap(a) for a in [Folder]])
        self.com_object.RemoveStore(*arguments)

    def removestore(self, Folder=None):
        """Alias for RemoveStore"""
        arguments = [Folder]
        return self.RemoveStore(*arguments)

    def remove_store(self, Folder=None):
        """Alias for RemoveStore"""
        arguments = [Folder]
        return self.RemoveStore(*arguments)

    def SendAndReceive(self, showProgressDialog=None):
        arguments = com_arguments([unwrap(a) for a in [showProgressDialog]])
        self.com_object.SendAndReceive(*arguments)

    def sendandreceive(self, showProgressDialog=None):
        """Alias for SendAndReceive"""
        arguments = [showProgressDialog]
        return self.SendAndReceive(*arguments)

    def send_and_receive(self, showProgressDialog=None):
        """Alias for SendAndReceive"""
        arguments = [showProgressDialog]
        return self.SendAndReceive(*arguments)


class NavigationFolder:

    def __init__(self, navigationfolder=None):
        self.com_object= navigationfolder

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def DisplayName(self):
        return NavigationFolder(self.com_object.DisplayName)

    @property
    def displayname(self):
        """Alias for DisplayName"""
        return self.DisplayName

    @property
    def display_name(self):
        """Alias for DisplayName"""
        return self.DisplayName

    @property
    def Folder(self):
        return Folder(self.com_object.Folder)

    @property
    def folder(self):
        """Alias for Folder"""
        return self.Folder

    @property
    def IsRemovable(self):
        return NavigationFolder(self.com_object.IsRemovable)

    @property
    def isremovable(self):
        """Alias for IsRemovable"""
        return self.IsRemovable

    @property
    def is_removable(self):
        """Alias for IsRemovable"""
        return self.IsRemovable

    @property
    def IsSelected(self):
        return NavigationFolder(self.com_object.IsSelected)

    @IsSelected.setter
    def IsSelected(self, value):
        self.com_object.IsSelected = value

    @property
    def isselected(self):
        """Alias for IsSelected"""
        return self.IsSelected

    @isselected.setter
    def isselected(self, value):
        """Alias for IsSelected.setter"""
        self.IsSelected = value

    @property
    def is_selected(self):
        """Alias for IsSelected"""
        return self.IsSelected

    @is_selected.setter
    def is_selected(self, value):
        """Alias for IsSelected.setter"""
        self.IsSelected = value

    @property
    def IsSideBySide(self):
        return NavigationFolder(self.com_object.IsSideBySide)

    @IsSideBySide.setter
    def IsSideBySide(self, value):
        self.com_object.IsSideBySide = value

    @property
    def issidebyside(self):
        """Alias for IsSideBySide"""
        return self.IsSideBySide

    @issidebyside.setter
    def issidebyside(self, value):
        """Alias for IsSideBySide.setter"""
        self.IsSideBySide = value

    @property
    def is_side_by_side(self):
        """Alias for IsSideBySide"""
        return self.IsSideBySide

    @is_side_by_side.setter
    def is_side_by_side(self, value):
        """Alias for IsSideBySide.setter"""
        self.IsSideBySide = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return NavigationFolder(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session


class NavigationFolders:

    def __init__(self, navigationfolders=None):
        self.com_object= navigationfolders

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Add(self, Folder=None):
        arguments = com_arguments([unwrap(a) for a in [Folder]])
        return NavigationFolder(self.com_object.Add(*arguments))

    def add(self, Folder=None):
        """Alias for Add"""
        arguments = [Folder]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return NavigationFolder(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Remove(self, RemovableFolder=None):
        arguments = com_arguments([unwrap(a) for a in [RemovableFolder]])
        self.com_object.Remove(*arguments)

    def remove(self, RemovableFolder=None):
        """Alias for Remove"""
        arguments = [RemovableFolder]
        return self.Remove(*arguments)


class NavigationGroup:

    def __init__(self, navigationgroup=None):
        self.com_object= navigationgroup

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def GroupType(self):
        return OlGroupType(self.com_object.GroupType)

    @property
    def grouptype(self):
        """Alias for GroupType"""
        return self.GroupType

    @property
    def group_type(self):
        """Alias for GroupType"""
        return self.GroupType

    @property
    def Name(self):
        return NavigationGroup(self.com_object.Name)

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def NavigationFolders(self):
        return NavigationFolders(self.com_object.NavigationFolders)

    @property
    def navigationfolders(self):
        """Alias for NavigationFolders"""
        return self.NavigationFolders

    @property
    def navigation_folders(self):
        """Alias for NavigationFolders"""
        return self.NavigationFolders

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return NavigationGroup(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session


class NavigationGroups:

    def __init__(self, navigationgroups=None):
        self.com_object= navigationgroups

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Create(self, GroupDisplayName=None):
        arguments = com_arguments([unwrap(a) for a in [GroupDisplayName]])
        return NavigationGroup(self.com_object.Create(*arguments))

    def create(self, GroupDisplayName=None):
        """Alias for Create"""
        arguments = [GroupDisplayName]
        return self.Create(*arguments)

    def Delete(self, Group=None):
        arguments = com_arguments([unwrap(a) for a in [Group]])
        self.com_object.Delete(*arguments)

    def delete(self, Group=None):
        """Alias for Delete"""
        arguments = [Group]
        return self.Delete(*arguments)

    def GetDefaultNavigationGroup(self, DefaultFolderGroup=None):
        arguments = com_arguments([unwrap(a) for a in [DefaultFolderGroup]])
        return NavigationGroup(self.com_object.GetDefaultNavigationGroup(*arguments))

    def getdefaultnavigationgroup(self, DefaultFolderGroup=None):
        """Alias for GetDefaultNavigationGroup"""
        arguments = [DefaultFolderGroup]
        return self.GetDefaultNavigationGroup(*arguments)

    def get_default_navigation_group(self, DefaultFolderGroup=None):
        """Alias for GetDefaultNavigationGroup"""
        arguments = [DefaultFolderGroup]
        return self.GetDefaultNavigationGroup(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return NavigationGroup(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class NavigationModule:

    def __init__(self, navigationmodule=None):
        self.com_object= navigationmodule

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Name(self):
        return NavigationModule(self.com_object.Name)

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NavigationModuleType(self):
        return olNavigationModuleType(self.com_object.NavigationModuleType)

    @property
    def navigationmoduletype(self):
        """Alias for NavigationModuleType"""
        return self.NavigationModuleType

    @property
    def navigation_module_type(self):
        """Alias for NavigationModuleType"""
        return self.NavigationModuleType

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return NavigationModule(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Visible(self):
        return NavigationModule(self.com_object.Visible)

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value


class NavigationModules:

    def __init__(self, navigationmodules=None):
        self.com_object= navigationmodules

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def GetNavigationModule(self, ModuleType=None):
        arguments = com_arguments([unwrap(a) for a in [ModuleType]])
        return NavigationModule(self.com_object.GetNavigationModule(*arguments))

    def getnavigationmodule(self, ModuleType=None):
        """Alias for GetNavigationModule"""
        arguments = [ModuleType]
        return self.GetNavigationModule(*arguments)

    def get_navigation_module(self, ModuleType=None):
        """Alias for GetNavigationModule"""
        arguments = [ModuleType]
        return self.GetNavigationModule(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return NavigationModule(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class NavigationPane:

    def __init__(self, navigationpane=None):
        self.com_object= navigationpane

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def CurrentModule(self):
        return NavigationModule(self.com_object.CurrentModule)

    @CurrentModule.setter
    def CurrentModule(self, value):
        self.com_object.CurrentModule = value

    @property
    def currentmodule(self):
        """Alias for CurrentModule"""
        return self.CurrentModule

    @currentmodule.setter
    def currentmodule(self, value):
        """Alias for CurrentModule.setter"""
        self.CurrentModule = value

    @property
    def current_module(self):
        """Alias for CurrentModule"""
        return self.CurrentModule

    @current_module.setter
    def current_module(self, value):
        """Alias for CurrentModule.setter"""
        self.CurrentModule = value

    @property
    def DisplayedModuleCount(self):
        return NavigationModule(self.com_object.DisplayedModuleCount)

    @DisplayedModuleCount.setter
    def DisplayedModuleCount(self, value):
        self.com_object.DisplayedModuleCount = value

    @property
    def displayedmodulecount(self):
        """Alias for DisplayedModuleCount"""
        return self.DisplayedModuleCount

    @displayedmodulecount.setter
    def displayedmodulecount(self, value):
        """Alias for DisplayedModuleCount.setter"""
        self.DisplayedModuleCount = value

    @property
    def displayed_module_count(self):
        """Alias for DisplayedModuleCount"""
        return self.DisplayedModuleCount

    @displayed_module_count.setter
    def displayed_module_count(self, value):
        """Alias for DisplayedModuleCount.setter"""
        self.DisplayedModuleCount = value

    @property
    def IsCollapsed(self):
        return self.com_object.IsCollapsed

    @IsCollapsed.setter
    def IsCollapsed(self, value):
        self.com_object.IsCollapsed = value

    @property
    def iscollapsed(self):
        """Alias for IsCollapsed"""
        return self.IsCollapsed

    @iscollapsed.setter
    def iscollapsed(self, value):
        """Alias for IsCollapsed.setter"""
        self.IsCollapsed = value

    @property
    def is_collapsed(self):
        """Alias for IsCollapsed"""
        return self.IsCollapsed

    @is_collapsed.setter
    def is_collapsed(self, value):
        """Alias for IsCollapsed.setter"""
        self.IsCollapsed = value

    @property
    def Modules(self):
        return NavigationModules(self.com_object.Modules)

    @property
    def modules(self):
        """Alias for Modules"""
        return self.Modules

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session


class NewItemAlertRuleAction:

    def __init__(self, newitemalertruleaction=None):
        self.com_object= newitemalertruleaction

    @property
    def ActionType(self):
        return OlRuleActionType(self.com_object.ActionType)

    @property
    def actiontype(self):
        """Alias for ActionType"""
        return self.ActionType

    @property
    def action_type(self):
        """Alias for ActionType"""
        return self.ActionType

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value


class NoteItem:

    def __init__(self, noteitem=None):
        self.com_object= noteitem

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoResolvedWinner(self):
        return self.com_object.AutoResolvedWinner

    @property
    def autoresolvedwinner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def auto_resolved_winner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def Body(self):
        return self.com_object.Body

    @Body.setter
    def Body(self, value):
        self.com_object.Body = value

    @property
    def body(self):
        """Alias for Body"""
        return self.Body

    @body.setter
    def body(self, value):
        """Alias for Body.setter"""
        self.Body = value

    @property
    def Categories(self):
        return self.com_object.Categories

    @Categories.setter
    def Categories(self, value):
        self.com_object.Categories = value

    @property
    def categories(self):
        """Alias for Categories"""
        return self.Categories

    @categories.setter
    def categories(self, value):
        """Alias for Categories.setter"""
        self.Categories = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Conflicts(self):
        return self.com_object.Conflicts

    @property
    def conflicts(self):
        """Alias for Conflicts"""
        return self.Conflicts

    @property
    def CreationTime(self):
        return self.com_object.CreationTime

    @property
    def creationtime(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def creation_time(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def DownloadState(self):
        return OlDownloadState(self.com_object.DownloadState)

    @property
    def downloadstate(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def download_state(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def EntryID(self):
        return self.com_object.EntryID

    @property
    def entryid(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def entry_i_d(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def GetInspector(self):
        return Inspector(self.com_object.GetInspector)

    @property
    def getinspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def get_inspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def IsConflict(self):
        return self.com_object.IsConflict

    @property
    def isconflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def is_conflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def ItemProperties(self):
        return ItemProperties(self.com_object.ItemProperties)

    @property
    def itemproperties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def item_properties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def LastModificationTime(self):
        return self.com_object.LastModificationTime

    @property
    def lastmodificationtime(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def last_modification_time(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def MarkForDownload(self):
        return OlRemoteStatus(self.com_object.MarkForDownload)

    @MarkForDownload.setter
    def MarkForDownload(self, value):
        self.com_object.MarkForDownload = value

    @property
    def markfordownload(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @markfordownload.setter
    def markfordownload(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def mark_for_download(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @mark_for_download.setter
    def mark_for_download(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def MessageClass(self):
        return self.com_object.MessageClass

    @MessageClass.setter
    def MessageClass(self, value):
        self.com_object.MessageClass = value

    @property
    def messageclass(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @messageclass.setter
    def messageclass(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def message_class(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @message_class.setter
    def message_class(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def Saved(self):
        return self.com_object.Saved

    @property
    def saved(self):
        """Alias for Saved"""
        return self.Saved

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Size(self):
        return self.com_object.Size

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @property
    def Subject(self):
        return self.com_object.Subject

    @Subject.setter
    def Subject(self, value):
        self.com_object.Subject = value

    @property
    def subject(self):
        """Alias for Subject"""
        return self.Subject

    @subject.setter
    def subject(self, value):
        """Alias for Subject.setter"""
        self.Subject = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Close(self, SaveMode=None):
        arguments = com_arguments([unwrap(a) for a in [SaveMode]])
        self.com_object.Close(*arguments)

    def close(self, SaveMode=None):
        """Alias for Close"""
        arguments = [SaveMode]
        return self.Close(*arguments)

    def Copy(self):
        return NoteItem(self.com_object.Copy())

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Display(self, Modal=None):
        arguments = com_arguments([unwrap(a) for a in [Modal]])
        self.com_object.Display(*arguments)

    def display(self, Modal=None):
        """Alias for Display"""
        arguments = [Modal]
        return self.Display(*arguments)

    def Move(self, DestFldr=None):
        arguments = com_arguments([unwrap(a) for a in [DestFldr]])
        return self.com_object.Move(*arguments)

    def move(self, DestFldr=None):
        """Alias for Move"""
        arguments = [DestFldr]
        return self.Move(*arguments)

    def PrintOut(self):
        self.com_object.PrintOut()

    def printout(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def print_out(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()

    def SaveAs(self, Path=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Path, Type]])
        self.com_object.SaveAs(*arguments)

    def saveas(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def save_as(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)


class NotesModule:

    def __init__(self, notesmodule=None):
        self.com_object= notesmodule

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Name(self):
        return NotesModule(self.com_object.Name)

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NavigationGroups(self):
        return NavigationGroups(self.com_object.NavigationGroups)

    @property
    def navigationgroups(self):
        """Alias for NavigationGroups"""
        return self.NavigationGroups

    @property
    def navigation_groups(self):
        """Alias for NavigationGroups"""
        return self.NavigationGroups

    @property
    def NavigationModuleType(self):
        return olNavigationModuleType(self.com_object.NavigationModuleType)

    @property
    def navigationmoduletype(self):
        """Alias for NavigationModuleType"""
        return self.NavigationModuleType

    @property
    def navigation_module_type(self):
        """Alias for NavigationModuleType"""
        return self.NavigationModuleType

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return NotesModule(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Visible(self):
        return NotesModule(self.com_object.Visible)

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value


# OlAccountType enumeration
olEas = 4
olExchange = 0
olHttp = 3
olImap = 1
olOtherAccount = 5
olPop3 = 2

# OlActionCopyLike enumeration
olForward = 2
olReply = 0
olReplyAll = 1
olReplyFolder = 3
olRespond = 4

# OlActionReplyStyle enumeration
olEmbedOriginalItem = 1
olIncludeOriginalText = 2
olIndentOriginalText = 3
olLinkOriginalItem = 4
olOmitOriginalText = 0
olReplyTickOriginalText = 1000
olUserPreference = 5

# OlActionResponseStyle enumeration
olOpen = 0
olPrompt = 2
olSend = 1

# OlActionShowOn enumeration
olDontShow = 0
olMenu = 1
olMenuAndToolbar = 2

# OlAddressEntryUserType enumeration
olExchangeAgentAddressEntry = 3
olExchangeDistributionListAddressEntry = 1
olExchangeOrganizationAddressEntry = 4
olExchangePublicFolderAddressEntry = 2
olExchangeRemoteUserAddressEntry = 5
olExchangeUserAddressEntry = 0
olLdapAddressEntry = 20
olOtherAddressEntry = 40
olOutlookContactAddressEntry = 10
olOutlookDistributionListAddressEntry = 11
olSmtpAddressEntry = 30

# OlAddressListType enumeration
olCustomAddressList = 4
olExchangeContainer = 1
olExchangeGlobalAddressList = 0
olOutlookAddressList = 2
olOutlookLdapAddressList = 3

# OlAlign enumeration
olAlignCenter = 1
olAlignLeft = 0
olAlignRight = 2

# OlAlignment enumeration
olAlignmentLeft = 0
olAlignmentRight = 1

# OlAlwaysDeleteConversation enumeration
olAlwaysDelete = 1
olAlwaysDeleteUnsupported = 2
olDoNotDelete = 0

# OlAppointmentCopyOptions enumeration
olCopyAsAccept = 2
olCreateAppointment = 1
olPromptUser = 0

# OlAppointmentTimeField enumeration
olAppointmentTimeFieldEnd = 3
olAppointmentTimeFieldNone = 1
olAppointmentTimeFieldStart = 2

# OlAttachmentBlockLevel enumeration
olAttachmentBlockLevelNone = 0
olAttachmentBlockLevelOpen = 1

# OlAttachmentType enumeration
olByReference = 4
olByValue = 1
olEmbeddeditem = 5
olOLE = 6

# OlAutoDiscoverConnectionMode enumeration
olAutoDiscoverConnectionExternal = 1
olAutoDiscoverConnectionInternal = 2
olAutoDiscoverConnectionInternalDomain = 3
olAutoDiscoverConnectionUnknown = 0

# OlAutoPreview enumeration
olAutoPreviewAll = 0
olAutoPreviewNone = 2
olAutoPreviewUnread = 1

# OlBackStyle enumeration
olBackStyleOpaque = 1
olBackStyleTransparent = 0

# OlBodyFormat enumeration
olFormatHTML = 2
olFormatPlain = 1
olFormatRichText = 3
olFormatUnspecified = 0

# OlBorderStyle enumeration
olBorderStyleNone = 0
olBorderStyleSingle = 1

# OlBusinessCardType enumeration
olBusinessCardTypeInterConnect = 1
olBusinessCardTypeOutlook = 0

# OlBusyStatus enumeration
olBusy = 2
olFree = 0
olOutOfOffice = 3
olTentative = 1
olWorkingElsewhere = 4

# OlCalendarDetail enumeration
olFreeBusyAndSubject = 1
olFreeBusyOnly = 0
olFullDetails = 2

# OlCalendarMailFormat enumeration
olCalendarMailFormatDailySchedule = 0
olCalendarMailFormatEventList = 1

# OlCalendarViewMode enumeration
olCalendarView5DayWeek = 4
olCalendarViewDay = 0
olCalendarViewMonth = 2
olCalendarViewMultiDay = 3
olCalendarViewWeek = 1

# OlCategoryColor enumeration
olCategoryColorBlack = 15
olCategoryColorBlue = 8
olCategoryColorDarkBlue = 23
olCategoryColorDarkGray = 14
olCategoryColorDarkGreen = 20
olCategoryColorDarkMaroon = 25
olCategoryColorDarkOlive = 22
olCategoryColorDarkOrange = 17
olCategoryColorDarkPeach = 18
olCategoryColorDarkPurple = 24
olCategoryColorDarkRed = 16
olCategoryColorDarkSteel = 12
olCategoryColorDarkTeal = 21
olCategoryColorDarkYellow = 19
olCategoryColorGray = 13
olCategoryColorGreen = 5
olCategoryColorMaroon = 10
olCategoryColorNone = 0
olCategoryColorOlive = 7
olCategoryColorOrange = 2
olCategoryColorPeach = 3
olCategoryColorPurple = 9
olCategoryColorRed = 1
olCategoryColorSteel = 11
olCategoryColorTeal = 6
olCategoryColorYellow = 4

# OlCategoryShortcutKey enumeration
olCategoryShortcutKeyCtrlF10 = 10
olCategoryShortcutKeyCtrlF11 = 11
olCategoryShortcutKeyCtrlF12 = 12
olCategoryShortcutKeyCtrlF2 = 2
olCategoryShortcutKeyCtrlF3 = 3
olCategoryShortcutKeyCtrlF4 = 4
olCategoryShortcutKeyCtrlF5 = 5
olCategoryShortcutKeyCtrlF6 = 6
olCategoryShortcutKeyCtrlF7 = 7
olCategoryShortcutKeyCtrlF8 = 8
olCategoryShortcutKeyCtrlF9 = 9
olCategoryShortcutKeyNone = 0

# OlColor enumeration
olAutoColor = 0
olColorAqua = 15
olColorBlack = 1
olColorBlue = 13
olColorFuchsia = 14
olColorGray = 8
olColorGreen = 3
olColorLime = 11
olColorMaroon = 2
olColorNavy = 5
olColorOlive = 4
olColorPurple = 6
olColorRed = 10
olColorSilver = 9
olColorTeal = 7
olColorWhite = 16
olColorYellow = 12

# OlComboBoxStyle enumeration
olComboBoxStyleCombo = 0
olComboBoxStyleList = 1

# OlContactPhoneNumber enumeration
olContactPhoneAssistant = 0
olContactPhoneBusiness = 1
olContactPhoneBusiness2 = 2
olContactPhoneBusinessFax = 3
olContactPhoneCallback = 4
olContactPhoneCar = 5
olContactPhoneCompany = 6
olContactPhoneHome = 7
olContactPhoneHome2 = 8
olContactPhoneHomeFax = 9
olContactPhoneISDN = 10
olContactPhoneMobile = 11
olContactPhoneOther = 12
olContactPhoneOtherFax = 13
olContactPhonePager = 14
olContactPhonePrimary = 15
olContactPhoneRadio = 16
olContactPhoneTelex = 17
olContactPhoneTTYTTD = 18

# OlDaysOfWeek enumeration
olSunday = 1
olMonday = 2
olTuesday = 4
olWednesday = 8
olThursday = 16
olFriday = 32
olSaturday = 64

# OlDayWeekTimeScale enumeration
olTimeScale10Minutes = 2
olTimeScale15Minutes = 3
olTimeScale30Minutes = 4
olTimeScale5Minutes = 0
olTimeScale60Minutes = 5
olTimeScale6Minutes = 1

# OlDefaultExpandCollapseSetting enumeration
olAllCollapsed = 1
olAllExpanded = 0
olLastViewed = 2

# OlDefaultFolders enumeration
olFolderCalendar = 9
olFolderConflicts = 19
olFolderContacts = 10
olFolderDeletedItems = 3
olFolderDrafts = 16
olFolderInbox = 6
olFolderJournal = 11
olFolderJunk = 23
olFolderLocalFailures = 21
olFolderManagedEmail = 29
olFolderNotes = 12
olFolderOutbox = 4
olFolderSentMail = 5
olFolderServerFailures = 22
olFolderSuggestedContacts = 30
olFolderSyncIssues = 20
olFolderTasks = 13
olFolderToDo = 28
olPublicFoldersAllPublicFolders = 18
olFolderRssFeeds = 25

# OlDefaultSelectNamesDisplayMode enumeration
olDefaultDelegates = 6
olDefaultMail = 1
olDefaultMeeting = 2
olDefaultMembers = 5
olDefaultPickRooms = 8
olDefaultSharingRequest = 4
olDefaultSingleName = 7
olDefaultTask = 3

# OlDisplayType enumeration
olAgent = 3
olDistList = 1
olForum = 2
olOrganization = 4
olPrivateDistList = 5
olRemoteUser = 6
olUser = 0

# OlDownloadState enumeration
olFullItem = 1
olHeaderOnly = 0

# OlDragBehavior enumeration
olDragBehaviorDisabled = 0
olDragBehaviorEnabled = 1

# OlEditorType enumeration
olEditorHTML = 2
olEditorRTF = 3
olEditorText = 1
olEditorWord = 4

# OlEnterFieldBehavior enumeration
olEnterFieldBehaviorRecallSelection = 1
olEnterFieldBehaviorSelectAll = 0

# OlExchangeConnectionMode enumeration
olCachedConnectedDrizzle = 600
olCachedConnectedFull = 700
olCachedConnectedHeaders = 500
olCachedDisconnected = 400
olCachedOffline = 200
olDisconnected = 300
olNoExchange = 0
olOffline = 100
olOnline = 800

# OlExchangeStoreType enumeration
olExchangeMailbox = 1
olExchangePublicFolder = 2
olNotExchange = 3
olPrimaryExchangeMailbox = 0
olAdditionalExchangeMailbox = 4

# OlFolderDisplayMode enumeration
olFolderDisplayFolderOnly = 1
olFolderDisplayNoNavigation = 2
olFolderDisplayNormal = 0

# OlFormatCurrency enumeration
olFormatCurrencyDecimal = 1
olFormatCurrencyNonDecimal = 2

# OlFormatDateTime enumeration
olFormatDateTimeBestFit = 17
olFormatDateTimeLongDate = 6
olFormatDateTimeLongDateReversed = 7
OlFormatDateTimeLongDayDate = 5
olFormatDateTimeLongDayDateTime = 1
olFormatDateTimeLongTime = 15
olFormatDateTimeShortDate = 8
olFormatDateTimeShortDateNumOnly = 9
olFormatDateTimeShortDateTime = 2
olFormatDateTimeShortDayDate = 13
olFormatDateTimeShortDayDateTime = 3
olFormatDateTimeShortDayMonth = 10
olFormatDateTimeShortDayMonthDateTime = 4
olFormatDateTimeShortMonthYear = 11
olFormatDateTimeShortMonthYearNumOnly = 12
olFormatDateTimeShortTime = 16

# OlFormatDuration enumeration
olFormatDurationLong = 2
olFormatDurationLongBusiness = 4
olFormatDurationShort = 1
olFormatDurationShortBusiness = 3

# OlFormatEnumeration enumeration
olFormatEnumBitmap = 1
olFormatEnumText = 2

# OlFormatInteger enumeration
olFormatIntegerComputer1 = 2
olFormatIntegerComputer2 = 3
olFormatIntegerComputer3 = 4
olFormatIntegerPlain = 1

# OlFormatKeywords enumeration
olFormatKeywordsText = 1

# OlFormatNumber enumeration
olFormatNumber1Decimal = 3
olFormatNumber2Decimal = 4
olFormatNumberAllDigits = 1
olFormatNumberComputer1 = 6
olFormatNumberComputer2 = 7
olFormatNumberComputer3 = 8
olFormatNumberRaw = 9
olFormatNumberScientific = 5
olFormatNumberTruncated = 2

# OlFormatPercent enumeration
olFormatPercent1Decimal = 2
olFormatPercent2Decimal = 3
olFormatPercentAllDigits = 4
olFormatPercentRounded = 1

# OlFormatSmartFrom enumeration
olFormatSmartFromFromOnly = 2
olFormatSmartFromFromTo = 1

# OlFormatText enumeration
olFormatTextText = 1

# OlFormatYesNo enumeration
olFormatYesNoIcon = 4
olFormatYesNoOnOff = 2
olFormatYesNoTrueFalse = 3
olFormatYesNoYesNo = 1

# OlFormRegionIcon enumeration
olFormRegionIconDefault = 1
olFormRegionIconEncrypted = 9
olFormRegionIconForwarded = 5
olFormRegionIconPage = 11
olFormRegionIconRead = 3
olFormRegionIconRecurring = 12
olFormRegionIconReplied = 4
olFormRegionIconSigned = 8
olFormRegionIconSubmitted = 7
olFormRegionIconUnread = 2
olFormRegionIconUnsent = 6
olFormRegionIconWindow = 10

# OlFormRegionMode enumeration
olFormRegionCompose = 1
olFormRegionPreview = 2
olFormRegionRead = 0

# OlFormRegionSize enumeration
olFormRegionTypeAdjoining = 1
olFormRegionTypeSeparate = 0

# OlFormRegistry enumeration
olDefaultRegistry = 0
olFolderRegistry = 3
olOrganizationRegistry = 4
olPersonalRegistry = 2

# OlGender enumeration
olFemale = 1
olMale = 2
olUnspecified = 0

# OlGridLineStyle enumeration
olGridLineDashes = 3
olGridLineLargeDots = 2
olGridLineNone = 0
olGridLineSmallDots = 1
olGridLineSolid = 4

# OlGroupType enumeration
olCustomFoldersGroup = 0
olFavoriteFoldersGroup = 4
olMyFoldersGroup = 1
olOtherFoldersGroup = 3
olPeopleFoldersGroup = 2
olReadOnlyGroup = 6
olRoomsGroup = 5

# OlHorizontalLayout enumeration
olHorizontalLayoutAlignCenter = 1
olHorizontalLayoutGrow = 3
olHorizontalLayoutAlignLeft = 0
olHorizontalLayoutAlignRight = 2

# OlIconViewPlacement enumeration
olIconAutoArrange = 2
olIconDoNotArrange = 0
olIconLineUp = 1
olIconSortAndAutoArrange = 3

# OlIconViewType enumeration
olIconViewLarge = 0
olIconViewList = 2
olIconViewSmall = 1

# OlImportance enumeration
olImportanceHigh = 2
olImportanceLow = 0
olImportanceNormal = 1

# OlInspectorClose enumeration
olDiscard = 1
olPromptForSave = 2
olSave = 0

# OlItemType enumeration
olAppointmentItem = 1
olContactItem = 2
olDistributionListItem = 7
olJournalItem = 4
olMailItem = 0
olNoteItem = 5
olPostItem = 6
olTaskItem = 3

# OlJournalRecipientType enumeration
olAssociatedContact = 1

class OlkBusinessCardControl:

    def __init__(self, olkbusinesscardcontrol=None):
        self.com_object= olkbusinesscardcontrol

    @property
    def MouseIcon(self):
        return self.com_object.MouseIcon

    @MouseIcon.setter
    def MouseIcon(self, value):
        self.com_object.MouseIcon = value

    @property
    def mouseicon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouseicon.setter
    def mouseicon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def mouse_icon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouse_icon.setter
    def mouse_icon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def MousePointer(self):
        return OlMousePointer(self.com_object.MousePointer)

    @MousePointer.setter
    def MousePointer(self, value):
        self.com_object.MousePointer = value

    @property
    def mousepointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mousepointer.setter
    def mousepointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def mouse_pointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mouse_pointer.setter
    def mouse_pointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value


class OlkCategory:

    def __init__(self, olkcategory=None):
        self.com_object= olkcategory

    @property
    def AutoSize(self):
        return self.com_object.AutoSize

    @AutoSize.setter
    def AutoSize(self, value):
        self.com_object.AutoSize = value

    @property
    def autosize(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @autosize.setter
    def autosize(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def auto_size(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @auto_size.setter
    def auto_size(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BackStyle(self):
        return olBackStyle(self.com_object.BackStyle)

    @BackStyle.setter
    def BackStyle(self, value):
        self.com_object.BackStyle = value

    @property
    def backstyle(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @backstyle.setter
    def backstyle(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def back_style(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @back_style.setter
    def back_style(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def ForeColor(self):
        return self.com_object.ForeColor

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def MouseIcon(self):
        return self.com_object.MouseIcon

    @MouseIcon.setter
    def MouseIcon(self, value):
        self.com_object.MouseIcon = value

    @property
    def mouseicon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouseicon.setter
    def mouseicon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def mouse_icon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouse_icon.setter
    def mouse_icon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def MousePointer(self):
        return OlMousePointer(self.com_object.MousePointer)

    @MousePointer.setter
    def MousePointer(self, value):
        self.com_object.MousePointer = value

    @property
    def mousepointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mousepointer.setter
    def mousepointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def mouse_pointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mouse_pointer.setter
    def mouse_pointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value


class OlkCheckBox:

    def __init__(self, olkcheckbox=None):
        self.com_object= olkcheckbox

    @property
    def Accelerator(self):
        return self.com_object.Accelerator

    @Accelerator.setter
    def Accelerator(self, value):
        self.com_object.Accelerator = value

    @property
    def accelerator(self):
        """Alias for Accelerator"""
        return self.Accelerator

    @accelerator.setter
    def accelerator(self, value):
        """Alias for Accelerator.setter"""
        self.Accelerator = value

    @property
    def Alignment(self):
        return olAlignment(self.com_object.Alignment)

    @Alignment.setter
    def Alignment(self, value):
        self.com_object.Alignment = value

    @property
    def alignment(self):
        """Alias for Alignment"""
        return self.Alignment

    @alignment.setter
    def alignment(self, value):
        """Alias for Alignment.setter"""
        self.Alignment = value

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BackStyle(self):
        return olBackStyle(self.com_object.BackStyle)

    @BackStyle.setter
    def BackStyle(self, value):
        self.com_object.BackStyle = value

    @property
    def backstyle(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @backstyle.setter
    def backstyle(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def back_style(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @back_style.setter
    def back_style(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Font(self):
        return self.com_object.Font

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def ForeColor(self):
        return self.com_object.ForeColor

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def MouseIcon(self):
        return self.com_object.MouseIcon

    @MouseIcon.setter
    def MouseIcon(self, value):
        self.com_object.MouseIcon = value

    @property
    def mouseicon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouseicon.setter
    def mouseicon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def mouse_icon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouse_icon.setter
    def mouse_icon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def MousePointer(self):
        return OlMousePointer(self.com_object.MousePointer)

    @MousePointer.setter
    def MousePointer(self, value):
        self.com_object.MousePointer = value

    @property
    def mousepointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mousepointer.setter
    def mousepointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def mouse_pointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mouse_pointer.setter
    def mouse_pointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def TripleState(self):
        return self.com_object.TripleState

    @TripleState.setter
    def TripleState(self, value):
        self.com_object.TripleState = value

    @property
    def triplestate(self):
        """Alias for TripleState"""
        return self.TripleState

    @triplestate.setter
    def triplestate(self, value):
        """Alias for TripleState.setter"""
        self.TripleState = value

    @property
    def triple_state(self):
        """Alias for TripleState"""
        return self.TripleState

    @triple_state.setter
    def triple_state(self, value):
        """Alias for TripleState.setter"""
        self.TripleState = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    @property
    def WordWrap(self):
        return self.com_object.WordWrap

    @WordWrap.setter
    def WordWrap(self, value):
        self.com_object.WordWrap = value

    @property
    def wordwrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @wordwrap.setter
    def wordwrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value

    @property
    def word_wrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @word_wrap.setter
    def word_wrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value


class OlkComboBox:

    def __init__(self, olkcombobox=None):
        self.com_object= olkcombobox

    @property
    def AutoSize(self):
        return self.com_object.AutoSize

    @AutoSize.setter
    def AutoSize(self, value):
        self.com_object.AutoSize = value

    @property
    def autosize(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @autosize.setter
    def autosize(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def auto_size(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @auto_size.setter
    def auto_size(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def AutoTab(self):
        return self.com_object.AutoTab

    @AutoTab.setter
    def AutoTab(self, value):
        self.com_object.AutoTab = value

    @property
    def autotab(self):
        """Alias for AutoTab"""
        return self.AutoTab

    @autotab.setter
    def autotab(self, value):
        """Alias for AutoTab.setter"""
        self.AutoTab = value

    @property
    def auto_tab(self):
        """Alias for AutoTab"""
        return self.AutoTab

    @auto_tab.setter
    def auto_tab(self, value):
        """Alias for AutoTab.setter"""
        self.AutoTab = value

    @property
    def AutoWordSelect(self):
        return self.com_object.AutoWordSelect

    @AutoWordSelect.setter
    def AutoWordSelect(self, value):
        self.com_object.AutoWordSelect = value

    @property
    def autowordselect(self):
        """Alias for AutoWordSelect"""
        return self.AutoWordSelect

    @autowordselect.setter
    def autowordselect(self, value):
        """Alias for AutoWordSelect.setter"""
        self.AutoWordSelect = value

    @property
    def auto_word_select(self):
        """Alias for AutoWordSelect"""
        return self.AutoWordSelect

    @auto_word_select.setter
    def auto_word_select(self, value):
        """Alias for AutoWordSelect.setter"""
        self.AutoWordSelect = value

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BorderStyle(self):
        return OlBorderStyle(self.com_object.BorderStyle)

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def DragBehavior(self):
        return self.com_object.DragBehavior

    @DragBehavior.setter
    def DragBehavior(self, value):
        self.com_object.DragBehavior = value

    @property
    def dragbehavior(self):
        """Alias for DragBehavior"""
        return self.DragBehavior

    @dragbehavior.setter
    def dragbehavior(self, value):
        """Alias for DragBehavior.setter"""
        self.DragBehavior = value

    @property
    def drag_behavior(self):
        """Alias for DragBehavior"""
        return self.DragBehavior

    @drag_behavior.setter
    def drag_behavior(self, value):
        """Alias for DragBehavior.setter"""
        self.DragBehavior = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def EnterFieldBehavior(self):
        return olEnterFieldBehavior(self.com_object.EnterFieldBehavior)

    @EnterFieldBehavior.setter
    def EnterFieldBehavior(self, value):
        self.com_object.EnterFieldBehavior = value

    @property
    def enterfieldbehavior(self):
        """Alias for EnterFieldBehavior"""
        return self.EnterFieldBehavior

    @enterfieldbehavior.setter
    def enterfieldbehavior(self, value):
        """Alias for EnterFieldBehavior.setter"""
        self.EnterFieldBehavior = value

    @property
    def enter_field_behavior(self):
        """Alias for EnterFieldBehavior"""
        return self.EnterFieldBehavior

    @enter_field_behavior.setter
    def enter_field_behavior(self, value):
        """Alias for EnterFieldBehavior.setter"""
        self.EnterFieldBehavior = value

    @property
    def Font(self):
        return self.com_object.Font

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def ForeColor(self):
        return self.com_object.ForeColor

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def HideSelection(self):
        return self.com_object.HideSelection

    @HideSelection.setter
    def HideSelection(self, value):
        self.com_object.HideSelection = value

    @property
    def hideselection(self):
        """Alias for HideSelection"""
        return self.HideSelection

    @hideselection.setter
    def hideselection(self, value):
        """Alias for HideSelection.setter"""
        self.HideSelection = value

    @property
    def hide_selection(self):
        """Alias for HideSelection"""
        return self.HideSelection

    @hide_selection.setter
    def hide_selection(self, value):
        """Alias for HideSelection.setter"""
        self.HideSelection = value

    @property
    def ListCount(self):
        return self.com_object.ListCount

    @property
    def listcount(self):
        """Alias for ListCount"""
        return self.ListCount

    @property
    def list_count(self):
        """Alias for ListCount"""
        return self.ListCount

    @property
    def ListIndex(self):
        return self.com_object.ListIndex

    @ListIndex.setter
    def ListIndex(self, value):
        self.com_object.ListIndex = value

    @property
    def listindex(self):
        """Alias for ListIndex"""
        return self.ListIndex

    @listindex.setter
    def listindex(self, value):
        """Alias for ListIndex.setter"""
        self.ListIndex = value

    @property
    def list_index(self):
        """Alias for ListIndex"""
        return self.ListIndex

    @list_index.setter
    def list_index(self, value):
        """Alias for ListIndex.setter"""
        self.ListIndex = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def MaxLength(self):
        return self.com_object.MaxLength

    @MaxLength.setter
    def MaxLength(self, value):
        self.com_object.MaxLength = value

    @property
    def maxlength(self):
        """Alias for MaxLength"""
        return self.MaxLength

    @maxlength.setter
    def maxlength(self, value):
        """Alias for MaxLength.setter"""
        self.MaxLength = value

    @property
    def max_length(self):
        """Alias for MaxLength"""
        return self.MaxLength

    @max_length.setter
    def max_length(self, value):
        """Alias for MaxLength.setter"""
        self.MaxLength = value

    @property
    def MouseIcon(self):
        return self.com_object.MouseIcon

    @MouseIcon.setter
    def MouseIcon(self, value):
        self.com_object.MouseIcon = value

    @property
    def mouseicon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouseicon.setter
    def mouseicon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def mouse_icon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouse_icon.setter
    def mouse_icon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def MousePointer(self):
        return OlMousePointer(self.com_object.MousePointer)

    @MousePointer.setter
    def MousePointer(self, value):
        self.com_object.MousePointer = value

    @property
    def mousepointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mousepointer.setter
    def mousepointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def mouse_pointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mouse_pointer.setter
    def mouse_pointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def SelectionMargin(self):
        return self.com_object.SelectionMargin

    @SelectionMargin.setter
    def SelectionMargin(self, value):
        self.com_object.SelectionMargin = value

    @property
    def selectionmargin(self):
        """Alias for SelectionMargin"""
        return self.SelectionMargin

    @selectionmargin.setter
    def selectionmargin(self, value):
        """Alias for SelectionMargin.setter"""
        self.SelectionMargin = value

    @property
    def selection_margin(self):
        """Alias for SelectionMargin"""
        return self.SelectionMargin

    @selection_margin.setter
    def selection_margin(self, value):
        """Alias for SelectionMargin.setter"""
        self.SelectionMargin = value

    @property
    def SelLength(self):
        return self.com_object.SelLength

    @SelLength.setter
    def SelLength(self, value):
        self.com_object.SelLength = value

    @property
    def sellength(self):
        """Alias for SelLength"""
        return self.SelLength

    @sellength.setter
    def sellength(self, value):
        """Alias for SelLength.setter"""
        self.SelLength = value

    @property
    def sel_length(self):
        """Alias for SelLength"""
        return self.SelLength

    @sel_length.setter
    def sel_length(self, value):
        """Alias for SelLength.setter"""
        self.SelLength = value

    @property
    def SelStart(self):
        return self.com_object.SelStart

    @SelStart.setter
    def SelStart(self, value):
        self.com_object.SelStart = value

    @property
    def selstart(self):
        """Alias for SelStart"""
        return self.SelStart

    @selstart.setter
    def selstart(self, value):
        """Alias for SelStart.setter"""
        self.SelStart = value

    @property
    def sel_start(self):
        """Alias for SelStart"""
        return self.SelStart

    @sel_start.setter
    def sel_start(self, value):
        """Alias for SelStart.setter"""
        self.SelStart = value

    @property
    def SelText(self):
        return self.com_object.SelText

    @property
    def seltext(self):
        """Alias for SelText"""
        return self.SelText

    @property
    def sel_text(self):
        """Alias for SelText"""
        return self.SelText

    @property
    def Style(self):
        return OlComboBoxStyle(self.com_object.Style)

    @Style.setter
    def Style(self, value):
        self.com_object.Style = value

    @property
    def style(self):
        """Alias for Style"""
        return self.Style

    @style.setter
    def style(self, value):
        """Alias for Style.setter"""
        self.Style = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def TextAlign(self):
        return OlTextAlign(self.com_object.TextAlign)

    @TextAlign.setter
    def TextAlign(self, value):
        self.com_object.TextAlign = value

    @property
    def textalign(self):
        """Alias for TextAlign"""
        return self.TextAlign

    @textalign.setter
    def textalign(self, value):
        """Alias for TextAlign.setter"""
        self.TextAlign = value

    @property
    def text_align(self):
        """Alias for TextAlign"""
        return self.TextAlign

    @text_align.setter
    def text_align(self, value):
        """Alias for TextAlign.setter"""
        self.TextAlign = value

    @property
    def TopIndex(self):
        return self.com_object.TopIndex

    @TopIndex.setter
    def TopIndex(self, value):
        self.com_object.TopIndex = value

    @property
    def topindex(self):
        """Alias for TopIndex"""
        return self.TopIndex

    @topindex.setter
    def topindex(self, value):
        """Alias for TopIndex.setter"""
        self.TopIndex = value

    @property
    def top_index(self):
        """Alias for TopIndex"""
        return self.TopIndex

    @top_index.setter
    def top_index(self, value):
        """Alias for TopIndex.setter"""
        self.TopIndex = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    def AddItem(self, ItemText=None, Index=None):
        arguments = com_arguments([unwrap(a) for a in [ItemText, Index]])
        self.com_object.AddItem(*arguments)

    def additem(self, ItemText=None, Index=None):
        """Alias for AddItem"""
        arguments = [ItemText, Index]
        return self.AddItem(*arguments)

    def add_item(self, ItemText=None, Index=None):
        """Alias for AddItem"""
        arguments = [ItemText, Index]
        return self.AddItem(*arguments)

    def Clear(self):
        self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Cut(self):
        self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def DropDown(self):
        self.com_object.DropDown()

    def dropdown(self):
        """Alias for DropDown"""
        return self.DropDown()

    def drop_down(self):
        """Alias for DropDown"""
        return self.DropDown()

    def GetItem(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.GetItem(*arguments)

    def getitem(self, Index=None):
        """Alias for GetItem"""
        arguments = [Index]
        return self.GetItem(*arguments)

    def get_item(self, Index=None):
        """Alias for GetItem"""
        arguments = [Index]
        return self.GetItem(*arguments)

    def Paste(self):
        self.com_object.Paste()

    def paste(self):
        """Alias for Paste"""
        return self.Paste()

    def RemoveItem(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.RemoveItem(*arguments)

    def removeitem(self, Index=None):
        """Alias for RemoveItem"""
        arguments = [Index]
        return self.RemoveItem(*arguments)

    def remove_item(self, Index=None):
        """Alias for RemoveItem"""
        arguments = [Index]
        return self.RemoveItem(*arguments)

    def SetItem(self, Index=None, Item=None):
        arguments = com_arguments([unwrap(a) for a in [Index, Item]])
        self.com_object.SetItem(*arguments)

    def setitem(self, Index=None, Item=None):
        """Alias for SetItem"""
        arguments = [Index, Item]
        return self.SetItem(*arguments)

    def set_item(self, Index=None, Item=None):
        """Alias for SetItem"""
        arguments = [Index, Item]
        return self.SetItem(*arguments)


class OlkCommandButton:

    def __init__(self, olkcommandbutton=None):
        self.com_object= olkcommandbutton

    @property
    def Accelerator(self):
        return self.com_object.Accelerator

    @Accelerator.setter
    def Accelerator(self, value):
        self.com_object.Accelerator = value

    @property
    def accelerator(self):
        """Alias for Accelerator"""
        return self.Accelerator

    @accelerator.setter
    def accelerator(self, value):
        """Alias for Accelerator.setter"""
        self.Accelerator = value

    @property
    def AutoSize(self):
        return self.com_object.AutoSize

    @AutoSize.setter
    def AutoSize(self, value):
        self.com_object.AutoSize = value

    @property
    def autosize(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @autosize.setter
    def autosize(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def auto_size(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @auto_size.setter
    def auto_size(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    @property
    def DisplayDropArrow(self):
        return self.com_object.DisplayDropArrow

    @DisplayDropArrow.setter
    def DisplayDropArrow(self, value):
        self.com_object.DisplayDropArrow = value

    @property
    def displaydroparrow(self):
        """Alias for DisplayDropArrow"""
        return self.DisplayDropArrow

    @displaydroparrow.setter
    def displaydroparrow(self, value):
        """Alias for DisplayDropArrow.setter"""
        self.DisplayDropArrow = value

    @property
    def display_drop_arrow(self):
        """Alias for DisplayDropArrow"""
        return self.DisplayDropArrow

    @display_drop_arrow.setter
    def display_drop_arrow(self, value):
        """Alias for DisplayDropArrow.setter"""
        self.DisplayDropArrow = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Font(self):
        return self.com_object.Font

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def MouseIcon(self):
        return self.com_object.MouseIcon

    @MouseIcon.setter
    def MouseIcon(self, value):
        self.com_object.MouseIcon = value

    @property
    def mouseicon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouseicon.setter
    def mouseicon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def mouse_icon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouse_icon.setter
    def mouse_icon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def MousePointer(self):
        return OlMousePointer(self.com_object.MousePointer)

    @MousePointer.setter
    def MousePointer(self, value):
        self.com_object.MousePointer = value

    @property
    def mousepointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mousepointer.setter
    def mousepointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def mouse_pointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mouse_pointer.setter
    def mouse_pointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def Picture(self):
        return self.com_object.Picture

    @Picture.setter
    def Picture(self, value):
        self.com_object.Picture = value

    @property
    def picture(self):
        """Alias for Picture"""
        return self.Picture

    @picture.setter
    def picture(self, value):
        """Alias for Picture.setter"""
        self.Picture = value

    @property
    def PictureAlignment(self):
        return OlPictureAlignment(self.com_object.PictureAlignment)

    @PictureAlignment.setter
    def PictureAlignment(self, value):
        self.com_object.PictureAlignment = value

    @property
    def picturealignment(self):
        """Alias for PictureAlignment"""
        return self.PictureAlignment

    @picturealignment.setter
    def picturealignment(self, value):
        """Alias for PictureAlignment.setter"""
        self.PictureAlignment = value

    @property
    def picture_alignment(self):
        """Alias for PictureAlignment"""
        return self.PictureAlignment

    @picture_alignment.setter
    def picture_alignment(self, value):
        """Alias for PictureAlignment.setter"""
        self.PictureAlignment = value

    @property
    def TextAlign(self):
        return OlTextAlign(self.com_object.TextAlign)

    @TextAlign.setter
    def TextAlign(self, value):
        self.com_object.TextAlign = value

    @property
    def textalign(self):
        """Alias for TextAlign"""
        return self.TextAlign

    @textalign.setter
    def textalign(self, value):
        """Alias for TextAlign.setter"""
        self.TextAlign = value

    @property
    def text_align(self):
        """Alias for TextAlign"""
        return self.TextAlign

    @text_align.setter
    def text_align(self, value):
        """Alias for TextAlign.setter"""
        self.TextAlign = value

    @property
    def WordWrap(self):
        return self.com_object.WordWrap

    @WordWrap.setter
    def WordWrap(self, value):
        self.com_object.WordWrap = value

    @property
    def wordwrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @wordwrap.setter
    def wordwrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value

    @property
    def word_wrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @word_wrap.setter
    def word_wrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value


class OlkContactPhoto:

    def __init__(self, olkcontactphoto=None):
        self.com_object= olkcontactphoto

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def MouseIcon(self):
        return self.com_object.MouseIcon

    @MouseIcon.setter
    def MouseIcon(self, value):
        self.com_object.MouseIcon = value

    @property
    def mouseicon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouseicon.setter
    def mouseicon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def mouse_icon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouse_icon.setter
    def mouse_icon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def MousePointer(self):
        return OlMousePointer(self.com_object.MousePointer)

    @MousePointer.setter
    def MousePointer(self, value):
        self.com_object.MousePointer = value

    @property
    def mousepointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mousepointer.setter
    def mousepointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def mouse_pointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mouse_pointer.setter
    def mouse_pointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value


class OlkControl:

    def __init__(self, olkcontrol=None):
        self.com_object= olkcontrol

    @property
    def ControlProperty(self):
        return self.com_object.ControlProperty

    @ControlProperty.setter
    def ControlProperty(self, value):
        self.com_object.ControlProperty = value

    @property
    def controlproperty(self):
        """Alias for ControlProperty"""
        return self.ControlProperty

    @controlproperty.setter
    def controlproperty(self, value):
        """Alias for ControlProperty.setter"""
        self.ControlProperty = value

    @property
    def control_property(self):
        """Alias for ControlProperty"""
        return self.ControlProperty

    @control_property.setter
    def control_property(self, value):
        """Alias for ControlProperty.setter"""
        self.ControlProperty = value

    @property
    def EnableAutoLayout(self):
        return self.com_object.EnableAutoLayout

    @EnableAutoLayout.setter
    def EnableAutoLayout(self, value):
        self.com_object.EnableAutoLayout = value

    @property
    def enableautolayout(self):
        """Alias for EnableAutoLayout"""
        return self.EnableAutoLayout

    @enableautolayout.setter
    def enableautolayout(self, value):
        """Alias for EnableAutoLayout.setter"""
        self.EnableAutoLayout = value

    @property
    def enable_auto_layout(self):
        """Alias for EnableAutoLayout"""
        return self.EnableAutoLayout

    @enable_auto_layout.setter
    def enable_auto_layout(self, value):
        """Alias for EnableAutoLayout.setter"""
        self.EnableAutoLayout = value

    @property
    def Format(self):
        return self.com_object.Format

    @Format.setter
    def Format(self, value):
        self.com_object.Format = value

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @format.setter
    def format(self, value):
        """Alias for Format.setter"""
        self.Format = value

    @property
    def HorizontalLayout(self):
        return OlHorizontalLayout(self.com_object.HorizontalLayout)

    @HorizontalLayout.setter
    def HorizontalLayout(self, value):
        self.com_object.HorizontalLayout = value

    @property
    def horizontallayout(self):
        """Alias for HorizontalLayout"""
        return self.HorizontalLayout

    @horizontallayout.setter
    def horizontallayout(self, value):
        """Alias for HorizontalLayout.setter"""
        self.HorizontalLayout = value

    @property
    def horizontal_layout(self):
        """Alias for HorizontalLayout"""
        return self.HorizontalLayout

    @horizontal_layout.setter
    def horizontal_layout(self, value):
        """Alias for HorizontalLayout.setter"""
        self.HorizontalLayout = value

    @property
    def ItemProperty(self):
        return self.com_object.ItemProperty

    @ItemProperty.setter
    def ItemProperty(self, value):
        self.com_object.ItemProperty = value

    @property
    def itemproperty(self):
        """Alias for ItemProperty"""
        return self.ItemProperty

    @itemproperty.setter
    def itemproperty(self, value):
        """Alias for ItemProperty.setter"""
        self.ItemProperty = value

    @property
    def item_property(self):
        """Alias for ItemProperty"""
        return self.ItemProperty

    @item_property.setter
    def item_property(self, value):
        """Alias for ItemProperty.setter"""
        self.ItemProperty = value

    @property
    def MinimumHeight(self):
        return self.com_object.MinimumHeight

    @MinimumHeight.setter
    def MinimumHeight(self, value):
        self.com_object.MinimumHeight = value

    @property
    def minimumheight(self):
        """Alias for MinimumHeight"""
        return self.MinimumHeight

    @minimumheight.setter
    def minimumheight(self, value):
        """Alias for MinimumHeight.setter"""
        self.MinimumHeight = value

    @property
    def minimum_height(self):
        """Alias for MinimumHeight"""
        return self.MinimumHeight

    @minimum_height.setter
    def minimum_height(self, value):
        """Alias for MinimumHeight.setter"""
        self.MinimumHeight = value

    @property
    def MinimumWidth(self):
        return self.com_object.MinimumWidth

    @MinimumWidth.setter
    def MinimumWidth(self, value):
        self.com_object.MinimumWidth = value

    @property
    def minimumwidth(self):
        """Alias for MinimumWidth"""
        return self.MinimumWidth

    @minimumwidth.setter
    def minimumwidth(self, value):
        """Alias for MinimumWidth.setter"""
        self.MinimumWidth = value

    @property
    def minimum_width(self):
        """Alias for MinimumWidth"""
        return self.MinimumWidth

    @minimum_width.setter
    def minimum_width(self, value):
        """Alias for MinimumWidth.setter"""
        self.MinimumWidth = value

    @property
    def PossibleValues(self):
        return self.com_object.PossibleValues

    @PossibleValues.setter
    def PossibleValues(self, value):
        self.com_object.PossibleValues = value

    @property
    def possiblevalues(self):
        """Alias for PossibleValues"""
        return self.PossibleValues

    @possiblevalues.setter
    def possiblevalues(self, value):
        """Alias for PossibleValues.setter"""
        self.PossibleValues = value

    @property
    def possible_values(self):
        """Alias for PossibleValues"""
        return self.PossibleValues

    @possible_values.setter
    def possible_values(self, value):
        """Alias for PossibleValues.setter"""
        self.PossibleValues = value

    @property
    def VerticalLayout(self):
        return OlVerticalLayout(self.com_object.VerticalLayout)

    @VerticalLayout.setter
    def VerticalLayout(self, value):
        self.com_object.VerticalLayout = value

    @property
    def verticallayout(self):
        """Alias for VerticalLayout"""
        return self.VerticalLayout

    @verticallayout.setter
    def verticallayout(self, value):
        """Alias for VerticalLayout.setter"""
        self.VerticalLayout = value

    @property
    def vertical_layout(self):
        """Alias for VerticalLayout"""
        return self.VerticalLayout

    @vertical_layout.setter
    def vertical_layout(self, value):
        """Alias for VerticalLayout.setter"""
        self.VerticalLayout = value


class OlkDateControl:

    def __init__(self, olkdatecontrol=None):
        self.com_object= olkdatecontrol

    @property
    def AutoSize(self):
        return self.com_object.AutoSize

    @AutoSize.setter
    def AutoSize(self, value):
        self.com_object.AutoSize = value

    @property
    def autosize(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @autosize.setter
    def autosize(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def auto_size(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @auto_size.setter
    def auto_size(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def AutoWordSelect(self):
        return self.com_object.AutoWordSelect

    @AutoWordSelect.setter
    def AutoWordSelect(self, value):
        self.com_object.AutoWordSelect = value

    @property
    def autowordselect(self):
        """Alias for AutoWordSelect"""
        return self.AutoWordSelect

    @autowordselect.setter
    def autowordselect(self, value):
        """Alias for AutoWordSelect.setter"""
        self.AutoWordSelect = value

    @property
    def auto_word_select(self):
        """Alias for AutoWordSelect"""
        return self.AutoWordSelect

    @auto_word_select.setter
    def auto_word_select(self, value):
        """Alias for AutoWordSelect.setter"""
        self.AutoWordSelect = value

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BackStyle(self):
        return olBackStyle(self.com_object.BackStyle)

    @BackStyle.setter
    def BackStyle(self, value):
        self.com_object.BackStyle = value

    @property
    def backstyle(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @backstyle.setter
    def backstyle(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def back_style(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @back_style.setter
    def back_style(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def Date(self):
        return self.com_object.Date

    @Date.setter
    def Date(self, value):
        self.com_object.Date = value

    @property
    def date(self):
        """Alias for Date"""
        return self.Date

    @date.setter
    def date(self, value):
        """Alias for Date.setter"""
        self.Date = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def EnterFieldBehavior(self):
        return olEnterFieldBehavior(self.com_object.EnterFieldBehavior)

    @EnterFieldBehavior.setter
    def EnterFieldBehavior(self, value):
        self.com_object.EnterFieldBehavior = value

    @property
    def enterfieldbehavior(self):
        """Alias for EnterFieldBehavior"""
        return self.EnterFieldBehavior

    @enterfieldbehavior.setter
    def enterfieldbehavior(self, value):
        """Alias for EnterFieldBehavior.setter"""
        self.EnterFieldBehavior = value

    @property
    def enter_field_behavior(self):
        """Alias for EnterFieldBehavior"""
        return self.EnterFieldBehavior

    @enter_field_behavior.setter
    def enter_field_behavior(self, value):
        """Alias for EnterFieldBehavior.setter"""
        self.EnterFieldBehavior = value

    @property
    def Font(self):
        return self.com_object.Font

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def ForeColor(self):
        return self.com_object.ForeColor

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def HideSelection(self):
        return self.com_object.HideSelection

    @HideSelection.setter
    def HideSelection(self, value):
        self.com_object.HideSelection = value

    @property
    def hideselection(self):
        """Alias for HideSelection"""
        return self.HideSelection

    @hideselection.setter
    def hideselection(self, value):
        """Alias for HideSelection.setter"""
        self.HideSelection = value

    @property
    def hide_selection(self):
        """Alias for HideSelection"""
        return self.HideSelection

    @hide_selection.setter
    def hide_selection(self, value):
        """Alias for HideSelection.setter"""
        self.HideSelection = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def MouseIcon(self):
        return self.com_object.MouseIcon

    @MouseIcon.setter
    def MouseIcon(self, value):
        self.com_object.MouseIcon = value

    @property
    def mouseicon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouseicon.setter
    def mouseicon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def mouse_icon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouse_icon.setter
    def mouse_icon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def MousePointer(self):
        return OlMousePointer(self.com_object.MousePointer)

    @MousePointer.setter
    def MousePointer(self, value):
        self.com_object.MousePointer = value

    @property
    def mousepointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mousepointer.setter
    def mousepointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def mouse_pointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mouse_pointer.setter
    def mouse_pointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def ShowNoneButton(self):
        return self.com_object.ShowNoneButton

    @ShowNoneButton.setter
    def ShowNoneButton(self, value):
        self.com_object.ShowNoneButton = value

    @property
    def shownonebutton(self):
        """Alias for ShowNoneButton"""
        return self.ShowNoneButton

    @shownonebutton.setter
    def shownonebutton(self, value):
        """Alias for ShowNoneButton.setter"""
        self.ShowNoneButton = value

    @property
    def show_none_button(self):
        """Alias for ShowNoneButton"""
        return self.ShowNoneButton

    @show_none_button.setter
    def show_none_button(self, value):
        """Alias for ShowNoneButton.setter"""
        self.ShowNoneButton = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def TextAlign(self):
        return OlTextAlign(self.com_object.TextAlign)

    @TextAlign.setter
    def TextAlign(self, value):
        self.com_object.TextAlign = value

    @property
    def textalign(self):
        """Alias for TextAlign"""
        return self.TextAlign

    @textalign.setter
    def textalign(self, value):
        """Alias for TextAlign.setter"""
        self.TextAlign = value

    @property
    def text_align(self):
        """Alias for TextAlign"""
        return self.TextAlign

    @text_align.setter
    def text_align(self, value):
        """Alias for TextAlign.setter"""
        self.TextAlign = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    def DropDown(self):
        self.com_object.DropDown()

    def dropdown(self):
        """Alias for DropDown"""
        return self.DropDown()

    def drop_down(self):
        """Alias for DropDown"""
        return self.DropDown()


class OlkFrameHeader:

    def __init__(self, olkframeheader=None):
        self.com_object= olkframeheader

    @property
    def Alignment(self):
        return olAlignment(self.com_object.Alignment)

    @Alignment.setter
    def Alignment(self, value):
        self.com_object.Alignment = value

    @property
    def alignment(self):
        """Alias for Alignment"""
        return self.Alignment

    @alignment.setter
    def alignment(self, value):
        """Alias for Alignment.setter"""
        self.Alignment = value

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Font(self):
        return self.com_object.Font

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def ForeColor(self):
        return self.com_object.ForeColor

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def MouseIcon(self):
        return self.com_object.MouseIcon

    @MouseIcon.setter
    def MouseIcon(self, value):
        self.com_object.MouseIcon = value

    @property
    def mouseicon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouseicon.setter
    def mouseicon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def mouse_icon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouse_icon.setter
    def mouse_icon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def MousePointer(self):
        return OlMousePointer(self.com_object.MousePointer)

    @MousePointer.setter
    def MousePointer(self, value):
        self.com_object.MousePointer = value

    @property
    def mousepointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mousepointer.setter
    def mousepointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def mouse_pointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mouse_pointer.setter
    def mouse_pointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value


class OlkInfoBar:

    def __init__(self, olkinfobar=None):
        self.com_object= olkinfobar

    @property
    def MouseIcon(self):
        return self.com_object.MouseIcon

    @MouseIcon.setter
    def MouseIcon(self, value):
        self.com_object.MouseIcon = value

    @property
    def mouseicon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouseicon.setter
    def mouseicon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def mouse_icon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouse_icon.setter
    def mouse_icon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def MousePointer(self):
        return OlMousePointer(self.com_object.MousePointer)

    @MousePointer.setter
    def MousePointer(self, value):
        self.com_object.MousePointer = value

    @property
    def mousepointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mousepointer.setter
    def mousepointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def mouse_pointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mouse_pointer.setter
    def mouse_pointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value


class OlkLabel:

    def __init__(self, olklabel=None):
        self.com_object= olklabel

    @property
    def Accelerator(self):
        return self.com_object.Accelerator

    @Accelerator.setter
    def Accelerator(self, value):
        self.com_object.Accelerator = value

    @property
    def accelerator(self):
        """Alias for Accelerator"""
        return self.Accelerator

    @accelerator.setter
    def accelerator(self, value):
        """Alias for Accelerator.setter"""
        self.Accelerator = value

    @property
    def AutoSize(self):
        return self.com_object.AutoSize

    @AutoSize.setter
    def AutoSize(self, value):
        self.com_object.AutoSize = value

    @property
    def autosize(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @autosize.setter
    def autosize(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def auto_size(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @auto_size.setter
    def auto_size(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BackStyle(self):
        return olBackStyle(self.com_object.BackStyle)

    @BackStyle.setter
    def BackStyle(self, value):
        self.com_object.BackStyle = value

    @property
    def backstyle(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @backstyle.setter
    def backstyle(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def back_style(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @back_style.setter
    def back_style(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def BorderStyle(self):
        return OlBorderStyle(self.com_object.BorderStyle)

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Font(self):
        return self.com_object.Font

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def ForeColor(self):
        return self.com_object.ForeColor

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def MouseIcon(self):
        return self.com_object.MouseIcon

    @MouseIcon.setter
    def MouseIcon(self, value):
        self.com_object.MouseIcon = value

    @property
    def mouseicon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouseicon.setter
    def mouseicon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def mouse_icon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouse_icon.setter
    def mouse_icon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def MousePointer(self):
        return OlMousePointer(self.com_object.MousePointer)

    @MousePointer.setter
    def MousePointer(self, value):
        self.com_object.MousePointer = value

    @property
    def mousepointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mousepointer.setter
    def mousepointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def mouse_pointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mouse_pointer.setter
    def mouse_pointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def TextAlign(self):
        return OlTextAlign(self.com_object.TextAlign)

    @TextAlign.setter
    def TextAlign(self, value):
        self.com_object.TextAlign = value

    @property
    def textalign(self):
        """Alias for TextAlign"""
        return self.TextAlign

    @textalign.setter
    def textalign(self, value):
        """Alias for TextAlign.setter"""
        self.TextAlign = value

    @property
    def text_align(self):
        """Alias for TextAlign"""
        return self.TextAlign

    @text_align.setter
    def text_align(self, value):
        """Alias for TextAlign.setter"""
        self.TextAlign = value

    @property
    def UseHeaderColor(self):
        return self.com_object.UseHeaderColor

    @UseHeaderColor.setter
    def UseHeaderColor(self, value):
        self.com_object.UseHeaderColor = value

    @property
    def useheadercolor(self):
        """Alias for UseHeaderColor"""
        return self.UseHeaderColor

    @useheadercolor.setter
    def useheadercolor(self, value):
        """Alias for UseHeaderColor.setter"""
        self.UseHeaderColor = value

    @property
    def use_header_color(self):
        """Alias for UseHeaderColor"""
        return self.UseHeaderColor

    @use_header_color.setter
    def use_header_color(self, value):
        """Alias for UseHeaderColor.setter"""
        self.UseHeaderColor = value

    @property
    def WordWrap(self):
        return self.com_object.WordWrap

    @WordWrap.setter
    def WordWrap(self, value):
        self.com_object.WordWrap = value

    @property
    def wordwrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @wordwrap.setter
    def wordwrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value

    @property
    def word_wrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @word_wrap.setter
    def word_wrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value


class OlkListBox:

    def __init__(self, olklistbox=None):
        self.com_object= olklistbox

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BorderStyle(self):
        return OlBorderStyle(self.com_object.BorderStyle)

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Font(self):
        return self.com_object.Font

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def ForeColor(self):
        return self.com_object.ForeColor

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def ListCount(self):
        return self.com_object.ListCount

    @property
    def listcount(self):
        """Alias for ListCount"""
        return self.ListCount

    @property
    def list_count(self):
        """Alias for ListCount"""
        return self.ListCount

    @property
    def ListIndex(self):
        return self.com_object.ListIndex

    @ListIndex.setter
    def ListIndex(self, value):
        self.com_object.ListIndex = value

    @property
    def listindex(self):
        """Alias for ListIndex"""
        return self.ListIndex

    @listindex.setter
    def listindex(self, value):
        """Alias for ListIndex.setter"""
        self.ListIndex = value

    @property
    def list_index(self):
        """Alias for ListIndex"""
        return self.ListIndex

    @list_index.setter
    def list_index(self, value):
        """Alias for ListIndex.setter"""
        self.ListIndex = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def MatchEntry(self):
        return olMatchEntry(self.com_object.MatchEntry)

    @MatchEntry.setter
    def MatchEntry(self, value):
        self.com_object.MatchEntry = value

    @property
    def matchentry(self):
        """Alias for MatchEntry"""
        return self.MatchEntry

    @matchentry.setter
    def matchentry(self, value):
        """Alias for MatchEntry.setter"""
        self.MatchEntry = value

    @property
    def match_entry(self):
        """Alias for MatchEntry"""
        return self.MatchEntry

    @match_entry.setter
    def match_entry(self, value):
        """Alias for MatchEntry.setter"""
        self.MatchEntry = value

    @property
    def MouseIcon(self):
        return self.com_object.MouseIcon

    @MouseIcon.setter
    def MouseIcon(self, value):
        self.com_object.MouseIcon = value

    @property
    def mouseicon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouseicon.setter
    def mouseicon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def mouse_icon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouse_icon.setter
    def mouse_icon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def MousePointer(self):
        return OlMousePointer(self.com_object.MousePointer)

    @MousePointer.setter
    def MousePointer(self, value):
        self.com_object.MousePointer = value

    @property
    def mousepointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mousepointer.setter
    def mousepointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def mouse_pointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mouse_pointer.setter
    def mouse_pointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def MultiSelect(self):
        return OlMultiSelect(self.com_object.MultiSelect)

    @MultiSelect.setter
    def MultiSelect(self, value):
        self.com_object.MultiSelect = value

    @property
    def multiselect(self):
        """Alias for MultiSelect"""
        return self.MultiSelect

    @multiselect.setter
    def multiselect(self, value):
        """Alias for MultiSelect.setter"""
        self.MultiSelect = value

    @property
    def multi_select(self):
        """Alias for MultiSelect"""
        return self.MultiSelect

    @multi_select.setter
    def multi_select(self, value):
        """Alias for MultiSelect.setter"""
        self.MultiSelect = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def TextAlign(self):
        return OlTextAlign(self.com_object.TextAlign)

    @TextAlign.setter
    def TextAlign(self, value):
        self.com_object.TextAlign = value

    @property
    def textalign(self):
        """Alias for TextAlign"""
        return self.TextAlign

    @textalign.setter
    def textalign(self, value):
        """Alias for TextAlign.setter"""
        self.TextAlign = value

    @property
    def text_align(self):
        """Alias for TextAlign"""
        return self.TextAlign

    @text_align.setter
    def text_align(self, value):
        """Alias for TextAlign.setter"""
        self.TextAlign = value

    @property
    def TopIndex(self):
        return self.com_object.TopIndex

    @TopIndex.setter
    def TopIndex(self, value):
        self.com_object.TopIndex = value

    @property
    def topindex(self):
        """Alias for TopIndex"""
        return self.TopIndex

    @topindex.setter
    def topindex(self, value):
        """Alias for TopIndex.setter"""
        self.TopIndex = value

    @property
    def top_index(self):
        """Alias for TopIndex"""
        return self.TopIndex

    @top_index.setter
    def top_index(self, value):
        """Alias for TopIndex.setter"""
        self.TopIndex = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    def AddItem(self, ItemText=None, Index=None):
        arguments = com_arguments([unwrap(a) for a in [ItemText, Index]])
        self.com_object.AddItem(*arguments)

    def additem(self, ItemText=None, Index=None):
        """Alias for AddItem"""
        arguments = [ItemText, Index]
        return self.AddItem(*arguments)

    def add_item(self, ItemText=None, Index=None):
        """Alias for AddItem"""
        arguments = [ItemText, Index]
        return self.AddItem(*arguments)

    def Clear(self):
        self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def GetItem(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.GetItem(*arguments)

    def getitem(self, Index=None):
        """Alias for GetItem"""
        arguments = [Index]
        return self.GetItem(*arguments)

    def get_item(self, Index=None):
        """Alias for GetItem"""
        arguments = [Index]
        return self.GetItem(*arguments)

    def GetSelected(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.GetSelected(*arguments)

    def getselected(self, Index=None):
        """Alias for GetSelected"""
        arguments = [Index]
        return self.GetSelected(*arguments)

    def get_selected(self, Index=None):
        """Alias for GetSelected"""
        arguments = [Index]
        return self.GetSelected(*arguments)

    def RemoveItem(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.RemoveItem(*arguments)

    def removeitem(self, Index=None):
        """Alias for RemoveItem"""
        arguments = [Index]
        return self.RemoveItem(*arguments)

    def remove_item(self, Index=None):
        """Alias for RemoveItem"""
        arguments = [Index]
        return self.RemoveItem(*arguments)

    def SetItem(self, Index=None, Item=None):
        arguments = com_arguments([unwrap(a) for a in [Index, Item]])
        self.com_object.SetItem(*arguments)

    def setitem(self, Index=None, Item=None):
        """Alias for SetItem"""
        arguments = [Index, Item]
        return self.SetItem(*arguments)

    def set_item(self, Index=None, Item=None):
        """Alias for SetItem"""
        arguments = [Index, Item]
        return self.SetItem(*arguments)

    def SetSelected(self, Index=None, Selected=None):
        arguments = com_arguments([unwrap(a) for a in [Index, Selected]])
        self.com_object.SetSelected(*arguments)

    def setselected(self, Index=None, Selected=None):
        """Alias for SetSelected"""
        arguments = [Index, Selected]
        return self.SetSelected(*arguments)

    def set_selected(self, Index=None, Selected=None):
        """Alias for SetSelected"""
        arguments = [Index, Selected]
        return self.SetSelected(*arguments)


class OlkOptionButton:

    def __init__(self, olkoptionbutton=None):
        self.com_object= olkoptionbutton

    @property
    def Accelerator(self):
        return self.com_object.Accelerator

    @Accelerator.setter
    def Accelerator(self, value):
        self.com_object.Accelerator = value

    @property
    def accelerator(self):
        """Alias for Accelerator"""
        return self.Accelerator

    @accelerator.setter
    def accelerator(self, value):
        """Alias for Accelerator.setter"""
        self.Accelerator = value

    @property
    def Alignment(self):
        return olAlignment(self.com_object.Alignment)

    @Alignment.setter
    def Alignment(self, value):
        self.com_object.Alignment = value

    @property
    def alignment(self):
        """Alias for Alignment"""
        return self.Alignment

    @alignment.setter
    def alignment(self, value):
        """Alias for Alignment.setter"""
        self.Alignment = value

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BackStyle(self):
        return olBackStyle(self.com_object.BackStyle)

    @BackStyle.setter
    def BackStyle(self, value):
        self.com_object.BackStyle = value

    @property
    def backstyle(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @backstyle.setter
    def backstyle(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def back_style(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @back_style.setter
    def back_style(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Font(self):
        return self.com_object.Font

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def ForeColor(self):
        return self.com_object.ForeColor

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def GroupName(self):
        return self.com_object.GroupName

    @GroupName.setter
    def GroupName(self, value):
        self.com_object.GroupName = value

    @property
    def groupname(self):
        """Alias for GroupName"""
        return self.GroupName

    @groupname.setter
    def groupname(self, value):
        """Alias for GroupName.setter"""
        self.GroupName = value

    @property
    def group_name(self):
        """Alias for GroupName"""
        return self.GroupName

    @group_name.setter
    def group_name(self, value):
        """Alias for GroupName.setter"""
        self.GroupName = value

    @property
    def MouseIcon(self):
        return self.com_object.MouseIcon

    @MouseIcon.setter
    def MouseIcon(self, value):
        self.com_object.MouseIcon = value

    @property
    def mouseicon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouseicon.setter
    def mouseicon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def mouse_icon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouse_icon.setter
    def mouse_icon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def MousePointer(self):
        return OlMousePointer(self.com_object.MousePointer)

    @MousePointer.setter
    def MousePointer(self, value):
        self.com_object.MousePointer = value

    @property
    def mousepointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mousepointer.setter
    def mousepointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def mouse_pointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mouse_pointer.setter
    def mouse_pointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    @property
    def WordWrap(self):
        return self.com_object.WordWrap

    @WordWrap.setter
    def WordWrap(self, value):
        self.com_object.WordWrap = value

    @property
    def wordwrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @wordwrap.setter
    def wordwrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value

    @property
    def word_wrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @word_wrap.setter
    def word_wrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value


class OlkPageControl:

    def __init__(self, olkpagecontrol=None):
        self.com_object= olkpagecontrol

    @property
    def Page(self):
        return OlPageType(self.com_object.Page)

    @Page.setter
    def Page(self, value):
        self.com_object.Page = value

    @property
    def page(self):
        """Alias for Page"""
        return self.Page

    @page.setter
    def page(self, value):
        """Alias for Page.setter"""
        self.Page = value


class OlkSenderPhoto:

    def __init__(self, olksenderphoto=None):
        self.com_object= olksenderphoto

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def MouseIcon(self):
        return self.com_object.MouseIcon

    @MouseIcon.setter
    def MouseIcon(self, value):
        self.com_object.MouseIcon = value

    @property
    def mouseicon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouseicon.setter
    def mouseicon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def mouse_icon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouse_icon.setter
    def mouse_icon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def MousePointer(self):
        return OlMousePointer(self.com_object.MousePointer)

    @MousePointer.setter
    def MousePointer(self, value):
        self.com_object.MousePointer = value

    @property
    def mousepointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mousepointer.setter
    def mousepointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def mouse_pointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mouse_pointer.setter
    def mouse_pointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def PreferredHeight(self):
        return self.com_object.PreferredHeight

    @property
    def preferredheight(self):
        """Alias for PreferredHeight"""
        return self.PreferredHeight

    @property
    def preferred_height(self):
        """Alias for PreferredHeight"""
        return self.PreferredHeight

    @property
    def PreferredWidth(self):
        return self.com_object.PreferredWidth

    @property
    def preferredwidth(self):
        """Alias for PreferredWidth"""
        return self.PreferredWidth

    @property
    def preferred_width(self):
        """Alias for PreferredWidth"""
        return self.PreferredWidth


class OlkTextBox:

    def __init__(self, olktextbox=None):
        self.com_object= olktextbox

    @property
    def AutoSize(self):
        return self.com_object.AutoSize

    @AutoSize.setter
    def AutoSize(self, value):
        self.com_object.AutoSize = value

    @property
    def autosize(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @autosize.setter
    def autosize(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def auto_size(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @auto_size.setter
    def auto_size(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def AutoTab(self):
        return self.com_object.AutoTab

    @AutoTab.setter
    def AutoTab(self, value):
        self.com_object.AutoTab = value

    @property
    def autotab(self):
        """Alias for AutoTab"""
        return self.AutoTab

    @autotab.setter
    def autotab(self, value):
        """Alias for AutoTab.setter"""
        self.AutoTab = value

    @property
    def auto_tab(self):
        """Alias for AutoTab"""
        return self.AutoTab

    @auto_tab.setter
    def auto_tab(self, value):
        """Alias for AutoTab.setter"""
        self.AutoTab = value

    @property
    def AutoWordSelect(self):
        return self.com_object.AutoWordSelect

    @AutoWordSelect.setter
    def AutoWordSelect(self, value):
        self.com_object.AutoWordSelect = value

    @property
    def autowordselect(self):
        """Alias for AutoWordSelect"""
        return self.AutoWordSelect

    @autowordselect.setter
    def autowordselect(self, value):
        """Alias for AutoWordSelect.setter"""
        self.AutoWordSelect = value

    @property
    def auto_word_select(self):
        """Alias for AutoWordSelect"""
        return self.AutoWordSelect

    @auto_word_select.setter
    def auto_word_select(self, value):
        """Alias for AutoWordSelect.setter"""
        self.AutoWordSelect = value

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BorderStyle(self):
        return OlBorderStyle(self.com_object.BorderStyle)

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def DragBehavior(self):
        return self.com_object.DragBehavior

    @DragBehavior.setter
    def DragBehavior(self, value):
        self.com_object.DragBehavior = value

    @property
    def dragbehavior(self):
        """Alias for DragBehavior"""
        return self.DragBehavior

    @dragbehavior.setter
    def dragbehavior(self, value):
        """Alias for DragBehavior.setter"""
        self.DragBehavior = value

    @property
    def drag_behavior(self):
        """Alias for DragBehavior"""
        return self.DragBehavior

    @drag_behavior.setter
    def drag_behavior(self, value):
        """Alias for DragBehavior.setter"""
        self.DragBehavior = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def EnterFieldBehavior(self):
        return olEnterFieldBehavior(self.com_object.EnterFieldBehavior)

    @EnterFieldBehavior.setter
    def EnterFieldBehavior(self, value):
        self.com_object.EnterFieldBehavior = value

    @property
    def enterfieldbehavior(self):
        """Alias for EnterFieldBehavior"""
        return self.EnterFieldBehavior

    @enterfieldbehavior.setter
    def enterfieldbehavior(self, value):
        """Alias for EnterFieldBehavior.setter"""
        self.EnterFieldBehavior = value

    @property
    def enter_field_behavior(self):
        """Alias for EnterFieldBehavior"""
        return self.EnterFieldBehavior

    @enter_field_behavior.setter
    def enter_field_behavior(self, value):
        """Alias for EnterFieldBehavior.setter"""
        self.EnterFieldBehavior = value

    @property
    def EnterKeyBehavior(self):
        return self.com_object.EnterKeyBehavior

    @EnterKeyBehavior.setter
    def EnterKeyBehavior(self, value):
        self.com_object.EnterKeyBehavior = value

    @property
    def enterkeybehavior(self):
        """Alias for EnterKeyBehavior"""
        return self.EnterKeyBehavior

    @enterkeybehavior.setter
    def enterkeybehavior(self, value):
        """Alias for EnterKeyBehavior.setter"""
        self.EnterKeyBehavior = value

    @property
    def enter_key_behavior(self):
        """Alias for EnterKeyBehavior"""
        return self.EnterKeyBehavior

    @enter_key_behavior.setter
    def enter_key_behavior(self, value):
        """Alias for EnterKeyBehavior.setter"""
        self.EnterKeyBehavior = value

    @property
    def Font(self):
        return self.com_object.Font

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def ForeColor(self):
        return self.com_object.ForeColor

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def HideSelection(self):
        return self.com_object.HideSelection

    @HideSelection.setter
    def HideSelection(self, value):
        self.com_object.HideSelection = value

    @property
    def hideselection(self):
        """Alias for HideSelection"""
        return self.HideSelection

    @hideselection.setter
    def hideselection(self, value):
        """Alias for HideSelection.setter"""
        self.HideSelection = value

    @property
    def hide_selection(self):
        """Alias for HideSelection"""
        return self.HideSelection

    @hide_selection.setter
    def hide_selection(self, value):
        """Alias for HideSelection.setter"""
        self.HideSelection = value

    @property
    def IntegralHeight(self):
        return self.com_object.IntegralHeight

    @IntegralHeight.setter
    def IntegralHeight(self, value):
        self.com_object.IntegralHeight = value

    @property
    def integralheight(self):
        """Alias for IntegralHeight"""
        return self.IntegralHeight

    @integralheight.setter
    def integralheight(self, value):
        """Alias for IntegralHeight.setter"""
        self.IntegralHeight = value

    @property
    def integral_height(self):
        """Alias for IntegralHeight"""
        return self.IntegralHeight

    @integral_height.setter
    def integral_height(self, value):
        """Alias for IntegralHeight.setter"""
        self.IntegralHeight = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def MaxLength(self):
        return self.com_object.MaxLength

    @MaxLength.setter
    def MaxLength(self, value):
        self.com_object.MaxLength = value

    @property
    def maxlength(self):
        """Alias for MaxLength"""
        return self.MaxLength

    @maxlength.setter
    def maxlength(self, value):
        """Alias for MaxLength.setter"""
        self.MaxLength = value

    @property
    def max_length(self):
        """Alias for MaxLength"""
        return self.MaxLength

    @max_length.setter
    def max_length(self, value):
        """Alias for MaxLength.setter"""
        self.MaxLength = value

    @property
    def MouseIcon(self):
        return self.com_object.MouseIcon

    @MouseIcon.setter
    def MouseIcon(self, value):
        self.com_object.MouseIcon = value

    @property
    def mouseicon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouseicon.setter
    def mouseicon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def mouse_icon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouse_icon.setter
    def mouse_icon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def MousePointer(self):
        return OlMousePointer(self.com_object.MousePointer)

    @MousePointer.setter
    def MousePointer(self, value):
        self.com_object.MousePointer = value

    @property
    def mousepointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mousepointer.setter
    def mousepointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def mouse_pointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mouse_pointer.setter
    def mouse_pointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def MultiLine(self):
        return self.com_object.MultiLine

    @MultiLine.setter
    def MultiLine(self, value):
        self.com_object.MultiLine = value

    @property
    def multiline(self):
        """Alias for MultiLine"""
        return self.MultiLine

    @multiline.setter
    def multiline(self, value):
        """Alias for MultiLine.setter"""
        self.MultiLine = value

    @property
    def multi_line(self):
        """Alias for MultiLine"""
        return self.MultiLine

    @multi_line.setter
    def multi_line(self, value):
        """Alias for MultiLine.setter"""
        self.MultiLine = value

    @property
    def PasswordChar(self):
        return self.com_object.PasswordChar

    @PasswordChar.setter
    def PasswordChar(self, value):
        self.com_object.PasswordChar = value

    @property
    def passwordchar(self):
        """Alias for PasswordChar"""
        return self.PasswordChar

    @passwordchar.setter
    def passwordchar(self, value):
        """Alias for PasswordChar.setter"""
        self.PasswordChar = value

    @property
    def password_char(self):
        """Alias for PasswordChar"""
        return self.PasswordChar

    @password_char.setter
    def password_char(self, value):
        """Alias for PasswordChar.setter"""
        self.PasswordChar = value

    @property
    def Scrollbars(self):
        return olScrollBars(self.com_object.Scrollbars)

    @Scrollbars.setter
    def Scrollbars(self, value):
        self.com_object.Scrollbars = value

    @property
    def scrollbars(self):
        """Alias for Scrollbars"""
        return self.Scrollbars

    @scrollbars.setter
    def scrollbars(self, value):
        """Alias for Scrollbars.setter"""
        self.Scrollbars = value

    @property
    def SelectionMargin(self):
        return self.com_object.SelectionMargin

    @SelectionMargin.setter
    def SelectionMargin(self, value):
        self.com_object.SelectionMargin = value

    @property
    def selectionmargin(self):
        """Alias for SelectionMargin"""
        return self.SelectionMargin

    @selectionmargin.setter
    def selectionmargin(self, value):
        """Alias for SelectionMargin.setter"""
        self.SelectionMargin = value

    @property
    def selection_margin(self):
        """Alias for SelectionMargin"""
        return self.SelectionMargin

    @selection_margin.setter
    def selection_margin(self, value):
        """Alias for SelectionMargin.setter"""
        self.SelectionMargin = value

    @property
    def SelLength(self):
        return self.com_object.SelLength

    @SelLength.setter
    def SelLength(self, value):
        self.com_object.SelLength = value

    @property
    def sellength(self):
        """Alias for SelLength"""
        return self.SelLength

    @sellength.setter
    def sellength(self, value):
        """Alias for SelLength.setter"""
        self.SelLength = value

    @property
    def sel_length(self):
        """Alias for SelLength"""
        return self.SelLength

    @sel_length.setter
    def sel_length(self, value):
        """Alias for SelLength.setter"""
        self.SelLength = value

    @property
    def SelStart(self):
        return self.com_object.SelStart

    @SelStart.setter
    def SelStart(self, value):
        self.com_object.SelStart = value

    @property
    def selstart(self):
        """Alias for SelStart"""
        return self.SelStart

    @selstart.setter
    def selstart(self, value):
        """Alias for SelStart.setter"""
        self.SelStart = value

    @property
    def sel_start(self):
        """Alias for SelStart"""
        return self.SelStart

    @sel_start.setter
    def sel_start(self, value):
        """Alias for SelStart.setter"""
        self.SelStart = value

    @property
    def SelText(self):
        return self.com_object.SelText

    @property
    def seltext(self):
        """Alias for SelText"""
        return self.SelText

    @property
    def sel_text(self):
        """Alias for SelText"""
        return self.SelText

    @property
    def TabKeyBehavior(self):
        return self.com_object.TabKeyBehavior

    @TabKeyBehavior.setter
    def TabKeyBehavior(self, value):
        self.com_object.TabKeyBehavior = value

    @property
    def tabkeybehavior(self):
        """Alias for TabKeyBehavior"""
        return self.TabKeyBehavior

    @tabkeybehavior.setter
    def tabkeybehavior(self, value):
        """Alias for TabKeyBehavior.setter"""
        self.TabKeyBehavior = value

    @property
    def tab_key_behavior(self):
        """Alias for TabKeyBehavior"""
        return self.TabKeyBehavior

    @tab_key_behavior.setter
    def tab_key_behavior(self, value):
        """Alias for TabKeyBehavior.setter"""
        self.TabKeyBehavior = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def TextAlign(self):
        return OlTextAlign(self.com_object.TextAlign)

    @TextAlign.setter
    def TextAlign(self, value):
        self.com_object.TextAlign = value

    @property
    def textalign(self):
        """Alias for TextAlign"""
        return self.TextAlign

    @textalign.setter
    def textalign(self, value):
        """Alias for TextAlign.setter"""
        self.TextAlign = value

    @property
    def text_align(self):
        """Alias for TextAlign"""
        return self.TextAlign

    @text_align.setter
    def text_align(self, value):
        """Alias for TextAlign.setter"""
        self.TextAlign = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    @property
    def WordWrap(self):
        return self.com_object.WordWrap

    @WordWrap.setter
    def WordWrap(self, value):
        self.com_object.WordWrap = value

    @property
    def wordwrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @wordwrap.setter
    def wordwrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value

    @property
    def word_wrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @word_wrap.setter
    def word_wrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value

    def Clear(self):
        self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Cut(self):
        self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def Paste(self):
        self.com_object.Paste()

    def paste(self):
        """Alias for Paste"""
        return self.Paste()


class OlkTimeControl:

    def __init__(self, olktimecontrol=None):
        self.com_object= olktimecontrol

    @property
    def AutoSize(self):
        return self.com_object.AutoSize

    @AutoSize.setter
    def AutoSize(self, value):
        self.com_object.AutoSize = value

    @property
    def autosize(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @autosize.setter
    def autosize(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def auto_size(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @auto_size.setter
    def auto_size(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def AutoWordSelect(self):
        return self.com_object.AutoWordSelect

    @AutoWordSelect.setter
    def AutoWordSelect(self, value):
        self.com_object.AutoWordSelect = value

    @property
    def autowordselect(self):
        """Alias for AutoWordSelect"""
        return self.AutoWordSelect

    @autowordselect.setter
    def autowordselect(self, value):
        """Alias for AutoWordSelect.setter"""
        self.AutoWordSelect = value

    @property
    def auto_word_select(self):
        """Alias for AutoWordSelect"""
        return self.AutoWordSelect

    @auto_word_select.setter
    def auto_word_select(self, value):
        """Alias for AutoWordSelect.setter"""
        self.AutoWordSelect = value

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BackStyle(self):
        return olBackStyle(self.com_object.BackStyle)

    @BackStyle.setter
    def BackStyle(self, value):
        self.com_object.BackStyle = value

    @property
    def backstyle(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @backstyle.setter
    def backstyle(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def back_style(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @back_style.setter
    def back_style(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def EnterFieldBehavior(self):
        return olEnterFieldBehavior(self.com_object.EnterFieldBehavior)

    @EnterFieldBehavior.setter
    def EnterFieldBehavior(self, value):
        self.com_object.EnterFieldBehavior = value

    @property
    def enterfieldbehavior(self):
        """Alias for EnterFieldBehavior"""
        return self.EnterFieldBehavior

    @enterfieldbehavior.setter
    def enterfieldbehavior(self, value):
        """Alias for EnterFieldBehavior.setter"""
        self.EnterFieldBehavior = value

    @property
    def enter_field_behavior(self):
        """Alias for EnterFieldBehavior"""
        return self.EnterFieldBehavior

    @enter_field_behavior.setter
    def enter_field_behavior(self, value):
        """Alias for EnterFieldBehavior.setter"""
        self.EnterFieldBehavior = value

    @property
    def Font(self):
        return self.com_object.Font

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def ForeColor(self):
        return self.com_object.ForeColor

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def HideSelection(self):
        return self.com_object.HideSelection

    @HideSelection.setter
    def HideSelection(self, value):
        self.com_object.HideSelection = value

    @property
    def hideselection(self):
        """Alias for HideSelection"""
        return self.HideSelection

    @hideselection.setter
    def hideselection(self, value):
        """Alias for HideSelection.setter"""
        self.HideSelection = value

    @property
    def hide_selection(self):
        """Alias for HideSelection"""
        return self.HideSelection

    @hide_selection.setter
    def hide_selection(self, value):
        """Alias for HideSelection.setter"""
        self.HideSelection = value

    @property
    def IntervalTime(self):
        return self.com_object.IntervalTime

    @IntervalTime.setter
    def IntervalTime(self, value):
        self.com_object.IntervalTime = value

    @property
    def intervaltime(self):
        """Alias for IntervalTime"""
        return self.IntervalTime

    @intervaltime.setter
    def intervaltime(self, value):
        """Alias for IntervalTime.setter"""
        self.IntervalTime = value

    @property
    def interval_time(self):
        """Alias for IntervalTime"""
        return self.IntervalTime

    @interval_time.setter
    def interval_time(self, value):
        """Alias for IntervalTime.setter"""
        self.IntervalTime = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def MouseIcon(self):
        return self.com_object.MouseIcon

    @MouseIcon.setter
    def MouseIcon(self, value):
        self.com_object.MouseIcon = value

    @property
    def mouseicon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouseicon.setter
    def mouseicon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def mouse_icon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouse_icon.setter
    def mouse_icon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def MousePointer(self):
        return OlMousePointer(self.com_object.MousePointer)

    @MousePointer.setter
    def MousePointer(self, value):
        self.com_object.MousePointer = value

    @property
    def mousepointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mousepointer.setter
    def mousepointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def mouse_pointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mouse_pointer.setter
    def mouse_pointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def ReferenceTime(self):
        return self.com_object.ReferenceTime

    @ReferenceTime.setter
    def ReferenceTime(self, value):
        self.com_object.ReferenceTime = value

    @property
    def referencetime(self):
        """Alias for ReferenceTime"""
        return self.ReferenceTime

    @referencetime.setter
    def referencetime(self, value):
        """Alias for ReferenceTime.setter"""
        self.ReferenceTime = value

    @property
    def reference_time(self):
        """Alias for ReferenceTime"""
        return self.ReferenceTime

    @reference_time.setter
    def reference_time(self, value):
        """Alias for ReferenceTime.setter"""
        self.ReferenceTime = value

    @property
    def Style(self):
        return OlTimeStyle(self.com_object.Style)

    @Style.setter
    def Style(self, value):
        self.com_object.Style = value

    @property
    def style(self):
        """Alias for Style"""
        return self.Style

    @style.setter
    def style(self, value):
        """Alias for Style.setter"""
        self.Style = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def TextAlign(self):
        return OlTextAlign(self.com_object.TextAlign)

    @TextAlign.setter
    def TextAlign(self, value):
        self.com_object.TextAlign = value

    @property
    def textalign(self):
        """Alias for TextAlign"""
        return self.TextAlign

    @textalign.setter
    def textalign(self, value):
        """Alias for TextAlign.setter"""
        self.TextAlign = value

    @property
    def text_align(self):
        """Alias for TextAlign"""
        return self.TextAlign

    @text_align.setter
    def text_align(self, value):
        """Alias for TextAlign.setter"""
        self.TextAlign = value

    @property
    def Time(self):
        return self.com_object.Time

    @Time.setter
    def Time(self, value):
        self.com_object.Time = value

    @property
    def time(self):
        """Alias for Time"""
        return self.Time

    @time.setter
    def time(self, value):
        """Alias for Time.setter"""
        self.Time = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    def DropDown(self):
        self.com_object.DropDown()

    def dropdown(self):
        """Alias for DropDown"""
        return self.DropDown()

    def drop_down(self):
        """Alias for DropDown"""
        return self.DropDown()


class OlkTimeZoneControl:

    def __init__(self, olktimezonecontrol=None):
        self.com_object= olktimezonecontrol

    @property
    def AppointmentTimeField(self):
        return OlAppointmentTimeField(self.com_object.AppointmentTimeField)

    @AppointmentTimeField.setter
    def AppointmentTimeField(self, value):
        self.com_object.AppointmentTimeField = value

    @property
    def appointmenttimefield(self):
        """Alias for AppointmentTimeField"""
        return self.AppointmentTimeField

    @appointmenttimefield.setter
    def appointmenttimefield(self, value):
        """Alias for AppointmentTimeField.setter"""
        self.AppointmentTimeField = value

    @property
    def appointment_time_field(self):
        """Alias for AppointmentTimeField"""
        return self.AppointmentTimeField

    @appointment_time_field.setter
    def appointment_time_field(self, value):
        """Alias for AppointmentTimeField.setter"""
        self.AppointmentTimeField = value

    @property
    def BorderStyle(self):
        return OlBorderStyle(self.com_object.BorderStyle)

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def MouseIcon(self):
        return self.com_object.MouseIcon

    @MouseIcon.setter
    def MouseIcon(self, value):
        self.com_object.MouseIcon = value

    @property
    def mouseicon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouseicon.setter
    def mouseicon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def mouse_icon(self):
        """Alias for MouseIcon"""
        return self.MouseIcon

    @mouse_icon.setter
    def mouse_icon(self, value):
        """Alias for MouseIcon.setter"""
        self.MouseIcon = value

    @property
    def MousePointer(self):
        return OlMousePointer(self.com_object.MousePointer)

    @MousePointer.setter
    def MousePointer(self, value):
        self.com_object.MousePointer = value

    @property
    def mousepointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mousepointer.setter
    def mousepointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def mouse_pointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mouse_pointer.setter
    def mouse_pointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def SelectedTimeZoneIndex(self):
        return Application.TimeZones(self.com_object.SelectedTimeZoneIndex)

    @SelectedTimeZoneIndex.setter
    def SelectedTimeZoneIndex(self, value):
        self.com_object.SelectedTimeZoneIndex = value

    @property
    def selectedtimezoneindex(self):
        """Alias for SelectedTimeZoneIndex"""
        return self.SelectedTimeZoneIndex

    @selectedtimezoneindex.setter
    def selectedtimezoneindex(self, value):
        """Alias for SelectedTimeZoneIndex.setter"""
        self.SelectedTimeZoneIndex = value

    @property
    def selected_time_zone_index(self):
        """Alias for SelectedTimeZoneIndex"""
        return self.SelectedTimeZoneIndex

    @selected_time_zone_index.setter
    def selected_time_zone_index(self, value):
        """Alias for SelectedTimeZoneIndex.setter"""
        self.SelectedTimeZoneIndex = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    def DropDown(self):
        self.com_object.DropDown()

    def dropdown(self):
        """Alias for DropDown"""
        return self.DropDown()

    def drop_down(self):
        """Alias for DropDown"""
        return self.DropDown()


# OlMailingAddress enumeration
olBusiness = 2
olHome = 1
olNone = 0
olOther = 3

# OlMailRecipientType enumeration
olBCC = 3
olCC = 2
olOriginator = 0
olTo = 1

# OlMarkInterval enumeration
olMarkComplete = 5
olMarkNextWeek = 3
olMarkNoDate = 4
olMarkThisWeek = 2
olMarkToday = 0
olMarkTomorrow = 1

# OlMatchEntry enumeration
olMatchEntryComplete = 1
olMatchEntryFirstLetter = 0
olMatchEntryNone = 2

# OlMeetingRecipientType enumeration
olOptional = 2
olOrganizer = 0
olRequired = 1
olResource = 3

# OlMeetingResponse enumeration
olMeetingAccepted = 3
olMeetingDeclined = 4
olMeetingTentative = 2

# OlMeetingStatus enumeration
olMeeting = 1
olMeetingCanceled = 5
olMeetingReceived = 3
olMeetingReceivedAndCanceled = 7
olNonMeeting = 0

# OlMouseButton enumeration
olMouseButtonLeft = 1
olMouseButtonRight = 2
olMouseButtonMiddle = 4

# OlMousePointer enumeration
olMousePointerAppStarting = 13
olMousePointerArrow = 1
olMousePointerCross = 2
olMousePointerCustom = 99
olMousePointerDefault = 0
olMousePointerHelp = 14
olMousePointerHourGlass = 11
olMousePointerIBeam = 3
olMousePointerNoDrop = 12
olMousePointerSizeAll = 15
olMousePointerSizeNESW = 6
olMousePointerSizeNS = 7
olMousePointerSizeNWSE = 8
olMousePointerSizeWE = 9
olMousePointerUpArrow = 10

# OlMultiLine enumeration
olAlwaysMultiLine = 2
olAlwaysSingleLine = 1
olWidthMultiLine = 0

# OlMultiSelect enumeration
olMultiSelectExtended = 2
olMultiSelectMulti = 1
olMultiSelectSingle = 0

# OlNavigationModuleType enumeration
olModuleCalendar = 1
olModuleContacts = 2
olModuleFolderList = 6
olModuleJournal = 4
olModuleMail = 0
olModuleNotes = 5
olModuleShortcuts = 7
olModuleSolutions = 8
olModuleTasks = 3

# OlObjectClass enumeration
olAccount = 105
olAccountRuleCondition = 135
olAccounts = 106
olAction = 32
olActions = 33
olAddressEntries = 21
olAddressEntry = 8
olAddressList = 7
olAddressLists = 20
olAddressRuleCondition = 170
olApplication = 0
olAppointment = 26
olAssignToCategoryRuleAction = 122
olAttachment = 5
olAttachments = 18
olAttachmentSelection = 169
olAutoFormatRule = 147
olAutoFormatRules = 148
olCalendarModule = 159
olCalendarSharing = 151
olCategories = 153
olCategory = 152
olCategoryRuleCondition = 130
olClassBusinessCardView = 168
olClassCalendarView = 139
olClassCardView = 138
olClassIconView = 137
olClassNavigationPane = 155
olClassPeopleView = 183
olClassTableView = 136
olClassTimeLineView = 140
olClassTimeZone = 174
olClassTimeZones = 175
olColumn = 154
olColumnFormat = 149
olColumns = 150
olConflict = 102
olConflicts = 103
olContact = 40
olContactsModule = 160
olConversation = 178
olConversationHeader = 182
olDistributionList = 69
olDocument = 41
olException = 30
olExceptions = 29
olExchangeDistributionList = 111
olExchangeUser = 110
olExplorer = 34
olExplorers = 60
olFolder = 2
olFolders = 15
olFolderUserProperties = 172
olFolderUserProperty = 171
olFormDescription = 37
olFormNameRuleCondition = 131
olFormRegion = 129
olFromRssFeedRuleCondition = 173
olFromRuleCondition = 132
olImportanceRuleCondition = 128
olInspector = 35
olInspectors = 61
olItemProperties = 98
olItemProperty = 99
olItems = 16
olJournal = 42
olJournalModule = 162
olMail = 43
olMailModule = 158
olMarkAsTaskRuleAction = 124
olMeetingCancellation = 54
olMeetingForwardNotification = 181
olMeetingRequest = 53
olMeetingResponseNegative = 55
olMeetingResponsePositive = 56
olMeetingResponseTentative = 57
olMoveOrCopyRuleAction = 118
olNamespace = 1
olNavigationFolder = 167
olNavigationFolders = 166
olNavigationGroup = 165
olNavigationGroups = 164
olNavigationModule = 157
olNavigationModules = 156
olNewItemAlertRuleAction = 125
olNote = 44
olNotesModule = 163
olOrderField = 144
olOrderFields = 145
olOutlookBarGroup = 66
olOutlookBarGroups = 65
olOutlookBarPane = 63
olOutlookBarShortcut = 68
olOutlookBarShortcuts = 67
olOutlookBarStorage = 64
olOutspace = 180
olPages = 36
olPanes = 62
olPlaySoundRuleAction = 123
olPost = 45
olPropertyAccessor = 112
olPropertyPages = 71
olPropertyPageSite = 70
olRecipient = 4
olRecipients = 17
olRecurrencePattern = 28
olReminder = 101
olReminders = 100
olRemote = 47
olReport = 46
olResults = 78
olRow = 121
olRule = 115
olRuleAction = 117
olRuleActions = 116
olRuleCondition = 127
olRuleConditions = 126
olRules = 114
olSearch = 77
olSelection = 74
olSelectNamesDialog = 109
olSenderInAddressListRuleCondition = 133
olSendRuleAction = 119
olSharing = 104
olSimpleItems = 179
olSolutionsModule = 177
olStorageItem = 113
olStore = 107
olStores = 108
olSyncObject = 72
olSyncObjects = 73
olTable = 120
olTask = 48
olTaskRequest = 49
olTaskRequestAccept = 51
olTaskRequestDecline = 52
olTaskRequestUpdate = 50
olTasksModule = 161
olTextRuleCondition = 134
olUserDefinedProperties = 172
olUserDefinedProperty = 171
olUserProperties = 38
olUserProperty = 39
olView = 80
olViewField = 142
olViewFields = 141
olViewFont = 146
olViews = 79

# OlOutlookBarViewType enumeration
olLargeIcon = 0
olSmallIcon = 1

# OlPageType enumeration
olPageTypePlanner = 0
olPageTypeTracker = 1

# OlPane enumeration
olFolderList = 2
olNavigationPane = 4
olOutlookBar = 1
olPreview = 3

# OlPermission enumeration
olDoNotForward = 1
olPermissionTemplate = 2
olUnrestricted = 0

# OlPermissionService enumeration
olPassport = 2
olUnknown = 0
olWindows = 1

# OlPictureAlignment enumeration
olPictureAlignmentLeft = 0
olPictureAlignmentTop = 1

# OlRecipientSelectors enumeration
olShowNone = 0
olShowTo = 1
olShowToCc = 2
olShowToCcBcc = 3

# OlRecurrenceState enumeration
olApptException = 3
olApptMaster = 1
olApptNotRecurring = 0
olApptOccurrence = 2

# OlRecurrenceType enumeration
olRecursDaily = 0
olRecursMonthly = 2
olRecursMonthNth = 3
olRecursWeekly = 1
olRecursYearly = 5
olRecursYearNth = 6

# OlReferenceType enumeration
olStrong = 1
olWeak = 0

# OlRemoteStatus enumeration
olMarkedForCopy = 3
olMarkedForDelete = 4
olMarkedForDownload = 2
olRemoteStatusNone = 0
olUnMarked = 1

# OlResponseStatus enumeration
olResponseAccepted = 3
olResponseDeclined = 4
olResponseNone = 0
olResponseNotResponded = 5
olResponseOrganized = 1
olResponseTentative = 2

# OlRuleActionType enumeration
olRuleActionAssignToCategory = 2
olRuleActionCcMessage = 27
olRuleActionClearCategories = 30
olRuleActionCopyToFolder = 5
olRuleActionCustomAction = 22
olRuleActionDefer = 28
olRuleActionDelete = 3
olRuleActionDeletePermanently = 4
olRuleActionDesktopAlert = 24
olRuleActionFlagClear = 13
olRuleActionFlagColor = 12
olRuleActionFlagForActionInDays = 11
olRuleActionForward = 6
olRuleActionForwardAsAttachment = 7
olRuleActionImportance = 14
olRuleActionMarkAsTask = 41
olRuleActionMarkRead = 19
olRuleActionMoveToFolder = 1
olRuleActionNewItemAlert = 23
olRuleActionNotifyDelivery = 26
olRuleActionNotifyRead = 25
olRuleActionPlaySound = 17
olRuleActionPrint = 16
olRuleActionRedirect = 8
olRuleActionRunScript = 20
olRuleActionSensitivity = 15
olRuleActionServerReply = 9
olRuleActionStartApplication = 18
olRuleActionStop = 21
olRuleActionTemplate = 10
olRuleActionUnknown = 0

# OlRuleConditionType enumeration
olConditionAccount = 3
olConditionAnyCategory = 29
olConditionBody = 13
olConditionBodyOrSubject = 14
olConditionCategory = 18
olConditionCc = 9
olConditionDateRange = 22
olConditionFlaggedForAction = 8
olConditionFormName = 23
olConditionFrom = 1
olConditionFromAnyRssFeed = 31
olConditionFromRssFeed = 30
olConditionHasAttachment = 20
olConditionImportance = 6
olConditionLocalMachineOnly = 27
olConditionMeetingInviteOrUpdate = 26
olConditionMessageHeader = 15
olConditionNotTo = 11
olConditionOnlyToMe = 4
olConditionOOF = 19
olConditionOtherMachine = 28
olConditionProperty = 24
olConditionRecipientAddress = 16
olConditionSenderAddress = 17
olConditionSenderInAddressBook = 25
olConditionSensitivity = 7
olConditionSentTo = 12
olConditionSizeRange = 21
olConditionSubject = 2
olConditionTo = 5
olConditionToOrCc = 10
olConditionUnknown = 0

# OlRuleExecuteOption enumeration
olRuleExecuteAllMessages = 0
olRuleExecuteReadMessages = 1
olRuleExecuteUnreadMessages = 2

# OlRuleType enumeration
olRuleReceive = 0
olRuleSend = 1

# OlSaveAsType enumeration
olDoc = 4
olHTML = 5
olICal = 8
olMHTML = 10
olMSG = 3
olMSGUnicode = 9
olRTF = 1
olTemplate = 2
olTXT = 0
olVCal = 7
olVCard = 6

# OlScrollBars enumeration
olScrollBarsBoth = 3
olScrollBarsHorizontal = 1
olScrollBarsNone = 0
olScrollBarsVertical = 2

# OlSearchScope enumeration
olSearchScopeAllFolders = 1
olSearchScopeAllOutlookItems = 2
olSearchScopeCurrentFolder = 0
olSearchScopeCurrentStore = 4
olSearchScopeSubfolders = 3

# OlSelectionContents enumeration
olConversationHeaders = 1

# OlSelectionLocation enumeration
olAttachmentWell = 4
olDailyTaskList = 3
olToDoBarAppointmentList = 2
olToDoBarTaskList = 1
olViewList = 0

# OlSensitivity enumeration
olConfidential = 3
olNormal = 0
olPersonal = 1
olPrivate = 2

# OlSharingMsgType enumeration
olSharingMsgTypeInvite = 2
olSharingMsgTypeInviteAndRequest = 3
olSharingMsgTypeRequest = 1
olSharingMsgTypeResponseAllow = 4
olSharingMsgTypeResponseDeny = 5
olSharingMsgTypeUnknown = 0

# OlSharingProvider enumeration
olProviderExchange = 1
olProviderFederate = 7
olProviderICal = 4
olProviderPubCal = 3
olProviderRSS = 6
olProviderSharePoint = 5
olProviderUnknown = 0
olProviderWebCal = 2

# OlShiftState enumeration
olShiftStateShiftMask = 1
olShiftStateCtrlMask = 2
olShiftStateAltMask = 4

# OlShowItemCount enumeration
olNoItemCount = 0
olShowTotalItemCount = 2
olShowUnreadItemCount = 1

# OlSolutionScope enumeration
olHideInDefaultModules = 0
olShowInDefaultModules = 1

# OlSortOrder enumeration
olAscending = 1
olDescending = 2
olSortNone = 0

# OlSpecialFolders enumeration
olSpecialFolderAllTasks = 0
olSpecialFolderReminders = 1

# OlStorageIdentifierType enumeration
olIdentifyByEntryID = 1
olIdentifyByMessageClass = 2
olIdentifyBySubject = 0

# OlStoreType enumeration
olStoreANSI = 3
olStoreDefault = 1
olStoreUnicode = 2

# OlSyncState enumeration
olSyncStarted = 1
olSyncStopped = 0

# OlTableContents enumeration
olHiddenItems = 1
olUserItems = 0

# OlTaskDelegationState enumeration
olTaskDelegationAccepted = 2
olTaskDelegationDeclined = 3
olTaskDelegationUnknown = 1
olTaskNotDelegated = 0

# OlTaskOwnership enumeration
olDelegatedTask = 1
olNewTask = 0
olOwnTask = 2

# OlTaskRecipientType enumeration
olFinalStatus = 3
olUpdate = 2

# OlTaskResponse enumeration
olTaskAccept = 2
olTaskAssign = 1
olTaskDecline = 3
olTaskSimple = 0

# OlTaskStatus enumeration
olTaskComplete = 2
olTaskDeferred = 4
olTaskInProgress = 1
olTaskNotStarted = 0
olTaskWaiting = 3

# OlTextAlign enumeration
olTextAlignCenter = 2
olTextAlignLeft = 1
olTextAlignRight = 3

# OlTimelineViewMode enumeration
olTimelineViewDay = 0
olTimelineViewMonth = 2
olTimelineViewWeek = 1

# OlTimeStyle enumeration
olTimeStyleShortDuration = 4
olTimeStyleTimeDuration = 1
olTimeStyleTimeOnly = 0

# OlTrackingStatus enumeration
olTrackingDelivered = 1
olTrackingNone = 0
olTrackingNotDelivered = 2
olTrackingNotRead = 3
olTrackingRead = 6
olTrackingRecallFailure = 4
olTrackingRecallSuccess = 5
olTrackingReplied = 7

# OlUnifiedGroupFolderType enumeration
olGroupCalendarFolder = 1
olGroupMailFolder = 0

# OlUnifiedGroupType enumeration
PrivateGroup = 1
PublicGroup = 2

# OlUserPropertyType enumeration
olCombination = 19
olCurrency = 14
olDateTime = 5
olDuration = 7
olEnumeration = 21
olFormula = 18
olInteger = 20
olKeywords = 11
olNumber = 3
olOutlookInternal = 0
olPercent = 12
olSmartFrom = 22
olText = 1
olYesNo = 6

# OlVerticalLayout enumeration
olVerticalLayoutAlignBottom = 2
olVerticalLayoutAlignGrow = 3
olVerticalLayoutAlignMiddle = 1
olVerticalLayoutAlignTop = 0

# OlViewSaveOption enumeration
olViewSaveOptionAllFoldersOfType = 2
olViewSaveOptionThisFolderEveryone = 0
olViewSaveOptionThisFolderOnlyMe = 1

# OlViewType enumeration
olTableView = 0
olCardView = 1
olCalendarView = 2
olIconView = 3
olTimelineView = 4
olBusinessCardView = 5
olDailyTaskListView = 6
olPeopleView = 7

# OlWindowState enumeration
olMaximized = 0
olMinimized = 1
olNormalWindow = 2

class OptionButton:

    def __init__(self, optionbutton=None):
        self.com_object= optionbutton


class OrderField:

    def __init__(self, orderfield=None):
        self.com_object= orderfield

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def IsDescending(self):
        return OrderField(self.com_object.IsDescending)

    @IsDescending.setter
    def IsDescending(self, value):
        self.com_object.IsDescending = value

    @property
    def isdescending(self):
        """Alias for IsDescending"""
        return self.IsDescending

    @isdescending.setter
    def isdescending(self, value):
        """Alias for IsDescending.setter"""
        self.IsDescending = value

    @property
    def is_descending(self):
        """Alias for IsDescending"""
        return self.IsDescending

    @is_descending.setter
    def is_descending(self, value):
        """Alias for IsDescending.setter"""
        self.IsDescending = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def ViewXMLSchemaName(self):
        return OrderField(self.com_object.ViewXMLSchemaName)

    @property
    def viewxmlschemaname(self):
        """Alias for ViewXMLSchemaName"""
        return self.ViewXMLSchemaName

    @property
    def view_x_m_l_schema_name(self):
        """Alias for ViewXMLSchemaName"""
        return self.ViewXMLSchemaName


class OrderFields:

    def __init__(self, orderfields=None):
        self.com_object= orderfields

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return OrderField(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Add(self, PropertyName=None, IsDescending=None):
        arguments = com_arguments([unwrap(a) for a in [PropertyName, IsDescending]])
        return OrderField(self.com_object.Add(*arguments))

    def add(self, PropertyName=None, IsDescending=None):
        """Alias for Add"""
        arguments = [PropertyName, IsDescending]
        return self.Add(*arguments)

    def Insert(self, PropertyName=None, Index=None, IsDescending=None):
        arguments = com_arguments([unwrap(a) for a in [PropertyName, Index, IsDescending]])
        return OrderField(self.com_object.Insert(*arguments))

    def insert(self, PropertyName=None, Index=None, IsDescending=None):
        """Alias for Insert"""
        arguments = [PropertyName, Index, IsDescending]
        return self.Insert(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return OrderField(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Remove(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Remove(*arguments)

    def remove(self, Index=None):
        """Alias for Remove"""
        arguments = [Index]
        return self.Remove(*arguments)

    def RemoveAll(self):
        self.com_object.RemoveAll()

    def removeall(self):
        """Alias for RemoveAll"""
        return self.RemoveAll()

    def remove_all(self):
        """Alias for RemoveAll"""
        return self.RemoveAll()


class OutlookBarGroup:

    def __init__(self, outlookbargroup=None):
        self.com_object= outlookbargroup

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Shortcuts(self):
        return OutlookBarShortcuts(self.com_object.Shortcuts)

    @property
    def shortcuts(self):
        """Alias for Shortcuts"""
        return self.Shortcuts

    @property
    def ViewType(self):
        return OlOutlookBarViewType(self.com_object.ViewType)

    @ViewType.setter
    def ViewType(self, value):
        self.com_object.ViewType = value

    @property
    def viewtype(self):
        """Alias for ViewType"""
        return self.ViewType

    @viewtype.setter
    def viewtype(self, value):
        """Alias for ViewType.setter"""
        self.ViewType = value

    @property
    def view_type(self):
        """Alias for ViewType"""
        return self.ViewType

    @view_type.setter
    def view_type(self, value):
        """Alias for ViewType.setter"""
        self.ViewType = value


class OutlookBarGroups:

    def __init__(self, outlookbargroups=None):
        self.com_object= outlookbargroups

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Add(self, Name=None, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Index]])
        return OutlookBarGroup(self.com_object.Add(*arguments))

    def add(self, Name=None, Index=None):
        """Alias for Add"""
        arguments = [Name, Index]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return OutlookBarGroup(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Remove(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Remove(*arguments)

    def remove(self, Index=None):
        """Alias for Remove"""
        arguments = [Index]
        return self.Remove(*arguments)


class OutlookBarPane:

    def __init__(self, outlookbarpane=None):
        self.com_object= outlookbarpane

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Contents(self):
        return OutlookBarStorage(self.com_object.Contents)

    @property
    def contents(self):
        """Alias for Contents"""
        return self.Contents

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value


class OutlookBarShortcut:

    def __init__(self, outlookbarshortcut=None):
        self.com_object= outlookbarshortcut

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Target(self):
        return self.com_object.Target

    @property
    def target(self):
        """Alias for Target"""
        return self.Target

    def SetIcon(self, Icon=None):
        arguments = com_arguments([unwrap(a) for a in [Icon]])
        self.com_object.SetIcon(*arguments)

    def seticon(self, Icon=None):
        """Alias for SetIcon"""
        arguments = [Icon]
        return self.SetIcon(*arguments)

    def set_icon(self, Icon=None):
        """Alias for SetIcon"""
        arguments = [Icon]
        return self.SetIcon(*arguments)


class OutlookBarShortcuts:

    def __init__(self, outlookbarshortcuts=None):
        self.com_object= outlookbarshortcuts

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Add(self, Target=None, Name=None, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Target, Name, Index]])
        return OutlookBarShortcut(self.com_object.Add(*arguments))

    def add(self, Target=None, Name=None, Index=None):
        """Alias for Add"""
        arguments = [Target, Name, Index]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return OutlookBarShortcut(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Remove(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Remove(*arguments)

    def remove(self, Index=None):
        """Alias for Remove"""
        arguments = [Index]
        return self.Remove(*arguments)


class OutlookBarStorage:

    def __init__(self, outlookbarstorage=None):
        self.com_object= outlookbarstorage

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Groups(self):
        return OutlookBarGroups(self.com_object.Groups)

    @property
    def groups(self):
        """Alias for Groups"""
        return self.Groups

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session


class Page:

    def __init__(self, page=None):
        self.com_object= page


class Pages:

    def __init__(self, pages=None):
        self.com_object= pages

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Add(self):
        return Page(self.com_object.Add())

    def add(self):
        """Alias for Add"""
        return self.Add()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Remove(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Remove(*arguments)

    def remove(self, Index=None):
        """Alias for Remove"""
        arguments = [Index]
        return self.Remove(*arguments)


class Panes:

    def __init__(self, panes=None):
        self.com_object= panes

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class PeopleView:

    def __init__(self, peopleview=None):
        self.com_object= peopleview

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return self.com_object.Class

    @property
    def Filter(self):
        return self.com_object.Filter

    @Filter.setter
    def Filter(self, value):
        self.com_object.Filter = value

    @property
    def filter(self):
        """Alias for Filter"""
        return self.Filter

    @filter.setter
    def filter(self, value):
        """Alias for Filter.setter"""
        self.Filter = value

    @property
    def Language(self):
        return self.com_object.Language

    @Language.setter
    def Language(self, value):
        self.com_object.Language = value

    @property
    def language(self):
        """Alias for Language"""
        return self.Language

    @language.setter
    def language(self, value):
        """Alias for Language.setter"""
        self.Language = value

    @property
    def LockUserChanges(self):
        return self.com_object.LockUserChanges

    @LockUserChanges.setter
    def LockUserChanges(self, value):
        self.com_object.LockUserChanges = value

    @property
    def lockuserchanges(self):
        """Alias for LockUserChanges"""
        return self.LockUserChanges

    @lockuserchanges.setter
    def lockuserchanges(self, value):
        """Alias for LockUserChanges.setter"""
        self.LockUserChanges = value

    @property
    def lock_user_changes(self):
        """Alias for LockUserChanges"""
        return self.LockUserChanges

    @lock_user_changes.setter
    def lock_user_changes(self, value):
        """Alias for LockUserChanges.setter"""
        self.LockUserChanges = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SaveOption(self):
        return self.com_object.SaveOption

    @property
    def saveoption(self):
        """Alias for SaveOption"""
        return self.SaveOption

    @property
    def save_option(self):
        """Alias for SaveOption"""
        return self.SaveOption

    @property
    def Session(self):
        return self.com_object.Session

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def SortFields(self):
        return self.com_object.SortFields

    @property
    def sortfields(self):
        """Alias for SortFields"""
        return self.SortFields

    @property
    def sort_fields(self):
        """Alias for SortFields"""
        return self.SortFields

    @property
    def Standard(self):
        return self.com_object.Standard

    @property
    def standard(self):
        """Alias for Standard"""
        return self.Standard

    @property
    def ViewType(self):
        return self.com_object.ViewType

    @property
    def viewtype(self):
        """Alias for ViewType"""
        return self.ViewType

    @property
    def view_type(self):
        """Alias for ViewType"""
        return self.ViewType

    @property
    def XML(self):
        return self.com_object.XML

    @XML.setter
    def XML(self, value):
        self.com_object.XML = value

    @property
    def xml(self):
        """Alias for XML"""
        return self.XML

    @xml.setter
    def xml(self, value):
        """Alias for XML.setter"""
        self.XML = value

    @property
    def x_m_l(self):
        """Alias for XML"""
        return self.XML

    @x_m_l.setter
    def x_m_l(self, value):
        """Alias for XML.setter"""
        self.XML = value

    def Apply(self):
        self.com_object.Apply()

    def apply(self):
        """Alias for Apply"""
        return self.Apply()

    def Copy(self, Name=None, SaveOption=None):
        arguments = com_arguments([unwrap(a) for a in [Name, SaveOption]])
        self.com_object.Copy(*arguments)

    def copy(self, Name=None, SaveOption=None):
        """Alias for Copy"""
        arguments = [Name, SaveOption]
        return self.Copy(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def GoToDate(self, Date=None):
        arguments = com_arguments([unwrap(a) for a in [Date]])
        self.com_object.GoToDate(*arguments)

    def gotodate(self, Date=None):
        """Alias for GoToDate"""
        arguments = [Date]
        return self.GoToDate(*arguments)

    def go_to_date(self, Date=None):
        """Alias for GoToDate"""
        arguments = [Date]
        return self.GoToDate(*arguments)

    def Reset(self):
        self.com_object.Reset()

    def reset(self):
        """Alias for Reset"""
        return self.Reset()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()


class PlaySoundRuleAction:

    def __init__(self, playsoundruleaction=None):
        self.com_object= playsoundruleaction

    @property
    def ActionType(self):
        return OlRuleActionType(self.com_object.ActionType)

    @property
    def actiontype(self):
        """Alias for ActionType"""
        return self.ActionType

    @property
    def action_type(self):
        """Alias for ActionType"""
        return self.ActionType

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def FilePath(self):
        return self.com_object.FilePath

    @FilePath.setter
    def FilePath(self, value):
        self.com_object.FilePath = value

    @property
    def filepath(self):
        """Alias for FilePath"""
        return self.FilePath

    @filepath.setter
    def filepath(self, value):
        """Alias for FilePath.setter"""
        self.FilePath = value

    @property
    def file_path(self):
        """Alias for FilePath"""
        return self.FilePath

    @file_path.setter
    def file_path(self, value):
        """Alias for FilePath.setter"""
        self.FilePath = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session


class PostItem:

    def __init__(self, postitem=None):
        self.com_object= postitem

    @property
    def Actions(self):
        return Actions(self.com_object.Actions)

    @property
    def actions(self):
        """Alias for Actions"""
        return self.Actions

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Attachments(self):
        return Attachments(self.com_object.Attachments)

    @property
    def attachments(self):
        """Alias for Attachments"""
        return self.Attachments

    @property
    def AutoResolvedWinner(self):
        return self.com_object.AutoResolvedWinner

    @property
    def autoresolvedwinner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def auto_resolved_winner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def BillingInformation(self):
        return self.com_object.BillingInformation

    @BillingInformation.setter
    def BillingInformation(self, value):
        self.com_object.BillingInformation = value

    @property
    def billinginformation(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billinginformation.setter
    def billinginformation(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def billing_information(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billing_information.setter
    def billing_information(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def Body(self):
        return self.com_object.Body

    @Body.setter
    def Body(self, value):
        self.com_object.Body = value

    @property
    def body(self):
        """Alias for Body"""
        return self.Body

    @body.setter
    def body(self, value):
        """Alias for Body.setter"""
        self.Body = value

    @property
    def BodyFormat(self):
        return OlBodyFormat(self.com_object.BodyFormat)

    @BodyFormat.setter
    def BodyFormat(self, value):
        self.com_object.BodyFormat = value

    @property
    def bodyformat(self):
        """Alias for BodyFormat"""
        return self.BodyFormat

    @bodyformat.setter
    def bodyformat(self, value):
        """Alias for BodyFormat.setter"""
        self.BodyFormat = value

    @property
    def body_format(self):
        """Alias for BodyFormat"""
        return self.BodyFormat

    @body_format.setter
    def body_format(self, value):
        """Alias for BodyFormat.setter"""
        self.BodyFormat = value

    @property
    def Categories(self):
        return self.com_object.Categories

    @Categories.setter
    def Categories(self, value):
        self.com_object.Categories = value

    @property
    def categories(self):
        """Alias for Categories"""
        return self.Categories

    @categories.setter
    def categories(self, value):
        """Alias for Categories.setter"""
        self.Categories = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Companies(self):
        return self.com_object.Companies

    @Companies.setter
    def Companies(self, value):
        self.com_object.Companies = value

    @property
    def companies(self):
        """Alias for Companies"""
        return self.Companies

    @companies.setter
    def companies(self, value):
        """Alias for Companies.setter"""
        self.Companies = value

    @property
    def Conflicts(self):
        return self.com_object.Conflicts

    @property
    def conflicts(self):
        """Alias for Conflicts"""
        return self.Conflicts

    @property
    def ConversationID(self):
        return Conversation(self.com_object.ConversationID)

    @property
    def conversationid(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def conversation_i_d(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def ConversationIndex(self):
        return self.com_object.ConversationIndex

    @property
    def conversationindex(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def conversation_index(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def ConversationTopic(self):
        return self.com_object.ConversationTopic

    @property
    def conversationtopic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def conversation_topic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def CreationTime(self):
        return self.com_object.CreationTime

    @property
    def creationtime(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def creation_time(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def DownloadState(self):
        return OlDownloadState(self.com_object.DownloadState)

    @property
    def downloadstate(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def download_state(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def EntryID(self):
        return self.com_object.EntryID

    @property
    def entryid(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def entry_i_d(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def ExpiryTime(self):
        return self.com_object.ExpiryTime

    @ExpiryTime.setter
    def ExpiryTime(self, value):
        self.com_object.ExpiryTime = value

    @property
    def expirytime(self):
        """Alias for ExpiryTime"""
        return self.ExpiryTime

    @expirytime.setter
    def expirytime(self, value):
        """Alias for ExpiryTime.setter"""
        self.ExpiryTime = value

    @property
    def expiry_time(self):
        """Alias for ExpiryTime"""
        return self.ExpiryTime

    @expiry_time.setter
    def expiry_time(self, value):
        """Alias for ExpiryTime.setter"""
        self.ExpiryTime = value

    @property
    def FormDescription(self):
        return FormDescription(self.com_object.FormDescription)

    @property
    def formdescription(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def form_description(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def GetInspector(self):
        return Inspector(self.com_object.GetInspector)

    @property
    def getinspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def get_inspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def HTMLBody(self):
        return self.com_object.HTMLBody

    @HTMLBody.setter
    def HTMLBody(self, value):
        self.com_object.HTMLBody = value

    @property
    def htmlbody(self):
        """Alias for HTMLBody"""
        return self.HTMLBody

    @htmlbody.setter
    def htmlbody(self, value):
        """Alias for HTMLBody.setter"""
        self.HTMLBody = value

    @property
    def h_t_m_l_body(self):
        """Alias for HTMLBody"""
        return self.HTMLBody

    @h_t_m_l_body.setter
    def h_t_m_l_body(self, value):
        """Alias for HTMLBody.setter"""
        self.HTMLBody = value

    @property
    def Importance(self):
        return OlImportance(self.com_object.Importance)

    @Importance.setter
    def Importance(self, value):
        self.com_object.Importance = value

    @property
    def importance(self):
        """Alias for Importance"""
        return self.Importance

    @importance.setter
    def importance(self, value):
        """Alias for Importance.setter"""
        self.Importance = value

    @property
    def InternetCodepage(self):
        return self.com_object.InternetCodepage

    @InternetCodepage.setter
    def InternetCodepage(self, value):
        self.com_object.InternetCodepage = value

    @property
    def internetcodepage(self):
        """Alias for InternetCodepage"""
        return self.InternetCodepage

    @internetcodepage.setter
    def internetcodepage(self, value):
        """Alias for InternetCodepage.setter"""
        self.InternetCodepage = value

    @property
    def internet_codepage(self):
        """Alias for InternetCodepage"""
        return self.InternetCodepage

    @internet_codepage.setter
    def internet_codepage(self, value):
        """Alias for InternetCodepage.setter"""
        self.InternetCodepage = value

    @property
    def IsConflict(self):
        return self.com_object.IsConflict

    @property
    def isconflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def is_conflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def IsMarkedAsTask(self):
        return PostItem(self.com_object.IsMarkedAsTask)

    @property
    def ismarkedastask(self):
        """Alias for IsMarkedAsTask"""
        return self.IsMarkedAsTask

    @property
    def is_marked_as_task(self):
        """Alias for IsMarkedAsTask"""
        return self.IsMarkedAsTask

    @property
    def ItemProperties(self):
        return ItemProperties(self.com_object.ItemProperties)

    @property
    def itemproperties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def item_properties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def LastModificationTime(self):
        return self.com_object.LastModificationTime

    @property
    def lastmodificationtime(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def last_modification_time(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def MarkForDownload(self):
        return OlRemoteStatus(self.com_object.MarkForDownload)

    @MarkForDownload.setter
    def MarkForDownload(self, value):
        self.com_object.MarkForDownload = value

    @property
    def markfordownload(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @markfordownload.setter
    def markfordownload(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def mark_for_download(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @mark_for_download.setter
    def mark_for_download(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def MessageClass(self):
        return self.com_object.MessageClass

    @MessageClass.setter
    def MessageClass(self, value):
        self.com_object.MessageClass = value

    @property
    def messageclass(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @messageclass.setter
    def messageclass(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def message_class(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @message_class.setter
    def message_class(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def Mileage(self):
        return self.com_object.Mileage

    @Mileage.setter
    def Mileage(self, value):
        self.com_object.Mileage = value

    @property
    def mileage(self):
        """Alias for Mileage"""
        return self.Mileage

    @mileage.setter
    def mileage(self, value):
        """Alias for Mileage.setter"""
        self.Mileage = value

    @property
    def NoAging(self):
        return self.com_object.NoAging

    @NoAging.setter
    def NoAging(self, value):
        self.com_object.NoAging = value

    @property
    def noaging(self):
        """Alias for NoAging"""
        return self.NoAging

    @noaging.setter
    def noaging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def no_aging(self):
        """Alias for NoAging"""
        return self.NoAging

    @no_aging.setter
    def no_aging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def OutlookInternalVersion(self):
        return self.com_object.OutlookInternalVersion

    @property
    def outlookinternalversion(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def outlook_internal_version(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def OutlookVersion(self):
        return self.com_object.OutlookVersion

    @property
    def outlookversion(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def outlook_version(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def ReceivedTime(self):
        return self.com_object.ReceivedTime

    @property
    def receivedtime(self):
        """Alias for ReceivedTime"""
        return self.ReceivedTime

    @property
    def received_time(self):
        """Alias for ReceivedTime"""
        return self.ReceivedTime

    @property
    def ReminderOverrideDefault(self):
        return self.com_object.ReminderOverrideDefault

    @ReminderOverrideDefault.setter
    def ReminderOverrideDefault(self, value):
        self.com_object.ReminderOverrideDefault = value

    @property
    def reminderoverridedefault(self):
        """Alias for ReminderOverrideDefault"""
        return self.ReminderOverrideDefault

    @reminderoverridedefault.setter
    def reminderoverridedefault(self, value):
        """Alias for ReminderOverrideDefault.setter"""
        self.ReminderOverrideDefault = value

    @property
    def reminder_override_default(self):
        """Alias for ReminderOverrideDefault"""
        return self.ReminderOverrideDefault

    @reminder_override_default.setter
    def reminder_override_default(self, value):
        """Alias for ReminderOverrideDefault.setter"""
        self.ReminderOverrideDefault = value

    @property
    def ReminderPlaySound(self):
        return self.com_object.ReminderPlaySound

    @ReminderPlaySound.setter
    def ReminderPlaySound(self, value):
        self.com_object.ReminderPlaySound = value

    @property
    def reminderplaysound(self):
        """Alias for ReminderPlaySound"""
        return self.ReminderPlaySound

    @reminderplaysound.setter
    def reminderplaysound(self, value):
        """Alias for ReminderPlaySound.setter"""
        self.ReminderPlaySound = value

    @property
    def reminder_play_sound(self):
        """Alias for ReminderPlaySound"""
        return self.ReminderPlaySound

    @reminder_play_sound.setter
    def reminder_play_sound(self, value):
        """Alias for ReminderPlaySound.setter"""
        self.ReminderPlaySound = value

    @property
    def ReminderSet(self):
        return self.com_object.ReminderSet

    @ReminderSet.setter
    def ReminderSet(self, value):
        self.com_object.ReminderSet = value

    @property
    def reminderset(self):
        """Alias for ReminderSet"""
        return self.ReminderSet

    @reminderset.setter
    def reminderset(self, value):
        """Alias for ReminderSet.setter"""
        self.ReminderSet = value

    @property
    def reminder_set(self):
        """Alias for ReminderSet"""
        return self.ReminderSet

    @reminder_set.setter
    def reminder_set(self, value):
        """Alias for ReminderSet.setter"""
        self.ReminderSet = value

    @property
    def ReminderSoundFile(self):
        return self.com_object.ReminderSoundFile

    @ReminderSoundFile.setter
    def ReminderSoundFile(self, value):
        self.com_object.ReminderSoundFile = value

    @property
    def remindersoundfile(self):
        """Alias for ReminderSoundFile"""
        return self.ReminderSoundFile

    @remindersoundfile.setter
    def remindersoundfile(self, value):
        """Alias for ReminderSoundFile.setter"""
        self.ReminderSoundFile = value

    @property
    def reminder_sound_file(self):
        """Alias for ReminderSoundFile"""
        return self.ReminderSoundFile

    @reminder_sound_file.setter
    def reminder_sound_file(self, value):
        """Alias for ReminderSoundFile.setter"""
        self.ReminderSoundFile = value

    @property
    def ReminderTime(self):
        return self.com_object.ReminderTime

    @ReminderTime.setter
    def ReminderTime(self, value):
        self.com_object.ReminderTime = value

    @property
    def remindertime(self):
        """Alias for ReminderTime"""
        return self.ReminderTime

    @remindertime.setter
    def remindertime(self, value):
        """Alias for ReminderTime.setter"""
        self.ReminderTime = value

    @property
    def reminder_time(self):
        """Alias for ReminderTime"""
        return self.ReminderTime

    @reminder_time.setter
    def reminder_time(self, value):
        """Alias for ReminderTime.setter"""
        self.ReminderTime = value

    @property
    def RTFBody(self):
        return self.com_object.RTFBody

    @RTFBody.setter
    def RTFBody(self, value):
        self.com_object.RTFBody = value

    @property
    def rtfbody(self):
        """Alias for RTFBody"""
        return self.RTFBody

    @rtfbody.setter
    def rtfbody(self, value):
        """Alias for RTFBody.setter"""
        self.RTFBody = value

    @property
    def r_t_f_body(self):
        """Alias for RTFBody"""
        return self.RTFBody

    @r_t_f_body.setter
    def r_t_f_body(self, value):
        """Alias for RTFBody.setter"""
        self.RTFBody = value

    @property
    def Saved(self):
        return self.com_object.Saved

    @property
    def saved(self):
        """Alias for Saved"""
        return self.Saved

    @property
    def SenderEmailAddress(self):
        return self.com_object.SenderEmailAddress

    @property
    def senderemailaddress(self):
        """Alias for SenderEmailAddress"""
        return self.SenderEmailAddress

    @property
    def sender_email_address(self):
        """Alias for SenderEmailAddress"""
        return self.SenderEmailAddress

    @property
    def SenderEmailType(self):
        return self.com_object.SenderEmailType

    @property
    def senderemailtype(self):
        """Alias for SenderEmailType"""
        return self.SenderEmailType

    @property
    def sender_email_type(self):
        """Alias for SenderEmailType"""
        return self.SenderEmailType

    @property
    def SenderName(self):
        return self.com_object.SenderName

    @property
    def sendername(self):
        """Alias for SenderName"""
        return self.SenderName

    @property
    def sender_name(self):
        """Alias for SenderName"""
        return self.SenderName

    @property
    def Sensitivity(self):
        return OlSensitivity(self.com_object.Sensitivity)

    @Sensitivity.setter
    def Sensitivity(self, value):
        self.com_object.Sensitivity = value

    @property
    def sensitivity(self):
        """Alias for Sensitivity"""
        return self.Sensitivity

    @sensitivity.setter
    def sensitivity(self, value):
        """Alias for Sensitivity.setter"""
        self.Sensitivity = value

    @property
    def SentOn(self):
        return self.com_object.SentOn

    @property
    def senton(self):
        """Alias for SentOn"""
        return self.SentOn

    @property
    def sent_on(self):
        """Alias for SentOn"""
        return self.SentOn

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Size(self):
        return self.com_object.Size

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @property
    def Subject(self):
        return self.com_object.Subject

    @Subject.setter
    def Subject(self, value):
        self.com_object.Subject = value

    @property
    def subject(self):
        """Alias for Subject"""
        return self.Subject

    @subject.setter
    def subject(self, value):
        """Alias for Subject.setter"""
        self.Subject = value

    @property
    def TaskCompletedDate(self):
        return PostItem(self.com_object.TaskCompletedDate)

    @TaskCompletedDate.setter
    def TaskCompletedDate(self, value):
        self.com_object.TaskCompletedDate = value

    @property
    def taskcompleteddate(self):
        """Alias for TaskCompletedDate"""
        return self.TaskCompletedDate

    @taskcompleteddate.setter
    def taskcompleteddate(self, value):
        """Alias for TaskCompletedDate.setter"""
        self.TaskCompletedDate = value

    @property
    def task_completed_date(self):
        """Alias for TaskCompletedDate"""
        return self.TaskCompletedDate

    @task_completed_date.setter
    def task_completed_date(self, value):
        """Alias for TaskCompletedDate.setter"""
        self.TaskCompletedDate = value

    @property
    def TaskDueDate(self):
        return PostItem(self.com_object.TaskDueDate)

    @TaskDueDate.setter
    def TaskDueDate(self, value):
        self.com_object.TaskDueDate = value

    @property
    def taskduedate(self):
        """Alias for TaskDueDate"""
        return self.TaskDueDate

    @taskduedate.setter
    def taskduedate(self, value):
        """Alias for TaskDueDate.setter"""
        self.TaskDueDate = value

    @property
    def task_due_date(self):
        """Alias for TaskDueDate"""
        return self.TaskDueDate

    @task_due_date.setter
    def task_due_date(self, value):
        """Alias for TaskDueDate.setter"""
        self.TaskDueDate = value

    @property
    def TaskStartDate(self):
        return PostItem(self.com_object.TaskStartDate)

    @TaskStartDate.setter
    def TaskStartDate(self, value):
        self.com_object.TaskStartDate = value

    @property
    def taskstartdate(self):
        """Alias for TaskStartDate"""
        return self.TaskStartDate

    @taskstartdate.setter
    def taskstartdate(self, value):
        """Alias for TaskStartDate.setter"""
        self.TaskStartDate = value

    @property
    def task_start_date(self):
        """Alias for TaskStartDate"""
        return self.TaskStartDate

    @task_start_date.setter
    def task_start_date(self, value):
        """Alias for TaskStartDate.setter"""
        self.TaskStartDate = value

    @property
    def TaskSubject(self):
        return PostItem(self.com_object.TaskSubject)

    @TaskSubject.setter
    def TaskSubject(self, value):
        self.com_object.TaskSubject = value

    @property
    def tasksubject(self):
        """Alias for TaskSubject"""
        return self.TaskSubject

    @tasksubject.setter
    def tasksubject(self, value):
        """Alias for TaskSubject.setter"""
        self.TaskSubject = value

    @property
    def task_subject(self):
        """Alias for TaskSubject"""
        return self.TaskSubject

    @task_subject.setter
    def task_subject(self, value):
        """Alias for TaskSubject.setter"""
        self.TaskSubject = value

    @property
    def ToDoTaskOrdinal(self):
        return PostItem(self.com_object.ToDoTaskOrdinal)

    @ToDoTaskOrdinal.setter
    def ToDoTaskOrdinal(self, value):
        self.com_object.ToDoTaskOrdinal = value

    @property
    def todotaskordinal(self):
        """Alias for ToDoTaskOrdinal"""
        return self.ToDoTaskOrdinal

    @todotaskordinal.setter
    def todotaskordinal(self, value):
        """Alias for ToDoTaskOrdinal.setter"""
        self.ToDoTaskOrdinal = value

    @property
    def to_do_task_ordinal(self):
        """Alias for ToDoTaskOrdinal"""
        return self.ToDoTaskOrdinal

    @to_do_task_ordinal.setter
    def to_do_task_ordinal(self, value):
        """Alias for ToDoTaskOrdinal.setter"""
        self.ToDoTaskOrdinal = value

    @property
    def UnRead(self):
        return self.com_object.UnRead

    @UnRead.setter
    def UnRead(self, value):
        self.com_object.UnRead = value

    @property
    def unread(self):
        """Alias for UnRead"""
        return self.UnRead

    @unread.setter
    def unread(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def un_read(self):
        """Alias for UnRead"""
        return self.UnRead

    @un_read.setter
    def un_read(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def UserProperties(self):
        return UserProperties(self.com_object.UserProperties)

    @property
    def userproperties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    @property
    def user_properties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    def ClearConversationIndex(self):
        self.com_object.ClearConversationIndex()

    def clearconversationindex(self):
        """Alias for ClearConversationIndex"""
        return self.ClearConversationIndex()

    def clear_conversation_index(self):
        """Alias for ClearConversationIndex"""
        return self.ClearConversationIndex()

    def ClearTaskFlag(self):
        self.com_object.ClearTaskFlag()

    def cleartaskflag(self):
        """Alias for ClearTaskFlag"""
        return self.ClearTaskFlag()

    def clear_task_flag(self):
        """Alias for ClearTaskFlag"""
        return self.ClearTaskFlag()

    def Close(self, SaveMode=None):
        arguments = com_arguments([unwrap(a) for a in [SaveMode]])
        self.com_object.Close(*arguments)

    def close(self, SaveMode=None):
        """Alias for Close"""
        arguments = [SaveMode]
        return self.Close(*arguments)

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Display(self, Modal=None):
        arguments = com_arguments([unwrap(a) for a in [Modal]])
        self.com_object.Display(*arguments)

    def display(self, Modal=None):
        """Alias for Display"""
        arguments = [Modal]
        return self.Display(*arguments)

    def Forward(self):
        return MailItem(self.com_object.Forward())

    def forward(self):
        """Alias for Forward"""
        return self.Forward()

    def GetConversation(self):
        return Conversation(self.com_object.GetConversation())

    def getconversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def get_conversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def MarkAsTask(self, MarkInterval=None):
        arguments = com_arguments([unwrap(a) for a in [MarkInterval]])
        self.com_object.MarkAsTask(*arguments)

    def markastask(self, MarkInterval=None):
        """Alias for MarkAsTask"""
        arguments = [MarkInterval]
        return self.MarkAsTask(*arguments)

    def mark_as_task(self, MarkInterval=None):
        """Alias for MarkAsTask"""
        arguments = [MarkInterval]
        return self.MarkAsTask(*arguments)

    def Move(self, DestFldr=None):
        arguments = com_arguments([unwrap(a) for a in [DestFldr]])
        return self.com_object.Move(*arguments)

    def move(self, DestFldr=None):
        """Alias for Move"""
        arguments = [DestFldr]
        return self.Move(*arguments)

    def Post(self):
        self.com_object.Post()

    def post(self):
        """Alias for Post"""
        return self.Post()

    def PrintOut(self):
        self.com_object.PrintOut()

    def printout(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def print_out(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def Reply(self):
        return MailItem(self.com_object.Reply())

    def reply(self):
        """Alias for Reply"""
        return self.Reply()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()

    def SaveAs(self, Path=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Path, Type]])
        self.com_object.SaveAs(*arguments)

    def saveas(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def save_as(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def ShowCategoriesDialog(self):
        self.com_object.ShowCategoriesDialog()

    def showcategoriesdialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()

    def show_categories_dialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()


class PreviewPane:

    def __init__(self, previewpane=None):
        self.com_object= previewpane

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return self.com_object.Class

    @property
    def Parent(self):
        return PreviewPane(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return self.com_object.Session

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def WordEditor(self):
        return self.com_object.WordEditor

    @property
    def wordeditor(self):
        """Alias for WordEditor"""
        return self.WordEditor

    @property
    def word_editor(self):
        """Alias for WordEditor"""
        return self.WordEditor


class PropertyAccessor:

    def __init__(self, propertyaccessor=None):
        self.com_object= propertyaccessor

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return PropertyAccessor(self.com_object.Class)

    @property
    def Parent(self):
        return PropertyAccessor(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def BinaryToString(self, Value=None):
        arguments = com_arguments([unwrap(a) for a in [Value]])
        return self.com_object.BinaryToString(*arguments)

    def binarytostring(self, Value=None):
        """Alias for BinaryToString"""
        arguments = [Value]
        return self.BinaryToString(*arguments)

    def binary_to_string(self, Value=None):
        """Alias for BinaryToString"""
        arguments = [Value]
        return self.BinaryToString(*arguments)

    def DeleteProperties(self, SchemaNames=None):
        arguments = com_arguments([unwrap(a) for a in [SchemaNames]])
        return self.com_object.DeleteProperties(*arguments)

    def deleteproperties(self, SchemaNames=None):
        """Alias for DeleteProperties"""
        arguments = [SchemaNames]
        return self.DeleteProperties(*arguments)

    def delete_properties(self, SchemaNames=None):
        """Alias for DeleteProperties"""
        arguments = [SchemaNames]
        return self.DeleteProperties(*arguments)

    def DeleteProperty(self, SchemaName=None):
        arguments = com_arguments([unwrap(a) for a in [SchemaName]])
        self.com_object.DeleteProperty(*arguments)

    def deleteproperty(self, SchemaName=None):
        """Alias for DeleteProperty"""
        arguments = [SchemaName]
        return self.DeleteProperty(*arguments)

    def delete_property(self, SchemaName=None):
        """Alias for DeleteProperty"""
        arguments = [SchemaName]
        return self.DeleteProperty(*arguments)

    def GetProperties(self, SchemaNames=None):
        arguments = com_arguments([unwrap(a) for a in [SchemaNames]])
        return self.com_object.GetProperties(*arguments)

    def getproperties(self, SchemaNames=None):
        """Alias for GetProperties"""
        arguments = [SchemaNames]
        return self.GetProperties(*arguments)

    def get_properties(self, SchemaNames=None):
        """Alias for GetProperties"""
        arguments = [SchemaNames]
        return self.GetProperties(*arguments)

    def GetProperty(self, SchemaName=None):
        arguments = com_arguments([unwrap(a) for a in [SchemaName]])
        return self.com_object.GetProperty(*arguments)

    def getproperty(self, SchemaName=None):
        """Alias for GetProperty"""
        arguments = [SchemaName]
        return self.GetProperty(*arguments)

    def get_property(self, SchemaName=None):
        """Alias for GetProperty"""
        arguments = [SchemaName]
        return self.GetProperty(*arguments)

    def LocalTimeToUTC(self, Value=None):
        arguments = com_arguments([unwrap(a) for a in [Value]])
        return self.com_object.LocalTimeToUTC(*arguments)

    def localtimetoutc(self, Value=None):
        """Alias for LocalTimeToUTC"""
        arguments = [Value]
        return self.LocalTimeToUTC(*arguments)

    def local_time_to_u_t_c(self, Value=None):
        """Alias for LocalTimeToUTC"""
        arguments = [Value]
        return self.LocalTimeToUTC(*arguments)

    def SetProperties(self, SchemaNames=None, Values=None):
        arguments = com_arguments([unwrap(a) for a in [SchemaNames, Values]])
        return self.com_object.SetProperties(*arguments)

    def setproperties(self, SchemaNames=None, Values=None):
        """Alias for SetProperties"""
        arguments = [SchemaNames, Values]
        return self.SetProperties(*arguments)

    def set_properties(self, SchemaNames=None, Values=None):
        """Alias for SetProperties"""
        arguments = [SchemaNames, Values]
        return self.SetProperties(*arguments)

    def SetProperty(self, SchemaName=None, Value=None):
        arguments = com_arguments([unwrap(a) for a in [SchemaName, Value]])
        self.com_object.SetProperty(*arguments)

    def setproperty(self, SchemaName=None, Value=None):
        """Alias for SetProperty"""
        arguments = [SchemaName, Value]
        return self.SetProperty(*arguments)

    def set_property(self, SchemaName=None, Value=None):
        """Alias for SetProperty"""
        arguments = [SchemaName, Value]
        return self.SetProperty(*arguments)

    def StringToBinary(self, Value=None):
        arguments = com_arguments([unwrap(a) for a in [Value]])
        return self.com_object.StringToBinary(*arguments)

    def stringtobinary(self, Value=None):
        """Alias for StringToBinary"""
        arguments = [Value]
        return self.StringToBinary(*arguments)

    def string_to_binary(self, Value=None):
        """Alias for StringToBinary"""
        arguments = [Value]
        return self.StringToBinary(*arguments)

    def UTCToLocalTime(self, Value=None):
        arguments = com_arguments([unwrap(a) for a in [Value]])
        return self.com_object.UTCToLocalTime(*arguments)

    def utctolocaltime(self, Value=None):
        """Alias for UTCToLocalTime"""
        arguments = [Value]
        return self.UTCToLocalTime(*arguments)

    def u_t_c_to_local_time(self, Value=None):
        """Alias for UTCToLocalTime"""
        arguments = [Value]
        return self.UTCToLocalTime(*arguments)


class PropertyPage:

    def __init__(self, propertypage=None):
        self.com_object= propertypage

    def Dirty(self, Dirty=None):
        arguments = com_arguments([unwrap(a) for a in [Dirty]])
        if hasattr(self.com_object, "GetDirty"):
            return self.com_object.GetDirty(*arguments)
        else:
            return self.com_object.Dirty(*arguments)

    def dirty(self, Dirty=None):
        """Alias for Dirty"""
        arguments = [Dirty]
        return self.Dirty(*arguments)

    def Apply(self):
        return self.com_object.Apply()

    def apply(self):
        """Alias for Apply"""
        return self.Apply()

    def GetPageInfo(self, HelpFile=None, HelpContext=None):
        arguments = com_arguments([unwrap(a) for a in [HelpFile, HelpContext]])
        return self.com_object.GetPageInfo(*arguments)

    def getpageinfo(self, HelpFile=None, HelpContext=None):
        """Alias for GetPageInfo"""
        arguments = [HelpFile, HelpContext]
        return self.GetPageInfo(*arguments)

    def get_page_info(self, HelpFile=None, HelpContext=None):
        """Alias for GetPageInfo"""
        arguments = [HelpFile, HelpContext]
        return self.GetPageInfo(*arguments)


class PropertyPages:

    def __init__(self, propertypages=None):
        self.com_object= propertypages

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Add(self, Page=None, Title=None):
        arguments = com_arguments([unwrap(a) for a in [Page, Title]])
        self.com_object.Add(*arguments)

    def add(self, Page=None, Title=None):
        """Alias for Add"""
        arguments = [Page, Title]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Remove(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Remove(*arguments)

    def remove(self, Index=None):
        """Alias for Remove"""
        arguments = [Index]
        return self.Remove(*arguments)


class PropertyPageSite:

    def __init__(self, propertypagesite=None):
        self.com_object= propertypagesite

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def OnStatusChange(self):
        self.com_object.OnStatusChange()

    def onstatuschange(self):
        """Alias for OnStatusChange"""
        return self.OnStatusChange()

    def on_status_change(self):
        """Alias for OnStatusChange"""
        return self.OnStatusChange()


class Recipient:

    def __init__(self, recipient=None):
        self.com_object= recipient

    @property
    def Address(self):
        return self.com_object.Address

    @property
    def address(self):
        """Alias for Address"""
        return self.Address

    @property
    def AddressEntry(self):
        return AddressEntry(self.com_object.AddressEntry)

    @AddressEntry.setter
    def AddressEntry(self, value):
        self.com_object.AddressEntry = value

    @property
    def addressentry(self):
        """Alias for AddressEntry"""
        return self.AddressEntry

    @addressentry.setter
    def addressentry(self, value):
        """Alias for AddressEntry.setter"""
        self.AddressEntry = value

    @property
    def address_entry(self):
        """Alias for AddressEntry"""
        return self.AddressEntry

    @address_entry.setter
    def address_entry(self, value):
        """Alias for AddressEntry.setter"""
        self.AddressEntry = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoResponse(self):
        return Recipient(self.com_object.AutoResponse)

    @AutoResponse.setter
    def AutoResponse(self, value):
        self.com_object.AutoResponse = value

    @property
    def autoresponse(self):
        """Alias for AutoResponse"""
        return self.AutoResponse

    @autoresponse.setter
    def autoresponse(self, value):
        """Alias for AutoResponse.setter"""
        self.AutoResponse = value

    @property
    def auto_response(self):
        """Alias for AutoResponse"""
        return self.AutoResponse

    @auto_response.setter
    def auto_response(self, value):
        """Alias for AutoResponse.setter"""
        self.AutoResponse = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def DisplayType(self):
        return OlDisplayType(self.com_object.DisplayType)

    @property
    def displaytype(self):
        """Alias for DisplayType"""
        return self.DisplayType

    @property
    def display_type(self):
        """Alias for DisplayType"""
        return self.DisplayType

    @property
    def EntryID(self):
        return self.com_object.EntryID

    @property
    def entryid(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def entry_i_d(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def MeetingResponseStatus(self):
        return OlResponseStatus(self.com_object.MeetingResponseStatus)

    @property
    def meetingresponsestatus(self):
        """Alias for MeetingResponseStatus"""
        return self.MeetingResponseStatus

    @property
    def meeting_response_status(self):
        """Alias for MeetingResponseStatus"""
        return self.MeetingResponseStatus

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def Resolved(self):
        return self.com_object.Resolved

    @property
    def resolved(self):
        """Alias for Resolved"""
        return self.Resolved

    @property
    def Sendable(self):
        return Recipient(self.com_object.Sendable)

    @Sendable.setter
    def Sendable(self, value):
        self.com_object.Sendable = value

    @property
    def sendable(self):
        """Alias for Sendable"""
        return self.Sendable

    @sendable.setter
    def sendable(self, value):
        """Alias for Sendable.setter"""
        self.Sendable = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def TrackingStatus(self):
        return OlTrackingStatus(self.com_object.TrackingStatus)

    @TrackingStatus.setter
    def TrackingStatus(self, value):
        self.com_object.TrackingStatus = value

    @property
    def trackingstatus(self):
        """Alias for TrackingStatus"""
        return self.TrackingStatus

    @trackingstatus.setter
    def trackingstatus(self, value):
        """Alias for TrackingStatus.setter"""
        self.TrackingStatus = value

    @property
    def tracking_status(self):
        """Alias for TrackingStatus"""
        return self.TrackingStatus

    @tracking_status.setter
    def tracking_status(self, value):
        """Alias for TrackingStatus.setter"""
        self.TrackingStatus = value

    @property
    def TrackingStatusTime(self):
        return self.com_object.TrackingStatusTime

    @TrackingStatusTime.setter
    def TrackingStatusTime(self, value):
        self.com_object.TrackingStatusTime = value

    @property
    def trackingstatustime(self):
        """Alias for TrackingStatusTime"""
        return self.TrackingStatusTime

    @trackingstatustime.setter
    def trackingstatustime(self, value):
        """Alias for TrackingStatusTime.setter"""
        self.TrackingStatusTime = value

    @property
    def tracking_status_time(self):
        """Alias for TrackingStatusTime"""
        return self.TrackingStatusTime

    @tracking_status_time.setter
    def tracking_status_time(self, value):
        """Alias for TrackingStatusTime.setter"""
        self.TrackingStatusTime = value

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def FreeBusy(self, Start=None, MinPerChar=None, CompleteFormat=None):
        arguments = com_arguments([unwrap(a) for a in [Start, MinPerChar, CompleteFormat]])
        return self.com_object.FreeBusy(*arguments)

    def freebusy(self, Start=None, MinPerChar=None, CompleteFormat=None):
        """Alias for FreeBusy"""
        arguments = [Start, MinPerChar, CompleteFormat]
        return self.FreeBusy(*arguments)

    def free_busy(self, Start=None, MinPerChar=None, CompleteFormat=None):
        """Alias for FreeBusy"""
        arguments = [Start, MinPerChar, CompleteFormat]
        return self.FreeBusy(*arguments)

    def Resolve(self):
        return self.com_object.Resolve()

    def resolve(self):
        """Alias for Resolve"""
        return self.Resolve()


class Recipients:

    def __init__(self, recipients=None):
        self.com_object= recipients

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Add(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        return Recipient(self.com_object.Add(*arguments))

    def add(self, Name=None):
        """Alias for Add"""
        arguments = [Name]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Recipient(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Remove(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Remove(*arguments)

    def remove(self, Index=None):
        """Alias for Remove"""
        arguments = [Index]
        return self.Remove(*arguments)

    def ResolveAll(self):
        return self.com_object.ResolveAll()

    def resolveall(self):
        """Alias for ResolveAll"""
        return self.ResolveAll()

    def resolve_all(self):
        """Alias for ResolveAll"""
        return self.ResolveAll()


class RecurrencePattern:

    def __init__(self, recurrencepattern=None):
        self.com_object= recurrencepattern

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def DayOfMonth(self):
        return self.com_object.DayOfMonth

    @DayOfMonth.setter
    def DayOfMonth(self, value):
        self.com_object.DayOfMonth = value

    @property
    def dayofmonth(self):
        """Alias for DayOfMonth"""
        return self.DayOfMonth

    @dayofmonth.setter
    def dayofmonth(self, value):
        """Alias for DayOfMonth.setter"""
        self.DayOfMonth = value

    @property
    def day_of_month(self):
        """Alias for DayOfMonth"""
        return self.DayOfMonth

    @day_of_month.setter
    def day_of_month(self, value):
        """Alias for DayOfMonth.setter"""
        self.DayOfMonth = value

    @property
    def DayOfWeekMask(self):
        return OlDaysOfWeek(self.com_object.DayOfWeekMask)

    @DayOfWeekMask.setter
    def DayOfWeekMask(self, value):
        self.com_object.DayOfWeekMask = value

    @property
    def dayofweekmask(self):
        """Alias for DayOfWeekMask"""
        return self.DayOfWeekMask

    @dayofweekmask.setter
    def dayofweekmask(self, value):
        """Alias for DayOfWeekMask.setter"""
        self.DayOfWeekMask = value

    @property
    def day_of_week_mask(self):
        """Alias for DayOfWeekMask"""
        return self.DayOfWeekMask

    @day_of_week_mask.setter
    def day_of_week_mask(self, value):
        """Alias for DayOfWeekMask.setter"""
        self.DayOfWeekMask = value

    @property
    def Duration(self):
        return RecurrencePattern(self.com_object.Duration)

    @Duration.setter
    def Duration(self, value):
        self.com_object.Duration = value

    @property
    def duration(self):
        """Alias for Duration"""
        return self.Duration

    @duration.setter
    def duration(self, value):
        """Alias for Duration.setter"""
        self.Duration = value

    @property
    def EndTime(self):
        return self.com_object.EndTime

    @EndTime.setter
    def EndTime(self, value):
        self.com_object.EndTime = value

    @property
    def endtime(self):
        """Alias for EndTime"""
        return self.EndTime

    @endtime.setter
    def endtime(self, value):
        """Alias for EndTime.setter"""
        self.EndTime = value

    @property
    def end_time(self):
        """Alias for EndTime"""
        return self.EndTime

    @end_time.setter
    def end_time(self, value):
        """Alias for EndTime.setter"""
        self.EndTime = value

    @property
    def Exceptions(self):
        return Exceptions(self.com_object.Exceptions)

    @property
    def exceptions(self):
        """Alias for Exceptions"""
        return self.Exceptions

    @property
    def Instance(self):
        return self.com_object.Instance

    @Instance.setter
    def Instance(self, value):
        self.com_object.Instance = value

    @property
    def instance(self):
        """Alias for Instance"""
        return self.Instance

    @instance.setter
    def instance(self, value):
        """Alias for Instance.setter"""
        self.Instance = value

    @property
    def Interval(self):
        return self.com_object.Interval

    @Interval.setter
    def Interval(self, value):
        self.com_object.Interval = value

    @property
    def interval(self):
        """Alias for Interval"""
        return self.Interval

    @interval.setter
    def interval(self, value):
        """Alias for Interval.setter"""
        self.Interval = value

    @property
    def MonthOfYear(self):
        return self.com_object.MonthOfYear

    @MonthOfYear.setter
    def MonthOfYear(self, value):
        self.com_object.MonthOfYear = value

    @property
    def monthofyear(self):
        """Alias for MonthOfYear"""
        return self.MonthOfYear

    @monthofyear.setter
    def monthofyear(self, value):
        """Alias for MonthOfYear.setter"""
        self.MonthOfYear = value

    @property
    def month_of_year(self):
        """Alias for MonthOfYear"""
        return self.MonthOfYear

    @month_of_year.setter
    def month_of_year(self, value):
        """Alias for MonthOfYear.setter"""
        self.MonthOfYear = value

    @property
    def NoEndDate(self):
        return self.com_object.NoEndDate

    @NoEndDate.setter
    def NoEndDate(self, value):
        self.com_object.NoEndDate = value

    @property
    def noenddate(self):
        """Alias for NoEndDate"""
        return self.NoEndDate

    @noenddate.setter
    def noenddate(self, value):
        """Alias for NoEndDate.setter"""
        self.NoEndDate = value

    @property
    def no_end_date(self):
        """Alias for NoEndDate"""
        return self.NoEndDate

    @no_end_date.setter
    def no_end_date(self, value):
        """Alias for NoEndDate.setter"""
        self.NoEndDate = value

    @property
    def Occurrences(self):
        return self.com_object.Occurrences

    @Occurrences.setter
    def Occurrences(self, value):
        self.com_object.Occurrences = value

    @property
    def occurrences(self):
        """Alias for Occurrences"""
        return self.Occurrences

    @occurrences.setter
    def occurrences(self, value):
        """Alias for Occurrences.setter"""
        self.Occurrences = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PatternEndDate(self):
        return self.com_object.PatternEndDate

    @PatternEndDate.setter
    def PatternEndDate(self, value):
        self.com_object.PatternEndDate = value

    @property
    def patternenddate(self):
        """Alias for PatternEndDate"""
        return self.PatternEndDate

    @patternenddate.setter
    def patternenddate(self, value):
        """Alias for PatternEndDate.setter"""
        self.PatternEndDate = value

    @property
    def pattern_end_date(self):
        """Alias for PatternEndDate"""
        return self.PatternEndDate

    @pattern_end_date.setter
    def pattern_end_date(self, value):
        """Alias for PatternEndDate.setter"""
        self.PatternEndDate = value

    @property
    def PatternStartDate(self):
        return self.com_object.PatternStartDate

    @PatternStartDate.setter
    def PatternStartDate(self, value):
        self.com_object.PatternStartDate = value

    @property
    def patternstartdate(self):
        """Alias for PatternStartDate"""
        return self.PatternStartDate

    @patternstartdate.setter
    def patternstartdate(self, value):
        """Alias for PatternStartDate.setter"""
        self.PatternStartDate = value

    @property
    def pattern_start_date(self):
        """Alias for PatternStartDate"""
        return self.PatternStartDate

    @pattern_start_date.setter
    def pattern_start_date(self, value):
        """Alias for PatternStartDate.setter"""
        self.PatternStartDate = value

    @property
    def RecurrenceType(self):
        return OlRecurrenceType(self.com_object.RecurrenceType)

    @RecurrenceType.setter
    def RecurrenceType(self, value):
        self.com_object.RecurrenceType = value

    @property
    def recurrencetype(self):
        """Alias for RecurrenceType"""
        return self.RecurrenceType

    @recurrencetype.setter
    def recurrencetype(self, value):
        """Alias for RecurrenceType.setter"""
        self.RecurrenceType = value

    @property
    def recurrence_type(self):
        """Alias for RecurrenceType"""
        return self.RecurrenceType

    @recurrence_type.setter
    def recurrence_type(self, value):
        """Alias for RecurrenceType.setter"""
        self.RecurrenceType = value

    @property
    def Regenerate(self):
        return self.com_object.Regenerate

    @Regenerate.setter
    def Regenerate(self, value):
        self.com_object.Regenerate = value

    @property
    def regenerate(self):
        """Alias for Regenerate"""
        return self.Regenerate

    @regenerate.setter
    def regenerate(self, value):
        """Alias for Regenerate.setter"""
        self.Regenerate = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def StartTime(self):
        return self.com_object.StartTime

    @StartTime.setter
    def StartTime(self, value):
        self.com_object.StartTime = value

    @property
    def starttime(self):
        """Alias for StartTime"""
        return self.StartTime

    @starttime.setter
    def starttime(self, value):
        """Alias for StartTime.setter"""
        self.StartTime = value

    @property
    def start_time(self):
        """Alias for StartTime"""
        return self.StartTime

    @start_time.setter
    def start_time(self, value):
        """Alias for StartTime.setter"""
        self.StartTime = value

    def GetOccurrence(self, StartDate=None):
        arguments = com_arguments([unwrap(a) for a in [StartDate]])
        return AppointmentItem(self.com_object.GetOccurrence(*arguments))

    def getoccurrence(self, StartDate=None):
        """Alias for GetOccurrence"""
        arguments = [StartDate]
        return self.GetOccurrence(*arguments)

    def get_occurrence(self, StartDate=None):
        """Alias for GetOccurrence"""
        arguments = [StartDate]
        return self.GetOccurrence(*arguments)


class Reminder:

    def __init__(self, reminder=None):
        self.com_object= reminder

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Caption(self):
        return self.com_object.Caption

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def IsVisible(self):
        return self.com_object.IsVisible

    @property
    def isvisible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @property
    def is_visible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @property
    def Item(self):
        return self.com_object.Item

    @property
    def item(self):
        """Alias for Item"""
        return self.Item

    @property
    def NextReminderDate(self):
        return self.com_object.NextReminderDate

    @property
    def nextreminderdate(self):
        """Alias for NextReminderDate"""
        return self.NextReminderDate

    @property
    def next_reminder_date(self):
        """Alias for NextReminderDate"""
        return self.NextReminderDate

    @property
    def OriginalReminderDate(self):
        return self.com_object.OriginalReminderDate

    @property
    def originalreminderdate(self):
        """Alias for OriginalReminderDate"""
        return self.OriginalReminderDate

    @property
    def original_reminder_date(self):
        """Alias for OriginalReminderDate"""
        return self.OriginalReminderDate

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Dismiss(self):
        self.com_object.Dismiss()

    def dismiss(self):
        """Alias for Dismiss"""
        return self.Dismiss()

    def Snooze(self, SnoozeTime=None):
        arguments = com_arguments([unwrap(a) for a in [SnoozeTime]])
        self.com_object.Snooze(*arguments)

    def snooze(self, SnoozeTime=None):
        """Alias for Snooze"""
        arguments = [SnoozeTime]
        return self.Snooze(*arguments)


class Reminders:

    def __init__(self, reminders=None):
        self.com_object= reminders

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Reminder(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Remove(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Remove(*arguments)

    def remove(self, Index=None):
        """Alias for Remove"""
        arguments = [Index]
        return self.Remove(*arguments)


class RemoteItem:

    def __init__(self, remoteitem=None):
        self.com_object= remoteitem

    @property
    def Actions(self):
        return Actions(self.com_object.Actions)

    @property
    def actions(self):
        """Alias for Actions"""
        return self.Actions

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Attachments(self):
        return Attachments(self.com_object.Attachments)

    @property
    def attachments(self):
        """Alias for Attachments"""
        return self.Attachments

    @property
    def AutoResolvedWinner(self):
        return self.com_object.AutoResolvedWinner

    @property
    def autoresolvedwinner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def auto_resolved_winner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def BillingInformation(self):
        return self.com_object.BillingInformation

    @BillingInformation.setter
    def BillingInformation(self, value):
        self.com_object.BillingInformation = value

    @property
    def billinginformation(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billinginformation.setter
    def billinginformation(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def billing_information(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billing_information.setter
    def billing_information(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def Body(self):
        return self.com_object.Body

    @Body.setter
    def Body(self, value):
        self.com_object.Body = value

    @property
    def body(self):
        """Alias for Body"""
        return self.Body

    @body.setter
    def body(self, value):
        """Alias for Body.setter"""
        self.Body = value

    @property
    def Categories(self):
        return self.com_object.Categories

    @Categories.setter
    def Categories(self, value):
        self.com_object.Categories = value

    @property
    def categories(self):
        """Alias for Categories"""
        return self.Categories

    @categories.setter
    def categories(self, value):
        """Alias for Categories.setter"""
        self.Categories = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Companies(self):
        return self.com_object.Companies

    @Companies.setter
    def Companies(self, value):
        self.com_object.Companies = value

    @property
    def companies(self):
        """Alias for Companies"""
        return self.Companies

    @companies.setter
    def companies(self, value):
        """Alias for Companies.setter"""
        self.Companies = value

    @property
    def Conflicts(self):
        return self.com_object.Conflicts

    @property
    def conflicts(self):
        """Alias for Conflicts"""
        return self.Conflicts

    @property
    def ConversationID(self):
        return Conversation(self.com_object.ConversationID)

    @property
    def conversationid(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def conversation_i_d(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def ConversationIndex(self):
        return self.com_object.ConversationIndex

    @property
    def conversationindex(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def conversation_index(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def ConversationTopic(self):
        return self.com_object.ConversationTopic

    @property
    def conversationtopic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def conversation_topic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def CreationTime(self):
        return self.com_object.CreationTime

    @property
    def creationtime(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def creation_time(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def DownloadState(self):
        return OlDownloadState(self.com_object.DownloadState)

    @property
    def downloadstate(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def download_state(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def EntryID(self):
        return self.com_object.EntryID

    @property
    def entryid(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def entry_i_d(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def FormDescription(self):
        return FormDescription(self.com_object.FormDescription)

    @property
    def formdescription(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def form_description(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def GetInspector(self):
        return Inspector(self.com_object.GetInspector)

    @property
    def getinspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def get_inspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def HasAttachment(self):
        return self.com_object.HasAttachment

    @property
    def hasattachment(self):
        """Alias for HasAttachment"""
        return self.HasAttachment

    @property
    def has_attachment(self):
        """Alias for HasAttachment"""
        return self.HasAttachment

    @property
    def Importance(self):
        return OlImportance(self.com_object.Importance)

    @Importance.setter
    def Importance(self, value):
        self.com_object.Importance = value

    @property
    def importance(self):
        """Alias for Importance"""
        return self.Importance

    @importance.setter
    def importance(self, value):
        """Alias for Importance.setter"""
        self.Importance = value

    @property
    def IsConflict(self):
        return self.com_object.IsConflict

    @property
    def isconflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def is_conflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def ItemProperties(self):
        return ItemProperties(self.com_object.ItemProperties)

    @property
    def itemproperties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def item_properties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def LastModificationTime(self):
        return self.com_object.LastModificationTime

    @property
    def lastmodificationtime(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def last_modification_time(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def MarkForDownload(self):
        return OlRemoteStatus(self.com_object.MarkForDownload)

    @MarkForDownload.setter
    def MarkForDownload(self, value):
        self.com_object.MarkForDownload = value

    @property
    def markfordownload(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @markfordownload.setter
    def markfordownload(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def mark_for_download(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @mark_for_download.setter
    def mark_for_download(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def MessageClass(self):
        return self.com_object.MessageClass

    @MessageClass.setter
    def MessageClass(self, value):
        self.com_object.MessageClass = value

    @property
    def messageclass(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @messageclass.setter
    def messageclass(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def message_class(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @message_class.setter
    def message_class(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def Mileage(self):
        return self.com_object.Mileage

    @Mileage.setter
    def Mileage(self, value):
        self.com_object.Mileage = value

    @property
    def mileage(self):
        """Alias for Mileage"""
        return self.Mileage

    @mileage.setter
    def mileage(self, value):
        """Alias for Mileage.setter"""
        self.Mileage = value

    @property
    def NoAging(self):
        return self.com_object.NoAging

    @NoAging.setter
    def NoAging(self, value):
        self.com_object.NoAging = value

    @property
    def noaging(self):
        """Alias for NoAging"""
        return self.NoAging

    @noaging.setter
    def noaging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def no_aging(self):
        """Alias for NoAging"""
        return self.NoAging

    @no_aging.setter
    def no_aging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def OutlookInternalVersion(self):
        return self.com_object.OutlookInternalVersion

    @property
    def outlookinternalversion(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def outlook_internal_version(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def OutlookVersion(self):
        return self.com_object.OutlookVersion

    @property
    def outlookversion(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def outlook_version(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def RemoteMessageClass(self):
        return self.com_object.RemoteMessageClass

    @property
    def remotemessageclass(self):
        """Alias for RemoteMessageClass"""
        return self.RemoteMessageClass

    @property
    def remote_message_class(self):
        """Alias for RemoteMessageClass"""
        return self.RemoteMessageClass

    @property
    def Saved(self):
        return self.com_object.Saved

    @property
    def saved(self):
        """Alias for Saved"""
        return self.Saved

    @property
    def Sensitivity(self):
        return OlSensitivity(self.com_object.Sensitivity)

    @Sensitivity.setter
    def Sensitivity(self, value):
        self.com_object.Sensitivity = value

    @property
    def sensitivity(self):
        """Alias for Sensitivity"""
        return self.Sensitivity

    @sensitivity.setter
    def sensitivity(self, value):
        """Alias for Sensitivity.setter"""
        self.Sensitivity = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Size(self):
        return self.com_object.Size

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @property
    def Subject(self):
        return self.com_object.Subject

    @Subject.setter
    def Subject(self, value):
        self.com_object.Subject = value

    @property
    def subject(self):
        """Alias for Subject"""
        return self.Subject

    @subject.setter
    def subject(self, value):
        """Alias for Subject.setter"""
        self.Subject = value

    @property
    def TransferSize(self):
        return self.com_object.TransferSize

    @property
    def transfersize(self):
        """Alias for TransferSize"""
        return self.TransferSize

    @property
    def transfer_size(self):
        """Alias for TransferSize"""
        return self.TransferSize

    @property
    def TransferTime(self):
        return self.com_object.TransferTime

    @property
    def transfertime(self):
        """Alias for TransferTime"""
        return self.TransferTime

    @property
    def transfer_time(self):
        """Alias for TransferTime"""
        return self.TransferTime

    @property
    def UnRead(self):
        return self.com_object.UnRead

    @UnRead.setter
    def UnRead(self, value):
        self.com_object.UnRead = value

    @property
    def unread(self):
        """Alias for UnRead"""
        return self.UnRead

    @unread.setter
    def unread(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def un_read(self):
        """Alias for UnRead"""
        return self.UnRead

    @un_read.setter
    def un_read(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def UserProperties(self):
        return UserProperties(self.com_object.UserProperties)

    @property
    def userproperties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    @property
    def user_properties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    def Close(self, SaveMode=None):
        arguments = com_arguments([unwrap(a) for a in [SaveMode]])
        self.com_object.Close(*arguments)

    def close(self, SaveMode=None):
        """Alias for Close"""
        arguments = [SaveMode]
        return self.Close(*arguments)

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Display(self, Modal=None):
        arguments = com_arguments([unwrap(a) for a in [Modal]])
        self.com_object.Display(*arguments)

    def display(self, Modal=None):
        """Alias for Display"""
        arguments = [Modal]
        return self.Display(*arguments)

    def GetConversation(self):
        return Conversation(self.com_object.GetConversation())

    def getconversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def get_conversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def Move(self, DestFldr=None):
        arguments = com_arguments([unwrap(a) for a in [DestFldr]])
        return self.com_object.Move(*arguments)

    def move(self, DestFldr=None):
        """Alias for Move"""
        arguments = [DestFldr]
        return self.Move(*arguments)

    def PrintOut(self):
        self.com_object.PrintOut()

    def printout(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def print_out(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()

    def SaveAs(self, Path=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Path, Type]])
        self.com_object.SaveAs(*arguments)

    def saveas(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def save_as(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def ShowCategoriesDialog(self):
        self.com_object.ShowCategoriesDialog()

    def showcategoriesdialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()

    def show_categories_dialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()


class ReportItem:

    def __init__(self, reportitem=None):
        self.com_object= reportitem

    @property
    def Actions(self):
        return Actions(self.com_object.Actions)

    @property
    def actions(self):
        """Alias for Actions"""
        return self.Actions

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Attachments(self):
        return Attachments(self.com_object.Attachments)

    @property
    def attachments(self):
        """Alias for Attachments"""
        return self.Attachments

    @property
    def AutoResolvedWinner(self):
        return self.com_object.AutoResolvedWinner

    @property
    def autoresolvedwinner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def auto_resolved_winner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def BillingInformation(self):
        return self.com_object.BillingInformation

    @BillingInformation.setter
    def BillingInformation(self, value):
        self.com_object.BillingInformation = value

    @property
    def billinginformation(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billinginformation.setter
    def billinginformation(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def billing_information(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billing_information.setter
    def billing_information(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def Body(self):
        return self.com_object.Body

    @Body.setter
    def Body(self, value):
        self.com_object.Body = value

    @property
    def body(self):
        """Alias for Body"""
        return self.Body

    @body.setter
    def body(self, value):
        """Alias for Body.setter"""
        self.Body = value

    @property
    def Categories(self):
        return self.com_object.Categories

    @Categories.setter
    def Categories(self, value):
        self.com_object.Categories = value

    @property
    def categories(self):
        """Alias for Categories"""
        return self.Categories

    @categories.setter
    def categories(self, value):
        """Alias for Categories.setter"""
        self.Categories = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Companies(self):
        return self.com_object.Companies

    @Companies.setter
    def Companies(self, value):
        self.com_object.Companies = value

    @property
    def companies(self):
        """Alias for Companies"""
        return self.Companies

    @companies.setter
    def companies(self, value):
        """Alias for Companies.setter"""
        self.Companies = value

    @property
    def Conflicts(self):
        return self.com_object.Conflicts

    @property
    def conflicts(self):
        """Alias for Conflicts"""
        return self.Conflicts

    @property
    def ConversationID(self):
        return Conversation(self.com_object.ConversationID)

    @property
    def conversationid(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def conversation_i_d(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def ConversationIndex(self):
        return self.com_object.ConversationIndex

    @property
    def conversationindex(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def conversation_index(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def ConversationTopic(self):
        return self.com_object.ConversationTopic

    @property
    def conversationtopic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def conversation_topic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def CreationTime(self):
        return self.com_object.CreationTime

    @property
    def creationtime(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def creation_time(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def DownloadState(self):
        return OlDownloadState(self.com_object.DownloadState)

    @property
    def downloadstate(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def download_state(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def EntryID(self):
        return self.com_object.EntryID

    @property
    def entryid(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def entry_i_d(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def FormDescription(self):
        return FormDescription(self.com_object.FormDescription)

    @property
    def formdescription(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def form_description(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def GetInspector(self):
        return Inspector(self.com_object.GetInspector)

    @property
    def getinspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def get_inspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def Importance(self):
        return OlImportance(self.com_object.Importance)

    @Importance.setter
    def Importance(self, value):
        self.com_object.Importance = value

    @property
    def importance(self):
        """Alias for Importance"""
        return self.Importance

    @importance.setter
    def importance(self, value):
        """Alias for Importance.setter"""
        self.Importance = value

    @property
    def IsConflict(self):
        return self.com_object.IsConflict

    @property
    def isconflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def is_conflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def ItemProperties(self):
        return ItemProperties(self.com_object.ItemProperties)

    @property
    def itemproperties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def item_properties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def LastModificationTime(self):
        return self.com_object.LastModificationTime

    @property
    def lastmodificationtime(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def last_modification_time(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def MarkForDownload(self):
        return OlRemoteStatus(self.com_object.MarkForDownload)

    @MarkForDownload.setter
    def MarkForDownload(self, value):
        self.com_object.MarkForDownload = value

    @property
    def markfordownload(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @markfordownload.setter
    def markfordownload(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def mark_for_download(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @mark_for_download.setter
    def mark_for_download(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def MessageClass(self):
        return self.com_object.MessageClass

    @MessageClass.setter
    def MessageClass(self, value):
        self.com_object.MessageClass = value

    @property
    def messageclass(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @messageclass.setter
    def messageclass(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def message_class(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @message_class.setter
    def message_class(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def Mileage(self):
        return self.com_object.Mileage

    @Mileage.setter
    def Mileage(self, value):
        self.com_object.Mileage = value

    @property
    def mileage(self):
        """Alias for Mileage"""
        return self.Mileage

    @mileage.setter
    def mileage(self, value):
        """Alias for Mileage.setter"""
        self.Mileage = value

    @property
    def NoAging(self):
        return self.com_object.NoAging

    @NoAging.setter
    def NoAging(self, value):
        self.com_object.NoAging = value

    @property
    def noaging(self):
        """Alias for NoAging"""
        return self.NoAging

    @noaging.setter
    def noaging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def no_aging(self):
        """Alias for NoAging"""
        return self.NoAging

    @no_aging.setter
    def no_aging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def OutlookInternalVersion(self):
        return self.com_object.OutlookInternalVersion

    @property
    def outlookinternalversion(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def outlook_internal_version(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def OutlookVersion(self):
        return self.com_object.OutlookVersion

    @property
    def outlookversion(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def outlook_version(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def RetentionExpirationDate(self):
        return ReportItem(self.com_object.RetentionExpirationDate)

    @property
    def retentionexpirationdate(self):
        """Alias for RetentionExpirationDate"""
        return self.RetentionExpirationDate

    @property
    def retention_expiration_date(self):
        """Alias for RetentionExpirationDate"""
        return self.RetentionExpirationDate

    @property
    def RetentionPolicyName(self):
        return self.com_object.RetentionPolicyName

    @property
    def retentionpolicyname(self):
        """Alias for RetentionPolicyName"""
        return self.RetentionPolicyName

    @property
    def retention_policy_name(self):
        """Alias for RetentionPolicyName"""
        return self.RetentionPolicyName

    @property
    def Saved(self):
        return self.com_object.Saved

    @property
    def saved(self):
        """Alias for Saved"""
        return self.Saved

    @property
    def Sensitivity(self):
        return OlSensitivity(self.com_object.Sensitivity)

    @Sensitivity.setter
    def Sensitivity(self, value):
        self.com_object.Sensitivity = value

    @property
    def sensitivity(self):
        """Alias for Sensitivity"""
        return self.Sensitivity

    @sensitivity.setter
    def sensitivity(self, value):
        """Alias for Sensitivity.setter"""
        self.Sensitivity = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Size(self):
        return self.com_object.Size

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @property
    def Subject(self):
        return self.com_object.Subject

    @Subject.setter
    def Subject(self, value):
        self.com_object.Subject = value

    @property
    def subject(self):
        """Alias for Subject"""
        return self.Subject

    @subject.setter
    def subject(self, value):
        """Alias for Subject.setter"""
        self.Subject = value

    @property
    def UnRead(self):
        return self.com_object.UnRead

    @UnRead.setter
    def UnRead(self, value):
        self.com_object.UnRead = value

    @property
    def unread(self):
        """Alias for UnRead"""
        return self.UnRead

    @unread.setter
    def unread(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def un_read(self):
        """Alias for UnRead"""
        return self.UnRead

    @un_read.setter
    def un_read(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def UserProperties(self):
        return UserProperties(self.com_object.UserProperties)

    @property
    def userproperties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    @property
    def user_properties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    def Close(self, SaveMode=None):
        arguments = com_arguments([unwrap(a) for a in [SaveMode]])
        self.com_object.Close(*arguments)

    def close(self, SaveMode=None):
        """Alias for Close"""
        arguments = [SaveMode]
        return self.Close(*arguments)

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Display(self, Modal=None):
        arguments = com_arguments([unwrap(a) for a in [Modal]])
        self.com_object.Display(*arguments)

    def display(self, Modal=None):
        """Alias for Display"""
        arguments = [Modal]
        return self.Display(*arguments)

    def GetConversation(self):
        return Conversation(self.com_object.GetConversation())

    def getconversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def get_conversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def Move(self, DestFldr=None):
        arguments = com_arguments([unwrap(a) for a in [DestFldr]])
        return self.com_object.Move(*arguments)

    def move(self, DestFldr=None):
        """Alias for Move"""
        arguments = [DestFldr]
        return self.Move(*arguments)

    def PrintOut(self):
        self.com_object.PrintOut()

    def printout(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def print_out(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()

    def SaveAs(self, Path=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Path, Type]])
        self.com_object.SaveAs(*arguments)

    def saveas(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def save_as(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def ShowCategoriesDialog(self):
        self.com_object.ShowCategoriesDialog()

    def showcategoriesdialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()

    def show_categories_dialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()


class Results:

    def __init__(self, results=None):
        self.com_object= results

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def DefaultItemType(self):
        return OlItemType(self.com_object.DefaultItemType)

    @DefaultItemType.setter
    def DefaultItemType(self, value):
        self.com_object.DefaultItemType = value

    @property
    def defaultitemtype(self):
        """Alias for DefaultItemType"""
        return self.DefaultItemType

    @defaultitemtype.setter
    def defaultitemtype(self, value):
        """Alias for DefaultItemType.setter"""
        self.DefaultItemType = value

    @property
    def default_item_type(self):
        """Alias for DefaultItemType"""
        return self.DefaultItemType

    @default_item_type.setter
    def default_item_type(self, value):
        """Alias for DefaultItemType.setter"""
        self.DefaultItemType = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def GetFirst(self):
        return self.com_object.GetFirst()

    def getfirst(self):
        """Alias for GetFirst"""
        return self.GetFirst()

    def get_first(self):
        """Alias for GetFirst"""
        return self.GetFirst()

    def GetLast(self):
        return self.com_object.GetLast()

    def getlast(self):
        """Alias for GetLast"""
        return self.GetLast()

    def get_last(self):
        """Alias for GetLast"""
        return self.GetLast()

    def GetNext(self):
        return self.com_object.GetNext()

    def getnext(self):
        """Alias for GetNext"""
        return self.GetNext()

    def get_next(self):
        """Alias for GetNext"""
        return self.GetNext()

    def GetPrevious(self):
        return self.com_object.GetPrevious()

    def getprevious(self):
        """Alias for GetPrevious"""
        return self.GetPrevious()

    def get_previous(self):
        """Alias for GetPrevious"""
        return self.GetPrevious()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def ResetColumns(self):
        self.com_object.ResetColumns()

    def resetcolumns(self):
        """Alias for ResetColumns"""
        return self.ResetColumns()

    def reset_columns(self):
        """Alias for ResetColumns"""
        return self.ResetColumns()

    def SetColumns(self, Columns=None):
        arguments = com_arguments([unwrap(a) for a in [Columns]])
        self.com_object.SetColumns(*arguments)

    def setcolumns(self, Columns=None):
        """Alias for SetColumns"""
        arguments = [Columns]
        return self.SetColumns(*arguments)

    def set_columns(self, Columns=None):
        """Alias for SetColumns"""
        arguments = [Columns]
        return self.SetColumns(*arguments)

    def Sort(self, Property=None, Descending=None):
        arguments = com_arguments([unwrap(a) for a in [Property, Descending]])
        self.com_object.Sort(*arguments)

    def sort(self, Property=None, Descending=None):
        """Alias for Sort"""
        arguments = [Property, Descending]
        return self.Sort(*arguments)


class Row:

    def __init__(self, row=None):
        self.com_object= row

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Parent(self):
        return Row(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def BinaryToString(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.BinaryToString(*arguments)

    def binarytostring(self, Index=None):
        """Alias for BinaryToString"""
        arguments = [Index]
        return self.BinaryToString(*arguments)

    def binary_to_string(self, Index=None):
        """Alias for BinaryToString"""
        arguments = [Index]
        return self.BinaryToString(*arguments)

    def GetValues(self):
        return self.com_object.GetValues()

    def getvalues(self):
        """Alias for GetValues"""
        return self.GetValues()

    def get_values(self):
        """Alias for GetValues"""
        return self.GetValues()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def LocalTimeToUTC(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.LocalTimeToUTC(*arguments)

    def localtimetoutc(self, Index=None):
        """Alias for LocalTimeToUTC"""
        arguments = [Index]
        return self.LocalTimeToUTC(*arguments)

    def local_time_to_u_t_c(self, Index=None):
        """Alias for LocalTimeToUTC"""
        arguments = [Index]
        return self.LocalTimeToUTC(*arguments)

    def UTCToLocalTime(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.UTCToLocalTime(*arguments)

    def utctolocaltime(self, Index=None):
        """Alias for UTCToLocalTime"""
        arguments = [Index]
        return self.UTCToLocalTime(*arguments)

    def u_t_c_to_local_time(self, Index=None):
        """Alias for UTCToLocalTime"""
        arguments = [Index]
        return self.UTCToLocalTime(*arguments)


class Rule:

    def __init__(self, rule=None):
        self.com_object= rule

    @property
    def Actions(self):
        return RuleActions(self.com_object.Actions)

    @property
    def actions(self):
        """Alias for Actions"""
        return self.Actions

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Conditions(self):
        return RuleConditions(self.com_object.Conditions)

    @property
    def conditions(self):
        """Alias for Conditions"""
        return self.Conditions

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Exceptions(self):
        return RuleConditions(self.com_object.Exceptions)

    @property
    def exceptions(self):
        """Alias for Exceptions"""
        return self.Exceptions

    @property
    def ExecutionOrder(self):
        return Rules(self.com_object.ExecutionOrder)

    @ExecutionOrder.setter
    def ExecutionOrder(self, value):
        self.com_object.ExecutionOrder = value

    @property
    def executionorder(self):
        """Alias for ExecutionOrder"""
        return self.ExecutionOrder

    @executionorder.setter
    def executionorder(self, value):
        """Alias for ExecutionOrder.setter"""
        self.ExecutionOrder = value

    @property
    def execution_order(self):
        """Alias for ExecutionOrder"""
        return self.ExecutionOrder

    @execution_order.setter
    def execution_order(self, value):
        """Alias for ExecutionOrder.setter"""
        self.ExecutionOrder = value

    @property
    def IsLocalRule(self):
        return self.com_object.IsLocalRule

    @property
    def islocalrule(self):
        """Alias for IsLocalRule"""
        return self.IsLocalRule

    @property
    def is_local_rule(self):
        """Alias for IsLocalRule"""
        return self.IsLocalRule

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RuleType(self):
        return OlRuleType(self.com_object.RuleType)

    @property
    def ruletype(self):
        """Alias for RuleType"""
        return self.RuleType

    @property
    def rule_type(self):
        """Alias for RuleType"""
        return self.RuleType

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Execute(self, ShowProgress=None, Folder=None, IncludeSubfolders=None, RuleExecuteOption=None):
        arguments = com_arguments([unwrap(a) for a in [ShowProgress, Folder, IncludeSubfolders, RuleExecuteOption]])
        self.com_object.Execute(*arguments)

    def execute(self, ShowProgress=None, Folder=None, IncludeSubfolders=None, RuleExecuteOption=None):
        """Alias for Execute"""
        arguments = [ShowProgress, Folder, IncludeSubfolders, RuleExecuteOption]
        return self.Execute(*arguments)


class RuleAction:

    def __init__(self, ruleaction=None):
        self.com_object= ruleaction

    @property
    def ActionType(self):
        return OlRuleActionType(self.com_object.ActionType)

    @property
    def actiontype(self):
        """Alias for ActionType"""
        return self.ActionType

    @property
    def action_type(self):
        """Alias for ActionType"""
        return self.ActionType

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Enabled(self):
        return RuleAction(self.com_object.Enabled)

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session


class RuleActions:

    def __init__(self, ruleactions=None):
        self.com_object= ruleactions

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AssignToCategory(self):
        return AssignToCategoryRuleAction(self.com_object.AssignToCategory)

    @property
    def assigntocategory(self):
        """Alias for AssignToCategory"""
        return self.AssignToCategory

    @property
    def assign_to_category(self):
        """Alias for AssignToCategory"""
        return self.AssignToCategory

    @property
    def CC(self):
        return SendRuleAction(self.com_object.CC)

    @property
    def cc(self):
        """Alias for CC"""
        return self.CC

    @property
    def c_c(self):
        """Alias for CC"""
        return self.CC

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def ClearCategories(self):
        return RuleAction(self.com_object.ClearCategories)

    @property
    def clearcategories(self):
        """Alias for ClearCategories"""
        return self.ClearCategories

    @property
    def clear_categories(self):
        """Alias for ClearCategories"""
        return self.ClearCategories

    @property
    def CopyToFolder(self):
        return MoveOrCopyRuleAction(self.com_object.CopyToFolder)

    @property
    def copytofolder(self):
        """Alias for CopyToFolder"""
        return self.CopyToFolder

    @property
    def copy_to_folder(self):
        """Alias for CopyToFolder"""
        return self.CopyToFolder

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Delete(self):
        return RuleAction(self.com_object.Delete)

    @property
    def delete(self):
        """Alias for Delete"""
        return self.Delete

    @property
    def DeletePermanently(self):
        return RuleAction(self.com_object.DeletePermanently)

    @property
    def deletepermanently(self):
        """Alias for DeletePermanently"""
        return self.DeletePermanently

    @property
    def delete_permanently(self):
        """Alias for DeletePermanently"""
        return self.DeletePermanently

    @property
    def DesktopAlert(self):
        return RuleAction(self.com_object.DesktopAlert)

    @property
    def desktopalert(self):
        """Alias for DesktopAlert"""
        return self.DesktopAlert

    @property
    def desktop_alert(self):
        """Alias for DesktopAlert"""
        return self.DesktopAlert

    @property
    def Forward(self):
        return SendRuleAction(self.com_object.Forward)

    @property
    def forward(self):
        """Alias for Forward"""
        return self.Forward

    @property
    def ForwardAsAttachment(self):
        return SendRuleAction(self.com_object.ForwardAsAttachment)

    @property
    def forwardasattachment(self):
        """Alias for ForwardAsAttachment"""
        return self.ForwardAsAttachment

    @property
    def forward_as_attachment(self):
        """Alias for ForwardAsAttachment"""
        return self.ForwardAsAttachment

    @property
    def MarkAsTask(self):
        return MarkAsTaskRuleAction(self.com_object.MarkAsTask)

    @property
    def markastask(self):
        """Alias for MarkAsTask"""
        return self.MarkAsTask

    @property
    def mark_as_task(self):
        """Alias for MarkAsTask"""
        return self.MarkAsTask

    @property
    def MoveToFolder(self):
        return MoveOrCopyRuleAction(self.com_object.MoveToFolder)

    @property
    def movetofolder(self):
        """Alias for MoveToFolder"""
        return self.MoveToFolder

    @property
    def move_to_folder(self):
        """Alias for MoveToFolder"""
        return self.MoveToFolder

    @property
    def NewItemAlert(self):
        return NewItemAlertRuleAction(self.com_object.NewItemAlert)

    @property
    def newitemalert(self):
        """Alias for NewItemAlert"""
        return self.NewItemAlert

    @property
    def new_item_alert(self):
        """Alias for NewItemAlert"""
        return self.NewItemAlert

    @property
    def NotifyDelivery(self):
        return RuleAction(self.com_object.NotifyDelivery)

    @property
    def notifydelivery(self):
        """Alias for NotifyDelivery"""
        return self.NotifyDelivery

    @property
    def notify_delivery(self):
        """Alias for NotifyDelivery"""
        return self.NotifyDelivery

    @property
    def NotifyRead(self):
        return RuleAction(self.com_object.NotifyRead)

    @property
    def notifyread(self):
        """Alias for NotifyRead"""
        return self.NotifyRead

    @property
    def notify_read(self):
        """Alias for NotifyRead"""
        return self.NotifyRead

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PlaySound(self):
        return PlaySoundRuleAction(self.com_object.PlaySound)

    @property
    def playsound(self):
        """Alias for PlaySound"""
        return self.PlaySound

    @property
    def play_sound(self):
        """Alias for PlaySound"""
        return self.PlaySound

    @property
    def Redirect(self):
        return SendRuleAction(self.com_object.Redirect)

    @property
    def redirect(self):
        """Alias for Redirect"""
        return self.Redirect

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Stop(self):
        return RuleAction(self.com_object.Stop)

    @property
    def stop(self):
        """Alias for Stop"""
        return self.Stop

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return RuleAction(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class RuleCondition:

    def __init__(self, rulecondition=None):
        self.com_object= rulecondition

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def ConditionType(self):
        return OlRuleConditionType(self.com_object.ConditionType)

    @property
    def conditiontype(self):
        """Alias for ConditionType"""
        return self.ConditionType

    @property
    def condition_type(self):
        """Alias for ConditionType"""
        return self.ConditionType

    @property
    def Enabled(self):
        return RuleCondition(self.com_object.Enabled)

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session


class RuleConditions:

    def __init__(self, ruleconditions=None):
        self.com_object= ruleconditions

    @property
    def Account(self):
        return AccountRuleCondition(self.com_object.Account)

    @property
    def account(self):
        """Alias for Account"""
        return self.Account

    @property
    def AnyCategory(self):
        return RuleCondition(self.com_object.AnyCategory)

    @property
    def anycategory(self):
        """Alias for AnyCategory"""
        return self.AnyCategory

    @property
    def any_category(self):
        """Alias for AnyCategory"""
        return self.AnyCategory

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Body(self):
        return TextRuleCondition(self.com_object.Body)

    @property
    def body(self):
        """Alias for Body"""
        return self.Body

    @property
    def BodyOrSubject(self):
        return TextRuleCondition(self.com_object.BodyOrSubject)

    @property
    def bodyorsubject(self):
        """Alias for BodyOrSubject"""
        return self.BodyOrSubject

    @property
    def body_or_subject(self):
        """Alias for BodyOrSubject"""
        return self.BodyOrSubject

    @property
    def Category(self):
        return CategoryRuleCondition(self.com_object.Category)

    @property
    def category(self):
        """Alias for Category"""
        return self.Category

    @property
    def CC(self):
        return RuleCondition(self.com_object.CC)

    @property
    def cc(self):
        """Alias for CC"""
        return self.CC

    @property
    def c_c(self):
        """Alias for CC"""
        return self.CC

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def FormName(self):
        return FormNameRuleCondition(self.com_object.FormName)

    @property
    def formname(self):
        """Alias for FormName"""
        return self.FormName

    @property
    def form_name(self):
        """Alias for FormName"""
        return self.FormName

    @property
    def From(self):
        return ToOrFromRuleCondition(self.com_object.From)

    @property
    def FromAnyRSSFeed(self):
        return RuleCondition(self.com_object.FromAnyRSSFeed)

    @property
    def fromanyrssfeed(self):
        """Alias for FromAnyRSSFeed"""
        return self.FromAnyRSSFeed

    @property
    def from_any_r_s_s_feed(self):
        """Alias for FromAnyRSSFeed"""
        return self.FromAnyRSSFeed

    @property
    def FromRssFeed(self):
        return FromRssFeedRuleCondition(self.com_object.FromRssFeed)

    @property
    def fromrssfeed(self):
        """Alias for FromRssFeed"""
        return self.FromRssFeed

    @property
    def from_rss_feed(self):
        """Alias for FromRssFeed"""
        return self.FromRssFeed

    @property
    def HasAttachment(self):
        return RuleCondition(self.com_object.HasAttachment)

    @property
    def hasattachment(self):
        """Alias for HasAttachment"""
        return self.HasAttachment

    @property
    def has_attachment(self):
        """Alias for HasAttachment"""
        return self.HasAttachment

    @property
    def Importance(self):
        return ImportanceRuleCondition(self.com_object.Importance)

    @property
    def importance(self):
        """Alias for Importance"""
        return self.Importance

    @property
    def MeetingInviteOrUpdate(self):
        return RuleCondition(self.com_object.MeetingInviteOrUpdate)

    @property
    def meetinginviteorupdate(self):
        """Alias for MeetingInviteOrUpdate"""
        return self.MeetingInviteOrUpdate

    @property
    def meeting_invite_or_update(self):
        """Alias for MeetingInviteOrUpdate"""
        return self.MeetingInviteOrUpdate

    @property
    def MessageHeader(self):
        return TextRuleCondition(self.com_object.MessageHeader)

    @property
    def messageheader(self):
        """Alias for MessageHeader"""
        return self.MessageHeader

    @property
    def message_header(self):
        """Alias for MessageHeader"""
        return self.MessageHeader

    @property
    def NotTo(self):
        return RuleCondition(self.com_object.NotTo)

    @property
    def notto(self):
        """Alias for NotTo"""
        return self.NotTo

    @property
    def not_to(self):
        """Alias for NotTo"""
        return self.NotTo

    @property
    def OnLocalMachine(self):
        return RuleCondition(self.com_object.OnLocalMachine)

    @property
    def onlocalmachine(self):
        """Alias for OnLocalMachine"""
        return self.OnLocalMachine

    @property
    def on_local_machine(self):
        """Alias for OnLocalMachine"""
        return self.OnLocalMachine

    @property
    def OnlyToMe(self):
        return RuleCondition(self.com_object.OnlyToMe)

    @property
    def onlytome(self):
        """Alias for OnlyToMe"""
        return self.OnlyToMe

    @property
    def only_to_me(self):
        """Alias for OnlyToMe"""
        return self.OnlyToMe

    @property
    def OnOtherMachine(self):
        return RuleCondition(self.com_object.OnOtherMachine)

    @property
    def onothermachine(self):
        """Alias for OnOtherMachine"""
        return self.OnOtherMachine

    @property
    def on_other_machine(self):
        """Alias for OnOtherMachine"""
        return self.OnOtherMachine

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RecipientAddress(self):
        return AddressRuleCondition(self.com_object.RecipientAddress)

    @property
    def recipientaddress(self):
        """Alias for RecipientAddress"""
        return self.RecipientAddress

    @property
    def recipient_address(self):
        """Alias for RecipientAddress"""
        return self.RecipientAddress

    @property
    def SenderAddress(self):
        return AddressRuleCondition(self.com_object.SenderAddress)

    @property
    def senderaddress(self):
        """Alias for SenderAddress"""
        return self.SenderAddress

    @property
    def sender_address(self):
        """Alias for SenderAddress"""
        return self.SenderAddress

    @property
    def SenderInAddressList(self):
        return SenderInAddressListRuleCondition(self.com_object.SenderInAddressList)

    @property
    def senderinaddresslist(self):
        """Alias for SenderInAddressList"""
        return self.SenderInAddressList

    @property
    def sender_in_address_list(self):
        """Alias for SenderInAddressList"""
        return self.SenderInAddressList

    @property
    def SentTo(self):
        return ToOrFromRuleCondition(self.com_object.SentTo)

    @property
    def sentto(self):
        """Alias for SentTo"""
        return self.SentTo

    @property
    def sent_to(self):
        """Alias for SentTo"""
        return self.SentTo

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Subject(self):
        return TextRuleCondition(self.com_object.Subject)

    @property
    def subject(self):
        """Alias for Subject"""
        return self.Subject

    @property
    def ToMe(self):
        return RuleCondition(self.com_object.ToMe)

    @property
    def tome(self):
        """Alias for ToMe"""
        return self.ToMe

    @property
    def to_me(self):
        """Alias for ToMe"""
        return self.ToMe

    @property
    def ToOrCc(self):
        return RuleCondition(self.com_object.ToOrCc)

    @property
    def toorcc(self):
        """Alias for ToOrCc"""
        return self.ToOrCc

    @property
    def to_or_cc(self):
        """Alias for ToOrCc"""
        return self.ToOrCc

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return RuleCondition(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Rules:

    def __init__(self, rules=None):
        self.com_object= rules

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def IsRssRulesProcessingEnabled(self):
        return self.com_object.IsRssRulesProcessingEnabled

    @IsRssRulesProcessingEnabled.setter
    def IsRssRulesProcessingEnabled(self, value):
        self.com_object.IsRssRulesProcessingEnabled = value

    @property
    def isrssrulesprocessingenabled(self):
        """Alias for IsRssRulesProcessingEnabled"""
        return self.IsRssRulesProcessingEnabled

    @isrssrulesprocessingenabled.setter
    def isrssrulesprocessingenabled(self, value):
        """Alias for IsRssRulesProcessingEnabled.setter"""
        self.IsRssRulesProcessingEnabled = value

    @property
    def is_rss_rules_processing_enabled(self):
        """Alias for IsRssRulesProcessingEnabled"""
        return self.IsRssRulesProcessingEnabled

    @is_rss_rules_processing_enabled.setter
    def is_rss_rules_processing_enabled(self, value):
        """Alias for IsRssRulesProcessingEnabled.setter"""
        self.IsRssRulesProcessingEnabled = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Create(self, Name=None, RuleType=None):
        arguments = com_arguments([unwrap(a) for a in [Name, RuleType]])
        return Rule(self.com_object.Create(*arguments))

    def create(self, Name=None, RuleType=None):
        """Alias for Create"""
        arguments = [Name, RuleType]
        return self.Create(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Rule(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Remove(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Remove(*arguments)

    def remove(self, Index=None):
        """Alias for Remove"""
        arguments = [Index]
        return self.Remove(*arguments)

    def Save(self, ShowProgress=None):
        arguments = com_arguments([unwrap(a) for a in [ShowProgress]])
        self.com_object.Save(*arguments)

    def save(self, ShowProgress=None):
        """Alias for Save"""
        arguments = [ShowProgress]
        return self.Save(*arguments)


class ScrollBar:

    def __init__(self, scrollbar=None):
        self.com_object= scrollbar


class Search:

    def __init__(self, search=None):
        self.com_object= search

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Filter(self):
        return self.com_object.Filter

    @property
    def filter(self):
        """Alias for Filter"""
        return self.Filter

    @property
    def IsSynchronous(self):
        return self.com_object.IsSynchronous

    @property
    def issynchronous(self):
        """Alias for IsSynchronous"""
        return self.IsSynchronous

    @property
    def is_synchronous(self):
        """Alias for IsSynchronous"""
        return self.IsSynchronous

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Results(self):
        return Results(self.com_object.Results)

    @property
    def results(self):
        """Alias for Results"""
        return self.Results

    @property
    def Scope(self):
        return self.com_object.Scope

    @property
    def scope(self):
        """Alias for Scope"""
        return self.Scope

    @property
    def SearchSubFolders(self):
        return self.com_object.SearchSubFolders

    @property
    def searchsubfolders(self):
        """Alias for SearchSubFolders"""
        return self.SearchSubFolders

    @property
    def search_sub_folders(self):
        """Alias for SearchSubFolders"""
        return self.SearchSubFolders

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Tag(self):
        return self.com_object.Tag

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    def GetTable(self):
        return Table(self.com_object.GetTable())

    def gettable(self):
        """Alias for GetTable"""
        return self.GetTable()

    def get_table(self):
        """Alias for GetTable"""
        return self.GetTable()

    def Save(self, SchFldrName=None):
        arguments = com_arguments([unwrap(a) for a in [SchFldrName]])
        self.com_object.Save(*arguments)

    def save(self, SchFldrName=None):
        """Alias for Save"""
        arguments = [SchFldrName]
        return self.Save(*arguments)

    def Stop(self):
        self.com_object.Stop()

    def stop(self):
        """Alias for Stop"""
        return self.Stop()


class Selection:

    def __init__(self, selection=None):
        self.com_object= selection

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Location(self):
        return OlSelectionLocation(self.com_object.Location)

    @property
    def location(self):
        """Alias for Location"""
        return self.Location

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def GetSelection(self, SelectionContents=None):
        arguments = com_arguments([unwrap(a) for a in [SelectionContents]])
        return Selection(self.com_object.GetSelection(*arguments))

    def getselection(self, SelectionContents=None):
        """Alias for GetSelection"""
        arguments = [SelectionContents]
        return self.GetSelection(*arguments)

    def get_selection(self, SelectionContents=None):
        """Alias for GetSelection"""
        arguments = [SelectionContents]
        return self.GetSelection(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class SelectNamesDialog:

    def __init__(self, selectnamesdialog=None):
        self.com_object= selectnamesdialog

    @property
    def AllowMultipleSelection(self):
        return self.com_object.AllowMultipleSelection

    @AllowMultipleSelection.setter
    def AllowMultipleSelection(self, value):
        self.com_object.AllowMultipleSelection = value

    @property
    def allowmultipleselection(self):
        """Alias for AllowMultipleSelection"""
        return self.AllowMultipleSelection

    @allowmultipleselection.setter
    def allowmultipleselection(self, value):
        """Alias for AllowMultipleSelection.setter"""
        self.AllowMultipleSelection = value

    @property
    def allow_multiple_selection(self):
        """Alias for AllowMultipleSelection"""
        return self.AllowMultipleSelection

    @allow_multiple_selection.setter
    def allow_multiple_selection(self, value):
        """Alias for AllowMultipleSelection.setter"""
        self.AllowMultipleSelection = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BccLabel(self):
        return self.com_object.BccLabel

    @BccLabel.setter
    def BccLabel(self, value):
        self.com_object.BccLabel = value

    @property
    def bcclabel(self):
        """Alias for BccLabel"""
        return self.BccLabel

    @bcclabel.setter
    def bcclabel(self, value):
        """Alias for BccLabel.setter"""
        self.BccLabel = value

    @property
    def bcc_label(self):
        """Alias for BccLabel"""
        return self.BccLabel

    @bcc_label.setter
    def bcc_label(self, value):
        """Alias for BccLabel.setter"""
        self.BccLabel = value

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    @property
    def CcLabel(self):
        return self.com_object.CcLabel

    @CcLabel.setter
    def CcLabel(self, value):
        self.com_object.CcLabel = value

    @property
    def cclabel(self):
        """Alias for CcLabel"""
        return self.CcLabel

    @cclabel.setter
    def cclabel(self, value):
        """Alias for CcLabel.setter"""
        self.CcLabel = value

    @property
    def cc_label(self):
        """Alias for CcLabel"""
        return self.CcLabel

    @cc_label.setter
    def cc_label(self, value):
        """Alias for CcLabel.setter"""
        self.CcLabel = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def ForceResolution(self):
        return SelectNamesDialog.Recipients(self.com_object.ForceResolution)

    @ForceResolution.setter
    def ForceResolution(self, value):
        self.com_object.ForceResolution = value

    @property
    def forceresolution(self):
        """Alias for ForceResolution"""
        return self.ForceResolution

    @forceresolution.setter
    def forceresolution(self, value):
        """Alias for ForceResolution.setter"""
        self.ForceResolution = value

    @property
    def force_resolution(self):
        """Alias for ForceResolution"""
        return self.ForceResolution

    @force_resolution.setter
    def force_resolution(self, value):
        """Alias for ForceResolution.setter"""
        self.ForceResolution = value

    @property
    def InitialAddressList(self):
        return AddressList(self.com_object.InitialAddressList)

    @InitialAddressList.setter
    def InitialAddressList(self, value):
        self.com_object.InitialAddressList = value

    @property
    def initialaddresslist(self):
        """Alias for InitialAddressList"""
        return self.InitialAddressList

    @initialaddresslist.setter
    def initialaddresslist(self, value):
        """Alias for InitialAddressList.setter"""
        self.InitialAddressList = value

    @property
    def initial_address_list(self):
        """Alias for InitialAddressList"""
        return self.InitialAddressList

    @initial_address_list.setter
    def initial_address_list(self, value):
        """Alias for InitialAddressList.setter"""
        self.InitialAddressList = value

    @property
    def NumberOfRecipientSelectors(self):
        return OlRecipientSelectors(self.com_object.NumberOfRecipientSelectors)

    @NumberOfRecipientSelectors.setter
    def NumberOfRecipientSelectors(self, value):
        self.com_object.NumberOfRecipientSelectors = value

    @property
    def numberofrecipientselectors(self):
        """Alias for NumberOfRecipientSelectors"""
        return self.NumberOfRecipientSelectors

    @numberofrecipientselectors.setter
    def numberofrecipientselectors(self, value):
        """Alias for NumberOfRecipientSelectors.setter"""
        self.NumberOfRecipientSelectors = value

    @property
    def number_of_recipient_selectors(self):
        """Alias for NumberOfRecipientSelectors"""
        return self.NumberOfRecipientSelectors

    @number_of_recipient_selectors.setter
    def number_of_recipient_selectors(self, value):
        """Alias for NumberOfRecipientSelectors.setter"""
        self.NumberOfRecipientSelectors = value

    @property
    def Parent(self):
        return SelectNamesDialog(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Recipients(self):
        return Recipients(self.com_object.Recipients)

    @Recipients.setter
    def Recipients(self, value):
        self.com_object.Recipients = value

    @property
    def recipients(self):
        """Alias for Recipients"""
        return self.Recipients

    @recipients.setter
    def recipients(self, value):
        """Alias for Recipients.setter"""
        self.Recipients = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def ShowOnlyInitialAddressList(self):
        return AddressList(self.com_object.ShowOnlyInitialAddressList)

    @ShowOnlyInitialAddressList.setter
    def ShowOnlyInitialAddressList(self, value):
        self.com_object.ShowOnlyInitialAddressList = value

    @property
    def showonlyinitialaddresslist(self):
        """Alias for ShowOnlyInitialAddressList"""
        return self.ShowOnlyInitialAddressList

    @showonlyinitialaddresslist.setter
    def showonlyinitialaddresslist(self, value):
        """Alias for ShowOnlyInitialAddressList.setter"""
        self.ShowOnlyInitialAddressList = value

    @property
    def show_only_initial_address_list(self):
        """Alias for ShowOnlyInitialAddressList"""
        return self.ShowOnlyInitialAddressList

    @show_only_initial_address_list.setter
    def show_only_initial_address_list(self, value):
        """Alias for ShowOnlyInitialAddressList.setter"""
        self.ShowOnlyInitialAddressList = value

    @property
    def ToLabel(self):
        return self.com_object.ToLabel

    @ToLabel.setter
    def ToLabel(self, value):
        self.com_object.ToLabel = value

    @property
    def tolabel(self):
        """Alias for ToLabel"""
        return self.ToLabel

    @tolabel.setter
    def tolabel(self, value):
        """Alias for ToLabel.setter"""
        self.ToLabel = value

    @property
    def to_label(self):
        """Alias for ToLabel"""
        return self.ToLabel

    @to_label.setter
    def to_label(self, value):
        """Alias for ToLabel.setter"""
        self.ToLabel = value

    def Display(self):
        return self.com_object.Display()

    def display(self):
        """Alias for Display"""
        return self.Display()

    def SetDefaultDisplayMode(self, defaultMode=None):
        arguments = com_arguments([unwrap(a) for a in [defaultMode]])
        self.com_object.SetDefaultDisplayMode(*arguments)

    def setdefaultdisplaymode(self, defaultMode=None):
        """Alias for SetDefaultDisplayMode"""
        arguments = [defaultMode]
        return self.SetDefaultDisplayMode(*arguments)

    def set_default_display_mode(self, defaultMode=None):
        """Alias for SetDefaultDisplayMode"""
        arguments = [defaultMode]
        return self.SetDefaultDisplayMode(*arguments)


class SenderInAddressListRuleCondition:

    def __init__(self, senderinaddresslistrulecondition=None):
        self.com_object= senderinaddresslistrulecondition

    @property
    def AddressList(self):
        return AddressList(self.com_object.AddressList)

    @AddressList.setter
    def AddressList(self, value):
        self.com_object.AddressList = value

    @property
    def addresslist(self):
        """Alias for AddressList"""
        return self.AddressList

    @addresslist.setter
    def addresslist(self, value):
        """Alias for AddressList.setter"""
        self.AddressList = value

    @property
    def address_list(self):
        """Alias for AddressList"""
        return self.AddressList

    @address_list.setter
    def address_list(self, value):
        """Alias for AddressList.setter"""
        self.AddressList = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def ConditionType(self):
        return OlRuleConditionType(self.com_object.ConditionType)

    @property
    def conditiontype(self):
        """Alias for ConditionType"""
        return self.ConditionType

    @property
    def condition_type(self):
        """Alias for ConditionType"""
        return self.ConditionType

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session


class SendRuleAction:

    def __init__(self, sendruleaction=None):
        self.com_object= sendruleaction

    @property
    def ActionType(self):
        return OlRuleActionType(self.com_object.ActionType)

    @property
    def actiontype(self):
        """Alias for ActionType"""
        return self.ActionType

    @property
    def action_type(self):
        """Alias for ActionType"""
        return self.ActionType

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Recipients(self):
        return Recipients(self.com_object.Recipients)

    @property
    def recipients(self):
        """Alias for Recipients"""
        return self.Recipients

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session


class SharingItem:

    def __init__(self, sharingitem=None):
        self.com_object= sharingitem

    @property
    def Actions(self):
        return Actions(self.com_object.Actions)

    @property
    def actions(self):
        """Alias for Actions"""
        return self.Actions

    @property
    def AllowWriteAccess(self):
        return self.com_object.AllowWriteAccess

    @AllowWriteAccess.setter
    def AllowWriteAccess(self, value):
        self.com_object.AllowWriteAccess = value

    @property
    def allowwriteaccess(self):
        """Alias for AllowWriteAccess"""
        return self.AllowWriteAccess

    @allowwriteaccess.setter
    def allowwriteaccess(self, value):
        """Alias for AllowWriteAccess.setter"""
        self.AllowWriteAccess = value

    @property
    def allow_write_access(self):
        """Alias for AllowWriteAccess"""
        return self.AllowWriteAccess

    @allow_write_access.setter
    def allow_write_access(self, value):
        """Alias for AllowWriteAccess.setter"""
        self.AllowWriteAccess = value

    @property
    def AlternateRecipientAllowed(self):
        return self.com_object.AlternateRecipientAllowed

    @AlternateRecipientAllowed.setter
    def AlternateRecipientAllowed(self, value):
        self.com_object.AlternateRecipientAllowed = value

    @property
    def alternaterecipientallowed(self):
        """Alias for AlternateRecipientAllowed"""
        return self.AlternateRecipientAllowed

    @alternaterecipientallowed.setter
    def alternaterecipientallowed(self, value):
        """Alias for AlternateRecipientAllowed.setter"""
        self.AlternateRecipientAllowed = value

    @property
    def alternate_recipient_allowed(self):
        """Alias for AlternateRecipientAllowed"""
        return self.AlternateRecipientAllowed

    @alternate_recipient_allowed.setter
    def alternate_recipient_allowed(self, value):
        """Alias for AlternateRecipientAllowed.setter"""
        self.AlternateRecipientAllowed = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Attachments(self):
        return Attachments(self.com_object.Attachments)

    @property
    def attachments(self):
        """Alias for Attachments"""
        return self.Attachments

    @property
    def AutoForwarded(self):
        return self.com_object.AutoForwarded

    @AutoForwarded.setter
    def AutoForwarded(self, value):
        self.com_object.AutoForwarded = value

    @property
    def autoforwarded(self):
        """Alias for AutoForwarded"""
        return self.AutoForwarded

    @autoforwarded.setter
    def autoforwarded(self, value):
        """Alias for AutoForwarded.setter"""
        self.AutoForwarded = value

    @property
    def auto_forwarded(self):
        """Alias for AutoForwarded"""
        return self.AutoForwarded

    @auto_forwarded.setter
    def auto_forwarded(self, value):
        """Alias for AutoForwarded.setter"""
        self.AutoForwarded = value

    @property
    def BCC(self):
        return SharingItem(self.com_object.BCC)

    @BCC.setter
    def BCC(self, value):
        self.com_object.BCC = value

    @property
    def bcc(self):
        """Alias for BCC"""
        return self.BCC

    @bcc.setter
    def bcc(self, value):
        """Alias for BCC.setter"""
        self.BCC = value

    @property
    def b_c_c(self):
        """Alias for BCC"""
        return self.BCC

    @b_c_c.setter
    def b_c_c(self, value):
        """Alias for BCC.setter"""
        self.BCC = value

    @property
    def BillingInformation(self):
        return SharingItem(self.com_object.BillingInformation)

    @BillingInformation.setter
    def BillingInformation(self, value):
        self.com_object.BillingInformation = value

    @property
    def billinginformation(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billinginformation.setter
    def billinginformation(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def billing_information(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billing_information.setter
    def billing_information(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def Body(self):
        return SharingItem(self.com_object.Body)

    @Body.setter
    def Body(self, value):
        self.com_object.Body = value

    @property
    def body(self):
        """Alias for Body"""
        return self.Body

    @body.setter
    def body(self, value):
        """Alias for Body.setter"""
        self.Body = value

    @property
    def BodyFormat(self):
        return OlBodyFormat(self.com_object.BodyFormat)

    @BodyFormat.setter
    def BodyFormat(self, value):
        self.com_object.BodyFormat = value

    @property
    def bodyformat(self):
        """Alias for BodyFormat"""
        return self.BodyFormat

    @bodyformat.setter
    def bodyformat(self, value):
        """Alias for BodyFormat.setter"""
        self.BodyFormat = value

    @property
    def body_format(self):
        """Alias for BodyFormat"""
        return self.BodyFormat

    @body_format.setter
    def body_format(self, value):
        """Alias for BodyFormat.setter"""
        self.BodyFormat = value

    @property
    def Categories(self):
        return SharingItem(self.com_object.Categories)

    @Categories.setter
    def Categories(self, value):
        self.com_object.Categories = value

    @property
    def categories(self):
        """Alias for Categories"""
        return self.Categories

    @categories.setter
    def categories(self, value):
        """Alias for Categories.setter"""
        self.Categories = value

    @property
    def CC(self):
        return SharingItem(self.com_object.CC)

    @CC.setter
    def CC(self, value):
        self.com_object.CC = value

    @property
    def cc(self):
        """Alias for CC"""
        return self.CC

    @cc.setter
    def cc(self, value):
        """Alias for CC.setter"""
        self.CC = value

    @property
    def c_c(self):
        """Alias for CC"""
        return self.CC

    @c_c.setter
    def c_c(self, value):
        """Alias for CC.setter"""
        self.CC = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Companies(self):
        return SharingItem(self.com_object.Companies)

    @Companies.setter
    def Companies(self, value):
        self.com_object.Companies = value

    @property
    def companies(self):
        """Alias for Companies"""
        return self.Companies

    @companies.setter
    def companies(self, value):
        """Alias for Companies.setter"""
        self.Companies = value

    @property
    def Conflicts(self):
        return self.com_object.Conflicts

    @property
    def conflicts(self):
        """Alias for Conflicts"""
        return self.Conflicts

    @property
    def ConversationID(self):
        return Conversation(self.com_object.ConversationID)

    @property
    def conversationid(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def conversation_i_d(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def ConversationIndex(self):
        return SharingItem(self.com_object.ConversationIndex)

    @property
    def conversationindex(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def conversation_index(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def ConversationTopic(self):
        return SharingItem(self.com_object.ConversationTopic)

    @property
    def conversationtopic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def conversation_topic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def CreationTime(self):
        return SharingItem(self.com_object.CreationTime)

    @property
    def creationtime(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def creation_time(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def DeferredDeliveryTime(self):
        return SharingItem(self.com_object.DeferredDeliveryTime)

    @DeferredDeliveryTime.setter
    def DeferredDeliveryTime(self, value):
        self.com_object.DeferredDeliveryTime = value

    @property
    def deferreddeliverytime(self):
        """Alias for DeferredDeliveryTime"""
        return self.DeferredDeliveryTime

    @deferreddeliverytime.setter
    def deferreddeliverytime(self, value):
        """Alias for DeferredDeliveryTime.setter"""
        self.DeferredDeliveryTime = value

    @property
    def deferred_delivery_time(self):
        """Alias for DeferredDeliveryTime"""
        return self.DeferredDeliveryTime

    @deferred_delivery_time.setter
    def deferred_delivery_time(self, value):
        """Alias for DeferredDeliveryTime.setter"""
        self.DeferredDeliveryTime = value

    @property
    def DeleteAfterSubmit(self):
        return self.com_object.DeleteAfterSubmit

    @DeleteAfterSubmit.setter
    def DeleteAfterSubmit(self, value):
        self.com_object.DeleteAfterSubmit = value

    @property
    def deleteaftersubmit(self):
        """Alias for DeleteAfterSubmit"""
        return self.DeleteAfterSubmit

    @deleteaftersubmit.setter
    def deleteaftersubmit(self, value):
        """Alias for DeleteAfterSubmit.setter"""
        self.DeleteAfterSubmit = value

    @property
    def delete_after_submit(self):
        """Alias for DeleteAfterSubmit"""
        return self.DeleteAfterSubmit

    @delete_after_submit.setter
    def delete_after_submit(self, value):
        """Alias for DeleteAfterSubmit.setter"""
        self.DeleteAfterSubmit = value

    @property
    def DownloadState(self):
        return OlDownloadState(self.com_object.DownloadState)

    @property
    def downloadstate(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def download_state(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def EntryID(self):
        return SharingItem(self.com_object.EntryID)

    @property
    def entryid(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def entry_i_d(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def ExpiryTime(self):
        return SharingItem(self.com_object.ExpiryTime)

    @ExpiryTime.setter
    def ExpiryTime(self, value):
        self.com_object.ExpiryTime = value

    @property
    def expirytime(self):
        """Alias for ExpiryTime"""
        return self.ExpiryTime

    @expirytime.setter
    def expirytime(self, value):
        """Alias for ExpiryTime.setter"""
        self.ExpiryTime = value

    @property
    def expiry_time(self):
        """Alias for ExpiryTime"""
        return self.ExpiryTime

    @expiry_time.setter
    def expiry_time(self, value):
        """Alias for ExpiryTime.setter"""
        self.ExpiryTime = value

    @property
    def FlagRequest(self):
        return SharingItem(self.com_object.FlagRequest)

    @FlagRequest.setter
    def FlagRequest(self, value):
        self.com_object.FlagRequest = value

    @property
    def flagrequest(self):
        """Alias for FlagRequest"""
        return self.FlagRequest

    @flagrequest.setter
    def flagrequest(self, value):
        """Alias for FlagRequest.setter"""
        self.FlagRequest = value

    @property
    def flag_request(self):
        """Alias for FlagRequest"""
        return self.FlagRequest

    @flag_request.setter
    def flag_request(self, value):
        """Alias for FlagRequest.setter"""
        self.FlagRequest = value

    @property
    def FormDescription(self):
        return FormDescription(self.com_object.FormDescription)

    @property
    def formdescription(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def form_description(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def GetInspector(self):
        return Inspector(self.com_object.GetInspector)

    @property
    def getinspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def get_inspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def HTMLBody(self):
        return SharingItem(self.com_object.HTMLBody)

    @HTMLBody.setter
    def HTMLBody(self, value):
        self.com_object.HTMLBody = value

    @property
    def htmlbody(self):
        """Alias for HTMLBody"""
        return self.HTMLBody

    @htmlbody.setter
    def htmlbody(self, value):
        """Alias for HTMLBody.setter"""
        self.HTMLBody = value

    @property
    def h_t_m_l_body(self):
        """Alias for HTMLBody"""
        return self.HTMLBody

    @h_t_m_l_body.setter
    def h_t_m_l_body(self, value):
        """Alias for HTMLBody.setter"""
        self.HTMLBody = value

    @property
    def Importance(self):
        return OlImportance(self.com_object.Importance)

    @Importance.setter
    def Importance(self, value):
        self.com_object.Importance = value

    @property
    def importance(self):
        """Alias for Importance"""
        return self.Importance

    @importance.setter
    def importance(self, value):
        """Alias for Importance.setter"""
        self.Importance = value

    @property
    def InternetCodepage(self):
        return self.com_object.InternetCodepage

    @InternetCodepage.setter
    def InternetCodepage(self, value):
        self.com_object.InternetCodepage = value

    @property
    def internetcodepage(self):
        """Alias for InternetCodepage"""
        return self.InternetCodepage

    @internetcodepage.setter
    def internetcodepage(self, value):
        """Alias for InternetCodepage.setter"""
        self.InternetCodepage = value

    @property
    def internet_codepage(self):
        """Alias for InternetCodepage"""
        return self.InternetCodepage

    @internet_codepage.setter
    def internet_codepage(self, value):
        """Alias for InternetCodepage.setter"""
        self.InternetCodepage = value

    @property
    def IsConflict(self):
        return SharingItem(self.com_object.IsConflict)

    @property
    def isconflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def is_conflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def IsMarkedAsTask(self):
        return SharingItem(self.com_object.IsMarkedAsTask)

    @property
    def ismarkedastask(self):
        """Alias for IsMarkedAsTask"""
        return self.IsMarkedAsTask

    @property
    def is_marked_as_task(self):
        """Alias for IsMarkedAsTask"""
        return self.IsMarkedAsTask

    @property
    def ItemProperties(self):
        return ItemProperties(self.com_object.ItemProperties)

    @property
    def itemproperties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def item_properties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def LastModificationTime(self):
        return SharingItem(self.com_object.LastModificationTime)

    @property
    def lastmodificationtime(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def last_modification_time(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def MarkForDownload(self):
        return OlRemoteStatus(self.com_object.MarkForDownload)

    @MarkForDownload.setter
    def MarkForDownload(self, value):
        self.com_object.MarkForDownload = value

    @property
    def markfordownload(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @markfordownload.setter
    def markfordownload(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def mark_for_download(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @mark_for_download.setter
    def mark_for_download(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def MessageClass(self):
        return SharingItem(self.com_object.MessageClass)

    @MessageClass.setter
    def MessageClass(self, value):
        self.com_object.MessageClass = value

    @property
    def messageclass(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @messageclass.setter
    def messageclass(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def message_class(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @message_class.setter
    def message_class(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def Mileage(self):
        return SharingItem(self.com_object.Mileage)

    @Mileage.setter
    def Mileage(self, value):
        self.com_object.Mileage = value

    @property
    def mileage(self):
        """Alias for Mileage"""
        return self.Mileage

    @mileage.setter
    def mileage(self, value):
        """Alias for Mileage.setter"""
        self.Mileage = value

    @property
    def NoAging(self):
        return SharingItem(self.com_object.NoAging)

    @NoAging.setter
    def NoAging(self, value):
        self.com_object.NoAging = value

    @property
    def noaging(self):
        """Alias for NoAging"""
        return self.NoAging

    @noaging.setter
    def noaging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def no_aging(self):
        """Alias for NoAging"""
        return self.NoAging

    @no_aging.setter
    def no_aging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def OriginatorDeliveryReportRequested(self):
        return SharingItem(self.com_object.OriginatorDeliveryReportRequested)

    @OriginatorDeliveryReportRequested.setter
    def OriginatorDeliveryReportRequested(self, value):
        self.com_object.OriginatorDeliveryReportRequested = value

    @property
    def originatordeliveryreportrequested(self):
        """Alias for OriginatorDeliveryReportRequested"""
        return self.OriginatorDeliveryReportRequested

    @originatordeliveryreportrequested.setter
    def originatordeliveryreportrequested(self, value):
        """Alias for OriginatorDeliveryReportRequested.setter"""
        self.OriginatorDeliveryReportRequested = value

    @property
    def originator_delivery_report_requested(self):
        """Alias for OriginatorDeliveryReportRequested"""
        return self.OriginatorDeliveryReportRequested

    @originator_delivery_report_requested.setter
    def originator_delivery_report_requested(self, value):
        """Alias for OriginatorDeliveryReportRequested.setter"""
        self.OriginatorDeliveryReportRequested = value

    @property
    def OutlookInternalVersion(self):
        return SharingItem(self.com_object.OutlookInternalVersion)

    @property
    def outlookinternalversion(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def outlook_internal_version(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def OutlookVersion(self):
        return SharingItem(self.com_object.OutlookVersion)

    @property
    def outlookversion(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def outlook_version(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def Parent(self):
        return SharingItem(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Permission(self):
        return self.com_object.Permission

    @Permission.setter
    def Permission(self, value):
        self.com_object.Permission = value

    @property
    def permission(self):
        """Alias for Permission"""
        return self.Permission

    @permission.setter
    def permission(self, value):
        """Alias for Permission.setter"""
        self.Permission = value

    @property
    def PermissionService(self):
        return self.com_object.PermissionService

    @PermissionService.setter
    def PermissionService(self, value):
        self.com_object.PermissionService = value

    @property
    def permissionservice(self):
        """Alias for PermissionService"""
        return self.PermissionService

    @permissionservice.setter
    def permissionservice(self, value):
        """Alias for PermissionService.setter"""
        self.PermissionService = value

    @property
    def permission_service(self):
        """Alias for PermissionService"""
        return self.PermissionService

    @permission_service.setter
    def permission_service(self, value):
        """Alias for PermissionService.setter"""
        self.PermissionService = value

    @property
    def PermissionTemplateGuid(self):
        return SharingItem(self.com_object.PermissionTemplateGuid)

    @PermissionTemplateGuid.setter
    def PermissionTemplateGuid(self, value):
        self.com_object.PermissionTemplateGuid = value

    @property
    def permissiontemplateguid(self):
        """Alias for PermissionTemplateGuid"""
        return self.PermissionTemplateGuid

    @permissiontemplateguid.setter
    def permissiontemplateguid(self, value):
        """Alias for PermissionTemplateGuid.setter"""
        self.PermissionTemplateGuid = value

    @property
    def permission_template_guid(self):
        """Alias for PermissionTemplateGuid"""
        return self.PermissionTemplateGuid

    @permission_template_guid.setter
    def permission_template_guid(self, value):
        """Alias for PermissionTemplateGuid.setter"""
        self.PermissionTemplateGuid = value

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def ReadReceiptRequested(self):
        return self.com_object.ReadReceiptRequested

    @property
    def readreceiptrequested(self):
        """Alias for ReadReceiptRequested"""
        return self.ReadReceiptRequested

    @property
    def read_receipt_requested(self):
        """Alias for ReadReceiptRequested"""
        return self.ReadReceiptRequested

    @property
    def ReceivedByEntryID(self):
        return self.com_object.ReceivedByEntryID

    @property
    def receivedbyentryid(self):
        """Alias for ReceivedByEntryID"""
        return self.ReceivedByEntryID

    @property
    def received_by_entry_i_d(self):
        """Alias for ReceivedByEntryID"""
        return self.ReceivedByEntryID

    @property
    def ReceivedByName(self):
        return SharingItem(self.com_object.ReceivedByName)

    @property
    def receivedbyname(self):
        """Alias for ReceivedByName"""
        return self.ReceivedByName

    @property
    def received_by_name(self):
        """Alias for ReceivedByName"""
        return self.ReceivedByName

    @property
    def ReceivedOnBehalfOfEntryID(self):
        return self.com_object.ReceivedOnBehalfOfEntryID

    @property
    def receivedonbehalfofentryid(self):
        """Alias for ReceivedOnBehalfOfEntryID"""
        return self.ReceivedOnBehalfOfEntryID

    @property
    def received_on_behalf_of_entry_i_d(self):
        """Alias for ReceivedOnBehalfOfEntryID"""
        return self.ReceivedOnBehalfOfEntryID

    @property
    def ReceivedOnBehalfOfName(self):
        return SharingItem(self.com_object.ReceivedOnBehalfOfName)

    @property
    def receivedonbehalfofname(self):
        """Alias for ReceivedOnBehalfOfName"""
        return self.ReceivedOnBehalfOfName

    @property
    def received_on_behalf_of_name(self):
        """Alias for ReceivedOnBehalfOfName"""
        return self.ReceivedOnBehalfOfName

    @property
    def ReceivedTime(self):
        return SharingItem(self.com_object.ReceivedTime)

    @property
    def receivedtime(self):
        """Alias for ReceivedTime"""
        return self.ReceivedTime

    @property
    def received_time(self):
        """Alias for ReceivedTime"""
        return self.ReceivedTime

    @property
    def RecipientReassignmentProhibited(self):
        return SharingItem(self.com_object.RecipientReassignmentProhibited)

    @RecipientReassignmentProhibited.setter
    def RecipientReassignmentProhibited(self, value):
        self.com_object.RecipientReassignmentProhibited = value

    @property
    def recipientreassignmentprohibited(self):
        """Alias for RecipientReassignmentProhibited"""
        return self.RecipientReassignmentProhibited

    @recipientreassignmentprohibited.setter
    def recipientreassignmentprohibited(self, value):
        """Alias for RecipientReassignmentProhibited.setter"""
        self.RecipientReassignmentProhibited = value

    @property
    def recipient_reassignment_prohibited(self):
        """Alias for RecipientReassignmentProhibited"""
        return self.RecipientReassignmentProhibited

    @recipient_reassignment_prohibited.setter
    def recipient_reassignment_prohibited(self, value):
        """Alias for RecipientReassignmentProhibited.setter"""
        self.RecipientReassignmentProhibited = value

    @property
    def Recipients(self):
        return Recipients(self.com_object.Recipients)

    @property
    def recipients(self):
        """Alias for Recipients"""
        return self.Recipients

    @property
    def ReminderOverrideDefault(self):
        return SharingItem(self.com_object.ReminderOverrideDefault)

    @ReminderOverrideDefault.setter
    def ReminderOverrideDefault(self, value):
        self.com_object.ReminderOverrideDefault = value

    @property
    def reminderoverridedefault(self):
        """Alias for ReminderOverrideDefault"""
        return self.ReminderOverrideDefault

    @reminderoverridedefault.setter
    def reminderoverridedefault(self, value):
        """Alias for ReminderOverrideDefault.setter"""
        self.ReminderOverrideDefault = value

    @property
    def reminder_override_default(self):
        """Alias for ReminderOverrideDefault"""
        return self.ReminderOverrideDefault

    @reminder_override_default.setter
    def reminder_override_default(self, value):
        """Alias for ReminderOverrideDefault.setter"""
        self.ReminderOverrideDefault = value

    @property
    def ReminderPlaySound(self):
        return SharingItem(self.com_object.ReminderPlaySound)

    @ReminderPlaySound.setter
    def ReminderPlaySound(self, value):
        self.com_object.ReminderPlaySound = value

    @property
    def reminderplaysound(self):
        """Alias for ReminderPlaySound"""
        return self.ReminderPlaySound

    @reminderplaysound.setter
    def reminderplaysound(self, value):
        """Alias for ReminderPlaySound.setter"""
        self.ReminderPlaySound = value

    @property
    def reminder_play_sound(self):
        """Alias for ReminderPlaySound"""
        return self.ReminderPlaySound

    @reminder_play_sound.setter
    def reminder_play_sound(self, value):
        """Alias for ReminderPlaySound.setter"""
        self.ReminderPlaySound = value

    @property
    def ReminderSet(self):
        return SharingItem(self.com_object.ReminderSet)

    @ReminderSet.setter
    def ReminderSet(self, value):
        self.com_object.ReminderSet = value

    @property
    def reminderset(self):
        """Alias for ReminderSet"""
        return self.ReminderSet

    @reminderset.setter
    def reminderset(self, value):
        """Alias for ReminderSet.setter"""
        self.ReminderSet = value

    @property
    def reminder_set(self):
        """Alias for ReminderSet"""
        return self.ReminderSet

    @reminder_set.setter
    def reminder_set(self, value):
        """Alias for ReminderSet.setter"""
        self.ReminderSet = value

    @property
    def ReminderSoundFile(self):
        return self.com_object.ReminderSoundFile

    @ReminderSoundFile.setter
    def ReminderSoundFile(self, value):
        self.com_object.ReminderSoundFile = value

    @property
    def remindersoundfile(self):
        """Alias for ReminderSoundFile"""
        return self.ReminderSoundFile

    @remindersoundfile.setter
    def remindersoundfile(self, value):
        """Alias for ReminderSoundFile.setter"""
        self.ReminderSoundFile = value

    @property
    def reminder_sound_file(self):
        """Alias for ReminderSoundFile"""
        return self.ReminderSoundFile

    @reminder_sound_file.setter
    def reminder_sound_file(self, value):
        """Alias for ReminderSoundFile.setter"""
        self.ReminderSoundFile = value

    @property
    def ReminderTime(self):
        return SharingItem(self.com_object.ReminderTime)

    @ReminderTime.setter
    def ReminderTime(self, value):
        self.com_object.ReminderTime = value

    @property
    def remindertime(self):
        """Alias for ReminderTime"""
        return self.ReminderTime

    @remindertime.setter
    def remindertime(self, value):
        """Alias for ReminderTime.setter"""
        self.ReminderTime = value

    @property
    def reminder_time(self):
        """Alias for ReminderTime"""
        return self.ReminderTime

    @reminder_time.setter
    def reminder_time(self, value):
        """Alias for ReminderTime.setter"""
        self.ReminderTime = value

    @property
    def RemoteID(self):
        return SharingItem(self.com_object.RemoteID)

    @property
    def remoteid(self):
        """Alias for RemoteID"""
        return self.RemoteID

    @property
    def remote_i_d(self):
        """Alias for RemoteID"""
        return self.RemoteID

    @property
    def RemoteName(self):
        return SharingItem(self.com_object.RemoteName)

    @property
    def remotename(self):
        """Alias for RemoteName"""
        return self.RemoteName

    @property
    def remote_name(self):
        """Alias for RemoteName"""
        return self.RemoteName

    @property
    def RemotePath(self):
        return SharingItem(self.com_object.RemotePath)

    @property
    def remotepath(self):
        """Alias for RemotePath"""
        return self.RemotePath

    @property
    def remote_path(self):
        """Alias for RemotePath"""
        return self.RemotePath

    @property
    def RemoteStatus(self):
        return OlRemoteStatus(self.com_object.RemoteStatus)

    @RemoteStatus.setter
    def RemoteStatus(self, value):
        self.com_object.RemoteStatus = value

    @property
    def remotestatus(self):
        """Alias for RemoteStatus"""
        return self.RemoteStatus

    @remotestatus.setter
    def remotestatus(self, value):
        """Alias for RemoteStatus.setter"""
        self.RemoteStatus = value

    @property
    def remote_status(self):
        """Alias for RemoteStatus"""
        return self.RemoteStatus

    @remote_status.setter
    def remote_status(self, value):
        """Alias for RemoteStatus.setter"""
        self.RemoteStatus = value

    @property
    def ReplyRecipientNames(self):
        return SharingItem(self.com_object.ReplyRecipientNames)

    @property
    def replyrecipientnames(self):
        """Alias for ReplyRecipientNames"""
        return self.ReplyRecipientNames

    @property
    def reply_recipient_names(self):
        """Alias for ReplyRecipientNames"""
        return self.ReplyRecipientNames

    @property
    def ReplyRecipients(self):
        return Recipients(self.com_object.ReplyRecipients)

    @property
    def replyrecipients(self):
        """Alias for ReplyRecipients"""
        return self.ReplyRecipients

    @property
    def reply_recipients(self):
        """Alias for ReplyRecipients"""
        return self.ReplyRecipients

    @property
    def RequestedFolder(self):
        return OlDefaultFolders(self.com_object.RequestedFolder)

    @property
    def requestedfolder(self):
        """Alias for RequestedFolder"""
        return self.RequestedFolder

    @property
    def requested_folder(self):
        """Alias for RequestedFolder"""
        return self.RequestedFolder

    @property
    def RetentionExpirationDate(self):
        return SharingItem(self.com_object.RetentionExpirationDate)

    @property
    def retentionexpirationdate(self):
        """Alias for RetentionExpirationDate"""
        return self.RetentionExpirationDate

    @property
    def retention_expiration_date(self):
        """Alias for RetentionExpirationDate"""
        return self.RetentionExpirationDate

    @property
    def RetentionPolicyName(self):
        return self.com_object.RetentionPolicyName

    @property
    def retentionpolicyname(self):
        """Alias for RetentionPolicyName"""
        return self.RetentionPolicyName

    @property
    def retention_policy_name(self):
        """Alias for RetentionPolicyName"""
        return self.RetentionPolicyName

    @property
    def RTFBody(self):
        return self.com_object.RTFBody

    @RTFBody.setter
    def RTFBody(self, value):
        self.com_object.RTFBody = value

    @property
    def rtfbody(self):
        """Alias for RTFBody"""
        return self.RTFBody

    @rtfbody.setter
    def rtfbody(self, value):
        """Alias for RTFBody.setter"""
        self.RTFBody = value

    @property
    def r_t_f_body(self):
        """Alias for RTFBody"""
        return self.RTFBody

    @r_t_f_body.setter
    def r_t_f_body(self, value):
        """Alias for RTFBody.setter"""
        self.RTFBody = value

    @property
    def Saved(self):
        return SharingItem(self.com_object.Saved)

    @property
    def saved(self):
        """Alias for Saved"""
        return self.Saved

    @property
    def SaveSentMessageFolder(self):
        return Folder(self.com_object.SaveSentMessageFolder)

    @SaveSentMessageFolder.setter
    def SaveSentMessageFolder(self, value):
        self.com_object.SaveSentMessageFolder = value

    @property
    def savesentmessagefolder(self):
        """Alias for SaveSentMessageFolder"""
        return self.SaveSentMessageFolder

    @savesentmessagefolder.setter
    def savesentmessagefolder(self, value):
        """Alias for SaveSentMessageFolder.setter"""
        self.SaveSentMessageFolder = value

    @property
    def save_sent_message_folder(self):
        """Alias for SaveSentMessageFolder"""
        return self.SaveSentMessageFolder

    @save_sent_message_folder.setter
    def save_sent_message_folder(self, value):
        """Alias for SaveSentMessageFolder.setter"""
        self.SaveSentMessageFolder = value

    @property
    def SenderEmailAddress(self):
        return SharingItem(self.com_object.SenderEmailAddress)

    @property
    def senderemailaddress(self):
        """Alias for SenderEmailAddress"""
        return self.SenderEmailAddress

    @property
    def sender_email_address(self):
        """Alias for SenderEmailAddress"""
        return self.SenderEmailAddress

    @property
    def SenderEmailType(self):
        return SharingItem(self.com_object.SenderEmailType)

    @property
    def senderemailtype(self):
        """Alias for SenderEmailType"""
        return self.SenderEmailType

    @property
    def sender_email_type(self):
        """Alias for SenderEmailType"""
        return self.SenderEmailType

    @property
    def SenderName(self):
        return SharingItem(self.com_object.SenderName)

    @property
    def sendername(self):
        """Alias for SenderName"""
        return self.SenderName

    @property
    def sender_name(self):
        """Alias for SenderName"""
        return self.SenderName

    @property
    def SendUsingAccount(self):
        return Account(self.com_object.SendUsingAccount)

    @SendUsingAccount.setter
    def SendUsingAccount(self, value):
        self.com_object.SendUsingAccount = value

    @property
    def sendusingaccount(self):
        """Alias for SendUsingAccount"""
        return self.SendUsingAccount

    @sendusingaccount.setter
    def sendusingaccount(self, value):
        """Alias for SendUsingAccount.setter"""
        self.SendUsingAccount = value

    @property
    def send_using_account(self):
        """Alias for SendUsingAccount"""
        return self.SendUsingAccount

    @send_using_account.setter
    def send_using_account(self, value):
        """Alias for SendUsingAccount.setter"""
        self.SendUsingAccount = value

    @property
    def Sensitivity(self):
        return OlSensitivity(self.com_object.Sensitivity)

    @Sensitivity.setter
    def Sensitivity(self, value):
        self.com_object.Sensitivity = value

    @property
    def sensitivity(self):
        """Alias for Sensitivity"""
        return self.Sensitivity

    @sensitivity.setter
    def sensitivity(self, value):
        """Alias for Sensitivity.setter"""
        self.Sensitivity = value

    @property
    def Sent(self):
        return SharingItem(self.com_object.Sent)

    @property
    def sent(self):
        """Alias for Sent"""
        return self.Sent

    @property
    def SentOn(self):
        return SharingItem(self.com_object.SentOn)

    @property
    def senton(self):
        """Alias for SentOn"""
        return self.SentOn

    @property
    def sent_on(self):
        """Alias for SentOn"""
        return self.SentOn

    @property
    def SentOnBehalfOfName(self):
        return SharingItem(self.com_object.SentOnBehalfOfName)

    @SentOnBehalfOfName.setter
    def SentOnBehalfOfName(self, value):
        self.com_object.SentOnBehalfOfName = value

    @property
    def sentonbehalfofname(self):
        """Alias for SentOnBehalfOfName"""
        return self.SentOnBehalfOfName

    @sentonbehalfofname.setter
    def sentonbehalfofname(self, value):
        """Alias for SentOnBehalfOfName.setter"""
        self.SentOnBehalfOfName = value

    @property
    def sent_on_behalf_of_name(self):
        """Alias for SentOnBehalfOfName"""
        return self.SentOnBehalfOfName

    @sent_on_behalf_of_name.setter
    def sent_on_behalf_of_name(self, value):
        """Alias for SentOnBehalfOfName.setter"""
        self.SentOnBehalfOfName = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def SharingProvider(self):
        return OlSharingProvider(self.com_object.SharingProvider)

    @property
    def sharingprovider(self):
        """Alias for SharingProvider"""
        return self.SharingProvider

    @property
    def sharing_provider(self):
        """Alias for SharingProvider"""
        return self.SharingProvider

    @property
    def SharingProviderGuid(self):
        return SharingItem(self.com_object.SharingProviderGuid)

    @property
    def sharingproviderguid(self):
        """Alias for SharingProviderGuid"""
        return self.SharingProviderGuid

    @property
    def sharing_provider_guid(self):
        """Alias for SharingProviderGuid"""
        return self.SharingProviderGuid

    @property
    def Size(self):
        return SharingItem(self.com_object.Size)

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @property
    def Subject(self):
        return SharingItem(self.com_object.Subject)

    @Subject.setter
    def Subject(self, value):
        self.com_object.Subject = value

    @property
    def subject(self):
        """Alias for Subject"""
        return self.Subject

    @subject.setter
    def subject(self, value):
        """Alias for Subject.setter"""
        self.Subject = value

    @property
    def Submitted(self):
        return SharingItem(self.com_object.Submitted)

    @property
    def submitted(self):
        """Alias for Submitted"""
        return self.Submitted

    @property
    def TaskCompletedDate(self):
        return SharingItem(self.com_object.TaskCompletedDate)

    @TaskCompletedDate.setter
    def TaskCompletedDate(self, value):
        self.com_object.TaskCompletedDate = value

    @property
    def taskcompleteddate(self):
        """Alias for TaskCompletedDate"""
        return self.TaskCompletedDate

    @taskcompleteddate.setter
    def taskcompleteddate(self, value):
        """Alias for TaskCompletedDate.setter"""
        self.TaskCompletedDate = value

    @property
    def task_completed_date(self):
        """Alias for TaskCompletedDate"""
        return self.TaskCompletedDate

    @task_completed_date.setter
    def task_completed_date(self, value):
        """Alias for TaskCompletedDate.setter"""
        self.TaskCompletedDate = value

    @property
    def TaskDueDate(self):
        return SharingItem(self.com_object.TaskDueDate)

    @TaskDueDate.setter
    def TaskDueDate(self, value):
        self.com_object.TaskDueDate = value

    @property
    def taskduedate(self):
        """Alias for TaskDueDate"""
        return self.TaskDueDate

    @taskduedate.setter
    def taskduedate(self, value):
        """Alias for TaskDueDate.setter"""
        self.TaskDueDate = value

    @property
    def task_due_date(self):
        """Alias for TaskDueDate"""
        return self.TaskDueDate

    @task_due_date.setter
    def task_due_date(self, value):
        """Alias for TaskDueDate.setter"""
        self.TaskDueDate = value

    @property
    def TaskStartDate(self):
        return SharingItem(self.com_object.TaskStartDate)

    @TaskStartDate.setter
    def TaskStartDate(self, value):
        self.com_object.TaskStartDate = value

    @property
    def taskstartdate(self):
        """Alias for TaskStartDate"""
        return self.TaskStartDate

    @taskstartdate.setter
    def taskstartdate(self, value):
        """Alias for TaskStartDate.setter"""
        self.TaskStartDate = value

    @property
    def task_start_date(self):
        """Alias for TaskStartDate"""
        return self.TaskStartDate

    @task_start_date.setter
    def task_start_date(self, value):
        """Alias for TaskStartDate.setter"""
        self.TaskStartDate = value

    @property
    def TaskSubject(self):
        return SharingItem(self.com_object.TaskSubject)

    @TaskSubject.setter
    def TaskSubject(self, value):
        self.com_object.TaskSubject = value

    @property
    def tasksubject(self):
        """Alias for TaskSubject"""
        return self.TaskSubject

    @tasksubject.setter
    def tasksubject(self, value):
        """Alias for TaskSubject.setter"""
        self.TaskSubject = value

    @property
    def task_subject(self):
        """Alias for TaskSubject"""
        return self.TaskSubject

    @task_subject.setter
    def task_subject(self, value):
        """Alias for TaskSubject.setter"""
        self.TaskSubject = value

    @property
    def To(self):
        return SharingItem(self.com_object.To)

    @To.setter
    def To(self, value):
        self.com_object.To = value

    @property
    def to(self):
        """Alias for To"""
        return self.To

    @to.setter
    def to(self, value):
        """Alias for To.setter"""
        self.To = value

    @property
    def ToDoTaskOrdinal(self):
        return SharingItem(self.com_object.ToDoTaskOrdinal)

    @ToDoTaskOrdinal.setter
    def ToDoTaskOrdinal(self, value):
        self.com_object.ToDoTaskOrdinal = value

    @property
    def todotaskordinal(self):
        """Alias for ToDoTaskOrdinal"""
        return self.ToDoTaskOrdinal

    @todotaskordinal.setter
    def todotaskordinal(self, value):
        """Alias for ToDoTaskOrdinal.setter"""
        self.ToDoTaskOrdinal = value

    @property
    def to_do_task_ordinal(self):
        """Alias for ToDoTaskOrdinal"""
        return self.ToDoTaskOrdinal

    @to_do_task_ordinal.setter
    def to_do_task_ordinal(self, value):
        """Alias for ToDoTaskOrdinal.setter"""
        self.ToDoTaskOrdinal = value

    @property
    def Type(self):
        return OlSharingMsgType(self.com_object.Type)

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    @property
    def UnRead(self):
        return SharingItem(self.com_object.UnRead)

    @UnRead.setter
    def UnRead(self, value):
        self.com_object.UnRead = value

    @property
    def unread(self):
        """Alias for UnRead"""
        return self.UnRead

    @unread.setter
    def unread(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def un_read(self):
        """Alias for UnRead"""
        return self.UnRead

    @un_read.setter
    def un_read(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def UserProperties(self):
        return UserProperties(self.com_object.UserProperties)

    @property
    def userproperties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    @property
    def user_properties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    def AddBusinessCard(self, contact=None):
        arguments = com_arguments([unwrap(a) for a in [contact]])
        self.com_object.AddBusinessCard(*arguments)

    def addbusinesscard(self, contact=None):
        """Alias for AddBusinessCard"""
        arguments = [contact]
        return self.AddBusinessCard(*arguments)

    def add_business_card(self, contact=None):
        """Alias for AddBusinessCard"""
        arguments = [contact]
        return self.AddBusinessCard(*arguments)

    def Allow(self):
        self.com_object.Allow()

    def allow(self):
        """Alias for Allow"""
        return self.Allow()

    def ClearConversationIndex(self):
        self.com_object.ClearConversationIndex()

    def clearconversationindex(self):
        """Alias for ClearConversationIndex"""
        return self.ClearConversationIndex()

    def clear_conversation_index(self):
        """Alias for ClearConversationIndex"""
        return self.ClearConversationIndex()

    def ClearTaskFlag(self):
        self.com_object.ClearTaskFlag()

    def cleartaskflag(self):
        """Alias for ClearTaskFlag"""
        return self.ClearTaskFlag()

    def clear_task_flag(self):
        """Alias for ClearTaskFlag"""
        return self.ClearTaskFlag()

    def Close(self, SaveMode=None):
        arguments = com_arguments([unwrap(a) for a in [SaveMode]])
        self.com_object.Close(*arguments)

    def close(self, SaveMode=None):
        """Alias for Close"""
        arguments = [SaveMode]
        return self.Close(*arguments)

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Deny(self):
        return SharingItem(self.com_object.Deny())

    def deny(self):
        """Alias for Deny"""
        return self.Deny()

    def Display(self, Modal=None):
        arguments = com_arguments([unwrap(a) for a in [Modal]])
        self.com_object.Display(*arguments)

    def display(self, Modal=None):
        """Alias for Display"""
        arguments = [Modal]
        return self.Display(*arguments)

    def Forward(self):
        return SharingItem(self.com_object.Forward())

    def forward(self):
        """Alias for Forward"""
        return self.Forward()

    def GetConversation(self):
        return Conversation(self.com_object.GetConversation())

    def getconversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def get_conversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def MarkAsTask(self, MarkInterval=None):
        arguments = com_arguments([unwrap(a) for a in [MarkInterval]])
        self.com_object.MarkAsTask(*arguments)

    def markastask(self, MarkInterval=None):
        """Alias for MarkAsTask"""
        arguments = [MarkInterval]
        return self.MarkAsTask(*arguments)

    def mark_as_task(self, MarkInterval=None):
        """Alias for MarkAsTask"""
        arguments = [MarkInterval]
        return self.MarkAsTask(*arguments)

    def Move(self, DestFldr=None):
        arguments = com_arguments([unwrap(a) for a in [DestFldr]])
        return self.com_object.Move(*arguments)

    def move(self, DestFldr=None):
        """Alias for Move"""
        arguments = [DestFldr]
        return self.Move(*arguments)

    def OpenSharedFolder(self):
        return Folder(self.com_object.OpenSharedFolder())

    def opensharedfolder(self):
        """Alias for OpenSharedFolder"""
        return self.OpenSharedFolder()

    def open_shared_folder(self):
        """Alias for OpenSharedFolder"""
        return self.OpenSharedFolder()

    def PrintOut(self):
        self.com_object.PrintOut()

    def printout(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def print_out(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def Reply(self):
        return MailItem(self.com_object.Reply())

    def reply(self):
        """Alias for Reply"""
        return self.Reply()

    def ReplyAll(self):
        return MailItem(self.com_object.ReplyAll())

    def replyall(self):
        """Alias for ReplyAll"""
        return self.ReplyAll()

    def reply_all(self):
        """Alias for ReplyAll"""
        return self.ReplyAll()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()

    def SaveAs(self, Path=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Path, Type]])
        self.com_object.SaveAs(*arguments)

    def saveas(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def save_as(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def Send(self):
        self.com_object.Send()

    def send(self):
        """Alias for Send"""
        return self.Send()

    def ShowCategoriesDialog(self):
        self.com_object.ShowCategoriesDialog()

    def showcategoriesdialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()

    def show_categories_dialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()


class SimpleItems:

    def __init__(self, simpleitems=None):
        self.com_object= simpleitems

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return SimpleItems(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return SimpleItems(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class SolutionsModule:

    def __init__(self, solutionsmodule=None):
        self.com_object= solutionsmodule

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Name(self):
        return SolutionsModule(self.com_object.Name)

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NavigationModuleType(self):
        return OlNavigationModuleType(self.com_object.NavigationModuleType)

    @property
    def navigationmoduletype(self):
        """Alias for NavigationModuleType"""
        return self.NavigationModuleType

    @property
    def navigation_module_type(self):
        """Alias for NavigationModuleType"""
        return self.NavigationModuleType

    @property
    def Parent(self):
        return SolutionsModule(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return SolutionsModule(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    def AddSolution(self, Solution=None, Scope=None):
        arguments = com_arguments([unwrap(a) for a in [Solution, Scope]])
        self.com_object.AddSolution(*arguments)

    def addsolution(self, Solution=None, Scope=None):
        """Alias for AddSolution"""
        arguments = [Solution, Scope]
        return self.AddSolution(*arguments)

    def add_solution(self, Solution=None, Scope=None):
        """Alias for AddSolution"""
        arguments = [Solution, Scope]
        return self.AddSolution(*arguments)


class SpinButton:

    def __init__(self, spinbutton=None):
        self.com_object= spinbutton


class StorageItem:

    def __init__(self, storageitem=None):
        self.com_object= storageitem

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Attachments(self):
        return Attachments(self.com_object.Attachments)

    @property
    def attachments(self):
        """Alias for Attachments"""
        return self.Attachments

    @property
    def Body(self):
        return self.com_object.Body

    @Body.setter
    def Body(self, value):
        self.com_object.Body = value

    @property
    def body(self):
        """Alias for Body"""
        return self.Body

    @body.setter
    def body(self, value):
        """Alias for Body.setter"""
        self.Body = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def CreationTime(self):
        return StorageItem(self.com_object.CreationTime)

    @property
    def creationtime(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def creation_time(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def Creator(self):
        return StorageItem(self.com_object.Creator)

    @Creator.setter
    def Creator(self, value):
        self.com_object.Creator = value

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @creator.setter
    def creator(self, value):
        """Alias for Creator.setter"""
        self.Creator = value

    @property
    def EntryID(self):
        return self.com_object.EntryID

    @property
    def entryid(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def entry_i_d(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def LastModificationTime(self):
        return self.com_object.LastModificationTime

    @property
    def lastmodificationtime(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def last_modification_time(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Size(self):
        return StorageItem(self.com_object.Size)

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @property
    def Subject(self):
        return self.com_object.Subject

    @Subject.setter
    def Subject(self, value):
        self.com_object.Subject = value

    @property
    def subject(self):
        """Alias for Subject"""
        return self.Subject

    @subject.setter
    def subject(self, value):
        """Alias for Subject.setter"""
        self.Subject = value

    @property
    def UserProperties(self):
        return UserProperties(self.com_object.UserProperties)

    @property
    def userproperties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    @property
    def user_properties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()


class Store:

    def __init__(self, store=None):
        self.com_object= store

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Categories(self):
        return Categories(self.com_object.Categories)

    @property
    def categories(self):
        """Alias for Categories"""
        return self.Categories

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def DisplayName(self):
        return Store(self.com_object.DisplayName)

    @property
    def displayname(self):
        """Alias for DisplayName"""
        return self.DisplayName

    @property
    def display_name(self):
        """Alias for DisplayName"""
        return self.DisplayName

    @property
    def ExchangeStoreType(self):
        return OlExchangeStoreType(self.com_object.ExchangeStoreType)

    @property
    def exchangestoretype(self):
        """Alias for ExchangeStoreType"""
        return self.ExchangeStoreType

    @property
    def exchange_store_type(self):
        """Alias for ExchangeStoreType"""
        return self.ExchangeStoreType

    @property
    def FilePath(self):
        return self.com_object.FilePath

    @property
    def filepath(self):
        """Alias for FilePath"""
        return self.FilePath

    @property
    def file_path(self):
        """Alias for FilePath"""
        return self.FilePath

    @property
    def IsCachedExchange(self):
        return Store(self.com_object.IsCachedExchange)

    @property
    def iscachedexchange(self):
        """Alias for IsCachedExchange"""
        return self.IsCachedExchange

    @property
    def is_cached_exchange(self):
        """Alias for IsCachedExchange"""
        return self.IsCachedExchange

    @property
    def IsConversationEnabled(self):
        return self.com_object.IsConversationEnabled

    @property
    def isconversationenabled(self):
        """Alias for IsConversationEnabled"""
        return self.IsConversationEnabled

    @property
    def is_conversation_enabled(self):
        """Alias for IsConversationEnabled"""
        return self.IsConversationEnabled

    @property
    def IsDataFileStore(self):
        return Store(self.com_object.IsDataFileStore)

    @property
    def isdatafilestore(self):
        """Alias for IsDataFileStore"""
        return self.IsDataFileStore

    @property
    def is_data_file_store(self):
        """Alias for IsDataFileStore"""
        return self.IsDataFileStore

    @property
    def IsInstantSearchEnabled(self):
        return self.com_object.IsInstantSearchEnabled

    @property
    def isinstantsearchenabled(self):
        """Alias for IsInstantSearchEnabled"""
        return self.IsInstantSearchEnabled

    @property
    def is_instant_search_enabled(self):
        """Alias for IsInstantSearchEnabled"""
        return self.IsInstantSearchEnabled

    @property
    def IsOpen(self):
        return Store(self.com_object.IsOpen)

    @property
    def isopen(self):
        """Alias for IsOpen"""
        return self.IsOpen

    @property
    def is_open(self):
        """Alias for IsOpen"""
        return self.IsOpen

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def StoreID(self):
        return Store(self.com_object.StoreID)

    @property
    def storeid(self):
        """Alias for StoreID"""
        return self.StoreID

    @property
    def store_i_d(self):
        """Alias for StoreID"""
        return self.StoreID

    def CreateUnifiedGroup(self, Name=None, Alias=None, Description=None, FAutoSubscribeMembers=None, GroupType=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Alias, Description, FAutoSubscribeMembers, GroupType]])
        return self.com_object.CreateUnifiedGroup(*arguments)

    def createunifiedgroup(self, Name=None, Alias=None, Description=None, FAutoSubscribeMembers=None, GroupType=None):
        """Alias for CreateUnifiedGroup"""
        arguments = [Name, Alias, Description, FAutoSubscribeMembers, GroupType]
        return self.CreateUnifiedGroup(*arguments)

    def create_unified_group(self, Name=None, Alias=None, Description=None, FAutoSubscribeMembers=None, GroupType=None):
        """Alias for CreateUnifiedGroup"""
        arguments = [Name, Alias, Description, FAutoSubscribeMembers, GroupType]
        return self.CreateUnifiedGroup(*arguments)

    def DeleteUnifiedGroup(self):
        return self.com_object.DeleteUnifiedGroup()

    def deleteunifiedgroup(self):
        """Alias for DeleteUnifiedGroup"""
        return self.DeleteUnifiedGroup()

    def delete_unified_group(self):
        """Alias for DeleteUnifiedGroup"""
        return self.DeleteUnifiedGroup()

    def GetDefaultFolder(self, FolderType=None):
        arguments = com_arguments([unwrap(a) for a in [FolderType]])
        return self.com_object.GetDefaultFolder(*arguments)

    def getdefaultfolder(self, FolderType=None):
        """Alias for GetDefaultFolder"""
        arguments = [FolderType]
        return self.GetDefaultFolder(*arguments)

    def get_default_folder(self, FolderType=None):
        """Alias for GetDefaultFolder"""
        arguments = [FolderType]
        return self.GetDefaultFolder(*arguments)

    def GetRootFolder(self):
        return Folder(self.com_object.GetRootFolder())

    def getrootfolder(self):
        """Alias for GetRootFolder"""
        return self.GetRootFolder()

    def get_root_folder(self):
        """Alias for GetRootFolder"""
        return self.GetRootFolder()

    def GetRules(self):
        return Rules(self.com_object.GetRules())

    def getrules(self):
        """Alias for GetRules"""
        return self.GetRules()

    def get_rules(self):
        """Alias for GetRules"""
        return self.GetRules()

    def GetSearchFolders(self):
        return Folders(self.com_object.GetSearchFolders())

    def getsearchfolders(self):
        """Alias for GetSearchFolders"""
        return self.GetSearchFolders()

    def get_search_folders(self):
        """Alias for GetSearchFolders"""
        return self.GetSearchFolders()

    def GetSpecialFolder(self, FolderType=None):
        arguments = com_arguments([unwrap(a) for a in [FolderType]])
        return Folder(self.com_object.GetSpecialFolder(*arguments))

    def getspecialfolder(self, FolderType=None):
        """Alias for GetSpecialFolder"""
        arguments = [FolderType]
        return self.GetSpecialFolder(*arguments)

    def get_special_folder(self, FolderType=None):
        """Alias for GetSpecialFolder"""
        arguments = [FolderType]
        return self.GetSpecialFolder(*arguments)

    def RefreshQuotaDisplay(self):
        self.com_object.RefreshQuotaDisplay()

    def refreshquotadisplay(self):
        """Alias for RefreshQuotaDisplay"""
        return self.RefreshQuotaDisplay()

    def refresh_quota_display(self):
        """Alias for RefreshQuotaDisplay"""
        return self.RefreshQuotaDisplay()


class Stores:

    def __init__(self, stores=None):
        self.com_object= stores

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Stores(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class SyncObject:

    def __init__(self, syncobject=None):
        self.com_object= syncobject

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Start(self):
        self.com_object.Start()

    def start(self):
        """Alias for Start"""
        return self.Start()

    def Stop(self):
        self.com_object.Stop()

    def stop(self):
        """Alias for Stop"""
        return self.Stop()


class SyncObjects:

    def __init__(self, syncobjects=None):
        self.com_object= syncobjects

    @property
    def AppFolders(self):
        return self.com_object.AppFolders

    @property
    def appfolders(self):
        """Alias for AppFolders"""
        return self.AppFolders

    @property
    def app_folders(self):
        """Alias for AppFolders"""
        return self.AppFolders

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return SyncObject(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Tab:

    def __init__(self, tab=None):
        self.com_object= tab


class Table:

    def __init__(self, table=None):
        self.com_object= table

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Columns(self):
        return Columns(self.com_object.Columns)

    @property
    def columns(self):
        """Alias for Columns"""
        return self.Columns

    @property
    def EndOfTable(self):
        return Table(self.com_object.EndOfTable)

    @property
    def endoftable(self):
        """Alias for EndOfTable"""
        return self.EndOfTable

    @property
    def end_of_table(self):
        """Alias for EndOfTable"""
        return self.EndOfTable

    @property
    def Parent(self):
        return Table(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def FindNextRow(self):
        return self.com_object.FindNextRow()

    def findnextrow(self):
        """Alias for FindNextRow"""
        return self.FindNextRow()

    def find_next_row(self):
        """Alias for FindNextRow"""
        return self.FindNextRow()

    def FindRow(self, Filter=None):
        arguments = com_arguments([unwrap(a) for a in [Filter]])
        return self.com_object.FindRow(*arguments)

    def findrow(self, Filter=None):
        """Alias for FindRow"""
        arguments = [Filter]
        return self.FindRow(*arguments)

    def find_row(self, Filter=None):
        """Alias for FindRow"""
        arguments = [Filter]
        return self.FindRow(*arguments)

    def GetArray(self, MaxRows=None):
        arguments = com_arguments([unwrap(a) for a in [MaxRows]])
        return self.com_object.GetArray(*arguments)

    def getarray(self, MaxRows=None):
        """Alias for GetArray"""
        arguments = [MaxRows]
        return self.GetArray(*arguments)

    def get_array(self, MaxRows=None):
        """Alias for GetArray"""
        arguments = [MaxRows]
        return self.GetArray(*arguments)

    def GetNextRow(self):
        return self.com_object.GetNextRow()

    def getnextrow(self):
        """Alias for GetNextRow"""
        return self.GetNextRow()

    def get_next_row(self):
        """Alias for GetNextRow"""
        return self.GetNextRow()

    def GetRowCount(self):
        return self.com_object.GetRowCount()

    def getrowcount(self):
        """Alias for GetRowCount"""
        return self.GetRowCount()

    def get_row_count(self):
        """Alias for GetRowCount"""
        return self.GetRowCount()

    def MoveToStart(self):
        self.com_object.MoveToStart()

    def movetostart(self):
        """Alias for MoveToStart"""
        return self.MoveToStart()

    def move_to_start(self):
        """Alias for MoveToStart"""
        return self.MoveToStart()

    def Restrict(self, Filter=None):
        arguments = com_arguments([unwrap(a) for a in [Filter]])
        return Table(self.com_object.Restrict(*arguments))

    def restrict(self, Filter=None):
        """Alias for Restrict"""
        arguments = [Filter]
        return self.Restrict(*arguments)

    def Sort(self, SortProperty=None, Descending=None):
        arguments = com_arguments([unwrap(a) for a in [SortProperty, Descending]])
        self.com_object.Sort(*arguments)

    def sort(self, SortProperty=None, Descending=None):
        """Alias for Sort"""
        arguments = [SortProperty, Descending]
        return self.Sort(*arguments)


class TableView:

    def __init__(self, tableview=None):
        self.com_object= tableview

    @property
    def AllowInCellEditing(self):
        return TableView(self.com_object.AllowInCellEditing)

    @AllowInCellEditing.setter
    def AllowInCellEditing(self, value):
        self.com_object.AllowInCellEditing = value

    @property
    def allowincellediting(self):
        """Alias for AllowInCellEditing"""
        return self.AllowInCellEditing

    @allowincellediting.setter
    def allowincellediting(self, value):
        """Alias for AllowInCellEditing.setter"""
        self.AllowInCellEditing = value

    @property
    def allow_in_cell_editing(self):
        """Alias for AllowInCellEditing"""
        return self.AllowInCellEditing

    @allow_in_cell_editing.setter
    def allow_in_cell_editing(self, value):
        """Alias for AllowInCellEditing.setter"""
        self.AllowInCellEditing = value

    @property
    def AlwaysExpandConversation(self):
        return self.com_object.AlwaysExpandConversation

    @AlwaysExpandConversation.setter
    def AlwaysExpandConversation(self, value):
        self.com_object.AlwaysExpandConversation = value

    @property
    def alwaysexpandconversation(self):
        """Alias for AlwaysExpandConversation"""
        return self.AlwaysExpandConversation

    @alwaysexpandconversation.setter
    def alwaysexpandconversation(self, value):
        """Alias for AlwaysExpandConversation.setter"""
        self.AlwaysExpandConversation = value

    @property
    def always_expand_conversation(self):
        """Alias for AlwaysExpandConversation"""
        return self.AlwaysExpandConversation

    @always_expand_conversation.setter
    def always_expand_conversation(self, value):
        """Alias for AlwaysExpandConversation.setter"""
        self.AlwaysExpandConversation = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoFormatRules(self):
        return AutoFormatRules(self.com_object.AutoFormatRules)

    @property
    def autoformatrules(self):
        """Alias for AutoFormatRules"""
        return self.AutoFormatRules

    @property
    def auto_format_rules(self):
        """Alias for AutoFormatRules"""
        return self.AutoFormatRules

    @property
    def AutomaticColumnSizing(self):
        return TableView(self.com_object.AutomaticColumnSizing)

    @AutomaticColumnSizing.setter
    def AutomaticColumnSizing(self, value):
        self.com_object.AutomaticColumnSizing = value

    @property
    def automaticcolumnsizing(self):
        """Alias for AutomaticColumnSizing"""
        return self.AutomaticColumnSizing

    @automaticcolumnsizing.setter
    def automaticcolumnsizing(self, value):
        """Alias for AutomaticColumnSizing.setter"""
        self.AutomaticColumnSizing = value

    @property
    def automatic_column_sizing(self):
        """Alias for AutomaticColumnSizing"""
        return self.AutomaticColumnSizing

    @automatic_column_sizing.setter
    def automatic_column_sizing(self, value):
        """Alias for AutomaticColumnSizing.setter"""
        self.AutomaticColumnSizing = value

    @property
    def AutomaticGrouping(self):
        return TableView(self.com_object.AutomaticGrouping)

    @AutomaticGrouping.setter
    def AutomaticGrouping(self, value):
        self.com_object.AutomaticGrouping = value

    @property
    def automaticgrouping(self):
        """Alias for AutomaticGrouping"""
        return self.AutomaticGrouping

    @automaticgrouping.setter
    def automaticgrouping(self, value):
        """Alias for AutomaticGrouping.setter"""
        self.AutomaticGrouping = value

    @property
    def automatic_grouping(self):
        """Alias for AutomaticGrouping"""
        return self.AutomaticGrouping

    @automatic_grouping.setter
    def automatic_grouping(self, value):
        """Alias for AutomaticGrouping.setter"""
        self.AutomaticGrouping = value

    @property
    def AutoPreview(self):
        return OlAutoPreview(self.com_object.AutoPreview)

    @AutoPreview.setter
    def AutoPreview(self, value):
        self.com_object.AutoPreview = value

    @property
    def autopreview(self):
        """Alias for AutoPreview"""
        return self.AutoPreview

    @autopreview.setter
    def autopreview(self, value):
        """Alias for AutoPreview.setter"""
        self.AutoPreview = value

    @property
    def auto_preview(self):
        """Alias for AutoPreview"""
        return self.AutoPreview

    @auto_preview.setter
    def auto_preview(self, value):
        """Alias for AutoPreview.setter"""
        self.AutoPreview = value

    @property
    def AutoPreviewFont(self):
        return ViewFont(self.com_object.AutoPreviewFont)

    @property
    def autopreviewfont(self):
        """Alias for AutoPreviewFont"""
        return self.AutoPreviewFont

    @property
    def auto_preview_font(self):
        """Alias for AutoPreviewFont"""
        return self.AutoPreviewFont

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def ColumnFont(self):
        return ViewFont(self.com_object.ColumnFont)

    @property
    def columnfont(self):
        """Alias for ColumnFont"""
        return self.ColumnFont

    @property
    def column_font(self):
        """Alias for ColumnFont"""
        return self.ColumnFont

    @property
    def DefaultExpandCollapseSetting(self):
        return OlDefaultExpandCollapseSetting(self.com_object.DefaultExpandCollapseSetting)

    @DefaultExpandCollapseSetting.setter
    def DefaultExpandCollapseSetting(self, value):
        self.com_object.DefaultExpandCollapseSetting = value

    @property
    def defaultexpandcollapsesetting(self):
        """Alias for DefaultExpandCollapseSetting"""
        return self.DefaultExpandCollapseSetting

    @defaultexpandcollapsesetting.setter
    def defaultexpandcollapsesetting(self, value):
        """Alias for DefaultExpandCollapseSetting.setter"""
        self.DefaultExpandCollapseSetting = value

    @property
    def default_expand_collapse_setting(self):
        """Alias for DefaultExpandCollapseSetting"""
        return self.DefaultExpandCollapseSetting

    @default_expand_collapse_setting.setter
    def default_expand_collapse_setting(self, value):
        """Alias for DefaultExpandCollapseSetting.setter"""
        self.DefaultExpandCollapseSetting = value

    @property
    def Filter(self):
        return self.com_object.Filter

    @Filter.setter
    def Filter(self, value):
        self.com_object.Filter = value

    @property
    def filter(self):
        """Alias for Filter"""
        return self.Filter

    @filter.setter
    def filter(self, value):
        """Alias for Filter.setter"""
        self.Filter = value

    @property
    def GridLineStyle(self):
        return OlGridLineStyle(self.com_object.GridLineStyle)

    @GridLineStyle.setter
    def GridLineStyle(self, value):
        self.com_object.GridLineStyle = value

    @property
    def gridlinestyle(self):
        """Alias for GridLineStyle"""
        return self.GridLineStyle

    @gridlinestyle.setter
    def gridlinestyle(self, value):
        """Alias for GridLineStyle.setter"""
        self.GridLineStyle = value

    @property
    def grid_line_style(self):
        """Alias for GridLineStyle"""
        return self.GridLineStyle

    @grid_line_style.setter
    def grid_line_style(self, value):
        """Alias for GridLineStyle.setter"""
        self.GridLineStyle = value

    @property
    def GroupByFields(self):
        return OrderFields(self.com_object.GroupByFields)

    @property
    def groupbyfields(self):
        """Alias for GroupByFields"""
        return self.GroupByFields

    @property
    def group_by_fields(self):
        """Alias for GroupByFields"""
        return self.GroupByFields

    @property
    def HideReadingPaneHeaderInfo(self):
        return TableView(self.com_object.HideReadingPaneHeaderInfo)

    @HideReadingPaneHeaderInfo.setter
    def HideReadingPaneHeaderInfo(self, value):
        self.com_object.HideReadingPaneHeaderInfo = value

    @property
    def hidereadingpaneheaderinfo(self):
        """Alias for HideReadingPaneHeaderInfo"""
        return self.HideReadingPaneHeaderInfo

    @hidereadingpaneheaderinfo.setter
    def hidereadingpaneheaderinfo(self, value):
        """Alias for HideReadingPaneHeaderInfo.setter"""
        self.HideReadingPaneHeaderInfo = value

    @property
    def hide_reading_pane_header_info(self):
        """Alias for HideReadingPaneHeaderInfo"""
        return self.HideReadingPaneHeaderInfo

    @hide_reading_pane_header_info.setter
    def hide_reading_pane_header_info(self, value):
        """Alias for HideReadingPaneHeaderInfo.setter"""
        self.HideReadingPaneHeaderInfo = value

    @property
    def Language(self):
        return self.com_object.Language

    @Language.setter
    def Language(self, value):
        self.com_object.Language = value

    @property
    def language(self):
        """Alias for Language"""
        return self.Language

    @language.setter
    def language(self, value):
        """Alias for Language.setter"""
        self.Language = value

    @property
    def LockUserChanges(self):
        return self.com_object.LockUserChanges

    @LockUserChanges.setter
    def LockUserChanges(self, value):
        self.com_object.LockUserChanges = value

    @property
    def lockuserchanges(self):
        """Alias for LockUserChanges"""
        return self.LockUserChanges

    @lockuserchanges.setter
    def lockuserchanges(self, value):
        """Alias for LockUserChanges.setter"""
        self.LockUserChanges = value

    @property
    def lock_user_changes(self):
        """Alias for LockUserChanges"""
        return self.LockUserChanges

    @lock_user_changes.setter
    def lock_user_changes(self, value):
        """Alias for LockUserChanges.setter"""
        self.LockUserChanges = value

    @property
    def MaxLinesInMultiLineView(self):
        return TableView(self.com_object.MaxLinesInMultiLineView)

    @MaxLinesInMultiLineView.setter
    def MaxLinesInMultiLineView(self, value):
        self.com_object.MaxLinesInMultiLineView = value

    @property
    def maxlinesinmultilineview(self):
        """Alias for MaxLinesInMultiLineView"""
        return self.MaxLinesInMultiLineView

    @maxlinesinmultilineview.setter
    def maxlinesinmultilineview(self, value):
        """Alias for MaxLinesInMultiLineView.setter"""
        self.MaxLinesInMultiLineView = value

    @property
    def max_lines_in_multi_line_view(self):
        """Alias for MaxLinesInMultiLineView"""
        return self.MaxLinesInMultiLineView

    @max_lines_in_multi_line_view.setter
    def max_lines_in_multi_line_view(self, value):
        """Alias for MaxLinesInMultiLineView.setter"""
        self.MaxLinesInMultiLineView = value

    @property
    def MultiLine(self):
        return OlMultiLine(self.com_object.MultiLine)

    @MultiLine.setter
    def MultiLine(self, value):
        self.com_object.MultiLine = value

    @property
    def multiline(self):
        """Alias for MultiLine"""
        return self.MultiLine

    @multiline.setter
    def multiline(self, value):
        """Alias for MultiLine.setter"""
        self.MultiLine = value

    @property
    def multi_line(self):
        """Alias for MultiLine"""
        return self.MultiLine

    @multi_line.setter
    def multi_line(self, value):
        """Alias for MultiLine.setter"""
        self.MultiLine = value

    @property
    def MultiLineWidth(self):
        return TableView(self.com_object.MultiLineWidth)

    @MultiLineWidth.setter
    def MultiLineWidth(self, value):
        self.com_object.MultiLineWidth = value

    @property
    def multilinewidth(self):
        """Alias for MultiLineWidth"""
        return self.MultiLineWidth

    @multilinewidth.setter
    def multilinewidth(self, value):
        """Alias for MultiLineWidth.setter"""
        self.MultiLineWidth = value

    @property
    def multi_line_width(self):
        """Alias for MultiLineWidth"""
        return self.MultiLineWidth

    @multi_line_width.setter
    def multi_line_width(self, value):
        """Alias for MultiLineWidth.setter"""
        self.MultiLineWidth = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RowFont(self):
        return ViewFont(self.com_object.RowFont)

    @property
    def rowfont(self):
        """Alias for RowFont"""
        return self.RowFont

    @property
    def row_font(self):
        """Alias for RowFont"""
        return self.RowFont

    @property
    def SaveOption(self):
        return OlViewSaveOption(self.com_object.SaveOption)

    @property
    def saveoption(self):
        """Alias for SaveOption"""
        return self.SaveOption

    @property
    def save_option(self):
        """Alias for SaveOption"""
        return self.SaveOption

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def ShowConversationByDate(self):
        return self.com_object.ShowConversationByDate

    @ShowConversationByDate.setter
    def ShowConversationByDate(self, value):
        self.com_object.ShowConversationByDate = value

    @property
    def showconversationbydate(self):
        """Alias for ShowConversationByDate"""
        return self.ShowConversationByDate

    @showconversationbydate.setter
    def showconversationbydate(self, value):
        """Alias for ShowConversationByDate.setter"""
        self.ShowConversationByDate = value

    @property
    def show_conversation_by_date(self):
        """Alias for ShowConversationByDate"""
        return self.ShowConversationByDate

    @show_conversation_by_date.setter
    def show_conversation_by_date(self, value):
        """Alias for ShowConversationByDate.setter"""
        self.ShowConversationByDate = value

    @property
    def ShowConversationSendersAboveSubject(self):
        return self.com_object.ShowConversationSendersAboveSubject

    @ShowConversationSendersAboveSubject.setter
    def ShowConversationSendersAboveSubject(self, value):
        self.com_object.ShowConversationSendersAboveSubject = value

    @property
    def showconversationsendersabovesubject(self):
        """Alias for ShowConversationSendersAboveSubject"""
        return self.ShowConversationSendersAboveSubject

    @showconversationsendersabovesubject.setter
    def showconversationsendersabovesubject(self, value):
        """Alias for ShowConversationSendersAboveSubject.setter"""
        self.ShowConversationSendersAboveSubject = value

    @property
    def show_conversation_senders_above_subject(self):
        """Alias for ShowConversationSendersAboveSubject"""
        return self.ShowConversationSendersAboveSubject

    @show_conversation_senders_above_subject.setter
    def show_conversation_senders_above_subject(self, value):
        """Alias for ShowConversationSendersAboveSubject.setter"""
        self.ShowConversationSendersAboveSubject = value

    @property
    def ShowFullConversations(self):
        return self.com_object.ShowFullConversations

    @ShowFullConversations.setter
    def ShowFullConversations(self, value):
        self.com_object.ShowFullConversations = value

    @property
    def showfullconversations(self):
        """Alias for ShowFullConversations"""
        return self.ShowFullConversations

    @showfullconversations.setter
    def showfullconversations(self, value):
        """Alias for ShowFullConversations.setter"""
        self.ShowFullConversations = value

    @property
    def show_full_conversations(self):
        """Alias for ShowFullConversations"""
        return self.ShowFullConversations

    @show_full_conversations.setter
    def show_full_conversations(self, value):
        """Alias for ShowFullConversations.setter"""
        self.ShowFullConversations = value

    @property
    def ShowItemsInGroups(self):
        return TableView(self.com_object.ShowItemsInGroups)

    @ShowItemsInGroups.setter
    def ShowItemsInGroups(self, value):
        self.com_object.ShowItemsInGroups = value

    @property
    def showitemsingroups(self):
        """Alias for ShowItemsInGroups"""
        return self.ShowItemsInGroups

    @showitemsingroups.setter
    def showitemsingroups(self, value):
        """Alias for ShowItemsInGroups.setter"""
        self.ShowItemsInGroups = value

    @property
    def show_items_in_groups(self):
        """Alias for ShowItemsInGroups"""
        return self.ShowItemsInGroups

    @show_items_in_groups.setter
    def show_items_in_groups(self, value):
        """Alias for ShowItemsInGroups.setter"""
        self.ShowItemsInGroups = value

    @property
    def ShowNewItemRow(self):
        return TableView(self.com_object.ShowNewItemRow)

    @ShowNewItemRow.setter
    def ShowNewItemRow(self, value):
        self.com_object.ShowNewItemRow = value

    @property
    def shownewitemrow(self):
        """Alias for ShowNewItemRow"""
        return self.ShowNewItemRow

    @shownewitemrow.setter
    def shownewitemrow(self, value):
        """Alias for ShowNewItemRow.setter"""
        self.ShowNewItemRow = value

    @property
    def show_new_item_row(self):
        """Alias for ShowNewItemRow"""
        return self.ShowNewItemRow

    @show_new_item_row.setter
    def show_new_item_row(self, value):
        """Alias for ShowNewItemRow.setter"""
        self.ShowNewItemRow = value

    @property
    def ShowReadingPane(self):
        return TableView(self.com_object.ShowReadingPane)

    @ShowReadingPane.setter
    def ShowReadingPane(self, value):
        self.com_object.ShowReadingPane = value

    @property
    def showreadingpane(self):
        """Alias for ShowReadingPane"""
        return self.ShowReadingPane

    @showreadingpane.setter
    def showreadingpane(self, value):
        """Alias for ShowReadingPane.setter"""
        self.ShowReadingPane = value

    @property
    def show_reading_pane(self):
        """Alias for ShowReadingPane"""
        return self.ShowReadingPane

    @show_reading_pane.setter
    def show_reading_pane(self, value):
        """Alias for ShowReadingPane.setter"""
        self.ShowReadingPane = value

    @property
    def SortFields(self):
        return OrderFields(self.com_object.SortFields)

    @property
    def sortfields(self):
        """Alias for SortFields"""
        return self.SortFields

    @property
    def sort_fields(self):
        """Alias for SortFields"""
        return self.SortFields

    @property
    def Standard(self):
        return TableView(self.com_object.Standard)

    @property
    def standard(self):
        """Alias for Standard"""
        return self.Standard

    @property
    def ViewFields(self):
        return ViewFields(self.com_object.ViewFields)

    @property
    def viewfields(self):
        """Alias for ViewFields"""
        return self.ViewFields

    @property
    def view_fields(self):
        """Alias for ViewFields"""
        return self.ViewFields

    @property
    def ViewType(self):
        return OlViewType(self.com_object.ViewType)

    @property
    def viewtype(self):
        """Alias for ViewType"""
        return self.ViewType

    @property
    def view_type(self):
        """Alias for ViewType"""
        return self.ViewType

    @property
    def XML(self):
        return self.com_object.XML

    @XML.setter
    def XML(self, value):
        self.com_object.XML = value

    @property
    def xml(self):
        """Alias for XML"""
        return self.XML

    @xml.setter
    def xml(self, value):
        """Alias for XML.setter"""
        self.XML = value

    @property
    def x_m_l(self):
        """Alias for XML"""
        return self.XML

    @x_m_l.setter
    def x_m_l(self, value):
        """Alias for XML.setter"""
        self.XML = value

    def Apply(self):
        self.com_object.Apply()

    def apply(self):
        """Alias for Apply"""
        return self.Apply()

    def Copy(self, Name=None, SaveOption=None):
        arguments = com_arguments([unwrap(a) for a in [Name, SaveOption]])
        return View(self.com_object.Copy(*arguments))

    def copy(self, Name=None, SaveOption=None):
        """Alias for Copy"""
        arguments = [Name, SaveOption]
        return self.Copy(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def GetTable(self):
        return Table(self.com_object.GetTable())

    def gettable(self):
        """Alias for GetTable"""
        return self.GetTable()

    def get_table(self):
        """Alias for GetTable"""
        return self.GetTable()

    def GoToDate(self, Date=None):
        arguments = com_arguments([unwrap(a) for a in [Date]])
        self.com_object.GoToDate(*arguments)

    def gotodate(self, Date=None):
        """Alias for GoToDate"""
        arguments = [Date]
        return self.GoToDate(*arguments)

    def go_to_date(self, Date=None):
        """Alias for GoToDate"""
        arguments = [Date]
        return self.GoToDate(*arguments)

    def Reset(self):
        self.com_object.Reset()

    def reset(self):
        """Alias for Reset"""
        return self.Reset()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()


class Tabs:

    def __init__(self, tabs=None):
        self.com_object= tabs


class TabStrip:

    def __init__(self, tabstrip=None):
        self.com_object= tabstrip


class TaskItem:

    def __init__(self, taskitem=None):
        self.com_object= taskitem

    @property
    def Actions(self):
        return Actions(self.com_object.Actions)

    @property
    def actions(self):
        """Alias for Actions"""
        return self.Actions

    @property
    def ActualWork(self):
        return self.com_object.ActualWork

    @ActualWork.setter
    def ActualWork(self, value):
        self.com_object.ActualWork = value

    @property
    def actualwork(self):
        """Alias for ActualWork"""
        return self.ActualWork

    @actualwork.setter
    def actualwork(self, value):
        """Alias for ActualWork.setter"""
        self.ActualWork = value

    @property
    def actual_work(self):
        """Alias for ActualWork"""
        return self.ActualWork

    @actual_work.setter
    def actual_work(self, value):
        """Alias for ActualWork.setter"""
        self.ActualWork = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Attachments(self):
        return Attachments(self.com_object.Attachments)

    @property
    def attachments(self):
        """Alias for Attachments"""
        return self.Attachments

    @property
    def AutoResolvedWinner(self):
        return self.com_object.AutoResolvedWinner

    @property
    def autoresolvedwinner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def auto_resolved_winner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def BillingInformation(self):
        return self.com_object.BillingInformation

    @BillingInformation.setter
    def BillingInformation(self, value):
        self.com_object.BillingInformation = value

    @property
    def billinginformation(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billinginformation.setter
    def billinginformation(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def billing_information(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billing_information.setter
    def billing_information(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def Body(self):
        return self.com_object.Body

    @Body.setter
    def Body(self, value):
        self.com_object.Body = value

    @property
    def body(self):
        """Alias for Body"""
        return self.Body

    @body.setter
    def body(self, value):
        """Alias for Body.setter"""
        self.Body = value

    @property
    def CardData(self):
        return self.com_object.CardData

    @CardData.setter
    def CardData(self, value):
        self.com_object.CardData = value

    @property
    def carddata(self):
        """Alias for CardData"""
        return self.CardData

    @carddata.setter
    def carddata(self, value):
        """Alias for CardData.setter"""
        self.CardData = value

    @property
    def card_data(self):
        """Alias for CardData"""
        return self.CardData

    @card_data.setter
    def card_data(self, value):
        """Alias for CardData.setter"""
        self.CardData = value

    @property
    def Categories(self):
        return self.com_object.Categories

    @Categories.setter
    def Categories(self, value):
        self.com_object.Categories = value

    @property
    def categories(self):
        """Alias for Categories"""
        return self.Categories

    @categories.setter
    def categories(self, value):
        """Alias for Categories.setter"""
        self.Categories = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Companies(self):
        return self.com_object.Companies

    @Companies.setter
    def Companies(self, value):
        self.com_object.Companies = value

    @property
    def companies(self):
        """Alias for Companies"""
        return self.Companies

    @companies.setter
    def companies(self, value):
        """Alias for Companies.setter"""
        self.Companies = value

    @property
    def Complete(self):
        return self.com_object.Complete

    @Complete.setter
    def Complete(self, value):
        self.com_object.Complete = value

    @property
    def complete(self):
        """Alias for Complete"""
        return self.Complete

    @complete.setter
    def complete(self, value):
        """Alias for Complete.setter"""
        self.Complete = value

    @property
    def Conflicts(self):
        return self.com_object.Conflicts

    @property
    def conflicts(self):
        """Alias for Conflicts"""
        return self.Conflicts

    @property
    def ContactNames(self):
        return self.com_object.ContactNames

    @ContactNames.setter
    def ContactNames(self, value):
        self.com_object.ContactNames = value

    @property
    def contactnames(self):
        """Alias for ContactNames"""
        return self.ContactNames

    @contactnames.setter
    def contactnames(self, value):
        """Alias for ContactNames.setter"""
        self.ContactNames = value

    @property
    def contact_names(self):
        """Alias for ContactNames"""
        return self.ContactNames

    @contact_names.setter
    def contact_names(self, value):
        """Alias for ContactNames.setter"""
        self.ContactNames = value

    @property
    def ConversationID(self):
        return Conversation(self.com_object.ConversationID)

    @property
    def conversationid(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def conversation_i_d(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def ConversationIndex(self):
        return self.com_object.ConversationIndex

    @property
    def conversationindex(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def conversation_index(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def ConversationTopic(self):
        return self.com_object.ConversationTopic

    @property
    def conversationtopic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def conversation_topic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def CreationTime(self):
        return self.com_object.CreationTime

    @property
    def creationtime(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def creation_time(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def DateCompleted(self):
        return self.com_object.DateCompleted

    @DateCompleted.setter
    def DateCompleted(self, value):
        self.com_object.DateCompleted = value

    @property
    def datecompleted(self):
        """Alias for DateCompleted"""
        return self.DateCompleted

    @datecompleted.setter
    def datecompleted(self, value):
        """Alias for DateCompleted.setter"""
        self.DateCompleted = value

    @property
    def date_completed(self):
        """Alias for DateCompleted"""
        return self.DateCompleted

    @date_completed.setter
    def date_completed(self, value):
        """Alias for DateCompleted.setter"""
        self.DateCompleted = value

    @property
    def DelegationState(self):
        return OlTaskDelegationState(self.com_object.DelegationState)

    @property
    def delegationstate(self):
        """Alias for DelegationState"""
        return self.DelegationState

    @property
    def delegation_state(self):
        """Alias for DelegationState"""
        return self.DelegationState

    @property
    def Delegator(self):
        return self.com_object.Delegator

    @property
    def delegator(self):
        """Alias for Delegator"""
        return self.Delegator

    @property
    def DownloadState(self):
        return OlDownloadState(self.com_object.DownloadState)

    @property
    def downloadstate(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def download_state(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def DueDate(self):
        return self.com_object.DueDate

    @DueDate.setter
    def DueDate(self, value):
        self.com_object.DueDate = value

    @property
    def duedate(self):
        """Alias for DueDate"""
        return self.DueDate

    @duedate.setter
    def duedate(self, value):
        """Alias for DueDate.setter"""
        self.DueDate = value

    @property
    def due_date(self):
        """Alias for DueDate"""
        return self.DueDate

    @due_date.setter
    def due_date(self, value):
        """Alias for DueDate.setter"""
        self.DueDate = value

    @property
    def EntryID(self):
        return self.com_object.EntryID

    @property
    def entryid(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def entry_i_d(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def FormDescription(self):
        return FormDescription(self.com_object.FormDescription)

    @property
    def formdescription(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def form_description(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def GetInspector(self):
        return Inspector(self.com_object.GetInspector)

    @property
    def getinspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def get_inspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def Importance(self):
        return OlImportance(self.com_object.Importance)

    @Importance.setter
    def Importance(self, value):
        self.com_object.Importance = value

    @property
    def importance(self):
        """Alias for Importance"""
        return self.Importance

    @importance.setter
    def importance(self, value):
        """Alias for Importance.setter"""
        self.Importance = value

    @property
    def InternetCodepage(self):
        return self.com_object.InternetCodepage

    @InternetCodepage.setter
    def InternetCodepage(self, value):
        self.com_object.InternetCodepage = value

    @property
    def internetcodepage(self):
        """Alias for InternetCodepage"""
        return self.InternetCodepage

    @internetcodepage.setter
    def internetcodepage(self, value):
        """Alias for InternetCodepage.setter"""
        self.InternetCodepage = value

    @property
    def internet_codepage(self):
        """Alias for InternetCodepage"""
        return self.InternetCodepage

    @internet_codepage.setter
    def internet_codepage(self, value):
        """Alias for InternetCodepage.setter"""
        self.InternetCodepage = value

    @property
    def IsConflict(self):
        return self.com_object.IsConflict

    @property
    def isconflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def is_conflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def IsRecurring(self):
        return self.com_object.IsRecurring

    @property
    def isrecurring(self):
        """Alias for IsRecurring"""
        return self.IsRecurring

    @property
    def is_recurring(self):
        """Alias for IsRecurring"""
        return self.IsRecurring

    @property
    def ItemProperties(self):
        return ItemProperties(self.com_object.ItemProperties)

    @property
    def itemproperties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def item_properties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def LastModificationTime(self):
        return self.com_object.LastModificationTime

    @property
    def lastmodificationtime(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def last_modification_time(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def MarkForDownload(self):
        return OlRemoteStatus(self.com_object.MarkForDownload)

    @MarkForDownload.setter
    def MarkForDownload(self, value):
        self.com_object.MarkForDownload = value

    @property
    def markfordownload(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @markfordownload.setter
    def markfordownload(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def mark_for_download(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @mark_for_download.setter
    def mark_for_download(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def MessageClass(self):
        return self.com_object.MessageClass

    @MessageClass.setter
    def MessageClass(self, value):
        self.com_object.MessageClass = value

    @property
    def messageclass(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @messageclass.setter
    def messageclass(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def message_class(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @message_class.setter
    def message_class(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def Mileage(self):
        return self.com_object.Mileage

    @Mileage.setter
    def Mileage(self, value):
        self.com_object.Mileage = value

    @property
    def mileage(self):
        """Alias for Mileage"""
        return self.Mileage

    @mileage.setter
    def mileage(self, value):
        """Alias for Mileage.setter"""
        self.Mileage = value

    @property
    def NoAging(self):
        return self.com_object.NoAging

    @NoAging.setter
    def NoAging(self, value):
        self.com_object.NoAging = value

    @property
    def noaging(self):
        """Alias for NoAging"""
        return self.NoAging

    @noaging.setter
    def noaging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def no_aging(self):
        """Alias for NoAging"""
        return self.NoAging

    @no_aging.setter
    def no_aging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def Ordinal(self):
        return self.com_object.Ordinal

    @Ordinal.setter
    def Ordinal(self, value):
        self.com_object.Ordinal = value

    @property
    def ordinal(self):
        """Alias for Ordinal"""
        return self.Ordinal

    @ordinal.setter
    def ordinal(self, value):
        """Alias for Ordinal.setter"""
        self.Ordinal = value

    @property
    def OutlookInternalVersion(self):
        return self.com_object.OutlookInternalVersion

    @property
    def outlookinternalversion(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def outlook_internal_version(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def OutlookVersion(self):
        return self.com_object.OutlookVersion

    @property
    def outlookversion(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def outlook_version(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def Owner(self):
        return self.com_object.Owner

    @Owner.setter
    def Owner(self, value):
        self.com_object.Owner = value

    @property
    def owner(self):
        """Alias for Owner"""
        return self.Owner

    @owner.setter
    def owner(self, value):
        """Alias for Owner.setter"""
        self.Owner = value

    @property
    def Ownership(self):
        return OlTaskOwnership(self.com_object.Ownership)

    @property
    def ownership(self):
        """Alias for Ownership"""
        return self.Ownership

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PercentComplete(self):
        return self.com_object.PercentComplete

    @PercentComplete.setter
    def PercentComplete(self, value):
        self.com_object.PercentComplete = value

    @property
    def percentcomplete(self):
        """Alias for PercentComplete"""
        return self.PercentComplete

    @percentcomplete.setter
    def percentcomplete(self, value):
        """Alias for PercentComplete.setter"""
        self.PercentComplete = value

    @property
    def percent_complete(self):
        """Alias for PercentComplete"""
        return self.PercentComplete

    @percent_complete.setter
    def percent_complete(self, value):
        """Alias for PercentComplete.setter"""
        self.PercentComplete = value

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def Recipients(self):
        return Recipients(self.com_object.Recipients)

    @property
    def recipients(self):
        """Alias for Recipients"""
        return self.Recipients

    @property
    def ReminderOverrideDefault(self):
        return self.com_object.ReminderOverrideDefault

    @ReminderOverrideDefault.setter
    def ReminderOverrideDefault(self, value):
        self.com_object.ReminderOverrideDefault = value

    @property
    def reminderoverridedefault(self):
        """Alias for ReminderOverrideDefault"""
        return self.ReminderOverrideDefault

    @reminderoverridedefault.setter
    def reminderoverridedefault(self, value):
        """Alias for ReminderOverrideDefault.setter"""
        self.ReminderOverrideDefault = value

    @property
    def reminder_override_default(self):
        """Alias for ReminderOverrideDefault"""
        return self.ReminderOverrideDefault

    @reminder_override_default.setter
    def reminder_override_default(self, value):
        """Alias for ReminderOverrideDefault.setter"""
        self.ReminderOverrideDefault = value

    @property
    def ReminderPlaySound(self):
        return self.com_object.ReminderPlaySound

    @ReminderPlaySound.setter
    def ReminderPlaySound(self, value):
        self.com_object.ReminderPlaySound = value

    @property
    def reminderplaysound(self):
        """Alias for ReminderPlaySound"""
        return self.ReminderPlaySound

    @reminderplaysound.setter
    def reminderplaysound(self, value):
        """Alias for ReminderPlaySound.setter"""
        self.ReminderPlaySound = value

    @property
    def reminder_play_sound(self):
        """Alias for ReminderPlaySound"""
        return self.ReminderPlaySound

    @reminder_play_sound.setter
    def reminder_play_sound(self, value):
        """Alias for ReminderPlaySound.setter"""
        self.ReminderPlaySound = value

    @property
    def ReminderSet(self):
        return self.com_object.ReminderSet

    @ReminderSet.setter
    def ReminderSet(self, value):
        self.com_object.ReminderSet = value

    @property
    def reminderset(self):
        """Alias for ReminderSet"""
        return self.ReminderSet

    @reminderset.setter
    def reminderset(self, value):
        """Alias for ReminderSet.setter"""
        self.ReminderSet = value

    @property
    def reminder_set(self):
        """Alias for ReminderSet"""
        return self.ReminderSet

    @reminder_set.setter
    def reminder_set(self, value):
        """Alias for ReminderSet.setter"""
        self.ReminderSet = value

    @property
    def ReminderSoundFile(self):
        return self.com_object.ReminderSoundFile

    @ReminderSoundFile.setter
    def ReminderSoundFile(self, value):
        self.com_object.ReminderSoundFile = value

    @property
    def remindersoundfile(self):
        """Alias for ReminderSoundFile"""
        return self.ReminderSoundFile

    @remindersoundfile.setter
    def remindersoundfile(self, value):
        """Alias for ReminderSoundFile.setter"""
        self.ReminderSoundFile = value

    @property
    def reminder_sound_file(self):
        """Alias for ReminderSoundFile"""
        return self.ReminderSoundFile

    @reminder_sound_file.setter
    def reminder_sound_file(self, value):
        """Alias for ReminderSoundFile.setter"""
        self.ReminderSoundFile = value

    @property
    def ReminderTime(self):
        return self.com_object.ReminderTime

    @ReminderTime.setter
    def ReminderTime(self, value):
        self.com_object.ReminderTime = value

    @property
    def remindertime(self):
        """Alias for ReminderTime"""
        return self.ReminderTime

    @remindertime.setter
    def remindertime(self, value):
        """Alias for ReminderTime.setter"""
        self.ReminderTime = value

    @property
    def reminder_time(self):
        """Alias for ReminderTime"""
        return self.ReminderTime

    @reminder_time.setter
    def reminder_time(self, value):
        """Alias for ReminderTime.setter"""
        self.ReminderTime = value

    @property
    def ResponseState(self):
        return OlTaskResponse(self.com_object.ResponseState)

    @property
    def responsestate(self):
        """Alias for ResponseState"""
        return self.ResponseState

    @property
    def response_state(self):
        """Alias for ResponseState"""
        return self.ResponseState

    @property
    def Role(self):
        return self.com_object.Role

    @Role.setter
    def Role(self, value):
        self.com_object.Role = value

    @property
    def role(self):
        """Alias for Role"""
        return self.Role

    @role.setter
    def role(self, value):
        """Alias for Role.setter"""
        self.Role = value

    @property
    def RTFBody(self):
        return self.com_object.RTFBody

    @RTFBody.setter
    def RTFBody(self, value):
        self.com_object.RTFBody = value

    @property
    def rtfbody(self):
        """Alias for RTFBody"""
        return self.RTFBody

    @rtfbody.setter
    def rtfbody(self, value):
        """Alias for RTFBody.setter"""
        self.RTFBody = value

    @property
    def r_t_f_body(self):
        """Alias for RTFBody"""
        return self.RTFBody

    @r_t_f_body.setter
    def r_t_f_body(self, value):
        """Alias for RTFBody.setter"""
        self.RTFBody = value

    @property
    def Saved(self):
        return self.com_object.Saved

    @property
    def saved(self):
        """Alias for Saved"""
        return self.Saved

    @property
    def SchedulePlusPriority(self):
        return self.com_object.SchedulePlusPriority

    @SchedulePlusPriority.setter
    def SchedulePlusPriority(self, value):
        self.com_object.SchedulePlusPriority = value

    @property
    def schedulepluspriority(self):
        """Alias for SchedulePlusPriority"""
        return self.SchedulePlusPriority

    @schedulepluspriority.setter
    def schedulepluspriority(self, value):
        """Alias for SchedulePlusPriority.setter"""
        self.SchedulePlusPriority = value

    @property
    def schedule_plus_priority(self):
        """Alias for SchedulePlusPriority"""
        return self.SchedulePlusPriority

    @schedule_plus_priority.setter
    def schedule_plus_priority(self, value):
        """Alias for SchedulePlusPriority.setter"""
        self.SchedulePlusPriority = value

    @property
    def SendUsingAccount(self):
        return Account(self.com_object.SendUsingAccount)

    @SendUsingAccount.setter
    def SendUsingAccount(self, value):
        self.com_object.SendUsingAccount = value

    @property
    def sendusingaccount(self):
        """Alias for SendUsingAccount"""
        return self.SendUsingAccount

    @sendusingaccount.setter
    def sendusingaccount(self, value):
        """Alias for SendUsingAccount.setter"""
        self.SendUsingAccount = value

    @property
    def send_using_account(self):
        """Alias for SendUsingAccount"""
        return self.SendUsingAccount

    @send_using_account.setter
    def send_using_account(self, value):
        """Alias for SendUsingAccount.setter"""
        self.SendUsingAccount = value

    @property
    def Sensitivity(self):
        return OlSensitivity(self.com_object.Sensitivity)

    @Sensitivity.setter
    def Sensitivity(self, value):
        self.com_object.Sensitivity = value

    @property
    def sensitivity(self):
        """Alias for Sensitivity"""
        return self.Sensitivity

    @sensitivity.setter
    def sensitivity(self, value):
        """Alias for Sensitivity.setter"""
        self.Sensitivity = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Size(self):
        return self.com_object.Size

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @property
    def StartDate(self):
        return self.com_object.StartDate

    @StartDate.setter
    def StartDate(self, value):
        self.com_object.StartDate = value

    @property
    def startdate(self):
        """Alias for StartDate"""
        return self.StartDate

    @startdate.setter
    def startdate(self, value):
        """Alias for StartDate.setter"""
        self.StartDate = value

    @property
    def start_date(self):
        """Alias for StartDate"""
        return self.StartDate

    @start_date.setter
    def start_date(self, value):
        """Alias for StartDate.setter"""
        self.StartDate = value

    @property
    def Status(self):
        return OlTaskStatus(self.com_object.Status)

    @Status.setter
    def Status(self, value):
        self.com_object.Status = value

    @property
    def status(self):
        """Alias for Status"""
        return self.Status

    @status.setter
    def status(self, value):
        """Alias for Status.setter"""
        self.Status = value

    @property
    def StatusOnCompletionRecipients(self):
        return self.com_object.StatusOnCompletionRecipients

    @StatusOnCompletionRecipients.setter
    def StatusOnCompletionRecipients(self, value):
        self.com_object.StatusOnCompletionRecipients = value

    @property
    def statusoncompletionrecipients(self):
        """Alias for StatusOnCompletionRecipients"""
        return self.StatusOnCompletionRecipients

    @statusoncompletionrecipients.setter
    def statusoncompletionrecipients(self, value):
        """Alias for StatusOnCompletionRecipients.setter"""
        self.StatusOnCompletionRecipients = value

    @property
    def status_on_completion_recipients(self):
        """Alias for StatusOnCompletionRecipients"""
        return self.StatusOnCompletionRecipients

    @status_on_completion_recipients.setter
    def status_on_completion_recipients(self, value):
        """Alias for StatusOnCompletionRecipients.setter"""
        self.StatusOnCompletionRecipients = value

    @property
    def StatusUpdateRecipients(self):
        return self.com_object.StatusUpdateRecipients

    @StatusUpdateRecipients.setter
    def StatusUpdateRecipients(self, value):
        self.com_object.StatusUpdateRecipients = value

    @property
    def statusupdaterecipients(self):
        """Alias for StatusUpdateRecipients"""
        return self.StatusUpdateRecipients

    @statusupdaterecipients.setter
    def statusupdaterecipients(self, value):
        """Alias for StatusUpdateRecipients.setter"""
        self.StatusUpdateRecipients = value

    @property
    def status_update_recipients(self):
        """Alias for StatusUpdateRecipients"""
        return self.StatusUpdateRecipients

    @status_update_recipients.setter
    def status_update_recipients(self, value):
        """Alias for StatusUpdateRecipients.setter"""
        self.StatusUpdateRecipients = value

    @property
    def Subject(self):
        return self.com_object.Subject

    @Subject.setter
    def Subject(self, value):
        self.com_object.Subject = value

    @property
    def subject(self):
        """Alias for Subject"""
        return self.Subject

    @subject.setter
    def subject(self, value):
        """Alias for Subject.setter"""
        self.Subject = value

    @property
    def TeamTask(self):
        return self.com_object.TeamTask

    @TeamTask.setter
    def TeamTask(self, value):
        self.com_object.TeamTask = value

    @property
    def teamtask(self):
        """Alias for TeamTask"""
        return self.TeamTask

    @teamtask.setter
    def teamtask(self, value):
        """Alias for TeamTask.setter"""
        self.TeamTask = value

    @property
    def team_task(self):
        """Alias for TeamTask"""
        return self.TeamTask

    @team_task.setter
    def team_task(self, value):
        """Alias for TeamTask.setter"""
        self.TeamTask = value

    @property
    def ToDoTaskOrdinal(self):
        return TaskItem(self.com_object.ToDoTaskOrdinal)

    @ToDoTaskOrdinal.setter
    def ToDoTaskOrdinal(self, value):
        self.com_object.ToDoTaskOrdinal = value

    @property
    def todotaskordinal(self):
        """Alias for ToDoTaskOrdinal"""
        return self.ToDoTaskOrdinal

    @todotaskordinal.setter
    def todotaskordinal(self, value):
        """Alias for ToDoTaskOrdinal.setter"""
        self.ToDoTaskOrdinal = value

    @property
    def to_do_task_ordinal(self):
        """Alias for ToDoTaskOrdinal"""
        return self.ToDoTaskOrdinal

    @to_do_task_ordinal.setter
    def to_do_task_ordinal(self, value):
        """Alias for ToDoTaskOrdinal.setter"""
        self.ToDoTaskOrdinal = value

    @property
    def TotalWork(self):
        return self.com_object.TotalWork

    @TotalWork.setter
    def TotalWork(self, value):
        self.com_object.TotalWork = value

    @property
    def totalwork(self):
        """Alias for TotalWork"""
        return self.TotalWork

    @totalwork.setter
    def totalwork(self, value):
        """Alias for TotalWork.setter"""
        self.TotalWork = value

    @property
    def total_work(self):
        """Alias for TotalWork"""
        return self.TotalWork

    @total_work.setter
    def total_work(self, value):
        """Alias for TotalWork.setter"""
        self.TotalWork = value

    @property
    def UnRead(self):
        return self.com_object.UnRead

    @UnRead.setter
    def UnRead(self, value):
        self.com_object.UnRead = value

    @property
    def unread(self):
        """Alias for UnRead"""
        return self.UnRead

    @unread.setter
    def unread(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def un_read(self):
        """Alias for UnRead"""
        return self.UnRead

    @un_read.setter
    def un_read(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def UserProperties(self):
        return UserProperties(self.com_object.UserProperties)

    @property
    def userproperties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    @property
    def user_properties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    def Assign(self):
        return TaskItem(self.com_object.Assign())

    def assign(self):
        """Alias for Assign"""
        return self.Assign()

    def CancelResponseState(self):
        self.com_object.CancelResponseState()

    def cancelresponsestate(self):
        """Alias for CancelResponseState"""
        return self.CancelResponseState()

    def cancel_response_state(self):
        """Alias for CancelResponseState"""
        return self.CancelResponseState()

    def ClearRecurrencePattern(self):
        self.com_object.ClearRecurrencePattern()

    def clearrecurrencepattern(self):
        """Alias for ClearRecurrencePattern"""
        return self.ClearRecurrencePattern()

    def clear_recurrence_pattern(self):
        """Alias for ClearRecurrencePattern"""
        return self.ClearRecurrencePattern()

    def Close(self, SaveMode=None):
        arguments = com_arguments([unwrap(a) for a in [SaveMode]])
        self.com_object.Close(*arguments)

    def close(self, SaveMode=None):
        """Alias for Close"""
        arguments = [SaveMode]
        return self.Close(*arguments)

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Display(self, Modal=None):
        arguments = com_arguments([unwrap(a) for a in [Modal]])
        self.com_object.Display(*arguments)

    def display(self, Modal=None):
        """Alias for Display"""
        arguments = [Modal]
        return self.Display(*arguments)

    def GetConversation(self):
        return Conversation(self.com_object.GetConversation())

    def getconversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def get_conversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def GetRecurrencePattern(self):
        return RecurrencePattern(self.com_object.GetRecurrencePattern())

    def getrecurrencepattern(self):
        """Alias for GetRecurrencePattern"""
        return self.GetRecurrencePattern()

    def get_recurrence_pattern(self):
        """Alias for GetRecurrencePattern"""
        return self.GetRecurrencePattern()

    def MarkComplete(self):
        self.com_object.MarkComplete()

    def markcomplete(self):
        """Alias for MarkComplete"""
        return self.MarkComplete()

    def mark_complete(self):
        """Alias for MarkComplete"""
        return self.MarkComplete()

    def Move(self, DestFldr=None):
        arguments = com_arguments([unwrap(a) for a in [DestFldr]])
        return self.com_object.Move(*arguments)

    def move(self, DestFldr=None):
        """Alias for Move"""
        arguments = [DestFldr]
        return self.Move(*arguments)

    def PrintOut(self):
        self.com_object.PrintOut()

    def printout(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def print_out(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def Respond(self, Response=None, fNoUI=None, fAdditionalTextDialog=None):
        arguments = com_arguments([unwrap(a) for a in [Response, fNoUI, fAdditionalTextDialog]])
        return TaskItem(self.com_object.Respond(*arguments))

    def respond(self, Response=None, fNoUI=None, fAdditionalTextDialog=None):
        """Alias for Respond"""
        arguments = [Response, fNoUI, fAdditionalTextDialog]
        return self.Respond(*arguments)

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()

    def SaveAs(self, Path=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Path, Type]])
        self.com_object.SaveAs(*arguments)

    def saveas(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def save_as(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def Send(self):
        self.com_object.Send()

    def send(self):
        """Alias for Send"""
        return self.Send()

    def ShowCategoriesDialog(self):
        self.com_object.ShowCategoriesDialog()

    def showcategoriesdialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()

    def show_categories_dialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()

    def SkipRecurrence(self):
        return self.com_object.SkipRecurrence()

    def skiprecurrence(self):
        """Alias for SkipRecurrence"""
        return self.SkipRecurrence()

    def skip_recurrence(self):
        """Alias for SkipRecurrence"""
        return self.SkipRecurrence()

    def StatusReport(self):
        return self.com_object.StatusReport()

    def statusreport(self):
        """Alias for StatusReport"""
        return self.StatusReport()

    def status_report(self):
        """Alias for StatusReport"""
        return self.StatusReport()


class TaskRequestAcceptItem:

    def __init__(self, taskrequestacceptitem=None):
        self.com_object= taskrequestacceptitem

    @property
    def Actions(self):
        return Actions(self.com_object.Actions)

    @property
    def actions(self):
        """Alias for Actions"""
        return self.Actions

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Attachments(self):
        return Attachments(self.com_object.Attachments)

    @property
    def attachments(self):
        """Alias for Attachments"""
        return self.Attachments

    @property
    def AutoResolvedWinner(self):
        return self.com_object.AutoResolvedWinner

    @property
    def autoresolvedwinner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def auto_resolved_winner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def BillingInformation(self):
        return self.com_object.BillingInformation

    @BillingInformation.setter
    def BillingInformation(self, value):
        self.com_object.BillingInformation = value

    @property
    def billinginformation(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billinginformation.setter
    def billinginformation(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def billing_information(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billing_information.setter
    def billing_information(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def Body(self):
        return self.com_object.Body

    @Body.setter
    def Body(self, value):
        self.com_object.Body = value

    @property
    def body(self):
        """Alias for Body"""
        return self.Body

    @body.setter
    def body(self, value):
        """Alias for Body.setter"""
        self.Body = value

    @property
    def Categories(self):
        return self.com_object.Categories

    @Categories.setter
    def Categories(self, value):
        self.com_object.Categories = value

    @property
    def categories(self):
        """Alias for Categories"""
        return self.Categories

    @categories.setter
    def categories(self, value):
        """Alias for Categories.setter"""
        self.Categories = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Companies(self):
        return self.com_object.Companies

    @Companies.setter
    def Companies(self, value):
        self.com_object.Companies = value

    @property
    def companies(self):
        """Alias for Companies"""
        return self.Companies

    @companies.setter
    def companies(self, value):
        """Alias for Companies.setter"""
        self.Companies = value

    @property
    def Conflicts(self):
        return self.com_object.Conflicts

    @property
    def conflicts(self):
        """Alias for Conflicts"""
        return self.Conflicts

    @property
    def ConversationID(self):
        return Conversation(self.com_object.ConversationID)

    @property
    def conversationid(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def conversation_i_d(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def ConversationIndex(self):
        return self.com_object.ConversationIndex

    @property
    def conversationindex(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def conversation_index(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def ConversationTopic(self):
        return self.com_object.ConversationTopic

    @property
    def conversationtopic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def conversation_topic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def CreationTime(self):
        return self.com_object.CreationTime

    @property
    def creationtime(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def creation_time(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def DownloadState(self):
        return OlDownloadState(self.com_object.DownloadState)

    @property
    def downloadstate(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def download_state(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def EntryID(self):
        return self.com_object.EntryID

    @property
    def entryid(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def entry_i_d(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def FormDescription(self):
        return FormDescription(self.com_object.FormDescription)

    @property
    def formdescription(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def form_description(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def GetInspector(self):
        return Inspector(self.com_object.GetInspector)

    @property
    def getinspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def get_inspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def Importance(self):
        return OlImportance(self.com_object.Importance)

    @Importance.setter
    def Importance(self, value):
        self.com_object.Importance = value

    @property
    def importance(self):
        """Alias for Importance"""
        return self.Importance

    @importance.setter
    def importance(self, value):
        """Alias for Importance.setter"""
        self.Importance = value

    @property
    def IsConflict(self):
        return self.com_object.IsConflict

    @property
    def isconflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def is_conflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def ItemProperties(self):
        return ItemProperties(self.com_object.ItemProperties)

    @property
    def itemproperties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def item_properties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def LastModificationTime(self):
        return self.com_object.LastModificationTime

    @property
    def lastmodificationtime(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def last_modification_time(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def MarkForDownload(self):
        return OlRemoteStatus(self.com_object.MarkForDownload)

    @MarkForDownload.setter
    def MarkForDownload(self, value):
        self.com_object.MarkForDownload = value

    @property
    def markfordownload(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @markfordownload.setter
    def markfordownload(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def mark_for_download(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @mark_for_download.setter
    def mark_for_download(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def MessageClass(self):
        return self.com_object.MessageClass

    @MessageClass.setter
    def MessageClass(self, value):
        self.com_object.MessageClass = value

    @property
    def messageclass(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @messageclass.setter
    def messageclass(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def message_class(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @message_class.setter
    def message_class(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def Mileage(self):
        return self.com_object.Mileage

    @Mileage.setter
    def Mileage(self, value):
        self.com_object.Mileage = value

    @property
    def mileage(self):
        """Alias for Mileage"""
        return self.Mileage

    @mileage.setter
    def mileage(self, value):
        """Alias for Mileage.setter"""
        self.Mileage = value

    @property
    def NoAging(self):
        return self.com_object.NoAging

    @NoAging.setter
    def NoAging(self, value):
        self.com_object.NoAging = value

    @property
    def noaging(self):
        """Alias for NoAging"""
        return self.NoAging

    @noaging.setter
    def noaging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def no_aging(self):
        """Alias for NoAging"""
        return self.NoAging

    @no_aging.setter
    def no_aging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def OutlookInternalVersion(self):
        return self.com_object.OutlookInternalVersion

    @property
    def outlookinternalversion(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def outlook_internal_version(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def OutlookVersion(self):
        return self.com_object.OutlookVersion

    @property
    def outlookversion(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def outlook_version(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def RTFBody(self):
        return self.com_object.RTFBody

    @RTFBody.setter
    def RTFBody(self, value):
        self.com_object.RTFBody = value

    @property
    def rtfbody(self):
        """Alias for RTFBody"""
        return self.RTFBody

    @rtfbody.setter
    def rtfbody(self, value):
        """Alias for RTFBody.setter"""
        self.RTFBody = value

    @property
    def r_t_f_body(self):
        """Alias for RTFBody"""
        return self.RTFBody

    @r_t_f_body.setter
    def r_t_f_body(self, value):
        """Alias for RTFBody.setter"""
        self.RTFBody = value

    @property
    def Saved(self):
        return self.com_object.Saved

    @property
    def saved(self):
        """Alias for Saved"""
        return self.Saved

    @property
    def Sensitivity(self):
        return OlSensitivity(self.com_object.Sensitivity)

    @Sensitivity.setter
    def Sensitivity(self, value):
        self.com_object.Sensitivity = value

    @property
    def sensitivity(self):
        """Alias for Sensitivity"""
        return self.Sensitivity

    @sensitivity.setter
    def sensitivity(self, value):
        """Alias for Sensitivity.setter"""
        self.Sensitivity = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Size(self):
        return self.com_object.Size

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @property
    def Subject(self):
        return self.com_object.Subject

    @Subject.setter
    def Subject(self, value):
        self.com_object.Subject = value

    @property
    def subject(self):
        """Alias for Subject"""
        return self.Subject

    @subject.setter
    def subject(self, value):
        """Alias for Subject.setter"""
        self.Subject = value

    @property
    def UnRead(self):
        return self.com_object.UnRead

    @UnRead.setter
    def UnRead(self, value):
        self.com_object.UnRead = value

    @property
    def unread(self):
        """Alias for UnRead"""
        return self.UnRead

    @unread.setter
    def unread(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def un_read(self):
        """Alias for UnRead"""
        return self.UnRead

    @un_read.setter
    def un_read(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def UserProperties(self):
        return UserProperties(self.com_object.UserProperties)

    @property
    def userproperties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    @property
    def user_properties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    def Close(self, SaveMode=None):
        arguments = com_arguments([unwrap(a) for a in [SaveMode]])
        self.com_object.Close(*arguments)

    def close(self, SaveMode=None):
        """Alias for Close"""
        arguments = [SaveMode]
        return self.Close(*arguments)

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Display(self, Modal=None):
        arguments = com_arguments([unwrap(a) for a in [Modal]])
        self.com_object.Display(*arguments)

    def display(self, Modal=None):
        """Alias for Display"""
        arguments = [Modal]
        return self.Display(*arguments)

    def GetAssociatedTask(self, AddToTaskList=None):
        arguments = com_arguments([unwrap(a) for a in [AddToTaskList]])
        return TaskItem(self.com_object.GetAssociatedTask(*arguments))

    def getassociatedtask(self, AddToTaskList=None):
        """Alias for GetAssociatedTask"""
        arguments = [AddToTaskList]
        return self.GetAssociatedTask(*arguments)

    def get_associated_task(self, AddToTaskList=None):
        """Alias for GetAssociatedTask"""
        arguments = [AddToTaskList]
        return self.GetAssociatedTask(*arguments)

    def GetConversation(self):
        return Conversation(self.com_object.GetConversation())

    def getconversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def get_conversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def Move(self, DestFldr=None):
        arguments = com_arguments([unwrap(a) for a in [DestFldr]])
        return self.com_object.Move(*arguments)

    def move(self, DestFldr=None):
        """Alias for Move"""
        arguments = [DestFldr]
        return self.Move(*arguments)

    def PrintOut(self):
        self.com_object.PrintOut()

    def printout(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def print_out(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()

    def SaveAs(self, Path=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Path, Type]])
        self.com_object.SaveAs(*arguments)

    def saveas(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def save_as(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def ShowCategoriesDialog(self):
        self.com_object.ShowCategoriesDialog()

    def showcategoriesdialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()

    def show_categories_dialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()


class TaskRequestDeclineItem:

    def __init__(self, taskrequestdeclineitem=None):
        self.com_object= taskrequestdeclineitem

    @property
    def Actions(self):
        return Actions(self.com_object.Actions)

    @property
    def actions(self):
        """Alias for Actions"""
        return self.Actions

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Attachments(self):
        return Attachments(self.com_object.Attachments)

    @property
    def attachments(self):
        """Alias for Attachments"""
        return self.Attachments

    @property
    def AutoResolvedWinner(self):
        return self.com_object.AutoResolvedWinner

    @property
    def autoresolvedwinner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def auto_resolved_winner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def BillingInformation(self):
        return self.com_object.BillingInformation

    @BillingInformation.setter
    def BillingInformation(self, value):
        self.com_object.BillingInformation = value

    @property
    def billinginformation(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billinginformation.setter
    def billinginformation(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def billing_information(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billing_information.setter
    def billing_information(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def Body(self):
        return self.com_object.Body

    @Body.setter
    def Body(self, value):
        self.com_object.Body = value

    @property
    def body(self):
        """Alias for Body"""
        return self.Body

    @body.setter
    def body(self, value):
        """Alias for Body.setter"""
        self.Body = value

    @property
    def Categories(self):
        return self.com_object.Categories

    @Categories.setter
    def Categories(self, value):
        self.com_object.Categories = value

    @property
    def categories(self):
        """Alias for Categories"""
        return self.Categories

    @categories.setter
    def categories(self, value):
        """Alias for Categories.setter"""
        self.Categories = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Companies(self):
        return self.com_object.Companies

    @Companies.setter
    def Companies(self, value):
        self.com_object.Companies = value

    @property
    def companies(self):
        """Alias for Companies"""
        return self.Companies

    @companies.setter
    def companies(self, value):
        """Alias for Companies.setter"""
        self.Companies = value

    @property
    def Conflicts(self):
        return self.com_object.Conflicts

    @property
    def conflicts(self):
        """Alias for Conflicts"""
        return self.Conflicts

    @property
    def ConversationID(self):
        return Conversation(self.com_object.ConversationID)

    @property
    def conversationid(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def conversation_i_d(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def ConversationIndex(self):
        return self.com_object.ConversationIndex

    @property
    def conversationindex(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def conversation_index(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def ConversationTopic(self):
        return self.com_object.ConversationTopic

    @property
    def conversationtopic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def conversation_topic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def CreationTime(self):
        return self.com_object.CreationTime

    @property
    def creationtime(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def creation_time(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def DownloadState(self):
        return OlDownloadState(self.com_object.DownloadState)

    @property
    def downloadstate(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def download_state(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def EntryID(self):
        return self.com_object.EntryID

    @property
    def entryid(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def entry_i_d(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def FormDescription(self):
        return FormDescription(self.com_object.FormDescription)

    @property
    def formdescription(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def form_description(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def GetInspector(self):
        return Inspector(self.com_object.GetInspector)

    @property
    def getinspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def get_inspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def Importance(self):
        return OlImportance(self.com_object.Importance)

    @Importance.setter
    def Importance(self, value):
        self.com_object.Importance = value

    @property
    def importance(self):
        """Alias for Importance"""
        return self.Importance

    @importance.setter
    def importance(self, value):
        """Alias for Importance.setter"""
        self.Importance = value

    @property
    def IsConflict(self):
        return self.com_object.IsConflict

    @property
    def isconflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def is_conflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def ItemProperties(self):
        return ItemProperties(self.com_object.ItemProperties)

    @property
    def itemproperties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def item_properties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def LastModificationTime(self):
        return self.com_object.LastModificationTime

    @property
    def lastmodificationtime(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def last_modification_time(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def MarkForDownload(self):
        return OlRemoteStatus(self.com_object.MarkForDownload)

    @MarkForDownload.setter
    def MarkForDownload(self, value):
        self.com_object.MarkForDownload = value

    @property
    def markfordownload(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @markfordownload.setter
    def markfordownload(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def mark_for_download(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @mark_for_download.setter
    def mark_for_download(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def MessageClass(self):
        return self.com_object.MessageClass

    @MessageClass.setter
    def MessageClass(self, value):
        self.com_object.MessageClass = value

    @property
    def messageclass(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @messageclass.setter
    def messageclass(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def message_class(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @message_class.setter
    def message_class(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def Mileage(self):
        return self.com_object.Mileage

    @Mileage.setter
    def Mileage(self, value):
        self.com_object.Mileage = value

    @property
    def mileage(self):
        """Alias for Mileage"""
        return self.Mileage

    @mileage.setter
    def mileage(self, value):
        """Alias for Mileage.setter"""
        self.Mileage = value

    @property
    def NoAging(self):
        return self.com_object.NoAging

    @NoAging.setter
    def NoAging(self, value):
        self.com_object.NoAging = value

    @property
    def noaging(self):
        """Alias for NoAging"""
        return self.NoAging

    @noaging.setter
    def noaging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def no_aging(self):
        """Alias for NoAging"""
        return self.NoAging

    @no_aging.setter
    def no_aging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def OutlookInternalVersion(self):
        return self.com_object.OutlookInternalVersion

    @property
    def outlookinternalversion(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def outlook_internal_version(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def OutlookVersion(self):
        return self.com_object.OutlookVersion

    @property
    def outlookversion(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def outlook_version(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def RTFBody(self):
        return self.com_object.RTFBody

    @RTFBody.setter
    def RTFBody(self, value):
        self.com_object.RTFBody = value

    @property
    def rtfbody(self):
        """Alias for RTFBody"""
        return self.RTFBody

    @rtfbody.setter
    def rtfbody(self, value):
        """Alias for RTFBody.setter"""
        self.RTFBody = value

    @property
    def r_t_f_body(self):
        """Alias for RTFBody"""
        return self.RTFBody

    @r_t_f_body.setter
    def r_t_f_body(self, value):
        """Alias for RTFBody.setter"""
        self.RTFBody = value

    @property
    def Saved(self):
        return self.com_object.Saved

    @property
    def saved(self):
        """Alias for Saved"""
        return self.Saved

    @property
    def Sensitivity(self):
        return OlSensitivity(self.com_object.Sensitivity)

    @Sensitivity.setter
    def Sensitivity(self, value):
        self.com_object.Sensitivity = value

    @property
    def sensitivity(self):
        """Alias for Sensitivity"""
        return self.Sensitivity

    @sensitivity.setter
    def sensitivity(self, value):
        """Alias for Sensitivity.setter"""
        self.Sensitivity = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Size(self):
        return self.com_object.Size

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @property
    def Subject(self):
        return self.com_object.Subject

    @Subject.setter
    def Subject(self, value):
        self.com_object.Subject = value

    @property
    def subject(self):
        """Alias for Subject"""
        return self.Subject

    @subject.setter
    def subject(self, value):
        """Alias for Subject.setter"""
        self.Subject = value

    @property
    def UnRead(self):
        return self.com_object.UnRead

    @UnRead.setter
    def UnRead(self, value):
        self.com_object.UnRead = value

    @property
    def unread(self):
        """Alias for UnRead"""
        return self.UnRead

    @unread.setter
    def unread(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def un_read(self):
        """Alias for UnRead"""
        return self.UnRead

    @un_read.setter
    def un_read(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def UserProperties(self):
        return UserProperties(self.com_object.UserProperties)

    @property
    def userproperties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    @property
    def user_properties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    def Close(self, SaveMode=None):
        arguments = com_arguments([unwrap(a) for a in [SaveMode]])
        self.com_object.Close(*arguments)

    def close(self, SaveMode=None):
        """Alias for Close"""
        arguments = [SaveMode]
        return self.Close(*arguments)

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Display(self, Modal=None):
        arguments = com_arguments([unwrap(a) for a in [Modal]])
        self.com_object.Display(*arguments)

    def display(self, Modal=None):
        """Alias for Display"""
        arguments = [Modal]
        return self.Display(*arguments)

    def GetAssociatedTask(self, AddToTaskList=None):
        arguments = com_arguments([unwrap(a) for a in [AddToTaskList]])
        return TaskItem(self.com_object.GetAssociatedTask(*arguments))

    def getassociatedtask(self, AddToTaskList=None):
        """Alias for GetAssociatedTask"""
        arguments = [AddToTaskList]
        return self.GetAssociatedTask(*arguments)

    def get_associated_task(self, AddToTaskList=None):
        """Alias for GetAssociatedTask"""
        arguments = [AddToTaskList]
        return self.GetAssociatedTask(*arguments)

    def GetConversation(self):
        return Conversation(self.com_object.GetConversation())

    def getconversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def get_conversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def Move(self, DestFldr=None):
        arguments = com_arguments([unwrap(a) for a in [DestFldr]])
        return self.com_object.Move(*arguments)

    def move(self, DestFldr=None):
        """Alias for Move"""
        arguments = [DestFldr]
        return self.Move(*arguments)

    def PrintOut(self):
        self.com_object.PrintOut()

    def printout(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def print_out(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()

    def SaveAs(self, Path=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Path, Type]])
        self.com_object.SaveAs(*arguments)

    def saveas(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def save_as(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def ShowCategoriesDialog(self):
        self.com_object.ShowCategoriesDialog()

    def showcategoriesdialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()

    def show_categories_dialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()


class TaskRequestItem:

    def __init__(self, taskrequestitem=None):
        self.com_object= taskrequestitem

    @property
    def Actions(self):
        return Actions(self.com_object.Actions)

    @property
    def actions(self):
        """Alias for Actions"""
        return self.Actions

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Attachments(self):
        return Attachments(self.com_object.Attachments)

    @property
    def attachments(self):
        """Alias for Attachments"""
        return self.Attachments

    @property
    def AutoResolvedWinner(self):
        return self.com_object.AutoResolvedWinner

    @property
    def autoresolvedwinner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def auto_resolved_winner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def BillingInformation(self):
        return self.com_object.BillingInformation

    @BillingInformation.setter
    def BillingInformation(self, value):
        self.com_object.BillingInformation = value

    @property
    def billinginformation(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billinginformation.setter
    def billinginformation(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def billing_information(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billing_information.setter
    def billing_information(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def Body(self):
        return self.com_object.Body

    @Body.setter
    def Body(self, value):
        self.com_object.Body = value

    @property
    def body(self):
        """Alias for Body"""
        return self.Body

    @body.setter
    def body(self, value):
        """Alias for Body.setter"""
        self.Body = value

    @property
    def Categories(self):
        return self.com_object.Categories

    @Categories.setter
    def Categories(self, value):
        self.com_object.Categories = value

    @property
    def categories(self):
        """Alias for Categories"""
        return self.Categories

    @categories.setter
    def categories(self, value):
        """Alias for Categories.setter"""
        self.Categories = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Companies(self):
        return self.com_object.Companies

    @Companies.setter
    def Companies(self, value):
        self.com_object.Companies = value

    @property
    def companies(self):
        """Alias for Companies"""
        return self.Companies

    @companies.setter
    def companies(self, value):
        """Alias for Companies.setter"""
        self.Companies = value

    @property
    def Conflicts(self):
        return self.com_object.Conflicts

    @property
    def conflicts(self):
        """Alias for Conflicts"""
        return self.Conflicts

    @property
    def ConversationID(self):
        return Conversation(self.com_object.ConversationID)

    @property
    def conversationid(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def conversation_i_d(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def ConversationIndex(self):
        return self.com_object.ConversationIndex

    @property
    def conversationindex(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def conversation_index(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def ConversationTopic(self):
        return self.com_object.ConversationTopic

    @property
    def conversationtopic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def conversation_topic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def CreationTime(self):
        return self.com_object.CreationTime

    @property
    def creationtime(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def creation_time(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def DownloadState(self):
        return OlDownloadState(self.com_object.DownloadState)

    @property
    def downloadstate(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def download_state(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def EntryID(self):
        return self.com_object.EntryID

    @property
    def entryid(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def entry_i_d(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def FormDescription(self):
        return FormDescription(self.com_object.FormDescription)

    @property
    def formdescription(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def form_description(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def GetInspector(self):
        return Inspector(self.com_object.GetInspector)

    @property
    def getinspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def get_inspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def Importance(self):
        return OlImportance(self.com_object.Importance)

    @Importance.setter
    def Importance(self, value):
        self.com_object.Importance = value

    @property
    def importance(self):
        """Alias for Importance"""
        return self.Importance

    @importance.setter
    def importance(self, value):
        """Alias for Importance.setter"""
        self.Importance = value

    @property
    def IsConflict(self):
        return self.com_object.IsConflict

    @property
    def isconflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def is_conflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def ItemProperties(self):
        return ItemProperties(self.com_object.ItemProperties)

    @property
    def itemproperties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def item_properties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def LastModificationTime(self):
        return self.com_object.LastModificationTime

    @property
    def lastmodificationtime(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def last_modification_time(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def MarkForDownload(self):
        return OlRemoteStatus(self.com_object.MarkForDownload)

    @MarkForDownload.setter
    def MarkForDownload(self, value):
        self.com_object.MarkForDownload = value

    @property
    def markfordownload(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @markfordownload.setter
    def markfordownload(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def mark_for_download(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @mark_for_download.setter
    def mark_for_download(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def MessageClass(self):
        return self.com_object.MessageClass

    @MessageClass.setter
    def MessageClass(self, value):
        self.com_object.MessageClass = value

    @property
    def messageclass(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @messageclass.setter
    def messageclass(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def message_class(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @message_class.setter
    def message_class(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def Mileage(self):
        return self.com_object.Mileage

    @Mileage.setter
    def Mileage(self, value):
        self.com_object.Mileage = value

    @property
    def mileage(self):
        """Alias for Mileage"""
        return self.Mileage

    @mileage.setter
    def mileage(self, value):
        """Alias for Mileage.setter"""
        self.Mileage = value

    @property
    def NoAging(self):
        return self.com_object.NoAging

    @NoAging.setter
    def NoAging(self, value):
        self.com_object.NoAging = value

    @property
    def noaging(self):
        """Alias for NoAging"""
        return self.NoAging

    @noaging.setter
    def noaging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def no_aging(self):
        """Alias for NoAging"""
        return self.NoAging

    @no_aging.setter
    def no_aging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def OutlookInternalVersion(self):
        return self.com_object.OutlookInternalVersion

    @property
    def outlookinternalversion(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def outlook_internal_version(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def OutlookVersion(self):
        return self.com_object.OutlookVersion

    @property
    def outlookversion(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def outlook_version(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def RTFBody(self):
        return self.com_object.RTFBody

    @RTFBody.setter
    def RTFBody(self, value):
        self.com_object.RTFBody = value

    @property
    def rtfbody(self):
        """Alias for RTFBody"""
        return self.RTFBody

    @rtfbody.setter
    def rtfbody(self, value):
        """Alias for RTFBody.setter"""
        self.RTFBody = value

    @property
    def r_t_f_body(self):
        """Alias for RTFBody"""
        return self.RTFBody

    @r_t_f_body.setter
    def r_t_f_body(self, value):
        """Alias for RTFBody.setter"""
        self.RTFBody = value

    @property
    def Saved(self):
        return self.com_object.Saved

    @property
    def saved(self):
        """Alias for Saved"""
        return self.Saved

    @property
    def Sensitivity(self):
        return OlSensitivity(self.com_object.Sensitivity)

    @Sensitivity.setter
    def Sensitivity(self, value):
        self.com_object.Sensitivity = value

    @property
    def sensitivity(self):
        """Alias for Sensitivity"""
        return self.Sensitivity

    @sensitivity.setter
    def sensitivity(self, value):
        """Alias for Sensitivity.setter"""
        self.Sensitivity = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Size(self):
        return self.com_object.Size

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @property
    def Subject(self):
        return self.com_object.Subject

    @Subject.setter
    def Subject(self, value):
        self.com_object.Subject = value

    @property
    def subject(self):
        """Alias for Subject"""
        return self.Subject

    @subject.setter
    def subject(self, value):
        """Alias for Subject.setter"""
        self.Subject = value

    @property
    def UnRead(self):
        return self.com_object.UnRead

    @UnRead.setter
    def UnRead(self, value):
        self.com_object.UnRead = value

    @property
    def unread(self):
        """Alias for UnRead"""
        return self.UnRead

    @unread.setter
    def unread(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def un_read(self):
        """Alias for UnRead"""
        return self.UnRead

    @un_read.setter
    def un_read(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def UserProperties(self):
        return UserProperties(self.com_object.UserProperties)

    @property
    def userproperties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    @property
    def user_properties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    def Close(self, SaveMode=None):
        arguments = com_arguments([unwrap(a) for a in [SaveMode]])
        self.com_object.Close(*arguments)

    def close(self, SaveMode=None):
        """Alias for Close"""
        arguments = [SaveMode]
        return self.Close(*arguments)

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Display(self, Modal=None):
        arguments = com_arguments([unwrap(a) for a in [Modal]])
        self.com_object.Display(*arguments)

    def display(self, Modal=None):
        """Alias for Display"""
        arguments = [Modal]
        return self.Display(*arguments)

    def GetAssociatedTask(self, AddToTaskList=None):
        arguments = com_arguments([unwrap(a) for a in [AddToTaskList]])
        return TaskItem(self.com_object.GetAssociatedTask(*arguments))

    def getassociatedtask(self, AddToTaskList=None):
        """Alias for GetAssociatedTask"""
        arguments = [AddToTaskList]
        return self.GetAssociatedTask(*arguments)

    def get_associated_task(self, AddToTaskList=None):
        """Alias for GetAssociatedTask"""
        arguments = [AddToTaskList]
        return self.GetAssociatedTask(*arguments)

    def GetConversation(self):
        return Conversation(self.com_object.GetConversation())

    def getconversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def get_conversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def Move(self, DestFldr=None):
        arguments = com_arguments([unwrap(a) for a in [DestFldr]])
        return self.com_object.Move(*arguments)

    def move(self, DestFldr=None):
        """Alias for Move"""
        arguments = [DestFldr]
        return self.Move(*arguments)

    def PrintOut(self):
        self.com_object.PrintOut()

    def printout(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def print_out(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()

    def SaveAs(self, Path=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Path, Type]])
        self.com_object.SaveAs(*arguments)

    def saveas(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def save_as(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def ShowCategoriesDialog(self):
        self.com_object.ShowCategoriesDialog()

    def showcategoriesdialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()

    def show_categories_dialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()


class TaskRequestUpdateItem:

    def __init__(self, taskrequestupdateitem=None):
        self.com_object= taskrequestupdateitem

    @property
    def Actions(self):
        return Actions(self.com_object.Actions)

    @property
    def actions(self):
        """Alias for Actions"""
        return self.Actions

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Attachments(self):
        return Attachments(self.com_object.Attachments)

    @property
    def attachments(self):
        """Alias for Attachments"""
        return self.Attachments

    @property
    def AutoResolvedWinner(self):
        return self.com_object.AutoResolvedWinner

    @property
    def autoresolvedwinner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def auto_resolved_winner(self):
        """Alias for AutoResolvedWinner"""
        return self.AutoResolvedWinner

    @property
    def BillingInformation(self):
        return self.com_object.BillingInformation

    @BillingInformation.setter
    def BillingInformation(self, value):
        self.com_object.BillingInformation = value

    @property
    def billinginformation(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billinginformation.setter
    def billinginformation(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def billing_information(self):
        """Alias for BillingInformation"""
        return self.BillingInformation

    @billing_information.setter
    def billing_information(self, value):
        """Alias for BillingInformation.setter"""
        self.BillingInformation = value

    @property
    def Body(self):
        return self.com_object.Body

    @Body.setter
    def Body(self, value):
        self.com_object.Body = value

    @property
    def body(self):
        """Alias for Body"""
        return self.Body

    @body.setter
    def body(self, value):
        """Alias for Body.setter"""
        self.Body = value

    @property
    def Categories(self):
        return self.com_object.Categories

    @Categories.setter
    def Categories(self, value):
        self.com_object.Categories = value

    @property
    def categories(self):
        """Alias for Categories"""
        return self.Categories

    @categories.setter
    def categories(self, value):
        """Alias for Categories.setter"""
        self.Categories = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Companies(self):
        return self.com_object.Companies

    @Companies.setter
    def Companies(self, value):
        self.com_object.Companies = value

    @property
    def companies(self):
        """Alias for Companies"""
        return self.Companies

    @companies.setter
    def companies(self, value):
        """Alias for Companies.setter"""
        self.Companies = value

    @property
    def Conflicts(self):
        return self.com_object.Conflicts

    @property
    def conflicts(self):
        """Alias for Conflicts"""
        return self.Conflicts

    @property
    def ConversationID(self):
        return Conversation(self.com_object.ConversationID)

    @property
    def conversationid(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def conversation_i_d(self):
        """Alias for ConversationID"""
        return self.ConversationID

    @property
    def ConversationIndex(self):
        return self.com_object.ConversationIndex

    @property
    def conversationindex(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def conversation_index(self):
        """Alias for ConversationIndex"""
        return self.ConversationIndex

    @property
    def ConversationTopic(self):
        return self.com_object.ConversationTopic

    @property
    def conversationtopic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def conversation_topic(self):
        """Alias for ConversationTopic"""
        return self.ConversationTopic

    @property
    def CreationTime(self):
        return self.com_object.CreationTime

    @property
    def creationtime(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def creation_time(self):
        """Alias for CreationTime"""
        return self.CreationTime

    @property
    def DownloadState(self):
        return OlDownloadState(self.com_object.DownloadState)

    @property
    def downloadstate(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def download_state(self):
        """Alias for DownloadState"""
        return self.DownloadState

    @property
    def EntryID(self):
        return self.com_object.EntryID

    @property
    def entryid(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def entry_i_d(self):
        """Alias for EntryID"""
        return self.EntryID

    @property
    def FormDescription(self):
        return FormDescription(self.com_object.FormDescription)

    @property
    def formdescription(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def form_description(self):
        """Alias for FormDescription"""
        return self.FormDescription

    @property
    def GetInspector(self):
        return Inspector(self.com_object.GetInspector)

    @property
    def getinspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def get_inspector(self):
        """Alias for GetInspector"""
        return self.GetInspector

    @property
    def Importance(self):
        return OlImportance(self.com_object.Importance)

    @Importance.setter
    def Importance(self, value):
        self.com_object.Importance = value

    @property
    def importance(self):
        """Alias for Importance"""
        return self.Importance

    @importance.setter
    def importance(self, value):
        """Alias for Importance.setter"""
        self.Importance = value

    @property
    def IsConflict(self):
        return self.com_object.IsConflict

    @property
    def isconflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def is_conflict(self):
        """Alias for IsConflict"""
        return self.IsConflict

    @property
    def ItemProperties(self):
        return ItemProperties(self.com_object.ItemProperties)

    @property
    def itemproperties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def item_properties(self):
        """Alias for ItemProperties"""
        return self.ItemProperties

    @property
    def LastModificationTime(self):
        return self.com_object.LastModificationTime

    @property
    def lastmodificationtime(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def last_modification_time(self):
        """Alias for LastModificationTime"""
        return self.LastModificationTime

    @property
    def MarkForDownload(self):
        return OlRemoteStatus(self.com_object.MarkForDownload)

    @MarkForDownload.setter
    def MarkForDownload(self, value):
        self.com_object.MarkForDownload = value

    @property
    def markfordownload(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @markfordownload.setter
    def markfordownload(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def mark_for_download(self):
        """Alias for MarkForDownload"""
        return self.MarkForDownload

    @mark_for_download.setter
    def mark_for_download(self, value):
        """Alias for MarkForDownload.setter"""
        self.MarkForDownload = value

    @property
    def MessageClass(self):
        return self.com_object.MessageClass

    @MessageClass.setter
    def MessageClass(self, value):
        self.com_object.MessageClass = value

    @property
    def messageclass(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @messageclass.setter
    def messageclass(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def message_class(self):
        """Alias for MessageClass"""
        return self.MessageClass

    @message_class.setter
    def message_class(self, value):
        """Alias for MessageClass.setter"""
        self.MessageClass = value

    @property
    def Mileage(self):
        return self.com_object.Mileage

    @Mileage.setter
    def Mileage(self, value):
        self.com_object.Mileage = value

    @property
    def mileage(self):
        """Alias for Mileage"""
        return self.Mileage

    @mileage.setter
    def mileage(self, value):
        """Alias for Mileage.setter"""
        self.Mileage = value

    @property
    def NoAging(self):
        return self.com_object.NoAging

    @NoAging.setter
    def NoAging(self, value):
        self.com_object.NoAging = value

    @property
    def noaging(self):
        """Alias for NoAging"""
        return self.NoAging

    @noaging.setter
    def noaging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def no_aging(self):
        """Alias for NoAging"""
        return self.NoAging

    @no_aging.setter
    def no_aging(self, value):
        """Alias for NoAging.setter"""
        self.NoAging = value

    @property
    def OutlookInternalVersion(self):
        return self.com_object.OutlookInternalVersion

    @property
    def outlookinternalversion(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def outlook_internal_version(self):
        """Alias for OutlookInternalVersion"""
        return self.OutlookInternalVersion

    @property
    def OutlookVersion(self):
        return self.com_object.OutlookVersion

    @property
    def outlookversion(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def outlook_version(self):
        """Alias for OutlookVersion"""
        return self.OutlookVersion

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PropertyAccessor(self):
        return PropertyAccessor(self.com_object.PropertyAccessor)

    @property
    def propertyaccessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def property_accessor(self):
        """Alias for PropertyAccessor"""
        return self.PropertyAccessor

    @property
    def RTFBody(self):
        return self.com_object.RTFBody

    @RTFBody.setter
    def RTFBody(self, value):
        self.com_object.RTFBody = value

    @property
    def rtfbody(self):
        """Alias for RTFBody"""
        return self.RTFBody

    @rtfbody.setter
    def rtfbody(self, value):
        """Alias for RTFBody.setter"""
        self.RTFBody = value

    @property
    def r_t_f_body(self):
        """Alias for RTFBody"""
        return self.RTFBody

    @r_t_f_body.setter
    def r_t_f_body(self, value):
        """Alias for RTFBody.setter"""
        self.RTFBody = value

    @property
    def Saved(self):
        return self.com_object.Saved

    @property
    def saved(self):
        """Alias for Saved"""
        return self.Saved

    @property
    def Sensitivity(self):
        return OlSensitivity(self.com_object.Sensitivity)

    @Sensitivity.setter
    def Sensitivity(self, value):
        self.com_object.Sensitivity = value

    @property
    def sensitivity(self):
        """Alias for Sensitivity"""
        return self.Sensitivity

    @sensitivity.setter
    def sensitivity(self, value):
        """Alias for Sensitivity.setter"""
        self.Sensitivity = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Size(self):
        return self.com_object.Size

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @property
    def Subject(self):
        return self.com_object.Subject

    @Subject.setter
    def Subject(self, value):
        self.com_object.Subject = value

    @property
    def subject(self):
        """Alias for Subject"""
        return self.Subject

    @subject.setter
    def subject(self, value):
        """Alias for Subject.setter"""
        self.Subject = value

    @property
    def UnRead(self):
        return self.com_object.UnRead

    @UnRead.setter
    def UnRead(self, value):
        self.com_object.UnRead = value

    @property
    def unread(self):
        """Alias for UnRead"""
        return self.UnRead

    @unread.setter
    def unread(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def un_read(self):
        """Alias for UnRead"""
        return self.UnRead

    @un_read.setter
    def un_read(self, value):
        """Alias for UnRead.setter"""
        self.UnRead = value

    @property
    def UserProperties(self):
        return UserProperties(self.com_object.UserProperties)

    @property
    def userproperties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    @property
    def user_properties(self):
        """Alias for UserProperties"""
        return self.UserProperties

    def Close(self, SaveMode=None):
        arguments = com_arguments([unwrap(a) for a in [SaveMode]])
        self.com_object.Close(*arguments)

    def close(self, SaveMode=None):
        """Alias for Close"""
        arguments = [SaveMode]
        return self.Close(*arguments)

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Display(self, Modal=None):
        arguments = com_arguments([unwrap(a) for a in [Modal]])
        self.com_object.Display(*arguments)

    def display(self, Modal=None):
        """Alias for Display"""
        arguments = [Modal]
        return self.Display(*arguments)

    def GetAssociatedTask(self, AddToTaskList=None):
        arguments = com_arguments([unwrap(a) for a in [AddToTaskList]])
        return TaskItem(self.com_object.GetAssociatedTask(*arguments))

    def getassociatedtask(self, AddToTaskList=None):
        """Alias for GetAssociatedTask"""
        arguments = [AddToTaskList]
        return self.GetAssociatedTask(*arguments)

    def get_associated_task(self, AddToTaskList=None):
        """Alias for GetAssociatedTask"""
        arguments = [AddToTaskList]
        return self.GetAssociatedTask(*arguments)

    def GetConversation(self):
        return Conversation(self.com_object.GetConversation())

    def getconversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def get_conversation(self):
        """Alias for GetConversation"""
        return self.GetConversation()

    def Move(self, DestFldr=None):
        arguments = com_arguments([unwrap(a) for a in [DestFldr]])
        return self.com_object.Move(*arguments)

    def move(self, DestFldr=None):
        """Alias for Move"""
        arguments = [DestFldr]
        return self.Move(*arguments)

    def PrintOut(self):
        self.com_object.PrintOut()

    def printout(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def print_out(self):
        """Alias for PrintOut"""
        return self.PrintOut()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()

    def SaveAs(self, Path=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Path, Type]])
        self.com_object.SaveAs(*arguments)

    def saveas(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def save_as(self, Path=None, Type=None):
        """Alias for SaveAs"""
        arguments = [Path, Type]
        return self.SaveAs(*arguments)

    def ShowCategoriesDialog(self):
        self.com_object.ShowCategoriesDialog()

    def showcategoriesdialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()

    def show_categories_dialog(self):
        """Alias for ShowCategoriesDialog"""
        return self.ShowCategoriesDialog()


class TasksModule:

    def __init__(self, tasksmodule=None):
        self.com_object= tasksmodule

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Name(self):
        return TasksModule(self.com_object.Name)

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NavigationGroups(self):
        return NavigationGroups(self.com_object.NavigationGroups)

    @property
    def navigationgroups(self):
        """Alias for NavigationGroups"""
        return self.NavigationGroups

    @property
    def navigation_groups(self):
        """Alias for NavigationGroups"""
        return self.NavigationGroups

    @property
    def NavigationModuleType(self):
        return OlNavigationModuleType(self.com_object.NavigationModuleType)

    @property
    def navigationmoduletype(self):
        """Alias for NavigationModuleType"""
        return self.NavigationModuleType

    @property
    def navigation_module_type(self):
        """Alias for NavigationModuleType"""
        return self.NavigationModuleType

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return TasksModule(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Visible(self):
        return TasksModule(self.com_object.Visible)

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value


class TextBox:

    def __init__(self, textbox=None):
        self.com_object= textbox


class TextRuleCondition:

    def __init__(self, textrulecondition=None):
        self.com_object= textrulecondition

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def ConditionType(self):
        return OlRuleConditionType(self.com_object.ConditionType)

    @property
    def conditiontype(self):
        """Alias for ConditionType"""
        return self.ConditionType

    @property
    def condition_type(self):
        """Alias for ConditionType"""
        return self.ConditionType

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value


class TimelineView:

    def __init__(self, timelineview=None):
        self.com_object= timelineview

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def DefaultExpandCollapseSetting(self):
        return OlDefaultExpandCollapseSetting(self.com_object.DefaultExpandCollapseSetting)

    @DefaultExpandCollapseSetting.setter
    def DefaultExpandCollapseSetting(self, value):
        self.com_object.DefaultExpandCollapseSetting = value

    @property
    def defaultexpandcollapsesetting(self):
        """Alias for DefaultExpandCollapseSetting"""
        return self.DefaultExpandCollapseSetting

    @defaultexpandcollapsesetting.setter
    def defaultexpandcollapsesetting(self, value):
        """Alias for DefaultExpandCollapseSetting.setter"""
        self.DefaultExpandCollapseSetting = value

    @property
    def default_expand_collapse_setting(self):
        """Alias for DefaultExpandCollapseSetting"""
        return self.DefaultExpandCollapseSetting

    @default_expand_collapse_setting.setter
    def default_expand_collapse_setting(self, value):
        """Alias for DefaultExpandCollapseSetting.setter"""
        self.DefaultExpandCollapseSetting = value

    @property
    def EndField(self):
        return TimelineView(self.com_object.EndField)

    @EndField.setter
    def EndField(self, value):
        self.com_object.EndField = value

    @property
    def endfield(self):
        """Alias for EndField"""
        return self.EndField

    @endfield.setter
    def endfield(self, value):
        """Alias for EndField.setter"""
        self.EndField = value

    @property
    def end_field(self):
        """Alias for EndField"""
        return self.EndField

    @end_field.setter
    def end_field(self, value):
        """Alias for EndField.setter"""
        self.EndField = value

    @property
    def Filter(self):
        return self.com_object.Filter

    @Filter.setter
    def Filter(self, value):
        self.com_object.Filter = value

    @property
    def filter(self):
        """Alias for Filter"""
        return self.Filter

    @filter.setter
    def filter(self, value):
        """Alias for Filter.setter"""
        self.Filter = value

    @property
    def GroupByFields(self):
        return OrderFields(self.com_object.GroupByFields)

    @property
    def groupbyfields(self):
        """Alias for GroupByFields"""
        return self.GroupByFields

    @property
    def group_by_fields(self):
        """Alias for GroupByFields"""
        return self.GroupByFields

    @property
    def ItemFont(self):
        return ViewFont(self.com_object.ItemFont)

    @property
    def itemfont(self):
        """Alias for ItemFont"""
        return self.ItemFont

    @property
    def item_font(self):
        """Alias for ItemFont"""
        return self.ItemFont

    @property
    def Language(self):
        return self.com_object.Language

    @Language.setter
    def Language(self, value):
        self.com_object.Language = value

    @property
    def language(self):
        """Alias for Language"""
        return self.Language

    @language.setter
    def language(self, value):
        """Alias for Language.setter"""
        self.Language = value

    @property
    def LockUserChanges(self):
        return self.com_object.LockUserChanges

    @LockUserChanges.setter
    def LockUserChanges(self, value):
        self.com_object.LockUserChanges = value

    @property
    def lockuserchanges(self):
        """Alias for LockUserChanges"""
        return self.LockUserChanges

    @lockuserchanges.setter
    def lockuserchanges(self, value):
        """Alias for LockUserChanges.setter"""
        self.LockUserChanges = value

    @property
    def lock_user_changes(self):
        """Alias for LockUserChanges"""
        return self.LockUserChanges

    @lock_user_changes.setter
    def lock_user_changes(self, value):
        """Alias for LockUserChanges.setter"""
        self.LockUserChanges = value

    @property
    def LowerScaleFont(self):
        return ViewFont(self.com_object.LowerScaleFont)

    @property
    def lowerscalefont(self):
        """Alias for LowerScaleFont"""
        return self.LowerScaleFont

    @property
    def lower_scale_font(self):
        """Alias for LowerScaleFont"""
        return self.LowerScaleFont

    @property
    def MaxLabelWidth(self):
        return TimelineView(self.com_object.MaxLabelWidth)

    @MaxLabelWidth.setter
    def MaxLabelWidth(self, value):
        self.com_object.MaxLabelWidth = value

    @property
    def maxlabelwidth(self):
        """Alias for MaxLabelWidth"""
        return self.MaxLabelWidth

    @maxlabelwidth.setter
    def maxlabelwidth(self, value):
        """Alias for MaxLabelWidth.setter"""
        self.MaxLabelWidth = value

    @property
    def max_label_width(self):
        """Alias for MaxLabelWidth"""
        return self.MaxLabelWidth

    @max_label_width.setter
    def max_label_width(self, value):
        """Alias for MaxLabelWidth.setter"""
        self.MaxLabelWidth = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SaveOption(self):
        return OlViewSaveOption(self.com_object.SaveOption)

    @property
    def saveoption(self):
        """Alias for SaveOption"""
        return self.SaveOption

    @property
    def save_option(self):
        """Alias for SaveOption"""
        return self.SaveOption

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def ShowLabelWhenViewingByMonth(self):
        return TimelineView(self.com_object.ShowLabelWhenViewingByMonth)

    @ShowLabelWhenViewingByMonth.setter
    def ShowLabelWhenViewingByMonth(self, value):
        self.com_object.ShowLabelWhenViewingByMonth = value

    @property
    def showlabelwhenviewingbymonth(self):
        """Alias for ShowLabelWhenViewingByMonth"""
        return self.ShowLabelWhenViewingByMonth

    @showlabelwhenviewingbymonth.setter
    def showlabelwhenviewingbymonth(self, value):
        """Alias for ShowLabelWhenViewingByMonth.setter"""
        self.ShowLabelWhenViewingByMonth = value

    @property
    def show_label_when_viewing_by_month(self):
        """Alias for ShowLabelWhenViewingByMonth"""
        return self.ShowLabelWhenViewingByMonth

    @show_label_when_viewing_by_month.setter
    def show_label_when_viewing_by_month(self, value):
        """Alias for ShowLabelWhenViewingByMonth.setter"""
        self.ShowLabelWhenViewingByMonth = value

    @property
    def ShowWeekNumbers(self):
        return TimelineView(self.com_object.ShowWeekNumbers)

    @ShowWeekNumbers.setter
    def ShowWeekNumbers(self, value):
        self.com_object.ShowWeekNumbers = value

    @property
    def showweeknumbers(self):
        """Alias for ShowWeekNumbers"""
        return self.ShowWeekNumbers

    @showweeknumbers.setter
    def showweeknumbers(self, value):
        """Alias for ShowWeekNumbers.setter"""
        self.ShowWeekNumbers = value

    @property
    def show_week_numbers(self):
        """Alias for ShowWeekNumbers"""
        return self.ShowWeekNumbers

    @show_week_numbers.setter
    def show_week_numbers(self, value):
        """Alias for ShowWeekNumbers.setter"""
        self.ShowWeekNumbers = value

    @property
    def Standard(self):
        return TimelineView(self.com_object.Standard)

    @property
    def standard(self):
        """Alias for Standard"""
        return self.Standard

    @property
    def StartField(self):
        return TimelineView(self.com_object.StartField)

    @StartField.setter
    def StartField(self, value):
        self.com_object.StartField = value

    @property
    def startfield(self):
        """Alias for StartField"""
        return self.StartField

    @startfield.setter
    def startfield(self, value):
        """Alias for StartField.setter"""
        self.StartField = value

    @property
    def start_field(self):
        """Alias for StartField"""
        return self.StartField

    @start_field.setter
    def start_field(self, value):
        """Alias for StartField.setter"""
        self.StartField = value

    @property
    def TimelineViewMode(self):
        return OlTimelineViewMode(self.com_object.TimelineViewMode)

    @TimelineViewMode.setter
    def TimelineViewMode(self, value):
        self.com_object.TimelineViewMode = value

    @property
    def timelineviewmode(self):
        """Alias for TimelineViewMode"""
        return self.TimelineViewMode

    @timelineviewmode.setter
    def timelineviewmode(self, value):
        """Alias for TimelineViewMode.setter"""
        self.TimelineViewMode = value

    @property
    def timeline_view_mode(self):
        """Alias for TimelineViewMode"""
        return self.TimelineViewMode

    @timeline_view_mode.setter
    def timeline_view_mode(self, value):
        """Alias for TimelineViewMode.setter"""
        self.TimelineViewMode = value

    @property
    def UpperScaleFont(self):
        return ViewFont(self.com_object.UpperScaleFont)

    @property
    def upperscalefont(self):
        """Alias for UpperScaleFont"""
        return self.UpperScaleFont

    @property
    def upper_scale_font(self):
        """Alias for UpperScaleFont"""
        return self.UpperScaleFont

    @property
    def ViewType(self):
        return OlViewType(self.com_object.ViewType)

    @property
    def viewtype(self):
        """Alias for ViewType"""
        return self.ViewType

    @property
    def view_type(self):
        """Alias for ViewType"""
        return self.ViewType

    @property
    def XML(self):
        return self.com_object.XML

    @XML.setter
    def XML(self, value):
        self.com_object.XML = value

    @property
    def xml(self):
        """Alias for XML"""
        return self.XML

    @xml.setter
    def xml(self, value):
        """Alias for XML.setter"""
        self.XML = value

    @property
    def x_m_l(self):
        """Alias for XML"""
        return self.XML

    @x_m_l.setter
    def x_m_l(self, value):
        """Alias for XML.setter"""
        self.XML = value

    def Apply(self):
        self.com_object.Apply()

    def apply(self):
        """Alias for Apply"""
        return self.Apply()

    def Copy(self, Name=None, SaveOption=None):
        arguments = com_arguments([unwrap(a) for a in [Name, SaveOption]])
        return View(self.com_object.Copy(*arguments))

    def copy(self, Name=None, SaveOption=None):
        """Alias for Copy"""
        arguments = [Name, SaveOption]
        return self.Copy(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def GoToDate(self, Date=None):
        arguments = com_arguments([unwrap(a) for a in [Date]])
        self.com_object.GoToDate(*arguments)

    def gotodate(self, Date=None):
        """Alias for GoToDate"""
        arguments = [Date]
        return self.GoToDate(*arguments)

    def go_to_date(self, Date=None):
        """Alias for GoToDate"""
        arguments = [Date]
        return self.GoToDate(*arguments)

    def Reset(self):
        self.com_object.Reset()

    def reset(self):
        """Alias for Reset"""
        return self.Reset()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()


class TimeZone:

    def __init__(self, timezone=None):
        self.com_object= timezone

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Bias(self):
        return self.com_object.Bias

    @property
    def bias(self):
        """Alias for Bias"""
        return self.Bias

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def DaylightBias(self):
        return self.com_object.DaylightBias

    @property
    def daylightbias(self):
        """Alias for DaylightBias"""
        return self.DaylightBias

    @property
    def daylight_bias(self):
        """Alias for DaylightBias"""
        return self.DaylightBias

    @property
    def DaylightDate(self):
        return self.com_object.DaylightDate

    @property
    def daylightdate(self):
        """Alias for DaylightDate"""
        return self.DaylightDate

    @property
    def daylight_date(self):
        """Alias for DaylightDate"""
        return self.DaylightDate

    @property
    def DaylightDesignation(self):
        return self.com_object.DaylightDesignation

    @property
    def daylightdesignation(self):
        """Alias for DaylightDesignation"""
        return self.DaylightDesignation

    @property
    def daylight_designation(self):
        """Alias for DaylightDesignation"""
        return self.DaylightDesignation

    @property
    def ID(self):
        return self.com_object.ID

    @property
    def id(self):
        """Alias for ID"""
        return self.ID

    @property
    def i_d(self):
        """Alias for ID"""
        return self.ID

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def StandardBias(self):
        return self.com_object.StandardBias

    @property
    def standardbias(self):
        """Alias for StandardBias"""
        return self.StandardBias

    @property
    def standard_bias(self):
        """Alias for StandardBias"""
        return self.StandardBias

    @property
    def StandardDate(self):
        return self.com_object.StandardDate

    @property
    def standarddate(self):
        """Alias for StandardDate"""
        return self.StandardDate

    @property
    def standard_date(self):
        """Alias for StandardDate"""
        return self.StandardDate

    @property
    def StandardDesignation(self):
        return self.com_object.StandardDesignation

    @property
    def standarddesignation(self):
        """Alias for StandardDesignation"""
        return self.StandardDesignation

    @property
    def standard_designation(self):
        """Alias for StandardDesignation"""
        return self.StandardDesignation


class TimeZones:

    def __init__(self, timezones=None):
        self.com_object= timezones

    def __call__(self, item):
        return TimeZone(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def CurrentTimeZone(self):
        return TimeZone(self.com_object.CurrentTimeZone)

    @property
    def currenttimezone(self):
        """Alias for CurrentTimeZone"""
        return self.CurrentTimeZone

    @property
    def current_time_zone(self):
        """Alias for CurrentTimeZone"""
        return self.CurrentTimeZone

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def ConvertTime(self, SourceDateTime=None, SourceTimeZone=None, DestinationTimeZone=None):
        arguments = com_arguments([unwrap(a) for a in [SourceDateTime, SourceTimeZone, DestinationTimeZone]])
        return self.com_object.ConvertTime(*arguments)

    def converttime(self, SourceDateTime=None, SourceTimeZone=None, DestinationTimeZone=None):
        """Alias for ConvertTime"""
        arguments = [SourceDateTime, SourceTimeZone, DestinationTimeZone]
        return self.ConvertTime(*arguments)

    def convert_time(self, SourceDateTime=None, SourceTimeZone=None, DestinationTimeZone=None):
        """Alias for ConvertTime"""
        arguments = [SourceDateTime, SourceTimeZone, DestinationTimeZone]
        return self.ConvertTime(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return TimeZone(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ToggleButton:

    def __init__(self, togglebutton=None):
        self.com_object= togglebutton


class ToOrFromRuleCondition:

    def __init__(self, toorfromrulecondition=None):
        self.com_object= toorfromrulecondition

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def ConditionType(self):
        return OlRuleConditionType(self.com_object.ConditionType)

    @property
    def conditiontype(self):
        """Alias for ConditionType"""
        return self.ConditionType

    @property
    def condition_type(self):
        """Alias for ConditionType"""
        return self.ConditionType

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Recipients(self):
        return Recipients(self.com_object.Recipients)

    @property
    def recipients(self):
        """Alias for Recipients"""
        return self.Recipients

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session


class UserDefinedProperties:

    def __init__(self, userdefinedproperties=None):
        self.com_object= userdefinedproperties

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Add(self, Name=None, Type=None, DisplayFormat=None, Formula=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Type, DisplayFormat, Formula]])
        return UserDefinedProperty(self.com_object.Add(*arguments))

    def add(self, Name=None, Type=None, DisplayFormat=None, Formula=None):
        """Alias for Add"""
        arguments = [Name, Type, DisplayFormat, Formula]
        return self.Add(*arguments)

    def Find(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        return self.com_object.Find(*arguments)

    def find(self, Name=None):
        """Alias for Find"""
        arguments = [Name]
        return self.Find(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return UserDefinedProperty(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Refresh(self):
        self.com_object.Refresh()

    def refresh(self):
        """Alias for Refresh"""
        return self.Refresh()

    def Remove(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Remove(*arguments)

    def remove(self, Index=None):
        """Alias for Remove"""
        arguments = [Index]
        return self.Remove(*arguments)


class UserDefinedProperty:

    def __init__(self, userdefinedproperty=None):
        self.com_object= userdefinedproperty

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def DisplayFormat(self):
        return UserDefinedProperty(self.com_object.DisplayFormat)

    @property
    def displayformat(self):
        """Alias for DisplayFormat"""
        return self.DisplayFormat

    @property
    def display_format(self):
        """Alias for DisplayFormat"""
        return self.DisplayFormat

    @property
    def Formula(self):
        return self.com_object.Formula

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Type(self):
        return OlUserPropertyType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class UserProperties:

    def __init__(self, userproperties=None):
        self.com_object= userproperties

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Add(self, Name=None, Type=None, AddToFolderFields=None, DisplayFormat=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Type, AddToFolderFields, DisplayFormat]])
        return UserProperty(self.com_object.Add(*arguments))

    def add(self, Name=None, Type=None, AddToFolderFields=None, DisplayFormat=None):
        """Alias for Add"""
        arguments = [Name, Type, AddToFolderFields, DisplayFormat]
        return self.Add(*arguments)

    def Find(self, Name=None, Custom=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Custom]])
        return self.com_object.Find(*arguments)

    def find(self, Name=None, Custom=None):
        """Alias for Find"""
        arguments = [Name, Custom]
        return self.Find(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return UserProperty(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Remove(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Remove(*arguments)

    def remove(self, Index=None):
        """Alias for Remove"""
        arguments = [Index]
        return self.Remove(*arguments)


class UserProperty:

    def __init__(self, userproperty=None):
        self.com_object= userproperty

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Type(self):
        return OlUserPropertyType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def ValidationFormula(self):
        return self.com_object.ValidationFormula

    @ValidationFormula.setter
    def ValidationFormula(self, value):
        self.com_object.ValidationFormula = value

    @property
    def validationformula(self):
        """Alias for ValidationFormula"""
        return self.ValidationFormula

    @validationformula.setter
    def validationformula(self, value):
        """Alias for ValidationFormula.setter"""
        self.ValidationFormula = value

    @property
    def validation_formula(self):
        """Alias for ValidationFormula"""
        return self.ValidationFormula

    @validation_formula.setter
    def validation_formula(self, value):
        """Alias for ValidationFormula.setter"""
        self.ValidationFormula = value

    @property
    def ValidationText(self):
        return self.com_object.ValidationText

    @ValidationText.setter
    def ValidationText(self, value):
        self.com_object.ValidationText = value

    @property
    def validationtext(self):
        """Alias for ValidationText"""
        return self.ValidationText

    @validationtext.setter
    def validationtext(self, value):
        """Alias for ValidationText.setter"""
        self.ValidationText = value

    @property
    def validation_text(self):
        """Alias for ValidationText"""
        return self.ValidationText

    @validation_text.setter
    def validation_text(self, value):
        """Alias for ValidationText.setter"""
        self.ValidationText = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class View:

    def __init__(self, view=None):
        self.com_object= view

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Filter(self):
        return self.com_object.Filter

    @Filter.setter
    def Filter(self, value):
        self.com_object.Filter = value

    @property
    def filter(self):
        """Alias for Filter"""
        return self.Filter

    @filter.setter
    def filter(self, value):
        """Alias for Filter.setter"""
        self.Filter = value

    @property
    def Language(self):
        return self.com_object.Language

    @Language.setter
    def Language(self, value):
        self.com_object.Language = value

    @property
    def language(self):
        """Alias for Language"""
        return self.Language

    @language.setter
    def language(self, value):
        """Alias for Language.setter"""
        self.Language = value

    @property
    def LockUserChanges(self):
        return self.com_object.LockUserChanges

    @LockUserChanges.setter
    def LockUserChanges(self, value):
        self.com_object.LockUserChanges = value

    @property
    def lockuserchanges(self):
        """Alias for LockUserChanges"""
        return self.LockUserChanges

    @lockuserchanges.setter
    def lockuserchanges(self, value):
        """Alias for LockUserChanges.setter"""
        self.LockUserChanges = value

    @property
    def lock_user_changes(self):
        """Alias for LockUserChanges"""
        return self.LockUserChanges

    @lock_user_changes.setter
    def lock_user_changes(self, value):
        """Alias for LockUserChanges.setter"""
        self.LockUserChanges = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SaveOption(self):
        return OlViewSaveOption(self.com_object.SaveOption)

    @property
    def saveoption(self):
        """Alias for SaveOption"""
        return self.SaveOption

    @property
    def save_option(self):
        """Alias for SaveOption"""
        return self.SaveOption

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Standard(self):
        return self.com_object.Standard

    @property
    def standard(self):
        """Alias for Standard"""
        return self.Standard

    @property
    def ViewType(self):
        return OlViewType(self.com_object.ViewType)

    @property
    def viewtype(self):
        """Alias for ViewType"""
        return self.ViewType

    @property
    def view_type(self):
        """Alias for ViewType"""
        return self.ViewType

    @property
    def XML(self):
        return self.com_object.XML

    @XML.setter
    def XML(self, value):
        self.com_object.XML = value

    @property
    def xml(self):
        """Alias for XML"""
        return self.XML

    @xml.setter
    def xml(self, value):
        """Alias for XML.setter"""
        self.XML = value

    @property
    def x_m_l(self):
        """Alias for XML"""
        return self.XML

    @x_m_l.setter
    def x_m_l(self, value):
        """Alias for XML.setter"""
        self.XML = value

    def Apply(self):
        self.com_object.Apply()

    def apply(self):
        """Alias for Apply"""
        return self.Apply()

    def Copy(self, Name=None, SaveOption=None):
        arguments = com_arguments([unwrap(a) for a in [Name, SaveOption]])
        self.com_object.Copy(*arguments)

    def copy(self, Name=None, SaveOption=None):
        """Alias for Copy"""
        arguments = [Name, SaveOption]
        return self.Copy(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def GoToDate(self, Date=None):
        arguments = com_arguments([unwrap(a) for a in [Date]])
        self.com_object.GoToDate(*arguments)

    def gotodate(self, Date=None):
        """Alias for GoToDate"""
        arguments = [Date]
        return self.GoToDate(*arguments)

    def go_to_date(self, Date=None):
        """Alias for GoToDate"""
        arguments = [Date]
        return self.GoToDate(*arguments)

    def Reset(self):
        self.com_object.Reset()

    def reset(self):
        """Alias for Reset"""
        return self.Reset()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()


class ViewField:

    def __init__(self, viewfield=None):
        self.com_object= viewfield

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def ColumnFormat(self):
        return ColumnFormat(self.com_object.ColumnFormat)

    @property
    def columnformat(self):
        """Alias for ColumnFormat"""
        return self.ColumnFormat

    @property
    def column_format(self):
        """Alias for ColumnFormat"""
        return self.ColumnFormat

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def ViewXMLSchemaName(self):
        return ViewField(self.com_object.ViewXMLSchemaName)

    @property
    def viewxmlschemaname(self):
        """Alias for ViewXMLSchemaName"""
        return self.ViewXMLSchemaName

    @property
    def view_x_m_l_schema_name(self):
        """Alias for ViewXMLSchemaName"""
        return self.ViewXMLSchemaName


class ViewFields:

    def __init__(self, viewfields=None):
        self.com_object= viewfields

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return ViewField(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Add(self, PropertyName=None):
        arguments = com_arguments([unwrap(a) for a in [PropertyName]])
        return ViewField(self.com_object.Add(*arguments))

    def add(self, PropertyName=None):
        """Alias for Add"""
        arguments = [PropertyName]
        return self.Add(*arguments)

    def Insert(self, PropertyName=None, Index=None):
        arguments = com_arguments([unwrap(a) for a in [PropertyName, Index]])
        return ViewField(self.com_object.Insert(*arguments))

    def insert(self, PropertyName=None, Index=None):
        """Alias for Insert"""
        arguments = [PropertyName, Index]
        return self.Insert(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ViewField(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Remove(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Remove(*arguments)

    def remove(self, Index=None):
        """Alias for Remove"""
        arguments = [Index]
        return self.Remove(*arguments)


class ViewFont:

    def __init__(self, viewfont=None):
        self.com_object= viewfont

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Bold(self):
        return ViewFont(self.com_object.Bold)

    @Bold.setter
    def Bold(self, value):
        self.com_object.Bold = value

    @property
    def bold(self):
        """Alias for Bold"""
        return self.Bold

    @bold.setter
    def bold(self, value):
        """Alias for Bold.setter"""
        self.Bold = value

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Color(self):
        return OlColor(self.com_object.Color)

    @Color.setter
    def Color(self, value):
        self.com_object.Color = value

    @property
    def color(self):
        """Alias for Color"""
        return self.Color

    @color.setter
    def color(self, value):
        """Alias for Color.setter"""
        self.Color = value

    @property
    def ExtendedColor(self):
        return OlCategoryColor(self.com_object.ExtendedColor)

    @ExtendedColor.setter
    def ExtendedColor(self, value):
        self.com_object.ExtendedColor = value

    @property
    def extendedcolor(self):
        """Alias for ExtendedColor"""
        return self.ExtendedColor

    @extendedcolor.setter
    def extendedcolor(self, value):
        """Alias for ExtendedColor.setter"""
        self.ExtendedColor = value

    @property
    def extended_color(self):
        """Alias for ExtendedColor"""
        return self.ExtendedColor

    @extended_color.setter
    def extended_color(self, value):
        """Alias for ExtendedColor.setter"""
        self.ExtendedColor = value

    @property
    def Italic(self):
        return ViewFont(self.com_object.Italic)

    @Italic.setter
    def Italic(self, value):
        self.com_object.Italic = value

    @property
    def italic(self):
        """Alias for Italic"""
        return self.Italic

    @italic.setter
    def italic(self, value):
        """Alias for Italic.setter"""
        self.Italic = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    @property
    def Size(self):
        return self.com_object.Size

    @Size.setter
    def Size(self, value):
        self.com_object.Size = value

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @size.setter
    def size(self, value):
        """Alias for Size.setter"""
        self.Size = value

    @property
    def Strikethrough(self):
        return ViewFont(self.com_object.Strikethrough)

    @Strikethrough.setter
    def Strikethrough(self, value):
        self.com_object.Strikethrough = value

    @property
    def strikethrough(self):
        """Alias for Strikethrough"""
        return self.Strikethrough

    @strikethrough.setter
    def strikethrough(self, value):
        """Alias for Strikethrough.setter"""
        self.Strikethrough = value

    @property
    def Underline(self):
        return ViewFont(self.com_object.Underline)

    @Underline.setter
    def Underline(self, value):
        self.com_object.Underline = value

    @property
    def underline(self):
        """Alias for Underline"""
        return self.Underline

    @underline.setter
    def underline(self, value):
        """Alias for Underline.setter"""
        self.Underline = value


class Views:

    def __init__(self, views=None):
        self.com_object= views

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Class(self):
        return OlObjectClass(self.com_object.Class)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Session(self):
        return NameSpace(self.com_object.Session)

    @property
    def session(self):
        """Alias for Session"""
        return self.Session

    def Add(self, Name=None, ViewType=None, SaveOption=None):
        arguments = com_arguments([unwrap(a) for a in [Name, ViewType, SaveOption]])
        return View(self.com_object.Add(*arguments))

    def add(self, Name=None, ViewType=None, SaveOption=None):
        """Alias for Add"""
        arguments = [Name, ViewType, SaveOption]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return View(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Remove(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Remove(*arguments)

    def remove(self, Index=None):
        """Alias for Remove"""
        arguments = [Index]
        return self.Remove(*arguments)

