from . import com_arguments, unwrap
from .office import *

import win32com.client

class ActionSetting:

    def __init__(self, actionsetting=None):
        self.com_object= actionsetting

    @property
    def Action(self):
        return self.com_object.Action

    @Action.setter
    def Action(self, value):
        self.com_object.Action = value

    @property
    def action(self):
        """Alias for Action"""
        return self.Action

    @action.setter
    def action(self, value):
        """Alias for Action.setter"""
        self.Action = value

    @property
    def ActionVerb(self):
        return self.com_object.ActionVerb

    @ActionVerb.setter
    def ActionVerb(self, value):
        self.com_object.ActionVerb = value

    @property
    def actionverb(self):
        """Alias for ActionVerb"""
        return self.ActionVerb

    @actionverb.setter
    def actionverb(self, value):
        """Alias for ActionVerb.setter"""
        self.ActionVerb = value

    @property
    def action_verb(self):
        """Alias for ActionVerb"""
        return self.ActionVerb

    @action_verb.setter
    def action_verb(self, value):
        """Alias for ActionVerb.setter"""
        self.ActionVerb = value

    @property
    def AnimateAction(self):
        return self.com_object.AnimateAction

    @AnimateAction.setter
    def AnimateAction(self, value):
        self.com_object.AnimateAction = value

    @property
    def animateaction(self):
        """Alias for AnimateAction"""
        return self.AnimateAction

    @animateaction.setter
    def animateaction(self, value):
        """Alias for AnimateAction.setter"""
        self.AnimateAction = value

    @property
    def animate_action(self):
        """Alias for AnimateAction"""
        return self.AnimateAction

    @animate_action.setter
    def animate_action(self, value):
        """Alias for AnimateAction.setter"""
        self.AnimateAction = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Hyperlink(self):
        return Hyperlink(self.com_object.Hyperlink)

    @property
    def hyperlink(self):
        """Alias for Hyperlink"""
        return self.Hyperlink

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Run(self):
        return self.com_object.Run

    @Run.setter
    def Run(self, value):
        self.com_object.Run = value

    @property
    def run(self):
        """Alias for Run"""
        return self.Run

    @run.setter
    def run(self, value):
        """Alias for Run.setter"""
        self.Run = value

    @property
    def ShowAndReturn(self):
        return self.com_object.ShowAndReturn

    @ShowAndReturn.setter
    def ShowAndReturn(self, value):
        self.com_object.ShowAndReturn = value

    @property
    def showandreturn(self):
        """Alias for ShowAndReturn"""
        return self.ShowAndReturn

    @showandreturn.setter
    def showandreturn(self, value):
        """Alias for ShowAndReturn.setter"""
        self.ShowAndReturn = value

    @property
    def show_and_return(self):
        """Alias for ShowAndReturn"""
        return self.ShowAndReturn

    @show_and_return.setter
    def show_and_return(self, value):
        """Alias for ShowAndReturn.setter"""
        self.ShowAndReturn = value

    @property
    def SlideShowName(self):
        return self.com_object.SlideShowName

    @SlideShowName.setter
    def SlideShowName(self, value):
        self.com_object.SlideShowName = value

    @property
    def slideshowname(self):
        """Alias for SlideShowName"""
        return self.SlideShowName

    @slideshowname.setter
    def slideshowname(self, value):
        """Alias for SlideShowName.setter"""
        self.SlideShowName = value

    @property
    def slide_show_name(self):
        """Alias for SlideShowName"""
        return self.SlideShowName

    @slide_show_name.setter
    def slide_show_name(self, value):
        """Alias for SlideShowName.setter"""
        self.SlideShowName = value

    @property
    def SoundEffect(self):
        return SoundEffect(self.com_object.SoundEffect)

    @property
    def soundeffect(self):
        """Alias for SoundEffect"""
        return self.SoundEffect

    @property
    def sound_effect(self):
        """Alias for SoundEffect"""
        return self.SoundEffect


class ActionSettings:

    def __init__(self, actionsettings=None):
        self.com_object= actionsettings

    def __call__(self, item):
        return ActionSetting(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ActionSetting(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class AddIn:

    def __init__(self, addin=None):
        self.com_object= addin

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoLoad(self):
        return self.com_object.AutoLoad

    @AutoLoad.setter
    def AutoLoad(self, value):
        self.com_object.AutoLoad = value

    @property
    def autoload(self):
        """Alias for AutoLoad"""
        return self.AutoLoad

    @autoload.setter
    def autoload(self, value):
        """Alias for AutoLoad.setter"""
        self.AutoLoad = value

    @property
    def auto_load(self):
        """Alias for AutoLoad"""
        return self.AutoLoad

    @auto_load.setter
    def auto_load(self, value):
        """Alias for AutoLoad.setter"""
        self.AutoLoad = value

    @property
    def FullName(self):
        return self.com_object.FullName

    @property
    def fullname(self):
        """Alias for FullName"""
        return self.FullName

    @property
    def full_name(self):
        """Alias for FullName"""
        return self.FullName

    @property
    def Loaded(self):
        return self.com_object.Loaded

    @Loaded.setter
    def Loaded(self, value):
        self.com_object.Loaded = value

    @property
    def loaded(self):
        """Alias for Loaded"""
        return self.Loaded

    @loaded.setter
    def loaded(self, value):
        """Alias for Loaded.setter"""
        self.Loaded = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Path(self):
        return AddIn(self.com_object.Path)

    @property
    def path(self):
        """Alias for Path"""
        return self.Path

    @property
    def Registered(self):
        return self.com_object.Registered

    @Registered.setter
    def Registered(self, value):
        self.com_object.Registered = value

    @property
    def registered(self):
        """Alias for Registered"""
        return self.Registered

    @registered.setter
    def registered(self, value):
        """Alias for Registered.setter"""
        self.Registered = value


class AddIns:

    def __init__(self, addins=None):
        self.com_object= addins

    def __call__(self, item):
        return AddIn(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        return AddIn(self.com_object.Add(*arguments))

    def add(self, FileName=None):
        """Alias for Add"""
        arguments = [FileName]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return AddIn(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Remove(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Remove(*arguments)

    def remove(self, Index=None):
        """Alias for Remove"""
        arguments = [Index]
        return self.Remove(*arguments)


class Adjustments:

    def __init__(self, adjustments=None):
        self.com_object= adjustments

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Item(self):
        return self.com_object.Item

    @Item.setter
    def Item(self, value):
        self.com_object.Item = value

    @property
    def item(self):
        """Alias for Item"""
        return self.Item

    @item.setter
    def item(self, value):
        """Alias for Item.setter"""
        self.Item = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class AnimationBehavior:

    def __init__(self, animationbehavior=None):
        self.com_object= animationbehavior

    @property
    def Accumulate(self):
        return self.com_object.Accumulate

    @Accumulate.setter
    def Accumulate(self, value):
        self.com_object.Accumulate = value

    @property
    def accumulate(self):
        """Alias for Accumulate"""
        return self.Accumulate

    @accumulate.setter
    def accumulate(self, value):
        """Alias for Accumulate.setter"""
        self.Accumulate = value

    @property
    def Additive(self):
        return self.com_object.Additive

    @Additive.setter
    def Additive(self, value):
        self.com_object.Additive = value

    @property
    def additive(self):
        """Alias for Additive"""
        return self.Additive

    @additive.setter
    def additive(self, value):
        """Alias for Additive.setter"""
        self.Additive = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ColorEffect(self):
        return ColorEffect(self.com_object.ColorEffect)

    @property
    def coloreffect(self):
        """Alias for ColorEffect"""
        return self.ColorEffect

    @property
    def color_effect(self):
        """Alias for ColorEffect"""
        return self.ColorEffect

    @property
    def CommandEffect(self):
        return CommandEffect(self.com_object.CommandEffect)

    @property
    def commandeffect(self):
        """Alias for CommandEffect"""
        return self.CommandEffect

    @property
    def command_effect(self):
        """Alias for CommandEffect"""
        return self.CommandEffect

    @property
    def FilterEffect(self):
        return FilterEffect(self.com_object.FilterEffect)

    @property
    def filtereffect(self):
        """Alias for FilterEffect"""
        return self.FilterEffect

    @property
    def filter_effect(self):
        """Alias for FilterEffect"""
        return self.FilterEffect

    @property
    def MotionEffect(self):
        return MotionEffect(self.com_object.MotionEffect)

    @property
    def motioneffect(self):
        """Alias for MotionEffect"""
        return self.MotionEffect

    @property
    def motion_effect(self):
        """Alias for MotionEffect"""
        return self.MotionEffect

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PropertyEffect(self):
        return PropertyEffect(self.com_object.PropertyEffect)

    @property
    def propertyeffect(self):
        """Alias for PropertyEffect"""
        return self.PropertyEffect

    @property
    def property_effect(self):
        """Alias for PropertyEffect"""
        return self.PropertyEffect

    @property
    def RotationEffect(self):
        return RotationEffect(self.com_object.RotationEffect)

    @property
    def rotationeffect(self):
        """Alias for RotationEffect"""
        return self.RotationEffect

    @property
    def rotation_effect(self):
        """Alias for RotationEffect"""
        return self.RotationEffect

    @property
    def ScaleEffect(self):
        return ScaleEffect(self.com_object.ScaleEffect)

    @property
    def scaleeffect(self):
        """Alias for ScaleEffect"""
        return self.ScaleEffect

    @property
    def scale_effect(self):
        """Alias for ScaleEffect"""
        return self.ScaleEffect

    @property
    def SetEffect(self):
        return SetEffect(self.com_object.SetEffect)

    @property
    def seteffect(self):
        """Alias for SetEffect"""
        return self.SetEffect

    @property
    def set_effect(self):
        """Alias for SetEffect"""
        return self.SetEffect

    @property
    def Timing(self):
        return Timing(self.com_object.Timing)

    @property
    def timing(self):
        """Alias for Timing"""
        return self.Timing

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class AnimationBehaviors:

    def __init__(self, animationbehaviors=None):
        self.com_object= animationbehaviors

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Type=None, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Index]])
        return AnimationBehavior(self.com_object.Add(*arguments))

    def add(self, Type=None, Index=None):
        """Alias for Add"""
        arguments = [Type, Index]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return AnimationBehavior(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class AnimationPoint:

    def __init__(self, animationpoint=None):
        self.com_object= animationpoint

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Time(self):
        return self.com_object.Time

    @Time.setter
    def Time(self, value):
        self.com_object.Time = value

    @property
    def time(self):
        """Alias for Time"""
        return self.Time

    @time.setter
    def time(self, value):
        """Alias for Time.setter"""
        self.Time = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class AnimationPoints:

    def __init__(self, animationpoints=None):
        self.com_object= animationpoints

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Smooth(self):
        return self.com_object.Smooth

    @Smooth.setter
    def Smooth(self, value):
        self.com_object.Smooth = value

    @property
    def smooth(self):
        """Alias for Smooth"""
        return self.Smooth

    @smooth.setter
    def smooth(self, value):
        """Alias for Smooth.setter"""
        self.Smooth = value

    def Add(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return AnimationPoint(self.com_object.Add(*arguments))

    def add(self, Index=None):
        """Alias for Add"""
        arguments = [Index]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return AnimationPoint(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class AnimationSettings:

    def __init__(self, animationsettings=None):
        self.com_object= animationsettings

    @property
    def AdvanceMode(self):
        return self.com_object.AdvanceMode

    @AdvanceMode.setter
    def AdvanceMode(self, value):
        self.com_object.AdvanceMode = value

    @property
    def advancemode(self):
        """Alias for AdvanceMode"""
        return self.AdvanceMode

    @advancemode.setter
    def advancemode(self, value):
        """Alias for AdvanceMode.setter"""
        self.AdvanceMode = value

    @property
    def advance_mode(self):
        """Alias for AdvanceMode"""
        return self.AdvanceMode

    @advance_mode.setter
    def advance_mode(self, value):
        """Alias for AdvanceMode.setter"""
        self.AdvanceMode = value

    @property
    def AdvanceTime(self):
        return self.com_object.AdvanceTime

    @AdvanceTime.setter
    def AdvanceTime(self, value):
        self.com_object.AdvanceTime = value

    @property
    def advancetime(self):
        """Alias for AdvanceTime"""
        return self.AdvanceTime

    @advancetime.setter
    def advancetime(self, value):
        """Alias for AdvanceTime.setter"""
        self.AdvanceTime = value

    @property
    def advance_time(self):
        """Alias for AdvanceTime"""
        return self.AdvanceTime

    @advance_time.setter
    def advance_time(self, value):
        """Alias for AdvanceTime.setter"""
        self.AdvanceTime = value

    @property
    def AfterEffect(self):
        return PpAfterEffect(self.com_object.AfterEffect)

    @AfterEffect.setter
    def AfterEffect(self, value):
        self.com_object.AfterEffect = value

    @property
    def aftereffect(self):
        """Alias for AfterEffect"""
        return self.AfterEffect

    @aftereffect.setter
    def aftereffect(self, value):
        """Alias for AfterEffect.setter"""
        self.AfterEffect = value

    @property
    def after_effect(self):
        """Alias for AfterEffect"""
        return self.AfterEffect

    @after_effect.setter
    def after_effect(self, value):
        """Alias for AfterEffect.setter"""
        self.AfterEffect = value

    @property
    def Animate(self):
        return self.com_object.Animate

    @Animate.setter
    def Animate(self, value):
        self.com_object.Animate = value

    @property
    def animate(self):
        """Alias for Animate"""
        return self.Animate

    @animate.setter
    def animate(self, value):
        """Alias for Animate.setter"""
        self.Animate = value

    @property
    def AnimateBackground(self):
        return self.com_object.AnimateBackground

    @AnimateBackground.setter
    def AnimateBackground(self, value):
        self.com_object.AnimateBackground = value

    @property
    def animatebackground(self):
        """Alias for AnimateBackground"""
        return self.AnimateBackground

    @animatebackground.setter
    def animatebackground(self, value):
        """Alias for AnimateBackground.setter"""
        self.AnimateBackground = value

    @property
    def animate_background(self):
        """Alias for AnimateBackground"""
        return self.AnimateBackground

    @animate_background.setter
    def animate_background(self, value):
        """Alias for AnimateBackground.setter"""
        self.AnimateBackground = value

    @property
    def AnimateTextInReverse(self):
        return self.com_object.AnimateTextInReverse

    @AnimateTextInReverse.setter
    def AnimateTextInReverse(self, value):
        self.com_object.AnimateTextInReverse = value

    @property
    def animatetextinreverse(self):
        """Alias for AnimateTextInReverse"""
        return self.AnimateTextInReverse

    @animatetextinreverse.setter
    def animatetextinreverse(self, value):
        """Alias for AnimateTextInReverse.setter"""
        self.AnimateTextInReverse = value

    @property
    def animate_text_in_reverse(self):
        """Alias for AnimateTextInReverse"""
        return self.AnimateTextInReverse

    @animate_text_in_reverse.setter
    def animate_text_in_reverse(self, value):
        """Alias for AnimateTextInReverse.setter"""
        self.AnimateTextInReverse = value

    @property
    def AnimationOrder(self):
        return self.com_object.AnimationOrder

    @AnimationOrder.setter
    def AnimationOrder(self, value):
        self.com_object.AnimationOrder = value

    @property
    def animationorder(self):
        """Alias for AnimationOrder"""
        return self.AnimationOrder

    @animationorder.setter
    def animationorder(self, value):
        """Alias for AnimationOrder.setter"""
        self.AnimationOrder = value

    @property
    def animation_order(self):
        """Alias for AnimationOrder"""
        return self.AnimationOrder

    @animation_order.setter
    def animation_order(self, value):
        """Alias for AnimationOrder.setter"""
        self.AnimationOrder = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ChartUnitEffect(self):
        return self.com_object.ChartUnitEffect

    @ChartUnitEffect.setter
    def ChartUnitEffect(self, value):
        self.com_object.ChartUnitEffect = value

    @property
    def chartuniteffect(self):
        """Alias for ChartUnitEffect"""
        return self.ChartUnitEffect

    @chartuniteffect.setter
    def chartuniteffect(self, value):
        """Alias for ChartUnitEffect.setter"""
        self.ChartUnitEffect = value

    @property
    def chart_unit_effect(self):
        """Alias for ChartUnitEffect"""
        return self.ChartUnitEffect

    @chart_unit_effect.setter
    def chart_unit_effect(self, value):
        """Alias for ChartUnitEffect.setter"""
        self.ChartUnitEffect = value

    @property
    def DimColor(self):
        return ColorFormat(self.com_object.DimColor)

    @DimColor.setter
    def DimColor(self, value):
        self.com_object.DimColor = value

    @property
    def dimcolor(self):
        """Alias for DimColor"""
        return self.DimColor

    @dimcolor.setter
    def dimcolor(self, value):
        """Alias for DimColor.setter"""
        self.DimColor = value

    @property
    def dim_color(self):
        """Alias for DimColor"""
        return self.DimColor

    @dim_color.setter
    def dim_color(self, value):
        """Alias for DimColor.setter"""
        self.DimColor = value

    @property
    def EntryEffect(self):
        return self.com_object.EntryEffect

    @EntryEffect.setter
    def EntryEffect(self, value):
        self.com_object.EntryEffect = value

    @property
    def entryeffect(self):
        """Alias for EntryEffect"""
        return self.EntryEffect

    @entryeffect.setter
    def entryeffect(self, value):
        """Alias for EntryEffect.setter"""
        self.EntryEffect = value

    @property
    def entry_effect(self):
        """Alias for EntryEffect"""
        return self.EntryEffect

    @entry_effect.setter
    def entry_effect(self, value):
        """Alias for EntryEffect.setter"""
        self.EntryEffect = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PlaySettings(self):
        return PlaySettings(self.com_object.PlaySettings)

    @property
    def playsettings(self):
        """Alias for PlaySettings"""
        return self.PlaySettings

    @property
    def play_settings(self):
        """Alias for PlaySettings"""
        return self.PlaySettings

    @property
    def SoundEffect(self):
        return SoundEffect(self.com_object.SoundEffect)

    @property
    def soundeffect(self):
        """Alias for SoundEffect"""
        return self.SoundEffect

    @property
    def sound_effect(self):
        """Alias for SoundEffect"""
        return self.SoundEffect

    @property
    def TextLevelEffect(self):
        return self.com_object.TextLevelEffect

    @TextLevelEffect.setter
    def TextLevelEffect(self, value):
        self.com_object.TextLevelEffect = value

    @property
    def textleveleffect(self):
        """Alias for TextLevelEffect"""
        return self.TextLevelEffect

    @textleveleffect.setter
    def textleveleffect(self, value):
        """Alias for TextLevelEffect.setter"""
        self.TextLevelEffect = value

    @property
    def text_level_effect(self):
        """Alias for TextLevelEffect"""
        return self.TextLevelEffect

    @text_level_effect.setter
    def text_level_effect(self, value):
        """Alias for TextLevelEffect.setter"""
        self.TextLevelEffect = value

    @property
    def TextUnitEffect(self):
        return self.com_object.TextUnitEffect

    @TextUnitEffect.setter
    def TextUnitEffect(self, value):
        self.com_object.TextUnitEffect = value

    @property
    def textuniteffect(self):
        """Alias for TextUnitEffect"""
        return self.TextUnitEffect

    @textuniteffect.setter
    def textuniteffect(self, value):
        """Alias for TextUnitEffect.setter"""
        self.TextUnitEffect = value

    @property
    def text_unit_effect(self):
        """Alias for TextUnitEffect"""
        return self.TextUnitEffect

    @text_unit_effect.setter
    def text_unit_effect(self, value):
        """Alias for TextUnitEffect.setter"""
        self.TextUnitEffect = value


class Application:

    def __init__(self, application=None):
        if application is None:
            self.com_object = win32com.client.gencache.EnsureDispatch("PowerPoint.Application")
        else:
            self.com_object = application

    @property
    def Active(self):
        return self.com_object.Active

    @property
    def active(self):
        """Alias for Active"""
        return self.Active

    @property
    def ActiveEncryptionSession(self):
        return self.com_object.ActiveEncryptionSession

    @property
    def activeencryptionsession(self):
        """Alias for ActiveEncryptionSession"""
        return self.ActiveEncryptionSession

    @property
    def active_encryption_session(self):
        """Alias for ActiveEncryptionSession"""
        return self.ActiveEncryptionSession

    @property
    def ActivePresentation(self):
        return Presentation(self.com_object.ActivePresentation)

    @property
    def activepresentation(self):
        """Alias for ActivePresentation"""
        return self.ActivePresentation

    @property
    def active_presentation(self):
        """Alias for ActivePresentation"""
        return self.ActivePresentation

    @property
    def ActivePrinter(self):
        return self.com_object.ActivePrinter

    @property
    def activeprinter(self):
        """Alias for ActivePrinter"""
        return self.ActivePrinter

    @property
    def active_printer(self):
        """Alias for ActivePrinter"""
        return self.ActivePrinter

    @property
    def ActiveProtectedViewWindow(self):
        return ProtectedViewWindow(self.com_object.ActiveProtectedViewWindow)

    @property
    def activeprotectedviewwindow(self):
        """Alias for ActiveProtectedViewWindow"""
        return self.ActiveProtectedViewWindow

    @property
    def active_protected_view_window(self):
        """Alias for ActiveProtectedViewWindow"""
        return self.ActiveProtectedViewWindow

    @property
    def ActiveWindow(self):
        return DocumentWindow(self.com_object.ActiveWindow)

    @property
    def activewindow(self):
        """Alias for ActiveWindow"""
        return self.ActiveWindow

    @property
    def active_window(self):
        """Alias for ActiveWindow"""
        return self.ActiveWindow

    @property
    def AddIns(self):
        return AddIns(self.com_object.AddIns)

    @property
    def addins(self):
        """Alias for AddIns"""
        return self.AddIns

    @property
    def add_ins(self):
        """Alias for AddIns"""
        return self.AddIns

    @property
    def Assistance(self):
        return self.com_object.Assistance

    @property
    def assistance(self):
        """Alias for Assistance"""
        return self.Assistance

    @property
    def AutoCorrect(self):
        return AutoCorrect(self.com_object.AutoCorrect)

    @property
    def autocorrect(self):
        """Alias for AutoCorrect"""
        return self.AutoCorrect

    @property
    def auto_correct(self):
        """Alias for AutoCorrect"""
        return self.AutoCorrect

    @property
    def AutomationSecurity(self):
        return self.com_object.AutomationSecurity

    @AutomationSecurity.setter
    def AutomationSecurity(self, value):
        self.com_object.AutomationSecurity = value

    @property
    def automationsecurity(self):
        """Alias for AutomationSecurity"""
        return self.AutomationSecurity

    @automationsecurity.setter
    def automationsecurity(self, value):
        """Alias for AutomationSecurity.setter"""
        self.AutomationSecurity = value

    @property
    def automation_security(self):
        """Alias for AutomationSecurity"""
        return self.AutomationSecurity

    @automation_security.setter
    def automation_security(self, value):
        """Alias for AutomationSecurity.setter"""
        self.AutomationSecurity = value

    @property
    def Build(self):
        return self.com_object.Build

    @property
    def build(self):
        """Alias for Build"""
        return self.Build

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    @property
    def ChartDataPointTrack(self):
        return self.com_object.ChartDataPointTrack

    @ChartDataPointTrack.setter
    def ChartDataPointTrack(self, value):
        self.com_object.ChartDataPointTrack = value

    @property
    def chartdatapointtrack(self):
        """Alias for ChartDataPointTrack"""
        return self.ChartDataPointTrack

    @chartdatapointtrack.setter
    def chartdatapointtrack(self, value):
        """Alias for ChartDataPointTrack.setter"""
        self.ChartDataPointTrack = value

    @property
    def chart_data_point_track(self):
        """Alias for ChartDataPointTrack"""
        return self.ChartDataPointTrack

    @chart_data_point_track.setter
    def chart_data_point_track(self, value):
        """Alias for ChartDataPointTrack.setter"""
        self.ChartDataPointTrack = value

    @property
    def COMAddIns(self):
        return self.com_object.COMAddIns

    @property
    def comaddins(self):
        """Alias for COMAddIns"""
        return self.COMAddIns

    @property
    def c_o_m_add_ins(self):
        """Alias for COMAddIns"""
        return self.COMAddIns

    @property
    def CommandBars(self):
        return self.com_object.CommandBars

    @property
    def commandbars(self):
        """Alias for CommandBars"""
        return self.CommandBars

    @property
    def command_bars(self):
        """Alias for CommandBars"""
        return self.CommandBars

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DisplayAlerts(self):
        return self.com_object.DisplayAlerts

    @DisplayAlerts.setter
    def DisplayAlerts(self, value):
        self.com_object.DisplayAlerts = value

    @property
    def displayalerts(self):
        """Alias for DisplayAlerts"""
        return self.DisplayAlerts

    @displayalerts.setter
    def displayalerts(self, value):
        """Alias for DisplayAlerts.setter"""
        self.DisplayAlerts = value

    @property
    def display_alerts(self):
        """Alias for DisplayAlerts"""
        return self.DisplayAlerts

    @display_alerts.setter
    def display_alerts(self, value):
        """Alias for DisplayAlerts.setter"""
        self.DisplayAlerts = value

    @property
    def DisplayDocumentInformationPanel(self):
        return self.com_object.DisplayDocumentInformationPanel

    @DisplayDocumentInformationPanel.setter
    def DisplayDocumentInformationPanel(self, value):
        self.com_object.DisplayDocumentInformationPanel = value

    @property
    def displaydocumentinformationpanel(self):
        """Alias for DisplayDocumentInformationPanel"""
        return self.DisplayDocumentInformationPanel

    @displaydocumentinformationpanel.setter
    def displaydocumentinformationpanel(self, value):
        """Alias for DisplayDocumentInformationPanel.setter"""
        self.DisplayDocumentInformationPanel = value

    @property
    def display_document_information_panel(self):
        """Alias for DisplayDocumentInformationPanel"""
        return self.DisplayDocumentInformationPanel

    @display_document_information_panel.setter
    def display_document_information_panel(self, value):
        """Alias for DisplayDocumentInformationPanel.setter"""
        self.DisplayDocumentInformationPanel = value

    @property
    def DisplayGridLines(self):
        return self.com_object.DisplayGridLines

    @DisplayGridLines.setter
    def DisplayGridLines(self, value):
        self.com_object.DisplayGridLines = value

    @property
    def displaygridlines(self):
        """Alias for DisplayGridLines"""
        return self.DisplayGridLines

    @displaygridlines.setter
    def displaygridlines(self, value):
        """Alias for DisplayGridLines.setter"""
        self.DisplayGridLines = value

    @property
    def display_grid_lines(self):
        """Alias for DisplayGridLines"""
        return self.DisplayGridLines

    @display_grid_lines.setter
    def display_grid_lines(self, value):
        """Alias for DisplayGridLines.setter"""
        self.DisplayGridLines = value

    @property
    def DisplayGuides(self):
        return self.com_object.DisplayGuides

    @property
    def displayguides(self):
        """Alias for DisplayGuides"""
        return self.DisplayGuides

    @property
    def display_guides(self):
        """Alias for DisplayGuides"""
        return self.DisplayGuides

    @property
    def FeatureInstall(self):
        return self.com_object.FeatureInstall

    @FeatureInstall.setter
    def FeatureInstall(self, value):
        self.com_object.FeatureInstall = value

    @property
    def featureinstall(self):
        """Alias for FeatureInstall"""
        return self.FeatureInstall

    @featureinstall.setter
    def featureinstall(self, value):
        """Alias for FeatureInstall.setter"""
        self.FeatureInstall = value

    @property
    def feature_install(self):
        """Alias for FeatureInstall"""
        return self.FeatureInstall

    @feature_install.setter
    def feature_install(self, value):
        """Alias for FeatureInstall.setter"""
        self.FeatureInstall = value

    def FileConverters(self, Index1=None, Index2=None):
        arguments = com_arguments([unwrap(a) for a in [Index1, Index2]])
        if hasattr(self.com_object, "GetFileConverters"):
            return self.com_object.GetFileConverters(*arguments)
        else:
            return self.com_object.FileConverters(*arguments)

    def fileconverters(self, Index1=None, Index2=None):
        """Alias for FileConverters"""
        arguments = [Index1, Index2]
        return self.FileConverters(*arguments)

    def file_converters(self, Index1=None, Index2=None):
        """Alias for FileConverters"""
        arguments = [Index1, Index2]
        return self.FileConverters(*arguments)

    def FileDialog(self, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Type]])
        if hasattr(self.com_object, "GetFileDialog"):
            return self.com_object.GetFileDialog(*arguments)
        else:
            return self.com_object.FileDialog(*arguments)

    def filedialog(self, Type=None):
        """Alias for FileDialog"""
        arguments = [Type]
        return self.FileDialog(*arguments)

    def file_dialog(self, Type=None):
        """Alias for FileDialog"""
        arguments = [Type]
        return self.FileDialog(*arguments)

    @property
    def FileValidation(self):
        return self.com_object.FileValidation

    @FileValidation.setter
    def FileValidation(self, value):
        self.com_object.FileValidation = value

    @property
    def filevalidation(self):
        """Alias for FileValidation"""
        return self.FileValidation

    @filevalidation.setter
    def filevalidation(self, value):
        """Alias for FileValidation.setter"""
        self.FileValidation = value

    @property
    def file_validation(self):
        """Alias for FileValidation"""
        return self.FileValidation

    @file_validation.setter
    def file_validation(self, value):
        """Alias for FileValidation.setter"""
        self.FileValidation = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def IsSandboxed(self):
        return self.com_object.IsSandboxed

    @property
    def issandboxed(self):
        """Alias for IsSandboxed"""
        return self.IsSandboxed

    @property
    def is_sandboxed(self):
        """Alias for IsSandboxed"""
        return self.IsSandboxed

    @property
    def LanguageSettings(self):
        return self.com_object.LanguageSettings

    @property
    def languagesettings(self):
        """Alias for LanguageSettings"""
        return self.LanguageSettings

    @property
    def language_settings(self):
        """Alias for LanguageSettings"""
        return self.LanguageSettings

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NewPresentation(self):
        return self.com_object.NewPresentation

    @property
    def newpresentation(self):
        """Alias for NewPresentation"""
        return self.NewPresentation

    @property
    def new_presentation(self):
        """Alias for NewPresentation"""
        return self.NewPresentation

    @property
    def OperatingSystem(self):
        return self.com_object.OperatingSystem

    @property
    def operatingsystem(self):
        """Alias for OperatingSystem"""
        return self.OperatingSystem

    @property
    def operating_system(self):
        """Alias for OperatingSystem"""
        return self.OperatingSystem

    @property
    def Options(self):
        return Options(self.com_object.Options)

    @property
    def options(self):
        """Alias for Options"""
        return self.Options

    @property
    def Path(self):
        return Application(self.com_object.Path)

    @property
    def path(self):
        """Alias for Path"""
        return self.Path

    @property
    def Presentations(self):
        return Presentations(self.com_object.Presentations)

    @property
    def presentations(self):
        """Alias for Presentations"""
        return self.Presentations

    @property
    def ProductCode(self):
        return self.com_object.ProductCode

    @property
    def productcode(self):
        """Alias for ProductCode"""
        return self.ProductCode

    @property
    def product_code(self):
        """Alias for ProductCode"""
        return self.ProductCode

    @property
    def ProtectedViewWindows(self):
        return ProtectedViewWindows(self.com_object.ProtectedViewWindows)

    @property
    def protectedviewwindows(self):
        """Alias for ProtectedViewWindows"""
        return self.ProtectedViewWindows

    @property
    def protected_view_windows(self):
        """Alias for ProtectedViewWindows"""
        return self.ProtectedViewWindows

    @property
    def SensitivityLabelPolicy(self):
        return self.com_object.SensitivityLabelPolicy

    @property
    def sensitivitylabelpolicy(self):
        """Alias for SensitivityLabelPolicy"""
        return self.SensitivityLabelPolicy

    @property
    def sensitivity_label_policy(self):
        """Alias for SensitivityLabelPolicy"""
        return self.SensitivityLabelPolicy

    @property
    def ShowStartupDialog(self):
        return self.com_object.ShowStartupDialog

    @ShowStartupDialog.setter
    def ShowStartupDialog(self, value):
        self.com_object.ShowStartupDialog = value

    @property
    def showstartupdialog(self):
        """Alias for ShowStartupDialog"""
        return self.ShowStartupDialog

    @showstartupdialog.setter
    def showstartupdialog(self, value):
        """Alias for ShowStartupDialog.setter"""
        self.ShowStartupDialog = value

    @property
    def show_startup_dialog(self):
        """Alias for ShowStartupDialog"""
        return self.ShowStartupDialog

    @show_startup_dialog.setter
    def show_startup_dialog(self, value):
        """Alias for ShowStartupDialog.setter"""
        self.ShowStartupDialog = value

    @property
    def ShowWindowsInTaskbar(self):
        return self.com_object.ShowWindowsInTaskbar

    @ShowWindowsInTaskbar.setter
    def ShowWindowsInTaskbar(self, value):
        self.com_object.ShowWindowsInTaskbar = value

    @property
    def showwindowsintaskbar(self):
        """Alias for ShowWindowsInTaskbar"""
        return self.ShowWindowsInTaskbar

    @showwindowsintaskbar.setter
    def showwindowsintaskbar(self, value):
        """Alias for ShowWindowsInTaskbar.setter"""
        self.ShowWindowsInTaskbar = value

    @property
    def show_windows_in_taskbar(self):
        """Alias for ShowWindowsInTaskbar"""
        return self.ShowWindowsInTaskbar

    @show_windows_in_taskbar.setter
    def show_windows_in_taskbar(self, value):
        """Alias for ShowWindowsInTaskbar.setter"""
        self.ShowWindowsInTaskbar = value

    @property
    def SlideShowWindows(self):
        return SlideShowWindows(self.com_object.SlideShowWindows)

    @property
    def slideshowwindows(self):
        """Alias for SlideShowWindows"""
        return self.SlideShowWindows

    @property
    def slide_show_windows(self):
        """Alias for SlideShowWindows"""
        return self.SlideShowWindows

    @property
    def SmartArtColors(self):
        return Application(self.com_object.SmartArtColors)

    @property
    def smartartcolors(self):
        """Alias for SmartArtColors"""
        return self.SmartArtColors

    @property
    def smart_art_colors(self):
        """Alias for SmartArtColors"""
        return self.SmartArtColors

    @property
    def SmartArtLayouts(self):
        return Application(self.com_object.SmartArtLayouts)

    @property
    def smartartlayouts(self):
        """Alias for SmartArtLayouts"""
        return self.SmartArtLayouts

    @property
    def smart_art_layouts(self):
        """Alias for SmartArtLayouts"""
        return self.SmartArtLayouts

    @property
    def SmartArtQuickStyles(self):
        return Application(self.com_object.SmartArtQuickStyles)

    @property
    def smartartquickstyles(self):
        """Alias for SmartArtQuickStyles"""
        return self.SmartArtQuickStyles

    @property
    def smart_art_quick_styles(self):
        """Alias for SmartArtQuickStyles"""
        return self.SmartArtQuickStyles

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def VBE(self):
        return self.com_object.VBE

    @property
    def vbe(self):
        """Alias for VBE"""
        return self.VBE

    @property
    def v_b_e(self):
        """Alias for VBE"""
        return self.VBE

    @property
    def Version(self):
        return self.com_object.Version

    @property
    def version(self):
        """Alias for Version"""
        return self.Version

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def Windows(self):
        return DocumentWindows(self.com_object.Windows)

    @property
    def windows(self):
        """Alias for Windows"""
        return self.Windows

    @property
    def WindowState(self):
        return self.com_object.WindowState

    @WindowState.setter
    def WindowState(self, value):
        self.com_object.WindowState = value

    @property
    def windowstate(self):
        """Alias for WindowState"""
        return self.WindowState

    @windowstate.setter
    def windowstate(self, value):
        """Alias for WindowState.setter"""
        self.WindowState = value

    @property
    def window_state(self):
        """Alias for WindowState"""
        return self.WindowState

    @window_state.setter
    def window_state(self, value):
        """Alias for WindowState.setter"""
        self.WindowState = value

    def Activate(self):
        self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()

    def Help(self, HelpFile=None, ContextID=None):
        arguments = com_arguments([unwrap(a) for a in [HelpFile, ContextID]])
        self.com_object.Help(*arguments)

    def help(self, HelpFile=None, ContextID=None):
        """Alias for Help"""
        arguments = [HelpFile, ContextID]
        return self.Help(*arguments)

    def OpenThemeFile(self, themeFileName=None):
        arguments = com_arguments([unwrap(a) for a in [themeFileName]])
        return self.com_object.OpenThemeFile(*arguments)

    def openthemefile(self, themeFileName=None):
        """Alias for OpenThemeFile"""
        arguments = [themeFileName]
        return self.OpenThemeFile(*arguments)

    def open_theme_file(self, themeFileName=None):
        """Alias for OpenThemeFile"""
        arguments = [themeFileName]
        return self.OpenThemeFile(*arguments)

    def Quit(self):
        self.com_object.Quit()

    def quit(self):
        """Alias for Quit"""
        return self.Quit()

    def Run(self, MacroName=None, safeArrayOfParams=None):
        arguments = com_arguments([unwrap(a) for a in [MacroName, safeArrayOfParams]])
        return self.com_object.Run(*arguments)

    def run(self, MacroName=None, safeArrayOfParams=None):
        """Alias for Run"""
        arguments = [MacroName, safeArrayOfParams]
        return self.Run(*arguments)

    def StartNewUndoEntry(self):
        self.com_object.StartNewUndoEntry()

    def startnewundoentry(self):
        """Alias for StartNewUndoEntry"""
        return self.StartNewUndoEntry()

    def start_new_undo_entry(self):
        """Alias for StartNewUndoEntry"""
        return self.StartNewUndoEntry()


class AutoCorrect:

    def __init__(self, autocorrect=None):
        self.com_object= autocorrect

    @property
    def DisplayAutoCorrectOptions(self):
        return self.com_object.DisplayAutoCorrectOptions

    @DisplayAutoCorrectOptions.setter
    def DisplayAutoCorrectOptions(self, value):
        self.com_object.DisplayAutoCorrectOptions = value

    @property
    def displayautocorrectoptions(self):
        """Alias for DisplayAutoCorrectOptions"""
        return self.DisplayAutoCorrectOptions

    @displayautocorrectoptions.setter
    def displayautocorrectoptions(self, value):
        """Alias for DisplayAutoCorrectOptions.setter"""
        self.DisplayAutoCorrectOptions = value

    @property
    def display_auto_correct_options(self):
        """Alias for DisplayAutoCorrectOptions"""
        return self.DisplayAutoCorrectOptions

    @display_auto_correct_options.setter
    def display_auto_correct_options(self, value):
        """Alias for DisplayAutoCorrectOptions.setter"""
        self.DisplayAutoCorrectOptions = value

    @property
    def DisplayAutoLayoutOptions(self):
        return self.com_object.DisplayAutoLayoutOptions

    @DisplayAutoLayoutOptions.setter
    def DisplayAutoLayoutOptions(self, value):
        self.com_object.DisplayAutoLayoutOptions = value

    @property
    def displayautolayoutoptions(self):
        """Alias for DisplayAutoLayoutOptions"""
        return self.DisplayAutoLayoutOptions

    @displayautolayoutoptions.setter
    def displayautolayoutoptions(self, value):
        """Alias for DisplayAutoLayoutOptions.setter"""
        self.DisplayAutoLayoutOptions = value

    @property
    def display_auto_layout_options(self):
        """Alias for DisplayAutoLayoutOptions"""
        return self.DisplayAutoLayoutOptions

    @display_auto_layout_options.setter
    def display_auto_layout_options(self, value):
        """Alias for DisplayAutoLayoutOptions.setter"""
        self.DisplayAutoLayoutOptions = value


class Axes:

    def __init__(self, axes=None):
        self.com_object= axes

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Type=None, AxisGroup=None):
        arguments = com_arguments([unwrap(a) for a in [Type, AxisGroup]])
        self.com_object.Item(*arguments)

    def item(self, Type=None, AxisGroup=None):
        """Alias for Item"""
        arguments = [Type, AxisGroup]
        return self.Item(*arguments)


class Axis:

    def __init__(self, axis=None):
        self.com_object= axis

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AxisBetweenCategories(self):
        return self.com_object.AxisBetweenCategories

    @AxisBetweenCategories.setter
    def AxisBetweenCategories(self, value):
        self.com_object.AxisBetweenCategories = value

    @property
    def axisbetweencategories(self):
        """Alias for AxisBetweenCategories"""
        return self.AxisBetweenCategories

    @axisbetweencategories.setter
    def axisbetweencategories(self, value):
        """Alias for AxisBetweenCategories.setter"""
        self.AxisBetweenCategories = value

    @property
    def axis_between_categories(self):
        """Alias for AxisBetweenCategories"""
        return self.AxisBetweenCategories

    @axis_between_categories.setter
    def axis_between_categories(self, value):
        """Alias for AxisBetweenCategories.setter"""
        self.AxisBetweenCategories = value

    @property
    def AxisGroup(self):
        return XlAxisGroup(self.com_object.AxisGroup)

    @property
    def axisgroup(self):
        """Alias for AxisGroup"""
        return self.AxisGroup

    @property
    def axis_group(self):
        """Alias for AxisGroup"""
        return self.AxisGroup

    @property
    def AxisTitle(self):
        return AxisTitle(self.com_object.AxisTitle)

    @property
    def axistitle(self):
        """Alias for AxisTitle"""
        return self.AxisTitle

    @property
    def axis_title(self):
        """Alias for AxisTitle"""
        return self.AxisTitle

    @property
    def BaseUnit(self):
        return XlTimeUnit(self.com_object.BaseUnit)

    @BaseUnit.setter
    def BaseUnit(self, value):
        self.com_object.BaseUnit = value

    @property
    def baseunit(self):
        """Alias for BaseUnit"""
        return self.BaseUnit

    @baseunit.setter
    def baseunit(self, value):
        """Alias for BaseUnit.setter"""
        self.BaseUnit = value

    @property
    def base_unit(self):
        """Alias for BaseUnit"""
        return self.BaseUnit

    @base_unit.setter
    def base_unit(self, value):
        """Alias for BaseUnit.setter"""
        self.BaseUnit = value

    @property
    def BaseUnitIsAuto(self):
        return self.com_object.BaseUnitIsAuto

    @BaseUnitIsAuto.setter
    def BaseUnitIsAuto(self, value):
        self.com_object.BaseUnitIsAuto = value

    @property
    def baseunitisauto(self):
        """Alias for BaseUnitIsAuto"""
        return self.BaseUnitIsAuto

    @baseunitisauto.setter
    def baseunitisauto(self, value):
        """Alias for BaseUnitIsAuto.setter"""
        self.BaseUnitIsAuto = value

    @property
    def base_unit_is_auto(self):
        """Alias for BaseUnitIsAuto"""
        return self.BaseUnitIsAuto

    @base_unit_is_auto.setter
    def base_unit_is_auto(self, value):
        """Alias for BaseUnitIsAuto.setter"""
        self.BaseUnitIsAuto = value

    @property
    def Border(self):
        return ChartBorder(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def CategoryNames(self):
        return self.com_object.CategoryNames

    @CategoryNames.setter
    def CategoryNames(self, value):
        self.com_object.CategoryNames = value

    @property
    def categorynames(self):
        """Alias for CategoryNames"""
        return self.CategoryNames

    @categorynames.setter
    def categorynames(self, value):
        """Alias for CategoryNames.setter"""
        self.CategoryNames = value

    @property
    def category_names(self):
        """Alias for CategoryNames"""
        return self.CategoryNames

    @category_names.setter
    def category_names(self, value):
        """Alias for CategoryNames.setter"""
        self.CategoryNames = value

    @property
    def CategoryType(self):
        return XlCategoryType(self.com_object.CategoryType)

    @CategoryType.setter
    def CategoryType(self, value):
        self.com_object.CategoryType = value

    @property
    def categorytype(self):
        """Alias for CategoryType"""
        return self.CategoryType

    @categorytype.setter
    def categorytype(self, value):
        """Alias for CategoryType.setter"""
        self.CategoryType = value

    @property
    def category_type(self):
        """Alias for CategoryType"""
        return self.CategoryType

    @category_type.setter
    def category_type(self, value):
        """Alias for CategoryType.setter"""
        self.CategoryType = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Crosses(self):
        return self.com_object.Crosses

    @Crosses.setter
    def Crosses(self, value):
        self.com_object.Crosses = value

    @property
    def crosses(self):
        """Alias for Crosses"""
        return self.Crosses

    @crosses.setter
    def crosses(self, value):
        """Alias for Crosses.setter"""
        self.Crosses = value

    @property
    def CrossesAt(self):
        return self.com_object.CrossesAt

    @CrossesAt.setter
    def CrossesAt(self, value):
        self.com_object.CrossesAt = value

    @property
    def crossesat(self):
        """Alias for CrossesAt"""
        return self.CrossesAt

    @crossesat.setter
    def crossesat(self, value):
        """Alias for CrossesAt.setter"""
        self.CrossesAt = value

    @property
    def crosses_at(self):
        """Alias for CrossesAt"""
        return self.CrossesAt

    @crosses_at.setter
    def crosses_at(self, value):
        """Alias for CrossesAt.setter"""
        self.CrossesAt = value

    @property
    def DisplayUnit(self):
        return XlDisplayUnit(self.com_object.DisplayUnit)

    @DisplayUnit.setter
    def DisplayUnit(self, value):
        self.com_object.DisplayUnit = value

    @property
    def displayunit(self):
        """Alias for DisplayUnit"""
        return self.DisplayUnit

    @displayunit.setter
    def displayunit(self, value):
        """Alias for DisplayUnit.setter"""
        self.DisplayUnit = value

    @property
    def display_unit(self):
        """Alias for DisplayUnit"""
        return self.DisplayUnit

    @display_unit.setter
    def display_unit(self, value):
        """Alias for DisplayUnit.setter"""
        self.DisplayUnit = value

    @property
    def DisplayUnitCustom(self):
        return self.com_object.DisplayUnitCustom

    @DisplayUnitCustom.setter
    def DisplayUnitCustom(self, value):
        self.com_object.DisplayUnitCustom = value

    @property
    def displayunitcustom(self):
        """Alias for DisplayUnitCustom"""
        return self.DisplayUnitCustom

    @displayunitcustom.setter
    def displayunitcustom(self, value):
        """Alias for DisplayUnitCustom.setter"""
        self.DisplayUnitCustom = value

    @property
    def display_unit_custom(self):
        """Alias for DisplayUnitCustom"""
        return self.DisplayUnitCustom

    @display_unit_custom.setter
    def display_unit_custom(self, value):
        """Alias for DisplayUnitCustom.setter"""
        self.DisplayUnitCustom = value

    @property
    def DisplayUnitLabel(self):
        return DisplayUnitLabel(self.com_object.DisplayUnitLabel)

    @property
    def displayunitlabel(self):
        """Alias for DisplayUnitLabel"""
        return self.DisplayUnitLabel

    @property
    def display_unit_label(self):
        """Alias for DisplayUnitLabel"""
        return self.DisplayUnitLabel

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def HasDisplayUnitLabel(self):
        return self.com_object.HasDisplayUnitLabel

    @HasDisplayUnitLabel.setter
    def HasDisplayUnitLabel(self, value):
        self.com_object.HasDisplayUnitLabel = value

    @property
    def hasdisplayunitlabel(self):
        """Alias for HasDisplayUnitLabel"""
        return self.HasDisplayUnitLabel

    @hasdisplayunitlabel.setter
    def hasdisplayunitlabel(self, value):
        """Alias for HasDisplayUnitLabel.setter"""
        self.HasDisplayUnitLabel = value

    @property
    def has_display_unit_label(self):
        """Alias for HasDisplayUnitLabel"""
        return self.HasDisplayUnitLabel

    @has_display_unit_label.setter
    def has_display_unit_label(self, value):
        """Alias for HasDisplayUnitLabel.setter"""
        self.HasDisplayUnitLabel = value

    @property
    def HasMajorGridlines(self):
        return self.com_object.HasMajorGridlines

    @HasMajorGridlines.setter
    def HasMajorGridlines(self, value):
        self.com_object.HasMajorGridlines = value

    @property
    def hasmajorgridlines(self):
        """Alias for HasMajorGridlines"""
        return self.HasMajorGridlines

    @hasmajorgridlines.setter
    def hasmajorgridlines(self, value):
        """Alias for HasMajorGridlines.setter"""
        self.HasMajorGridlines = value

    @property
    def has_major_gridlines(self):
        """Alias for HasMajorGridlines"""
        return self.HasMajorGridlines

    @has_major_gridlines.setter
    def has_major_gridlines(self, value):
        """Alias for HasMajorGridlines.setter"""
        self.HasMajorGridlines = value

    @property
    def HasMinorGridlines(self):
        return self.com_object.HasMinorGridlines

    @HasMinorGridlines.setter
    def HasMinorGridlines(self, value):
        self.com_object.HasMinorGridlines = value

    @property
    def hasminorgridlines(self):
        """Alias for HasMinorGridlines"""
        return self.HasMinorGridlines

    @hasminorgridlines.setter
    def hasminorgridlines(self, value):
        """Alias for HasMinorGridlines.setter"""
        self.HasMinorGridlines = value

    @property
    def has_minor_gridlines(self):
        """Alias for HasMinorGridlines"""
        return self.HasMinorGridlines

    @has_minor_gridlines.setter
    def has_minor_gridlines(self, value):
        """Alias for HasMinorGridlines.setter"""
        self.HasMinorGridlines = value

    @property
    def HasTitle(self):
        return self.com_object.HasTitle

    @HasTitle.setter
    def HasTitle(self, value):
        self.com_object.HasTitle = value

    @property
    def hastitle(self):
        """Alias for HasTitle"""
        return self.HasTitle

    @hastitle.setter
    def hastitle(self, value):
        """Alias for HasTitle.setter"""
        self.HasTitle = value

    @property
    def has_title(self):
        """Alias for HasTitle"""
        return self.HasTitle

    @has_title.setter
    def has_title(self, value):
        """Alias for HasTitle.setter"""
        self.HasTitle = value

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def Left(self):
        return self.com_object.Left

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @property
    def LogBase(self):
        return self.com_object.LogBase

    @LogBase.setter
    def LogBase(self, value):
        self.com_object.LogBase = value

    @property
    def logbase(self):
        """Alias for LogBase"""
        return self.LogBase

    @logbase.setter
    def logbase(self, value):
        """Alias for LogBase.setter"""
        self.LogBase = value

    @property
    def log_base(self):
        """Alias for LogBase"""
        return self.LogBase

    @log_base.setter
    def log_base(self, value):
        """Alias for LogBase.setter"""
        self.LogBase = value

    @property
    def MajorGridlines(self):
        return Gridlines(self.com_object.MajorGridlines)

    @property
    def majorgridlines(self):
        """Alias for MajorGridlines"""
        return self.MajorGridlines

    @property
    def major_gridlines(self):
        """Alias for MajorGridlines"""
        return self.MajorGridlines

    @property
    def MajorTickMark(self):
        return XlTickMark(self.com_object.MajorTickMark)

    @MajorTickMark.setter
    def MajorTickMark(self, value):
        self.com_object.MajorTickMark = value

    @property
    def majortickmark(self):
        """Alias for MajorTickMark"""
        return self.MajorTickMark

    @majortickmark.setter
    def majortickmark(self, value):
        """Alias for MajorTickMark.setter"""
        self.MajorTickMark = value

    @property
    def major_tick_mark(self):
        """Alias for MajorTickMark"""
        return self.MajorTickMark

    @major_tick_mark.setter
    def major_tick_mark(self, value):
        """Alias for MajorTickMark.setter"""
        self.MajorTickMark = value

    @property
    def MajorUnit(self):
        return self.com_object.MajorUnit

    @MajorUnit.setter
    def MajorUnit(self, value):
        self.com_object.MajorUnit = value

    @property
    def majorunit(self):
        """Alias for MajorUnit"""
        return self.MajorUnit

    @majorunit.setter
    def majorunit(self, value):
        """Alias for MajorUnit.setter"""
        self.MajorUnit = value

    @property
    def major_unit(self):
        """Alias for MajorUnit"""
        return self.MajorUnit

    @major_unit.setter
    def major_unit(self, value):
        """Alias for MajorUnit.setter"""
        self.MajorUnit = value

    @property
    def MajorUnitIsAuto(self):
        return self.com_object.MajorUnitIsAuto

    @MajorUnitIsAuto.setter
    def MajorUnitIsAuto(self, value):
        self.com_object.MajorUnitIsAuto = value

    @property
    def majorunitisauto(self):
        """Alias for MajorUnitIsAuto"""
        return self.MajorUnitIsAuto

    @majorunitisauto.setter
    def majorunitisauto(self, value):
        """Alias for MajorUnitIsAuto.setter"""
        self.MajorUnitIsAuto = value

    @property
    def major_unit_is_auto(self):
        """Alias for MajorUnitIsAuto"""
        return self.MajorUnitIsAuto

    @major_unit_is_auto.setter
    def major_unit_is_auto(self, value):
        """Alias for MajorUnitIsAuto.setter"""
        self.MajorUnitIsAuto = value

    @property
    def MajorUnitScale(self):
        return self.com_object.MajorUnitScale

    @MajorUnitScale.setter
    def MajorUnitScale(self, value):
        self.com_object.MajorUnitScale = value

    @property
    def majorunitscale(self):
        """Alias for MajorUnitScale"""
        return self.MajorUnitScale

    @majorunitscale.setter
    def majorunitscale(self, value):
        """Alias for MajorUnitScale.setter"""
        self.MajorUnitScale = value

    @property
    def major_unit_scale(self):
        """Alias for MajorUnitScale"""
        return self.MajorUnitScale

    @major_unit_scale.setter
    def major_unit_scale(self, value):
        """Alias for MajorUnitScale.setter"""
        self.MajorUnitScale = value

    @property
    def MaximumScale(self):
        return self.com_object.MaximumScale

    @MaximumScale.setter
    def MaximumScale(self, value):
        self.com_object.MaximumScale = value

    @property
    def maximumscale(self):
        """Alias for MaximumScale"""
        return self.MaximumScale

    @maximumscale.setter
    def maximumscale(self, value):
        """Alias for MaximumScale.setter"""
        self.MaximumScale = value

    @property
    def maximum_scale(self):
        """Alias for MaximumScale"""
        return self.MaximumScale

    @maximum_scale.setter
    def maximum_scale(self, value):
        """Alias for MaximumScale.setter"""
        self.MaximumScale = value

    @property
    def MaximumScaleIsAuto(self):
        return self.com_object.MaximumScaleIsAuto

    @MaximumScaleIsAuto.setter
    def MaximumScaleIsAuto(self, value):
        self.com_object.MaximumScaleIsAuto = value

    @property
    def maximumscaleisauto(self):
        """Alias for MaximumScaleIsAuto"""
        return self.MaximumScaleIsAuto

    @maximumscaleisauto.setter
    def maximumscaleisauto(self, value):
        """Alias for MaximumScaleIsAuto.setter"""
        self.MaximumScaleIsAuto = value

    @property
    def maximum_scale_is_auto(self):
        """Alias for MaximumScaleIsAuto"""
        return self.MaximumScaleIsAuto

    @maximum_scale_is_auto.setter
    def maximum_scale_is_auto(self, value):
        """Alias for MaximumScaleIsAuto.setter"""
        self.MaximumScaleIsAuto = value

    @property
    def MinimumScale(self):
        return self.com_object.MinimumScale

    @MinimumScale.setter
    def MinimumScale(self, value):
        self.com_object.MinimumScale = value

    @property
    def minimumscale(self):
        """Alias for MinimumScale"""
        return self.MinimumScale

    @minimumscale.setter
    def minimumscale(self, value):
        """Alias for MinimumScale.setter"""
        self.MinimumScale = value

    @property
    def minimum_scale(self):
        """Alias for MinimumScale"""
        return self.MinimumScale

    @minimum_scale.setter
    def minimum_scale(self, value):
        """Alias for MinimumScale.setter"""
        self.MinimumScale = value

    @property
    def MinimumScaleIsAuto(self):
        return self.com_object.MinimumScaleIsAuto

    @MinimumScaleIsAuto.setter
    def MinimumScaleIsAuto(self, value):
        self.com_object.MinimumScaleIsAuto = value

    @property
    def minimumscaleisauto(self):
        """Alias for MinimumScaleIsAuto"""
        return self.MinimumScaleIsAuto

    @minimumscaleisauto.setter
    def minimumscaleisauto(self, value):
        """Alias for MinimumScaleIsAuto.setter"""
        self.MinimumScaleIsAuto = value

    @property
    def minimum_scale_is_auto(self):
        """Alias for MinimumScaleIsAuto"""
        return self.MinimumScaleIsAuto

    @minimum_scale_is_auto.setter
    def minimum_scale_is_auto(self, value):
        """Alias for MinimumScaleIsAuto.setter"""
        self.MinimumScaleIsAuto = value

    @property
    def MinorGridlines(self):
        return Gridlines(self.com_object.MinorGridlines)

    @property
    def minorgridlines(self):
        """Alias for MinorGridlines"""
        return self.MinorGridlines

    @property
    def minor_gridlines(self):
        """Alias for MinorGridlines"""
        return self.MinorGridlines

    @property
    def MinorTickMark(self):
        return XlTickMark(self.com_object.MinorTickMark)

    @MinorTickMark.setter
    def MinorTickMark(self, value):
        self.com_object.MinorTickMark = value

    @property
    def minortickmark(self):
        """Alias for MinorTickMark"""
        return self.MinorTickMark

    @minortickmark.setter
    def minortickmark(self, value):
        """Alias for MinorTickMark.setter"""
        self.MinorTickMark = value

    @property
    def minor_tick_mark(self):
        """Alias for MinorTickMark"""
        return self.MinorTickMark

    @minor_tick_mark.setter
    def minor_tick_mark(self, value):
        """Alias for MinorTickMark.setter"""
        self.MinorTickMark = value

    @property
    def MinorUnit(self):
        return self.com_object.MinorUnit

    @MinorUnit.setter
    def MinorUnit(self, value):
        self.com_object.MinorUnit = value

    @property
    def minorunit(self):
        """Alias for MinorUnit"""
        return self.MinorUnit

    @minorunit.setter
    def minorunit(self, value):
        """Alias for MinorUnit.setter"""
        self.MinorUnit = value

    @property
    def minor_unit(self):
        """Alias for MinorUnit"""
        return self.MinorUnit

    @minor_unit.setter
    def minor_unit(self, value):
        """Alias for MinorUnit.setter"""
        self.MinorUnit = value

    @property
    def MinorUnitIsAuto(self):
        return self.com_object.MinorUnitIsAuto

    @MinorUnitIsAuto.setter
    def MinorUnitIsAuto(self, value):
        self.com_object.MinorUnitIsAuto = value

    @property
    def minorunitisauto(self):
        """Alias for MinorUnitIsAuto"""
        return self.MinorUnitIsAuto

    @minorunitisauto.setter
    def minorunitisauto(self, value):
        """Alias for MinorUnitIsAuto.setter"""
        self.MinorUnitIsAuto = value

    @property
    def minor_unit_is_auto(self):
        """Alias for MinorUnitIsAuto"""
        return self.MinorUnitIsAuto

    @minor_unit_is_auto.setter
    def minor_unit_is_auto(self, value):
        """Alias for MinorUnitIsAuto.setter"""
        self.MinorUnitIsAuto = value

    @property
    def MinorUnitScale(self):
        return self.com_object.MinorUnitScale

    @MinorUnitScale.setter
    def MinorUnitScale(self, value):
        self.com_object.MinorUnitScale = value

    @property
    def minorunitscale(self):
        """Alias for MinorUnitScale"""
        return self.MinorUnitScale

    @minorunitscale.setter
    def minorunitscale(self, value):
        """Alias for MinorUnitScale.setter"""
        self.MinorUnitScale = value

    @property
    def minor_unit_scale(self):
        """Alias for MinorUnitScale"""
        return self.MinorUnitScale

    @minor_unit_scale.setter
    def minor_unit_scale(self, value):
        """Alias for MinorUnitScale.setter"""
        self.MinorUnitScale = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ReversePlotOrder(self):
        return self.com_object.ReversePlotOrder

    @ReversePlotOrder.setter
    def ReversePlotOrder(self, value):
        self.com_object.ReversePlotOrder = value

    @property
    def reverseplotorder(self):
        """Alias for ReversePlotOrder"""
        return self.ReversePlotOrder

    @reverseplotorder.setter
    def reverseplotorder(self, value):
        """Alias for ReversePlotOrder.setter"""
        self.ReversePlotOrder = value

    @property
    def reverse_plot_order(self):
        """Alias for ReversePlotOrder"""
        return self.ReversePlotOrder

    @reverse_plot_order.setter
    def reverse_plot_order(self, value):
        """Alias for ReversePlotOrder.setter"""
        self.ReversePlotOrder = value

    @property
    def ScaleType(self):
        return XlScaleType(self.com_object.ScaleType)

    @ScaleType.setter
    def ScaleType(self, value):
        self.com_object.ScaleType = value

    @property
    def scaletype(self):
        """Alias for ScaleType"""
        return self.ScaleType

    @scaletype.setter
    def scaletype(self, value):
        """Alias for ScaleType.setter"""
        self.ScaleType = value

    @property
    def scale_type(self):
        """Alias for ScaleType"""
        return self.ScaleType

    @scale_type.setter
    def scale_type(self, value):
        """Alias for ScaleType.setter"""
        self.ScaleType = value

    @property
    def TickLabelPosition(self):
        return self.com_object.TickLabelPosition

    @TickLabelPosition.setter
    def TickLabelPosition(self, value):
        self.com_object.TickLabelPosition = value

    @property
    def ticklabelposition(self):
        """Alias for TickLabelPosition"""
        return self.TickLabelPosition

    @ticklabelposition.setter
    def ticklabelposition(self, value):
        """Alias for TickLabelPosition.setter"""
        self.TickLabelPosition = value

    @property
    def tick_label_position(self):
        """Alias for TickLabelPosition"""
        return self.TickLabelPosition

    @tick_label_position.setter
    def tick_label_position(self, value):
        """Alias for TickLabelPosition.setter"""
        self.TickLabelPosition = value

    @property
    def TickLabels(self):
        return TickLabels(self.com_object.TickLabels)

    @property
    def ticklabels(self):
        """Alias for TickLabels"""
        return self.TickLabels

    @property
    def tick_labels(self):
        """Alias for TickLabels"""
        return self.TickLabels

    @property
    def TickLabelSpacing(self):
        return self.com_object.TickLabelSpacing

    @TickLabelSpacing.setter
    def TickLabelSpacing(self, value):
        self.com_object.TickLabelSpacing = value

    @property
    def ticklabelspacing(self):
        """Alias for TickLabelSpacing"""
        return self.TickLabelSpacing

    @ticklabelspacing.setter
    def ticklabelspacing(self, value):
        """Alias for TickLabelSpacing.setter"""
        self.TickLabelSpacing = value

    @property
    def tick_label_spacing(self):
        """Alias for TickLabelSpacing"""
        return self.TickLabelSpacing

    @tick_label_spacing.setter
    def tick_label_spacing(self, value):
        """Alias for TickLabelSpacing.setter"""
        self.TickLabelSpacing = value

    @property
    def TickLabelSpacingIsAuto(self):
        return self.com_object.TickLabelSpacingIsAuto

    @TickLabelSpacingIsAuto.setter
    def TickLabelSpacingIsAuto(self, value):
        self.com_object.TickLabelSpacingIsAuto = value

    @property
    def ticklabelspacingisauto(self):
        """Alias for TickLabelSpacingIsAuto"""
        return self.TickLabelSpacingIsAuto

    @ticklabelspacingisauto.setter
    def ticklabelspacingisauto(self, value):
        """Alias for TickLabelSpacingIsAuto.setter"""
        self.TickLabelSpacingIsAuto = value

    @property
    def tick_label_spacing_is_auto(self):
        """Alias for TickLabelSpacingIsAuto"""
        return self.TickLabelSpacingIsAuto

    @tick_label_spacing_is_auto.setter
    def tick_label_spacing_is_auto(self, value):
        """Alias for TickLabelSpacingIsAuto.setter"""
        self.TickLabelSpacingIsAuto = value

    @property
    def TickMarkSpacing(self):
        return self.com_object.TickMarkSpacing

    @TickMarkSpacing.setter
    def TickMarkSpacing(self, value):
        self.com_object.TickMarkSpacing = value

    @property
    def tickmarkspacing(self):
        """Alias for TickMarkSpacing"""
        return self.TickMarkSpacing

    @tickmarkspacing.setter
    def tickmarkspacing(self, value):
        """Alias for TickMarkSpacing.setter"""
        self.TickMarkSpacing = value

    @property
    def tick_mark_spacing(self):
        """Alias for TickMarkSpacing"""
        return self.TickMarkSpacing

    @tick_mark_spacing.setter
    def tick_mark_spacing(self, value):
        """Alias for TickMarkSpacing.setter"""
        self.TickMarkSpacing = value

    @property
    def Top(self):
        return self.com_object.Top

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @property
    def Type(self):
        return XlAxisType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class AxisTitle:

    def __init__(self, axistitle=None):
        self.com_object= axistitle

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    def Characters(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        if hasattr(self.com_object, "GetCharacters"):
            return ChartCharacters(self.com_object.GetCharacters(*arguments))
        else:
            return ChartCharacters(self.com_object.Characters(*arguments))

    def characters(self, Start=None, Length=None):
        """Alias for Characters"""
        arguments = [Start, Length]
        return self.Characters(*arguments)

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def FormulaLocal(self):
        return self.com_object.FormulaLocal

    @FormulaLocal.setter
    def FormulaLocal(self, value):
        self.com_object.FormulaLocal = value

    @property
    def formulalocal(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formulalocal.setter
    def formulalocal(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def formula_local(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formula_local.setter
    def formula_local(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def FormulaR1C1(self):
        return self.com_object.FormulaR1C1

    @FormulaR1C1.setter
    def FormulaR1C1(self, value):
        self.com_object.FormulaR1C1 = value

    @property
    def formular1c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formular1c1.setter
    def formular1c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def formula_r1_c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formula_r1_c1.setter
    def formula_r1_c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def FormulaR1C1Local(self):
        return self.com_object.FormulaR1C1Local

    @FormulaR1C1Local.setter
    def FormulaR1C1Local(self, value):
        self.com_object.FormulaR1C1Local = value

    @property
    def formular1c1local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formular1c1local.setter
    def formular1c1local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def formula_r1_c1_local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formula_r1_c1_local.setter
    def formula_r1_c1_local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def HorizontalAlignment(self):
        return self.com_object.HorizontalAlignment

    @HorizontalAlignment.setter
    def HorizontalAlignment(self, value):
        self.com_object.HorizontalAlignment = value

    @property
    def horizontalalignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontalalignment.setter
    def horizontalalignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def horizontal_alignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def IncludeInLayout(self):
        return self.com_object.IncludeInLayout

    @IncludeInLayout.setter
    def IncludeInLayout(self, value):
        self.com_object.IncludeInLayout = value

    @property
    def includeinlayout(self):
        """Alias for IncludeInLayout"""
        return self.IncludeInLayout

    @includeinlayout.setter
    def includeinlayout(self, value):
        """Alias for IncludeInLayout.setter"""
        self.IncludeInLayout = value

    @property
    def include_in_layout(self):
        """Alias for IncludeInLayout"""
        return self.IncludeInLayout

    @include_in_layout.setter
    def include_in_layout(self, value):
        """Alias for IncludeInLayout.setter"""
        self.IncludeInLayout = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return XlChartElementPosition(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def ReadingOrder(self):
        return XlReadingOrder(self.com_object.ReadingOrder)

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def VerticalAlignment(self):
        return self.com_object.VerticalAlignment

    @VerticalAlignment.setter
    def VerticalAlignment(self, value):
        self.com_object.VerticalAlignment = value

    @property
    def verticalalignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @verticalalignment.setter
    def verticalalignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def vertical_alignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @vertical_alignment.setter
    def vertical_alignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Borders:

    def __init__(self, borders=None):
        self.com_object= borders

    def __call__(self, item):
        return Border(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, BorderType=None):
        arguments = com_arguments([unwrap(a) for a in [BorderType]])
        return LineFormat(self.com_object.Item(*arguments))

    def item(self, BorderType=None):
        """Alias for Item"""
        arguments = [BorderType]
        return self.Item(*arguments)


class Broadcast:

    def __init__(self, broadcast=None):
        self.com_object= broadcast

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AttendeeUrl(self):
        return self.com_object.AttendeeUrl

    @property
    def attendeeurl(self):
        """Alias for AttendeeUrl"""
        return self.AttendeeUrl

    @property
    def attendee_url(self):
        """Alias for AttendeeUrl"""
        return self.AttendeeUrl

    @property
    def Capabilities(self):
        return self.com_object.Capabilities

    @property
    def capabilities(self):
        """Alias for Capabilities"""
        return self.Capabilities

    @property
    def IsBroadcasting(self):
        return self.com_object.IsBroadcasting

    @property
    def isbroadcasting(self):
        """Alias for IsBroadcasting"""
        return self.IsBroadcasting

    @property
    def is_broadcasting(self):
        """Alias for IsBroadcasting"""
        return self.IsBroadcasting

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PresenterServiceUrl(self):
        return self.com_object.PresenterServiceUrl

    @property
    def presenterserviceurl(self):
        """Alias for PresenterServiceUrl"""
        return self.PresenterServiceUrl

    @property
    def presenter_service_url(self):
        """Alias for PresenterServiceUrl"""
        return self.PresenterServiceUrl

    @property
    def SessionID(self):
        return self.com_object.SessionID

    @property
    def sessionid(self):
        """Alias for SessionID"""
        return self.SessionID

    @property
    def session_i_d(self):
        """Alias for SessionID"""
        return self.SessionID

    @property
    def State(self):
        return self.com_object.State

    @property
    def state(self):
        """Alias for State"""
        return self.State

    def AddMeetingNotes(self, notesUrl=None, notesWacUrl=None):
        arguments = com_arguments([unwrap(a) for a in [notesUrl, notesWacUrl]])
        return self.com_object.AddMeetingNotes(*arguments)

    def addmeetingnotes(self, notesUrl=None, notesWacUrl=None):
        """Alias for AddMeetingNotes"""
        arguments = [notesUrl, notesWacUrl]
        return self.AddMeetingNotes(*arguments)

    def add_meeting_notes(self, notesUrl=None, notesWacUrl=None):
        """Alias for AddMeetingNotes"""
        arguments = [notesUrl, notesWacUrl]
        return self.AddMeetingNotes(*arguments)

    def End(self):
        return self.com_object.End()

    def end(self):
        """Alias for End"""
        return self.End()

    def Pause(self):
        return self.com_object.Pause()

    def pause(self):
        """Alias for Pause"""
        return self.Pause()

    def Resume(self):
        return self.com_object.Resume()

    def resume(self):
        """Alias for Resume"""
        return self.Resume()

    def Start(self, serverUrl=None):
        arguments = com_arguments([unwrap(a) for a in [serverUrl]])
        self.com_object.Start(*arguments)

    def start(self, serverUrl=None):
        """Alias for Start"""
        arguments = [serverUrl]
        return self.Start(*arguments)


class BulletFormat:

    def __init__(self, bulletformat=None):
        self.com_object= bulletformat

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Character(self):
        return self.com_object.Character

    @Character.setter
    def Character(self, value):
        self.com_object.Character = value

    @property
    def character(self):
        """Alias for Character"""
        return self.Character

    @character.setter
    def character(self, value):
        """Alias for Character.setter"""
        self.Character = value

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def Number(self):
        return self.com_object.Number

    @property
    def number(self):
        """Alias for Number"""
        return self.Number

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RelativeSize(self):
        return self.com_object.RelativeSize

    @RelativeSize.setter
    def RelativeSize(self, value):
        self.com_object.RelativeSize = value

    @property
    def relativesize(self):
        """Alias for RelativeSize"""
        return self.RelativeSize

    @relativesize.setter
    def relativesize(self, value):
        """Alias for RelativeSize.setter"""
        self.RelativeSize = value

    @property
    def relative_size(self):
        """Alias for RelativeSize"""
        return self.RelativeSize

    @relative_size.setter
    def relative_size(self, value):
        """Alias for RelativeSize.setter"""
        self.RelativeSize = value

    @property
    def StartValue(self):
        return self.com_object.StartValue

    @StartValue.setter
    def StartValue(self, value):
        self.com_object.StartValue = value

    @property
    def startvalue(self):
        """Alias for StartValue"""
        return self.StartValue

    @startvalue.setter
    def startvalue(self, value):
        """Alias for StartValue.setter"""
        self.StartValue = value

    @property
    def start_value(self):
        """Alias for StartValue"""
        return self.StartValue

    @start_value.setter
    def start_value(self, value):
        """Alias for StartValue.setter"""
        self.StartValue = value

    @property
    def Style(self):
        return self.com_object.Style

    @Style.setter
    def Style(self, value):
        self.com_object.Style = value

    @property
    def style(self):
        """Alias for Style"""
        return self.Style

    @style.setter
    def style(self, value):
        """Alias for Style.setter"""
        self.Style = value

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    @property
    def UseTextColor(self):
        return self.com_object.UseTextColor

    @UseTextColor.setter
    def UseTextColor(self, value):
        self.com_object.UseTextColor = value

    @property
    def usetextcolor(self):
        """Alias for UseTextColor"""
        return self.UseTextColor

    @usetextcolor.setter
    def usetextcolor(self, value):
        """Alias for UseTextColor.setter"""
        self.UseTextColor = value

    @property
    def use_text_color(self):
        """Alias for UseTextColor"""
        return self.UseTextColor

    @use_text_color.setter
    def use_text_color(self, value):
        """Alias for UseTextColor.setter"""
        self.UseTextColor = value

    @property
    def UseTextFont(self):
        return self.com_object.UseTextFont

    @UseTextFont.setter
    def UseTextFont(self, value):
        self.com_object.UseTextFont = value

    @property
    def usetextfont(self):
        """Alias for UseTextFont"""
        return self.UseTextFont

    @usetextfont.setter
    def usetextfont(self, value):
        """Alias for UseTextFont.setter"""
        self.UseTextFont = value

    @property
    def use_text_font(self):
        """Alias for UseTextFont"""
        return self.UseTextFont

    @use_text_font.setter
    def use_text_font(self, value):
        """Alias for UseTextFont.setter"""
        self.UseTextFont = value

    def Picture(self):
        self.com_object.Picture()

    def picture(self):
        """Alias for Picture"""
        return self.Picture()


class CalloutFormat:

    def __init__(self, calloutformat=None):
        self.com_object= calloutformat

    @property
    def Accent(self):
        return self.com_object.Accent

    @Accent.setter
    def Accent(self, value):
        self.com_object.Accent = value

    @property
    def accent(self):
        """Alias for Accent"""
        return self.Accent

    @accent.setter
    def accent(self, value):
        """Alias for Accent.setter"""
        self.Accent = value

    @property
    def Angle(self):
        return self.com_object.Angle

    @Angle.setter
    def Angle(self, value):
        self.com_object.Angle = value

    @property
    def angle(self):
        """Alias for Angle"""
        return self.Angle

    @angle.setter
    def angle(self, value):
        """Alias for Angle.setter"""
        self.Angle = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoAttach(self):
        return self.com_object.AutoAttach

    @AutoAttach.setter
    def AutoAttach(self, value):
        self.com_object.AutoAttach = value

    @property
    def autoattach(self):
        """Alias for AutoAttach"""
        return self.AutoAttach

    @autoattach.setter
    def autoattach(self, value):
        """Alias for AutoAttach.setter"""
        self.AutoAttach = value

    @property
    def auto_attach(self):
        """Alias for AutoAttach"""
        return self.AutoAttach

    @auto_attach.setter
    def auto_attach(self, value):
        """Alias for AutoAttach.setter"""
        self.AutoAttach = value

    @property
    def AutoLength(self):
        return self.com_object.AutoLength

    @property
    def autolength(self):
        """Alias for AutoLength"""
        return self.AutoLength

    @property
    def auto_length(self):
        """Alias for AutoLength"""
        return self.AutoLength

    @property
    def Border(self):
        return self.com_object.Border

    @Border.setter
    def Border(self, value):
        self.com_object.Border = value

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @border.setter
    def border(self, value):
        """Alias for Border.setter"""
        self.Border = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Drop(self):
        return self.com_object.Drop

    @property
    def drop(self):
        """Alias for Drop"""
        return self.Drop

    @property
    def DropType(self):
        return self.com_object.DropType

    @property
    def droptype(self):
        """Alias for DropType"""
        return self.DropType

    @property
    def drop_type(self):
        """Alias for DropType"""
        return self.DropType

    @property
    def Gap(self):
        return self.com_object.Gap

    @Gap.setter
    def Gap(self, value):
        self.com_object.Gap = value

    @property
    def gap(self):
        """Alias for Gap"""
        return self.Gap

    @gap.setter
    def gap(self, value):
        """Alias for Gap.setter"""
        self.Gap = value

    @property
    def Length(self):
        return self.com_object.Length

    @property
    def length(self):
        """Alias for Length"""
        return self.Length

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    def AutomaticLength(self):
        self.com_object.AutomaticLength()

    def automaticlength(self):
        """Alias for AutomaticLength"""
        return self.AutomaticLength()

    def automatic_length(self):
        """Alias for AutomaticLength"""
        return self.AutomaticLength()

    def CustomDrop(self, Drop=None):
        arguments = com_arguments([unwrap(a) for a in [Drop]])
        return self.com_object.CustomDrop(*arguments)

    def customdrop(self, Drop=None):
        """Alias for CustomDrop"""
        arguments = [Drop]
        return self.CustomDrop(*arguments)

    def custom_drop(self, Drop=None):
        """Alias for CustomDrop"""
        arguments = [Drop]
        return self.CustomDrop(*arguments)

    def CustomLength(self, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Length]])
        return self.com_object.CustomLength(*arguments)

    def customlength(self, Length=None):
        """Alias for CustomLength"""
        arguments = [Length]
        return self.CustomLength(*arguments)

    def custom_length(self, Length=None):
        """Alias for CustomLength"""
        arguments = [Length]
        return self.CustomLength(*arguments)

    def PresetDrop(self, DropType=None):
        arguments = com_arguments([unwrap(a) for a in [DropType]])
        self.com_object.PresetDrop(*arguments)

    def presetdrop(self, DropType=None):
        """Alias for PresetDrop"""
        arguments = [DropType]
        return self.PresetDrop(*arguments)

    def preset_drop(self, DropType=None):
        """Alias for PresetDrop"""
        arguments = [DropType]
        return self.PresetDrop(*arguments)


class CategoryCollection:

    def __init__(self, categorycollection=None):
        self.com_object= categorycollection

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return CHARTCATEGORY(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Cell:

    def __init__(self, cell=None):
        self.com_object= cell

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Selected(self):
        return self.com_object.Selected

    @property
    def selected(self):
        """Alias for Selected"""
        return self.Selected

    @property
    def Shape(self):
        return Shape(self.com_object.Shape)

    @property
    def shape(self):
        """Alias for Shape"""
        return self.Shape

    def Merge(self, MergeTo=None):
        arguments = com_arguments([unwrap(a) for a in [MergeTo]])
        self.com_object.Merge(*arguments)

    def merge(self, MergeTo=None):
        """Alias for Merge"""
        arguments = [MergeTo]
        return self.Merge(*arguments)

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()

    def Split(self, NumRows=None, NumColumns=None):
        arguments = com_arguments([unwrap(a) for a in [NumRows, NumColumns]])
        self.com_object.Split(*arguments)

    def split(self, NumRows=None, NumColumns=None):
        """Alias for Split"""
        arguments = [NumRows, NumColumns]
        return self.Split(*arguments)


class CellRange:

    def __init__(self, cellrange=None):
        self.com_object= cellrange

    def __call__(self, item):
        return CellRange(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Cell(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Chart:

    def __init__(self, chart=None):
        self.com_object= chart

    @property
    def AlternativeText(self):
        return self.com_object.AlternativeText

    @AlternativeText.setter
    def AlternativeText(self, value):
        self.com_object.AlternativeText = value

    @property
    def alternativetext(self):
        """Alias for AlternativeText"""
        return self.AlternativeText

    @alternativetext.setter
    def alternativetext(self, value):
        """Alias for AlternativeText.setter"""
        self.AlternativeText = value

    @property
    def alternative_text(self):
        """Alias for AlternativeText"""
        return self.AlternativeText

    @alternative_text.setter
    def alternative_text(self, value):
        """Alias for AlternativeText.setter"""
        self.AlternativeText = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoScaling(self):
        return self.com_object.AutoScaling

    @AutoScaling.setter
    def AutoScaling(self, value):
        self.com_object.AutoScaling = value

    @property
    def autoscaling(self):
        """Alias for AutoScaling"""
        return self.AutoScaling

    @autoscaling.setter
    def autoscaling(self, value):
        """Alias for AutoScaling.setter"""
        self.AutoScaling = value

    @property
    def auto_scaling(self):
        """Alias for AutoScaling"""
        return self.AutoScaling

    @auto_scaling.setter
    def auto_scaling(self, value):
        """Alias for AutoScaling.setter"""
        self.AutoScaling = value

    @property
    def BackWall(self):
        return Walls(self.com_object.BackWall)

    @property
    def backwall(self):
        """Alias for BackWall"""
        return self.BackWall

    @property
    def back_wall(self):
        """Alias for BackWall"""
        return self.BackWall

    @property
    def BarShape(self):
        return XlBarShape(self.com_object.BarShape)

    @BarShape.setter
    def BarShape(self, value):
        self.com_object.BarShape = value

    @property
    def barshape(self):
        """Alias for BarShape"""
        return self.BarShape

    @barshape.setter
    def barshape(self, value):
        """Alias for BarShape.setter"""
        self.BarShape = value

    @property
    def bar_shape(self):
        """Alias for BarShape"""
        return self.BarShape

    @bar_shape.setter
    def bar_shape(self, value):
        """Alias for BarShape.setter"""
        self.BarShape = value

    @property
    def CategoryLabelLevel(self):
        return self.com_object.CategoryLabelLevel

    @CategoryLabelLevel.setter
    def CategoryLabelLevel(self, value):
        self.com_object.CategoryLabelLevel = value

    @property
    def categorylabellevel(self):
        """Alias for CategoryLabelLevel"""
        return self.CategoryLabelLevel

    @categorylabellevel.setter
    def categorylabellevel(self, value):
        """Alias for CategoryLabelLevel.setter"""
        self.CategoryLabelLevel = value

    @property
    def category_label_level(self):
        """Alias for CategoryLabelLevel"""
        return self.CategoryLabelLevel

    @category_label_level.setter
    def category_label_level(self, value):
        """Alias for CategoryLabelLevel.setter"""
        self.CategoryLabelLevel = value

    @property
    def ChartArea(self):
        return ChartArea(self.com_object.ChartArea)

    @property
    def chartarea(self):
        """Alias for ChartArea"""
        return self.ChartArea

    @property
    def chart_area(self):
        """Alias for ChartArea"""
        return self.ChartArea

    @property
    def ChartColor(self):
        return self.com_object.ChartColor

    @ChartColor.setter
    def ChartColor(self, value):
        self.com_object.ChartColor = value

    @property
    def chartcolor(self):
        """Alias for ChartColor"""
        return self.ChartColor

    @chartcolor.setter
    def chartcolor(self, value):
        """Alias for ChartColor.setter"""
        self.ChartColor = value

    @property
    def chart_color(self):
        """Alias for ChartColor"""
        return self.ChartColor

    @chart_color.setter
    def chart_color(self, value):
        """Alias for ChartColor.setter"""
        self.ChartColor = value

    @property
    def ChartData(self):
        return ChartData(self.com_object.ChartData)

    @property
    def chartdata(self):
        """Alias for ChartData"""
        return self.ChartData

    @property
    def chart_data(self):
        """Alias for ChartData"""
        return self.ChartData

    @property
    def ChartStyle(self):
        return self.com_object.ChartStyle

    @ChartStyle.setter
    def ChartStyle(self, value):
        self.com_object.ChartStyle = value

    @property
    def chartstyle(self):
        """Alias for ChartStyle"""
        return self.ChartStyle

    @chartstyle.setter
    def chartstyle(self, value):
        """Alias for ChartStyle.setter"""
        self.ChartStyle = value

    @property
    def chart_style(self):
        """Alias for ChartStyle"""
        return self.ChartStyle

    @chart_style.setter
    def chart_style(self, value):
        """Alias for ChartStyle.setter"""
        self.ChartStyle = value

    @property
    def ChartTitle(self):
        return ChartTitle(self.com_object.ChartTitle)

    @property
    def charttitle(self):
        """Alias for ChartTitle"""
        return self.ChartTitle

    @property
    def chart_title(self):
        """Alias for ChartTitle"""
        return self.ChartTitle

    @property
    def ChartType(self):
        return self.com_object.ChartType

    @ChartType.setter
    def ChartType(self, value):
        self.com_object.ChartType = value

    @property
    def charttype(self):
        """Alias for ChartType"""
        return self.ChartType

    @charttype.setter
    def charttype(self, value):
        """Alias for ChartType.setter"""
        self.ChartType = value

    @property
    def chart_type(self):
        """Alias for ChartType"""
        return self.ChartType

    @chart_type.setter
    def chart_type(self, value):
        """Alias for ChartType.setter"""
        self.ChartType = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DataTable(self):
        return DataTable(self.com_object.DataTable)

    @property
    def datatable(self):
        """Alias for DataTable"""
        return self.DataTable

    @property
    def data_table(self):
        """Alias for DataTable"""
        return self.DataTable

    @property
    def DepthPercent(self):
        return self.com_object.DepthPercent

    @DepthPercent.setter
    def DepthPercent(self, value):
        self.com_object.DepthPercent = value

    @property
    def depthpercent(self):
        """Alias for DepthPercent"""
        return self.DepthPercent

    @depthpercent.setter
    def depthpercent(self, value):
        """Alias for DepthPercent.setter"""
        self.DepthPercent = value

    @property
    def depth_percent(self):
        """Alias for DepthPercent"""
        return self.DepthPercent

    @depth_percent.setter
    def depth_percent(self, value):
        """Alias for DepthPercent.setter"""
        self.DepthPercent = value

    @property
    def DisplayBlanksAs(self):
        return XlDisplayBlanksAs(self.com_object.DisplayBlanksAs)

    @DisplayBlanksAs.setter
    def DisplayBlanksAs(self, value):
        self.com_object.DisplayBlanksAs = value

    @property
    def displayblanksas(self):
        """Alias for DisplayBlanksAs"""
        return self.DisplayBlanksAs

    @displayblanksas.setter
    def displayblanksas(self, value):
        """Alias for DisplayBlanksAs.setter"""
        self.DisplayBlanksAs = value

    @property
    def display_blanks_as(self):
        """Alias for DisplayBlanksAs"""
        return self.DisplayBlanksAs

    @display_blanks_as.setter
    def display_blanks_as(self, value):
        """Alias for DisplayBlanksAs.setter"""
        self.DisplayBlanksAs = value

    @property
    def Elevation(self):
        return self.com_object.Elevation

    @Elevation.setter
    def Elevation(self, value):
        self.com_object.Elevation = value

    @property
    def elevation(self):
        """Alias for Elevation"""
        return self.Elevation

    @elevation.setter
    def elevation(self, value):
        """Alias for Elevation.setter"""
        self.Elevation = value

    @property
    def Floor(self):
        return Floor(self.com_object.Floor)

    @property
    def floor(self):
        """Alias for Floor"""
        return self.Floor

    @property
    def Format(self):
        return self.com_object.Format

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def GapDepth(self):
        return self.com_object.GapDepth

    @GapDepth.setter
    def GapDepth(self, value):
        self.com_object.GapDepth = value

    @property
    def gapdepth(self):
        """Alias for GapDepth"""
        return self.GapDepth

    @gapdepth.setter
    def gapdepth(self, value):
        """Alias for GapDepth.setter"""
        self.GapDepth = value

    @property
    def gap_depth(self):
        """Alias for GapDepth"""
        return self.GapDepth

    @gap_depth.setter
    def gap_depth(self, value):
        """Alias for GapDepth.setter"""
        self.GapDepth = value

    @property
    def HasAxis(self):
        return self.com_object.HasAxis

    @HasAxis.setter
    def HasAxis(self, value):
        self.com_object.HasAxis = value

    @property
    def hasaxis(self):
        """Alias for HasAxis"""
        return self.HasAxis

    @hasaxis.setter
    def hasaxis(self, value):
        """Alias for HasAxis.setter"""
        self.HasAxis = value

    @property
    def has_axis(self):
        """Alias for HasAxis"""
        return self.HasAxis

    @has_axis.setter
    def has_axis(self, value):
        """Alias for HasAxis.setter"""
        self.HasAxis = value

    @property
    def HasDataTable(self):
        return self.com_object.HasDataTable

    @HasDataTable.setter
    def HasDataTable(self, value):
        self.com_object.HasDataTable = value

    @property
    def hasdatatable(self):
        """Alias for HasDataTable"""
        return self.HasDataTable

    @hasdatatable.setter
    def hasdatatable(self, value):
        """Alias for HasDataTable.setter"""
        self.HasDataTable = value

    @property
    def has_data_table(self):
        """Alias for HasDataTable"""
        return self.HasDataTable

    @has_data_table.setter
    def has_data_table(self, value):
        """Alias for HasDataTable.setter"""
        self.HasDataTable = value

    @property
    def HasLegend(self):
        return self.com_object.HasLegend

    @HasLegend.setter
    def HasLegend(self, value):
        self.com_object.HasLegend = value

    @property
    def haslegend(self):
        """Alias for HasLegend"""
        return self.HasLegend

    @haslegend.setter
    def haslegend(self, value):
        """Alias for HasLegend.setter"""
        self.HasLegend = value

    @property
    def has_legend(self):
        """Alias for HasLegend"""
        return self.HasLegend

    @has_legend.setter
    def has_legend(self, value):
        """Alias for HasLegend.setter"""
        self.HasLegend = value

    @property
    def HasTitle(self):
        return self.com_object.HasTitle

    @HasTitle.setter
    def HasTitle(self, value):
        self.com_object.HasTitle = value

    @property
    def hastitle(self):
        """Alias for HasTitle"""
        return self.HasTitle

    @hastitle.setter
    def hastitle(self, value):
        """Alias for HasTitle.setter"""
        self.HasTitle = value

    @property
    def has_title(self):
        """Alias for HasTitle"""
        return self.HasTitle

    @has_title.setter
    def has_title(self, value):
        """Alias for HasTitle.setter"""
        self.HasTitle = value

    @property
    def HeightPercent(self):
        return self.com_object.HeightPercent

    @HeightPercent.setter
    def HeightPercent(self, value):
        self.com_object.HeightPercent = value

    @property
    def heightpercent(self):
        """Alias for HeightPercent"""
        return self.HeightPercent

    @heightpercent.setter
    def heightpercent(self, value):
        """Alias for HeightPercent.setter"""
        self.HeightPercent = value

    @property
    def height_percent(self):
        """Alias for HeightPercent"""
        return self.HeightPercent

    @height_percent.setter
    def height_percent(self, value):
        """Alias for HeightPercent.setter"""
        self.HeightPercent = value

    @property
    def Legend(self):
        return Legend(self.com_object.Legend)

    @property
    def legend(self):
        """Alias for Legend"""
        return self.Legend

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Perspective(self):
        return self.com_object.Perspective

    @Perspective.setter
    def Perspective(self, value):
        self.com_object.Perspective = value

    @property
    def perspective(self):
        """Alias for Perspective"""
        return self.Perspective

    @perspective.setter
    def perspective(self, value):
        """Alias for Perspective.setter"""
        self.Perspective = value

    @property
    def PlotArea(self):
        return PlotArea(self.com_object.PlotArea)

    @property
    def plotarea(self):
        """Alias for PlotArea"""
        return self.PlotArea

    @property
    def plot_area(self):
        """Alias for PlotArea"""
        return self.PlotArea

    @property
    def PlotBy(self):
        return self.com_object.PlotBy

    @PlotBy.setter
    def PlotBy(self, value):
        self.com_object.PlotBy = value

    @property
    def plotby(self):
        """Alias for PlotBy"""
        return self.PlotBy

    @plotby.setter
    def plotby(self, value):
        """Alias for PlotBy.setter"""
        self.PlotBy = value

    @property
    def plot_by(self):
        """Alias for PlotBy"""
        return self.PlotBy

    @plot_by.setter
    def plot_by(self, value):
        """Alias for PlotBy.setter"""
        self.PlotBy = value

    @property
    def PlotVisibleOnly(self):
        return self.com_object.PlotVisibleOnly

    @PlotVisibleOnly.setter
    def PlotVisibleOnly(self, value):
        self.com_object.PlotVisibleOnly = value

    @property
    def plotvisibleonly(self):
        """Alias for PlotVisibleOnly"""
        return self.PlotVisibleOnly

    @plotvisibleonly.setter
    def plotvisibleonly(self, value):
        """Alias for PlotVisibleOnly.setter"""
        self.PlotVisibleOnly = value

    @property
    def plot_visible_only(self):
        """Alias for PlotVisibleOnly"""
        return self.PlotVisibleOnly

    @plot_visible_only.setter
    def plot_visible_only(self, value):
        """Alias for PlotVisibleOnly.setter"""
        self.PlotVisibleOnly = value

    @property
    def RightAngleAxes(self):
        return self.com_object.RightAngleAxes

    @RightAngleAxes.setter
    def RightAngleAxes(self, value):
        self.com_object.RightAngleAxes = value

    @property
    def rightangleaxes(self):
        """Alias for RightAngleAxes"""
        return self.RightAngleAxes

    @rightangleaxes.setter
    def rightangleaxes(self, value):
        """Alias for RightAngleAxes.setter"""
        self.RightAngleAxes = value

    @property
    def right_angle_axes(self):
        """Alias for RightAngleAxes"""
        return self.RightAngleAxes

    @right_angle_axes.setter
    def right_angle_axes(self, value):
        """Alias for RightAngleAxes.setter"""
        self.RightAngleAxes = value

    @property
    def Rotation(self):
        return self.com_object.Rotation

    @Rotation.setter
    def Rotation(self, value):
        self.com_object.Rotation = value

    @property
    def rotation(self):
        """Alias for Rotation"""
        return self.Rotation

    @rotation.setter
    def rotation(self, value):
        """Alias for Rotation.setter"""
        self.Rotation = value

    @property
    def SeriesNameLevel(self):
        return self.com_object.SeriesNameLevel

    @SeriesNameLevel.setter
    def SeriesNameLevel(self, value):
        self.com_object.SeriesNameLevel = value

    @property
    def seriesnamelevel(self):
        """Alias for SeriesNameLevel"""
        return self.SeriesNameLevel

    @seriesnamelevel.setter
    def seriesnamelevel(self, value):
        """Alias for SeriesNameLevel.setter"""
        self.SeriesNameLevel = value

    @property
    def series_name_level(self):
        """Alias for SeriesNameLevel"""
        return self.SeriesNameLevel

    @series_name_level.setter
    def series_name_level(self, value):
        """Alias for SeriesNameLevel.setter"""
        self.SeriesNameLevel = value

    @property
    def Shapes(self):
        return Shapes(self.com_object.Shapes)

    @property
    def shapes(self):
        """Alias for Shapes"""
        return self.Shapes

    @property
    def ShowAllFieldButtons(self):
        return self.com_object.ShowAllFieldButtons

    @ShowAllFieldButtons.setter
    def ShowAllFieldButtons(self, value):
        self.com_object.ShowAllFieldButtons = value

    @property
    def showallfieldbuttons(self):
        """Alias for ShowAllFieldButtons"""
        return self.ShowAllFieldButtons

    @showallfieldbuttons.setter
    def showallfieldbuttons(self, value):
        """Alias for ShowAllFieldButtons.setter"""
        self.ShowAllFieldButtons = value

    @property
    def show_all_field_buttons(self):
        """Alias for ShowAllFieldButtons"""
        return self.ShowAllFieldButtons

    @show_all_field_buttons.setter
    def show_all_field_buttons(self, value):
        """Alias for ShowAllFieldButtons.setter"""
        self.ShowAllFieldButtons = value

    @property
    def ShowAxisFieldButtons(self):
        return self.com_object.ShowAxisFieldButtons

    @ShowAxisFieldButtons.setter
    def ShowAxisFieldButtons(self, value):
        self.com_object.ShowAxisFieldButtons = value

    @property
    def showaxisfieldbuttons(self):
        """Alias for ShowAxisFieldButtons"""
        return self.ShowAxisFieldButtons

    @showaxisfieldbuttons.setter
    def showaxisfieldbuttons(self, value):
        """Alias for ShowAxisFieldButtons.setter"""
        self.ShowAxisFieldButtons = value

    @property
    def show_axis_field_buttons(self):
        """Alias for ShowAxisFieldButtons"""
        return self.ShowAxisFieldButtons

    @show_axis_field_buttons.setter
    def show_axis_field_buttons(self, value):
        """Alias for ShowAxisFieldButtons.setter"""
        self.ShowAxisFieldButtons = value

    @property
    def ShowDataLabelsOverMaximum(self):
        return self.com_object.ShowDataLabelsOverMaximum

    @ShowDataLabelsOverMaximum.setter
    def ShowDataLabelsOverMaximum(self, value):
        self.com_object.ShowDataLabelsOverMaximum = value

    @property
    def showdatalabelsovermaximum(self):
        """Alias for ShowDataLabelsOverMaximum"""
        return self.ShowDataLabelsOverMaximum

    @showdatalabelsovermaximum.setter
    def showdatalabelsovermaximum(self, value):
        """Alias for ShowDataLabelsOverMaximum.setter"""
        self.ShowDataLabelsOverMaximum = value

    @property
    def show_data_labels_over_maximum(self):
        """Alias for ShowDataLabelsOverMaximum"""
        return self.ShowDataLabelsOverMaximum

    @show_data_labels_over_maximum.setter
    def show_data_labels_over_maximum(self, value):
        """Alias for ShowDataLabelsOverMaximum.setter"""
        self.ShowDataLabelsOverMaximum = value

    @property
    def ShowLegendFieldButtons(self):
        return self.com_object.ShowLegendFieldButtons

    @ShowLegendFieldButtons.setter
    def ShowLegendFieldButtons(self, value):
        self.com_object.ShowLegendFieldButtons = value

    @property
    def showlegendfieldbuttons(self):
        """Alias for ShowLegendFieldButtons"""
        return self.ShowLegendFieldButtons

    @showlegendfieldbuttons.setter
    def showlegendfieldbuttons(self, value):
        """Alias for ShowLegendFieldButtons.setter"""
        self.ShowLegendFieldButtons = value

    @property
    def show_legend_field_buttons(self):
        """Alias for ShowLegendFieldButtons"""
        return self.ShowLegendFieldButtons

    @show_legend_field_buttons.setter
    def show_legend_field_buttons(self, value):
        """Alias for ShowLegendFieldButtons.setter"""
        self.ShowLegendFieldButtons = value

    @property
    def ShowReportFilterFieldButtons(self):
        return self.com_object.ShowReportFilterFieldButtons

    @ShowReportFilterFieldButtons.setter
    def ShowReportFilterFieldButtons(self, value):
        self.com_object.ShowReportFilterFieldButtons = value

    @property
    def showreportfilterfieldbuttons(self):
        """Alias for ShowReportFilterFieldButtons"""
        return self.ShowReportFilterFieldButtons

    @showreportfilterfieldbuttons.setter
    def showreportfilterfieldbuttons(self, value):
        """Alias for ShowReportFilterFieldButtons.setter"""
        self.ShowReportFilterFieldButtons = value

    @property
    def show_report_filter_field_buttons(self):
        """Alias for ShowReportFilterFieldButtons"""
        return self.ShowReportFilterFieldButtons

    @show_report_filter_field_buttons.setter
    def show_report_filter_field_buttons(self, value):
        """Alias for ShowReportFilterFieldButtons.setter"""
        self.ShowReportFilterFieldButtons = value

    @property
    def ShowValueFieldButtons(self):
        return self.com_object.ShowValueFieldButtons

    @ShowValueFieldButtons.setter
    def ShowValueFieldButtons(self, value):
        self.com_object.ShowValueFieldButtons = value

    @property
    def showvaluefieldbuttons(self):
        """Alias for ShowValueFieldButtons"""
        return self.ShowValueFieldButtons

    @showvaluefieldbuttons.setter
    def showvaluefieldbuttons(self, value):
        """Alias for ShowValueFieldButtons.setter"""
        self.ShowValueFieldButtons = value

    @property
    def show_value_field_buttons(self):
        """Alias for ShowValueFieldButtons"""
        return self.ShowValueFieldButtons

    @show_value_field_buttons.setter
    def show_value_field_buttons(self, value):
        """Alias for ShowValueFieldButtons.setter"""
        self.ShowValueFieldButtons = value

    @property
    def SideWall(self):
        return Walls(self.com_object.SideWall)

    @property
    def sidewall(self):
        """Alias for SideWall"""
        return self.SideWall

    @property
    def side_wall(self):
        """Alias for SideWall"""
        return self.SideWall

    @property
    def Title(self):
        return self.com_object.Title

    @Title.setter
    def Title(self, value):
        self.com_object.Title = value

    @property
    def title(self):
        """Alias for Title"""
        return self.Title

    @title.setter
    def title(self, value):
        """Alias for Title.setter"""
        self.Title = value

    @property
    def Walls(self):
        return Walls(self.com_object.Walls)

    @property
    def walls(self):
        """Alias for Walls"""
        return self.Walls

    def ApplyChartTemplate(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        self.com_object.ApplyChartTemplate(*arguments)

    def applycharttemplate(self, FileName=None):
        """Alias for ApplyChartTemplate"""
        arguments = [FileName]
        return self.ApplyChartTemplate(*arguments)

    def apply_chart_template(self, FileName=None):
        """Alias for ApplyChartTemplate"""
        arguments = [FileName]
        return self.ApplyChartTemplate(*arguments)

    def ApplyDataLabels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        arguments = com_arguments([unwrap(a) for a in [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]])
        self.com_object.ApplyDataLabels(*arguments)

    def applydatalabels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        """Alias for ApplyDataLabels"""
        arguments = [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]
        return self.ApplyDataLabels(*arguments)

    def apply_data_labels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        """Alias for ApplyDataLabels"""
        arguments = [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]
        return self.ApplyDataLabels(*arguments)

    def ApplyLayout(self, Layout=None, ChartType=None):
        arguments = com_arguments([unwrap(a) for a in [Layout, ChartType]])
        self.com_object.ApplyLayout(*arguments)

    def applylayout(self, Layout=None, ChartType=None):
        """Alias for ApplyLayout"""
        arguments = [Layout, ChartType]
        return self.ApplyLayout(*arguments)

    def apply_layout(self, Layout=None, ChartType=None):
        """Alias for ApplyLayout"""
        arguments = [Layout, ChartType]
        return self.ApplyLayout(*arguments)

    def Axes(self, Type=None, AxisGroup=None):
        arguments = com_arguments([unwrap(a) for a in [Type, AxisGroup]])
        return self.com_object.Axes(*arguments)

    def axes(self, Type=None, AxisGroup=None):
        """Alias for Axes"""
        arguments = [Type, AxisGroup]
        return self.Axes(*arguments)

    def ChartGroups(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.ChartGroups(*arguments)

    def chartgroups(self, Index=None):
        """Alias for ChartGroups"""
        arguments = [Index]
        return self.ChartGroups(*arguments)

    def chart_groups(self, Index=None):
        """Alias for ChartGroups"""
        arguments = [Index]
        return self.ChartGroups(*arguments)

    def ChartWizard(self, Source=None, Gallery=None, Format=None, PlotBy=None, CategoryLabels=None, SeriesLabels=None, HasLegend=None, Title=None, CategoryTitle=None, ValueTitle=None, ExtraTitle=None):
        arguments = com_arguments([unwrap(a) for a in [Source, Gallery, Format, PlotBy, CategoryLabels, SeriesLabels, HasLegend, Title, CategoryTitle, ValueTitle, ExtraTitle]])
        self.com_object.ChartWizard(*arguments)

    def chartwizard(self, Source=None, Gallery=None, Format=None, PlotBy=None, CategoryLabels=None, SeriesLabels=None, HasLegend=None, Title=None, CategoryTitle=None, ValueTitle=None, ExtraTitle=None):
        """Alias for ChartWizard"""
        arguments = [Source, Gallery, Format, PlotBy, CategoryLabels, SeriesLabels, HasLegend, Title, CategoryTitle, ValueTitle, ExtraTitle]
        return self.ChartWizard(*arguments)

    def chart_wizard(self, Source=None, Gallery=None, Format=None, PlotBy=None, CategoryLabels=None, SeriesLabels=None, HasLegend=None, Title=None, CategoryTitle=None, ValueTitle=None, ExtraTitle=None):
        """Alias for ChartWizard"""
        arguments = [Source, Gallery, Format, PlotBy, CategoryLabels, SeriesLabels, HasLegend, Title, CategoryTitle, ValueTitle, ExtraTitle]
        return self.ChartWizard(*arguments)

    def ClearToMatchColorStyle(self):
        return self.com_object.ClearToMatchColorStyle()

    def cleartomatchcolorstyle(self):
        """Alias for ClearToMatchColorStyle"""
        return self.ClearToMatchColorStyle()

    def clear_to_match_color_style(self):
        """Alias for ClearToMatchColorStyle"""
        return self.ClearToMatchColorStyle()

    def ClearToMatchStyle(self):
        self.com_object.ClearToMatchStyle()

    def cleartomatchstyle(self):
        """Alias for ClearToMatchStyle"""
        return self.ClearToMatchStyle()

    def clear_to_match_style(self):
        """Alias for ClearToMatchStyle"""
        return self.ClearToMatchStyle()

    def Copy(self, Before=None, After=None):
        arguments = com_arguments([unwrap(a) for a in [Before, After]])
        self.com_object.Copy(*arguments)

    def copy(self, Before=None, After=None):
        """Alias for Copy"""
        arguments = [Before, After]
        return self.Copy(*arguments)

    def CopyPicture(self, Appearance=None, Format=None, Size=None):
        arguments = com_arguments([unwrap(a) for a in [Appearance, Format, Size]])
        self.com_object.CopyPicture(*arguments)

    def copypicture(self, Appearance=None, Format=None, Size=None):
        """Alias for CopyPicture"""
        arguments = [Appearance, Format, Size]
        return self.CopyPicture(*arguments)

    def copy_picture(self, Appearance=None, Format=None, Size=None):
        """Alias for CopyPicture"""
        arguments = [Appearance, Format, Size]
        return self.CopyPicture(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Export(self, FileName=None, FilterName=None, Interactive=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, FilterName, Interactive]])
        self.com_object.Export(*arguments)

    def export(self, FileName=None, FilterName=None, Interactive=None):
        """Alias for Export"""
        arguments = [FileName, FilterName, Interactive]
        return self.Export(*arguments)

    def FullSeriesCollection(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.FullSeriesCollection(*arguments)

    def fullseriescollection(self, Index=None):
        """Alias for FullSeriesCollection"""
        arguments = [Index]
        return self.FullSeriesCollection(*arguments)

    def full_series_collection(self, Index=None):
        """Alias for FullSeriesCollection"""
        arguments = [Index]
        return self.FullSeriesCollection(*arguments)

    def GetChartElement(self, x=None, y=None, ElementID=None, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [x, y, ElementID, Arg1, Arg2]])
        self.com_object.GetChartElement(*arguments)

    def getchartelement(self, x=None, y=None, ElementID=None, Arg1=None, Arg2=None):
        """Alias for GetChartElement"""
        arguments = [x, y, ElementID, Arg1, Arg2]
        return self.GetChartElement(*arguments)

    def get_chart_element(self, x=None, y=None, ElementID=None, Arg1=None, Arg2=None):
        """Alias for GetChartElement"""
        arguments = [x, y, ElementID, Arg1, Arg2]
        return self.GetChartElement(*arguments)

    def Paste(self, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Type]])
        self.com_object.Paste(*arguments)

    def paste(self, Type=None):
        """Alias for Paste"""
        arguments = [Type]
        return self.Paste(*arguments)

    def Refresh(self):
        self.com_object.Refresh()

    def refresh(self):
        """Alias for Refresh"""
        return self.Refresh()

    def SaveChartTemplate(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        self.com_object.SaveChartTemplate(*arguments)

    def savecharttemplate(self, FileName=None):
        """Alias for SaveChartTemplate"""
        arguments = [FileName]
        return self.SaveChartTemplate(*arguments)

    def save_chart_template(self, FileName=None):
        """Alias for SaveChartTemplate"""
        arguments = [FileName]
        return self.SaveChartTemplate(*arguments)

    def Select(self, Replace=None):
        arguments = com_arguments([unwrap(a) for a in [Replace]])
        self.com_object.Select(*arguments)

    def select(self, Replace=None):
        """Alias for Select"""
        arguments = [Replace]
        return self.Select(*arguments)

    def SeriesCollection(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return SeriesCollection(self.com_object.SeriesCollection(*arguments))

    def seriescollection(self, Index=None):
        """Alias for SeriesCollection"""
        arguments = [Index]
        return self.SeriesCollection(*arguments)

    def series_collection(self, Index=None):
        """Alias for SeriesCollection"""
        arguments = [Index]
        return self.SeriesCollection(*arguments)

    def SetBackgroundPicture(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        self.com_object.SetBackgroundPicture(*arguments)

    def setbackgroundpicture(self, FileName=None):
        """Alias for SetBackgroundPicture"""
        arguments = [FileName]
        return self.SetBackgroundPicture(*arguments)

    def set_background_picture(self, FileName=None):
        """Alias for SetBackgroundPicture"""
        arguments = [FileName]
        return self.SetBackgroundPicture(*arguments)

    def SetDefaultChart(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        self.com_object.SetDefaultChart(*arguments)

    def setdefaultchart(self, Name=None):
        """Alias for SetDefaultChart"""
        arguments = [Name]
        return self.SetDefaultChart(*arguments)

    def set_default_chart(self, Name=None):
        """Alias for SetDefaultChart"""
        arguments = [Name]
        return self.SetDefaultChart(*arguments)

    def SetElement(self, Element=None):
        arguments = com_arguments([unwrap(a) for a in [Element]])
        self.com_object.SetElement(*arguments)

    def setelement(self, Element=None):
        """Alias for SetElement"""
        arguments = [Element]
        return self.SetElement(*arguments)

    def set_element(self, Element=None):
        """Alias for SetElement"""
        arguments = [Element]
        return self.SetElement(*arguments)

    def SetSourceData(self, Source=None, PlotBy=None):
        arguments = com_arguments([unwrap(a) for a in [Source, PlotBy]])
        self.com_object.SetSourceData(*arguments)

    def setsourcedata(self, Source=None, PlotBy=None):
        """Alias for SetSourceData"""
        arguments = [Source, PlotBy]
        return self.SetSourceData(*arguments)

    def set_source_data(self, Source=None, PlotBy=None):
        """Alias for SetSourceData"""
        arguments = [Source, PlotBy]
        return self.SetSourceData(*arguments)


class ChartArea:

    def __init__(self, chartarea=None):
        self.com_object= chartarea

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Clear(self):
        self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()

    def ClearContents(self):
        self.com_object.ClearContents()

    def clearcontents(self):
        """Alias for ClearContents"""
        return self.ClearContents()

    def clear_contents(self):
        """Alias for ClearContents"""
        return self.ClearContents()

    def ClearFormats(self):
        self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class ChartBorder:

    def __init__(self, chartborder=None):
        self.com_object= chartborder

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Color(self):
        return self.com_object.Color

    @Color.setter
    def Color(self, value):
        self.com_object.Color = value

    @property
    def color(self):
        """Alias for Color"""
        return self.Color

    @color.setter
    def color(self, value):
        """Alias for Color.setter"""
        self.Color = value

    @property
    def ColorIndex(self):
        return self.com_object.ColorIndex

    @ColorIndex.setter
    def ColorIndex(self, value):
        self.com_object.ColorIndex = value

    @property
    def colorindex(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @colorindex.setter
    def colorindex(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def color_index(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @color_index.setter
    def color_index(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def LineStyle(self):
        return XlLineStyle(self.com_object.LineStyle)

    @LineStyle.setter
    def LineStyle(self, value):
        self.com_object.LineStyle = value

    @property
    def linestyle(self):
        """Alias for LineStyle"""
        return self.LineStyle

    @linestyle.setter
    def linestyle(self, value):
        """Alias for LineStyle.setter"""
        self.LineStyle = value

    @property
    def line_style(self):
        """Alias for LineStyle"""
        return self.LineStyle

    @line_style.setter
    def line_style(self, value):
        """Alias for LineStyle.setter"""
        self.LineStyle = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Weight(self):
        return XlBorderWeight(self.com_object.Weight)

    @Weight.setter
    def Weight(self, value):
        self.com_object.Weight = value

    @property
    def weight(self):
        """Alias for Weight"""
        return self.Weight

    @weight.setter
    def weight(self, value):
        """Alias for Weight.setter"""
        self.Weight = value


class ChartCategory:

    def __init__(self, chartcategory=None):
        self.com_object= chartcategory

    @property
    def IsFiltered(self):
        return self.com_object.IsFiltered

    @IsFiltered.setter
    def IsFiltered(self, value):
        self.com_object.IsFiltered = value

    @property
    def isfiltered(self):
        """Alias for IsFiltered"""
        return self.IsFiltered

    @isfiltered.setter
    def isfiltered(self, value):
        """Alias for IsFiltered.setter"""
        self.IsFiltered = value

    @property
    def is_filtered(self):
        """Alias for IsFiltered"""
        return self.IsFiltered

    @is_filtered.setter
    def is_filtered(self, value):
        """Alias for IsFiltered.setter"""
        self.IsFiltered = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class ChartCharacters:

    def __init__(self, chartcharacters=None):
        self.com_object= chartcharacters

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Caption(self):
        return self.com_object.Caption

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Font(self):
        return ChartFont(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PhoneticCharacters(self):
        return self.com_object.PhoneticCharacters

    @PhoneticCharacters.setter
    def PhoneticCharacters(self, value):
        self.com_object.PhoneticCharacters = value

    @property
    def phoneticcharacters(self):
        """Alias for PhoneticCharacters"""
        return self.PhoneticCharacters

    @phoneticcharacters.setter
    def phoneticcharacters(self, value):
        """Alias for PhoneticCharacters.setter"""
        self.PhoneticCharacters = value

    @property
    def phonetic_characters(self):
        """Alias for PhoneticCharacters"""
        return self.PhoneticCharacters

    @phonetic_characters.setter
    def phonetic_characters(self, value):
        """Alias for PhoneticCharacters.setter"""
        self.PhoneticCharacters = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Insert(self, String=None):
        arguments = com_arguments([unwrap(a) for a in [String]])
        self.com_object.Insert(*arguments)

    def insert(self, String=None):
        """Alias for Insert"""
        arguments = [String]
        return self.Insert(*arguments)


class ChartData:

    def __init__(self, chartdata=None):
        self.com_object= chartdata

    @property
    def IsLinked(self):
        return self.com_object.IsLinked

    @property
    def islinked(self):
        """Alias for IsLinked"""
        return self.IsLinked

    @property
    def is_linked(self):
        """Alias for IsLinked"""
        return self.IsLinked

    @property
    def Workbook(self):
        return self.com_object.Workbook

    @property
    def workbook(self):
        """Alias for Workbook"""
        return self.Workbook

    def Activate(self):
        self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()

    def ActivateChartDataWindow(self):
        return self.com_object.ActivateChartDataWindow()

    def activatechartdatawindow(self):
        """Alias for ActivateChartDataWindow"""
        return self.ActivateChartDataWindow()

    def activate_chart_data_window(self):
        """Alias for ActivateChartDataWindow"""
        return self.ActivateChartDataWindow()

    def BreakLink(self):
        self.com_object.BreakLink()

    def breaklink(self):
        """Alias for BreakLink"""
        return self.BreakLink()

    def break_link(self):
        """Alias for BreakLink"""
        return self.BreakLink()


class ChartFont:

    def __init__(self, chartfont=None):
        self.com_object= chartfont

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Background(self):
        return XlBackground(self.com_object.Background)

    @Background.setter
    def Background(self, value):
        self.com_object.Background = value

    @property
    def background(self):
        """Alias for Background"""
        return self.Background

    @background.setter
    def background(self, value):
        """Alias for Background.setter"""
        self.Background = value

    @property
    def Bold(self):
        return self.com_object.Bold

    @Bold.setter
    def Bold(self, value):
        self.com_object.Bold = value

    @property
    def bold(self):
        """Alias for Bold"""
        return self.Bold

    @bold.setter
    def bold(self, value):
        """Alias for Bold.setter"""
        self.Bold = value

    @property
    def Color(self):
        return self.com_object.Color

    @Color.setter
    def Color(self, value):
        self.com_object.Color = value

    @property
    def color(self):
        """Alias for Color"""
        return self.Color

    @color.setter
    def color(self, value):
        """Alias for Color.setter"""
        self.Color = value

    @property
    def ColorIndex(self):
        return self.com_object.ColorIndex

    @ColorIndex.setter
    def ColorIndex(self, value):
        self.com_object.ColorIndex = value

    @property
    def colorindex(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @colorindex.setter
    def colorindex(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def color_index(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @color_index.setter
    def color_index(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def FontStyle(self):
        return self.com_object.FontStyle

    @FontStyle.setter
    def FontStyle(self, value):
        self.com_object.FontStyle = value

    @property
    def fontstyle(self):
        """Alias for FontStyle"""
        return self.FontStyle

    @fontstyle.setter
    def fontstyle(self, value):
        """Alias for FontStyle.setter"""
        self.FontStyle = value

    @property
    def font_style(self):
        """Alias for FontStyle"""
        return self.FontStyle

    @font_style.setter
    def font_style(self, value):
        """Alias for FontStyle.setter"""
        self.FontStyle = value

    @property
    def Italic(self):
        return self.com_object.Italic

    @Italic.setter
    def Italic(self, value):
        self.com_object.Italic = value

    @property
    def italic(self):
        """Alias for Italic"""
        return self.Italic

    @italic.setter
    def italic(self, value):
        """Alias for Italic.setter"""
        self.Italic = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Size(self):
        return self.com_object.Size

    @Size.setter
    def Size(self, value):
        self.com_object.Size = value

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @size.setter
    def size(self, value):
        """Alias for Size.setter"""
        self.Size = value

    @property
    def Strikethrough(self):
        return self.com_object.Strikethrough

    @Strikethrough.setter
    def Strikethrough(self, value):
        self.com_object.Strikethrough = value

    @property
    def strikethrough(self):
        """Alias for Strikethrough"""
        return self.Strikethrough

    @strikethrough.setter
    def strikethrough(self, value):
        """Alias for Strikethrough.setter"""
        self.Strikethrough = value

    @property
    def Subscript(self):
        return self.com_object.Subscript

    @Subscript.setter
    def Subscript(self, value):
        self.com_object.Subscript = value

    @property
    def subscript(self):
        """Alias for Subscript"""
        return self.Subscript

    @subscript.setter
    def subscript(self, value):
        """Alias for Subscript.setter"""
        self.Subscript = value

    @property
    def Superscript(self):
        return self.com_object.Superscript

    @Superscript.setter
    def Superscript(self, value):
        self.com_object.Superscript = value

    @property
    def superscript(self):
        """Alias for Superscript"""
        return self.Superscript

    @superscript.setter
    def superscript(self, value):
        """Alias for Superscript.setter"""
        self.Superscript = value

    @property
    def Underline(self):
        return XlUnderlineStyle(self.com_object.Underline)

    @Underline.setter
    def Underline(self, value):
        self.com_object.Underline = value

    @property
    def underline(self):
        """Alias for Underline"""
        return self.Underline

    @underline.setter
    def underline(self, value):
        """Alias for Underline.setter"""
        self.Underline = value


class ChartFormat:

    def __init__(self, chartformat=None):
        self.com_object= chartformat

    @property
    def Adjustments(self):
        return self.com_object.Adjustments

    @property
    def adjustments(self):
        """Alias for Adjustments"""
        return self.Adjustments

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoShapeType(self):
        return self.com_object.AutoShapeType

    @AutoShapeType.setter
    def AutoShapeType(self, value):
        self.com_object.AutoShapeType = value

    @property
    def autoshapetype(self):
        """Alias for AutoShapeType"""
        return self.AutoShapeType

    @autoshapetype.setter
    def autoshapetype(self, value):
        """Alias for AutoShapeType.setter"""
        self.AutoShapeType = value

    @property
    def auto_shape_type(self):
        """Alias for AutoShapeType"""
        return self.AutoShapeType

    @auto_shape_type.setter
    def auto_shape_type(self, value):
        """Alias for AutoShapeType.setter"""
        self.AutoShapeType = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Fill(self):
        return FillFormat(self.com_object.Fill)

    @property
    def fill(self):
        """Alias for Fill"""
        return self.Fill

    @property
    def Glow(self):
        return self.com_object.Glow

    @property
    def glow(self):
        """Alias for Glow"""
        return self.Glow

    @property
    def Line(self):
        return LineFormat(self.com_object.Line)

    @property
    def line(self):
        """Alias for Line"""
        return self.Line

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PictureFormat(self):
        return PictureFormat(self.com_object.PictureFormat)

    @property
    def pictureformat(self):
        """Alias for PictureFormat"""
        return self.PictureFormat

    @property
    def picture_format(self):
        """Alias for PictureFormat"""
        return self.PictureFormat

    @property
    def Shadow(self):
        return ShadowFormat(self.com_object.Shadow)

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @property
    def SoftEdge(self):
        return self.com_object.SoftEdge

    @property
    def softedge(self):
        """Alias for SoftEdge"""
        return self.SoftEdge

    @property
    def soft_edge(self):
        """Alias for SoftEdge"""
        return self.SoftEdge

    @property
    def TextFrame2(self):
        return TextFrame2(self.com_object.TextFrame2)

    @property
    def textframe2(self):
        """Alias for TextFrame2"""
        return self.TextFrame2

    @property
    def text_frame2(self):
        """Alias for TextFrame2"""
        return self.TextFrame2

    @property
    def ThreeD(self):
        return ThreeDFormat(self.com_object.ThreeD)

    @property
    def threed(self):
        """Alias for ThreeD"""
        return self.ThreeD

    @property
    def three_d(self):
        """Alias for ThreeD"""
        return self.ThreeD


class ChartGroup:

    def __init__(self, chartgroup=None):
        self.com_object= chartgroup

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AxisGroup(self):
        return XlAxisGroup(self.com_object.AxisGroup)

    @AxisGroup.setter
    def AxisGroup(self, value):
        self.com_object.AxisGroup = value

    @property
    def axisgroup(self):
        """Alias for AxisGroup"""
        return self.AxisGroup

    @axisgroup.setter
    def axisgroup(self, value):
        """Alias for AxisGroup.setter"""
        self.AxisGroup = value

    @property
    def axis_group(self):
        """Alias for AxisGroup"""
        return self.AxisGroup

    @axis_group.setter
    def axis_group(self, value):
        """Alias for AxisGroup.setter"""
        self.AxisGroup = value

    @property
    def BinsCountValue(self):
        return self.com_object.BinsCountValue

    @BinsCountValue.setter
    def BinsCountValue(self, value):
        self.com_object.BinsCountValue = value

    @property
    def binscountvalue(self):
        """Alias for BinsCountValue"""
        return self.BinsCountValue

    @binscountvalue.setter
    def binscountvalue(self, value):
        """Alias for BinsCountValue.setter"""
        self.BinsCountValue = value

    @property
    def bins_count_value(self):
        """Alias for BinsCountValue"""
        return self.BinsCountValue

    @bins_count_value.setter
    def bins_count_value(self, value):
        """Alias for BinsCountValue.setter"""
        self.BinsCountValue = value

    @property
    def BinsOverflowEnabled(self):
        return self.com_object.BinsOverflowEnabled

    @BinsOverflowEnabled.setter
    def BinsOverflowEnabled(self, value):
        self.com_object.BinsOverflowEnabled = value

    @property
    def binsoverflowenabled(self):
        """Alias for BinsOverflowEnabled"""
        return self.BinsOverflowEnabled

    @binsoverflowenabled.setter
    def binsoverflowenabled(self, value):
        """Alias for BinsOverflowEnabled.setter"""
        self.BinsOverflowEnabled = value

    @property
    def bins_overflow_enabled(self):
        """Alias for BinsOverflowEnabled"""
        return self.BinsOverflowEnabled

    @bins_overflow_enabled.setter
    def bins_overflow_enabled(self, value):
        """Alias for BinsOverflowEnabled.setter"""
        self.BinsOverflowEnabled = value

    @property
    def BinsOverflowValue(self):
        return self.com_object.BinsOverflowValue

    @BinsOverflowValue.setter
    def BinsOverflowValue(self, value):
        self.com_object.BinsOverflowValue = value

    @property
    def binsoverflowvalue(self):
        """Alias for BinsOverflowValue"""
        return self.BinsOverflowValue

    @binsoverflowvalue.setter
    def binsoverflowvalue(self, value):
        """Alias for BinsOverflowValue.setter"""
        self.BinsOverflowValue = value

    @property
    def bins_overflow_value(self):
        """Alias for BinsOverflowValue"""
        return self.BinsOverflowValue

    @bins_overflow_value.setter
    def bins_overflow_value(self, value):
        """Alias for BinsOverflowValue.setter"""
        self.BinsOverflowValue = value

    @property
    def BinsType(self):
        return self.com_object.BinsType

    @BinsType.setter
    def BinsType(self, value):
        self.com_object.BinsType = value

    @property
    def binstype(self):
        """Alias for BinsType"""
        return self.BinsType

    @binstype.setter
    def binstype(self, value):
        """Alias for BinsType.setter"""
        self.BinsType = value

    @property
    def bins_type(self):
        """Alias for BinsType"""
        return self.BinsType

    @bins_type.setter
    def bins_type(self, value):
        """Alias for BinsType.setter"""
        self.BinsType = value

    @property
    def BinsUnderflowEnabled(self):
        return self.com_object.BinsUnderflowEnabled

    @BinsUnderflowEnabled.setter
    def BinsUnderflowEnabled(self, value):
        self.com_object.BinsUnderflowEnabled = value

    @property
    def binsunderflowenabled(self):
        """Alias for BinsUnderflowEnabled"""
        return self.BinsUnderflowEnabled

    @binsunderflowenabled.setter
    def binsunderflowenabled(self, value):
        """Alias for BinsUnderflowEnabled.setter"""
        self.BinsUnderflowEnabled = value

    @property
    def bins_underflow_enabled(self):
        """Alias for BinsUnderflowEnabled"""
        return self.BinsUnderflowEnabled

    @bins_underflow_enabled.setter
    def bins_underflow_enabled(self, value):
        """Alias for BinsUnderflowEnabled.setter"""
        self.BinsUnderflowEnabled = value

    @property
    def BinsUnderflowValue(self):
        return self.com_object.BinsUnderflowValue

    @BinsUnderflowValue.setter
    def BinsUnderflowValue(self, value):
        self.com_object.BinsUnderflowValue = value

    @property
    def binsunderflowvalue(self):
        """Alias for BinsUnderflowValue"""
        return self.BinsUnderflowValue

    @binsunderflowvalue.setter
    def binsunderflowvalue(self, value):
        """Alias for BinsUnderflowValue.setter"""
        self.BinsUnderflowValue = value

    @property
    def bins_underflow_value(self):
        """Alias for BinsUnderflowValue"""
        return self.BinsUnderflowValue

    @bins_underflow_value.setter
    def bins_underflow_value(self, value):
        """Alias for BinsUnderflowValue.setter"""
        self.BinsUnderflowValue = value

    @property
    def BinWidthValue(self):
        return self.com_object.BinWidthValue

    @BinWidthValue.setter
    def BinWidthValue(self, value):
        self.com_object.BinWidthValue = value

    @property
    def binwidthvalue(self):
        """Alias for BinWidthValue"""
        return self.BinWidthValue

    @binwidthvalue.setter
    def binwidthvalue(self, value):
        """Alias for BinWidthValue.setter"""
        self.BinWidthValue = value

    @property
    def bin_width_value(self):
        """Alias for BinWidthValue"""
        return self.BinWidthValue

    @bin_width_value.setter
    def bin_width_value(self, value):
        """Alias for BinWidthValue.setter"""
        self.BinWidthValue = value

    @property
    def BubbleScale(self):
        return self.com_object.BubbleScale

    @BubbleScale.setter
    def BubbleScale(self, value):
        self.com_object.BubbleScale = value

    @property
    def bubblescale(self):
        """Alias for BubbleScale"""
        return self.BubbleScale

    @bubblescale.setter
    def bubblescale(self, value):
        """Alias for BubbleScale.setter"""
        self.BubbleScale = value

    @property
    def bubble_scale(self):
        """Alias for BubbleScale"""
        return self.BubbleScale

    @bubble_scale.setter
    def bubble_scale(self, value):
        """Alias for BubbleScale.setter"""
        self.BubbleScale = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DoughnutHoleSize(self):
        return self.com_object.DoughnutHoleSize

    @DoughnutHoleSize.setter
    def DoughnutHoleSize(self, value):
        self.com_object.DoughnutHoleSize = value

    @property
    def doughnutholesize(self):
        """Alias for DoughnutHoleSize"""
        return self.DoughnutHoleSize

    @doughnutholesize.setter
    def doughnutholesize(self, value):
        """Alias for DoughnutHoleSize.setter"""
        self.DoughnutHoleSize = value

    @property
    def doughnut_hole_size(self):
        """Alias for DoughnutHoleSize"""
        return self.DoughnutHoleSize

    @doughnut_hole_size.setter
    def doughnut_hole_size(self, value):
        """Alias for DoughnutHoleSize.setter"""
        self.DoughnutHoleSize = value

    @property
    def DownBars(self):
        return DownBars(self.com_object.DownBars)

    @property
    def downbars(self):
        """Alias for DownBars"""
        return self.DownBars

    @property
    def down_bars(self):
        """Alias for DownBars"""
        return self.DownBars

    @property
    def DropLines(self):
        return DropLines(self.com_object.DropLines)

    @property
    def droplines(self):
        """Alias for DropLines"""
        return self.DropLines

    @property
    def drop_lines(self):
        """Alias for DropLines"""
        return self.DropLines

    @property
    def FirstSliceAngle(self):
        return self.com_object.FirstSliceAngle

    @FirstSliceAngle.setter
    def FirstSliceAngle(self, value):
        self.com_object.FirstSliceAngle = value

    @property
    def firstsliceangle(self):
        """Alias for FirstSliceAngle"""
        return self.FirstSliceAngle

    @firstsliceangle.setter
    def firstsliceangle(self, value):
        """Alias for FirstSliceAngle.setter"""
        self.FirstSliceAngle = value

    @property
    def first_slice_angle(self):
        """Alias for FirstSliceAngle"""
        return self.FirstSliceAngle

    @first_slice_angle.setter
    def first_slice_angle(self, value):
        """Alias for FirstSliceAngle.setter"""
        self.FirstSliceAngle = value

    @property
    def GapWidth(self):
        return self.com_object.GapWidth

    @GapWidth.setter
    def GapWidth(self, value):
        self.com_object.GapWidth = value

    @property
    def gapwidth(self):
        """Alias for GapWidth"""
        return self.GapWidth

    @gapwidth.setter
    def gapwidth(self, value):
        """Alias for GapWidth.setter"""
        self.GapWidth = value

    @property
    def gap_width(self):
        """Alias for GapWidth"""
        return self.GapWidth

    @gap_width.setter
    def gap_width(self, value):
        """Alias for GapWidth.setter"""
        self.GapWidth = value

    @property
    def Has3DShading(self):
        return self.com_object.Has3DShading

    @Has3DShading.setter
    def Has3DShading(self, value):
        self.com_object.Has3DShading = value

    @property
    def has3dshading(self):
        """Alias for Has3DShading"""
        return self.Has3DShading

    @has3dshading.setter
    def has3dshading(self, value):
        """Alias for Has3DShading.setter"""
        self.Has3DShading = value

    @property
    def has3_d_shading(self):
        """Alias for Has3DShading"""
        return self.Has3DShading

    @has3_d_shading.setter
    def has3_d_shading(self, value):
        """Alias for Has3DShading.setter"""
        self.Has3DShading = value

    @property
    def HasDropLines(self):
        return self.com_object.HasDropLines

    @HasDropLines.setter
    def HasDropLines(self, value):
        self.com_object.HasDropLines = value

    @property
    def hasdroplines(self):
        """Alias for HasDropLines"""
        return self.HasDropLines

    @hasdroplines.setter
    def hasdroplines(self, value):
        """Alias for HasDropLines.setter"""
        self.HasDropLines = value

    @property
    def has_drop_lines(self):
        """Alias for HasDropLines"""
        return self.HasDropLines

    @has_drop_lines.setter
    def has_drop_lines(self, value):
        """Alias for HasDropLines.setter"""
        self.HasDropLines = value

    @property
    def HasHiLoLines(self):
        return self.com_object.HasHiLoLines

    @HasHiLoLines.setter
    def HasHiLoLines(self, value):
        self.com_object.HasHiLoLines = value

    @property
    def hashilolines(self):
        """Alias for HasHiLoLines"""
        return self.HasHiLoLines

    @hashilolines.setter
    def hashilolines(self, value):
        """Alias for HasHiLoLines.setter"""
        self.HasHiLoLines = value

    @property
    def has_hi_lo_lines(self):
        """Alias for HasHiLoLines"""
        return self.HasHiLoLines

    @has_hi_lo_lines.setter
    def has_hi_lo_lines(self, value):
        """Alias for HasHiLoLines.setter"""
        self.HasHiLoLines = value

    @property
    def HasRadarAxisLabels(self):
        return self.com_object.HasRadarAxisLabels

    @HasRadarAxisLabels.setter
    def HasRadarAxisLabels(self, value):
        self.com_object.HasRadarAxisLabels = value

    @property
    def hasradaraxislabels(self):
        """Alias for HasRadarAxisLabels"""
        return self.HasRadarAxisLabels

    @hasradaraxislabels.setter
    def hasradaraxislabels(self, value):
        """Alias for HasRadarAxisLabels.setter"""
        self.HasRadarAxisLabels = value

    @property
    def has_radar_axis_labels(self):
        """Alias for HasRadarAxisLabels"""
        return self.HasRadarAxisLabels

    @has_radar_axis_labels.setter
    def has_radar_axis_labels(self, value):
        """Alias for HasRadarAxisLabels.setter"""
        self.HasRadarAxisLabels = value

    @property
    def HasSeriesLines(self):
        return self.com_object.HasSeriesLines

    @HasSeriesLines.setter
    def HasSeriesLines(self, value):
        self.com_object.HasSeriesLines = value

    @property
    def hasserieslines(self):
        """Alias for HasSeriesLines"""
        return self.HasSeriesLines

    @hasserieslines.setter
    def hasserieslines(self, value):
        """Alias for HasSeriesLines.setter"""
        self.HasSeriesLines = value

    @property
    def has_series_lines(self):
        """Alias for HasSeriesLines"""
        return self.HasSeriesLines

    @has_series_lines.setter
    def has_series_lines(self, value):
        """Alias for HasSeriesLines.setter"""
        self.HasSeriesLines = value

    @property
    def HasUpDownBars(self):
        return self.com_object.HasUpDownBars

    @HasUpDownBars.setter
    def HasUpDownBars(self, value):
        self.com_object.HasUpDownBars = value

    @property
    def hasupdownbars(self):
        """Alias for HasUpDownBars"""
        return self.HasUpDownBars

    @hasupdownbars.setter
    def hasupdownbars(self, value):
        """Alias for HasUpDownBars.setter"""
        self.HasUpDownBars = value

    @property
    def has_up_down_bars(self):
        """Alias for HasUpDownBars"""
        return self.HasUpDownBars

    @has_up_down_bars.setter
    def has_up_down_bars(self, value):
        """Alias for HasUpDownBars.setter"""
        self.HasUpDownBars = value

    @property
    def HiLoLines(self):
        return HiLoLines(self.com_object.HiLoLines)

    @property
    def hilolines(self):
        """Alias for HiLoLines"""
        return self.HiLoLines

    @property
    def hi_lo_lines(self):
        """Alias for HiLoLines"""
        return self.HiLoLines

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Overlap(self):
        return self.com_object.Overlap

    @Overlap.setter
    def Overlap(self, value):
        self.com_object.Overlap = value

    @property
    def overlap(self):
        """Alias for Overlap"""
        return self.Overlap

    @overlap.setter
    def overlap(self, value):
        """Alias for Overlap.setter"""
        self.Overlap = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RadarAxisLabels(self):
        return TickLabels(self.com_object.RadarAxisLabels)

    @property
    def radaraxislabels(self):
        """Alias for RadarAxisLabels"""
        return self.RadarAxisLabels

    @property
    def radar_axis_labels(self):
        """Alias for RadarAxisLabels"""
        return self.RadarAxisLabels

    @property
    def SecondPlotSize(self):
        return self.com_object.SecondPlotSize

    @SecondPlotSize.setter
    def SecondPlotSize(self, value):
        self.com_object.SecondPlotSize = value

    @property
    def secondplotsize(self):
        """Alias for SecondPlotSize"""
        return self.SecondPlotSize

    @secondplotsize.setter
    def secondplotsize(self, value):
        """Alias for SecondPlotSize.setter"""
        self.SecondPlotSize = value

    @property
    def second_plot_size(self):
        """Alias for SecondPlotSize"""
        return self.SecondPlotSize

    @second_plot_size.setter
    def second_plot_size(self, value):
        """Alias for SecondPlotSize.setter"""
        self.SecondPlotSize = value

    @property
    def SeriesLines(self):
        return SeriesLines(self.com_object.SeriesLines)

    @property
    def serieslines(self):
        """Alias for SeriesLines"""
        return self.SeriesLines

    @property
    def series_lines(self):
        """Alias for SeriesLines"""
        return self.SeriesLines

    @property
    def ShowNegativeBubbles(self):
        return self.com_object.ShowNegativeBubbles

    @ShowNegativeBubbles.setter
    def ShowNegativeBubbles(self, value):
        self.com_object.ShowNegativeBubbles = value

    @property
    def shownegativebubbles(self):
        """Alias for ShowNegativeBubbles"""
        return self.ShowNegativeBubbles

    @shownegativebubbles.setter
    def shownegativebubbles(self, value):
        """Alias for ShowNegativeBubbles.setter"""
        self.ShowNegativeBubbles = value

    @property
    def show_negative_bubbles(self):
        """Alias for ShowNegativeBubbles"""
        return self.ShowNegativeBubbles

    @show_negative_bubbles.setter
    def show_negative_bubbles(self, value):
        """Alias for ShowNegativeBubbles.setter"""
        self.ShowNegativeBubbles = value

    @property
    def SizeRepresents(self):
        return self.com_object.SizeRepresents

    @SizeRepresents.setter
    def SizeRepresents(self, value):
        self.com_object.SizeRepresents = value

    @property
    def sizerepresents(self):
        """Alias for SizeRepresents"""
        return self.SizeRepresents

    @sizerepresents.setter
    def sizerepresents(self, value):
        """Alias for SizeRepresents.setter"""
        self.SizeRepresents = value

    @property
    def size_represents(self):
        """Alias for SizeRepresents"""
        return self.SizeRepresents

    @size_represents.setter
    def size_represents(self, value):
        """Alias for SizeRepresents.setter"""
        self.SizeRepresents = value

    @property
    def SplitType(self):
        return XlChartSplitType(self.com_object.SplitType)

    @SplitType.setter
    def SplitType(self, value):
        self.com_object.SplitType = value

    @property
    def splittype(self):
        """Alias for SplitType"""
        return self.SplitType

    @splittype.setter
    def splittype(self, value):
        """Alias for SplitType.setter"""
        self.SplitType = value

    @property
    def split_type(self):
        """Alias for SplitType"""
        return self.SplitType

    @split_type.setter
    def split_type(self, value):
        """Alias for SplitType.setter"""
        self.SplitType = value

    @property
    def SplitValue(self):
        return self.com_object.SplitValue

    @SplitValue.setter
    def SplitValue(self, value):
        self.com_object.SplitValue = value

    @property
    def splitvalue(self):
        """Alias for SplitValue"""
        return self.SplitValue

    @splitvalue.setter
    def splitvalue(self, value):
        """Alias for SplitValue.setter"""
        self.SplitValue = value

    @property
    def split_value(self):
        """Alias for SplitValue"""
        return self.SplitValue

    @split_value.setter
    def split_value(self, value):
        """Alias for SplitValue.setter"""
        self.SplitValue = value

    @property
    def UpBars(self):
        return UpBars(self.com_object.UpBars)

    @property
    def upbars(self):
        """Alias for UpBars"""
        return self.UpBars

    @property
    def up_bars(self):
        """Alias for UpBars"""
        return self.UpBars

    @property
    def VaryByCategories(self):
        return self.com_object.VaryByCategories

    @VaryByCategories.setter
    def VaryByCategories(self, value):
        self.com_object.VaryByCategories = value

    @property
    def varybycategories(self):
        """Alias for VaryByCategories"""
        return self.VaryByCategories

    @varybycategories.setter
    def varybycategories(self, value):
        """Alias for VaryByCategories.setter"""
        self.VaryByCategories = value

    @property
    def vary_by_categories(self):
        """Alias for VaryByCategories"""
        return self.VaryByCategories

    @vary_by_categories.setter
    def vary_by_categories(self, value):
        """Alias for VaryByCategories.setter"""
        self.VaryByCategories = value

    def CategoryCollection(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.CategoryCollection(*arguments)

    def categorycollection(self, Index=None):
        """Alias for CategoryCollection"""
        arguments = [Index]
        return self.CategoryCollection(*arguments)

    def category_collection(self, Index=None):
        """Alias for CategoryCollection"""
        arguments = [Index]
        return self.CategoryCollection(*arguments)

    def FullCategoryCollection(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.FullCategoryCollection(*arguments)

    def fullcategorycollection(self, Index=None):
        """Alias for FullCategoryCollection"""
        arguments = [Index]
        return self.FullCategoryCollection(*arguments)

    def full_category_collection(self, Index=None):
        """Alias for FullCategoryCollection"""
        arguments = [Index]
        return self.FullCategoryCollection(*arguments)

    def SeriesCollection(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return SeriesCollection(self.com_object.SeriesCollection(*arguments))

    def seriescollection(self, Index=None):
        """Alias for SeriesCollection"""
        arguments = [Index]
        return self.SeriesCollection(*arguments)

    def series_collection(self, Index=None):
        """Alias for SeriesCollection"""
        arguments = [Index]
        return self.SeriesCollection(*arguments)


class ChartGroups:

    def __init__(self, chartgroups=None):
        self.com_object= chartgroups

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ChartGroup(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ChartTitle:

    def __init__(self, charttitle=None):
        self.com_object= charttitle

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    def Characters(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        if hasattr(self.com_object, "GetCharacters"):
            return ChartCharacters(self.com_object.GetCharacters(*arguments))
        else:
            return ChartCharacters(self.com_object.Characters(*arguments))

    def characters(self, Start=None, Length=None):
        """Alias for Characters"""
        arguments = [Start, Length]
        return self.Characters(*arguments)

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def FormulaLocal(self):
        return self.com_object.FormulaLocal

    @FormulaLocal.setter
    def FormulaLocal(self, value):
        self.com_object.FormulaLocal = value

    @property
    def formulalocal(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formulalocal.setter
    def formulalocal(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def formula_local(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formula_local.setter
    def formula_local(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def FormulaR1C1(self):
        return self.com_object.FormulaR1C1

    @FormulaR1C1.setter
    def FormulaR1C1(self, value):
        self.com_object.FormulaR1C1 = value

    @property
    def formular1c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formular1c1.setter
    def formular1c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def formula_r1_c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formula_r1_c1.setter
    def formula_r1_c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def FormulaR1C1Local(self):
        return self.com_object.FormulaR1C1Local

    @FormulaR1C1Local.setter
    def FormulaR1C1Local(self, value):
        self.com_object.FormulaR1C1Local = value

    @property
    def formular1c1local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formular1c1local.setter
    def formular1c1local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def formula_r1_c1_local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formula_r1_c1_local.setter
    def formula_r1_c1_local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HorizontalAlignment(self):
        return self.com_object.HorizontalAlignment

    @HorizontalAlignment.setter
    def HorizontalAlignment(self, value):
        self.com_object.HorizontalAlignment = value

    @property
    def horizontalalignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontalalignment.setter
    def horizontalalignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def horizontal_alignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def IncludeInLayout(self):
        return self.com_object.IncludeInLayout

    @IncludeInLayout.setter
    def IncludeInLayout(self, value):
        self.com_object.IncludeInLayout = value

    @property
    def includeinlayout(self):
        """Alias for IncludeInLayout"""
        return self.IncludeInLayout

    @includeinlayout.setter
    def includeinlayout(self, value):
        """Alias for IncludeInLayout.setter"""
        self.IncludeInLayout = value

    @property
    def include_in_layout(self):
        """Alias for IncludeInLayout"""
        return self.IncludeInLayout

    @include_in_layout.setter
    def include_in_layout(self, value):
        """Alias for IncludeInLayout.setter"""
        self.IncludeInLayout = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return XlChartElementPosition(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def ReadingOrder(self):
        return XlReadingOrder(self.com_object.ReadingOrder)

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def VerticalAlignment(self):
        return self.com_object.VerticalAlignment

    @VerticalAlignment.setter
    def VerticalAlignment(self, value):
        self.com_object.VerticalAlignment = value

    @property
    def verticalalignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @verticalalignment.setter
    def verticalalignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def vertical_alignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @vertical_alignment.setter
    def vertical_alignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Coauthoring:

    def __init__(self, coauthoring=None):
        self.com_object= coauthoring

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def FavorServerEditsDuringMerge(self):
        return self.com_object.FavorServerEditsDuringMerge

    @FavorServerEditsDuringMerge.setter
    def FavorServerEditsDuringMerge(self, value):
        self.com_object.FavorServerEditsDuringMerge = value

    @property
    def favorservereditsduringmerge(self):
        """Alias for FavorServerEditsDuringMerge"""
        return self.FavorServerEditsDuringMerge

    @favorservereditsduringmerge.setter
    def favorservereditsduringmerge(self, value):
        """Alias for FavorServerEditsDuringMerge.setter"""
        self.FavorServerEditsDuringMerge = value

    @property
    def favor_server_edits_during_merge(self):
        """Alias for FavorServerEditsDuringMerge"""
        return self.FavorServerEditsDuringMerge

    @favor_server_edits_during_merge.setter
    def favor_server_edits_during_merge(self, value):
        """Alias for FavorServerEditsDuringMerge.setter"""
        self.FavorServerEditsDuringMerge = value

    @property
    def MergeMode(self):
        return self.com_object.MergeMode

    @property
    def mergemode(self):
        """Alias for MergeMode"""
        return self.MergeMode

    @property
    def merge_mode(self):
        """Alias for MergeMode"""
        return self.MergeMode

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PendingUpdates(self):
        return self.com_object.PendingUpdates

    @property
    def pendingupdates(self):
        """Alias for PendingUpdates"""
        return self.PendingUpdates

    @property
    def pending_updates(self):
        """Alias for PendingUpdates"""
        return self.PendingUpdates

    def EndReview(self):
        self.com_object.EndReview()

    def endreview(self):
        """Alias for EndReview"""
        return self.EndReview()

    def end_review(self):
        """Alias for EndReview"""
        return self.EndReview()


class ColorEffect:

    def __init__(self, coloreffect=None):
        self.com_object= coloreffect

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def By(self):
        return ColorFormat(self.com_object.By)

    @property
    def by(self):
        """Alias for By"""
        return self.By

    @property
    def From(self):
        return self.com_object.From

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def To(self):
        return self.com_object.To

    @To.setter
    def To(self, value):
        self.com_object.To = value

    @property
    def to(self):
        """Alias for To"""
        return self.To

    @to.setter
    def to(self, value):
        """Alias for To.setter"""
        self.To = value


class ColorFormat:

    def __init__(self, colorformat=None):
        self.com_object= colorformat

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Brightness(self):
        return self.com_object.Brightness

    @Brightness.setter
    def Brightness(self, value):
        self.com_object.Brightness = value

    @property
    def brightness(self):
        """Alias for Brightness"""
        return self.Brightness

    @brightness.setter
    def brightness(self, value):
        """Alias for Brightness.setter"""
        self.Brightness = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ObjectThemeColor(self):
        return ColorFormat(self.com_object.ObjectThemeColor)

    @ObjectThemeColor.setter
    def ObjectThemeColor(self, value):
        self.com_object.ObjectThemeColor = value

    @property
    def objectthemecolor(self):
        """Alias for ObjectThemeColor"""
        return self.ObjectThemeColor

    @objectthemecolor.setter
    def objectthemecolor(self, value):
        """Alias for ObjectThemeColor.setter"""
        self.ObjectThemeColor = value

    @property
    def object_theme_color(self):
        """Alias for ObjectThemeColor"""
        return self.ObjectThemeColor

    @object_theme_color.setter
    def object_theme_color(self, value):
        """Alias for ObjectThemeColor.setter"""
        self.ObjectThemeColor = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RGB(self):
        return self.com_object.RGB

    @RGB.setter
    def RGB(self, value):
        self.com_object.RGB = value

    @property
    def rgb(self):
        """Alias for RGB"""
        return self.RGB

    @rgb.setter
    def rgb(self, value):
        """Alias for RGB.setter"""
        self.RGB = value

    @property
    def r_g_b(self):
        """Alias for RGB"""
        return self.RGB

    @r_g_b.setter
    def r_g_b(self, value):
        """Alias for RGB.setter"""
        self.RGB = value

    @property
    def SchemeColor(self):
        return self.com_object.SchemeColor

    @SchemeColor.setter
    def SchemeColor(self, value):
        self.com_object.SchemeColor = value

    @property
    def schemecolor(self):
        """Alias for SchemeColor"""
        return self.SchemeColor

    @schemecolor.setter
    def schemecolor(self, value):
        """Alias for SchemeColor.setter"""
        self.SchemeColor = value

    @property
    def scheme_color(self):
        """Alias for SchemeColor"""
        return self.SchemeColor

    @scheme_color.setter
    def scheme_color(self, value):
        """Alias for SchemeColor.setter"""
        self.SchemeColor = value

    @property
    def TintAndShade(self):
        return self.com_object.TintAndShade

    @TintAndShade.setter
    def TintAndShade(self, value):
        self.com_object.TintAndShade = value

    @property
    def tintandshade(self):
        """Alias for TintAndShade"""
        return self.TintAndShade

    @tintandshade.setter
    def tintandshade(self, value):
        """Alias for TintAndShade.setter"""
        self.TintAndShade = value

    @property
    def tint_and_shade(self):
        """Alias for TintAndShade"""
        return self.TintAndShade

    @tint_and_shade.setter
    def tint_and_shade(self, value):
        """Alias for TintAndShade.setter"""
        self.TintAndShade = value

    @property
    def Type(self):
        return self.com_object.Type

    @property
    def type(self):
        """Alias for Type"""
        return self.Type


class ColorScheme:

    def __init__(self, colorscheme=None):
        self.com_object= colorscheme

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Colors(self, SchemeColor=None):
        arguments = com_arguments([unwrap(a) for a in [SchemeColor]])
        return RGBColor(self.com_object.Colors(*arguments))

    def colors(self, SchemeColor=None):
        """Alias for Colors"""
        arguments = [SchemeColor]
        return self.Colors(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class ColorSchemes:

    def __init__(self, colorschemes=None):
        self.com_object= colorschemes

    def __call__(self, item):
        return ColorScheme(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Scheme=None):
        arguments = com_arguments([unwrap(a) for a in [Scheme]])
        return ColorScheme(self.com_object.Add(*arguments))

    def add(self, Scheme=None):
        """Alias for Add"""
        arguments = [Scheme]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ColorScheme(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Column:

    def __init__(self, column=None):
        self.com_object= column

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    def Cells(self, RowIndex=None, ColumnIndex=None):
        arguments = com_arguments([unwrap(a) for a in [RowIndex, ColumnIndex]])
        if hasattr(self.com_object, "GetCells"):
            return CellRange(self.com_object.GetCells(*arguments))
        else:
            return CellRange(self.com_object.Cells(*arguments))

    def cells(self, RowIndex=None, ColumnIndex=None):
        """Alias for Cells"""
        arguments = [RowIndex, ColumnIndex]
        return self.Cells(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Columns:

    def __init__(self, columns=None):
        self.com_object= columns

    def __call__(self, item):
        return Column(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, BeforeColumn=None):
        arguments = com_arguments([unwrap(a) for a in [BeforeColumn]])
        return Column(self.com_object.Add(*arguments))

    def add(self, BeforeColumn=None):
        """Alias for Add"""
        arguments = [BeforeColumn]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Column(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class CommandEffect:

    def __init__(self, commandeffect=None):
        self.com_object= commandeffect

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def bookmark(self):
        return self.com_object.bookmark

    @bookmark.setter
    def bookmark(self, value):
        self.com_object.bookmark = value

    @property
    def Command(self):
        return self.com_object.Command

    @Command.setter
    def Command(self, value):
        self.com_object.Command = value

    @property
    def command(self):
        """Alias for Command"""
        return self.Command

    @command.setter
    def command(self, value):
        """Alias for Command.setter"""
        self.Command = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value


class Comment:

    def __init__(self, comment=None):
        self.com_object= comment

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Author(self):
        return Comment(self.com_object.Author)

    @property
    def author(self):
        """Alias for Author"""
        return self.Author

    @property
    def AuthorIndex(self):
        return self.com_object.AuthorIndex

    @property
    def authorindex(self):
        """Alias for AuthorIndex"""
        return self.AuthorIndex

    @property
    def author_index(self):
        """Alias for AuthorIndex"""
        return self.AuthorIndex

    @property
    def AuthorInitials(self):
        return Comment(self.com_object.AuthorInitials)

    @property
    def authorinitials(self):
        """Alias for AuthorInitials"""
        return self.AuthorInitials

    @property
    def author_initials(self):
        """Alias for AuthorInitials"""
        return self.AuthorInitials

    @property
    def Collapsed(self):
        return self.com_object.Collapsed

    @property
    def collapsed(self):
        """Alias for Collapsed"""
        return self.Collapsed

    @property
    def DateTime(self):
        return self.com_object.DateTime

    @property
    def datetime(self):
        """Alias for DateTime"""
        return self.DateTime

    @property
    def date_time(self):
        """Alias for DateTime"""
        return self.DateTime

    @property
    def Left(self):
        return self.com_object.Left

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ProviderID(self):
        return self.com_object.ProviderID

    @property
    def providerid(self):
        """Alias for ProviderID"""
        return self.ProviderID

    @property
    def provider_i_d(self):
        """Alias for ProviderID"""
        return self.ProviderID

    @property
    def Replies(self):
        return Comment(self.com_object.Replies)

    @property
    def replies(self):
        """Alias for Replies"""
        return self.Replies

    @property
    def Text(self):
        return self.com_object.Text

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @property
    def TimeZoneBias(self):
        return self.com_object.TimeZoneBias

    @property
    def timezonebias(self):
        """Alias for TimeZoneBias"""
        return self.TimeZoneBias

    @property
    def time_zone_bias(self):
        """Alias for TimeZoneBias"""
        return self.TimeZoneBias

    @property
    def Top(self):
        return self.com_object.Top

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @property
    def UserID(self):
        return self.com_object.UserID

    @property
    def userid(self):
        """Alias for UserID"""
        return self.UserID

    @property
    def user_i_d(self):
        """Alias for UserID"""
        return self.UserID

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class Comments:

    def __init__(self, comments=None):
        self.com_object= comments

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Left=None, Top=None, Author=None, AuthorInitials=None, Text=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Author, AuthorInitials, Text]])
        return Comment(self.com_object.Add(*arguments))

    def add(self, Left=None, Top=None, Author=None, AuthorInitials=None, Text=None):
        """Alias for Add"""
        arguments = [Left, Top, Author, AuthorInitials, Text]
        return self.Add(*arguments)

    def Add2(self, Left=None, Top=None, Author=None, AuthorInitials=None, Text=None, ProviderID=None, UserID=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Author, AuthorInitials, Text, ProviderID, UserID]])
        return COMMENT(self.com_object.Add2(*arguments))

    def add2(self, Left=None, Top=None, Author=None, AuthorInitials=None, Text=None, ProviderID=None, UserID=None):
        """Alias for Add2"""
        arguments = [Left, Top, Author, AuthorInitials, Text, ProviderID, UserID]
        return self.Add2(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Comment(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ConnectorFormat:

    def __init__(self, connectorformat=None):
        self.com_object= connectorformat

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BeginConnected(self):
        return self.com_object.BeginConnected

    @BeginConnected.setter
    def BeginConnected(self, value):
        self.com_object.BeginConnected = value

    @property
    def beginconnected(self):
        """Alias for BeginConnected"""
        return self.BeginConnected

    @beginconnected.setter
    def beginconnected(self, value):
        """Alias for BeginConnected.setter"""
        self.BeginConnected = value

    @property
    def begin_connected(self):
        """Alias for BeginConnected"""
        return self.BeginConnected

    @begin_connected.setter
    def begin_connected(self, value):
        """Alias for BeginConnected.setter"""
        self.BeginConnected = value

    @property
    def BeginConnectedShape(self):
        return Shape(self.com_object.BeginConnectedShape)

    @property
    def beginconnectedshape(self):
        """Alias for BeginConnectedShape"""
        return self.BeginConnectedShape

    @property
    def begin_connected_shape(self):
        """Alias for BeginConnectedShape"""
        return self.BeginConnectedShape

    @property
    def BeginConnectionSite(self):
        return self.com_object.BeginConnectionSite

    @property
    def beginconnectionsite(self):
        """Alias for BeginConnectionSite"""
        return self.BeginConnectionSite

    @property
    def begin_connection_site(self):
        """Alias for BeginConnectionSite"""
        return self.BeginConnectionSite

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def EndConnected(self):
        return self.com_object.EndConnected

    @property
    def endconnected(self):
        """Alias for EndConnected"""
        return self.EndConnected

    @property
    def end_connected(self):
        """Alias for EndConnected"""
        return self.EndConnected

    @property
    def EndConnectedShape(self):
        return Shape(self.com_object.EndConnectedShape)

    @property
    def endconnectedshape(self):
        """Alias for EndConnectedShape"""
        return self.EndConnectedShape

    @property
    def end_connected_shape(self):
        """Alias for EndConnectedShape"""
        return self.EndConnectedShape

    @property
    def EndConnectionSite(self):
        return self.com_object.EndConnectionSite

    @property
    def endconnectionsite(self):
        """Alias for EndConnectionSite"""
        return self.EndConnectionSite

    @property
    def end_connection_site(self):
        """Alias for EndConnectionSite"""
        return self.EndConnectionSite

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    def BeginConnect(self, ConnectedShape=None, ConnectionSite=None):
        arguments = com_arguments([unwrap(a) for a in [ConnectedShape, ConnectionSite]])
        self.com_object.BeginConnect(*arguments)

    def beginconnect(self, ConnectedShape=None, ConnectionSite=None):
        """Alias for BeginConnect"""
        arguments = [ConnectedShape, ConnectionSite]
        return self.BeginConnect(*arguments)

    def begin_connect(self, ConnectedShape=None, ConnectionSite=None):
        """Alias for BeginConnect"""
        arguments = [ConnectedShape, ConnectionSite]
        return self.BeginConnect(*arguments)

    def BeginDisconnect(self):
        self.com_object.BeginDisconnect()

    def begindisconnect(self):
        """Alias for BeginDisconnect"""
        return self.BeginDisconnect()

    def begin_disconnect(self):
        """Alias for BeginDisconnect"""
        return self.BeginDisconnect()

    def EndConnect(self, ConnectedShape=None, ConnectionSite=None):
        arguments = com_arguments([unwrap(a) for a in [ConnectedShape, ConnectionSite]])
        self.com_object.EndConnect(*arguments)

    def endconnect(self, ConnectedShape=None, ConnectionSite=None):
        """Alias for EndConnect"""
        arguments = [ConnectedShape, ConnectionSite]
        return self.EndConnect(*arguments)

    def end_connect(self, ConnectedShape=None, ConnectionSite=None):
        """Alias for EndConnect"""
        arguments = [ConnectedShape, ConnectionSite]
        return self.EndConnect(*arguments)

    def EndDisconnect(self):
        self.com_object.EndDisconnect()

    def enddisconnect(self):
        """Alias for EndDisconnect"""
        return self.EndDisconnect()

    def end_disconnect(self):
        """Alias for EndDisconnect"""
        return self.EndDisconnect()


class CustomerData:

    def __init__(self, customerdata=None):
        self.com_object= customerdata

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return CustomerData(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self):
        return self.com_object.Add()

    def add(self):
        """Alias for Add"""
        return self.Add()

    def Delete(self, Id=None):
        arguments = com_arguments([unwrap(a) for a in [Id]])
        self.com_object.Delete(*arguments)

    def delete(self, Id=None):
        """Alias for Delete"""
        arguments = [Id]
        return self.Delete(*arguments)

    def Item(self, Id=None):
        arguments = com_arguments([unwrap(a) for a in [Id]])
        return self.com_object.Item(*arguments)

    def item(self, Id=None):
        """Alias for Item"""
        arguments = [Id]
        return self.Item(*arguments)


class CustomLayout:

    def __init__(self, customlayout=None):
        self.com_object= customlayout

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Background(self):
        return ShapeRange(self.com_object.Background)

    @property
    def background(self):
        """Alias for Background"""
        return self.Background

    @property
    def CustomerData(self):
        return CustomerData(self.com_object.CustomerData)

    @property
    def customerdata(self):
        """Alias for CustomerData"""
        return self.CustomerData

    @property
    def customer_data(self):
        """Alias for CustomerData"""
        return self.CustomerData

    @property
    def Design(self):
        return Design(self.com_object.Design)

    @property
    def design(self):
        """Alias for Design"""
        return self.Design

    @property
    def DisplayMasterShapes(self):
        return self.com_object.DisplayMasterShapes

    @DisplayMasterShapes.setter
    def DisplayMasterShapes(self, value):
        self.com_object.DisplayMasterShapes = value

    @property
    def displaymastershapes(self):
        """Alias for DisplayMasterShapes"""
        return self.DisplayMasterShapes

    @displaymastershapes.setter
    def displaymastershapes(self, value):
        """Alias for DisplayMasterShapes.setter"""
        self.DisplayMasterShapes = value

    @property
    def display_master_shapes(self):
        """Alias for DisplayMasterShapes"""
        return self.DisplayMasterShapes

    @display_master_shapes.setter
    def display_master_shapes(self, value):
        """Alias for DisplayMasterShapes.setter"""
        self.DisplayMasterShapes = value

    @property
    def FollowMasterBackground(self):
        return self.com_object.FollowMasterBackground

    @FollowMasterBackground.setter
    def FollowMasterBackground(self, value):
        self.com_object.FollowMasterBackground = value

    @property
    def followmasterbackground(self):
        """Alias for FollowMasterBackground"""
        return self.FollowMasterBackground

    @followmasterbackground.setter
    def followmasterbackground(self, value):
        """Alias for FollowMasterBackground.setter"""
        self.FollowMasterBackground = value

    @property
    def follow_master_background(self):
        """Alias for FollowMasterBackground"""
        return self.FollowMasterBackground

    @follow_master_background.setter
    def follow_master_background(self, value):
        """Alias for FollowMasterBackground.setter"""
        self.FollowMasterBackground = value

    @property
    def Guides(self):
        return self.com_object.Guides

    @property
    def guides(self):
        """Alias for Guides"""
        return self.Guides

    @property
    def HeadersFooters(self):
        return HeadersFooters(self.com_object.HeadersFooters)

    @property
    def headersfooters(self):
        """Alias for HeadersFooters"""
        return self.HeadersFooters

    @property
    def headers_footers(self):
        """Alias for HeadersFooters"""
        return self.HeadersFooters

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def Hyperlinks(self):
        return Hyperlinks(self.com_object.Hyperlinks)

    @property
    def hyperlinks(self):
        """Alias for Hyperlinks"""
        return self.Hyperlinks

    @property
    def Index(self):
        return CustomLayouts(self.com_object.Index)

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def MatchingName(self):
        return self.com_object.MatchingName

    @MatchingName.setter
    def MatchingName(self, value):
        self.com_object.MatchingName = value

    @property
    def matchingname(self):
        """Alias for MatchingName"""
        return self.MatchingName

    @matchingname.setter
    def matchingname(self, value):
        """Alias for MatchingName.setter"""
        self.MatchingName = value

    @property
    def matching_name(self):
        """Alias for MatchingName"""
        return self.MatchingName

    @matching_name.setter
    def matching_name(self, value):
        """Alias for MatchingName.setter"""
        self.MatchingName = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return CustomLayout(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Preserved(self):
        return self.com_object.Preserved

    @Preserved.setter
    def Preserved(self, value):
        self.com_object.Preserved = value

    @property
    def preserved(self):
        """Alias for Preserved"""
        return self.Preserved

    @preserved.setter
    def preserved(self, value):
        """Alias for Preserved.setter"""
        self.Preserved = value

    @property
    def Shapes(self):
        return Shapes(self.com_object.Shapes)

    @property
    def shapes(self):
        """Alias for Shapes"""
        return self.Shapes

    @property
    def SlideShowTransition(self):
        return SlideShowTransition(self.com_object.SlideShowTransition)

    @property
    def slideshowtransition(self):
        """Alias for SlideShowTransition"""
        return self.SlideShowTransition

    @property
    def slide_show_transition(self):
        """Alias for SlideShowTransition"""
        return self.SlideShowTransition

    @property
    def ThemeColorScheme(self):
        return self.com_object.ThemeColorScheme

    @property
    def themecolorscheme(self):
        """Alias for ThemeColorScheme"""
        return self.ThemeColorScheme

    @property
    def theme_color_scheme(self):
        """Alias for ThemeColorScheme"""
        return self.ThemeColorScheme

    @property
    def TimeLine(self):
        return TimeLine(self.com_object.TimeLine)

    @property
    def timeline(self):
        """Alias for TimeLine"""
        return self.TimeLine

    @property
    def time_line(self):
        """Alias for TimeLine"""
        return self.TimeLine

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Cut(self):
        self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Duplicate(self):
        return CustomLayout(self.com_object.Duplicate())

    def duplicate(self):
        """Alias for Duplicate"""
        return self.Duplicate()

    def MoveTo(self, toPos=None):
        arguments = com_arguments([unwrap(a) for a in [toPos]])
        self.com_object.MoveTo(*arguments)

    def moveto(self, toPos=None):
        """Alias for MoveTo"""
        arguments = [toPos]
        return self.MoveTo(*arguments)

    def move_to(self, toPos=None):
        """Alias for MoveTo"""
        arguments = [toPos]
        return self.MoveTo(*arguments)

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class CustomLayouts:

    def __init__(self, customlayouts=None):
        self.com_object= customlayouts

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return CustomLayout(self.com_object.Add(*arguments))

    def add(self, Index=None):
        """Alias for Add"""
        arguments = [Index]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return CustomLayout(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Paste(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return CustomLayout(self.com_object.Paste(*arguments))

    def paste(self, Index=None):
        """Alias for Paste"""
        arguments = [Index]
        return self.Paste(*arguments)


class DataLabel:

    def __init__(self, datalabel=None):
        self.com_object= datalabel

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoText(self):
        return self.com_object.AutoText

    @AutoText.setter
    def AutoText(self, value):
        self.com_object.AutoText = value

    @property
    def autotext(self):
        """Alias for AutoText"""
        return self.AutoText

    @autotext.setter
    def autotext(self, value):
        """Alias for AutoText.setter"""
        self.AutoText = value

    @property
    def auto_text(self):
        """Alias for AutoText"""
        return self.AutoText

    @auto_text.setter
    def auto_text(self, value):
        """Alias for AutoText.setter"""
        self.AutoText = value

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    def Characters(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        if hasattr(self.com_object, "GetCharacters"):
            return ChartCharacters(self.com_object.GetCharacters(*arguments))
        else:
            return ChartCharacters(self.com_object.Characters(*arguments))

    def characters(self, Start=None, Length=None):
        """Alias for Characters"""
        arguments = [Start, Length]
        return self.Characters(*arguments)

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def FormulaLocal(self):
        return self.com_object.FormulaLocal

    @FormulaLocal.setter
    def FormulaLocal(self, value):
        self.com_object.FormulaLocal = value

    @property
    def formulalocal(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formulalocal.setter
    def formulalocal(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def formula_local(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formula_local.setter
    def formula_local(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def FormulaR1C1(self):
        return self.com_object.FormulaR1C1

    @FormulaR1C1.setter
    def FormulaR1C1(self, value):
        self.com_object.FormulaR1C1 = value

    @property
    def formular1c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formular1c1.setter
    def formular1c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def formula_r1_c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formula_r1_c1.setter
    def formula_r1_c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def FormulaR1C1Local(self):
        return self.com_object.FormulaR1C1Local

    @FormulaR1C1Local.setter
    def FormulaR1C1Local(self, value):
        self.com_object.FormulaR1C1Local = value

    @property
    def formular1c1local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formular1c1local.setter
    def formular1c1local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def formula_r1_c1_local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formula_r1_c1_local.setter
    def formula_r1_c1_local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def HorizontalAlignment(self):
        return self.com_object.HorizontalAlignment

    @HorizontalAlignment.setter
    def HorizontalAlignment(self, value):
        self.com_object.HorizontalAlignment = value

    @property
    def horizontalalignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontalalignment.setter
    def horizontalalignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def horizontal_alignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NumberFormat(self):
        return self.com_object.NumberFormat

    @NumberFormat.setter
    def NumberFormat(self, value):
        self.com_object.NumberFormat = value

    @property
    def numberformat(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @numberformat.setter
    def numberformat(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def number_format(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @number_format.setter
    def number_format(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def NumberFormatLinked(self):
        return self.com_object.NumberFormatLinked

    @NumberFormatLinked.setter
    def NumberFormatLinked(self, value):
        self.com_object.NumberFormatLinked = value

    @property
    def numberformatlinked(self):
        """Alias for NumberFormatLinked"""
        return self.NumberFormatLinked

    @numberformatlinked.setter
    def numberformatlinked(self, value):
        """Alias for NumberFormatLinked.setter"""
        self.NumberFormatLinked = value

    @property
    def number_format_linked(self):
        """Alias for NumberFormatLinked"""
        return self.NumberFormatLinked

    @number_format_linked.setter
    def number_format_linked(self, value):
        """Alias for NumberFormatLinked.setter"""
        self.NumberFormatLinked = value

    @property
    def NumberFormatLocal(self):
        return self.com_object.NumberFormatLocal

    @NumberFormatLocal.setter
    def NumberFormatLocal(self, value):
        self.com_object.NumberFormatLocal = value

    @property
    def numberformatlocal(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @numberformatlocal.setter
    def numberformatlocal(self, value):
        """Alias for NumberFormatLocal.setter"""
        self.NumberFormatLocal = value

    @property
    def number_format_local(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @number_format_local.setter
    def number_format_local(self, value):
        """Alias for NumberFormatLocal.setter"""
        self.NumberFormatLocal = value

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return XlDataLabelPosition(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def ReadingOrder(self):
        return XlReadingOrder(self.com_object.ReadingOrder)

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def Separator(self):
        return self.com_object.Separator

    @Separator.setter
    def Separator(self, value):
        self.com_object.Separator = value

    @property
    def separator(self):
        """Alias for Separator"""
        return self.Separator

    @separator.setter
    def separator(self, value):
        """Alias for Separator.setter"""
        self.Separator = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def ShowBubbleSize(self):
        return self.com_object.ShowBubbleSize

    @ShowBubbleSize.setter
    def ShowBubbleSize(self, value):
        self.com_object.ShowBubbleSize = value

    @property
    def showbubblesize(self):
        """Alias for ShowBubbleSize"""
        return self.ShowBubbleSize

    @showbubblesize.setter
    def showbubblesize(self, value):
        """Alias for ShowBubbleSize.setter"""
        self.ShowBubbleSize = value

    @property
    def show_bubble_size(self):
        """Alias for ShowBubbleSize"""
        return self.ShowBubbleSize

    @show_bubble_size.setter
    def show_bubble_size(self, value):
        """Alias for ShowBubbleSize.setter"""
        self.ShowBubbleSize = value

    @property
    def ShowCategoryName(self):
        return self.com_object.ShowCategoryName

    @ShowCategoryName.setter
    def ShowCategoryName(self, value):
        self.com_object.ShowCategoryName = value

    @property
    def showcategoryname(self):
        """Alias for ShowCategoryName"""
        return self.ShowCategoryName

    @showcategoryname.setter
    def showcategoryname(self, value):
        """Alias for ShowCategoryName.setter"""
        self.ShowCategoryName = value

    @property
    def show_category_name(self):
        """Alias for ShowCategoryName"""
        return self.ShowCategoryName

    @show_category_name.setter
    def show_category_name(self, value):
        """Alias for ShowCategoryName.setter"""
        self.ShowCategoryName = value

    @property
    def ShowLegendKey(self):
        return self.com_object.ShowLegendKey

    @ShowLegendKey.setter
    def ShowLegendKey(self, value):
        self.com_object.ShowLegendKey = value

    @property
    def showlegendkey(self):
        """Alias for ShowLegendKey"""
        return self.ShowLegendKey

    @showlegendkey.setter
    def showlegendkey(self, value):
        """Alias for ShowLegendKey.setter"""
        self.ShowLegendKey = value

    @property
    def show_legend_key(self):
        """Alias for ShowLegendKey"""
        return self.ShowLegendKey

    @show_legend_key.setter
    def show_legend_key(self, value):
        """Alias for ShowLegendKey.setter"""
        self.ShowLegendKey = value

    @property
    def ShowPercentage(self):
        return self.com_object.ShowPercentage

    @ShowPercentage.setter
    def ShowPercentage(self, value):
        self.com_object.ShowPercentage = value

    @property
    def showpercentage(self):
        """Alias for ShowPercentage"""
        return self.ShowPercentage

    @showpercentage.setter
    def showpercentage(self, value):
        """Alias for ShowPercentage.setter"""
        self.ShowPercentage = value

    @property
    def show_percentage(self):
        """Alias for ShowPercentage"""
        return self.ShowPercentage

    @show_percentage.setter
    def show_percentage(self, value):
        """Alias for ShowPercentage.setter"""
        self.ShowPercentage = value

    @property
    def ShowRange(self):
        return self.com_object.ShowRange

    @ShowRange.setter
    def ShowRange(self, value):
        self.com_object.ShowRange = value

    @property
    def showrange(self):
        """Alias for ShowRange"""
        return self.ShowRange

    @showrange.setter
    def showrange(self, value):
        """Alias for ShowRange.setter"""
        self.ShowRange = value

    @property
    def show_range(self):
        """Alias for ShowRange"""
        return self.ShowRange

    @show_range.setter
    def show_range(self, value):
        """Alias for ShowRange.setter"""
        self.ShowRange = value

    @property
    def ShowSeriesName(self):
        return self.com_object.ShowSeriesName

    @ShowSeriesName.setter
    def ShowSeriesName(self, value):
        self.com_object.ShowSeriesName = value

    @property
    def showseriesname(self):
        """Alias for ShowSeriesName"""
        return self.ShowSeriesName

    @showseriesname.setter
    def showseriesname(self, value):
        """Alias for ShowSeriesName.setter"""
        self.ShowSeriesName = value

    @property
    def show_series_name(self):
        """Alias for ShowSeriesName"""
        return self.ShowSeriesName

    @show_series_name.setter
    def show_series_name(self, value):
        """Alias for ShowSeriesName.setter"""
        self.ShowSeriesName = value

    @property
    def ShowValue(self):
        return self.com_object.ShowValue

    @ShowValue.setter
    def ShowValue(self, value):
        self.com_object.ShowValue = value

    @property
    def showvalue(self):
        """Alias for ShowValue"""
        return self.ShowValue

    @showvalue.setter
    def showvalue(self, value):
        """Alias for ShowValue.setter"""
        self.ShowValue = value

    @property
    def show_value(self):
        """Alias for ShowValue"""
        return self.ShowValue

    @show_value.setter
    def show_value(self, value):
        """Alias for ShowValue.setter"""
        self.ShowValue = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def VerticalAlignment(self):
        return self.com_object.VerticalAlignment

    @VerticalAlignment.setter
    def VerticalAlignment(self, value):
        self.com_object.VerticalAlignment = value

    @property
    def verticalalignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @verticalalignment.setter
    def verticalalignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def vertical_alignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @vertical_alignment.setter
    def vertical_alignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class DataLabels:

    def __init__(self, datalabels=None):
        self.com_object= datalabels

    def __call__(self, item):
        return DataLabel(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoText(self):
        return self.com_object.AutoText

    @AutoText.setter
    def AutoText(self, value):
        self.com_object.AutoText = value

    @property
    def autotext(self):
        """Alias for AutoText"""
        return self.AutoText

    @autotext.setter
    def autotext(self, value):
        """Alias for AutoText.setter"""
        self.AutoText = value

    @property
    def auto_text(self):
        """Alias for AutoText"""
        return self.AutoText

    @auto_text.setter
    def auto_text(self, value):
        """Alias for AutoText.setter"""
        self.AutoText = value

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def HorizontalAlignment(self):
        return self.com_object.HorizontalAlignment

    @HorizontalAlignment.setter
    def HorizontalAlignment(self, value):
        self.com_object.HorizontalAlignment = value

    @property
    def horizontalalignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontalalignment.setter
    def horizontalalignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def horizontal_alignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NumberFormat(self):
        return self.com_object.NumberFormat

    @NumberFormat.setter
    def NumberFormat(self, value):
        self.com_object.NumberFormat = value

    @property
    def numberformat(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @numberformat.setter
    def numberformat(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def number_format(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @number_format.setter
    def number_format(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def NumberFormatLinked(self):
        return self.com_object.NumberFormatLinked

    @NumberFormatLinked.setter
    def NumberFormatLinked(self, value):
        self.com_object.NumberFormatLinked = value

    @property
    def numberformatlinked(self):
        """Alias for NumberFormatLinked"""
        return self.NumberFormatLinked

    @numberformatlinked.setter
    def numberformatlinked(self, value):
        """Alias for NumberFormatLinked.setter"""
        self.NumberFormatLinked = value

    @property
    def number_format_linked(self):
        """Alias for NumberFormatLinked"""
        return self.NumberFormatLinked

    @number_format_linked.setter
    def number_format_linked(self, value):
        """Alias for NumberFormatLinked.setter"""
        self.NumberFormatLinked = value

    @property
    def NumberFormatLocal(self):
        return self.com_object.NumberFormatLocal

    @NumberFormatLocal.setter
    def NumberFormatLocal(self, value):
        self.com_object.NumberFormatLocal = value

    @property
    def numberformatlocal(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @numberformatlocal.setter
    def numberformatlocal(self, value):
        """Alias for NumberFormatLocal.setter"""
        self.NumberFormatLocal = value

    @property
    def number_format_local(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @number_format_local.setter
    def number_format_local(self, value):
        """Alias for NumberFormatLocal.setter"""
        self.NumberFormatLocal = value

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return self.com_object.Position

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def ReadingOrder(self):
        return XlReadingOrder(self.com_object.ReadingOrder)

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def Separator(self):
        return self.com_object.Separator

    @Separator.setter
    def Separator(self, value):
        self.com_object.Separator = value

    @property
    def separator(self):
        """Alias for Separator"""
        return self.Separator

    @separator.setter
    def separator(self, value):
        """Alias for Separator.setter"""
        self.Separator = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def ShowBubbleSize(self):
        return self.com_object.ShowBubbleSize

    @ShowBubbleSize.setter
    def ShowBubbleSize(self, value):
        self.com_object.ShowBubbleSize = value

    @property
    def showbubblesize(self):
        """Alias for ShowBubbleSize"""
        return self.ShowBubbleSize

    @showbubblesize.setter
    def showbubblesize(self, value):
        """Alias for ShowBubbleSize.setter"""
        self.ShowBubbleSize = value

    @property
    def show_bubble_size(self):
        """Alias for ShowBubbleSize"""
        return self.ShowBubbleSize

    @show_bubble_size.setter
    def show_bubble_size(self, value):
        """Alias for ShowBubbleSize.setter"""
        self.ShowBubbleSize = value

    @property
    def ShowCategoryName(self):
        return self.com_object.ShowCategoryName

    @ShowCategoryName.setter
    def ShowCategoryName(self, value):
        self.com_object.ShowCategoryName = value

    @property
    def showcategoryname(self):
        """Alias for ShowCategoryName"""
        return self.ShowCategoryName

    @showcategoryname.setter
    def showcategoryname(self, value):
        """Alias for ShowCategoryName.setter"""
        self.ShowCategoryName = value

    @property
    def show_category_name(self):
        """Alias for ShowCategoryName"""
        return self.ShowCategoryName

    @show_category_name.setter
    def show_category_name(self, value):
        """Alias for ShowCategoryName.setter"""
        self.ShowCategoryName = value

    @property
    def ShowLegendKey(self):
        return self.com_object.ShowLegendKey

    @ShowLegendKey.setter
    def ShowLegendKey(self, value):
        self.com_object.ShowLegendKey = value

    @property
    def showlegendkey(self):
        """Alias for ShowLegendKey"""
        return self.ShowLegendKey

    @showlegendkey.setter
    def showlegendkey(self, value):
        """Alias for ShowLegendKey.setter"""
        self.ShowLegendKey = value

    @property
    def show_legend_key(self):
        """Alias for ShowLegendKey"""
        return self.ShowLegendKey

    @show_legend_key.setter
    def show_legend_key(self, value):
        """Alias for ShowLegendKey.setter"""
        self.ShowLegendKey = value

    @property
    def ShowPercentage(self):
        return self.com_object.ShowPercentage

    @ShowPercentage.setter
    def ShowPercentage(self, value):
        self.com_object.ShowPercentage = value

    @property
    def showpercentage(self):
        """Alias for ShowPercentage"""
        return self.ShowPercentage

    @showpercentage.setter
    def showpercentage(self, value):
        """Alias for ShowPercentage.setter"""
        self.ShowPercentage = value

    @property
    def show_percentage(self):
        """Alias for ShowPercentage"""
        return self.ShowPercentage

    @show_percentage.setter
    def show_percentage(self, value):
        """Alias for ShowPercentage.setter"""
        self.ShowPercentage = value

    @property
    def ShowRange(self):
        return self.com_object.ShowRange

    @ShowRange.setter
    def ShowRange(self, value):
        self.com_object.ShowRange = value

    @property
    def showrange(self):
        """Alias for ShowRange"""
        return self.ShowRange

    @showrange.setter
    def showrange(self, value):
        """Alias for ShowRange.setter"""
        self.ShowRange = value

    @property
    def show_range(self):
        """Alias for ShowRange"""
        return self.ShowRange

    @show_range.setter
    def show_range(self, value):
        """Alias for ShowRange.setter"""
        self.ShowRange = value

    @property
    def ShowSeriesName(self):
        return self.com_object.ShowSeriesName

    @ShowSeriesName.setter
    def ShowSeriesName(self, value):
        self.com_object.ShowSeriesName = value

    @property
    def showseriesname(self):
        """Alias for ShowSeriesName"""
        return self.ShowSeriesName

    @showseriesname.setter
    def showseriesname(self, value):
        """Alias for ShowSeriesName.setter"""
        self.ShowSeriesName = value

    @property
    def show_series_name(self):
        """Alias for ShowSeriesName"""
        return self.ShowSeriesName

    @show_series_name.setter
    def show_series_name(self, value):
        """Alias for ShowSeriesName.setter"""
        self.ShowSeriesName = value

    @property
    def ShowValue(self):
        return self.com_object.ShowValue

    @ShowValue.setter
    def ShowValue(self, value):
        self.com_object.ShowValue = value

    @property
    def showvalue(self):
        """Alias for ShowValue"""
        return self.ShowValue

    @showvalue.setter
    def showvalue(self, value):
        """Alias for ShowValue.setter"""
        self.ShowValue = value

    @property
    def show_value(self):
        """Alias for ShowValue"""
        return self.ShowValue

    @show_value.setter
    def show_value(self, value):
        """Alias for ShowValue.setter"""
        self.ShowValue = value

    @property
    def VerticalAlignment(self):
        return self.com_object.VerticalAlignment

    @VerticalAlignment.setter
    def VerticalAlignment(self, value):
        self.com_object.VerticalAlignment = value

    @property
    def verticalalignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @verticalalignment.setter
    def verticalalignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def vertical_alignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @vertical_alignment.setter
    def vertical_alignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return DataLabel(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Propagate(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Propagate(*arguments)

    def propagate(self, Index=None):
        """Alias for Propagate"""
        arguments = [Index]
        return self.Propagate(*arguments)

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class DataTable:

    def __init__(self, datatable=None):
        self.com_object= datatable

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Border(self):
        return ChartBorder(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Font(self):
        return ChartFont(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def HasBorderHorizontal(self):
        return self.com_object.HasBorderHorizontal

    @HasBorderHorizontal.setter
    def HasBorderHorizontal(self, value):
        self.com_object.HasBorderHorizontal = value

    @property
    def hasborderhorizontal(self):
        """Alias for HasBorderHorizontal"""
        return self.HasBorderHorizontal

    @hasborderhorizontal.setter
    def hasborderhorizontal(self, value):
        """Alias for HasBorderHorizontal.setter"""
        self.HasBorderHorizontal = value

    @property
    def has_border_horizontal(self):
        """Alias for HasBorderHorizontal"""
        return self.HasBorderHorizontal

    @has_border_horizontal.setter
    def has_border_horizontal(self, value):
        """Alias for HasBorderHorizontal.setter"""
        self.HasBorderHorizontal = value

    @property
    def HasBorderOutline(self):
        return self.com_object.HasBorderOutline

    @HasBorderOutline.setter
    def HasBorderOutline(self, value):
        self.com_object.HasBorderOutline = value

    @property
    def hasborderoutline(self):
        """Alias for HasBorderOutline"""
        return self.HasBorderOutline

    @hasborderoutline.setter
    def hasborderoutline(self, value):
        """Alias for HasBorderOutline.setter"""
        self.HasBorderOutline = value

    @property
    def has_border_outline(self):
        """Alias for HasBorderOutline"""
        return self.HasBorderOutline

    @has_border_outline.setter
    def has_border_outline(self, value):
        """Alias for HasBorderOutline.setter"""
        self.HasBorderOutline = value

    @property
    def HasBorderVertical(self):
        return self.com_object.HasBorderVertical

    @HasBorderVertical.setter
    def HasBorderVertical(self, value):
        self.com_object.HasBorderVertical = value

    @property
    def hasbordervertical(self):
        """Alias for HasBorderVertical"""
        return self.HasBorderVertical

    @hasbordervertical.setter
    def hasbordervertical(self, value):
        """Alias for HasBorderVertical.setter"""
        self.HasBorderVertical = value

    @property
    def has_border_vertical(self):
        """Alias for HasBorderVertical"""
        return self.HasBorderVertical

    @has_border_vertical.setter
    def has_border_vertical(self, value):
        """Alias for HasBorderVertical.setter"""
        self.HasBorderVertical = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ShowLegendKey(self):
        return self.com_object.ShowLegendKey

    @ShowLegendKey.setter
    def ShowLegendKey(self, value):
        self.com_object.ShowLegendKey = value

    @property
    def showlegendkey(self):
        """Alias for ShowLegendKey"""
        return self.ShowLegendKey

    @showlegendkey.setter
    def showlegendkey(self, value):
        """Alias for ShowLegendKey.setter"""
        self.ShowLegendKey = value

    @property
    def show_legend_key(self):
        """Alias for ShowLegendKey"""
        return self.ShowLegendKey

    @show_legend_key.setter
    def show_legend_key(self, value):
        """Alias for ShowLegendKey.setter"""
        self.ShowLegendKey = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Design:

    def __init__(self, design=None):
        self.com_object= design

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Preserved(self):
        return self.com_object.Preserved

    @Preserved.setter
    def Preserved(self, value):
        self.com_object.Preserved = value

    @property
    def preserved(self):
        """Alias for Preserved"""
        return self.Preserved

    @preserved.setter
    def preserved(self, value):
        """Alias for Preserved.setter"""
        self.Preserved = value

    @property
    def SlideMaster(self):
        return Master(self.com_object.SlideMaster)

    @property
    def slidemaster(self):
        """Alias for SlideMaster"""
        return self.SlideMaster

    @property
    def slide_master(self):
        """Alias for SlideMaster"""
        return self.SlideMaster

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def MoveTo(self, toPos=None):
        arguments = com_arguments([unwrap(a) for a in [toPos]])
        self.com_object.MoveTo(*arguments)

    def moveto(self, toPos=None):
        """Alias for MoveTo"""
        arguments = [toPos]
        return self.MoveTo(*arguments)

    def move_to(self, toPos=None):
        """Alias for MoveTo"""
        arguments = [toPos]
        return self.MoveTo(*arguments)


class Designs:

    def __init__(self, designs=None):
        self.com_object= designs

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, designName=None, Index=None):
        arguments = com_arguments([unwrap(a) for a in [designName, Index]])
        return Design(self.com_object.Add(*arguments))

    def add(self, designName=None, Index=None):
        """Alias for Add"""
        arguments = [designName, Index]
        return self.Add(*arguments)

    def Clone(self, pOriginal=None, Index=None):
        arguments = com_arguments([unwrap(a) for a in [pOriginal, Index]])
        return Design(self.com_object.Clone(*arguments))

    def clone(self, pOriginal=None, Index=None):
        """Alias for Clone"""
        arguments = [pOriginal, Index]
        return self.Clone(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Design(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Load(self, TemplateName=None, Index=None):
        arguments = com_arguments([unwrap(a) for a in [TemplateName, Index]])
        return Design(self.com_object.Load(*arguments))

    def load(self, TemplateName=None, Index=None):
        """Alias for Load"""
        arguments = [TemplateName, Index]
        return self.Load(*arguments)


class DisplayUnitLabel:

    def __init__(self, displayunitlabel=None):
        self.com_object= displayunitlabel

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    def Characters(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        if hasattr(self.com_object, "GetCharacters"):
            return ChartCharacters(self.com_object.GetCharacters(*arguments))
        else:
            return ChartCharacters(self.com_object.Characters(*arguments))

    def characters(self, Start=None, Length=None):
        """Alias for Characters"""
        arguments = [Start, Length]
        return self.Characters(*arguments)

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def FormulaLocal(self):
        return self.com_object.FormulaLocal

    @FormulaLocal.setter
    def FormulaLocal(self, value):
        self.com_object.FormulaLocal = value

    @property
    def formulalocal(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formulalocal.setter
    def formulalocal(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def formula_local(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formula_local.setter
    def formula_local(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def FormulaR1C1(self):
        return self.com_object.FormulaR1C1

    @FormulaR1C1.setter
    def FormulaR1C1(self, value):
        self.com_object.FormulaR1C1 = value

    @property
    def formular1c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formular1c1.setter
    def formular1c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def formula_r1_c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formula_r1_c1.setter
    def formula_r1_c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def FormulaR1C1Local(self):
        return self.com_object.FormulaR1C1Local

    @FormulaR1C1Local.setter
    def FormulaR1C1Local(self, value):
        self.com_object.FormulaR1C1Local = value

    @property
    def formular1c1local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formular1c1local.setter
    def formular1c1local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def formula_r1_c1_local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formula_r1_c1_local.setter
    def formula_r1_c1_local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def HorizontalAlignment(self):
        return self.com_object.HorizontalAlignment

    @HorizontalAlignment.setter
    def HorizontalAlignment(self, value):
        self.com_object.HorizontalAlignment = value

    @property
    def horizontalalignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontalalignment.setter
    def horizontalalignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def horizontal_alignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return XlChartElementPosition(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def ReadingOrder(self):
        return XlReadingOrder(self.com_object.ReadingOrder)

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def VerticalAlignment(self):
        return self.com_object.VerticalAlignment

    @VerticalAlignment.setter
    def VerticalAlignment(self, value):
        self.com_object.VerticalAlignment = value

    @property
    def verticalalignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @verticalalignment.setter
    def verticalalignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def vertical_alignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @vertical_alignment.setter
    def vertical_alignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class DocumentWindow:

    def __init__(self, documentwindow=None):
        self.com_object= documentwindow

    @property
    def Active(self):
        return self.com_object.Active

    @property
    def active(self):
        """Alias for Active"""
        return self.Active

    @property
    def ActivePane(self):
        return Pane(self.com_object.ActivePane)

    @property
    def activepane(self):
        """Alias for ActivePane"""
        return self.ActivePane

    @property
    def active_pane(self):
        """Alias for ActivePane"""
        return self.ActivePane

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BlackAndWhite(self):
        return self.com_object.BlackAndWhite

    @BlackAndWhite.setter
    def BlackAndWhite(self, value):
        self.com_object.BlackAndWhite = value

    @property
    def blackandwhite(self):
        """Alias for BlackAndWhite"""
        return self.BlackAndWhite

    @blackandwhite.setter
    def blackandwhite(self, value):
        """Alias for BlackAndWhite.setter"""
        self.BlackAndWhite = value

    @property
    def black_and_white(self):
        """Alias for BlackAndWhite"""
        return self.BlackAndWhite

    @black_and_white.setter
    def black_and_white(self, value):
        """Alias for BlackAndWhite.setter"""
        self.BlackAndWhite = value

    @property
    def Caption(self):
        return self.com_object.Caption

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Panes(self):
        return Panes(self.com_object.Panes)

    @property
    def panes(self):
        """Alias for Panes"""
        return self.Panes

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Presentation(self):
        return Presentation(self.com_object.Presentation)

    @property
    def presentation(self):
        """Alias for Presentation"""
        return self.Presentation

    @property
    def Selection(self):
        return Selection(self.com_object.Selection)

    @property
    def selection(self):
        """Alias for Selection"""
        return self.Selection

    @property
    def SplitHorizontal(self):
        return self.com_object.SplitHorizontal

    @SplitHorizontal.setter
    def SplitHorizontal(self, value):
        self.com_object.SplitHorizontal = value

    @property
    def splithorizontal(self):
        """Alias for SplitHorizontal"""
        return self.SplitHorizontal

    @splithorizontal.setter
    def splithorizontal(self, value):
        """Alias for SplitHorizontal.setter"""
        self.SplitHorizontal = value

    @property
    def split_horizontal(self):
        """Alias for SplitHorizontal"""
        return self.SplitHorizontal

    @split_horizontal.setter
    def split_horizontal(self, value):
        """Alias for SplitHorizontal.setter"""
        self.SplitHorizontal = value

    @property
    def SplitVertical(self):
        return self.com_object.SplitVertical

    @SplitVertical.setter
    def SplitVertical(self, value):
        self.com_object.SplitVertical = value

    @property
    def splitvertical(self):
        """Alias for SplitVertical"""
        return self.SplitVertical

    @splitvertical.setter
    def splitvertical(self, value):
        """Alias for SplitVertical.setter"""
        self.SplitVertical = value

    @property
    def split_vertical(self):
        """Alias for SplitVertical"""
        return self.SplitVertical

    @split_vertical.setter
    def split_vertical(self, value):
        """Alias for SplitVertical.setter"""
        self.SplitVertical = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def View(self):
        return View(self.com_object.View)

    @property
    def view(self):
        """Alias for View"""
        return self.View

    @property
    def ViewType(self):
        return self.com_object.ViewType

    @ViewType.setter
    def ViewType(self, value):
        self.com_object.ViewType = value

    @property
    def viewtype(self):
        """Alias for ViewType"""
        return self.ViewType

    @viewtype.setter
    def viewtype(self, value):
        """Alias for ViewType.setter"""
        self.ViewType = value

    @property
    def view_type(self):
        """Alias for ViewType"""
        return self.ViewType

    @view_type.setter
    def view_type(self, value):
        """Alias for ViewType.setter"""
        self.ViewType = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def WindowState(self):
        return self.com_object.WindowState

    @WindowState.setter
    def WindowState(self, value):
        self.com_object.WindowState = value

    @property
    def windowstate(self):
        """Alias for WindowState"""
        return self.WindowState

    @windowstate.setter
    def windowstate(self, value):
        """Alias for WindowState.setter"""
        self.WindowState = value

    @property
    def window_state(self):
        """Alias for WindowState"""
        return self.WindowState

    @window_state.setter
    def window_state(self, value):
        """Alias for WindowState.setter"""
        self.WindowState = value

    def Activate(self):
        self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()

    def Close(self):
        self.com_object.Close()

    def close(self):
        """Alias for Close"""
        return self.Close()

    def ExpandSection(self, sectionIndex=None, Expand=None):
        arguments = com_arguments([unwrap(a) for a in [sectionIndex, Expand]])
        self.com_object.ExpandSection(*arguments)

    def expandsection(self, sectionIndex=None, Expand=None):
        """Alias for ExpandSection"""
        arguments = [sectionIndex, Expand]
        return self.ExpandSection(*arguments)

    def expand_section(self, sectionIndex=None, Expand=None):
        """Alias for ExpandSection"""
        arguments = [sectionIndex, Expand]
        return self.ExpandSection(*arguments)

    def FitToPage(self):
        self.com_object.FitToPage()

    def fittopage(self):
        """Alias for FitToPage"""
        return self.FitToPage()

    def fit_to_page(self):
        """Alias for FitToPage"""
        return self.FitToPage()

    def IsSectionExpanded(self, sectionIndex=None):
        arguments = com_arguments([unwrap(a) for a in [sectionIndex]])
        return self.com_object.IsSectionExpanded(*arguments)

    def issectionexpanded(self, sectionIndex=None):
        """Alias for IsSectionExpanded"""
        arguments = [sectionIndex]
        return self.IsSectionExpanded(*arguments)

    def is_section_expanded(self, sectionIndex=None):
        """Alias for IsSectionExpanded"""
        arguments = [sectionIndex]
        return self.IsSectionExpanded(*arguments)

    def LargeScroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        arguments = com_arguments([unwrap(a) for a in [Down, Up, ToRight, ToLeft]])
        self.com_object.LargeScroll(*arguments)

    def largescroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        """Alias for LargeScroll"""
        arguments = [Down, Up, ToRight, ToLeft]
        return self.LargeScroll(*arguments)

    def large_scroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        """Alias for LargeScroll"""
        arguments = [Down, Up, ToRight, ToLeft]
        return self.LargeScroll(*arguments)

    def NewWindow(self):
        return DocumentWindow(self.com_object.NewWindow())

    def newwindow(self):
        """Alias for NewWindow"""
        return self.NewWindow()

    def new_window(self):
        """Alias for NewWindow"""
        return self.NewWindow()

    def PointsToScreenPixelsX(self, Points=None):
        arguments = com_arguments([unwrap(a) for a in [Points]])
        return self.com_object.PointsToScreenPixelsX(*arguments)

    def pointstoscreenpixelsx(self, Points=None):
        """Alias for PointsToScreenPixelsX"""
        arguments = [Points]
        return self.PointsToScreenPixelsX(*arguments)

    def points_to_screen_pixels_x(self, Points=None):
        """Alias for PointsToScreenPixelsX"""
        arguments = [Points]
        return self.PointsToScreenPixelsX(*arguments)

    def PointsToScreenPixelsY(self, Points=None):
        arguments = com_arguments([unwrap(a) for a in [Points]])
        return self.com_object.PointsToScreenPixelsY(*arguments)

    def pointstoscreenpixelsy(self, Points=None):
        """Alias for PointsToScreenPixelsY"""
        arguments = [Points]
        return self.PointsToScreenPixelsY(*arguments)

    def points_to_screen_pixels_y(self, Points=None):
        """Alias for PointsToScreenPixelsY"""
        arguments = [Points]
        return self.PointsToScreenPixelsY(*arguments)

    def RangeFromPoint(self, x=None, y=None):
        arguments = com_arguments([unwrap(a) for a in [x, y]])
        self.com_object.RangeFromPoint(*arguments)

    def rangefrompoint(self, x=None, y=None):
        """Alias for RangeFromPoint"""
        arguments = [x, y]
        return self.RangeFromPoint(*arguments)

    def range_from_point(self, x=None, y=None):
        """Alias for RangeFromPoint"""
        arguments = [x, y]
        return self.RangeFromPoint(*arguments)

    def ScrollIntoView(self, Left=None, Top=None, Width=None, Height=None, Start=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height, Start]])
        self.com_object.ScrollIntoView(*arguments)

    def scrollintoview(self, Left=None, Top=None, Width=None, Height=None, Start=None):
        """Alias for ScrollIntoView"""
        arguments = [Left, Top, Width, Height, Start]
        return self.ScrollIntoView(*arguments)

    def scroll_into_view(self, Left=None, Top=None, Width=None, Height=None, Start=None):
        """Alias for ScrollIntoView"""
        arguments = [Left, Top, Width, Height, Start]
        return self.ScrollIntoView(*arguments)

    def SmallScroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        arguments = com_arguments([unwrap(a) for a in [Down, Up, ToRight, ToLeft]])
        self.com_object.SmallScroll(*arguments)

    def smallscroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        """Alias for SmallScroll"""
        arguments = [Down, Up, ToRight, ToLeft]
        return self.SmallScroll(*arguments)

    def small_scroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        """Alias for SmallScroll"""
        arguments = [Down, Up, ToRight, ToLeft]
        return self.SmallScroll(*arguments)


class DocumentWindows:

    def __init__(self, documentwindows=None):
        self.com_object= documentwindows

    def __call__(self, item):
        return DocumentWindow(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Arrange(self, arrangeStyle=None):
        arguments = com_arguments([unwrap(a) for a in [arrangeStyle]])
        return self.com_object.Arrange(*arguments)

    def arrange(self, arrangeStyle=None):
        """Alias for Arrange"""
        arguments = [arrangeStyle]
        return self.Arrange(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return DocumentWindow(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class DownBars:

    def __init__(self, downbars=None):
        self.com_object= downbars

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class DropLines:

    def __init__(self, droplines=None):
        self.com_object= droplines

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Border(self):
        return ChartBorder(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Effect:

    def __init__(self, effect=None):
        self.com_object= effect

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Behaviors(self):
        return AnimationBehaviors(self.com_object.Behaviors)

    @property
    def behaviors(self):
        """Alias for Behaviors"""
        return self.Behaviors

    @property
    def DisplayName(self):
        return self.com_object.DisplayName

    @property
    def displayname(self):
        """Alias for DisplayName"""
        return self.DisplayName

    @property
    def display_name(self):
        """Alias for DisplayName"""
        return self.DisplayName

    @property
    def EffectInformation(self):
        return EffectInformation(self.com_object.EffectInformation)

    @property
    def effectinformation(self):
        """Alias for EffectInformation"""
        return self.EffectInformation

    @property
    def effect_information(self):
        """Alias for EffectInformation"""
        return self.EffectInformation

    @property
    def EffectParameters(self):
        return EffectParameters(self.com_object.EffectParameters)

    @property
    def effectparameters(self):
        """Alias for EffectParameters"""
        return self.EffectParameters

    @property
    def effect_parameters(self):
        """Alias for EffectParameters"""
        return self.EffectParameters

    @property
    def EffectType(self):
        return self.com_object.EffectType

    @EffectType.setter
    def EffectType(self, value):
        self.com_object.EffectType = value

    @property
    def effecttype(self):
        """Alias for EffectType"""
        return self.EffectType

    @effecttype.setter
    def effecttype(self, value):
        """Alias for EffectType.setter"""
        self.EffectType = value

    @property
    def effect_type(self):
        """Alias for EffectType"""
        return self.EffectType

    @effect_type.setter
    def effect_type(self, value):
        """Alias for EffectType.setter"""
        self.EffectType = value

    @property
    def Exit(self):
        return self.com_object.Exit

    @Exit.setter
    def Exit(self, value):
        self.com_object.Exit = value

    @property
    def exit(self):
        """Alias for Exit"""
        return self.Exit

    @exit.setter
    def exit(self, value):
        """Alias for Exit.setter"""
        self.Exit = value

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Paragraph(self):
        return self.com_object.Paragraph

    @Paragraph.setter
    def Paragraph(self, value):
        self.com_object.Paragraph = value

    @property
    def paragraph(self):
        """Alias for Paragraph"""
        return self.Paragraph

    @paragraph.setter
    def paragraph(self, value):
        """Alias for Paragraph.setter"""
        self.Paragraph = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Shape(self):
        return Shape(self.com_object.Shape)

    @property
    def shape(self):
        """Alias for Shape"""
        return self.Shape

    @property
    def TextRangeLength(self):
        return self.com_object.TextRangeLength

    @TextRangeLength.setter
    def TextRangeLength(self, value):
        self.com_object.TextRangeLength = value

    @property
    def textrangelength(self):
        """Alias for TextRangeLength"""
        return self.TextRangeLength

    @textrangelength.setter
    def textrangelength(self, value):
        """Alias for TextRangeLength.setter"""
        self.TextRangeLength = value

    @property
    def text_range_length(self):
        """Alias for TextRangeLength"""
        return self.TextRangeLength

    @text_range_length.setter
    def text_range_length(self, value):
        """Alias for TextRangeLength.setter"""
        self.TextRangeLength = value

    @property
    def TextRangeStart(self):
        return self.com_object.TextRangeStart

    @TextRangeStart.setter
    def TextRangeStart(self, value):
        self.com_object.TextRangeStart = value

    @property
    def textrangestart(self):
        """Alias for TextRangeStart"""
        return self.TextRangeStart

    @textrangestart.setter
    def textrangestart(self, value):
        """Alias for TextRangeStart.setter"""
        self.TextRangeStart = value

    @property
    def text_range_start(self):
        """Alias for TextRangeStart"""
        return self.TextRangeStart

    @text_range_start.setter
    def text_range_start(self, value):
        """Alias for TextRangeStart.setter"""
        self.TextRangeStart = value

    @property
    def Timing(self):
        return Timing(self.com_object.Timing)

    @property
    def timing(self):
        """Alias for Timing"""
        return self.Timing

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def MoveAfter(self, Effect=None):
        arguments = com_arguments([unwrap(a) for a in [Effect]])
        self.com_object.MoveAfter(*arguments)

    def moveafter(self, Effect=None):
        """Alias for MoveAfter"""
        arguments = [Effect]
        return self.MoveAfter(*arguments)

    def move_after(self, Effect=None):
        """Alias for MoveAfter"""
        arguments = [Effect]
        return self.MoveAfter(*arguments)

    def MoveBefore(self, Effect=None):
        arguments = com_arguments([unwrap(a) for a in [Effect]])
        self.com_object.MoveBefore(*arguments)

    def movebefore(self, Effect=None):
        """Alias for MoveBefore"""
        arguments = [Effect]
        return self.MoveBefore(*arguments)

    def move_before(self, Effect=None):
        """Alias for MoveBefore"""
        arguments = [Effect]
        return self.MoveBefore(*arguments)

    def MoveTo(self, toPos=None):
        arguments = com_arguments([unwrap(a) for a in [toPos]])
        self.com_object.MoveTo(*arguments)

    def moveto(self, toPos=None):
        """Alias for MoveTo"""
        arguments = [toPos]
        return self.MoveTo(*arguments)

    def move_to(self, toPos=None):
        """Alias for MoveTo"""
        arguments = [toPos]
        return self.MoveTo(*arguments)


class EffectInformation:

    def __init__(self, effectinformation=None):
        self.com_object= effectinformation

    @property
    def AfterEffect(self):
        return PpAfterEffect(self.com_object.AfterEffect)

    @property
    def aftereffect(self):
        """Alias for AfterEffect"""
        return self.AfterEffect

    @property
    def after_effect(self):
        """Alias for AfterEffect"""
        return self.AfterEffect

    @property
    def AnimateBackground(self):
        return self.com_object.AnimateBackground

    @property
    def animatebackground(self):
        """Alias for AnimateBackground"""
        return self.AnimateBackground

    @property
    def animate_background(self):
        """Alias for AnimateBackground"""
        return self.AnimateBackground

    @property
    def AnimateTextInReverse(self):
        return self.com_object.AnimateTextInReverse

    @AnimateTextInReverse.setter
    def AnimateTextInReverse(self, value):
        self.com_object.AnimateTextInReverse = value

    @property
    def animatetextinreverse(self):
        """Alias for AnimateTextInReverse"""
        return self.AnimateTextInReverse

    @animatetextinreverse.setter
    def animatetextinreverse(self, value):
        """Alias for AnimateTextInReverse.setter"""
        self.AnimateTextInReverse = value

    @property
    def animate_text_in_reverse(self):
        """Alias for AnimateTextInReverse"""
        return self.AnimateTextInReverse

    @animate_text_in_reverse.setter
    def animate_text_in_reverse(self, value):
        """Alias for AnimateTextInReverse.setter"""
        self.AnimateTextInReverse = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BuildByLevelEffect(self):
        return self.com_object.BuildByLevelEffect

    @property
    def buildbyleveleffect(self):
        """Alias for BuildByLevelEffect"""
        return self.BuildByLevelEffect

    @property
    def build_by_level_effect(self):
        """Alias for BuildByLevelEffect"""
        return self.BuildByLevelEffect

    @property
    def Dim(self):
        return ColorFormat(self.com_object.Dim)

    @property
    def dim(self):
        """Alias for Dim"""
        return self.Dim

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PlaySettings(self):
        return PlaySettings(self.com_object.PlaySettings)

    @property
    def playsettings(self):
        """Alias for PlaySettings"""
        return self.PlaySettings

    @property
    def play_settings(self):
        """Alias for PlaySettings"""
        return self.PlaySettings

    @property
    def SoundEffect(self):
        return SoundEffect(self.com_object.SoundEffect)

    @property
    def soundeffect(self):
        """Alias for SoundEffect"""
        return self.SoundEffect

    @property
    def sound_effect(self):
        """Alias for SoundEffect"""
        return self.SoundEffect

    @property
    def TextUnitEffect(self):
        return self.com_object.TextUnitEffect

    @property
    def textuniteffect(self):
        """Alias for TextUnitEffect"""
        return self.TextUnitEffect

    @property
    def text_unit_effect(self):
        """Alias for TextUnitEffect"""
        return self.TextUnitEffect


class EffectParameters:

    def __init__(self, effectparameters=None):
        self.com_object= effectparameters

    @property
    def Amount(self):
        return self.com_object.Amount

    @Amount.setter
    def Amount(self, value):
        self.com_object.Amount = value

    @property
    def amount(self):
        """Alias for Amount"""
        return self.Amount

    @amount.setter
    def amount(self, value):
        """Alias for Amount.setter"""
        self.Amount = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Color2(self):
        return ColorFormat(self.com_object.Color2)

    @property
    def color2(self):
        """Alias for Color2"""
        return self.Color2

    @property
    def Direction(self):
        return self.com_object.Direction

    @Direction.setter
    def Direction(self, value):
        self.com_object.Direction = value

    @property
    def direction(self):
        """Alias for Direction"""
        return self.Direction

    @direction.setter
    def direction(self, value):
        """Alias for Direction.setter"""
        self.Direction = value

    @property
    def FontName(self):
        return self.com_object.FontName

    @FontName.setter
    def FontName(self, value):
        self.com_object.FontName = value

    @property
    def fontname(self):
        """Alias for FontName"""
        return self.FontName

    @fontname.setter
    def fontname(self, value):
        """Alias for FontName.setter"""
        self.FontName = value

    @property
    def font_name(self):
        """Alias for FontName"""
        return self.FontName

    @font_name.setter
    def font_name(self, value):
        """Alias for FontName.setter"""
        self.FontName = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Relative(self):
        return self.com_object.Relative

    @Relative.setter
    def Relative(self, value):
        self.com_object.Relative = value

    @property
    def relative(self):
        """Alias for Relative"""
        return self.Relative

    @relative.setter
    def relative(self, value):
        """Alias for Relative.setter"""
        self.Relative = value

    @property
    def Size(self):
        return self.com_object.Size

    @Size.setter
    def Size(self, value):
        self.com_object.Size = value

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @size.setter
    def size(self, value):
        """Alias for Size.setter"""
        self.Size = value


class ErrorBars:

    def __init__(self, errorbars=None):
        self.com_object= errorbars

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Border(self):
        return ChartBorder(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def EndStyle(self):
        return self.com_object.EndStyle

    @EndStyle.setter
    def EndStyle(self, value):
        self.com_object.EndStyle = value

    @property
    def endstyle(self):
        """Alias for EndStyle"""
        return self.EndStyle

    @endstyle.setter
    def endstyle(self, value):
        """Alias for EndStyle.setter"""
        self.EndStyle = value

    @property
    def end_style(self):
        """Alias for EndStyle"""
        return self.EndStyle

    @end_style.setter
    def end_style(self, value):
        """Alias for EndStyle.setter"""
        self.EndStyle = value

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def ClearFormats(self):
        self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class ExtraColors:

    def __init__(self, extracolors=None):
        self.com_object= extracolors

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Type]])
        self.com_object.Add(*arguments)

    def add(self, Type=None):
        """Alias for Add"""
        arguments = [Type]
        return self.Add(*arguments)

    def Clear(self):
        self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class FileConverter:

    def __init__(self, fileconverter=None):
        self.com_object= fileconverter

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def CanOpen(self):
        return self.com_object.CanOpen

    @property
    def canopen(self):
        """Alias for CanOpen"""
        return self.CanOpen

    @property
    def can_open(self):
        """Alias for CanOpen"""
        return self.CanOpen

    @property
    def CanSave(self):
        return self.com_object.CanSave

    @property
    def cansave(self):
        """Alias for CanSave"""
        return self.CanSave

    @property
    def can_save(self):
        """Alias for CanSave"""
        return self.CanSave

    @property
    def ClassName(self):
        return self.com_object.ClassName

    @property
    def classname(self):
        """Alias for ClassName"""
        return self.ClassName

    @property
    def class_name(self):
        """Alias for ClassName"""
        return self.ClassName

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Extensions(self):
        return FileConverter(self.com_object.Extensions)

    @property
    def extensions(self):
        """Alias for Extensions"""
        return self.Extensions

    @property
    def FormatName(self):
        return self.com_object.FormatName

    @property
    def formatname(self):
        """Alias for FormatName"""
        return self.FormatName

    @property
    def format_name(self):
        """Alias for FormatName"""
        return self.FormatName

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def OpenFormat(self):
        return self.com_object.OpenFormat

    @property
    def openformat(self):
        """Alias for OpenFormat"""
        return self.OpenFormat

    @property
    def open_format(self):
        """Alias for OpenFormat"""
        return self.OpenFormat

    @property
    def Parent(self):
        return FileConverter(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Path(self):
        return self.com_object.Path

    @property
    def path(self):
        """Alias for Path"""
        return self.Path

    @property
    def SaveFormat(self):
        return self.com_object.SaveFormat

    @property
    def saveformat(self):
        """Alias for SaveFormat"""
        return self.SaveFormat

    @property
    def save_format(self):
        """Alias for SaveFormat"""
        return self.SaveFormat


class FileConverters:

    def __init__(self, fileconverters=None):
        self.com_object= fileconverters

    def __call__(self, item):
        return FileConverter(self.com_object(item))

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return FileConverter(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class FillFormat:

    def __init__(self, fillformat=None):
        self.com_object= fillformat

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BackColor(self):
        return ColorFormat(self.com_object.BackColor)

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ForeColor(self):
        return ColorFormat(self.com_object.ForeColor)

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def GradientAngle(self):
        return self.com_object.GradientAngle

    @GradientAngle.setter
    def GradientAngle(self, value):
        self.com_object.GradientAngle = value

    @property
    def gradientangle(self):
        """Alias for GradientAngle"""
        return self.GradientAngle

    @gradientangle.setter
    def gradientangle(self, value):
        """Alias for GradientAngle.setter"""
        self.GradientAngle = value

    @property
    def gradient_angle(self):
        """Alias for GradientAngle"""
        return self.GradientAngle

    @gradient_angle.setter
    def gradient_angle(self, value):
        """Alias for GradientAngle.setter"""
        self.GradientAngle = value

    @property
    def GradientColorType(self):
        return self.com_object.GradientColorType

    @property
    def gradientcolortype(self):
        """Alias for GradientColorType"""
        return self.GradientColorType

    @property
    def gradient_color_type(self):
        """Alias for GradientColorType"""
        return self.GradientColorType

    @property
    def GradientDegree(self):
        return self.com_object.GradientDegree

    @property
    def gradientdegree(self):
        """Alias for GradientDegree"""
        return self.GradientDegree

    @property
    def gradient_degree(self):
        """Alias for GradientDegree"""
        return self.GradientDegree

    @property
    def GradientStops(self):
        return self.com_object.GradientStops

    @property
    def gradientstops(self):
        """Alias for GradientStops"""
        return self.GradientStops

    @property
    def gradient_stops(self):
        """Alias for GradientStops"""
        return self.GradientStops

    @property
    def GradientStyle(self):
        return self.com_object.GradientStyle

    @property
    def gradientstyle(self):
        """Alias for GradientStyle"""
        return self.GradientStyle

    @property
    def gradient_style(self):
        """Alias for GradientStyle"""
        return self.GradientStyle

    @property
    def GradientVariant(self):
        return self.com_object.GradientVariant

    @property
    def gradientvariant(self):
        """Alias for GradientVariant"""
        return self.GradientVariant

    @property
    def gradient_variant(self):
        """Alias for GradientVariant"""
        return self.GradientVariant

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Pattern(self):
        return self.com_object.Pattern

    @property
    def pattern(self):
        """Alias for Pattern"""
        return self.Pattern

    @property
    def PictureEffects(self):
        return self.com_object.PictureEffects

    @property
    def pictureeffects(self):
        """Alias for PictureEffects"""
        return self.PictureEffects

    @property
    def picture_effects(self):
        """Alias for PictureEffects"""
        return self.PictureEffects

    @property
    def PresetGradientType(self):
        return self.com_object.PresetGradientType

    @property
    def presetgradienttype(self):
        """Alias for PresetGradientType"""
        return self.PresetGradientType

    @property
    def preset_gradient_type(self):
        """Alias for PresetGradientType"""
        return self.PresetGradientType

    @property
    def PresetTexture(self):
        return self.com_object.PresetTexture

    @property
    def presettexture(self):
        """Alias for PresetTexture"""
        return self.PresetTexture

    @property
    def preset_texture(self):
        """Alias for PresetTexture"""
        return self.PresetTexture

    @property
    def RotateWithObject(self):
        return self.com_object.RotateWithObject

    @RotateWithObject.setter
    def RotateWithObject(self, value):
        self.com_object.RotateWithObject = value

    @property
    def rotatewithobject(self):
        """Alias for RotateWithObject"""
        return self.RotateWithObject

    @rotatewithobject.setter
    def rotatewithobject(self, value):
        """Alias for RotateWithObject.setter"""
        self.RotateWithObject = value

    @property
    def rotate_with_object(self):
        """Alias for RotateWithObject"""
        return self.RotateWithObject

    @rotate_with_object.setter
    def rotate_with_object(self, value):
        """Alias for RotateWithObject.setter"""
        self.RotateWithObject = value

    @property
    def TextureAlignment(self):
        return self.com_object.TextureAlignment

    @TextureAlignment.setter
    def TextureAlignment(self, value):
        self.com_object.TextureAlignment = value

    @property
    def texturealignment(self):
        """Alias for TextureAlignment"""
        return self.TextureAlignment

    @texturealignment.setter
    def texturealignment(self, value):
        """Alias for TextureAlignment.setter"""
        self.TextureAlignment = value

    @property
    def texture_alignment(self):
        """Alias for TextureAlignment"""
        return self.TextureAlignment

    @texture_alignment.setter
    def texture_alignment(self, value):
        """Alias for TextureAlignment.setter"""
        self.TextureAlignment = value

    @property
    def TextureHorizontalScale(self):
        return self.com_object.TextureHorizontalScale

    @TextureHorizontalScale.setter
    def TextureHorizontalScale(self, value):
        self.com_object.TextureHorizontalScale = value

    @property
    def texturehorizontalscale(self):
        """Alias for TextureHorizontalScale"""
        return self.TextureHorizontalScale

    @texturehorizontalscale.setter
    def texturehorizontalscale(self, value):
        """Alias for TextureHorizontalScale.setter"""
        self.TextureHorizontalScale = value

    @property
    def texture_horizontal_scale(self):
        """Alias for TextureHorizontalScale"""
        return self.TextureHorizontalScale

    @texture_horizontal_scale.setter
    def texture_horizontal_scale(self, value):
        """Alias for TextureHorizontalScale.setter"""
        self.TextureHorizontalScale = value

    @property
    def TextureName(self):
        return self.com_object.TextureName

    @property
    def texturename(self):
        """Alias for TextureName"""
        return self.TextureName

    @property
    def texture_name(self):
        """Alias for TextureName"""
        return self.TextureName

    @property
    def TextureOffsetX(self):
        return self.com_object.TextureOffsetX

    @TextureOffsetX.setter
    def TextureOffsetX(self, value):
        self.com_object.TextureOffsetX = value

    @property
    def textureoffsetx(self):
        """Alias for TextureOffsetX"""
        return self.TextureOffsetX

    @textureoffsetx.setter
    def textureoffsetx(self, value):
        """Alias for TextureOffsetX.setter"""
        self.TextureOffsetX = value

    @property
    def texture_offset_x(self):
        """Alias for TextureOffsetX"""
        return self.TextureOffsetX

    @texture_offset_x.setter
    def texture_offset_x(self, value):
        """Alias for TextureOffsetX.setter"""
        self.TextureOffsetX = value

    @property
    def TextureOffsetY(self):
        return self.com_object.TextureOffsetY

    @TextureOffsetY.setter
    def TextureOffsetY(self, value):
        self.com_object.TextureOffsetY = value

    @property
    def textureoffsety(self):
        """Alias for TextureOffsetY"""
        return self.TextureOffsetY

    @textureoffsety.setter
    def textureoffsety(self, value):
        """Alias for TextureOffsetY.setter"""
        self.TextureOffsetY = value

    @property
    def texture_offset_y(self):
        """Alias for TextureOffsetY"""
        return self.TextureOffsetY

    @texture_offset_y.setter
    def texture_offset_y(self, value):
        """Alias for TextureOffsetY.setter"""
        self.TextureOffsetY = value

    @property
    def TextureTile(self):
        return self.com_object.TextureTile

    @TextureTile.setter
    def TextureTile(self, value):
        self.com_object.TextureTile = value

    @property
    def texturetile(self):
        """Alias for TextureTile"""
        return self.TextureTile

    @texturetile.setter
    def texturetile(self, value):
        """Alias for TextureTile.setter"""
        self.TextureTile = value

    @property
    def texture_tile(self):
        """Alias for TextureTile"""
        return self.TextureTile

    @texture_tile.setter
    def texture_tile(self, value):
        """Alias for TextureTile.setter"""
        self.TextureTile = value

    @property
    def TextureType(self):
        return self.com_object.TextureType

    @property
    def texturetype(self):
        """Alias for TextureType"""
        return self.TextureType

    @property
    def texture_type(self):
        """Alias for TextureType"""
        return self.TextureType

    @property
    def TextureVerticalScale(self):
        return self.com_object.TextureVerticalScale

    @TextureVerticalScale.setter
    def TextureVerticalScale(self, value):
        self.com_object.TextureVerticalScale = value

    @property
    def textureverticalscale(self):
        """Alias for TextureVerticalScale"""
        return self.TextureVerticalScale

    @textureverticalscale.setter
    def textureverticalscale(self, value):
        """Alias for TextureVerticalScale.setter"""
        self.TextureVerticalScale = value

    @property
    def texture_vertical_scale(self):
        """Alias for TextureVerticalScale"""
        return self.TextureVerticalScale

    @texture_vertical_scale.setter
    def texture_vertical_scale(self, value):
        """Alias for TextureVerticalScale.setter"""
        self.TextureVerticalScale = value

    @property
    def Transparency(self):
        return self.com_object.Transparency

    @Transparency.setter
    def Transparency(self, value):
        self.com_object.Transparency = value

    @property
    def transparency(self):
        """Alias for Transparency"""
        return self.Transparency

    @transparency.setter
    def transparency(self, value):
        """Alias for Transparency.setter"""
        self.Transparency = value

    @property
    def Type(self):
        return self.com_object.Type

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    def Background(self):
        self.com_object.Background()

    def background(self):
        """Alias for Background"""
        return self.Background()

    def OneColorGradient(self, Style=None, Variant=None, Degree=None):
        arguments = com_arguments([unwrap(a) for a in [Style, Variant, Degree]])
        self.com_object.OneColorGradient(*arguments)

    def onecolorgradient(self, Style=None, Variant=None, Degree=None):
        """Alias for OneColorGradient"""
        arguments = [Style, Variant, Degree]
        return self.OneColorGradient(*arguments)

    def one_color_gradient(self, Style=None, Variant=None, Degree=None):
        """Alias for OneColorGradient"""
        arguments = [Style, Variant, Degree]
        return self.OneColorGradient(*arguments)

    def Patterned(self, Pattern=None):
        arguments = com_arguments([unwrap(a) for a in [Pattern]])
        self.com_object.Patterned(*arguments)

    def patterned(self, Pattern=None):
        """Alias for Patterned"""
        arguments = [Pattern]
        return self.Patterned(*arguments)

    def PresetGradient(self, Style=None, Variant=None, PresetGradientType=None):
        arguments = com_arguments([unwrap(a) for a in [Style, Variant, PresetGradientType]])
        self.com_object.PresetGradient(*arguments)

    def presetgradient(self, Style=None, Variant=None, PresetGradientType=None):
        """Alias for PresetGradient"""
        arguments = [Style, Variant, PresetGradientType]
        return self.PresetGradient(*arguments)

    def preset_gradient(self, Style=None, Variant=None, PresetGradientType=None):
        """Alias for PresetGradient"""
        arguments = [Style, Variant, PresetGradientType]
        return self.PresetGradient(*arguments)

    def PresetTextured(self, PresetTexture=None):
        arguments = com_arguments([unwrap(a) for a in [PresetTexture]])
        self.com_object.PresetTextured(*arguments)

    def presettextured(self, PresetTexture=None):
        """Alias for PresetTextured"""
        arguments = [PresetTexture]
        return self.PresetTextured(*arguments)

    def preset_textured(self, PresetTexture=None):
        """Alias for PresetTextured"""
        arguments = [PresetTexture]
        return self.PresetTextured(*arguments)

    def Solid(self):
        self.com_object.Solid()

    def solid(self):
        """Alias for Solid"""
        return self.Solid()

    def TwoColorGradient(self, Style=None, Variant=None):
        arguments = com_arguments([unwrap(a) for a in [Style, Variant]])
        self.com_object.TwoColorGradient(*arguments)

    def twocolorgradient(self, Style=None, Variant=None):
        """Alias for TwoColorGradient"""
        arguments = [Style, Variant]
        return self.TwoColorGradient(*arguments)

    def two_color_gradient(self, Style=None, Variant=None):
        """Alias for TwoColorGradient"""
        arguments = [Style, Variant]
        return self.TwoColorGradient(*arguments)

    def UserPicture(self, PictureFile=None):
        arguments = com_arguments([unwrap(a) for a in [PictureFile]])
        self.com_object.UserPicture(*arguments)

    def userpicture(self, PictureFile=None):
        """Alias for UserPicture"""
        arguments = [PictureFile]
        return self.UserPicture(*arguments)

    def user_picture(self, PictureFile=None):
        """Alias for UserPicture"""
        arguments = [PictureFile]
        return self.UserPicture(*arguments)

    def UserTextured(self, TextureFile=None):
        arguments = com_arguments([unwrap(a) for a in [TextureFile]])
        self.com_object.UserTextured(*arguments)

    def usertextured(self, TextureFile=None):
        """Alias for UserTextured"""
        arguments = [TextureFile]
        return self.UserTextured(*arguments)

    def user_textured(self, TextureFile=None):
        """Alias for UserTextured"""
        arguments = [TextureFile]
        return self.UserTextured(*arguments)


class FilterEffect:

    def __init__(self, filtereffect=None):
        self.com_object= filtereffect

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Reveal(self):
        return self.com_object.Reveal

    @Reveal.setter
    def Reveal(self, value):
        self.com_object.Reveal = value

    @property
    def reveal(self):
        """Alias for Reveal"""
        return self.Reveal

    @reveal.setter
    def reveal(self, value):
        """Alias for Reveal.setter"""
        self.Reveal = value

    @property
    def Subtype(self):
        return self.com_object.Subtype

    @Subtype.setter
    def Subtype(self, value):
        self.com_object.Subtype = value

    @property
    def subtype(self):
        """Alias for Subtype"""
        return self.Subtype

    @subtype.setter
    def subtype(self, value):
        """Alias for Subtype.setter"""
        self.Subtype = value

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value


class Floor:

    def __init__(self, floor=None):
        self.com_object= floor

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PictureType(self):
        return self.com_object.PictureType

    @PictureType.setter
    def PictureType(self, value):
        self.com_object.PictureType = value

    @property
    def picturetype(self):
        """Alias for PictureType"""
        return self.PictureType

    @picturetype.setter
    def picturetype(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def picture_type(self):
        """Alias for PictureType"""
        return self.PictureType

    @picture_type.setter
    def picture_type(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def Thickness(self):
        return self.com_object.Thickness

    @Thickness.setter
    def Thickness(self, value):
        self.com_object.Thickness = value

    @property
    def thickness(self):
        """Alias for Thickness"""
        return self.Thickness

    @thickness.setter
    def thickness(self, value):
        """Alias for Thickness.setter"""
        self.Thickness = value

    def ClearFormats(self):
        self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Paste(self):
        self.com_object.Paste()

    def paste(self):
        """Alias for Paste"""
        return self.Paste()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Font:

    def __init__(self, font=None):
        self.com_object= font

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoRotateNumbers(self):
        return self.com_object.AutoRotateNumbers

    @AutoRotateNumbers.setter
    def AutoRotateNumbers(self, value):
        self.com_object.AutoRotateNumbers = value

    @property
    def autorotatenumbers(self):
        """Alias for AutoRotateNumbers"""
        return self.AutoRotateNumbers

    @autorotatenumbers.setter
    def autorotatenumbers(self, value):
        """Alias for AutoRotateNumbers.setter"""
        self.AutoRotateNumbers = value

    @property
    def auto_rotate_numbers(self):
        """Alias for AutoRotateNumbers"""
        return self.AutoRotateNumbers

    @auto_rotate_numbers.setter
    def auto_rotate_numbers(self, value):
        """Alias for AutoRotateNumbers.setter"""
        self.AutoRotateNumbers = value

    @property
    def BaselineOffset(self):
        return self.com_object.BaselineOffset

    @BaselineOffset.setter
    def BaselineOffset(self, value):
        self.com_object.BaselineOffset = value

    @property
    def baselineoffset(self):
        """Alias for BaselineOffset"""
        return self.BaselineOffset

    @baselineoffset.setter
    def baselineoffset(self, value):
        """Alias for BaselineOffset.setter"""
        self.BaselineOffset = value

    @property
    def baseline_offset(self):
        """Alias for BaselineOffset"""
        return self.BaselineOffset

    @baseline_offset.setter
    def baseline_offset(self, value):
        """Alias for BaselineOffset.setter"""
        self.BaselineOffset = value

    @property
    def Bold(self):
        return self.com_object.Bold

    @Bold.setter
    def Bold(self, value):
        self.com_object.Bold = value

    @property
    def bold(self):
        """Alias for Bold"""
        return self.Bold

    @bold.setter
    def bold(self, value):
        """Alias for Bold.setter"""
        self.Bold = value

    @property
    def Color(self):
        return Font(self.com_object.Color)

    @Color.setter
    def Color(self, value):
        self.com_object.Color = value

    @property
    def color(self):
        """Alias for Color"""
        return self.Color

    @color.setter
    def color(self, value):
        """Alias for Color.setter"""
        self.Color = value

    @property
    def Embeddable(self):
        return self.com_object.Embeddable

    @property
    def embeddable(self):
        """Alias for Embeddable"""
        return self.Embeddable

    @property
    def Embedded(self):
        return self.com_object.Embedded

    @property
    def embedded(self):
        """Alias for Embedded"""
        return self.Embedded

    @property
    def Emboss(self):
        return self.com_object.Emboss

    @Emboss.setter
    def Emboss(self, value):
        self.com_object.Emboss = value

    @property
    def emboss(self):
        """Alias for Emboss"""
        return self.Emboss

    @emboss.setter
    def emboss(self, value):
        """Alias for Emboss.setter"""
        self.Emboss = value

    @property
    def Italic(self):
        return self.com_object.Italic

    @Italic.setter
    def Italic(self, value):
        self.com_object.Italic = value

    @property
    def italic(self):
        """Alias for Italic"""
        return self.Italic

    @italic.setter
    def italic(self, value):
        """Alias for Italic.setter"""
        self.Italic = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def NameAscii(self):
        return self.com_object.NameAscii

    @NameAscii.setter
    def NameAscii(self, value):
        self.com_object.NameAscii = value

    @property
    def nameascii(self):
        """Alias for NameAscii"""
        return self.NameAscii

    @nameascii.setter
    def nameascii(self, value):
        """Alias for NameAscii.setter"""
        self.NameAscii = value

    @property
    def name_ascii(self):
        """Alias for NameAscii"""
        return self.NameAscii

    @name_ascii.setter
    def name_ascii(self, value):
        """Alias for NameAscii.setter"""
        self.NameAscii = value

    @property
    def NameComplexScript(self):
        return self.com_object.NameComplexScript

    @NameComplexScript.setter
    def NameComplexScript(self, value):
        self.com_object.NameComplexScript = value

    @property
    def namecomplexscript(self):
        """Alias for NameComplexScript"""
        return self.NameComplexScript

    @namecomplexscript.setter
    def namecomplexscript(self, value):
        """Alias for NameComplexScript.setter"""
        self.NameComplexScript = value

    @property
    def name_complex_script(self):
        """Alias for NameComplexScript"""
        return self.NameComplexScript

    @name_complex_script.setter
    def name_complex_script(self, value):
        """Alias for NameComplexScript.setter"""
        self.NameComplexScript = value

    @property
    def NameFarEast(self):
        return self.com_object.NameFarEast

    @NameFarEast.setter
    def NameFarEast(self, value):
        self.com_object.NameFarEast = value

    @property
    def namefareast(self):
        """Alias for NameFarEast"""
        return self.NameFarEast

    @namefareast.setter
    def namefareast(self, value):
        """Alias for NameFarEast.setter"""
        self.NameFarEast = value

    @property
    def name_far_east(self):
        """Alias for NameFarEast"""
        return self.NameFarEast

    @name_far_east.setter
    def name_far_east(self, value):
        """Alias for NameFarEast.setter"""
        self.NameFarEast = value

    @property
    def NameOther(self):
        return self.com_object.NameOther

    @NameOther.setter
    def NameOther(self, value):
        self.com_object.NameOther = value

    @property
    def nameother(self):
        """Alias for NameOther"""
        return self.NameOther

    @nameother.setter
    def nameother(self, value):
        """Alias for NameOther.setter"""
        self.NameOther = value

    @property
    def name_other(self):
        """Alias for NameOther"""
        return self.NameOther

    @name_other.setter
    def name_other(self, value):
        """Alias for NameOther.setter"""
        self.NameOther = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Size(self):
        return self.com_object.Size

    @Size.setter
    def Size(self, value):
        self.com_object.Size = value

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @size.setter
    def size(self, value):
        """Alias for Size.setter"""
        self.Size = value

    @property
    def Subscript(self):
        return self.com_object.Subscript

    @Subscript.setter
    def Subscript(self, value):
        self.com_object.Subscript = value

    @property
    def subscript(self):
        """Alias for Subscript"""
        return self.Subscript

    @subscript.setter
    def subscript(self, value):
        """Alias for Subscript.setter"""
        self.Subscript = value

    @property
    def Superscript(self):
        return self.com_object.Superscript

    @Superscript.setter
    def Superscript(self, value):
        self.com_object.Superscript = value

    @property
    def superscript(self):
        """Alias for Superscript"""
        return self.Superscript

    @superscript.setter
    def superscript(self, value):
        """Alias for Superscript.setter"""
        self.Superscript = value

    @property
    def Underline(self):
        return self.com_object.Underline

    @Underline.setter
    def Underline(self, value):
        self.com_object.Underline = value

    @property
    def underline(self):
        """Alias for Underline"""
        return self.Underline

    @underline.setter
    def underline(self, value):
        """Alias for Underline.setter"""
        self.Underline = value


class Fonts:

    def __init__(self, fonts=None):
        self.com_object= fonts

    def __call__(self, item):
        return Font(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Font(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Replace(self, Original=None, Replacement=None):
        arguments = com_arguments([unwrap(a) for a in [Original, Replacement]])
        self.com_object.Replace(*arguments)

    def replace(self, Original=None, Replacement=None):
        """Alias for Replace"""
        arguments = [Original, Replacement]
        return self.Replace(*arguments)


class FreeformBuilder:

    def __init__(self, freeformbuilder=None):
        self.com_object= freeformbuilder

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def AddNodes(self, SegmentType=None, EditingType=None, X1=None, Y1=None, X2=None, Y2=None, X3=None, Y3=None):
        arguments = com_arguments([unwrap(a) for a in [SegmentType, EditingType, X1, Y1, X2, Y2, X3, Y3]])
        self.com_object.AddNodes(*arguments)

    def addnodes(self, SegmentType=None, EditingType=None, X1=None, Y1=None, X2=None, Y2=None, X3=None, Y3=None):
        """Alias for AddNodes"""
        arguments = [SegmentType, EditingType, X1, Y1, X2, Y2, X3, Y3]
        return self.AddNodes(*arguments)

    def add_nodes(self, SegmentType=None, EditingType=None, X1=None, Y1=None, X2=None, Y2=None, X3=None, Y3=None):
        """Alias for AddNodes"""
        arguments = [SegmentType, EditingType, X1, Y1, X2, Y2, X3, Y3]
        return self.AddNodes(*arguments)

    def ConvertToShape(self):
        return Shape(self.com_object.ConvertToShape())

    def converttoshape(self):
        """Alias for ConvertToShape"""
        return self.ConvertToShape()

    def convert_to_shape(self):
        """Alias for ConvertToShape"""
        return self.ConvertToShape()


class FullSeriesCollection:

    def __init__(self, fullseriescollection=None):
        self.com_object= fullseriescollection

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Series(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Gridlines:

    def __init__(self, gridlines=None):
        self.com_object= gridlines

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Border(self):
        return ChartBorder(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class GroupShapes:

    def __init__(self, groupshapes=None):
        self.com_object= groupshapes

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Shape(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Range(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ShapeRange(self.com_object.Range(*arguments))

    def range(self, Index=None):
        """Alias for Range"""
        arguments = [Index]
        return self.Range(*arguments)


class Guide:

    def __init__(self, guide=None):
        self.com_object= guide

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Color(self):
        return self.com_object.Color

    @property
    def color(self):
        """Alias for Color"""
        return self.Color

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return self.com_object.Position

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class Guides:

    def __init__(self, guides=None):
        self.com_object= guides

    def __call__(self, item):
        return Guide(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self):
        return Guide(self.com_object.Add())

    def add(self):
        """Alias for Add"""
        return self.Add()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Guide(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class HeaderFooter:

    def __init__(self, headerfooter=None):
        self.com_object= headerfooter

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Format(self):
        return self.com_object.Format

    @Format.setter
    def Format(self, value):
        self.com_object.Format = value

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @format.setter
    def format(self, value):
        """Alias for Format.setter"""
        self.Format = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def UseFormat(self):
        return self.com_object.UseFormat

    @UseFormat.setter
    def UseFormat(self, value):
        self.com_object.UseFormat = value

    @property
    def useformat(self):
        """Alias for UseFormat"""
        return self.UseFormat

    @useformat.setter
    def useformat(self, value):
        """Alias for UseFormat.setter"""
        self.UseFormat = value

    @property
    def use_format(self):
        """Alias for UseFormat"""
        return self.UseFormat

    @use_format.setter
    def use_format(self, value):
        """Alias for UseFormat.setter"""
        self.UseFormat = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value


class HeadersFooters:

    def __init__(self, headersfooters=None):
        self.com_object= headersfooters

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def DateAndTime(self):
        return HeaderFooter(self.com_object.DateAndTime)

    @property
    def dateandtime(self):
        """Alias for DateAndTime"""
        return self.DateAndTime

    @property
    def date_and_time(self):
        """Alias for DateAndTime"""
        return self.DateAndTime

    @property
    def DisplayOnTitleSlide(self):
        return self.com_object.DisplayOnTitleSlide

    @DisplayOnTitleSlide.setter
    def DisplayOnTitleSlide(self, value):
        self.com_object.DisplayOnTitleSlide = value

    @property
    def displayontitleslide(self):
        """Alias for DisplayOnTitleSlide"""
        return self.DisplayOnTitleSlide

    @displayontitleslide.setter
    def displayontitleslide(self, value):
        """Alias for DisplayOnTitleSlide.setter"""
        self.DisplayOnTitleSlide = value

    @property
    def display_on_title_slide(self):
        """Alias for DisplayOnTitleSlide"""
        return self.DisplayOnTitleSlide

    @display_on_title_slide.setter
    def display_on_title_slide(self, value):
        """Alias for DisplayOnTitleSlide.setter"""
        self.DisplayOnTitleSlide = value

    @property
    def Footer(self):
        return HeaderFooter(self.com_object.Footer)

    @property
    def footer(self):
        """Alias for Footer"""
        return self.Footer

    @property
    def Header(self):
        return HeaderFooter(self.com_object.Header)

    @property
    def header(self):
        """Alias for Header"""
        return self.Header

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SlideNumber(self):
        return HeaderFooter(self.com_object.SlideNumber)

    @property
    def slidenumber(self):
        """Alias for SlideNumber"""
        return self.SlideNumber

    @property
    def slide_number(self):
        """Alias for SlideNumber"""
        return self.SlideNumber

    def Clear(self):
        self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()


class HiLoLines:

    def __init__(self, hilolines=None):
        self.com_object= hilolines

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Border(self):
        return ChartBorder(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Hyperlink:

    def __init__(self, hyperlink=None):
        self.com_object= hyperlink

    @property
    def Address(self):
        return self.com_object.Address

    @Address.setter
    def Address(self, value):
        self.com_object.Address = value

    @property
    def address(self):
        """Alias for Address"""
        return self.Address

    @address.setter
    def address(self, value):
        """Alias for Address.setter"""
        self.Address = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def EmailSubject(self):
        return self.com_object.EmailSubject

    @EmailSubject.setter
    def EmailSubject(self, value):
        self.com_object.EmailSubject = value

    @property
    def emailsubject(self):
        """Alias for EmailSubject"""
        return self.EmailSubject

    @emailsubject.setter
    def emailsubject(self, value):
        """Alias for EmailSubject.setter"""
        self.EmailSubject = value

    @property
    def email_subject(self):
        """Alias for EmailSubject"""
        return self.EmailSubject

    @email_subject.setter
    def email_subject(self, value):
        """Alias for EmailSubject.setter"""
        self.EmailSubject = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ScreenTip(self):
        return self.com_object.ScreenTip

    @ScreenTip.setter
    def ScreenTip(self, value):
        self.com_object.ScreenTip = value

    @property
    def screentip(self):
        """Alias for ScreenTip"""
        return self.ScreenTip

    @screentip.setter
    def screentip(self, value):
        """Alias for ScreenTip.setter"""
        self.ScreenTip = value

    @property
    def screen_tip(self):
        """Alias for ScreenTip"""
        return self.ScreenTip

    @screen_tip.setter
    def screen_tip(self, value):
        """Alias for ScreenTip.setter"""
        self.ScreenTip = value

    @property
    def ShowAndReturn(self):
        return self.com_object.ShowAndReturn

    @ShowAndReturn.setter
    def ShowAndReturn(self, value):
        self.com_object.ShowAndReturn = value

    @property
    def showandreturn(self):
        """Alias for ShowAndReturn"""
        return self.ShowAndReturn

    @showandreturn.setter
    def showandreturn(self, value):
        """Alias for ShowAndReturn.setter"""
        self.ShowAndReturn = value

    @property
    def show_and_return(self):
        """Alias for ShowAndReturn"""
        return self.ShowAndReturn

    @show_and_return.setter
    def show_and_return(self, value):
        """Alias for ShowAndReturn.setter"""
        self.ShowAndReturn = value

    @property
    def SubAddress(self):
        return self.com_object.SubAddress

    @SubAddress.setter
    def SubAddress(self, value):
        self.com_object.SubAddress = value

    @property
    def subaddress(self):
        """Alias for SubAddress"""
        return self.SubAddress

    @subaddress.setter
    def subaddress(self, value):
        """Alias for SubAddress.setter"""
        self.SubAddress = value

    @property
    def sub_address(self):
        """Alias for SubAddress"""
        return self.SubAddress

    @sub_address.setter
    def sub_address(self, value):
        """Alias for SubAddress.setter"""
        self.SubAddress = value

    @property
    def TextToDisplay(self):
        return self.com_object.TextToDisplay

    @TextToDisplay.setter
    def TextToDisplay(self, value):
        self.com_object.TextToDisplay = value

    @property
    def texttodisplay(self):
        """Alias for TextToDisplay"""
        return self.TextToDisplay

    @texttodisplay.setter
    def texttodisplay(self, value):
        """Alias for TextToDisplay.setter"""
        self.TextToDisplay = value

    @property
    def text_to_display(self):
        """Alias for TextToDisplay"""
        return self.TextToDisplay

    @text_to_display.setter
    def text_to_display(self, value):
        """Alias for TextToDisplay.setter"""
        self.TextToDisplay = value

    @property
    def Type(self):
        return self.com_object.Type

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def AddToFavorites(self):
        self.com_object.AddToFavorites()

    def addtofavorites(self):
        """Alias for AddToFavorites"""
        return self.AddToFavorites()

    def add_to_favorites(self):
        """Alias for AddToFavorites"""
        return self.AddToFavorites()

    def CreateNewDocument(self, FileName=None, EditNow=None, Overwrite=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, EditNow, Overwrite]])
        return self.com_object.CreateNewDocument(*arguments)

    def createnewdocument(self, FileName=None, EditNow=None, Overwrite=None):
        """Alias for CreateNewDocument"""
        arguments = [FileName, EditNow, Overwrite]
        return self.CreateNewDocument(*arguments)

    def create_new_document(self, FileName=None, EditNow=None, Overwrite=None):
        """Alias for CreateNewDocument"""
        arguments = [FileName, EditNow, Overwrite]
        return self.CreateNewDocument(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Follow(self):
        self.com_object.Follow()

    def follow(self):
        """Alias for Follow"""
        return self.Follow()


class Hyperlinks:

    def __init__(self, hyperlinks=None):
        self.com_object= hyperlinks

    def __call__(self, item):
        return Hyperlink(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Hyperlink(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Interior:

    def __init__(self, interior=None):
        self.com_object= interior

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Color(self):
        return self.com_object.Color

    @Color.setter
    def Color(self, value):
        self.com_object.Color = value

    @property
    def color(self):
        """Alias for Color"""
        return self.Color

    @color.setter
    def color(self, value):
        """Alias for Color.setter"""
        self.Color = value

    @property
    def ColorIndex(self):
        return self.com_object.ColorIndex

    @ColorIndex.setter
    def ColorIndex(self, value):
        self.com_object.ColorIndex = value

    @property
    def colorindex(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @colorindex.setter
    def colorindex(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def color_index(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @color_index.setter
    def color_index(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def InvertIfNegative(self):
        return self.com_object.InvertIfNegative

    @InvertIfNegative.setter
    def InvertIfNegative(self, value):
        self.com_object.InvertIfNegative = value

    @property
    def invertifnegative(self):
        """Alias for InvertIfNegative"""
        return self.InvertIfNegative

    @invertifnegative.setter
    def invertifnegative(self, value):
        """Alias for InvertIfNegative.setter"""
        self.InvertIfNegative = value

    @property
    def invert_if_negative(self):
        """Alias for InvertIfNegative"""
        return self.InvertIfNegative

    @invert_if_negative.setter
    def invert_if_negative(self, value):
        """Alias for InvertIfNegative.setter"""
        self.InvertIfNegative = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Pattern(self):
        return XlPattern(self.com_object.Pattern)

    @Pattern.setter
    def Pattern(self, value):
        self.com_object.Pattern = value

    @property
    def pattern(self):
        """Alias for Pattern"""
        return self.Pattern

    @pattern.setter
    def pattern(self, value):
        """Alias for Pattern.setter"""
        self.Pattern = value

    @property
    def PatternColor(self):
        return self.com_object.PatternColor

    @PatternColor.setter
    def PatternColor(self, value):
        self.com_object.PatternColor = value

    @property
    def patterncolor(self):
        """Alias for PatternColor"""
        return self.PatternColor

    @patterncolor.setter
    def patterncolor(self, value):
        """Alias for PatternColor.setter"""
        self.PatternColor = value

    @property
    def pattern_color(self):
        """Alias for PatternColor"""
        return self.PatternColor

    @pattern_color.setter
    def pattern_color(self, value):
        """Alias for PatternColor.setter"""
        self.PatternColor = value

    @property
    def PatternColorIndex(self):
        return XlColorIndex(self.com_object.PatternColorIndex)

    @PatternColorIndex.setter
    def PatternColorIndex(self, value):
        self.com_object.PatternColorIndex = value

    @property
    def patterncolorindex(self):
        """Alias for PatternColorIndex"""
        return self.PatternColorIndex

    @patterncolorindex.setter
    def patterncolorindex(self, value):
        """Alias for PatternColorIndex.setter"""
        self.PatternColorIndex = value

    @property
    def pattern_color_index(self):
        """Alias for PatternColorIndex"""
        return self.PatternColorIndex

    @pattern_color_index.setter
    def pattern_color_index(self, value):
        """Alias for PatternColorIndex.setter"""
        self.PatternColorIndex = value


class LeaderLines:

    def __init__(self, leaderlines=None):
        self.com_object= leaderlines

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Border(self):
        return ChartBorder(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Legend:

    def __init__(self, legend=None):
        self.com_object= legend

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def IncludeInLayout(self):
        return self.com_object.IncludeInLayout

    @IncludeInLayout.setter
    def IncludeInLayout(self, value):
        self.com_object.IncludeInLayout = value

    @property
    def includeinlayout(self):
        """Alias for IncludeInLayout"""
        return self.IncludeInLayout

    @includeinlayout.setter
    def includeinlayout(self, value):
        """Alias for IncludeInLayout.setter"""
        self.IncludeInLayout = value

    @property
    def include_in_layout(self):
        """Alias for IncludeInLayout"""
        return self.IncludeInLayout

    @include_in_layout.setter
    def include_in_layout(self, value):
        """Alias for IncludeInLayout.setter"""
        self.IncludeInLayout = value

    @property
    def Left(self):
        return self.com_object.Left

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return XlLegendPosition(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Clear(self):
        self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def LegendEntries(self):
        return LegendEntries(self.com_object.LegendEntries())

    def legendentries(self):
        """Alias for LegendEntries"""
        return self.LegendEntries()

    def legend_entries(self):
        """Alias for LegendEntries"""
        return self.LegendEntries()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class LegendEntries:

    def __init__(self, legendentries=None):
        self.com_object= legendentries

    def __call__(self, item):
        return LegendEntrie(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return LegendEntry(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class LegendEntry:

    def __init__(self, legendentry=None):
        self.com_object= legendentry

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Font(self):
        return ChartFont(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Left(self):
        return self.com_object.Left

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @property
    def LegendKey(self):
        return LegendKey(self.com_object.LegendKey)

    @property
    def legendkey(self):
        """Alias for LegendKey"""
        return self.LegendKey

    @property
    def legend_key(self):
        """Alias for LegendKey"""
        return self.LegendKey

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Top(self):
        return self.com_object.Top

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class LegendKey:

    def __init__(self, legendkey=None):
        self.com_object= legendkey

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def InvertIfNegative(self):
        return self.com_object.InvertIfNegative

    @InvertIfNegative.setter
    def InvertIfNegative(self, value):
        self.com_object.InvertIfNegative = value

    @property
    def invertifnegative(self):
        """Alias for InvertIfNegative"""
        return self.InvertIfNegative

    @invertifnegative.setter
    def invertifnegative(self, value):
        """Alias for InvertIfNegative.setter"""
        self.InvertIfNegative = value

    @property
    def invert_if_negative(self):
        """Alias for InvertIfNegative"""
        return self.InvertIfNegative

    @invert_if_negative.setter
    def invert_if_negative(self, value):
        """Alias for InvertIfNegative.setter"""
        self.InvertIfNegative = value

    @property
    def Left(self):
        return self.com_object.Left

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @property
    def MarkerBackgroundColor(self):
        return self.com_object.MarkerBackgroundColor

    @MarkerBackgroundColor.setter
    def MarkerBackgroundColor(self, value):
        self.com_object.MarkerBackgroundColor = value

    @property
    def markerbackgroundcolor(self):
        """Alias for MarkerBackgroundColor"""
        return self.MarkerBackgroundColor

    @markerbackgroundcolor.setter
    def markerbackgroundcolor(self, value):
        """Alias for MarkerBackgroundColor.setter"""
        self.MarkerBackgroundColor = value

    @property
    def marker_background_color(self):
        """Alias for MarkerBackgroundColor"""
        return self.MarkerBackgroundColor

    @marker_background_color.setter
    def marker_background_color(self, value):
        """Alias for MarkerBackgroundColor.setter"""
        self.MarkerBackgroundColor = value

    @property
    def MarkerBackgroundColorIndex(self):
        return XlColorIndex(self.com_object.MarkerBackgroundColorIndex)

    @MarkerBackgroundColorIndex.setter
    def MarkerBackgroundColorIndex(self, value):
        self.com_object.MarkerBackgroundColorIndex = value

    @property
    def markerbackgroundcolorindex(self):
        """Alias for MarkerBackgroundColorIndex"""
        return self.MarkerBackgroundColorIndex

    @markerbackgroundcolorindex.setter
    def markerbackgroundcolorindex(self, value):
        """Alias for MarkerBackgroundColorIndex.setter"""
        self.MarkerBackgroundColorIndex = value

    @property
    def marker_background_color_index(self):
        """Alias for MarkerBackgroundColorIndex"""
        return self.MarkerBackgroundColorIndex

    @marker_background_color_index.setter
    def marker_background_color_index(self, value):
        """Alias for MarkerBackgroundColorIndex.setter"""
        self.MarkerBackgroundColorIndex = value

    @property
    def MarkerForegroundColor(self):
        return self.com_object.MarkerForegroundColor

    @MarkerForegroundColor.setter
    def MarkerForegroundColor(self, value):
        self.com_object.MarkerForegroundColor = value

    @property
    def markerforegroundcolor(self):
        """Alias for MarkerForegroundColor"""
        return self.MarkerForegroundColor

    @markerforegroundcolor.setter
    def markerforegroundcolor(self, value):
        """Alias for MarkerForegroundColor.setter"""
        self.MarkerForegroundColor = value

    @property
    def marker_foreground_color(self):
        """Alias for MarkerForegroundColor"""
        return self.MarkerForegroundColor

    @marker_foreground_color.setter
    def marker_foreground_color(self, value):
        """Alias for MarkerForegroundColor.setter"""
        self.MarkerForegroundColor = value

    @property
    def MarkerForegroundColorIndex(self):
        return XlColorIndex(self.com_object.MarkerForegroundColorIndex)

    @MarkerForegroundColorIndex.setter
    def MarkerForegroundColorIndex(self, value):
        self.com_object.MarkerForegroundColorIndex = value

    @property
    def markerforegroundcolorindex(self):
        """Alias for MarkerForegroundColorIndex"""
        return self.MarkerForegroundColorIndex

    @markerforegroundcolorindex.setter
    def markerforegroundcolorindex(self, value):
        """Alias for MarkerForegroundColorIndex.setter"""
        self.MarkerForegroundColorIndex = value

    @property
    def marker_foreground_color_index(self):
        """Alias for MarkerForegroundColorIndex"""
        return self.MarkerForegroundColorIndex

    @marker_foreground_color_index.setter
    def marker_foreground_color_index(self, value):
        """Alias for MarkerForegroundColorIndex.setter"""
        self.MarkerForegroundColorIndex = value

    @property
    def MarkerSize(self):
        return self.com_object.MarkerSize

    @MarkerSize.setter
    def MarkerSize(self, value):
        self.com_object.MarkerSize = value

    @property
    def markersize(self):
        """Alias for MarkerSize"""
        return self.MarkerSize

    @markersize.setter
    def markersize(self, value):
        """Alias for MarkerSize.setter"""
        self.MarkerSize = value

    @property
    def marker_size(self):
        """Alias for MarkerSize"""
        return self.MarkerSize

    @marker_size.setter
    def marker_size(self, value):
        """Alias for MarkerSize.setter"""
        self.MarkerSize = value

    @property
    def MarkerStyle(self):
        return XlMarkerStyle(self.com_object.MarkerStyle)

    @MarkerStyle.setter
    def MarkerStyle(self, value):
        self.com_object.MarkerStyle = value

    @property
    def markerstyle(self):
        """Alias for MarkerStyle"""
        return self.MarkerStyle

    @markerstyle.setter
    def markerstyle(self, value):
        """Alias for MarkerStyle.setter"""
        self.MarkerStyle = value

    @property
    def marker_style(self):
        """Alias for MarkerStyle"""
        return self.MarkerStyle

    @marker_style.setter
    def marker_style(self, value):
        """Alias for MarkerStyle.setter"""
        self.MarkerStyle = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PictureType(self):
        return XlChartPictureType(self.com_object.PictureType)

    @PictureType.setter
    def PictureType(self, value):
        self.com_object.PictureType = value

    @property
    def picturetype(self):
        """Alias for PictureType"""
        return self.PictureType

    @picturetype.setter
    def picturetype(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def picture_type(self):
        """Alias for PictureType"""
        return self.PictureType

    @picture_type.setter
    def picture_type(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def PictureUnit2(self):
        return self.com_object.PictureUnit2

    @PictureUnit2.setter
    def PictureUnit2(self, value):
        self.com_object.PictureUnit2 = value

    @property
    def pictureunit2(self):
        """Alias for PictureUnit2"""
        return self.PictureUnit2

    @pictureunit2.setter
    def pictureunit2(self, value):
        """Alias for PictureUnit2.setter"""
        self.PictureUnit2 = value

    @property
    def picture_unit2(self):
        """Alias for PictureUnit2"""
        return self.PictureUnit2

    @picture_unit2.setter
    def picture_unit2(self, value):
        """Alias for PictureUnit2.setter"""
        self.PictureUnit2 = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Smooth(self):
        return self.com_object.Smooth

    @Smooth.setter
    def Smooth(self, value):
        self.com_object.Smooth = value

    @property
    def smooth(self):
        """Alias for Smooth"""
        return self.Smooth

    @smooth.setter
    def smooth(self, value):
        """Alias for Smooth.setter"""
        self.Smooth = value

    @property
    def Top(self):
        return self.com_object.Top

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    def ClearFormats(self):
        self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class LineFormat:

    def __init__(self, lineformat=None):
        self.com_object= lineformat

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BackColor(self):
        return ColorFormat(self.com_object.BackColor)

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BeginArrowheadLength(self):
        return self.com_object.BeginArrowheadLength

    @BeginArrowheadLength.setter
    def BeginArrowheadLength(self, value):
        self.com_object.BeginArrowheadLength = value

    @property
    def beginarrowheadlength(self):
        """Alias for BeginArrowheadLength"""
        return self.BeginArrowheadLength

    @beginarrowheadlength.setter
    def beginarrowheadlength(self, value):
        """Alias for BeginArrowheadLength.setter"""
        self.BeginArrowheadLength = value

    @property
    def begin_arrowhead_length(self):
        """Alias for BeginArrowheadLength"""
        return self.BeginArrowheadLength

    @begin_arrowhead_length.setter
    def begin_arrowhead_length(self, value):
        """Alias for BeginArrowheadLength.setter"""
        self.BeginArrowheadLength = value

    @property
    def BeginArrowheadStyle(self):
        return self.com_object.BeginArrowheadStyle

    @BeginArrowheadStyle.setter
    def BeginArrowheadStyle(self, value):
        self.com_object.BeginArrowheadStyle = value

    @property
    def beginarrowheadstyle(self):
        """Alias for BeginArrowheadStyle"""
        return self.BeginArrowheadStyle

    @beginarrowheadstyle.setter
    def beginarrowheadstyle(self, value):
        """Alias for BeginArrowheadStyle.setter"""
        self.BeginArrowheadStyle = value

    @property
    def begin_arrowhead_style(self):
        """Alias for BeginArrowheadStyle"""
        return self.BeginArrowheadStyle

    @begin_arrowhead_style.setter
    def begin_arrowhead_style(self, value):
        """Alias for BeginArrowheadStyle.setter"""
        self.BeginArrowheadStyle = value

    @property
    def BeginArrowheadWidth(self):
        return self.com_object.BeginArrowheadWidth

    @BeginArrowheadWidth.setter
    def BeginArrowheadWidth(self, value):
        self.com_object.BeginArrowheadWidth = value

    @property
    def beginarrowheadwidth(self):
        """Alias for BeginArrowheadWidth"""
        return self.BeginArrowheadWidth

    @beginarrowheadwidth.setter
    def beginarrowheadwidth(self, value):
        """Alias for BeginArrowheadWidth.setter"""
        self.BeginArrowheadWidth = value

    @property
    def begin_arrowhead_width(self):
        """Alias for BeginArrowheadWidth"""
        return self.BeginArrowheadWidth

    @begin_arrowhead_width.setter
    def begin_arrowhead_width(self, value):
        """Alias for BeginArrowheadWidth.setter"""
        self.BeginArrowheadWidth = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DashStyle(self):
        return self.com_object.DashStyle

    @DashStyle.setter
    def DashStyle(self, value):
        self.com_object.DashStyle = value

    @property
    def dashstyle(self):
        """Alias for DashStyle"""
        return self.DashStyle

    @dashstyle.setter
    def dashstyle(self, value):
        """Alias for DashStyle.setter"""
        self.DashStyle = value

    @property
    def dash_style(self):
        """Alias for DashStyle"""
        return self.DashStyle

    @dash_style.setter
    def dash_style(self, value):
        """Alias for DashStyle.setter"""
        self.DashStyle = value

    @property
    def EndArrowheadLength(self):
        return self.com_object.EndArrowheadLength

    @EndArrowheadLength.setter
    def EndArrowheadLength(self, value):
        self.com_object.EndArrowheadLength = value

    @property
    def endarrowheadlength(self):
        """Alias for EndArrowheadLength"""
        return self.EndArrowheadLength

    @endarrowheadlength.setter
    def endarrowheadlength(self, value):
        """Alias for EndArrowheadLength.setter"""
        self.EndArrowheadLength = value

    @property
    def end_arrowhead_length(self):
        """Alias for EndArrowheadLength"""
        return self.EndArrowheadLength

    @end_arrowhead_length.setter
    def end_arrowhead_length(self, value):
        """Alias for EndArrowheadLength.setter"""
        self.EndArrowheadLength = value

    @property
    def EndArrowheadStyle(self):
        return self.com_object.EndArrowheadStyle

    @EndArrowheadStyle.setter
    def EndArrowheadStyle(self, value):
        self.com_object.EndArrowheadStyle = value

    @property
    def endarrowheadstyle(self):
        """Alias for EndArrowheadStyle"""
        return self.EndArrowheadStyle

    @endarrowheadstyle.setter
    def endarrowheadstyle(self, value):
        """Alias for EndArrowheadStyle.setter"""
        self.EndArrowheadStyle = value

    @property
    def end_arrowhead_style(self):
        """Alias for EndArrowheadStyle"""
        return self.EndArrowheadStyle

    @end_arrowhead_style.setter
    def end_arrowhead_style(self, value):
        """Alias for EndArrowheadStyle.setter"""
        self.EndArrowheadStyle = value

    @property
    def EndArrowheadWidth(self):
        return self.com_object.EndArrowheadWidth

    @EndArrowheadWidth.setter
    def EndArrowheadWidth(self, value):
        self.com_object.EndArrowheadWidth = value

    @property
    def endarrowheadwidth(self):
        """Alias for EndArrowheadWidth"""
        return self.EndArrowheadWidth

    @endarrowheadwidth.setter
    def endarrowheadwidth(self, value):
        """Alias for EndArrowheadWidth.setter"""
        self.EndArrowheadWidth = value

    @property
    def end_arrowhead_width(self):
        """Alias for EndArrowheadWidth"""
        return self.EndArrowheadWidth

    @end_arrowhead_width.setter
    def end_arrowhead_width(self, value):
        """Alias for EndArrowheadWidth.setter"""
        self.EndArrowheadWidth = value

    @property
    def ForeColor(self):
        return ColorFormat(self.com_object.ForeColor)

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def InsetPen(self):
        return self.com_object.InsetPen

    @InsetPen.setter
    def InsetPen(self, value):
        self.com_object.InsetPen = value

    @property
    def insetpen(self):
        """Alias for InsetPen"""
        return self.InsetPen

    @insetpen.setter
    def insetpen(self, value):
        """Alias for InsetPen.setter"""
        self.InsetPen = value

    @property
    def inset_pen(self):
        """Alias for InsetPen"""
        return self.InsetPen

    @inset_pen.setter
    def inset_pen(self, value):
        """Alias for InsetPen.setter"""
        self.InsetPen = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Pattern(self):
        return self.com_object.Pattern

    @Pattern.setter
    def Pattern(self, value):
        self.com_object.Pattern = value

    @property
    def pattern(self):
        """Alias for Pattern"""
        return self.Pattern

    @pattern.setter
    def pattern(self, value):
        """Alias for Pattern.setter"""
        self.Pattern = value

    @property
    def Style(self):
        return self.com_object.Style

    @Style.setter
    def Style(self, value):
        self.com_object.Style = value

    @property
    def style(self):
        """Alias for Style"""
        return self.Style

    @style.setter
    def style(self, value):
        """Alias for Style.setter"""
        self.Style = value

    @property
    def Transparency(self):
        return self.com_object.Transparency

    @Transparency.setter
    def Transparency(self, value):
        self.com_object.Transparency = value

    @property
    def transparency(self):
        """Alias for Transparency"""
        return self.Transparency

    @transparency.setter
    def transparency(self, value):
        """Alias for Transparency.setter"""
        self.Transparency = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Weight(self):
        return self.com_object.Weight

    @Weight.setter
    def Weight(self, value):
        self.com_object.Weight = value

    @property
    def weight(self):
        """Alias for Weight"""
        return self.Weight

    @weight.setter
    def weight(self, value):
        """Alias for Weight.setter"""
        self.Weight = value


class LinkFormat:

    def __init__(self, linkformat=None):
        self.com_object= linkformat

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoUpdate(self):
        return self.com_object.AutoUpdate

    @AutoUpdate.setter
    def AutoUpdate(self, value):
        self.com_object.AutoUpdate = value

    @property
    def autoupdate(self):
        """Alias for AutoUpdate"""
        return self.AutoUpdate

    @autoupdate.setter
    def autoupdate(self, value):
        """Alias for AutoUpdate.setter"""
        self.AutoUpdate = value

    @property
    def auto_update(self):
        """Alias for AutoUpdate"""
        return self.AutoUpdate

    @auto_update.setter
    def auto_update(self, value):
        """Alias for AutoUpdate.setter"""
        self.AutoUpdate = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SourceFullName(self):
        return self.com_object.SourceFullName

    @SourceFullName.setter
    def SourceFullName(self, value):
        self.com_object.SourceFullName = value

    @property
    def sourcefullname(self):
        """Alias for SourceFullName"""
        return self.SourceFullName

    @sourcefullname.setter
    def sourcefullname(self, value):
        """Alias for SourceFullName.setter"""
        self.SourceFullName = value

    @property
    def source_full_name(self):
        """Alias for SourceFullName"""
        return self.SourceFullName

    @source_full_name.setter
    def source_full_name(self, value):
        """Alias for SourceFullName.setter"""
        self.SourceFullName = value

    def BreakLink(self):
        return self.com_object.BreakLink()

    def breaklink(self):
        """Alias for BreakLink"""
        return self.BreakLink()

    def break_link(self):
        """Alias for BreakLink"""
        return self.BreakLink()

    def Update(self):
        self.com_object.Update()

    def update(self):
        """Alias for Update"""
        return self.Update()


class Master:

    def __init__(self, master=None):
        self.com_object= master

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Background(self):
        return ShapeRange(self.com_object.Background)

    @property
    def background(self):
        """Alias for Background"""
        return self.Background

    @property
    def BackgroundStyle(self):
        return self.com_object.BackgroundStyle

    @BackgroundStyle.setter
    def BackgroundStyle(self, value):
        self.com_object.BackgroundStyle = value

    @property
    def backgroundstyle(self):
        """Alias for BackgroundStyle"""
        return self.BackgroundStyle

    @backgroundstyle.setter
    def backgroundstyle(self, value):
        """Alias for BackgroundStyle.setter"""
        self.BackgroundStyle = value

    @property
    def background_style(self):
        """Alias for BackgroundStyle"""
        return self.BackgroundStyle

    @background_style.setter
    def background_style(self, value):
        """Alias for BackgroundStyle.setter"""
        self.BackgroundStyle = value

    @property
    def ColorScheme(self):
        return ColorScheme(self.com_object.ColorScheme)

    @ColorScheme.setter
    def ColorScheme(self, value):
        self.com_object.ColorScheme = value

    @property
    def colorscheme(self):
        """Alias for ColorScheme"""
        return self.ColorScheme

    @colorscheme.setter
    def colorscheme(self, value):
        """Alias for ColorScheme.setter"""
        self.ColorScheme = value

    @property
    def color_scheme(self):
        """Alias for ColorScheme"""
        return self.ColorScheme

    @color_scheme.setter
    def color_scheme(self, value):
        """Alias for ColorScheme.setter"""
        self.ColorScheme = value

    @property
    def CustomerData(self):
        return CustomerData(self.com_object.CustomerData)

    @property
    def customerdata(self):
        """Alias for CustomerData"""
        return self.CustomerData

    @property
    def customer_data(self):
        """Alias for CustomerData"""
        return self.CustomerData

    @property
    def CustomLayouts(self):
        return CustomLayouts(self.com_object.CustomLayouts)

    @property
    def customlayouts(self):
        """Alias for CustomLayouts"""
        return self.CustomLayouts

    @property
    def custom_layouts(self):
        """Alias for CustomLayouts"""
        return self.CustomLayouts

    @property
    def Design(self):
        return Design(self.com_object.Design)

    @property
    def design(self):
        """Alias for Design"""
        return self.Design

    @property
    def Guides(self):
        return Guides(self.com_object.Guides)

    @property
    def guides(self):
        """Alias for Guides"""
        return self.Guides

    @property
    def HeadersFooters(self):
        return HeadersFooters(self.com_object.HeadersFooters)

    @property
    def headersfooters(self):
        """Alias for HeadersFooters"""
        return self.HeadersFooters

    @property
    def headers_footers(self):
        """Alias for HeadersFooters"""
        return self.HeadersFooters

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def Hyperlinks(self):
        return Hyperlinks(self.com_object.Hyperlinks)

    @property
    def hyperlinks(self):
        """Alias for Hyperlinks"""
        return self.Hyperlinks

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Shapes(self):
        return Shapes(self.com_object.Shapes)

    @property
    def shapes(self):
        """Alias for Shapes"""
        return self.Shapes

    @property
    def SlideShowTransition(self):
        return SlideShowTransition(self.com_object.SlideShowTransition)

    @property
    def slideshowtransition(self):
        """Alias for SlideShowTransition"""
        return self.SlideShowTransition

    @property
    def slide_show_transition(self):
        """Alias for SlideShowTransition"""
        return self.SlideShowTransition

    @property
    def TextStyles(self):
        return TextStyles(self.com_object.TextStyles)

    @property
    def textstyles(self):
        """Alias for TextStyles"""
        return self.TextStyles

    @property
    def text_styles(self):
        """Alias for TextStyles"""
        return self.TextStyles

    @property
    def Theme(self):
        return Theme(self.com_object.Theme)

    @property
    def theme(self):
        """Alias for Theme"""
        return self.Theme

    @property
    def TimeLine(self):
        return TimeLine(self.com_object.TimeLine)

    @property
    def timeline(self):
        """Alias for TimeLine"""
        return self.TimeLine

    @property
    def time_line(self):
        """Alias for TimeLine"""
        return self.TimeLine

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    def ApplyTheme(self, themeName=None):
        arguments = com_arguments([unwrap(a) for a in [themeName]])
        self.com_object.ApplyTheme(*arguments)

    def applytheme(self, themeName=None):
        """Alias for ApplyTheme"""
        arguments = [themeName]
        return self.ApplyTheme(*arguments)

    def apply_theme(self, themeName=None):
        """Alias for ApplyTheme"""
        arguments = [themeName]
        return self.ApplyTheme(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class MediaBookmark:

    def __init__(self, mediabookmark=None):
        self.com_object= mediabookmark

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Position(self):
        return self.com_object.Position

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class MediaBookmarks:

    def __init__(self, mediabookmarks=None):
        self.com_object= mediabookmarks

    def __call__(self, item):
        return MediaBookmark(self.com_object(item))

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Add(self, Position=None, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Position, Name]])
        return MediaBookmark(self.com_object.Add(*arguments))

    def add(self, Position=None, Name=None):
        """Alias for Add"""
        arguments = [Position, Name]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return MediaBookmark(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class MediaFormat:

    def __init__(self, mediaformat=None):
        self.com_object= mediaformat

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AudioCompressionType(self):
        return self.com_object.AudioCompressionType

    @property
    def audiocompressiontype(self):
        """Alias for AudioCompressionType"""
        return self.AudioCompressionType

    @property
    def audio_compression_type(self):
        """Alias for AudioCompressionType"""
        return self.AudioCompressionType

    @property
    def AudioSamplingRate(self):
        return self.com_object.AudioSamplingRate

    @property
    def audiosamplingrate(self):
        """Alias for AudioSamplingRate"""
        return self.AudioSamplingRate

    @property
    def audio_sampling_rate(self):
        """Alias for AudioSamplingRate"""
        return self.AudioSamplingRate

    @property
    def EndPoint(self):
        return self.com_object.EndPoint

    @EndPoint.setter
    def EndPoint(self, value):
        self.com_object.EndPoint = value

    @property
    def endpoint(self):
        """Alias for EndPoint"""
        return self.EndPoint

    @endpoint.setter
    def endpoint(self, value):
        """Alias for EndPoint.setter"""
        self.EndPoint = value

    @property
    def end_point(self):
        """Alias for EndPoint"""
        return self.EndPoint

    @end_point.setter
    def end_point(self, value):
        """Alias for EndPoint.setter"""
        self.EndPoint = value

    @property
    def FadeInDuration(self):
        return self.com_object.FadeInDuration

    @FadeInDuration.setter
    def FadeInDuration(self, value):
        self.com_object.FadeInDuration = value

    @property
    def fadeinduration(self):
        """Alias for FadeInDuration"""
        return self.FadeInDuration

    @fadeinduration.setter
    def fadeinduration(self, value):
        """Alias for FadeInDuration.setter"""
        self.FadeInDuration = value

    @property
    def fade_in_duration(self):
        """Alias for FadeInDuration"""
        return self.FadeInDuration

    @fade_in_duration.setter
    def fade_in_duration(self, value):
        """Alias for FadeInDuration.setter"""
        self.FadeInDuration = value

    @property
    def FadeOutDuration(self):
        return self.com_object.FadeOutDuration

    @FadeOutDuration.setter
    def FadeOutDuration(self, value):
        self.com_object.FadeOutDuration = value

    @property
    def fadeoutduration(self):
        """Alias for FadeOutDuration"""
        return self.FadeOutDuration

    @fadeoutduration.setter
    def fadeoutduration(self, value):
        """Alias for FadeOutDuration.setter"""
        self.FadeOutDuration = value

    @property
    def fade_out_duration(self):
        """Alias for FadeOutDuration"""
        return self.FadeOutDuration

    @fade_out_duration.setter
    def fade_out_duration(self, value):
        """Alias for FadeOutDuration.setter"""
        self.FadeOutDuration = value

    @property
    def IsEmbedded(self):
        return self.com_object.IsEmbedded

    @property
    def isembedded(self):
        """Alias for IsEmbedded"""
        return self.IsEmbedded

    @property
    def is_embedded(self):
        """Alias for IsEmbedded"""
        return self.IsEmbedded

    @property
    def IsLinked(self):
        return self.com_object.IsLinked

    @property
    def islinked(self):
        """Alias for IsLinked"""
        return self.IsLinked

    @property
    def is_linked(self):
        """Alias for IsLinked"""
        return self.IsLinked

    @property
    def Length(self):
        return self.com_object.Length

    @property
    def length(self):
        """Alias for Length"""
        return self.Length

    @property
    def MediaBookmarks(self):
        return MediaBookmarks(self.com_object.MediaBookmarks)

    @property
    def mediabookmarks(self):
        """Alias for MediaBookmarks"""
        return self.MediaBookmarks

    @property
    def media_bookmarks(self):
        """Alias for MediaBookmarks"""
        return self.MediaBookmarks

    @property
    def Muted(self):
        return self.com_object.Muted

    @Muted.setter
    def Muted(self, value):
        self.com_object.Muted = value

    @property
    def muted(self):
        """Alias for Muted"""
        return self.Muted

    @muted.setter
    def muted(self, value):
        """Alias for Muted.setter"""
        self.Muted = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ResamplingStatus(self):
        return self.com_object.ResamplingStatus

    @property
    def resamplingstatus(self):
        """Alias for ResamplingStatus"""
        return self.ResamplingStatus

    @property
    def resampling_status(self):
        """Alias for ResamplingStatus"""
        return self.ResamplingStatus

    @property
    def SampleHeight(self):
        return self.com_object.SampleHeight

    @property
    def sampleheight(self):
        """Alias for SampleHeight"""
        return self.SampleHeight

    @property
    def sample_height(self):
        """Alias for SampleHeight"""
        return self.SampleHeight

    @property
    def SampleWidth(self):
        return self.com_object.SampleWidth

    @property
    def samplewidth(self):
        """Alias for SampleWidth"""
        return self.SampleWidth

    @property
    def sample_width(self):
        """Alias for SampleWidth"""
        return self.SampleWidth

    @property
    def StartPoint(self):
        return self.com_object.StartPoint

    @StartPoint.setter
    def StartPoint(self, value):
        self.com_object.StartPoint = value

    @property
    def startpoint(self):
        """Alias for StartPoint"""
        return self.StartPoint

    @startpoint.setter
    def startpoint(self, value):
        """Alias for StartPoint.setter"""
        self.StartPoint = value

    @property
    def start_point(self):
        """Alias for StartPoint"""
        return self.StartPoint

    @start_point.setter
    def start_point(self, value):
        """Alias for StartPoint.setter"""
        self.StartPoint = value

    @property
    def VideoCompressionType(self):
        return self.com_object.VideoCompressionType

    @property
    def videocompressiontype(self):
        """Alias for VideoCompressionType"""
        return self.VideoCompressionType

    @property
    def video_compression_type(self):
        """Alias for VideoCompressionType"""
        return self.VideoCompressionType

    @property
    def VideoFrameRate(self):
        return self.com_object.VideoFrameRate

    @property
    def videoframerate(self):
        """Alias for VideoFrameRate"""
        return self.VideoFrameRate

    @property
    def video_frame_rate(self):
        """Alias for VideoFrameRate"""
        return self.VideoFrameRate

    @property
    def Volume(self):
        return self.com_object.Volume

    @Volume.setter
    def Volume(self, value):
        self.com_object.Volume = value

    @property
    def volume(self):
        """Alias for Volume"""
        return self.Volume

    @volume.setter
    def volume(self, value):
        """Alias for Volume.setter"""
        self.Volume = value

    def Resample(self, Trim=None, SampleHeight=None, SampleWidth=None, VideoFrameRate=None, AudioSamplingRate=None, VideoBitRate=None):
        arguments = com_arguments([unwrap(a) for a in [Trim, SampleHeight, SampleWidth, VideoFrameRate, AudioSamplingRate, VideoBitRate]])
        return self.com_object.Resample(*arguments)

    def resample(self, Trim=None, SampleHeight=None, SampleWidth=None, VideoFrameRate=None, AudioSamplingRate=None, VideoBitRate=None):
        """Alias for Resample"""
        arguments = [Trim, SampleHeight, SampleWidth, VideoFrameRate, AudioSamplingRate, VideoBitRate]
        return self.Resample(*arguments)

    def ResampleFromProfile(self, profile=None):
        arguments = com_arguments([unwrap(a) for a in [profile]])
        return self.com_object.ResampleFromProfile(*arguments)

    def resamplefromprofile(self, profile=None):
        """Alias for ResampleFromProfile"""
        arguments = [profile]
        return self.ResampleFromProfile(*arguments)

    def resample_from_profile(self, profile=None):
        """Alias for ResampleFromProfile"""
        arguments = [profile]
        return self.ResampleFromProfile(*arguments)

    def SetDisplayPicture(self, Position=None):
        arguments = com_arguments([unwrap(a) for a in [Position]])
        return self.com_object.SetDisplayPicture(*arguments)

    def setdisplaypicture(self, Position=None):
        """Alias for SetDisplayPicture"""
        arguments = [Position]
        return self.SetDisplayPicture(*arguments)

    def set_display_picture(self, Position=None):
        """Alias for SetDisplayPicture"""
        arguments = [Position]
        return self.SetDisplayPicture(*arguments)

    def SetDisplayPictureFromFile(self, FilePath=None):
        arguments = com_arguments([unwrap(a) for a in [FilePath]])
        return self.com_object.SetDisplayPictureFromFile(*arguments)

    def setdisplaypicturefromfile(self, FilePath=None):
        """Alias for SetDisplayPictureFromFile"""
        arguments = [FilePath]
        return self.SetDisplayPictureFromFile(*arguments)

    def set_display_picture_from_file(self, FilePath=None):
        """Alias for SetDisplayPictureFromFile"""
        arguments = [FilePath]
        return self.SetDisplayPictureFromFile(*arguments)


class Model3DFormat:

    def __init__(self, model3dformat=None):
        self.com_object= model3dformat

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoFit(self):
        return self.com_object.AutoFit

    @AutoFit.setter
    def AutoFit(self, value):
        self.com_object.AutoFit = value

    @property
    def autofit(self):
        """Alias for AutoFit"""
        return self.AutoFit

    @autofit.setter
    def autofit(self, value):
        """Alias for AutoFit.setter"""
        self.AutoFit = value

    @property
    def auto_fit(self):
        """Alias for AutoFit"""
        return self.AutoFit

    @auto_fit.setter
    def auto_fit(self, value):
        """Alias for AutoFit.setter"""
        self.AutoFit = value

    @property
    def CameraPositionX(self):
        return self.com_object.CameraPositionX

    @CameraPositionX.setter
    def CameraPositionX(self, value):
        self.com_object.CameraPositionX = value

    @property
    def camerapositionx(self):
        """Alias for CameraPositionX"""
        return self.CameraPositionX

    @camerapositionx.setter
    def camerapositionx(self, value):
        """Alias for CameraPositionX.setter"""
        self.CameraPositionX = value

    @property
    def camera_position_x(self):
        """Alias for CameraPositionX"""
        return self.CameraPositionX

    @camera_position_x.setter
    def camera_position_x(self, value):
        """Alias for CameraPositionX.setter"""
        self.CameraPositionX = value

    @property
    def CameraPositionY(self):
        return self.com_object.CameraPositionY

    @CameraPositionY.setter
    def CameraPositionY(self, value):
        self.com_object.CameraPositionY = value

    @property
    def camerapositiony(self):
        """Alias for CameraPositionY"""
        return self.CameraPositionY

    @camerapositiony.setter
    def camerapositiony(self, value):
        """Alias for CameraPositionY.setter"""
        self.CameraPositionY = value

    @property
    def camera_position_y(self):
        """Alias for CameraPositionY"""
        return self.CameraPositionY

    @camera_position_y.setter
    def camera_position_y(self, value):
        """Alias for CameraPositionY.setter"""
        self.CameraPositionY = value

    @property
    def CameraPositionZ(self):
        return self.com_object.CameraPositionZ

    @CameraPositionZ.setter
    def CameraPositionZ(self, value):
        self.com_object.CameraPositionZ = value

    @property
    def camerapositionz(self):
        """Alias for CameraPositionZ"""
        return self.CameraPositionZ

    @camerapositionz.setter
    def camerapositionz(self, value):
        """Alias for CameraPositionZ.setter"""
        self.CameraPositionZ = value

    @property
    def camera_position_z(self):
        """Alias for CameraPositionZ"""
        return self.CameraPositionZ

    @camera_position_z.setter
    def camera_position_z(self, value):
        """Alias for CameraPositionZ.setter"""
        self.CameraPositionZ = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def FieldOfView(self):
        return self.com_object.FieldOfView

    @FieldOfView.setter
    def FieldOfView(self, value):
        self.com_object.FieldOfView = value

    @property
    def fieldofview(self):
        """Alias for FieldOfView"""
        return self.FieldOfView

    @fieldofview.setter
    def fieldofview(self, value):
        """Alias for FieldOfView.setter"""
        self.FieldOfView = value

    @property
    def field_of_view(self):
        """Alias for FieldOfView"""
        return self.FieldOfView

    @field_of_view.setter
    def field_of_view(self, value):
        """Alias for FieldOfView.setter"""
        self.FieldOfView = value

    @property
    def LookAtPointX(self):
        return self.com_object.LookAtPointX

    @LookAtPointX.setter
    def LookAtPointX(self, value):
        self.com_object.LookAtPointX = value

    @property
    def lookatpointx(self):
        """Alias for LookAtPointX"""
        return self.LookAtPointX

    @lookatpointx.setter
    def lookatpointx(self, value):
        """Alias for LookAtPointX.setter"""
        self.LookAtPointX = value

    @property
    def look_at_point_x(self):
        """Alias for LookAtPointX"""
        return self.LookAtPointX

    @look_at_point_x.setter
    def look_at_point_x(self, value):
        """Alias for LookAtPointX.setter"""
        self.LookAtPointX = value

    @property
    def LookAtPointY(self):
        return self.com_object.LookAtPointY

    @LookAtPointY.setter
    def LookAtPointY(self, value):
        self.com_object.LookAtPointY = value

    @property
    def lookatpointy(self):
        """Alias for LookAtPointY"""
        return self.LookAtPointY

    @lookatpointy.setter
    def lookatpointy(self, value):
        """Alias for LookAtPointY.setter"""
        self.LookAtPointY = value

    @property
    def look_at_point_y(self):
        """Alias for LookAtPointY"""
        return self.LookAtPointY

    @look_at_point_y.setter
    def look_at_point_y(self, value):
        """Alias for LookAtPointY.setter"""
        self.LookAtPointY = value

    @property
    def LookAtPointZ(self):
        return self.com_object.LookAtPointZ

    @LookAtPointZ.setter
    def LookAtPointZ(self, value):
        self.com_object.LookAtPointZ = value

    @property
    def lookatpointz(self):
        """Alias for LookAtPointZ"""
        return self.LookAtPointZ

    @lookatpointz.setter
    def lookatpointz(self, value):
        """Alias for LookAtPointZ.setter"""
        self.LookAtPointZ = value

    @property
    def look_at_point_z(self):
        """Alias for LookAtPointZ"""
        return self.LookAtPointZ

    @look_at_point_z.setter
    def look_at_point_z(self, value):
        """Alias for LookAtPointZ.setter"""
        self.LookAtPointZ = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RotationX(self):
        return self.com_object.RotationX

    @RotationX.setter
    def RotationX(self, value):
        self.com_object.RotationX = value

    @property
    def rotationx(self):
        """Alias for RotationX"""
        return self.RotationX

    @rotationx.setter
    def rotationx(self, value):
        """Alias for RotationX.setter"""
        self.RotationX = value

    @property
    def rotation_x(self):
        """Alias for RotationX"""
        return self.RotationX

    @rotation_x.setter
    def rotation_x(self, value):
        """Alias for RotationX.setter"""
        self.RotationX = value

    @property
    def RotationY(self):
        return self.com_object.RotationY

    @RotationY.setter
    def RotationY(self, value):
        self.com_object.RotationY = value

    @property
    def rotationy(self):
        """Alias for RotationY"""
        return self.RotationY

    @rotationy.setter
    def rotationy(self, value):
        """Alias for RotationY.setter"""
        self.RotationY = value

    @property
    def rotation_y(self):
        """Alias for RotationY"""
        return self.RotationY

    @rotation_y.setter
    def rotation_y(self, value):
        """Alias for RotationY.setter"""
        self.RotationY = value

    @property
    def RotationZ(self):
        return self.com_object.RotationZ

    @RotationZ.setter
    def RotationZ(self, value):
        self.com_object.RotationZ = value

    @property
    def rotationz(self):
        """Alias for RotationZ"""
        return self.RotationZ

    @rotationz.setter
    def rotationz(self, value):
        """Alias for RotationZ.setter"""
        self.RotationZ = value

    @property
    def rotation_z(self):
        """Alias for RotationZ"""
        return self.RotationZ

    @rotation_z.setter
    def rotation_z(self, value):
        """Alias for RotationZ.setter"""
        self.RotationZ = value

    def IncrementRotationX(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotationX(*arguments)

    def incrementrotationx(self, Increment=None):
        """Alias for IncrementRotationX"""
        arguments = [Increment]
        return self.IncrementRotationX(*arguments)

    def increment_rotation_x(self, Increment=None):
        """Alias for IncrementRotationX"""
        arguments = [Increment]
        return self.IncrementRotationX(*arguments)

    def IncrementRotationY(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotationY(*arguments)

    def incrementrotationy(self, Increment=None):
        """Alias for IncrementRotationY"""
        arguments = [Increment]
        return self.IncrementRotationY(*arguments)

    def increment_rotation_y(self, Increment=None):
        """Alias for IncrementRotationY"""
        arguments = [Increment]
        return self.IncrementRotationY(*arguments)

    def IncrementRotationZ(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotationZ(*arguments)

    def incrementrotationz(self, Increment=None):
        """Alias for IncrementRotationZ"""
        arguments = [Increment]
        return self.IncrementRotationZ(*arguments)

    def increment_rotation_z(self, Increment=None):
        """Alias for IncrementRotationZ"""
        arguments = [Increment]
        return self.IncrementRotationZ(*arguments)

    def ResetModel(self, ResetSize=None):
        arguments = com_arguments([unwrap(a) for a in [ResetSize]])
        self.com_object.ResetModel(*arguments)

    def resetmodel(self, ResetSize=None):
        """Alias for ResetModel"""
        arguments = [ResetSize]
        return self.ResetModel(*arguments)

    def reset_model(self, ResetSize=None):
        """Alias for ResetModel"""
        arguments = [ResetSize]
        return self.ResetModel(*arguments)


class MotionEffect:

    def __init__(self, motioneffect=None):
        self.com_object= motioneffect

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ByX(self):
        return self.com_object.ByX

    @ByX.setter
    def ByX(self, value):
        self.com_object.ByX = value

    @property
    def byx(self):
        """Alias for ByX"""
        return self.ByX

    @byx.setter
    def byx(self, value):
        """Alias for ByX.setter"""
        self.ByX = value

    @property
    def by_x(self):
        """Alias for ByX"""
        return self.ByX

    @by_x.setter
    def by_x(self, value):
        """Alias for ByX.setter"""
        self.ByX = value

    @property
    def ByY(self):
        return self.com_object.ByY

    @ByY.setter
    def ByY(self, value):
        self.com_object.ByY = value

    @property
    def byy(self):
        """Alias for ByY"""
        return self.ByY

    @byy.setter
    def byy(self, value):
        """Alias for ByY.setter"""
        self.ByY = value

    @property
    def by_y(self):
        """Alias for ByY"""
        return self.ByY

    @by_y.setter
    def by_y(self, value):
        """Alias for ByY.setter"""
        self.ByY = value

    @property
    def FromX(self):
        return self.com_object.FromX

    @FromX.setter
    def FromX(self, value):
        self.com_object.FromX = value

    @property
    def fromx(self):
        """Alias for FromX"""
        return self.FromX

    @fromx.setter
    def fromx(self, value):
        """Alias for FromX.setter"""
        self.FromX = value

    @property
    def from_x(self):
        """Alias for FromX"""
        return self.FromX

    @from_x.setter
    def from_x(self, value):
        """Alias for FromX.setter"""
        self.FromX = value

    @property
    def FromY(self):
        return MotionEffect(self.com_object.FromY)

    @FromY.setter
    def FromY(self, value):
        self.com_object.FromY = value

    @property
    def fromy(self):
        """Alias for FromY"""
        return self.FromY

    @fromy.setter
    def fromy(self, value):
        """Alias for FromY.setter"""
        self.FromY = value

    @property
    def from_y(self):
        """Alias for FromY"""
        return self.FromY

    @from_y.setter
    def from_y(self, value):
        """Alias for FromY.setter"""
        self.FromY = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Path(self):
        return self.com_object.Path

    @Path.setter
    def Path(self, value):
        self.com_object.Path = value

    @property
    def path(self):
        """Alias for Path"""
        return self.Path

    @path.setter
    def path(self, value):
        """Alias for Path.setter"""
        self.Path = value

    @property
    def ToX(self):
        return self.com_object.ToX

    @ToX.setter
    def ToX(self, value):
        self.com_object.ToX = value

    @property
    def tox(self):
        """Alias for ToX"""
        return self.ToX

    @tox.setter
    def tox(self, value):
        """Alias for ToX.setter"""
        self.ToX = value

    @property
    def to_x(self):
        """Alias for ToX"""
        return self.ToX

    @to_x.setter
    def to_x(self, value):
        """Alias for ToX.setter"""
        self.ToX = value

    @property
    def ToY(self):
        return MotionEffect(self.com_object.ToY)

    @ToY.setter
    def ToY(self, value):
        self.com_object.ToY = value

    @property
    def toy(self):
        """Alias for ToY"""
        return self.ToY

    @toy.setter
    def toy(self, value):
        """Alias for ToY.setter"""
        self.ToY = value

    @property
    def to_y(self):
        """Alias for ToY"""
        return self.ToY

    @to_y.setter
    def to_y(self, value):
        """Alias for ToY.setter"""
        self.ToY = value


# MsoAnimAccumulate enumeration
msoAnimAccumulateAlways = 2
msoAnimAccumulateNone = 1

# MsoAnimAdditive enumeration
msoAnimAdditiveAddBase = 1
msoAnimAdditiveAddSum = 2

# MsoAnimAfterEffect enumeration
msoAnimAfterEffectDim = 1
msoAnimAfterEffectHide = 2
msoAnimAfterEffectHideOnNextClick = 3
msoAnimAfterEffectMixed = -1
msoAnimAfterEffectNone = 0

# MsoAnimateByLevel enumeration
msoAnimateChartAllAtOnce = 7
msoAnimateChartByCategory = 8
msoAnimateChartByCategoryElements = 9
msoAnimateChartBySeries = 10
msoAnimateChartBySeriesElements = 11
msoAnimateDiagramAllAtOnce = 12
msoAnimateDiagramBreadthByLevel = 16
msoAnimateDiagramBreadthByNode = 15
msoAnimateDiagramClockwise = 17
msoAnimateDiagramClockwiseIn = 18
msoAnimateDiagramClockwiseOut = 19
msoAnimateDiagramCounterClockwise = 20
msoAnimateDiagramCounterClockwiseIn = 21
msoAnimateDiagramCounterClockwiseOut = 22
msoAnimateDiagramDepthByBranch = 14
msoAnimateDiagramDepthByNode = 13
msoAnimateDiagramDown = 26
msoAnimateDiagramInByRing = 23
msoAnimateDiagramOutByRing = 24
msoAnimateDiagramUp = 25
msoAnimateLevelMixed = -1
msoAnimateLevelNone = 0
msoAnimateTextByAllLevels = 1
msoAnimateTextByFifthLevel = 6
msoAnimateTextByFirstLevel = 2
msoAnimateTextByFourthLevel = 5
msoAnimateTextBySecondLevel = 3
msoAnimateTextByThirdLevel = 4

# MsoAnimCommandType enumeration
msoAnimCommandTypeCall = 1
msoAnimCommandTypeEvent = 0
msoAnimCommandTypeVerb = 2

# MsoAnimDirection enumeration
msoAnimDirectionAcross = 18
msoAnimDirectionBottom = 11
msoAnimDirectionBottomLeft = 15
msoAnimDirectionBottomRight = 14
msoAnimDirectionCenter = 28
msoAnimDirectionClockwise = 21
msoAnimDirectionCounterclockwise = 22
msoAnimDirectionCycleClockwise = 43
msoAnimDirectionCycleCounterclockwise = 44
msoAnimDirectionDown = 3
msoAnimDirectionDownLeft = 9
msoAnimDirectionDownRight = 8
msoAnimDirectionFontAllCaps = 40
msoAnimDirectionFontBold = 35
msoAnimDirectionFontItalic = 36
msoAnimDirectionFontShadow = 39
msoAnimDirectionFontStrikethrough = 38
msoAnimDirectionFontUnderline = 37
msoAnimDirectionGradual = 42
msoAnimDirectionHorizontal = 16
msoAnimDirectionHorizontalIn = 23
msoAnimDirectionHorizontalOut = 24
msoAnimDirectionIn = 19
msoAnimDirectionInBottom = 31
msoAnimDirectionInCenter = 30
msoAnimDirectionInSlightly = 29
msoAnimDirectionInstant = 41
msoAnimDirectionLeft = 4
msoAnimDirectionNone = 0
msoAnimDirectionOrdinalMask = 5
msoAnimDirectionOut = 20
msoAnimDirectionOutBottom = 34
msoAnimDirectionOutCenter = 33
msoAnimDirectionOutSlightly = 32
msoAnimDirectionRight = 2
msoAnimDirectionSlightly = 27
msoAnimDirectionTop = 10
msoAnimDirectionTopLeft = 12
msoAnimDirectionTopRight = 13
msoAnimDirectionUp = 1
msoAnimDirectionUpLeft = 6
msoAnimDirectionUpRight = 7
msoAnimDirectionVertical = 17
msoAnimDirectionVerticalIn = 25
msoAnimDirectionVerticalOut = 26

# MsoAnimEffect enumeration
msoAnimEffectAppear = 1
msoAnimEffectArcUp = 47
msoAnimEffectAscend = 39
msoAnimEffectBlast = 64
msoAnimEffectBlinds = 3
msoAnimEffectBoldFlash = 63
msoAnimEffectBoldReveal = 65
msoAnimEffectBoomerang = 25
msoAnimEffectBounce = 26
msoAnimEffectBox = 4
msoAnimEffectBrushOnColor = 66
msoAnimEffectBrushOnUnderline = 67
msoAnimEffectCenterRevolve = 40
msoAnimEffectChangeFillColor = 54
msoAnimEffectChangeFont = 55
msoAnimEffectChangeFontColor = 56
msoAnimEffectChangeFontSize = 57
msoAnimEffectChangeFontStyle = 58
msoAnimEffectChangeLineColor = 60
msoAnimEffectCheckerboard = 5
msoAnimEffectCircle = 6
msoAnimEffectColorBlend = 68
msoAnimEffectColorReveal = 27
msoAnimEffectColorWave = 69
msoAnimEffectComplementaryColor = 70
msoAnimEffectComplementaryColor2 = 71
msoAnimEffectContrastingColor = 72
msoAnimEffectCrawl = 7
msoAnimEffectCredits = 28
msoAnimEffectCustom = 0
msoAnimEffectDarken = 73
msoAnimEffectDesaturate = 74
msoAnimEffectDescend = 42
msoAnimEffectDiamond = 8
msoAnimEffectDissolve = 9
msoAnimEffectEaseIn = 29
msoAnimEffectExpand = 50
msoAnimEffectFade = 10
msoAnimEffectFadedSwivel = 41
msoAnimEffectFadedZoom = 48
msoAnimEffectFlashBulb = 75
msoAnimEffectFlashOnce = 11
msoAnimEffectFlicker = 76
msoAnimEffectFlip = 51
msoAnimEffectFloat = 30
msoAnimEffectFly = 2
msoAnimEffectFold = 53
msoAnimEffectGlide = 49
msoAnimEffectGrowAndTurn = 31
msoAnimEffectGrowShrink = 59
msoAnimEffectGrowWithColor = 77
msoAnimEffectLighten = 78
msoAnimEffectLightSpeed = 32
msoAnimEffectMediaPause = 84
msoAnimEffectMediaPlay = 83
msoAnimEffectMediaStop = 85
msoAnimEffectPath4PointStar = 101
msoAnimEffectPath5PointStar = 90
msoAnimEffectPath6PointStar = 96
msoAnimEffectPath8PointStar = 102
msoAnimEffectPathArcDown = 122
msoAnimEffectPathArcLeft = 136
msoAnimEffectPathArcRight = 143
msoAnimEffectPathArcUp = 129
msoAnimEffectPathBean = 116
msoAnimEffectPathBounceLeft = 126
msoAnimEffectPathBounceRight = 139
msoAnimEffectPathBuzzsaw = 110
msoAnimEffectPathCircle = 86
msoAnimEffectPathCrescentMoon = 91
msoAnimEffectPathCurvedSquare = 105
msoAnimEffectPathCurvedX = 106
msoAnimEffectPathCurvyLeft = 133
msoAnimEffectPathCurvyRight = 146
msoAnimEffectPathCurvyStar = 108
msoAnimEffectPathDecayingWave = 145
msoAnimEffectPathDiagonalDownRight = 134
msoAnimEffectPathDiagonalUpRight = 141
msoAnimEffectPathDiamond = 88
msoAnimEffectPathDown = 127
msoAnimEffectPathEqualTriangle = 98
msoAnimEffectPathFigure8Four = 113
msoAnimEffectPathFootball = 97
msoAnimEffectPathFunnel = 137
msoAnimEffectPathHeart = 94
msoAnimEffectPathHeartbeat = 130
msoAnimEffectPathHexagon = 89
msoAnimEffectPathHorizontalFigure8 = 111
msoAnimEffectPathInvertedSquare = 119
msoAnimEffectPathInvertedTriangle = 118
msoAnimEffectPathLeft = 120
msoAnimEffectPathLoopdeLoop = 109
msoAnimEffectPathNeutron = 114
msoAnimEffectPathOctagon = 95
msoAnimEffectPathParallelogram = 99
msoAnimEffectPathPeanut = 112
msoAnimEffectPathPentagon = 100
msoAnimEffectPathPlus = 117
msoAnimEffectPathPointyStar = 104
msoAnimEffectPathRight = 149
msoAnimEffectPathRightTriangle = 87
msoAnimEffectPathSCurve1 = 144
msoAnimEffectPathSCurve2 = 124
msoAnimEffectPathSineWave = 125
msoAnimEffectPathSpiralLeft = 140
msoAnimEffectPathSpiralRight = 131
msoAnimEffectPathSpring = 138
msoAnimEffectPathSquare = 92
msoAnimEffectPathStairsDown = 147
msoAnimEffectPathSwoosh = 115
msoAnimEffectPathTeardrop = 103
msoAnimEffectPathTrapezoid = 93
msoAnimEffectPathTurnDown = 135
msoAnimEffectPathTurnRight = 121
msoAnimEffectPathTurnUp = 128
msoAnimEffectPathTurnUpRight = 142
msoAnimEffectPathUp = 148
msoAnimEffectPathVerticalFigure8 = 107
msoAnimEffectPathWave = 132
msoAnimEffectPathZigzag = 123
msoAnimEffectPeek = 12
msoAnimEffectPinwheel = 33
msoAnimEffectPlus = 13
msoAnimEffectRandomBars = 14
msoAnimEffectRandomEffects = 24
msoAnimEffectRiseUp = 34
msoAnimEffectShimmer = 52
msoAnimEffectSling = 43
msoAnimEffectSpin = 61
msoAnimEffectSpinner = 44
msoAnimEffectSpiral = 15
msoAnimEffectSplit = 16
msoAnimEffectStretch = 17
msoAnimEffectStretchy = 45
msoAnimEffectStrips = 18
msoAnimEffectStyleEmphasis = 79
msoAnimEffectSwish = 35
msoAnimEffectSwivel = 19
msoAnimEffectTeeter = 80
msoAnimEffectThinLine = 36
msoAnimEffectTransparency = 62
msoAnimEffectUnfold = 37
msoAnimEffectVerticalGrow = 81
msoAnimEffectWave = 82
msoAnimEffectWedge = 20
msoAnimEffectWheel = 21
msoAnimEffectWhip = 38
msoAnimEffectWipe = 22
msoAnimEffectZip = 46
msoAnimEffectZoom = 23

# MsoAnimEffectAfter enumeration
msoAnimEffectAfterFreeze = 1
msoAnimEffectAfterHold = 3
msoAnimEffectAfterRemove = 2
msoAnimEffectAfterTransition = 4

# MsoAnimEffectRestart enumeration
msoAnimEffectRestartAlways = 1
msoAnimEffectRestartNever = 3
msoAnimEffectRestartWhenOff = 2

# MsoAnimFilterEffectSubtype enumeration
msoAnimFilterEffectSubtypeAcross = 9
msoAnimFilterEffectSubtypeDown = 25
msoAnimFilterEffectSubtypeDownLeft = 14
msoAnimFilterEffectSubtypeDownRight = 16
msoAnimFilterEffectSubtypeFromBottom = 13
msoAnimFilterEffectSubtypeFromLeft = 10
msoAnimFilterEffectSubtypeFromRight = 11
msoAnimFilterEffectSubtypeFromTop = 12
msoAnimFilterEffectSubtypeHorizontal = 5
msoAnimFilterEffectSubtypeIn = 7
msoAnimFilterEffectSubtypeInHorizontal = 3
msoAnimFilterEffectSubtypeInVertical = 1
msoAnimFilterEffectSubtypeLeft = 23
msoAnimFilterEffectSubtypeNone = 0
msoAnimFilterEffectSubtypeOut = 8
msoAnimFilterEffectSubtypeOutHorizontal = 4
msoAnimFilterEffectSubtypeOutVertical = 2
msoAnimFilterEffectSubtypeRight = 24
msoAnimFilterEffectSubtypeSpokes1 = 18
msoAnimFilterEffectSubtypeSpokes2 = 19
msoAnimFilterEffectSubtypeSpokes3 = 20
msoAnimFilterEffectSubtypeSpokes4 = 21
msoAnimFilterEffectSubtypeSpokes8 = 22
msoAnimFilterEffectSubtypeUp = 26
msoAnimFilterEffectSubtypeUpLeft = 15
msoAnimFilterEffectSubtypeUpRight = 17
msoAnimFilterEffectSubtypeVertical = 6

# MsoAnimFilterEffectType enumeration
msoAnimFilterEffectTypeBarn = 1
msoAnimFilterEffectTypeBlinds = 2
msoAnimFilterEffectTypeBox = 3
msoAnimFilterEffectTypeCheckerboard = 4
msoAnimFilterEffectTypeCircle = 5
msoAnimFilterEffectTypeDiamond = 6
msoAnimFilterEffectTypeDissolve = 7
msoAnimFilterEffectTypeFade = 8
msoAnimFilterEffectTypeImage = 9
msoAnimFilterEffectTypeNone = 0
msoAnimFilterEffectTypePixelate = 10
msoAnimFilterEffectTypePlus = 11
msoAnimFilterEffectTypeRandomBar = 12
msoAnimFilterEffectTypeSlide = 13
msoAnimFilterEffectTypeStretch = 14
msoAnimFilterEffectTypeStrips = 15
msoAnimFilterEffectTypeWedge = 16
msoAnimFilterEffectTypeWheel = 17
msoAnimFilterEffectTypeWipe = 18

# MsoAnimProperty enumeration
msoAnimColor = 7
msoAnimHeight = 4
msoAnimNone = 0
msoAnimOpacity = 5
msoAnimRotation = 6
msoAnimShapeFillBackColor = 1007
msoAnimShapeFillColor = 1005
msoAnimShapeFillOn = 1004
msoAnimShapeFillOpacity = 1006
msoAnimShapeLineColor = 1009
msoAnimShapeLineOn = 1008
msoAnimShapePictureBrightness = 1001
msoAnimShapePictureContrast = 1000
msoAnimShapePictureGamma = 1002
msoAnimShapePictureGrayscale = 1003
msoAnimShapeShadowColor = 1012
msoAnimShapeShadowOffsetX = 1014
msoAnimShapeShadowOffsetY = 1015
msoAnimShapeShadowOn = 1010
msoAnimShapeShadowOpacity = 1013
msoAnimShapeShadowType = 1011
msoAnimTextBulletCharacter = 111
msoAnimTextBulletColor = 114
msoAnimTextBulletFontName = 112
msoAnimTextBulletNumber = 113
msoAnimTextBulletRelativeSize = 115
msoAnimTextBulletStyle = 116
msoAnimTextBulletType = 117
msoAnimTextFontBold = 100
msoAnimTextFontColor = 101
msoAnimTextFontEmboss = 102
msoAnimTextFontItalic = 103
msoAnimTextFontName = 104
msoAnimTextFontShadow = 105
msoAnimTextFontSize = 106
msoAnimTextFontStrikeThrough = 110
msoAnimTextFontSubscript = 107
msoAnimTextFontSuperscript = 108
msoAnimTextFontUnderline = 109
msoAnimVisibility = 8
msoAnimWidth = 3
msoAnimX = 1
msoAnimY = 2

# MsoAnimTextUnitEffect enumeration
msoAnimTextUnitEffectByCharacter = 1
msoAnimTextUnitEffectByParagraph = 0
msoAnimTextUnitEffectByWord = 2
msoAnimTextUnitEffectMixed = -1

# MsoAnimTriggerType enumeration
msoAnimTriggerAfterPrevious = 3
msoAnimTriggerMixed = -1
msoAnimTriggerNone = 0
msoAnimTriggerOnPageClick = 1
msoAnimTriggerOnShapeClick = 4
msoAnimTriggerWithPrevious = 2
msoAnimTriggerOnMediaBookmark = 5

# MsoAnimType enumeration
msoAnimTypeColor = 2
msoAnimTypeCommand = 6
msoAnimTypeFilter = 7
msoAnimTypeMixed = -2
msoAnimTypeMotion = 1
msoAnimTypeNone = 0
msoAnimTypeProperty = 5
msoAnimTypeRotation = 4
msoAnimTypeScale = 3
msoAnimTypeSet = 8

# MsoClickState enumeration
msoClickStateAfterAllAnimations = -2
msoClickStateBeforeAutomaticAnimations = -1

class NamedSlideShow:

    def __init__(self, namedslideshow=None):
        self.com_object= namedslideshow

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SlideIDs(self):
        return self.com_object.SlideIDs

    @property
    def slideids(self):
        """Alias for SlideIDs"""
        return self.SlideIDs

    @property
    def slide_i_ds(self):
        """Alias for SlideIDs"""
        return self.SlideIDs

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class NamedSlideShows:

    def __init__(self, namedslideshows=None):
        self.com_object= namedslideshows

    def __call__(self, item):
        return NamedSlideShow(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, SafeArrayOfSlideIDs=None):
        arguments = com_arguments([unwrap(a) for a in [Name, SafeArrayOfSlideIDs]])
        return NamedSlideShow(self.com_object.Add(*arguments))

    def add(self, Name=None, SafeArrayOfSlideIDs=None):
        """Alias for Add"""
        arguments = [Name, SafeArrayOfSlideIDs]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return NamedSlideShow(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ObjectVerbs:

    def __init__(self, objectverbs=None):
        self.com_object= objectverbs

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class OLEFormat:

    def __init__(self, oleformat=None):
        self.com_object= oleformat

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def FollowColors(self):
        return self.com_object.FollowColors

    @FollowColors.setter
    def FollowColors(self, value):
        self.com_object.FollowColors = value

    @property
    def followcolors(self):
        """Alias for FollowColors"""
        return self.FollowColors

    @followcolors.setter
    def followcolors(self, value):
        """Alias for FollowColors.setter"""
        self.FollowColors = value

    @property
    def follow_colors(self):
        """Alias for FollowColors"""
        return self.FollowColors

    @follow_colors.setter
    def follow_colors(self, value):
        """Alias for FollowColors.setter"""
        self.FollowColors = value

    @property
    def Object(self):
        return self.com_object.Object

    @property
    def object(self):
        """Alias for Object"""
        return self.Object

    @property
    def ObjectVerbs(self):
        return ObjectVerbs(self.com_object.ObjectVerbs)

    @property
    def objectverbs(self):
        """Alias for ObjectVerbs"""
        return self.ObjectVerbs

    @property
    def object_verbs(self):
        """Alias for ObjectVerbs"""
        return self.ObjectVerbs

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ProgID(self):
        return self.com_object.ProgID

    @property
    def progid(self):
        """Alias for ProgID"""
        return self.ProgID

    @property
    def prog_i_d(self):
        """Alias for ProgID"""
        return self.ProgID

    def Activate(self):
        self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()

    def DoVerb(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.DoVerb(*arguments)

    def doverb(self, Index=None):
        """Alias for DoVerb"""
        arguments = [Index]
        return self.DoVerb(*arguments)

    def do_verb(self, Index=None):
        """Alias for DoVerb"""
        arguments = [Index]
        return self.DoVerb(*arguments)


class Options:

    def __init__(self, options=None):
        self.com_object= options

    @property
    def DisplayPasteOptions(self):
        return self.com_object.DisplayPasteOptions

    @DisplayPasteOptions.setter
    def DisplayPasteOptions(self, value):
        self.com_object.DisplayPasteOptions = value

    @property
    def displaypasteoptions(self):
        """Alias for DisplayPasteOptions"""
        return self.DisplayPasteOptions

    @displaypasteoptions.setter
    def displaypasteoptions(self, value):
        """Alias for DisplayPasteOptions.setter"""
        self.DisplayPasteOptions = value

    @property
    def display_paste_options(self):
        """Alias for DisplayPasteOptions"""
        return self.DisplayPasteOptions

    @display_paste_options.setter
    def display_paste_options(self, value):
        """Alias for DisplayPasteOptions.setter"""
        self.DisplayPasteOptions = value

    @property
    def ShowCoauthoringMergeChanges(self):
        return self.com_object.ShowCoauthoringMergeChanges

    @property
    def showcoauthoringmergechanges(self):
        """Alias for ShowCoauthoringMergeChanges"""
        return self.ShowCoauthoringMergeChanges

    @property
    def show_coauthoring_merge_changes(self):
        """Alias for ShowCoauthoringMergeChanges"""
        return self.ShowCoauthoringMergeChanges


class PageSetup:

    def __init__(self, pagesetup=None):
        self.com_object= pagesetup

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def FirstSlideNumber(self):
        return self.com_object.FirstSlideNumber

    @FirstSlideNumber.setter
    def FirstSlideNumber(self, value):
        self.com_object.FirstSlideNumber = value

    @property
    def firstslidenumber(self):
        """Alias for FirstSlideNumber"""
        return self.FirstSlideNumber

    @firstslidenumber.setter
    def firstslidenumber(self, value):
        """Alias for FirstSlideNumber.setter"""
        self.FirstSlideNumber = value

    @property
    def first_slide_number(self):
        """Alias for FirstSlideNumber"""
        return self.FirstSlideNumber

    @first_slide_number.setter
    def first_slide_number(self, value):
        """Alias for FirstSlideNumber.setter"""
        self.FirstSlideNumber = value

    @property
    def NotesOrientation(self):
        return self.com_object.NotesOrientation

    @NotesOrientation.setter
    def NotesOrientation(self, value):
        self.com_object.NotesOrientation = value

    @property
    def notesorientation(self):
        """Alias for NotesOrientation"""
        return self.NotesOrientation

    @notesorientation.setter
    def notesorientation(self, value):
        """Alias for NotesOrientation.setter"""
        self.NotesOrientation = value

    @property
    def notes_orientation(self):
        """Alias for NotesOrientation"""
        return self.NotesOrientation

    @notes_orientation.setter
    def notes_orientation(self, value):
        """Alias for NotesOrientation.setter"""
        self.NotesOrientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SlideHeight(self):
        return self.com_object.SlideHeight

    @SlideHeight.setter
    def SlideHeight(self, value):
        self.com_object.SlideHeight = value

    @property
    def slideheight(self):
        """Alias for SlideHeight"""
        return self.SlideHeight

    @slideheight.setter
    def slideheight(self, value):
        """Alias for SlideHeight.setter"""
        self.SlideHeight = value

    @property
    def slide_height(self):
        """Alias for SlideHeight"""
        return self.SlideHeight

    @slide_height.setter
    def slide_height(self, value):
        """Alias for SlideHeight.setter"""
        self.SlideHeight = value

    @property
    def SlideOrientation(self):
        return self.com_object.SlideOrientation

    @SlideOrientation.setter
    def SlideOrientation(self, value):
        self.com_object.SlideOrientation = value

    @property
    def slideorientation(self):
        """Alias for SlideOrientation"""
        return self.SlideOrientation

    @slideorientation.setter
    def slideorientation(self, value):
        """Alias for SlideOrientation.setter"""
        self.SlideOrientation = value

    @property
    def slide_orientation(self):
        """Alias for SlideOrientation"""
        return self.SlideOrientation

    @slide_orientation.setter
    def slide_orientation(self, value):
        """Alias for SlideOrientation.setter"""
        self.SlideOrientation = value

    @property
    def SlideSize(self):
        return self.com_object.SlideSize

    @SlideSize.setter
    def SlideSize(self, value):
        self.com_object.SlideSize = value

    @property
    def slidesize(self):
        """Alias for SlideSize"""
        return self.SlideSize

    @slidesize.setter
    def slidesize(self, value):
        """Alias for SlideSize.setter"""
        self.SlideSize = value

    @property
    def slide_size(self):
        """Alias for SlideSize"""
        return self.SlideSize

    @slide_size.setter
    def slide_size(self, value):
        """Alias for SlideSize.setter"""
        self.SlideSize = value

    @property
    def SlideWidth(self):
        return self.com_object.SlideWidth

    @SlideWidth.setter
    def SlideWidth(self, value):
        self.com_object.SlideWidth = value

    @property
    def slidewidth(self):
        """Alias for SlideWidth"""
        return self.SlideWidth

    @slidewidth.setter
    def slidewidth(self, value):
        """Alias for SlideWidth.setter"""
        self.SlideWidth = value

    @property
    def slide_width(self):
        """Alias for SlideWidth"""
        return self.SlideWidth

    @slide_width.setter
    def slide_width(self, value):
        """Alias for SlideWidth.setter"""
        self.SlideWidth = value


class Pane:

    def __init__(self, pane=None):
        self.com_object= pane

    @property
    def Active(self):
        return self.com_object.Active

    @property
    def active(self):
        """Alias for Active"""
        return self.Active

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ViewType(self):
        return self.com_object.ViewType

    @property
    def viewtype(self):
        """Alias for ViewType"""
        return self.ViewType

    @property
    def view_type(self):
        """Alias for ViewType"""
        return self.ViewType

    def Activate(self):
        self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()


class Panes:

    def __init__(self, panes=None):
        self.com_object= panes

    def __call__(self, item):
        return Pane(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Pane(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ParagraphFormat:

    def __init__(self, paragraphformat=None):
        self.com_object= paragraphformat

    @property
    def Alignment(self):
        return self.com_object.Alignment

    @Alignment.setter
    def Alignment(self, value):
        self.com_object.Alignment = value

    @property
    def alignment(self):
        """Alias for Alignment"""
        return self.Alignment

    @alignment.setter
    def alignment(self, value):
        """Alias for Alignment.setter"""
        self.Alignment = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BaseLineAlignment(self):
        return self.com_object.BaseLineAlignment

    @BaseLineAlignment.setter
    def BaseLineAlignment(self, value):
        self.com_object.BaseLineAlignment = value

    @property
    def baselinealignment(self):
        """Alias for BaseLineAlignment"""
        return self.BaseLineAlignment

    @baselinealignment.setter
    def baselinealignment(self, value):
        """Alias for BaseLineAlignment.setter"""
        self.BaseLineAlignment = value

    @property
    def base_line_alignment(self):
        """Alias for BaseLineAlignment"""
        return self.BaseLineAlignment

    @base_line_alignment.setter
    def base_line_alignment(self, value):
        """Alias for BaseLineAlignment.setter"""
        self.BaseLineAlignment = value

    @property
    def Bullet(self):
        return BulletFormat(self.com_object.Bullet)

    @property
    def bullet(self):
        """Alias for Bullet"""
        return self.Bullet

    @property
    def FarEastLineBreakControl(self):
        return self.com_object.FarEastLineBreakControl

    @FarEastLineBreakControl.setter
    def FarEastLineBreakControl(self, value):
        self.com_object.FarEastLineBreakControl = value

    @property
    def fareastlinebreakcontrol(self):
        """Alias for FarEastLineBreakControl"""
        return self.FarEastLineBreakControl

    @fareastlinebreakcontrol.setter
    def fareastlinebreakcontrol(self, value):
        """Alias for FarEastLineBreakControl.setter"""
        self.FarEastLineBreakControl = value

    @property
    def far_east_line_break_control(self):
        """Alias for FarEastLineBreakControl"""
        return self.FarEastLineBreakControl

    @far_east_line_break_control.setter
    def far_east_line_break_control(self, value):
        """Alias for FarEastLineBreakControl.setter"""
        self.FarEastLineBreakControl = value

    @property
    def HangingPunctuation(self):
        return self.com_object.HangingPunctuation

    @HangingPunctuation.setter
    def HangingPunctuation(self, value):
        self.com_object.HangingPunctuation = value

    @property
    def hangingpunctuation(self):
        """Alias for HangingPunctuation"""
        return self.HangingPunctuation

    @hangingpunctuation.setter
    def hangingpunctuation(self, value):
        """Alias for HangingPunctuation.setter"""
        self.HangingPunctuation = value

    @property
    def hanging_punctuation(self):
        """Alias for HangingPunctuation"""
        return self.HangingPunctuation

    @hanging_punctuation.setter
    def hanging_punctuation(self, value):
        """Alias for HangingPunctuation.setter"""
        self.HangingPunctuation = value

    @property
    def LineRuleAfter(self):
        return self.com_object.LineRuleAfter

    @LineRuleAfter.setter
    def LineRuleAfter(self, value):
        self.com_object.LineRuleAfter = value

    @property
    def lineruleafter(self):
        """Alias for LineRuleAfter"""
        return self.LineRuleAfter

    @lineruleafter.setter
    def lineruleafter(self, value):
        """Alias for LineRuleAfter.setter"""
        self.LineRuleAfter = value

    @property
    def line_rule_after(self):
        """Alias for LineRuleAfter"""
        return self.LineRuleAfter

    @line_rule_after.setter
    def line_rule_after(self, value):
        """Alias for LineRuleAfter.setter"""
        self.LineRuleAfter = value

    @property
    def LineRuleBefore(self):
        return self.com_object.LineRuleBefore

    @LineRuleBefore.setter
    def LineRuleBefore(self, value):
        self.com_object.LineRuleBefore = value

    @property
    def linerulebefore(self):
        """Alias for LineRuleBefore"""
        return self.LineRuleBefore

    @linerulebefore.setter
    def linerulebefore(self, value):
        """Alias for LineRuleBefore.setter"""
        self.LineRuleBefore = value

    @property
    def line_rule_before(self):
        """Alias for LineRuleBefore"""
        return self.LineRuleBefore

    @line_rule_before.setter
    def line_rule_before(self, value):
        """Alias for LineRuleBefore.setter"""
        self.LineRuleBefore = value

    @property
    def LineRuleWithin(self):
        return self.com_object.LineRuleWithin

    @LineRuleWithin.setter
    def LineRuleWithin(self, value):
        self.com_object.LineRuleWithin = value

    @property
    def linerulewithin(self):
        """Alias for LineRuleWithin"""
        return self.LineRuleWithin

    @linerulewithin.setter
    def linerulewithin(self, value):
        """Alias for LineRuleWithin.setter"""
        self.LineRuleWithin = value

    @property
    def line_rule_within(self):
        """Alias for LineRuleWithin"""
        return self.LineRuleWithin

    @line_rule_within.setter
    def line_rule_within(self, value):
        """Alias for LineRuleWithin.setter"""
        self.LineRuleWithin = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SpaceAfter(self):
        return self.com_object.SpaceAfter

    @SpaceAfter.setter
    def SpaceAfter(self, value):
        self.com_object.SpaceAfter = value

    @property
    def spaceafter(self):
        """Alias for SpaceAfter"""
        return self.SpaceAfter

    @spaceafter.setter
    def spaceafter(self, value):
        """Alias for SpaceAfter.setter"""
        self.SpaceAfter = value

    @property
    def space_after(self):
        """Alias for SpaceAfter"""
        return self.SpaceAfter

    @space_after.setter
    def space_after(self, value):
        """Alias for SpaceAfter.setter"""
        self.SpaceAfter = value

    @property
    def SpaceBefore(self):
        return self.com_object.SpaceBefore

    @SpaceBefore.setter
    def SpaceBefore(self, value):
        self.com_object.SpaceBefore = value

    @property
    def spacebefore(self):
        """Alias for SpaceBefore"""
        return self.SpaceBefore

    @spacebefore.setter
    def spacebefore(self, value):
        """Alias for SpaceBefore.setter"""
        self.SpaceBefore = value

    @property
    def space_before(self):
        """Alias for SpaceBefore"""
        return self.SpaceBefore

    @space_before.setter
    def space_before(self, value):
        """Alias for SpaceBefore.setter"""
        self.SpaceBefore = value

    @property
    def SpaceWithin(self):
        return self.com_object.SpaceWithin

    @SpaceWithin.setter
    def SpaceWithin(self, value):
        self.com_object.SpaceWithin = value

    @property
    def spacewithin(self):
        """Alias for SpaceWithin"""
        return self.SpaceWithin

    @spacewithin.setter
    def spacewithin(self, value):
        """Alias for SpaceWithin.setter"""
        self.SpaceWithin = value

    @property
    def space_within(self):
        """Alias for SpaceWithin"""
        return self.SpaceWithin

    @space_within.setter
    def space_within(self, value):
        """Alias for SpaceWithin.setter"""
        self.SpaceWithin = value

    @property
    def TextDirection(self):
        return self.com_object.TextDirection

    @TextDirection.setter
    def TextDirection(self, value):
        self.com_object.TextDirection = value

    @property
    def textdirection(self):
        """Alias for TextDirection"""
        return self.TextDirection

    @textdirection.setter
    def textdirection(self, value):
        """Alias for TextDirection.setter"""
        self.TextDirection = value

    @property
    def text_direction(self):
        """Alias for TextDirection"""
        return self.TextDirection

    @text_direction.setter
    def text_direction(self, value):
        """Alias for TextDirection.setter"""
        self.TextDirection = value

    @property
    def WordWrap(self):
        return self.com_object.WordWrap

    @WordWrap.setter
    def WordWrap(self, value):
        self.com_object.WordWrap = value

    @property
    def wordwrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @wordwrap.setter
    def wordwrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value

    @property
    def word_wrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @word_wrap.setter
    def word_wrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value


class PictureFormat:

    def __init__(self, pictureformat=None):
        self.com_object= pictureformat

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Brightness(self):
        return self.com_object.Brightness

    @Brightness.setter
    def Brightness(self, value):
        self.com_object.Brightness = value

    @property
    def brightness(self):
        """Alias for Brightness"""
        return self.Brightness

    @brightness.setter
    def brightness(self, value):
        """Alias for Brightness.setter"""
        self.Brightness = value

    @property
    def ColorType(self):
        return self.com_object.ColorType

    @ColorType.setter
    def ColorType(self, value):
        self.com_object.ColorType = value

    @property
    def colortype(self):
        """Alias for ColorType"""
        return self.ColorType

    @colortype.setter
    def colortype(self, value):
        """Alias for ColorType.setter"""
        self.ColorType = value

    @property
    def color_type(self):
        """Alias for ColorType"""
        return self.ColorType

    @color_type.setter
    def color_type(self, value):
        """Alias for ColorType.setter"""
        self.ColorType = value

    @property
    def Contrast(self):
        return self.com_object.Contrast

    @Contrast.setter
    def Contrast(self, value):
        self.com_object.Contrast = value

    @property
    def contrast(self):
        """Alias for Contrast"""
        return self.Contrast

    @contrast.setter
    def contrast(self, value):
        """Alias for Contrast.setter"""
        self.Contrast = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Crop(self):
        return self.com_object.Crop

    @Crop.setter
    def Crop(self, value):
        self.com_object.Crop = value

    @property
    def crop(self):
        """Alias for Crop"""
        return self.Crop

    @crop.setter
    def crop(self, value):
        """Alias for Crop.setter"""
        self.Crop = value

    @property
    def CropBottom(self):
        return self.com_object.CropBottom

    @CropBottom.setter
    def CropBottom(self, value):
        self.com_object.CropBottom = value

    @property
    def cropbottom(self):
        """Alias for CropBottom"""
        return self.CropBottom

    @cropbottom.setter
    def cropbottom(self, value):
        """Alias for CropBottom.setter"""
        self.CropBottom = value

    @property
    def crop_bottom(self):
        """Alias for CropBottom"""
        return self.CropBottom

    @crop_bottom.setter
    def crop_bottom(self, value):
        """Alias for CropBottom.setter"""
        self.CropBottom = value

    @property
    def CropLeft(self):
        return self.com_object.CropLeft

    @CropLeft.setter
    def CropLeft(self, value):
        self.com_object.CropLeft = value

    @property
    def cropleft(self):
        """Alias for CropLeft"""
        return self.CropLeft

    @cropleft.setter
    def cropleft(self, value):
        """Alias for CropLeft.setter"""
        self.CropLeft = value

    @property
    def crop_left(self):
        """Alias for CropLeft"""
        return self.CropLeft

    @crop_left.setter
    def crop_left(self, value):
        """Alias for CropLeft.setter"""
        self.CropLeft = value

    @property
    def CropRight(self):
        return self.com_object.CropRight

    @CropRight.setter
    def CropRight(self, value):
        self.com_object.CropRight = value

    @property
    def cropright(self):
        """Alias for CropRight"""
        return self.CropRight

    @cropright.setter
    def cropright(self, value):
        """Alias for CropRight.setter"""
        self.CropRight = value

    @property
    def crop_right(self):
        """Alias for CropRight"""
        return self.CropRight

    @crop_right.setter
    def crop_right(self, value):
        """Alias for CropRight.setter"""
        self.CropRight = value

    @property
    def CropTop(self):
        return self.com_object.CropTop

    @CropTop.setter
    def CropTop(self, value):
        self.com_object.CropTop = value

    @property
    def croptop(self):
        """Alias for CropTop"""
        return self.CropTop

    @croptop.setter
    def croptop(self, value):
        """Alias for CropTop.setter"""
        self.CropTop = value

    @property
    def crop_top(self):
        """Alias for CropTop"""
        return self.CropTop

    @crop_top.setter
    def crop_top(self, value):
        """Alias for CropTop.setter"""
        self.CropTop = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def TransparencyColor(self):
        return self.com_object.TransparencyColor

    @TransparencyColor.setter
    def TransparencyColor(self, value):
        self.com_object.TransparencyColor = value

    @property
    def transparencycolor(self):
        """Alias for TransparencyColor"""
        return self.TransparencyColor

    @transparencycolor.setter
    def transparencycolor(self, value):
        """Alias for TransparencyColor.setter"""
        self.TransparencyColor = value

    @property
    def transparency_color(self):
        """Alias for TransparencyColor"""
        return self.TransparencyColor

    @transparency_color.setter
    def transparency_color(self, value):
        """Alias for TransparencyColor.setter"""
        self.TransparencyColor = value

    @property
    def TransparentBackground(self):
        return self.com_object.TransparentBackground

    @TransparentBackground.setter
    def TransparentBackground(self, value):
        self.com_object.TransparentBackground = value

    @property
    def transparentbackground(self):
        """Alias for TransparentBackground"""
        return self.TransparentBackground

    @transparentbackground.setter
    def transparentbackground(self, value):
        """Alias for TransparentBackground.setter"""
        self.TransparentBackground = value

    @property
    def transparent_background(self):
        """Alias for TransparentBackground"""
        return self.TransparentBackground

    @transparent_background.setter
    def transparent_background(self, value):
        """Alias for TransparentBackground.setter"""
        self.TransparentBackground = value

    def IncrementBrightness(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementBrightness(*arguments)

    def incrementbrightness(self, Increment=None):
        """Alias for IncrementBrightness"""
        arguments = [Increment]
        return self.IncrementBrightness(*arguments)

    def increment_brightness(self, Increment=None):
        """Alias for IncrementBrightness"""
        arguments = [Increment]
        return self.IncrementBrightness(*arguments)

    def IncrementContrast(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementContrast(*arguments)

    def incrementcontrast(self, Increment=None):
        """Alias for IncrementContrast"""
        arguments = [Increment]
        return self.IncrementContrast(*arguments)

    def increment_contrast(self, Increment=None):
        """Alias for IncrementContrast"""
        arguments = [Increment]
        return self.IncrementContrast(*arguments)


class PlaceholderFormat:

    def __init__(self, placeholderformat=None):
        self.com_object= placeholderformat

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ContainedType(self):
        return self.com_object.ContainedType

    @property
    def containedtype(self):
        """Alias for ContainedType"""
        return self.ContainedType

    @property
    def contained_type(self):
        """Alias for ContainedType"""
        return self.ContainedType

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Type(self):
        return self.com_object.Type

    @property
    def type(self):
        """Alias for Type"""
        return self.Type


class Placeholders:

    def __init__(self, placeholders=None):
        self.com_object= placeholders

    def __call__(self, item):
        return Placeholder(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def FindByName(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Shape(self.com_object.FindByName(*arguments))

    def findbyname(self, Index=None):
        """Alias for FindByName"""
        arguments = [Index]
        return self.FindByName(*arguments)

    def find_by_name(self, Index=None):
        """Alias for FindByName"""
        arguments = [Index]
        return self.FindByName(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Shape(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Player:

    def __init__(self, player=None):
        self.com_object= player

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def CurrentPosition(self):
        return self.com_object.CurrentPosition

    @CurrentPosition.setter
    def CurrentPosition(self, value):
        self.com_object.CurrentPosition = value

    @property
    def currentposition(self):
        """Alias for CurrentPosition"""
        return self.CurrentPosition

    @currentposition.setter
    def currentposition(self, value):
        """Alias for CurrentPosition.setter"""
        self.CurrentPosition = value

    @property
    def current_position(self):
        """Alias for CurrentPosition"""
        return self.CurrentPosition

    @current_position.setter
    def current_position(self, value):
        """Alias for CurrentPosition.setter"""
        self.CurrentPosition = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def State(self):
        return self.com_object.State

    @property
    def state(self):
        """Alias for State"""
        return self.State

    def GoToNextBookmark(self):
        self.com_object.GoToNextBookmark()

    def gotonextbookmark(self):
        """Alias for GoToNextBookmark"""
        return self.GoToNextBookmark()

    def go_to_next_bookmark(self):
        """Alias for GoToNextBookmark"""
        return self.GoToNextBookmark()

    def GoToPreviousBookmark(self):
        self.com_object.GoToPreviousBookmark()

    def gotopreviousbookmark(self):
        """Alias for GoToPreviousBookmark"""
        return self.GoToPreviousBookmark()

    def go_to_previous_bookmark(self):
        """Alias for GoToPreviousBookmark"""
        return self.GoToPreviousBookmark()

    def Pause(self):
        self.com_object.Pause()

    def pause(self):
        """Alias for Pause"""
        return self.Pause()

    def Play(self):
        return self.com_object.Play()

    def play(self):
        """Alias for Play"""
        return self.Play()

    def Stop(self):
        self.com_object.Stop()

    def stop(self):
        """Alias for Stop"""
        return self.Stop()


class PlaySettings:

    def __init__(self, playsettings=None):
        self.com_object= playsettings

    @property
    def ActionVerb(self):
        return self.com_object.ActionVerb

    @ActionVerb.setter
    def ActionVerb(self, value):
        self.com_object.ActionVerb = value

    @property
    def actionverb(self):
        """Alias for ActionVerb"""
        return self.ActionVerb

    @actionverb.setter
    def actionverb(self, value):
        """Alias for ActionVerb.setter"""
        self.ActionVerb = value

    @property
    def action_verb(self):
        """Alias for ActionVerb"""
        return self.ActionVerb

    @action_verb.setter
    def action_verb(self, value):
        """Alias for ActionVerb.setter"""
        self.ActionVerb = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def HideWhileNotPlaying(self):
        return self.com_object.HideWhileNotPlaying

    @HideWhileNotPlaying.setter
    def HideWhileNotPlaying(self, value):
        self.com_object.HideWhileNotPlaying = value

    @property
    def hidewhilenotplaying(self):
        """Alias for HideWhileNotPlaying"""
        return self.HideWhileNotPlaying

    @hidewhilenotplaying.setter
    def hidewhilenotplaying(self, value):
        """Alias for HideWhileNotPlaying.setter"""
        self.HideWhileNotPlaying = value

    @property
    def hide_while_not_playing(self):
        """Alias for HideWhileNotPlaying"""
        return self.HideWhileNotPlaying

    @hide_while_not_playing.setter
    def hide_while_not_playing(self, value):
        """Alias for HideWhileNotPlaying.setter"""
        self.HideWhileNotPlaying = value

    @property
    def LoopUntilStopped(self):
        return self.com_object.LoopUntilStopped

    @LoopUntilStopped.setter
    def LoopUntilStopped(self, value):
        self.com_object.LoopUntilStopped = value

    @property
    def loopuntilstopped(self):
        """Alias for LoopUntilStopped"""
        return self.LoopUntilStopped

    @loopuntilstopped.setter
    def loopuntilstopped(self, value):
        """Alias for LoopUntilStopped.setter"""
        self.LoopUntilStopped = value

    @property
    def loop_until_stopped(self):
        """Alias for LoopUntilStopped"""
        return self.LoopUntilStopped

    @loop_until_stopped.setter
    def loop_until_stopped(self, value):
        """Alias for LoopUntilStopped.setter"""
        self.LoopUntilStopped = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PauseAnimation(self):
        return self.com_object.PauseAnimation

    @PauseAnimation.setter
    def PauseAnimation(self, value):
        self.com_object.PauseAnimation = value

    @property
    def pauseanimation(self):
        """Alias for PauseAnimation"""
        return self.PauseAnimation

    @pauseanimation.setter
    def pauseanimation(self, value):
        """Alias for PauseAnimation.setter"""
        self.PauseAnimation = value

    @property
    def pause_animation(self):
        """Alias for PauseAnimation"""
        return self.PauseAnimation

    @pause_animation.setter
    def pause_animation(self, value):
        """Alias for PauseAnimation.setter"""
        self.PauseAnimation = value

    @property
    def PlayOnEntry(self):
        return self.com_object.PlayOnEntry

    @PlayOnEntry.setter
    def PlayOnEntry(self, value):
        self.com_object.PlayOnEntry = value

    @property
    def playonentry(self):
        """Alias for PlayOnEntry"""
        return self.PlayOnEntry

    @playonentry.setter
    def playonentry(self, value):
        """Alias for PlayOnEntry.setter"""
        self.PlayOnEntry = value

    @property
    def play_on_entry(self):
        """Alias for PlayOnEntry"""
        return self.PlayOnEntry

    @play_on_entry.setter
    def play_on_entry(self, value):
        """Alias for PlayOnEntry.setter"""
        self.PlayOnEntry = value

    @property
    def RewindMovie(self):
        return self.com_object.RewindMovie

    @RewindMovie.setter
    def RewindMovie(self, value):
        self.com_object.RewindMovie = value

    @property
    def rewindmovie(self):
        """Alias for RewindMovie"""
        return self.RewindMovie

    @rewindmovie.setter
    def rewindmovie(self, value):
        """Alias for RewindMovie.setter"""
        self.RewindMovie = value

    @property
    def rewind_movie(self):
        """Alias for RewindMovie"""
        return self.RewindMovie

    @rewind_movie.setter
    def rewind_movie(self, value):
        """Alias for RewindMovie.setter"""
        self.RewindMovie = value

    @property
    def StopAfterSlides(self):
        return self.com_object.StopAfterSlides

    @StopAfterSlides.setter
    def StopAfterSlides(self, value):
        self.com_object.StopAfterSlides = value

    @property
    def stopafterslides(self):
        """Alias for StopAfterSlides"""
        return self.StopAfterSlides

    @stopafterslides.setter
    def stopafterslides(self, value):
        """Alias for StopAfterSlides.setter"""
        self.StopAfterSlides = value

    @property
    def stop_after_slides(self):
        """Alias for StopAfterSlides"""
        return self.StopAfterSlides

    @stop_after_slides.setter
    def stop_after_slides(self, value):
        """Alias for StopAfterSlides.setter"""
        self.StopAfterSlides = value


class PlotArea:

    def __init__(self, plotarea=None):
        self.com_object= plotarea

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def InsideHeight(self):
        return self.com_object.InsideHeight

    @InsideHeight.setter
    def InsideHeight(self, value):
        self.com_object.InsideHeight = value

    @property
    def insideheight(self):
        """Alias for InsideHeight"""
        return self.InsideHeight

    @insideheight.setter
    def insideheight(self, value):
        """Alias for InsideHeight.setter"""
        self.InsideHeight = value

    @property
    def inside_height(self):
        """Alias for InsideHeight"""
        return self.InsideHeight

    @inside_height.setter
    def inside_height(self, value):
        """Alias for InsideHeight.setter"""
        self.InsideHeight = value

    @property
    def InsideLeft(self):
        return self.com_object.InsideLeft

    @InsideLeft.setter
    def InsideLeft(self, value):
        self.com_object.InsideLeft = value

    @property
    def insideleft(self):
        """Alias for InsideLeft"""
        return self.InsideLeft

    @insideleft.setter
    def insideleft(self, value):
        """Alias for InsideLeft.setter"""
        self.InsideLeft = value

    @property
    def inside_left(self):
        """Alias for InsideLeft"""
        return self.InsideLeft

    @inside_left.setter
    def inside_left(self, value):
        """Alias for InsideLeft.setter"""
        self.InsideLeft = value

    @property
    def InsideTop(self):
        return self.com_object.InsideTop

    @InsideTop.setter
    def InsideTop(self, value):
        self.com_object.InsideTop = value

    @property
    def insidetop(self):
        """Alias for InsideTop"""
        return self.InsideTop

    @insidetop.setter
    def insidetop(self, value):
        """Alias for InsideTop.setter"""
        self.InsideTop = value

    @property
    def inside_top(self):
        """Alias for InsideTop"""
        return self.InsideTop

    @inside_top.setter
    def inside_top(self, value):
        """Alias for InsideTop.setter"""
        self.InsideTop = value

    @property
    def InsideWidth(self):
        return self.com_object.InsideWidth

    @InsideWidth.setter
    def InsideWidth(self, value):
        self.com_object.InsideWidth = value

    @property
    def insidewidth(self):
        """Alias for InsideWidth"""
        return self.InsideWidth

    @insidewidth.setter
    def insidewidth(self, value):
        """Alias for InsideWidth.setter"""
        self.InsideWidth = value

    @property
    def inside_width(self):
        """Alias for InsideWidth"""
        return self.InsideWidth

    @inside_width.setter
    def inside_width(self, value):
        """Alias for InsideWidth.setter"""
        self.InsideWidth = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return XlChartElementPosition(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def ClearFormats(self):
        self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Point:

    def __init__(self, point=None):
        self.com_object= point

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ApplyPictToEnd(self):
        return self.com_object.ApplyPictToEnd

    @ApplyPictToEnd.setter
    def ApplyPictToEnd(self, value):
        self.com_object.ApplyPictToEnd = value

    @property
    def applypicttoend(self):
        """Alias for ApplyPictToEnd"""
        return self.ApplyPictToEnd

    @applypicttoend.setter
    def applypicttoend(self, value):
        """Alias for ApplyPictToEnd.setter"""
        self.ApplyPictToEnd = value

    @property
    def apply_pict_to_end(self):
        """Alias for ApplyPictToEnd"""
        return self.ApplyPictToEnd

    @apply_pict_to_end.setter
    def apply_pict_to_end(self, value):
        """Alias for ApplyPictToEnd.setter"""
        self.ApplyPictToEnd = value

    @property
    def ApplyPictToFront(self):
        return self.com_object.ApplyPictToFront

    @ApplyPictToFront.setter
    def ApplyPictToFront(self, value):
        self.com_object.ApplyPictToFront = value

    @property
    def applypicttofront(self):
        """Alias for ApplyPictToFront"""
        return self.ApplyPictToFront

    @applypicttofront.setter
    def applypicttofront(self, value):
        """Alias for ApplyPictToFront.setter"""
        self.ApplyPictToFront = value

    @property
    def apply_pict_to_front(self):
        """Alias for ApplyPictToFront"""
        return self.ApplyPictToFront

    @apply_pict_to_front.setter
    def apply_pict_to_front(self, value):
        """Alias for ApplyPictToFront.setter"""
        self.ApplyPictToFront = value

    @property
    def ApplyPictToSides(self):
        return self.com_object.ApplyPictToSides

    @ApplyPictToSides.setter
    def ApplyPictToSides(self, value):
        self.com_object.ApplyPictToSides = value

    @property
    def applypicttosides(self):
        """Alias for ApplyPictToSides"""
        return self.ApplyPictToSides

    @applypicttosides.setter
    def applypicttosides(self, value):
        """Alias for ApplyPictToSides.setter"""
        self.ApplyPictToSides = value

    @property
    def apply_pict_to_sides(self):
        """Alias for ApplyPictToSides"""
        return self.ApplyPictToSides

    @apply_pict_to_sides.setter
    def apply_pict_to_sides(self, value):
        """Alias for ApplyPictToSides.setter"""
        self.ApplyPictToSides = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DataLabel(self):
        return DataLabel(self.com_object.DataLabel)

    @property
    def datalabel(self):
        """Alias for DataLabel"""
        return self.DataLabel

    @property
    def data_label(self):
        """Alias for DataLabel"""
        return self.DataLabel

    @property
    def Explosion(self):
        return self.com_object.Explosion

    @Explosion.setter
    def Explosion(self, value):
        self.com_object.Explosion = value

    @property
    def explosion(self):
        """Alias for Explosion"""
        return self.Explosion

    @explosion.setter
    def explosion(self, value):
        """Alias for Explosion.setter"""
        self.Explosion = value

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Has3DEffect(self):
        return self.com_object.Has3DEffect

    @Has3DEffect.setter
    def Has3DEffect(self, value):
        self.com_object.Has3DEffect = value

    @property
    def has3deffect(self):
        """Alias for Has3DEffect"""
        return self.Has3DEffect

    @has3deffect.setter
    def has3deffect(self, value):
        """Alias for Has3DEffect.setter"""
        self.Has3DEffect = value

    @property
    def has3_d_effect(self):
        """Alias for Has3DEffect"""
        return self.Has3DEffect

    @has3_d_effect.setter
    def has3_d_effect(self, value):
        """Alias for Has3DEffect.setter"""
        self.Has3DEffect = value

    @property
    def HasDataLabel(self):
        return self.com_object.HasDataLabel

    @HasDataLabel.setter
    def HasDataLabel(self, value):
        self.com_object.HasDataLabel = value

    @property
    def hasdatalabel(self):
        """Alias for HasDataLabel"""
        return self.HasDataLabel

    @hasdatalabel.setter
    def hasdatalabel(self, value):
        """Alias for HasDataLabel.setter"""
        self.HasDataLabel = value

    @property
    def has_data_label(self):
        """Alias for HasDataLabel"""
        return self.HasDataLabel

    @has_data_label.setter
    def has_data_label(self, value):
        """Alias for HasDataLabel.setter"""
        self.HasDataLabel = value

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def InvertIfNegative(self):
        return self.com_object.InvertIfNegative

    @InvertIfNegative.setter
    def InvertIfNegative(self, value):
        self.com_object.InvertIfNegative = value

    @property
    def invertifnegative(self):
        """Alias for InvertIfNegative"""
        return self.InvertIfNegative

    @invertifnegative.setter
    def invertifnegative(self, value):
        """Alias for InvertIfNegative.setter"""
        self.InvertIfNegative = value

    @property
    def invert_if_negative(self):
        """Alias for InvertIfNegative"""
        return self.InvertIfNegative

    @invert_if_negative.setter
    def invert_if_negative(self, value):
        """Alias for InvertIfNegative.setter"""
        self.InvertIfNegative = value

    @property
    def IsTotal(self):
        return self.com_object.IsTotal

    @IsTotal.setter
    def IsTotal(self, value):
        self.com_object.IsTotal = value

    @property
    def istotal(self):
        """Alias for IsTotal"""
        return self.IsTotal

    @istotal.setter
    def istotal(self, value):
        """Alias for IsTotal.setter"""
        self.IsTotal = value

    @property
    def is_total(self):
        """Alias for IsTotal"""
        return self.IsTotal

    @is_total.setter
    def is_total(self, value):
        """Alias for IsTotal.setter"""
        self.IsTotal = value

    @property
    def Left(self):
        return self.com_object.Left

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @property
    def MarkerBackgroundColor(self):
        return self.com_object.MarkerBackgroundColor

    @MarkerBackgroundColor.setter
    def MarkerBackgroundColor(self, value):
        self.com_object.MarkerBackgroundColor = value

    @property
    def markerbackgroundcolor(self):
        """Alias for MarkerBackgroundColor"""
        return self.MarkerBackgroundColor

    @markerbackgroundcolor.setter
    def markerbackgroundcolor(self, value):
        """Alias for MarkerBackgroundColor.setter"""
        self.MarkerBackgroundColor = value

    @property
    def marker_background_color(self):
        """Alias for MarkerBackgroundColor"""
        return self.MarkerBackgroundColor

    @marker_background_color.setter
    def marker_background_color(self, value):
        """Alias for MarkerBackgroundColor.setter"""
        self.MarkerBackgroundColor = value

    @property
    def MarkerBackgroundColorIndex(self):
        return XlColorIndex(self.com_object.MarkerBackgroundColorIndex)

    @MarkerBackgroundColorIndex.setter
    def MarkerBackgroundColorIndex(self, value):
        self.com_object.MarkerBackgroundColorIndex = value

    @property
    def markerbackgroundcolorindex(self):
        """Alias for MarkerBackgroundColorIndex"""
        return self.MarkerBackgroundColorIndex

    @markerbackgroundcolorindex.setter
    def markerbackgroundcolorindex(self, value):
        """Alias for MarkerBackgroundColorIndex.setter"""
        self.MarkerBackgroundColorIndex = value

    @property
    def marker_background_color_index(self):
        """Alias for MarkerBackgroundColorIndex"""
        return self.MarkerBackgroundColorIndex

    @marker_background_color_index.setter
    def marker_background_color_index(self, value):
        """Alias for MarkerBackgroundColorIndex.setter"""
        self.MarkerBackgroundColorIndex = value

    @property
    def MarkerForegroundColor(self):
        return self.com_object.MarkerForegroundColor

    @MarkerForegroundColor.setter
    def MarkerForegroundColor(self, value):
        self.com_object.MarkerForegroundColor = value

    @property
    def markerforegroundcolor(self):
        """Alias for MarkerForegroundColor"""
        return self.MarkerForegroundColor

    @markerforegroundcolor.setter
    def markerforegroundcolor(self, value):
        """Alias for MarkerForegroundColor.setter"""
        self.MarkerForegroundColor = value

    @property
    def marker_foreground_color(self):
        """Alias for MarkerForegroundColor"""
        return self.MarkerForegroundColor

    @marker_foreground_color.setter
    def marker_foreground_color(self, value):
        """Alias for MarkerForegroundColor.setter"""
        self.MarkerForegroundColor = value

    @property
    def MarkerForegroundColorIndex(self):
        return XlColorIndex(self.com_object.MarkerForegroundColorIndex)

    @MarkerForegroundColorIndex.setter
    def MarkerForegroundColorIndex(self, value):
        self.com_object.MarkerForegroundColorIndex = value

    @property
    def markerforegroundcolorindex(self):
        """Alias for MarkerForegroundColorIndex"""
        return self.MarkerForegroundColorIndex

    @markerforegroundcolorindex.setter
    def markerforegroundcolorindex(self, value):
        """Alias for MarkerForegroundColorIndex.setter"""
        self.MarkerForegroundColorIndex = value

    @property
    def marker_foreground_color_index(self):
        """Alias for MarkerForegroundColorIndex"""
        return self.MarkerForegroundColorIndex

    @marker_foreground_color_index.setter
    def marker_foreground_color_index(self, value):
        """Alias for MarkerForegroundColorIndex.setter"""
        self.MarkerForegroundColorIndex = value

    @property
    def MarkerSize(self):
        return self.com_object.MarkerSize

    @MarkerSize.setter
    def MarkerSize(self, value):
        self.com_object.MarkerSize = value

    @property
    def markersize(self):
        """Alias for MarkerSize"""
        return self.MarkerSize

    @markersize.setter
    def markersize(self, value):
        """Alias for MarkerSize.setter"""
        self.MarkerSize = value

    @property
    def marker_size(self):
        """Alias for MarkerSize"""
        return self.MarkerSize

    @marker_size.setter
    def marker_size(self, value):
        """Alias for MarkerSize.setter"""
        self.MarkerSize = value

    @property
    def MarkerStyle(self):
        return XlMarkerStyle(self.com_object.MarkerStyle)

    @MarkerStyle.setter
    def MarkerStyle(self, value):
        self.com_object.MarkerStyle = value

    @property
    def markerstyle(self):
        """Alias for MarkerStyle"""
        return self.MarkerStyle

    @markerstyle.setter
    def markerstyle(self, value):
        """Alias for MarkerStyle.setter"""
        self.MarkerStyle = value

    @property
    def marker_style(self):
        """Alias for MarkerStyle"""
        return self.MarkerStyle

    @marker_style.setter
    def marker_style(self, value):
        """Alias for MarkerStyle.setter"""
        self.MarkerStyle = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PictureType(self):
        return XlChartPictureType(self.com_object.PictureType)

    @PictureType.setter
    def PictureType(self, value):
        self.com_object.PictureType = value

    @property
    def picturetype(self):
        """Alias for PictureType"""
        return self.PictureType

    @picturetype.setter
    def picturetype(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def picture_type(self):
        """Alias for PictureType"""
        return self.PictureType

    @picture_type.setter
    def picture_type(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def PictureUnit2(self):
        return self.com_object.PictureUnit2

    @PictureUnit2.setter
    def PictureUnit2(self, value):
        self.com_object.PictureUnit2 = value

    @property
    def pictureunit2(self):
        """Alias for PictureUnit2"""
        return self.PictureUnit2

    @pictureunit2.setter
    def pictureunit2(self, value):
        """Alias for PictureUnit2.setter"""
        self.PictureUnit2 = value

    @property
    def picture_unit2(self):
        """Alias for PictureUnit2"""
        return self.PictureUnit2

    @picture_unit2.setter
    def picture_unit2(self, value):
        """Alias for PictureUnit2.setter"""
        self.PictureUnit2 = value

    @property
    def SecondaryPlot(self):
        return self.com_object.SecondaryPlot

    @SecondaryPlot.setter
    def SecondaryPlot(self, value):
        self.com_object.SecondaryPlot = value

    @property
    def secondaryplot(self):
        """Alias for SecondaryPlot"""
        return self.SecondaryPlot

    @secondaryplot.setter
    def secondaryplot(self, value):
        """Alias for SecondaryPlot.setter"""
        self.SecondaryPlot = value

    @property
    def secondary_plot(self):
        """Alias for SecondaryPlot"""
        return self.SecondaryPlot

    @secondary_plot.setter
    def secondary_plot(self, value):
        """Alias for SecondaryPlot.setter"""
        self.SecondaryPlot = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Top(self):
        return self.com_object.Top

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    def ApplyDataLabels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        arguments = com_arguments([unwrap(a) for a in [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]])
        self.com_object.ApplyDataLabels(*arguments)

    def applydatalabels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        """Alias for ApplyDataLabels"""
        arguments = [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]
        return self.ApplyDataLabels(*arguments)

    def apply_data_labels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        """Alias for ApplyDataLabels"""
        arguments = [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]
        return self.ApplyDataLabels(*arguments)

    def ClearFormats(self):
        self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Paste(self):
        self.com_object.Paste()

    def paste(self):
        """Alias for Paste"""
        return self.Paste()

    def PieSliceLocation(self, loc=None, Index=None):
        arguments = com_arguments([unwrap(a) for a in [loc, Index]])
        return self.com_object.PieSliceLocation(*arguments)

    def pieslicelocation(self, loc=None, Index=None):
        """Alias for PieSliceLocation"""
        arguments = [loc, Index]
        return self.PieSliceLocation(*arguments)

    def pie_slice_location(self, loc=None, Index=None):
        """Alias for PieSliceLocation"""
        arguments = [loc, Index]
        return self.PieSliceLocation(*arguments)

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Points:

    def __init__(self, points=None):
        self.com_object= points

    def __call__(self, item):
        return Point(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Point(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


# PpActionType enumeration
ppActionEndShow = 6
ppActionFirstSlide = 3
ppActionHyperlink = 7
ppActionLastSlide = 4
ppActionLastSlideViewed = 5
ppActionMixed = -2
ppActionNamedSlideShow = 10
ppActionNextSlide = 1
ppActionNone = 0
ppActionOLEVerb = 11
ppActionPlay = 12
ppActionPreviousSlide = 2
ppActionRunMacro = 8
ppActionRunProgram = 9

# PpAdvanceMode enumeration
ppAdvanceModeMixed = -2
ppAdvanceOnClick = 1
ppAdvanceOnTime = 2

# PpAfterEffect enumeration
ppAfterEffectDim = 2
ppAfterEffectHide = 1
ppAfterEffectHideOnClick = 3
ppAfterEffectMixed = -2
ppAfterEffectNothing = 0

# PpAlertLevel enumeration
ppAlertsAll = 2
ppAlertsNone = 1

# PpArrangeStyle enumeration
ppArrangeCascade = 2
ppArrangeTiled = 1

# PpAutoSize enumeration
ppAutoSizeMixed = -2
ppAutoSizeNone = 0
ppAutoSizeShapeToFitText = 1

# PpBaselineAlignment enumeration
ppBaselineAlignBaseline = 1
ppBaselineAlignCenter = 3
ppBaselineAlignFarEast50 = 4
ppBaselineAlignMixed = -2
ppBaselineAlignTop = 2

# PpBorderType enumeration
ppBorderBottom = 3
ppBorderDiagonalDown = 5
ppBorderDiagonalUp = 6
ppBorderLeft = 2
ppBorderRight = 4
ppBorderTop = 1

# PpBulletType enumeration
ppBulletMixed = -2
ppBulletNone = 0
ppBulletNumbered = 2
ppBulletPicture = 3
ppBulletUnnumbered = 1

# PpChangeCase enumeration
ppCaseLower = 2
ppCaseSentence = 1
ppCaseTitle = 4
ppCaseToggle = 5
ppCaseUpper = 3

# PpChartUnitEffect enumeration
ppAnimateByCategory = 2
ppAnimateByCategoryElements = 4
ppAnimateBySeries = 1
ppAnimateBySeriesElements = 3
ppAnimateChartAllAtOnce = 5
ppAnimateChartMixed = -2

# PpCheckInVersionType enumeration
ppCheckInMajorVersion = 1
ppCheckInMinorVersion = 0
ppCheckInOverwriteVersion = 2

# PpColorSchemeIndex enumeration
ppAccent1 = 6
ppAccent2 = 7
ppAccent3 = 8
ppBackground = 1
ppFill = 5
ppForeground = 2
ppNotSchemeColor = 0
ppSchemeColorMixed = -2
ppShadow = 3
ppTitle = 4

# PpDateTimeFormat enumeration
ppDateTimeddddMMMMddyyyy = 2
ppDateTimedMMMMyyyy = 3
ppDateTimedMMMyy = 5
ppDateTimeFigureOut = 14
ppDateTimeFormatMixed = -2
ppDateTimeHmm = 10
ppDateTimehmmAMPM = 12
ppDateTimeHmmss = 11
ppDateTimehmmssAMPM = 13
ppDateTimeMdyy = 1
ppDateTimeMMddyyHmm = 8
ppDateTimeMMddyyhmmAMPM = 9
ppDateTimeMMMMdyyyy = 4
ppDateTimeMMMMyy = 6
ppDateTimeMMyy = 7
ppDateTimeUAQ1 = 15
ppDateTimeUAQ2 = 16
ppDateTimeUAQ3 = 17
ppDateTimeUAQ4 = 18
ppDateTimeUAQ5 = 19
ppDateTimeUAQ6 = 20
ppDateTimeUAQ7 = 21

# PpDirection enumeration
ppDirectionLeftToRight = 1
ppDirectionMixed = -2
ppDirectionRightToLeft = 2

# PpEntryEffect enumeration
ppEffectAppear = 3844
ppEffectBlindsHorizontal = 769
ppEffectBlindsVertical = 770
ppEffectBoxDown = 3925
ppEffectBoxIn = 3074
ppEffectBoxLeft = 3922
ppEffectBoxOut = 3073
ppEffectBoxRight = 3924
ppEffectBoxUp = 3923
ppEffectCheckerboardAcross = 1025
ppEffectCheckerboardDown = 1026
ppEffectCircleOut = 3845
ppEffectCombHorizontal = 3847
ppEffectCombVertical = 3848
ppEffectConveyorLeft = 3882
ppEffectConveyorRight = 3883
ppEffectCoverDown = 1284
ppEffectCoverLeft = 1281
ppEffectCoverLeftDown = 1287
ppEffectCoverLeftUp = 1285
ppEffectCoverRight = 1283
ppEffectCoverRightDown = 1288
ppEffectCoverRightUp = 1286
ppEffectCoverUp = 1282
ppEffectCrawlFromDown = 3344
ppEffectCrawlFromLeft = 3341
ppEffectCrawlFromRight = 3343
ppEffectCrawlFromUp = 3342
ppEffectCubeDown = 3917
ppEffectCubeLeft = 3914
ppEffectCubeRight = 3916
ppEffectCubeUp = 3915
ppEffectCut = 257
ppEffectCutThroughBlack = 258
ppEffectDiamondOut = 3846
ppEffectDissolve = 1537
ppEffectDoorsHorizontal = 3885
ppEffectDoorsVertical = 3884
ppEffectFade = 1793
ppEffectFadeSmoothly = 3849
ppEffectFerrisWheelLeft = 3899
ppEffectFerrisWheelRight = 3900
ppEffectFlashbulb = 3909
ppEffectFlashOnceFast = 3841
ppEffectFlashOnceMedium = 3842
ppEffectFlashOnceSlow = 3843
ppEffectFlipDown = 3908
ppEffectFlipLeft = 3905
ppEffectFlipRight = 3907
ppEffectFlipUp = 3906
ppEffectFlyFromBottom = 3332
ppEffectFlyFromBottomLeft = 3335
ppEffectFlyFromBottomRight = 3336
ppEffectFlyFromLeft = 3329
ppEffectFlyFromRight = 3331
ppEffectFlyFromTop = 3330
ppEffectFlyFromTopLeft = 3333
ppEffectFlyFromTopRight = 3334
ppEffectFlyThroughIn = 3890
ppEffectFlyThroughInBounce = 3892
ppEffectFlyThroughOut = 3891
ppEffectFlyThroughOutBounce = 3893
ppEffectGalleryLeft = 3880
ppEffectGalleryRight = 3881
ppEffectGlitterDiamondDown = 3875
ppEffectGlitterDiamondLeft = 3872
ppEffectGlitterDiamondRight = 3874
ppEffectGlitterDiamondUp = 3873
ppEffectGlitterHexagonDown = 3879
ppEffectGlitterHexagonLeft = 3876
ppEffectGlitterHexagonRight = 3878
ppEffectGlitterHexagonUp = 3877
ppEffectHoneycomb = 3898
ppEffectMixed = -2
ppEffectNewsflash = 3850
ppEffectNone = 0
ppEffectOrbitDown = 3929
ppEffectOrbitLeft = 3926
ppEffectOrbitRight = 3928
ppEffectOrbitUp = 3927
ppEffectPanDown = 3933
ppEffectPanLeft = 3930
ppEffectPanRight = 3932
ppEffectPanUp = 3931
ppEffectPeekFromDown = 3338
ppEffectPeekFromLeft = 3337
ppEffectPeekFromRight = 3339
ppEffectPeekFromUp = 3340
ppEffectPlusOut = 3851
ppEffectPushDown = 3852
ppEffectPushLeft = 3853
ppEffectPushRight = 3854
ppEffectPushUp = 3855
ppEffectRandom = 513
ppEffectRandomBarsHorizontal = 2305
ppEffectRandomBarsVertical = 2306
ppEffectRevealBlackLeft = 3896
ppEffectRevealBlackRight = 3897
ppEffectRevealSmoothLeft = 3894
ppEffectRevealSmoothRight = 3895
ppEffectRippleCenter = 3867
ppEffectRippleLeftDown = 3870
ppEffectRippleLeftUp = 3869
ppEffectRippleRightDown = 3871
ppEffectRippleRightUp = 3868
ppEffectRotateDown = 3921
ppEffectRotateLeft = 3918
ppEffectRotateRight = 3920
ppEffectRotateUp = 3919
ppEffectShredRectangleIn = 3912
ppEffectShredRectangleOut = 3913
ppEffectShredStripsIn = 3910
ppEffectShredStripsOut = 3911
ppEffectSpiral = 3357
ppEffectSplitHorizontalIn = 3586
ppEffectSplitHorizontalOut = 3585
ppEffectSplitVerticalIn = 3588
ppEffectSplitVerticalOut = 3587
ppEffectStretchAcross = 3351
ppEffectStretchDown = 3355
ppEffectStretchLeft = 3352
ppEffectStretchRight = 3354
ppEffectStretchUp = 3353
ppEffectStripsDownLeft = 2563
ppEffectStripsDownRight = 2564
ppEffectStripsLeftDown = 2567
ppEffectStripsLeftUp = 2565
ppEffectStripsRightDown = 2568
ppEffectStripsRightUp = 2566
ppEffectStripsUpLeft = 2561
ppEffectStripsUpRight = 2562
ppEffectSwitchDown = 3904
ppEffectSwitchLeft = 3901
ppEffectSwitchRight = 3903
ppEffectSwitchUp = 3902
ppEffectSwivel = 3356
ppEffectUncoverDown = 2052
ppEffectUncoverLeft = 2049
ppEffectUncoverLeftDown = 2055
ppEffectUncoverLeftUp = 2053
ppEffectUncoverRight = 2051
ppEffectUncoverRightDown = 2056
ppEffectUncoverRightUp = 2054
ppEffectUncoverUp = 2050
ppEffectVortexDown = 3866
ppEffectVortexLeft = 3863
ppEffectVortexRight = 3865
ppEffectVortexUp = 3864
ppEffectWarpIn = 3888
ppEffectWarpOut = 3889
ppEffectWedge = 3856
ppEffectWheel1Spoke = 3857
ppEffectWheel2Spokes = 3858
ppEffectWheel3Spokes = 3859
ppEffectWheel4Spokes = 3860
ppEffectWheel8Spokes = 3861
ppEffectWheelReverse1Spoke = 3862
ppEffectWindowHorizontal = 3887
ppEffectWindowVertical = 3886
ppEffectWipeDown = 2820
ppEffectWipeLeft = 2817
ppEffectWipeRight = 2819
ppEffectWipeUp = 2818
ppEffectZoomBottom = 3350
ppEffectZoomCenter = 3349
ppEffectZoomIn = 3345
ppEffectZoomInSlightly = 3346
ppEffectZoomOut = 3347
ppEffectZoomOutSlightly = 3348

# PpFarEastLineBreakLevel enumeration
ppFarEastLineBreakLevelCustom = 3
ppFarEastLineBreakLevelNormal = 1
ppFarEastLineBreakLevelStrict = 2

# PpFixedFormatIntent enumeration
ppFixedFormatIntentPrint = 2
ppFixedFormatIntentScreen = 1

# PpFixedFormatType enumeration
ppFixedFormatTypePDF = 2
ppFixedFormatTypeXPS = 1

# PpFollowColors enumeration
ppFollowColorsMixed = -2
ppFollowColorsNone = 0
ppFollowColorsScheme = 1
ppFollowColorsTextAndBackground = 2

# PpFrameColors enumeration
ppFrameColorsBlackTextOnWhite = 5
ppFrameColorsBrowserColors = 1
ppFrameColorsPresentationSchemeAccentColor = 3
ppFrameColorsPresentationSchemeTextColor = 2
ppFrameColorsWhiteTextOnBlack = 4

# PpHTMLVersion enumeration
ppHTMLAutodetect = 4
ppHTMLDual = 3
ppHTMLv3 = 1
ppHTMLv4 = 2

# PpIndentControl enumeration
ppIndentControlMixed = -2
ppIndentKeepAttr = 2
ppIndentReplaceAttr = 1

# PpMediaType enumeration
ppMediaTypeMixed = -2
ppMediaTypeMovie = 3
ppMediaTypeOther = 1
ppMediaTypeSound = 2

# PpMouseActivation enumeration
ppMouseClick = 1
ppMouseOver = 2

# PpNumberedBulletStyle enumeration
ppBulletAlphaLCParenBoth = 8
ppBulletAlphaLCParenRight = 9
ppBulletAlphaLCPeriod = 0
ppBulletAlphaUCParenBoth = 10
ppBulletAlphaUCParenRight = 11
ppBulletAlphaUCPeriod = 1
ppBulletArabicAbjadDash = 24
ppBulletArabicAlphaDash = 23
ppBulletArabicDBPeriod = 29
ppBulletArabicDBPlain = 28
ppBulletArabicParenBoth = 12
ppBulletArabicParenRight = 2
ppBulletArabicPeriod = 3
ppBulletArabicPlain = 13
ppBulletCircleNumDBPlain = 18
ppBulletCircleNumWDBlackPlain = 20
ppBulletCircleNumWDWhitePlain = 19
ppBulletHebrewAlphaDash = 25
ppBulletHindiAlpha1Period = 40
ppBulletHindiAlphaPeriod = 36
ppBulletHindiNumParenRight = 39
ppBulletHindiNumPeriod = 37
ppBulletKanjiKoreanPeriod = 27
ppBulletKanjiKoreanPlain = 26
ppBulletKanjiSimpChinDBPeriod = 38
ppBulletRomanLCParenBoth = 4
ppBulletRomanLCParenRight = 5
ppBulletRomanLCPeriod = 6
ppBulletRomanUCParenBoth = 14
ppBulletRomanUCParenRight = 15
ppBulletRomanUCPeriod = 7
ppBulletSimpChinPeriod = 17
ppBulletSimpChinPlain = 16
ppBulletStyleMixed = -2
ppBulletThaiAlphaParenBoth = 32
ppBulletThaiAlphaParenRight = 31
ppBulletThaiAlphaPeriod = 30
ppBulletThaiNumParenBoth = 35
ppBulletThaiNumParenRight = 34
ppBulletThaiNumPeriod = 33
ppBulletTradChinPeriod = 22
ppBulletTradChinPlain = 21

# PpParagraphAlignment enumeration
ppAlignCenter = 2
ppAlignDistribute = 5
ppAlignJustify = 4
ppAlignJustifyLow = 7
ppAlignLeft = 1
ppAlignmentMixed = -2
ppAlignRight = 3
ppAlignThaiDistribute = 6

# PpPasteDataType enumeration
ppPasteBitmap = 1
ppPasteDefault = 0
ppPasteEnhancedMetafile = 2
ppPasteGIF = 4
ppPasteHTML = 8
ppPasteJPG = 5
ppPasteMetafilePicture = 3
ppPasteOLEObject = 10
ppPastePNG = 6
ppPasteRTF = 9
ppPasteShape = 11
ppPasteText = 7

# PpPlaceholderType enumeration
ppPlaceholderMixed = -2
ppPlaceholderTitle = 1
ppPlaceholderBody = 2
ppPlaceholderCenterTitle = 3
ppPlaceholderSubtitle = 4
ppPlaceholderVerticalTitle = 5
ppPlaceholderVerticalBody = 6
ppPlaceholderObject = 7
ppPlaceholderChart = 8
ppPlaceholderBitmap = 9
ppPlaceholderMediaClip = 10
ppPlaceholderOrgChart = 11
ppPlaceholderTable = 12
ppPlaceholderSlideNumber = 13
ppPlaceholderHeader = 14
ppPlaceholderFooter = 15
ppPlaceholderDate = 16
ppPlaceholderVerticalObject = 17
ppPlaceholderPicture = 18
ppPlaceholderCameo = 19

# PpPrintColorType enumeration
ppPrintBlackAndWhite = 2
ppPrintColor = 1
ppPrintPureBlackAndWhite = 3

# PpPrintHandoutOrder enumeration
ppPrintHandoutHorizontalFirst = 2
ppPrintHandoutVerticalFirst = 1

# PpPrintOutputType enumeration
ppPrintOutputBuildSlides = 7
ppPrintOutputFourSlideHandouts = 8
ppPrintOutputNineSlideHandouts = 9
ppPrintOutputNotesPages = 5
ppPrintOutputOneSlideHandouts = 10
ppPrintOutputOutline = 6
ppPrintOutputSixSlideHandouts = 4
ppPrintOutputSlides = 1
ppPrintOutputThreeSlideHandouts = 3
ppPrintOutputTwoSlideHandouts = 2

# PpPrintRangeType enumeration
ppPrintAll = 1
ppPrintCurrent = 3
ppPrintNamedSlideShow = 5
ppPrintSelection = 2
ppPrintSlideRange = 4

# PpPublishSourceType enumeration
ppPublishAll = 1
ppPublishNamedSlideShow = 3
ppPublishSlideRange = 2

# PpRemoveDocInfoType enumeration
ppRDIAll = 99
ppRDIAtMentions = 18
ppRDIComments = 1
ppRDIContentType = 16
ppRDIDocumentManagementPolicy = 15
ppRDIDocumentProperties = 8
ppRDIDocumentServerProperties = 14
ppRDIDocumentWorkspace = 10
ppRDIInkAnnotations = 11
ppRDIPublishPath = 13
ppRDIRemovePersonalInformation = 4
ppRDISlideUpdateInformation = 17

# PpRevisionInfo enumeration
ppRevisionInfoBaseline = 1
ppRevisionInfoMerged = 2
ppRevisionInfoNone = 0

# PpSelectionType enumeration
ppSelectionNone = 0
ppSelectionShapes = 2
ppSelectionSlides = 1
ppSelectionText = 3

# PpSlideLayout enumeration
ppLayoutBlank = 12
ppLayoutChart = 8
ppLayoutChartAndText = 6
ppLayoutClipArtAndText = 10
ppLayoutClipArtAndVerticalText = 26
ppLayoutComparison = 34
ppLayoutContentWithCaption = 35
ppLayoutCustom = 32
ppLayoutFourObjects = 24
ppLayoutLargeObject = 15
ppLayoutMediaClipAndText = 18
ppLayoutMixed = -2
ppLayoutObject = 16
ppLayoutObjectAndText = 14
ppLayoutObjectAndTwoObjects = 30
ppLayoutObjectOverText = 19
ppLayoutOrgchart = 7
ppLayoutPictureWithCaption = 36
ppLayoutSectionHeader = 33
ppLayoutTable = 4
ppLayoutText = 2
ppLayoutTextAndChart = 5
ppLayoutTextAndClipArt = 9
ppLayoutTextAndMediaClip = 17
ppLayoutTextAndObject = 13
ppLayoutTextAndTwoObjects = 21
ppLayoutTextOverObject = 20
ppLayoutTitle = 1
ppLayoutTitleOnly = 11
ppLayoutTwoColumnText = 3
ppLayoutTwoObjects = 29
ppLayoutTwoObjectsAndObject = 31
ppLayoutTwoObjectsAndText = 22
ppLayoutTwoObjectsOverText = 23
ppLayoutVerticalText = 25
ppLayoutVerticalTitleAndText = 27
ppLayoutVerticalTitleAndTextOverChart = 28

# PpSlideShowAdvanceMode enumeration
ppSlideShowManualAdvance = 1
ppSlideShowRehearseNewTimings = 3
ppSlideShowUseSlideTimings = 2

# PpSlideShowPointerType enumeration
ppSlideShowPointerAlwaysHidden = 3
ppSlideShowPointerArrow = 1
ppSlideShowPointerAutoArrow = 4
ppSlideShowPointerEraser = 5
ppSlideShowPointerNone = 0
ppSlideShowPointerPen = 2

# PpSlideShowRangeType enumeration
ppShowAll = 1
ppShowNamedSlideShow = 3
ppShowSlideRange = 2

# PpSlideShowState enumeration
ppSlideShowBlackScreen = 3
ppSlideShowDone = 5
ppSlideShowPaused = 2
ppSlideShowRunning = 1
ppSlideShowWhiteScreen = 4

# PpSlideShowType enumeration
ppShowTypeKiosk = 3
ppShowTypeSpeaker = 1
ppShowTypeWindow = 2
ppShowTypeWindow2 = 4

# PpSlideSizeType enumeration
ppSlideSize35MM = 4
ppSlideSizeA3Paper = 9
ppSlideSizeA4Paper = 3
ppSlideSizeB4ISOPaper = 10
ppSlideSizeB4JISPaper = 12
ppSlideSizeB5ISOPaper = 11
ppSlideSizeB5JISPaper = 13
ppSlideSizeBanner = 6
ppSlideSizeCustom = 7
ppSlideSizeHagakiCard = 14
ppSlideSizeLedgerPaper = 8
ppSlideSizeLetterPaper = 2
ppSlideSizeOnScreen = 1
ppSlideSizeOverhead = 5

# PpSoundEffectType enumeration
ppSoundEffectsMixed = -2
ppSoundFile = 2
ppSoundNone = 0
ppSoundStopPrevious = 1

# PpSoundFormatType enumeration
ppSoundFormatCDAudio = 3
ppSoundFormatMIDI = 2
ppSoundFormatMixed = -2
ppSoundFormatNone = 0
ppSoundFormatWAV = 1

# PpTabStopType enumeration
ppTabStopCenter = 2
ppTabStopDecimal = 4
ppTabStopLeft = 1
ppTabStopMixed = -2
ppTabStopRight = 3

# PpTextLevelEffect enumeration
ppAnimateByAllLevels = 16
ppAnimateByFifthLevel = 5
ppAnimateByFirstLevel = 1
ppAnimateByFourthLevel = 4
ppAnimateBySecondLevel = 2
ppAnimateByThirdLevel = 3
ppAnimateLevelMixed = -2
ppAnimateLevelNone = 0

# PpTextStyleType enumeration
ppBodyStyle = 3
ppDefaultStyle = 1
ppTitleStyle = 2

# PpTextUnitEffect enumeration
ppAnimateByCharacter = 2
ppAnimateByParagraph = 0
ppAnimateByWord = 1
ppAnimateUnitMixed = -2

# PpTransitionSpeed enumeration
ppTransitionSpeedFast = 3
ppTransitionSpeedMedium = 2
ppTransitionSpeedMixed = -2
ppTransitionSpeedSlow = 1

# PpUpdateOption enumeration
ppUpdateOptionAutomatic = 2
ppUpdateOptionManual = 1
ppUpdateOptionMixed = -2

# PpViewType enumeration
ppViewHandoutMaster = 4
ppViewMasterThumbnails = 12
ppViewNormal = 9
ppViewNotesMaster = 5
ppViewNotesPage = 3
ppViewOutline = 6
ppViewPrintPreview = 10
ppViewSlide = 1
ppViewSlideMaster = 2
ppViewSlideSorter = 7
ppViewThumbnails = 11
ppViewTitleMaster = 8

# PpWindowState enumeration
ppWindowMaximized = 3
ppWindowMinimized = 2
ppWindowNormal = 1

class Presentation:

    def __init__(self, presentation=None):
        self.com_object= presentation

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoSaveOn(self):
        return self.com_object.AutoSaveOn

    @AutoSaveOn.setter
    def AutoSaveOn(self, value):
        self.com_object.AutoSaveOn = value

    @property
    def autosaveon(self):
        """Alias for AutoSaveOn"""
        return self.AutoSaveOn

    @autosaveon.setter
    def autosaveon(self, value):
        """Alias for AutoSaveOn.setter"""
        self.AutoSaveOn = value

    @property
    def auto_save_on(self):
        """Alias for AutoSaveOn"""
        return self.AutoSaveOn

    @auto_save_on.setter
    def auto_save_on(self, value):
        """Alias for AutoSaveOn.setter"""
        self.AutoSaveOn = value

    @property
    def Broadcast(self):
        return Broadcast(self.com_object.Broadcast)

    @property
    def broadcast(self):
        """Alias for Broadcast"""
        return self.Broadcast

    @property
    def BuiltInDocumentProperties(self):
        return self.com_object.BuiltInDocumentProperties

    @property
    def builtindocumentproperties(self):
        """Alias for BuiltInDocumentProperties"""
        return self.BuiltInDocumentProperties

    @property
    def built_in_document_properties(self):
        """Alias for BuiltInDocumentProperties"""
        return self.BuiltInDocumentProperties

    @property
    def ChartDataPointTrack(self):
        return self.com_object.ChartDataPointTrack

    @ChartDataPointTrack.setter
    def ChartDataPointTrack(self, value):
        self.com_object.ChartDataPointTrack = value

    @property
    def chartdatapointtrack(self):
        """Alias for ChartDataPointTrack"""
        return self.ChartDataPointTrack

    @chartdatapointtrack.setter
    def chartdatapointtrack(self, value):
        """Alias for ChartDataPointTrack.setter"""
        self.ChartDataPointTrack = value

    @property
    def chart_data_point_track(self):
        """Alias for ChartDataPointTrack"""
        return self.ChartDataPointTrack

    @chart_data_point_track.setter
    def chart_data_point_track(self, value):
        """Alias for ChartDataPointTrack.setter"""
        self.ChartDataPointTrack = value

    @property
    def Coauthoring(self):
        return Coauthoring(self.com_object.Coauthoring)

    @property
    def coauthoring(self):
        """Alias for Coauthoring"""
        return self.Coauthoring

    @property
    def ColorSchemes(self):
        return ColorSchemes(self.com_object.ColorSchemes)

    @property
    def colorschemes(self):
        """Alias for ColorSchemes"""
        return self.ColorSchemes

    @property
    def color_schemes(self):
        """Alias for ColorSchemes"""
        return self.ColorSchemes

    @property
    def CommandBars(self):
        return self.com_object.CommandBars

    @property
    def commandbars(self):
        """Alias for CommandBars"""
        return self.CommandBars

    @property
    def command_bars(self):
        """Alias for CommandBars"""
        return self.CommandBars

    @property
    def Container(self):
        return self.com_object.Container

    @property
    def container(self):
        """Alias for Container"""
        return self.Container

    @property
    def ContentTypeProperties(self):
        return self.com_object.ContentTypeProperties

    @property
    def contenttypeproperties(self):
        """Alias for ContentTypeProperties"""
        return self.ContentTypeProperties

    @property
    def content_type_properties(self):
        """Alias for ContentTypeProperties"""
        return self.ContentTypeProperties

    @property
    def CreateVideoStatus(self):
        return Presentation(self.com_object.CreateVideoStatus)

    @property
    def createvideostatus(self):
        """Alias for CreateVideoStatus"""
        return self.CreateVideoStatus

    @property
    def create_video_status(self):
        """Alias for CreateVideoStatus"""
        return self.CreateVideoStatus

    @property
    def CustomDocumentProperties(self):
        return self.com_object.CustomDocumentProperties

    @property
    def customdocumentproperties(self):
        """Alias for CustomDocumentProperties"""
        return self.CustomDocumentProperties

    @property
    def custom_document_properties(self):
        """Alias for CustomDocumentProperties"""
        return self.CustomDocumentProperties

    @property
    def CustomerData(self):
        return CustomerData(self.com_object.CustomerData)

    @property
    def customerdata(self):
        """Alias for CustomerData"""
        return self.CustomerData

    @property
    def customer_data(self):
        """Alias for CustomerData"""
        return self.CustomerData

    @property
    def CustomXMLParts(self):
        return self.com_object.CustomXMLParts

    @property
    def customxmlparts(self):
        """Alias for CustomXMLParts"""
        return self.CustomXMLParts

    @property
    def custom_x_m_l_parts(self):
        """Alias for CustomXMLParts"""
        return self.CustomXMLParts

    @property
    def DefaultLanguageID(self):
        return self.com_object.DefaultLanguageID

    @DefaultLanguageID.setter
    def DefaultLanguageID(self, value):
        self.com_object.DefaultLanguageID = value

    @property
    def defaultlanguageid(self):
        """Alias for DefaultLanguageID"""
        return self.DefaultLanguageID

    @defaultlanguageid.setter
    def defaultlanguageid(self, value):
        """Alias for DefaultLanguageID.setter"""
        self.DefaultLanguageID = value

    @property
    def default_language_i_d(self):
        """Alias for DefaultLanguageID"""
        return self.DefaultLanguageID

    @default_language_i_d.setter
    def default_language_i_d(self, value):
        """Alias for DefaultLanguageID.setter"""
        self.DefaultLanguageID = value

    @property
    def DefaultShape(self):
        return Shape(self.com_object.DefaultShape)

    @property
    def defaultshape(self):
        """Alias for DefaultShape"""
        return self.DefaultShape

    @property
    def default_shape(self):
        """Alias for DefaultShape"""
        return self.DefaultShape

    @property
    def Designs(self):
        return Designs(self.com_object.Designs)

    @property
    def designs(self):
        """Alias for Designs"""
        return self.Designs

    @property
    def DisplayComments(self):
        return self.com_object.DisplayComments

    @DisplayComments.setter
    def DisplayComments(self, value):
        self.com_object.DisplayComments = value

    @property
    def displaycomments(self):
        """Alias for DisplayComments"""
        return self.DisplayComments

    @displaycomments.setter
    def displaycomments(self, value):
        """Alias for DisplayComments.setter"""
        self.DisplayComments = value

    @property
    def display_comments(self):
        """Alias for DisplayComments"""
        return self.DisplayComments

    @display_comments.setter
    def display_comments(self, value):
        """Alias for DisplayComments.setter"""
        self.DisplayComments = value

    @property
    def DocumentInspectors(self):
        return self.com_object.DocumentInspectors

    @property
    def documentinspectors(self):
        """Alias for DocumentInspectors"""
        return self.DocumentInspectors

    @property
    def document_inspectors(self):
        """Alias for DocumentInspectors"""
        return self.DocumentInspectors

    @property
    def DocumentLibraryVersions(self):
        return self.com_object.DocumentLibraryVersions

    @property
    def documentlibraryversions(self):
        """Alias for DocumentLibraryVersions"""
        return self.DocumentLibraryVersions

    @property
    def document_library_versions(self):
        """Alias for DocumentLibraryVersions"""
        return self.DocumentLibraryVersions

    @property
    def EncryptionProvider(self):
        return self.com_object.EncryptionProvider

    @EncryptionProvider.setter
    def EncryptionProvider(self, value):
        self.com_object.EncryptionProvider = value

    @property
    def encryptionprovider(self):
        """Alias for EncryptionProvider"""
        return self.EncryptionProvider

    @encryptionprovider.setter
    def encryptionprovider(self, value):
        """Alias for EncryptionProvider.setter"""
        self.EncryptionProvider = value

    @property
    def encryption_provider(self):
        """Alias for EncryptionProvider"""
        return self.EncryptionProvider

    @encryption_provider.setter
    def encryption_provider(self, value):
        """Alias for EncryptionProvider.setter"""
        self.EncryptionProvider = value

    @property
    def EnvelopeVisible(self):
        return self.com_object.EnvelopeVisible

    @EnvelopeVisible.setter
    def EnvelopeVisible(self, value):
        self.com_object.EnvelopeVisible = value

    @property
    def envelopevisible(self):
        """Alias for EnvelopeVisible"""
        return self.EnvelopeVisible

    @envelopevisible.setter
    def envelopevisible(self, value):
        """Alias for EnvelopeVisible.setter"""
        self.EnvelopeVisible = value

    @property
    def envelope_visible(self):
        """Alias for EnvelopeVisible"""
        return self.EnvelopeVisible

    @envelope_visible.setter
    def envelope_visible(self, value):
        """Alias for EnvelopeVisible.setter"""
        self.EnvelopeVisible = value

    @property
    def ExtraColors(self):
        return ExtraColors(self.com_object.ExtraColors)

    @property
    def extracolors(self):
        """Alias for ExtraColors"""
        return self.ExtraColors

    @property
    def extra_colors(self):
        """Alias for ExtraColors"""
        return self.ExtraColors

    @property
    def FarEastLineBreakLanguage(self):
        return self.com_object.FarEastLineBreakLanguage

    @FarEastLineBreakLanguage.setter
    def FarEastLineBreakLanguage(self, value):
        self.com_object.FarEastLineBreakLanguage = value

    @property
    def fareastlinebreaklanguage(self):
        """Alias for FarEastLineBreakLanguage"""
        return self.FarEastLineBreakLanguage

    @fareastlinebreaklanguage.setter
    def fareastlinebreaklanguage(self, value):
        """Alias for FarEastLineBreakLanguage.setter"""
        self.FarEastLineBreakLanguage = value

    @property
    def far_east_line_break_language(self):
        """Alias for FarEastLineBreakLanguage"""
        return self.FarEastLineBreakLanguage

    @far_east_line_break_language.setter
    def far_east_line_break_language(self, value):
        """Alias for FarEastLineBreakLanguage.setter"""
        self.FarEastLineBreakLanguage = value

    @property
    def FarEastLineBreakLevel(self):
        return self.com_object.FarEastLineBreakLevel

    @FarEastLineBreakLevel.setter
    def FarEastLineBreakLevel(self, value):
        self.com_object.FarEastLineBreakLevel = value

    @property
    def fareastlinebreaklevel(self):
        """Alias for FarEastLineBreakLevel"""
        return self.FarEastLineBreakLevel

    @fareastlinebreaklevel.setter
    def fareastlinebreaklevel(self, value):
        """Alias for FarEastLineBreakLevel.setter"""
        self.FarEastLineBreakLevel = value

    @property
    def far_east_line_break_level(self):
        """Alias for FarEastLineBreakLevel"""
        return self.FarEastLineBreakLevel

    @far_east_line_break_level.setter
    def far_east_line_break_level(self, value):
        """Alias for FarEastLineBreakLevel.setter"""
        self.FarEastLineBreakLevel = value

    @property
    def Final(self):
        return self.com_object.Final

    @Final.setter
    def Final(self, value):
        self.com_object.Final = value

    @property
    def final(self):
        """Alias for Final"""
        return self.Final

    @final.setter
    def final(self, value):
        """Alias for Final.setter"""
        self.Final = value

    @property
    def Fonts(self):
        return Fonts(self.com_object.Fonts)

    @property
    def fonts(self):
        """Alias for Fonts"""
        return self.Fonts

    @property
    def FullName(self):
        return self.com_object.FullName

    @property
    def fullname(self):
        """Alias for FullName"""
        return self.FullName

    @property
    def full_name(self):
        """Alias for FullName"""
        return self.FullName

    @property
    def GridDistance(self):
        return self.com_object.GridDistance

    @GridDistance.setter
    def GridDistance(self, value):
        self.com_object.GridDistance = value

    @property
    def griddistance(self):
        """Alias for GridDistance"""
        return self.GridDistance

    @griddistance.setter
    def griddistance(self, value):
        """Alias for GridDistance.setter"""
        self.GridDistance = value

    @property
    def grid_distance(self):
        """Alias for GridDistance"""
        return self.GridDistance

    @grid_distance.setter
    def grid_distance(self, value):
        """Alias for GridDistance.setter"""
        self.GridDistance = value

    @property
    def Guides(self):
        return self.com_object.Guides

    @property
    def guides(self):
        """Alias for Guides"""
        return self.Guides

    @property
    def HandoutMaster(self):
        return Master(self.com_object.HandoutMaster)

    @property
    def handoutmaster(self):
        """Alias for HandoutMaster"""
        return self.HandoutMaster

    @property
    def handout_master(self):
        """Alias for HandoutMaster"""
        return self.HandoutMaster

    @property
    def HasHandoutMaster(self):
        return self.com_object.HasHandoutMaster

    @property
    def hashandoutmaster(self):
        """Alias for HasHandoutMaster"""
        return self.HasHandoutMaster

    @property
    def has_handout_master(self):
        """Alias for HasHandoutMaster"""
        return self.HasHandoutMaster

    @property
    def HasNotesMaster(self):
        return self.com_object.HasNotesMaster

    @property
    def hasnotesmaster(self):
        """Alias for HasNotesMaster"""
        return self.HasNotesMaster

    @property
    def has_notes_master(self):
        """Alias for HasNotesMaster"""
        return self.HasNotesMaster

    @property
    def HasTitleMaster(self):
        return self.com_object.HasTitleMaster

    @property
    def hastitlemaster(self):
        """Alias for HasTitleMaster"""
        return self.HasTitleMaster

    @property
    def has_title_master(self):
        """Alias for HasTitleMaster"""
        return self.HasTitleMaster

    @property
    def HasVBProject(self):
        return self.com_object.HasVBProject

    @property
    def hasvbproject(self):
        """Alias for HasVBProject"""
        return self.HasVBProject

    @property
    def has_v_b_project(self):
        """Alias for HasVBProject"""
        return self.HasVBProject

    @property
    def InMergeMode(self):
        return self.com_object.InMergeMode

    @property
    def inmergemode(self):
        """Alias for InMergeMode"""
        return self.InMergeMode

    @property
    def in_merge_mode(self):
        """Alias for InMergeMode"""
        return self.InMergeMode

    @property
    def IsFullyDownloaded(self):
        return self.com_object.IsFullyDownloaded

    @property
    def isfullydownloaded(self):
        """Alias for IsFullyDownloaded"""
        return self.IsFullyDownloaded

    @property
    def is_fully_downloaded(self):
        """Alias for IsFullyDownloaded"""
        return self.IsFullyDownloaded

    @property
    def LayoutDirection(self):
        return self.com_object.LayoutDirection

    @LayoutDirection.setter
    def LayoutDirection(self, value):
        self.com_object.LayoutDirection = value

    @property
    def layoutdirection(self):
        """Alias for LayoutDirection"""
        return self.LayoutDirection

    @layoutdirection.setter
    def layoutdirection(self, value):
        """Alias for LayoutDirection.setter"""
        self.LayoutDirection = value

    @property
    def layout_direction(self):
        """Alias for LayoutDirection"""
        return self.LayoutDirection

    @layout_direction.setter
    def layout_direction(self, value):
        """Alias for LayoutDirection.setter"""
        self.LayoutDirection = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NoLineBreakAfter(self):
        return self.com_object.NoLineBreakAfter

    @NoLineBreakAfter.setter
    def NoLineBreakAfter(self, value):
        self.com_object.NoLineBreakAfter = value

    @property
    def nolinebreakafter(self):
        """Alias for NoLineBreakAfter"""
        return self.NoLineBreakAfter

    @nolinebreakafter.setter
    def nolinebreakafter(self, value):
        """Alias for NoLineBreakAfter.setter"""
        self.NoLineBreakAfter = value

    @property
    def no_line_break_after(self):
        """Alias for NoLineBreakAfter"""
        return self.NoLineBreakAfter

    @no_line_break_after.setter
    def no_line_break_after(self, value):
        """Alias for NoLineBreakAfter.setter"""
        self.NoLineBreakAfter = value

    @property
    def NoLineBreakBefore(self):
        return self.com_object.NoLineBreakBefore

    @NoLineBreakBefore.setter
    def NoLineBreakBefore(self, value):
        self.com_object.NoLineBreakBefore = value

    @property
    def nolinebreakbefore(self):
        """Alias for NoLineBreakBefore"""
        return self.NoLineBreakBefore

    @nolinebreakbefore.setter
    def nolinebreakbefore(self, value):
        """Alias for NoLineBreakBefore.setter"""
        self.NoLineBreakBefore = value

    @property
    def no_line_break_before(self):
        """Alias for NoLineBreakBefore"""
        return self.NoLineBreakBefore

    @no_line_break_before.setter
    def no_line_break_before(self, value):
        """Alias for NoLineBreakBefore.setter"""
        self.NoLineBreakBefore = value

    @property
    def NotesMaster(self):
        return Master(self.com_object.NotesMaster)

    @property
    def notesmaster(self):
        """Alias for NotesMaster"""
        return self.NotesMaster

    @property
    def notes_master(self):
        """Alias for NotesMaster"""
        return self.NotesMaster

    @property
    def PageSetup(self):
        return PageSetup(self.com_object.PageSetup)

    @property
    def pagesetup(self):
        """Alias for PageSetup"""
        return self.PageSetup

    @property
    def page_setup(self):
        """Alias for PageSetup"""
        return self.PageSetup

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Password(self):
        return self.com_object.Password

    @Password.setter
    def Password(self, value):
        self.com_object.Password = value

    @property
    def password(self):
        """Alias for Password"""
        return self.Password

    @password.setter
    def password(self, value):
        """Alias for Password.setter"""
        self.Password = value

    @property
    def PasswordEncryptionAlgorithm(self):
        return self.com_object.PasswordEncryptionAlgorithm

    @property
    def passwordencryptionalgorithm(self):
        """Alias for PasswordEncryptionAlgorithm"""
        return self.PasswordEncryptionAlgorithm

    @property
    def password_encryption_algorithm(self):
        """Alias for PasswordEncryptionAlgorithm"""
        return self.PasswordEncryptionAlgorithm

    @property
    def PasswordEncryptionFileProperties(self):
        return self.com_object.PasswordEncryptionFileProperties

    @property
    def passwordencryptionfileproperties(self):
        """Alias for PasswordEncryptionFileProperties"""
        return self.PasswordEncryptionFileProperties

    @property
    def password_encryption_file_properties(self):
        """Alias for PasswordEncryptionFileProperties"""
        return self.PasswordEncryptionFileProperties

    @property
    def PasswordEncryptionKeyLength(self):
        return self.com_object.PasswordEncryptionKeyLength

    @property
    def passwordencryptionkeylength(self):
        """Alias for PasswordEncryptionKeyLength"""
        return self.PasswordEncryptionKeyLength

    @property
    def password_encryption_key_length(self):
        """Alias for PasswordEncryptionKeyLength"""
        return self.PasswordEncryptionKeyLength

    @property
    def PasswordEncryptionProvider(self):
        return self.com_object.PasswordEncryptionProvider

    @property
    def passwordencryptionprovider(self):
        """Alias for PasswordEncryptionProvider"""
        return self.PasswordEncryptionProvider

    @property
    def password_encryption_provider(self):
        """Alias for PasswordEncryptionProvider"""
        return self.PasswordEncryptionProvider

    @property
    def Path(self):
        return Presentation(self.com_object.Path)

    @property
    def path(self):
        """Alias for Path"""
        return self.Path

    @property
    def PrintOptions(self):
        return PrintOptions(self.com_object.PrintOptions)

    @property
    def printoptions(self):
        """Alias for PrintOptions"""
        return self.PrintOptions

    @property
    def print_options(self):
        """Alias for PrintOptions"""
        return self.PrintOptions

    @property
    def ReadOnly(self):
        return self.com_object.ReadOnly

    @property
    def readonly(self):
        """Alias for ReadOnly"""
        return self.ReadOnly

    @property
    def read_only(self):
        """Alias for ReadOnly"""
        return self.ReadOnly

    @property
    def ReadOnlyRecommended(self):
        return self.com_object.ReadOnlyRecommended

    @property
    def readonlyrecommended(self):
        """Alias for ReadOnlyRecommended"""
        return self.ReadOnlyRecommended

    @property
    def read_only_recommended(self):
        """Alias for ReadOnlyRecommended"""
        return self.ReadOnlyRecommended

    @property
    def RemovePersonalInformation(self):
        return self.com_object.RemovePersonalInformation

    @RemovePersonalInformation.setter
    def RemovePersonalInformation(self, value):
        self.com_object.RemovePersonalInformation = value

    @property
    def removepersonalinformation(self):
        """Alias for RemovePersonalInformation"""
        return self.RemovePersonalInformation

    @removepersonalinformation.setter
    def removepersonalinformation(self, value):
        """Alias for RemovePersonalInformation.setter"""
        self.RemovePersonalInformation = value

    @property
    def remove_personal_information(self):
        """Alias for RemovePersonalInformation"""
        return self.RemovePersonalInformation

    @remove_personal_information.setter
    def remove_personal_information(self, value):
        """Alias for RemovePersonalInformation.setter"""
        self.RemovePersonalInformation = value

    @property
    def Research(self):
        return Research(self.com_object.Research)

    @property
    def research(self):
        """Alias for Research"""
        return self.Research

    @property
    def Saved(self):
        return self.com_object.Saved

    @Saved.setter
    def Saved(self, value):
        self.com_object.Saved = value

    @property
    def saved(self):
        """Alias for Saved"""
        return self.Saved

    @saved.setter
    def saved(self, value):
        """Alias for Saved.setter"""
        self.Saved = value

    @property
    def SectionProperties(self):
        return SectionProperties(self.com_object.SectionProperties)

    @property
    def sectionproperties(self):
        """Alias for SectionProperties"""
        return self.SectionProperties

    @property
    def section_properties(self):
        """Alias for SectionProperties"""
        return self.SectionProperties

    @property
    def SensitivityLabel(self):
        return self.com_object.SensitivityLabel

    @property
    def sensitivitylabel(self):
        """Alias for SensitivityLabel"""
        return self.SensitivityLabel

    @property
    def sensitivity_label(self):
        """Alias for SensitivityLabel"""
        return self.SensitivityLabel

    @property
    def ServerPolicy(self):
        return self.com_object.ServerPolicy

    @property
    def serverpolicy(self):
        """Alias for ServerPolicy"""
        return self.ServerPolicy

    @property
    def server_policy(self):
        """Alias for ServerPolicy"""
        return self.ServerPolicy

    @property
    def SharedWorkspace(self):
        return self.com_object.SharedWorkspace

    @property
    def sharedworkspace(self):
        """Alias for SharedWorkspace"""
        return self.SharedWorkspace

    @property
    def shared_workspace(self):
        """Alias for SharedWorkspace"""
        return self.SharedWorkspace

    @property
    def Signatures(self):
        return self.com_object.Signatures

    @property
    def signatures(self):
        """Alias for Signatures"""
        return self.Signatures

    @property
    def SlideMaster(self):
        return Master(self.com_object.SlideMaster)

    @property
    def slidemaster(self):
        """Alias for SlideMaster"""
        return self.SlideMaster

    @property
    def slide_master(self):
        """Alias for SlideMaster"""
        return self.SlideMaster

    @property
    def Slides(self):
        return Slides(self.com_object.Slides)

    @property
    def slides(self):
        """Alias for Slides"""
        return self.Slides

    @property
    def SlideShowSettings(self):
        return SlideShowSettings(self.com_object.SlideShowSettings)

    @property
    def slideshowsettings(self):
        """Alias for SlideShowSettings"""
        return self.SlideShowSettings

    @property
    def slide_show_settings(self):
        """Alias for SlideShowSettings"""
        return self.SlideShowSettings

    @property
    def SlideShowWindow(self):
        return SlideShowWindow(self.com_object.SlideShowWindow)

    @property
    def slideshowwindow(self):
        """Alias for SlideShowWindow"""
        return self.SlideShowWindow

    @property
    def slide_show_window(self):
        """Alias for SlideShowWindow"""
        return self.SlideShowWindow

    @property
    def SnapToGrid(self):
        return self.com_object.SnapToGrid

    @SnapToGrid.setter
    def SnapToGrid(self, value):
        self.com_object.SnapToGrid = value

    @property
    def snaptogrid(self):
        """Alias for SnapToGrid"""
        return self.SnapToGrid

    @snaptogrid.setter
    def snaptogrid(self, value):
        """Alias for SnapToGrid.setter"""
        self.SnapToGrid = value

    @property
    def snap_to_grid(self):
        """Alias for SnapToGrid"""
        return self.SnapToGrid

    @snap_to_grid.setter
    def snap_to_grid(self, value):
        """Alias for SnapToGrid.setter"""
        self.SnapToGrid = value

    @property
    def Sync(self):
        return self.com_object.Sync

    @property
    def sync(self):
        """Alias for Sync"""
        return self.Sync

    @property
    def Tags(self):
        return Tags(self.com_object.Tags)

    @property
    def tags(self):
        """Alias for Tags"""
        return self.Tags

    @property
    def TemplateName(self):
        return self.com_object.TemplateName

    @property
    def templatename(self):
        """Alias for TemplateName"""
        return self.TemplateName

    @property
    def template_name(self):
        """Alias for TemplateName"""
        return self.TemplateName

    @property
    def TitleMaster(self):
        return Master(self.com_object.TitleMaster)

    @property
    def titlemaster(self):
        """Alias for TitleMaster"""
        return self.TitleMaster

    @property
    def title_master(self):
        """Alias for TitleMaster"""
        return self.TitleMaster

    @property
    def VBASigned(self):
        return self.com_object.VBASigned

    @property
    def vbasigned(self):
        """Alias for VBASigned"""
        return self.VBASigned

    @property
    def v_b_a_signed(self):
        """Alias for VBASigned"""
        return self.VBASigned

    @property
    def VBProject(self):
        return self.com_object.VBProject

    @property
    def vbproject(self):
        """Alias for VBProject"""
        return self.VBProject

    @property
    def v_b_project(self):
        """Alias for VBProject"""
        return self.VBProject

    @property
    def Windows(self):
        return DocumentWindows(self.com_object.Windows)

    @property
    def windows(self):
        """Alias for Windows"""
        return self.Windows

    @property
    def WritePassword(self):
        return self.com_object.WritePassword

    @WritePassword.setter
    def WritePassword(self, value):
        self.com_object.WritePassword = value

    @property
    def writepassword(self):
        """Alias for WritePassword"""
        return self.WritePassword

    @writepassword.setter
    def writepassword(self, value):
        """Alias for WritePassword.setter"""
        self.WritePassword = value

    @property
    def write_password(self):
        """Alias for WritePassword"""
        return self.WritePassword

    @write_password.setter
    def write_password(self, value):
        """Alias for WritePassword.setter"""
        self.WritePassword = value

    def AcceptAll(self):
        return self.com_object.AcceptAll()

    def acceptall(self):
        """Alias for AcceptAll"""
        return self.AcceptAll()

    def accept_all(self):
        """Alias for AcceptAll"""
        return self.AcceptAll()

    def AddTitleMaster(self):
        return Master(self.com_object.AddTitleMaster())

    def addtitlemaster(self):
        """Alias for AddTitleMaster"""
        return self.AddTitleMaster()

    def add_title_master(self):
        """Alias for AddTitleMaster"""
        return self.AddTitleMaster()

    def AddToFavorites(self):
        self.com_object.AddToFavorites()

    def addtofavorites(self):
        """Alias for AddToFavorites"""
        return self.AddToFavorites()

    def add_to_favorites(self):
        """Alias for AddToFavorites"""
        return self.AddToFavorites()

    def ApplyTemplate(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        self.com_object.ApplyTemplate(*arguments)

    def applytemplate(self, FileName=None):
        """Alias for ApplyTemplate"""
        arguments = [FileName]
        return self.ApplyTemplate(*arguments)

    def apply_template(self, FileName=None):
        """Alias for ApplyTemplate"""
        arguments = [FileName]
        return self.ApplyTemplate(*arguments)

    def ApplyTemplate2(self):
        return self.com_object.ApplyTemplate2()

    def applytemplate2(self):
        """Alias for ApplyTemplate2"""
        return self.ApplyTemplate2()

    def apply_template2(self):
        """Alias for ApplyTemplate2"""
        return self.ApplyTemplate2()

    def ApplyTheme(self, themeName=None):
        arguments = com_arguments([unwrap(a) for a in [themeName]])
        self.com_object.ApplyTheme(*arguments)

    def applytheme(self, themeName=None):
        """Alias for ApplyTheme"""
        arguments = [themeName]
        return self.ApplyTheme(*arguments)

    def apply_theme(self, themeName=None):
        """Alias for ApplyTheme"""
        arguments = [themeName]
        return self.ApplyTheme(*arguments)

    def CanCheckIn(self):
        return self.com_object.CanCheckIn()

    def cancheckin(self):
        """Alias for CanCheckIn"""
        return self.CanCheckIn()

    def can_check_in(self):
        """Alias for CanCheckIn"""
        return self.CanCheckIn()

    def CheckIn(self, SaveChanges=None, Comments=None, MakePublic=None):
        arguments = com_arguments([unwrap(a) for a in [SaveChanges, Comments, MakePublic]])
        self.com_object.CheckIn(*arguments)

    def checkin(self, SaveChanges=None, Comments=None, MakePublic=None):
        """Alias for CheckIn"""
        arguments = [SaveChanges, Comments, MakePublic]
        return self.CheckIn(*arguments)

    def check_in(self, SaveChanges=None, Comments=None, MakePublic=None):
        """Alias for CheckIn"""
        arguments = [SaveChanges, Comments, MakePublic]
        return self.CheckIn(*arguments)

    def CheckInWithVersion(self, SaveChanges=None, Comments=None, MakePublic=None, VersionType=None):
        arguments = com_arguments([unwrap(a) for a in [SaveChanges, Comments, MakePublic, VersionType]])
        self.com_object.CheckInWithVersion(*arguments)

    def checkinwithversion(self, SaveChanges=None, Comments=None, MakePublic=None, VersionType=None):
        """Alias for CheckInWithVersion"""
        arguments = [SaveChanges, Comments, MakePublic, VersionType]
        return self.CheckInWithVersion(*arguments)

    def check_in_with_version(self, SaveChanges=None, Comments=None, MakePublic=None, VersionType=None):
        """Alias for CheckInWithVersion"""
        arguments = [SaveChanges, Comments, MakePublic, VersionType]
        return self.CheckInWithVersion(*arguments)

    def Close(self):
        self.com_object.Close()

    def close(self):
        """Alias for Close"""
        return self.Close()

    def Convert2(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        self.com_object.Convert2(*arguments)

    def convert2(self, FileName=None):
        """Alias for Convert2"""
        arguments = [FileName]
        return self.Convert2(*arguments)

    def CreateVideo(self, FileName=None, UseTimingsAndNarrations=None, DefaultSlideDuration=None, VertResolution=None, FramesPerSecond=None, Quality=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, UseTimingsAndNarrations, DefaultSlideDuration, VertResolution, FramesPerSecond, Quality]])
        self.com_object.CreateVideo(*arguments)

    def createvideo(self, FileName=None, UseTimingsAndNarrations=None, DefaultSlideDuration=None, VertResolution=None, FramesPerSecond=None, Quality=None):
        """Alias for CreateVideo"""
        arguments = [FileName, UseTimingsAndNarrations, DefaultSlideDuration, VertResolution, FramesPerSecond, Quality]
        return self.CreateVideo(*arguments)

    def create_video(self, FileName=None, UseTimingsAndNarrations=None, DefaultSlideDuration=None, VertResolution=None, FramesPerSecond=None, Quality=None):
        """Alias for CreateVideo"""
        arguments = [FileName, UseTimingsAndNarrations, DefaultSlideDuration, VertResolution, FramesPerSecond, Quality]
        return self.CreateVideo(*arguments)

    def EndReview(self):
        return self.com_object.EndReview()

    def endreview(self):
        """Alias for EndReview"""
        return self.EndReview()

    def end_review(self):
        """Alias for EndReview"""
        return self.EndReview()

    def EnsureAllMediaUpgraded(self):
        self.com_object.EnsureAllMediaUpgraded()

    def ensureallmediaupgraded(self):
        """Alias for EnsureAllMediaUpgraded"""
        return self.EnsureAllMediaUpgraded()

    def ensure_all_media_upgraded(self):
        """Alias for EnsureAllMediaUpgraded"""
        return self.EnsureAllMediaUpgraded()

    def Export(self, Path=None, FilterName=None, ScaleWidth=None, ScaleHeight=None):
        arguments = com_arguments([unwrap(a) for a in [Path, FilterName, ScaleWidth, ScaleHeight]])
        self.com_object.Export(*arguments)

    def export(self, Path=None, FilterName=None, ScaleWidth=None, ScaleHeight=None):
        """Alias for Export"""
        arguments = [Path, FilterName, ScaleWidth, ScaleHeight]
        return self.Export(*arguments)

    def ExportAsFixedFormat(self, Path=None, FixedFormatType=None, Intent=None, FrameSlides=None, HandoutOrder=None, OutputType=None, PrintHiddenSlides=None, PrintRange=None, RangeType=None, SlideShowName=None, IncludeDocProperties=None, KeepIRMSettings=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, ExternalExporter=None):
        arguments = com_arguments([unwrap(a) for a in [Path, FixedFormatType, Intent, FrameSlides, HandoutOrder, OutputType, PrintHiddenSlides, PrintRange, RangeType, SlideShowName, IncludeDocProperties, KeepIRMSettings, DocStructureTags, BitmapMissingFonts, UseISO19005_1, ExternalExporter]])
        self.com_object.ExportAsFixedFormat(*arguments)

    def exportasfixedformat(self, Path=None, FixedFormatType=None, Intent=None, FrameSlides=None, HandoutOrder=None, OutputType=None, PrintHiddenSlides=None, PrintRange=None, RangeType=None, SlideShowName=None, IncludeDocProperties=None, KeepIRMSettings=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, ExternalExporter=None):
        """Alias for ExportAsFixedFormat"""
        arguments = [Path, FixedFormatType, Intent, FrameSlides, HandoutOrder, OutputType, PrintHiddenSlides, PrintRange, RangeType, SlideShowName, IncludeDocProperties, KeepIRMSettings, DocStructureTags, BitmapMissingFonts, UseISO19005_1, ExternalExporter]
        return self.ExportAsFixedFormat(*arguments)

    def export_as_fixed_format(self, Path=None, FixedFormatType=None, Intent=None, FrameSlides=None, HandoutOrder=None, OutputType=None, PrintHiddenSlides=None, PrintRange=None, RangeType=None, SlideShowName=None, IncludeDocProperties=None, KeepIRMSettings=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, ExternalExporter=None):
        """Alias for ExportAsFixedFormat"""
        arguments = [Path, FixedFormatType, Intent, FrameSlides, HandoutOrder, OutputType, PrintHiddenSlides, PrintRange, RangeType, SlideShowName, IncludeDocProperties, KeepIRMSettings, DocStructureTags, BitmapMissingFonts, UseISO19005_1, ExternalExporter]
        return self.ExportAsFixedFormat(*arguments)

    def ExportAsFixedFormat2(self, Path=None, FixedFormatType=None, Intent=None, FrameSlides=None, HandoutOrder=None, OutputType=None, PrintHiddenSlides=None, PrintRange=None, RangeType=None, SlideShowName=None, IncludeDocProperties=None, KeepIRMSettings=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, IncludeMarkup=None, ExternalExporter=None):
        arguments = com_arguments([unwrap(a) for a in [Path, FixedFormatType, Intent, FrameSlides, HandoutOrder, OutputType, PrintHiddenSlides, PrintRange, RangeType, SlideShowName, IncludeDocProperties, KeepIRMSettings, DocStructureTags, BitmapMissingFonts, UseISO19005_1, IncludeMarkup, ExternalExporter]])
        return self.com_object.ExportAsFixedFormat2(*arguments)

    def exportasfixedformat2(self, Path=None, FixedFormatType=None, Intent=None, FrameSlides=None, HandoutOrder=None, OutputType=None, PrintHiddenSlides=None, PrintRange=None, RangeType=None, SlideShowName=None, IncludeDocProperties=None, KeepIRMSettings=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, IncludeMarkup=None, ExternalExporter=None):
        """Alias for ExportAsFixedFormat2"""
        arguments = [Path, FixedFormatType, Intent, FrameSlides, HandoutOrder, OutputType, PrintHiddenSlides, PrintRange, RangeType, SlideShowName, IncludeDocProperties, KeepIRMSettings, DocStructureTags, BitmapMissingFonts, UseISO19005_1, IncludeMarkup, ExternalExporter]
        return self.ExportAsFixedFormat2(*arguments)

    def export_as_fixed_format2(self, Path=None, FixedFormatType=None, Intent=None, FrameSlides=None, HandoutOrder=None, OutputType=None, PrintHiddenSlides=None, PrintRange=None, RangeType=None, SlideShowName=None, IncludeDocProperties=None, KeepIRMSettings=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, IncludeMarkup=None, ExternalExporter=None):
        """Alias for ExportAsFixedFormat2"""
        arguments = [Path, FixedFormatType, Intent, FrameSlides, HandoutOrder, OutputType, PrintHiddenSlides, PrintRange, RangeType, SlideShowName, IncludeDocProperties, KeepIRMSettings, DocStructureTags, BitmapMissingFonts, UseISO19005_1, IncludeMarkup, ExternalExporter]
        return self.ExportAsFixedFormat2(*arguments)

    def ExportAsFixedFormat3(self, Path=None, FixedFormatType=None, Intent=None, FrameSlides=None, HandoutOrder=None, OutputType=None, PrintHiddenSlides=None, PrintRange=None, RangeType=None, SlideShowName=None, IncludeDocProperties=None, KeepIRMSettings=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, IncludeMarkup=None, ExternalExporter=None, Bookmarks=None, DocumentMarkup=None, PromotedHyperlinkShape=None):
        arguments = com_arguments([unwrap(a) for a in [Path, FixedFormatType, Intent, FrameSlides, HandoutOrder, OutputType, PrintHiddenSlides, PrintRange, RangeType, SlideShowName, IncludeDocProperties, KeepIRMSettings, DocStructureTags, BitmapMissingFonts, UseISO19005_1, IncludeMarkup, ExternalExporter, Bookmarks, DocumentMarkup, PromotedHyperlinkShape]])
        return self.com_object.ExportAsFixedFormat3(*arguments)

    def exportasfixedformat3(self, Path=None, FixedFormatType=None, Intent=None, FrameSlides=None, HandoutOrder=None, OutputType=None, PrintHiddenSlides=None, PrintRange=None, RangeType=None, SlideShowName=None, IncludeDocProperties=None, KeepIRMSettings=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, IncludeMarkup=None, ExternalExporter=None, Bookmarks=None, DocumentMarkup=None, PromotedHyperlinkShape=None):
        """Alias for ExportAsFixedFormat3"""
        arguments = [Path, FixedFormatType, Intent, FrameSlides, HandoutOrder, OutputType, PrintHiddenSlides, PrintRange, RangeType, SlideShowName, IncludeDocProperties, KeepIRMSettings, DocStructureTags, BitmapMissingFonts, UseISO19005_1, IncludeMarkup, ExternalExporter, Bookmarks, DocumentMarkup, PromotedHyperlinkShape]
        return self.ExportAsFixedFormat3(*arguments)

    def export_as_fixed_format3(self, Path=None, FixedFormatType=None, Intent=None, FrameSlides=None, HandoutOrder=None, OutputType=None, PrintHiddenSlides=None, PrintRange=None, RangeType=None, SlideShowName=None, IncludeDocProperties=None, KeepIRMSettings=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, IncludeMarkup=None, ExternalExporter=None, Bookmarks=None, DocumentMarkup=None, PromotedHyperlinkShape=None):
        """Alias for ExportAsFixedFormat3"""
        arguments = [Path, FixedFormatType, Intent, FrameSlides, HandoutOrder, OutputType, PrintHiddenSlides, PrintRange, RangeType, SlideShowName, IncludeDocProperties, KeepIRMSettings, DocStructureTags, BitmapMissingFonts, UseISO19005_1, IncludeMarkup, ExternalExporter, Bookmarks, DocumentMarkup, PromotedHyperlinkShape]
        return self.ExportAsFixedFormat3(*arguments)

    def FollowHyperlink(self, Address=None, SubAddress=None, NewWindow=None, AddHistory=None, ExtraInfo=None, Method=None, HeaderInfo=None):
        arguments = com_arguments([unwrap(a) for a in [Address, SubAddress, NewWindow, AddHistory, ExtraInfo, Method, HeaderInfo]])
        return self.com_object.FollowHyperlink(*arguments)

    def followhyperlink(self, Address=None, SubAddress=None, NewWindow=None, AddHistory=None, ExtraInfo=None, Method=None, HeaderInfo=None):
        """Alias for FollowHyperlink"""
        arguments = [Address, SubAddress, NewWindow, AddHistory, ExtraInfo, Method, HeaderInfo]
        return self.FollowHyperlink(*arguments)

    def follow_hyperlink(self, Address=None, SubAddress=None, NewWindow=None, AddHistory=None, ExtraInfo=None, Method=None, HeaderInfo=None):
        """Alias for FollowHyperlink"""
        arguments = [Address, SubAddress, NewWindow, AddHistory, ExtraInfo, Method, HeaderInfo]
        return self.FollowHyperlink(*arguments)

    def GetWorkflowTasks(self):
        return self.com_object.GetWorkflowTasks()

    def getworkflowtasks(self):
        """Alias for GetWorkflowTasks"""
        return self.GetWorkflowTasks()

    def get_workflow_tasks(self):
        """Alias for GetWorkflowTasks"""
        return self.GetWorkflowTasks()

    def GetWorkflowTemplates(self):
        return self.com_object.GetWorkflowTemplates()

    def getworkflowtemplates(self):
        """Alias for GetWorkflowTemplates"""
        return self.GetWorkflowTemplates()

    def get_workflow_templates(self):
        """Alias for GetWorkflowTemplates"""
        return self.GetWorkflowTemplates()

    def LockServerFile(self):
        self.com_object.LockServerFile()

    def lockserverfile(self):
        """Alias for LockServerFile"""
        return self.LockServerFile()

    def lock_server_file(self):
        """Alias for LockServerFile"""
        return self.LockServerFile()

    def Merge(self, Path=None):
        arguments = com_arguments([unwrap(a) for a in [Path]])
        return self.com_object.Merge(*arguments)

    def merge(self, Path=None):
        """Alias for Merge"""
        arguments = [Path]
        return self.Merge(*arguments)

    def MergeWithBaseline(self, withPresentation=None, baselinePresentation=None):
        arguments = com_arguments([unwrap(a) for a in [withPresentation, baselinePresentation]])
        return self.com_object.MergeWithBaseline(*arguments)

    def mergewithbaseline(self, withPresentation=None, baselinePresentation=None):
        """Alias for MergeWithBaseline"""
        arguments = [withPresentation, baselinePresentation]
        return self.MergeWithBaseline(*arguments)

    def merge_with_baseline(self, withPresentation=None, baselinePresentation=None):
        """Alias for MergeWithBaseline"""
        arguments = [withPresentation, baselinePresentation]
        return self.MergeWithBaseline(*arguments)

    def NewWindow(self):
        return DocumentWindow(self.com_object.NewWindow())

    def newwindow(self):
        """Alias for NewWindow"""
        return self.NewWindow()

    def new_window(self):
        """Alias for NewWindow"""
        return self.NewWindow()

    def PrintOut(self, From=None, To=None, PrintToFile=None, Copies=None, Collate=None):
        arguments = com_arguments([unwrap(a) for a in [From, To, PrintToFile, Copies, Collate]])
        self.com_object.PrintOut(*arguments)

    def printout(self, From=None, To=None, PrintToFile=None, Copies=None, Collate=None):
        """Alias for PrintOut"""
        arguments = [From, To, PrintToFile, Copies, Collate]
        return self.PrintOut(*arguments)

    def print_out(self, From=None, To=None, PrintToFile=None, Copies=None, Collate=None):
        """Alias for PrintOut"""
        arguments = [From, To, PrintToFile, Copies, Collate]
        return self.PrintOut(*arguments)

    def PublishSlides(self, SlideLibraryUrl=None, Overwrite=None):
        arguments = com_arguments([unwrap(a) for a in [SlideLibraryUrl, Overwrite]])
        self.com_object.PublishSlides(*arguments)

    def publishslides(self, SlideLibraryUrl=None, Overwrite=None):
        """Alias for PublishSlides"""
        arguments = [SlideLibraryUrl, Overwrite]
        return self.PublishSlides(*arguments)

    def publish_slides(self, SlideLibraryUrl=None, Overwrite=None):
        """Alias for PublishSlides"""
        arguments = [SlideLibraryUrl, Overwrite]
        return self.PublishSlides(*arguments)

    def RejectAll(self):
        return self.com_object.RejectAll()

    def rejectall(self):
        """Alias for RejectAll"""
        return self.RejectAll()

    def reject_all(self):
        """Alias for RejectAll"""
        return self.RejectAll()

    def RemoveDocumentInformation(self, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Type]])
        self.com_object.RemoveDocumentInformation(*arguments)

    def removedocumentinformation(self, Type=None):
        """Alias for RemoveDocumentInformation"""
        arguments = [Type]
        return self.RemoveDocumentInformation(*arguments)

    def remove_document_information(self, Type=None):
        """Alias for RemoveDocumentInformation"""
        arguments = [Type]
        return self.RemoveDocumentInformation(*arguments)

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()

    def SaveAs(self, FileName=None, FileFormat=None, EmbedFonts=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, FileFormat, EmbedFonts]])
        self.com_object.SaveAs(*arguments)

    def saveas(self, FileName=None, FileFormat=None, EmbedFonts=None):
        """Alias for SaveAs"""
        arguments = [FileName, FileFormat, EmbedFonts]
        return self.SaveAs(*arguments)

    def save_as(self, FileName=None, FileFormat=None, EmbedFonts=None):
        """Alias for SaveAs"""
        arguments = [FileName, FileFormat, EmbedFonts]
        return self.SaveAs(*arguments)

    def SaveCopyAs(self, FileName=None, FileFormat=None, EmbedTrueTypeFonts=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, FileFormat, EmbedTrueTypeFonts]])
        self.com_object.SaveCopyAs(*arguments)

    def savecopyas(self, FileName=None, FileFormat=None, EmbedTrueTypeFonts=None):
        """Alias for SaveCopyAs"""
        arguments = [FileName, FileFormat, EmbedTrueTypeFonts]
        return self.SaveCopyAs(*arguments)

    def save_copy_as(self, FileName=None, FileFormat=None, EmbedTrueTypeFonts=None):
        """Alias for SaveCopyAs"""
        arguments = [FileName, FileFormat, EmbedTrueTypeFonts]
        return self.SaveCopyAs(*arguments)

    def SaveCopyAs2(self, FileName=None, FileFormat=None, EmbedTrueTypeFonts=None, ReadOnlyRecommended=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, FileFormat, EmbedTrueTypeFonts, ReadOnlyRecommended]])
        self.com_object.SaveCopyAs2(*arguments)

    def savecopyas2(self, FileName=None, FileFormat=None, EmbedTrueTypeFonts=None, ReadOnlyRecommended=None):
        """Alias for SaveCopyAs2"""
        arguments = [FileName, FileFormat, EmbedTrueTypeFonts, ReadOnlyRecommended]
        return self.SaveCopyAs2(*arguments)

    def save_copy_as2(self, FileName=None, FileFormat=None, EmbedTrueTypeFonts=None, ReadOnlyRecommended=None):
        """Alias for SaveCopyAs2"""
        arguments = [FileName, FileFormat, EmbedTrueTypeFonts, ReadOnlyRecommended]
        return self.SaveCopyAs2(*arguments)

    def SendFaxOverInternet(self, Recipients=None, Subject=None, ShowMessage=None):
        arguments = com_arguments([unwrap(a) for a in [Recipients, Subject, ShowMessage]])
        self.com_object.SendFaxOverInternet(*arguments)

    def sendfaxoverinternet(self, Recipients=None, Subject=None, ShowMessage=None):
        """Alias for SendFaxOverInternet"""
        arguments = [Recipients, Subject, ShowMessage]
        return self.SendFaxOverInternet(*arguments)

    def send_fax_over_internet(self, Recipients=None, Subject=None, ShowMessage=None):
        """Alias for SendFaxOverInternet"""
        arguments = [Recipients, Subject, ShowMessage]
        return self.SendFaxOverInternet(*arguments)

    def SetPasswordEncryptionOptions(self, PasswordEncryptionProvider=None, PasswordEncryptionAlgorithm=None, PasswordEncryptionKeyLength=None, PasswordEncryptionFileProperties=None):
        arguments = com_arguments([unwrap(a) for a in [PasswordEncryptionProvider, PasswordEncryptionAlgorithm, PasswordEncryptionKeyLength, PasswordEncryptionFileProperties]])
        self.com_object.SetPasswordEncryptionOptions(*arguments)

    def setpasswordencryptionoptions(self, PasswordEncryptionProvider=None, PasswordEncryptionAlgorithm=None, PasswordEncryptionKeyLength=None, PasswordEncryptionFileProperties=None):
        """Alias for SetPasswordEncryptionOptions"""
        arguments = [PasswordEncryptionProvider, PasswordEncryptionAlgorithm, PasswordEncryptionKeyLength, PasswordEncryptionFileProperties]
        return self.SetPasswordEncryptionOptions(*arguments)

    def set_password_encryption_options(self, PasswordEncryptionProvider=None, PasswordEncryptionAlgorithm=None, PasswordEncryptionKeyLength=None, PasswordEncryptionFileProperties=None):
        """Alias for SetPasswordEncryptionOptions"""
        arguments = [PasswordEncryptionProvider, PasswordEncryptionAlgorithm, PasswordEncryptionKeyLength, PasswordEncryptionFileProperties]
        return self.SetPasswordEncryptionOptions(*arguments)

    def UpdateLinks(self):
        self.com_object.UpdateLinks()

    def updatelinks(self):
        """Alias for UpdateLinks"""
        return self.UpdateLinks()

    def update_links(self):
        """Alias for UpdateLinks"""
        return self.UpdateLinks()


class Presentations:

    def __init__(self, presentations=None):
        self.com_object= presentations

    def __call__(self, item):
        return Presentation(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, WithWindow=None):
        arguments = com_arguments([unwrap(a) for a in [WithWindow]])
        return Presentation(self.com_object.Add(*arguments))

    def add(self, WithWindow=None):
        """Alias for Add"""
        arguments = [WithWindow]
        return self.Add(*arguments)

    def CanCheckOut(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        return self.com_object.CanCheckOut(*arguments)

    def cancheckout(self, FileName=None):
        """Alias for CanCheckOut"""
        arguments = [FileName]
        return self.CanCheckOut(*arguments)

    def can_check_out(self, FileName=None):
        """Alias for CanCheckOut"""
        arguments = [FileName]
        return self.CanCheckOut(*arguments)

    def CheckOut(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        return self.com_object.CheckOut(*arguments)

    def checkout(self, FileName=None):
        """Alias for CheckOut"""
        arguments = [FileName]
        return self.CheckOut(*arguments)

    def check_out(self, FileName=None):
        """Alias for CheckOut"""
        arguments = [FileName]
        return self.CheckOut(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Presentation(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Open(self, FileName=None, ReadOnly=None, Untitled=None, WithWindow=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, ReadOnly, Untitled, WithWindow]])
        return Presentation(self.com_object.Open(*arguments))

    def open(self, FileName=None, ReadOnly=None, Untitled=None, WithWindow=None):
        """Alias for Open"""
        arguments = [FileName, ReadOnly, Untitled, WithWindow]
        return self.Open(*arguments)

    def Open2007(self, FileName=None, ReadOnly=None, Untitled=None, WithWindow=None, OpenAndRepair=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, ReadOnly, Untitled, WithWindow, OpenAndRepair]])
        return Presentation(self.com_object.Open2007(*arguments))

    def open2007(self, FileName=None, ReadOnly=None, Untitled=None, WithWindow=None, OpenAndRepair=None):
        """Alias for Open2007"""
        arguments = [FileName, ReadOnly, Untitled, WithWindow, OpenAndRepair]
        return self.Open2007(*arguments)


class PrintOptions:

    def __init__(self, printoptions=None):
        self.com_object= printoptions

    @property
    def ActivePrinter(self):
        return self.com_object.ActivePrinter

    @property
    def activeprinter(self):
        """Alias for ActivePrinter"""
        return self.ActivePrinter

    @property
    def active_printer(self):
        """Alias for ActivePrinter"""
        return self.ActivePrinter

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Collate(self):
        return self.com_object.Collate

    @Collate.setter
    def Collate(self, value):
        self.com_object.Collate = value

    @property
    def collate(self):
        """Alias for Collate"""
        return self.Collate

    @collate.setter
    def collate(self, value):
        """Alias for Collate.setter"""
        self.Collate = value

    @property
    def FitToPage(self):
        return self.com_object.FitToPage

    @FitToPage.setter
    def FitToPage(self, value):
        self.com_object.FitToPage = value

    @property
    def fittopage(self):
        """Alias for FitToPage"""
        return self.FitToPage

    @fittopage.setter
    def fittopage(self, value):
        """Alias for FitToPage.setter"""
        self.FitToPage = value

    @property
    def fit_to_page(self):
        """Alias for FitToPage"""
        return self.FitToPage

    @fit_to_page.setter
    def fit_to_page(self, value):
        """Alias for FitToPage.setter"""
        self.FitToPage = value

    @property
    def FrameSlides(self):
        return self.com_object.FrameSlides

    @FrameSlides.setter
    def FrameSlides(self, value):
        self.com_object.FrameSlides = value

    @property
    def frameslides(self):
        """Alias for FrameSlides"""
        return self.FrameSlides

    @frameslides.setter
    def frameslides(self, value):
        """Alias for FrameSlides.setter"""
        self.FrameSlides = value

    @property
    def frame_slides(self):
        """Alias for FrameSlides"""
        return self.FrameSlides

    @frame_slides.setter
    def frame_slides(self, value):
        """Alias for FrameSlides.setter"""
        self.FrameSlides = value

    @property
    def HandoutOrder(self):
        return self.com_object.HandoutOrder

    @HandoutOrder.setter
    def HandoutOrder(self, value):
        self.com_object.HandoutOrder = value

    @property
    def handoutorder(self):
        """Alias for HandoutOrder"""
        return self.HandoutOrder

    @handoutorder.setter
    def handoutorder(self, value):
        """Alias for HandoutOrder.setter"""
        self.HandoutOrder = value

    @property
    def handout_order(self):
        """Alias for HandoutOrder"""
        return self.HandoutOrder

    @handout_order.setter
    def handout_order(self, value):
        """Alias for HandoutOrder.setter"""
        self.HandoutOrder = value

    @property
    def HighQuality(self):
        return self.com_object.HighQuality

    @HighQuality.setter
    def HighQuality(self, value):
        self.com_object.HighQuality = value

    @property
    def highquality(self):
        """Alias for HighQuality"""
        return self.HighQuality

    @highquality.setter
    def highquality(self, value):
        """Alias for HighQuality.setter"""
        self.HighQuality = value

    @property
    def high_quality(self):
        """Alias for HighQuality"""
        return self.HighQuality

    @high_quality.setter
    def high_quality(self, value):
        """Alias for HighQuality.setter"""
        self.HighQuality = value

    @property
    def NumberOfCopies(self):
        return self.com_object.NumberOfCopies

    @NumberOfCopies.setter
    def NumberOfCopies(self, value):
        self.com_object.NumberOfCopies = value

    @property
    def numberofcopies(self):
        """Alias for NumberOfCopies"""
        return self.NumberOfCopies

    @numberofcopies.setter
    def numberofcopies(self, value):
        """Alias for NumberOfCopies.setter"""
        self.NumberOfCopies = value

    @property
    def number_of_copies(self):
        """Alias for NumberOfCopies"""
        return self.NumberOfCopies

    @number_of_copies.setter
    def number_of_copies(self, value):
        """Alias for NumberOfCopies.setter"""
        self.NumberOfCopies = value

    @property
    def OutputType(self):
        return self.com_object.OutputType

    @OutputType.setter
    def OutputType(self, value):
        self.com_object.OutputType = value

    @property
    def outputtype(self):
        """Alias for OutputType"""
        return self.OutputType

    @outputtype.setter
    def outputtype(self, value):
        """Alias for OutputType.setter"""
        self.OutputType = value

    @property
    def output_type(self):
        """Alias for OutputType"""
        return self.OutputType

    @output_type.setter
    def output_type(self, value):
        """Alias for OutputType.setter"""
        self.OutputType = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PrintColorType(self):
        return self.com_object.PrintColorType

    @PrintColorType.setter
    def PrintColorType(self, value):
        self.com_object.PrintColorType = value

    @property
    def printcolortype(self):
        """Alias for PrintColorType"""
        return self.PrintColorType

    @printcolortype.setter
    def printcolortype(self, value):
        """Alias for PrintColorType.setter"""
        self.PrintColorType = value

    @property
    def print_color_type(self):
        """Alias for PrintColorType"""
        return self.PrintColorType

    @print_color_type.setter
    def print_color_type(self, value):
        """Alias for PrintColorType.setter"""
        self.PrintColorType = value

    @property
    def PrintComments(self):
        return self.com_object.PrintComments

    @PrintComments.setter
    def PrintComments(self, value):
        self.com_object.PrintComments = value

    @property
    def printcomments(self):
        """Alias for PrintComments"""
        return self.PrintComments

    @printcomments.setter
    def printcomments(self, value):
        """Alias for PrintComments.setter"""
        self.PrintComments = value

    @property
    def print_comments(self):
        """Alias for PrintComments"""
        return self.PrintComments

    @print_comments.setter
    def print_comments(self, value):
        """Alias for PrintComments.setter"""
        self.PrintComments = value

    @property
    def PrintFontsAsGraphics(self):
        return self.com_object.PrintFontsAsGraphics

    @PrintFontsAsGraphics.setter
    def PrintFontsAsGraphics(self, value):
        self.com_object.PrintFontsAsGraphics = value

    @property
    def printfontsasgraphics(self):
        """Alias for PrintFontsAsGraphics"""
        return self.PrintFontsAsGraphics

    @printfontsasgraphics.setter
    def printfontsasgraphics(self, value):
        """Alias for PrintFontsAsGraphics.setter"""
        self.PrintFontsAsGraphics = value

    @property
    def print_fonts_as_graphics(self):
        """Alias for PrintFontsAsGraphics"""
        return self.PrintFontsAsGraphics

    @print_fonts_as_graphics.setter
    def print_fonts_as_graphics(self, value):
        """Alias for PrintFontsAsGraphics.setter"""
        self.PrintFontsAsGraphics = value

    @property
    def PrintHiddenSlides(self):
        return self.com_object.PrintHiddenSlides

    @PrintHiddenSlides.setter
    def PrintHiddenSlides(self, value):
        self.com_object.PrintHiddenSlides = value

    @property
    def printhiddenslides(self):
        """Alias for PrintHiddenSlides"""
        return self.PrintHiddenSlides

    @printhiddenslides.setter
    def printhiddenslides(self, value):
        """Alias for PrintHiddenSlides.setter"""
        self.PrintHiddenSlides = value

    @property
    def print_hidden_slides(self):
        """Alias for PrintHiddenSlides"""
        return self.PrintHiddenSlides

    @print_hidden_slides.setter
    def print_hidden_slides(self, value):
        """Alias for PrintHiddenSlides.setter"""
        self.PrintHiddenSlides = value

    @property
    def PrintInBackground(self):
        return self.com_object.PrintInBackground

    @PrintInBackground.setter
    def PrintInBackground(self, value):
        self.com_object.PrintInBackground = value

    @property
    def printinbackground(self):
        """Alias for PrintInBackground"""
        return self.PrintInBackground

    @printinbackground.setter
    def printinbackground(self, value):
        """Alias for PrintInBackground.setter"""
        self.PrintInBackground = value

    @property
    def print_in_background(self):
        """Alias for PrintInBackground"""
        return self.PrintInBackground

    @print_in_background.setter
    def print_in_background(self, value):
        """Alias for PrintInBackground.setter"""
        self.PrintInBackground = value

    @property
    def Ranges(self):
        return PrintRanges(self.com_object.Ranges)

    @property
    def ranges(self):
        """Alias for Ranges"""
        return self.Ranges

    @property
    def RangeType(self):
        return self.com_object.RangeType

    @RangeType.setter
    def RangeType(self, value):
        self.com_object.RangeType = value

    @property
    def rangetype(self):
        """Alias for RangeType"""
        return self.RangeType

    @rangetype.setter
    def rangetype(self, value):
        """Alias for RangeType.setter"""
        self.RangeType = value

    @property
    def range_type(self):
        """Alias for RangeType"""
        return self.RangeType

    @range_type.setter
    def range_type(self, value):
        """Alias for RangeType.setter"""
        self.RangeType = value

    @property
    def sectionIndex(self):
        return PrintOptions(self.com_object.sectionIndex)

    @sectionIndex.setter
    def sectionIndex(self, value):
        self.com_object.sectionIndex = value

    @property
    def sectionindex(self):
        """Alias for sectionIndex"""
        return self.sectionIndex

    @sectionindex.setter
    def sectionindex(self, value):
        """Alias for sectionIndex.setter"""
        self.sectionIndex = value

    @property
    def section_index(self):
        """Alias for sectionIndex"""
        return self.sectionIndex

    @section_index.setter
    def section_index(self, value):
        """Alias for sectionIndex.setter"""
        self.sectionIndex = value

    @property
    def SlideShowName(self):
        return self.com_object.SlideShowName

    @SlideShowName.setter
    def SlideShowName(self, value):
        self.com_object.SlideShowName = value

    @property
    def slideshowname(self):
        """Alias for SlideShowName"""
        return self.SlideShowName

    @slideshowname.setter
    def slideshowname(self, value):
        """Alias for SlideShowName.setter"""
        self.SlideShowName = value

    @property
    def slide_show_name(self):
        """Alias for SlideShowName"""
        return self.SlideShowName

    @slide_show_name.setter
    def slide_show_name(self, value):
        """Alias for SlideShowName.setter"""
        self.SlideShowName = value


class PrintRange:

    def __init__(self, printrange=None):
        self.com_object= printrange

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def End(self):
        return self.com_object.End

    @property
    def end(self):
        """Alias for End"""
        return self.End

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Start(self):
        return self.com_object.Start

    @property
    def start(self):
        """Alias for Start"""
        return self.Start

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class PrintRanges:

    def __init__(self, printranges=None):
        self.com_object= printranges

    def __call__(self, item):
        return PrintRange(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Start=None, End=None):
        arguments = com_arguments([unwrap(a) for a in [Start, End]])
        return PrintRange(self.com_object.Add(*arguments))

    def add(self, Start=None, End=None):
        """Alias for Add"""
        arguments = [Start, End]
        return self.Add(*arguments)

    def ClearAll(self):
        return self.com_object.ClearAll()

    def clearall(self):
        """Alias for ClearAll"""
        return self.ClearAll()

    def clear_all(self):
        """Alias for ClearAll"""
        return self.ClearAll()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return PrintRange(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class PropertyEffect:

    def __init__(self, propertyeffect=None):
        self.com_object= propertyeffect

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def From(self):
        return self.com_object.From

    @From.setter
    def From(self, value):
        self.com_object.From = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Points(self):
        return AnimationPoints(self.com_object.Points)

    @property
    def points(self):
        """Alias for Points"""
        return self.Points

    @property
    def Property(self):
        return self.com_object.Property

    @Property.setter
    def Property(self, value):
        self.com_object.Property = value

    @property
    def To(self):
        return self.com_object.To

    @To.setter
    def To(self, value):
        self.com_object.To = value

    @property
    def to(self):
        """Alias for To"""
        return self.To

    @to.setter
    def to(self, value):
        """Alias for To.setter"""
        self.To = value


class ProtectedViewWindow:

    def __init__(self, protectedviewwindow=None):
        self.com_object= protectedviewwindow

    @property
    def Active(self):
        return self.com_object.Active

    @property
    def active(self):
        """Alias for Active"""
        return self.Active

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Caption(self):
        return self.com_object.Caption

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Presentation(self):
        return Presentation(self.com_object.Presentation)

    @property
    def presentation(self):
        """Alias for Presentation"""
        return self.Presentation

    @property
    def SourceName(self):
        return ProtectedViewWindow(self.com_object.SourceName)

    @property
    def sourcename(self):
        """Alias for SourceName"""
        return self.SourceName

    @property
    def source_name(self):
        """Alias for SourceName"""
        return self.SourceName

    @property
    def SourcePath(self):
        return ProtectedViewWindow(self.com_object.SourcePath)

    @property
    def sourcepath(self):
        """Alias for SourcePath"""
        return self.SourcePath

    @property
    def source_path(self):
        """Alias for SourcePath"""
        return self.SourcePath

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def WindowState(self):
        return self.com_object.WindowState

    @WindowState.setter
    def WindowState(self, value):
        self.com_object.WindowState = value

    @property
    def windowstate(self):
        """Alias for WindowState"""
        return self.WindowState

    @windowstate.setter
    def windowstate(self, value):
        """Alias for WindowState.setter"""
        self.WindowState = value

    @property
    def window_state(self):
        """Alias for WindowState"""
        return self.WindowState

    @window_state.setter
    def window_state(self, value):
        """Alias for WindowState.setter"""
        self.WindowState = value

    def Activate(self):
        self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()

    def Close(self):
        self.com_object.Close()

    def close(self):
        """Alias for Close"""
        return self.Close()

    def Edit(self, ModifyPassword=None):
        arguments = com_arguments([unwrap(a) for a in [ModifyPassword]])
        return Presentation(self.com_object.Edit(*arguments))

    def edit(self, ModifyPassword=None):
        """Alias for Edit"""
        arguments = [ModifyPassword]
        return self.Edit(*arguments)


class ProtectedViewWindows:

    def __init__(self, protectedviewwindows=None):
        self.com_object= protectedviewwindows

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ProtectedViewWindow(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Open(self, FileName=None, ReadPassword=None, OpenAndRepair=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, ReadPassword, OpenAndRepair]])
        return ProtectedViewWindow(self.com_object.Open(*arguments))

    def open(self, FileName=None, ReadPassword=None, OpenAndRepair=None):
        """Alias for Open"""
        arguments = [FileName, ReadPassword, OpenAndRepair]
        return self.Open(*arguments)


class PublishObject:

    def __init__(self, publishobject=None):
        self.com_object= publishobject

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def FileName(self):
        return self.com_object.FileName

    @FileName.setter
    def FileName(self, value):
        self.com_object.FileName = value

    @property
    def filename(self):
        """Alias for FileName"""
        return self.FileName

    @filename.setter
    def filename(self, value):
        """Alias for FileName.setter"""
        self.FileName = value

    @property
    def file_name(self):
        """Alias for FileName"""
        return self.FileName

    @file_name.setter
    def file_name(self, value):
        """Alias for FileName.setter"""
        self.FileName = value

    @property
    def HTMLVersion(self):
        return self.com_object.HTMLVersion

    @HTMLVersion.setter
    def HTMLVersion(self, value):
        self.com_object.HTMLVersion = value

    @property
    def htmlversion(self):
        """Alias for HTMLVersion"""
        return self.HTMLVersion

    @htmlversion.setter
    def htmlversion(self, value):
        """Alias for HTMLVersion.setter"""
        self.HTMLVersion = value

    @property
    def h_t_m_l_version(self):
        """Alias for HTMLVersion"""
        return self.HTMLVersion

    @h_t_m_l_version.setter
    def h_t_m_l_version(self, value):
        """Alias for HTMLVersion.setter"""
        self.HTMLVersion = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RangeEnd(self):
        return self.com_object.RangeEnd

    @RangeEnd.setter
    def RangeEnd(self, value):
        self.com_object.RangeEnd = value

    @property
    def rangeend(self):
        """Alias for RangeEnd"""
        return self.RangeEnd

    @rangeend.setter
    def rangeend(self, value):
        """Alias for RangeEnd.setter"""
        self.RangeEnd = value

    @property
    def range_end(self):
        """Alias for RangeEnd"""
        return self.RangeEnd

    @range_end.setter
    def range_end(self, value):
        """Alias for RangeEnd.setter"""
        self.RangeEnd = value

    @property
    def RangeStart(self):
        return self.com_object.RangeStart

    @RangeStart.setter
    def RangeStart(self, value):
        self.com_object.RangeStart = value

    @property
    def rangestart(self):
        """Alias for RangeStart"""
        return self.RangeStart

    @rangestart.setter
    def rangestart(self, value):
        """Alias for RangeStart.setter"""
        self.RangeStart = value

    @property
    def range_start(self):
        """Alias for RangeStart"""
        return self.RangeStart

    @range_start.setter
    def range_start(self, value):
        """Alias for RangeStart.setter"""
        self.RangeStart = value

    @property
    def SlideShowName(self):
        return self.com_object.SlideShowName

    @SlideShowName.setter
    def SlideShowName(self, value):
        self.com_object.SlideShowName = value

    @property
    def slideshowname(self):
        """Alias for SlideShowName"""
        return self.SlideShowName

    @slideshowname.setter
    def slideshowname(self, value):
        """Alias for SlideShowName.setter"""
        self.SlideShowName = value

    @property
    def slide_show_name(self):
        """Alias for SlideShowName"""
        return self.SlideShowName

    @slide_show_name.setter
    def slide_show_name(self, value):
        """Alias for SlideShowName.setter"""
        self.SlideShowName = value

    @property
    def SourceType(self):
        return self.com_object.SourceType

    @SourceType.setter
    def SourceType(self, value):
        self.com_object.SourceType = value

    @property
    def sourcetype(self):
        """Alias for SourceType"""
        return self.SourceType

    @sourcetype.setter
    def sourcetype(self, value):
        """Alias for SourceType.setter"""
        self.SourceType = value

    @property
    def source_type(self):
        """Alias for SourceType"""
        return self.SourceType

    @source_type.setter
    def source_type(self, value):
        """Alias for SourceType.setter"""
        self.SourceType = value

    @property
    def SpeakerNotes(self):
        return self.com_object.SpeakerNotes

    @SpeakerNotes.setter
    def SpeakerNotes(self, value):
        self.com_object.SpeakerNotes = value

    @property
    def speakernotes(self):
        """Alias for SpeakerNotes"""
        return self.SpeakerNotes

    @speakernotes.setter
    def speakernotes(self, value):
        """Alias for SpeakerNotes.setter"""
        self.SpeakerNotes = value

    @property
    def speaker_notes(self):
        """Alias for SpeakerNotes"""
        return self.SpeakerNotes

    @speaker_notes.setter
    def speaker_notes(self, value):
        """Alias for SpeakerNotes.setter"""
        self.SpeakerNotes = value

    def Publish(self):
        self.com_object.Publish()

    def publish(self):
        """Alias for Publish"""
        return self.Publish()


class PublishObjects:

    def __init__(self, publishobjects=None):
        self.com_object= publishobjects

    def __call__(self, item):
        return PublishObject(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return PublishObject(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ResampleMediaTasks:

    def __init__(self, resamplemediatasks=None):
        self.com_object= resamplemediatasks

    def __call__(self, item):
        return ResampleMediaTask(self.com_object(item))

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def PercentComplete(self):
        return self.com_object.PercentComplete

    @property
    def percentcomplete(self):
        """Alias for PercentComplete"""
        return self.PercentComplete

    @property
    def percent_complete(self):
        """Alias for PercentComplete"""
        return self.PercentComplete

    def Cancel(self):
        return self.com_object.Cancel()

    def cancel(self):
        """Alias for Cancel"""
        return self.Cancel()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ResampleMediaTask(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Pause(self):
        self.com_object.Pause()

    def pause(self):
        """Alias for Pause"""
        return self.Pause()

    def Resume(self):
        return self.com_object.Resume()

    def resume(self):
        """Alias for Resume"""
        return self.Resume()


class Research:

    def __init__(self, research=None):
        self.com_object= research

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def IsResearchService(self, ServiceID=None):
        arguments = com_arguments([unwrap(a) for a in [ServiceID]])
        return self.com_object.IsResearchService(*arguments)

    def isresearchservice(self, ServiceID=None):
        """Alias for IsResearchService"""
        arguments = [ServiceID]
        return self.IsResearchService(*arguments)

    def is_research_service(self, ServiceID=None):
        """Alias for IsResearchService"""
        arguments = [ServiceID]
        return self.IsResearchService(*arguments)

    def Query(self, ServiceID=None, QueryString=None, QueryLanguage=None, UseSelection=None, RequeryContextXML=None, NewQueryContextXML=None, LaunchQuery=None):
        arguments = com_arguments([unwrap(a) for a in [ServiceID, QueryString, QueryLanguage, UseSelection, RequeryContextXML, NewQueryContextXML, LaunchQuery]])
        self.com_object.Query(*arguments)

    def query(self, ServiceID=None, QueryString=None, QueryLanguage=None, UseSelection=None, RequeryContextXML=None, NewQueryContextXML=None, LaunchQuery=None):
        """Alias for Query"""
        arguments = [ServiceID, QueryString, QueryLanguage, UseSelection, RequeryContextXML, NewQueryContextXML, LaunchQuery]
        return self.Query(*arguments)

    def SetLanguagePair(self, Language1=None, Language2=None):
        arguments = com_arguments([unwrap(a) for a in [Language1, Language2]])
        self.com_object.SetLanguagePair(*arguments)

    def setlanguagepair(self, Language1=None, Language2=None):
        """Alias for SetLanguagePair"""
        arguments = [Language1, Language2]
        return self.SetLanguagePair(*arguments)

    def set_language_pair(self, Language1=None, Language2=None):
        """Alias for SetLanguagePair"""
        arguments = [Language1, Language2]
        return self.SetLanguagePair(*arguments)


class RGBColor:

    def __init__(self, rgbcolor=None):
        self.com_object= rgbcolor

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RGB(self):
        return PpColorSchemeIndex(self.com_object.RGB)

    @RGB.setter
    def RGB(self, value):
        self.com_object.RGB = value

    @property
    def rgb(self):
        """Alias for RGB"""
        return self.RGB

    @rgb.setter
    def rgb(self, value):
        """Alias for RGB.setter"""
        self.RGB = value

    @property
    def r_g_b(self):
        """Alias for RGB"""
        return self.RGB

    @r_g_b.setter
    def r_g_b(self, value):
        """Alias for RGB.setter"""
        self.RGB = value


class RotationEffect:

    def __init__(self, rotationeffect=None):
        self.com_object= rotationeffect

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def By(self):
        return self.com_object.By

    @By.setter
    def By(self, value):
        self.com_object.By = value

    @property
    def by(self):
        """Alias for By"""
        return self.By

    @by.setter
    def by(self, value):
        """Alias for By.setter"""
        self.By = value

    @property
    def From(self):
        return self.com_object.From

    @From.setter
    def From(self, value):
        self.com_object.From = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def To(self):
        return self.com_object.To

    @To.setter
    def To(self, value):
        self.com_object.To = value

    @property
    def to(self):
        """Alias for To"""
        return self.To

    @to.setter
    def to(self, value):
        """Alias for To.setter"""
        self.To = value


class Row:

    def __init__(self, row=None):
        self.com_object= row

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    def Cells(self, RowIndex=None, ColumnIndex=None):
        arguments = com_arguments([unwrap(a) for a in [RowIndex, ColumnIndex]])
        if hasattr(self.com_object, "GetCells"):
            return CellRange(self.com_object.GetCells(*arguments))
        else:
            return CellRange(self.com_object.Cells(*arguments))

    def cells(self, RowIndex=None, ColumnIndex=None):
        """Alias for Cells"""
        arguments = [RowIndex, ColumnIndex]
        return self.Cells(*arguments)

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Rows:

    def __init__(self, rows=None):
        self.com_object= rows

    def __call__(self, item):
        return Row(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, BeforeRow=None):
        arguments = com_arguments([unwrap(a) for a in [BeforeRow]])
        return Row(self.com_object.Add(*arguments))

    def add(self, BeforeRow=None):
        """Alias for Add"""
        arguments = [BeforeRow]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Row(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Ruler:

    def __init__(self, ruler=None):
        self.com_object= ruler

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Levels(self):
        return RulerLevels(self.com_object.Levels)

    @property
    def levels(self):
        """Alias for Levels"""
        return self.Levels

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def TabStops(self):
        return TabStops(self.com_object.TabStops)

    @property
    def tabstops(self):
        """Alias for TabStops"""
        return self.TabStops

    @property
    def tab_stops(self):
        """Alias for TabStops"""
        return self.TabStops


class RulerLevel:

    def __init__(self, rulerlevel=None):
        self.com_object= rulerlevel

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def FirstMargin(self):
        return self.com_object.FirstMargin

    @FirstMargin.setter
    def FirstMargin(self, value):
        self.com_object.FirstMargin = value

    @property
    def firstmargin(self):
        """Alias for FirstMargin"""
        return self.FirstMargin

    @firstmargin.setter
    def firstmargin(self, value):
        """Alias for FirstMargin.setter"""
        self.FirstMargin = value

    @property
    def first_margin(self):
        """Alias for FirstMargin"""
        return self.FirstMargin

    @first_margin.setter
    def first_margin(self, value):
        """Alias for FirstMargin.setter"""
        self.FirstMargin = value

    @property
    def LeftMargin(self):
        return self.com_object.LeftMargin

    @LeftMargin.setter
    def LeftMargin(self, value):
        self.com_object.LeftMargin = value

    @property
    def leftmargin(self):
        """Alias for LeftMargin"""
        return self.LeftMargin

    @leftmargin.setter
    def leftmargin(self, value):
        """Alias for LeftMargin.setter"""
        self.LeftMargin = value

    @property
    def left_margin(self):
        """Alias for LeftMargin"""
        return self.LeftMargin

    @left_margin.setter
    def left_margin(self, value):
        """Alias for LeftMargin.setter"""
        self.LeftMargin = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class RulerLevels:

    def __init__(self, rulerlevels=None):
        self.com_object= rulerlevels

    def __call__(self, item):
        return RulerLevel(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return RulerLevel(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ScaleEffect:

    def __init__(self, scaleeffect=None):
        self.com_object= scaleeffect

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ByX(self):
        return self.com_object.ByX

    @ByX.setter
    def ByX(self, value):
        self.com_object.ByX = value

    @property
    def byx(self):
        """Alias for ByX"""
        return self.ByX

    @byx.setter
    def byx(self, value):
        """Alias for ByX.setter"""
        self.ByX = value

    @property
    def by_x(self):
        """Alias for ByX"""
        return self.ByX

    @by_x.setter
    def by_x(self, value):
        """Alias for ByX.setter"""
        self.ByX = value

    @property
    def ByY(self):
        return self.com_object.ByY

    @ByY.setter
    def ByY(self, value):
        self.com_object.ByY = value

    @property
    def byy(self):
        """Alias for ByY"""
        return self.ByY

    @byy.setter
    def byy(self, value):
        """Alias for ByY.setter"""
        self.ByY = value

    @property
    def by_y(self):
        """Alias for ByY"""
        return self.ByY

    @by_y.setter
    def by_y(self, value):
        """Alias for ByY.setter"""
        self.ByY = value

    @property
    def FromX(self):
        return self.com_object.FromX

    @FromX.setter
    def FromX(self, value):
        self.com_object.FromX = value

    @property
    def fromx(self):
        """Alias for FromX"""
        return self.FromX

    @fromx.setter
    def fromx(self, value):
        """Alias for FromX.setter"""
        self.FromX = value

    @property
    def from_x(self):
        """Alias for FromX"""
        return self.FromX

    @from_x.setter
    def from_x(self, value):
        """Alias for FromX.setter"""
        self.FromX = value

    @property
    def FromY(self):
        return ScaleEffect(self.com_object.FromY)

    @FromY.setter
    def FromY(self, value):
        self.com_object.FromY = value

    @property
    def fromy(self):
        """Alias for FromY"""
        return self.FromY

    @fromy.setter
    def fromy(self, value):
        """Alias for FromY.setter"""
        self.FromY = value

    @property
    def from_y(self):
        """Alias for FromY"""
        return self.FromY

    @from_y.setter
    def from_y(self, value):
        """Alias for FromY.setter"""
        self.FromY = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ToX(self):
        return self.com_object.ToX

    @ToX.setter
    def ToX(self, value):
        self.com_object.ToX = value

    @property
    def tox(self):
        """Alias for ToX"""
        return self.ToX

    @tox.setter
    def tox(self, value):
        """Alias for ToX.setter"""
        self.ToX = value

    @property
    def to_x(self):
        """Alias for ToX"""
        return self.ToX

    @to_x.setter
    def to_x(self, value):
        """Alias for ToX.setter"""
        self.ToX = value

    @property
    def ToY(self):
        return ScaleEffect(self.com_object.ToY)

    @ToY.setter
    def ToY(self, value):
        self.com_object.ToY = value

    @property
    def toy(self):
        """Alias for ToY"""
        return self.ToY

    @toy.setter
    def toy(self, value):
        """Alias for ToY.setter"""
        self.ToY = value

    @property
    def to_y(self):
        """Alias for ToY"""
        return self.ToY

    @to_y.setter
    def to_y(self, value):
        """Alias for ToY.setter"""
        self.ToY = value


class SectionProperties:

    def __init__(self, sectionproperties=None):
        self.com_object= sectionproperties

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def AddBeforeSlide(self, SlideIndex=None, sectionName=None):
        arguments = com_arguments([unwrap(a) for a in [SlideIndex, sectionName]])
        return self.com_object.AddBeforeSlide(*arguments)

    def addbeforeslide(self, SlideIndex=None, sectionName=None):
        """Alias for AddBeforeSlide"""
        arguments = [SlideIndex, sectionName]
        return self.AddBeforeSlide(*arguments)

    def add_before_slide(self, SlideIndex=None, sectionName=None):
        """Alias for AddBeforeSlide"""
        arguments = [SlideIndex, sectionName]
        return self.AddBeforeSlide(*arguments)

    def AddSection(self, sectionIndex=None, sectionName=None):
        arguments = com_arguments([unwrap(a) for a in [sectionIndex, sectionName]])
        return self.com_object.AddSection(*arguments)

    def addsection(self, sectionIndex=None, sectionName=None):
        """Alias for AddSection"""
        arguments = [sectionIndex, sectionName]
        return self.AddSection(*arguments)

    def add_section(self, sectionIndex=None, sectionName=None):
        """Alias for AddSection"""
        arguments = [sectionIndex, sectionName]
        return self.AddSection(*arguments)

    def Delete(self, sectionIndex=None, deleteSlides=None):
        arguments = com_arguments([unwrap(a) for a in [sectionIndex, deleteSlides]])
        self.com_object.Delete(*arguments)

    def delete(self, sectionIndex=None, deleteSlides=None):
        """Alias for Delete"""
        arguments = [sectionIndex, deleteSlides]
        return self.Delete(*arguments)

    def FirstSlide(self, sectionIndex=None):
        arguments = com_arguments([unwrap(a) for a in [sectionIndex]])
        return self.com_object.FirstSlide(*arguments)

    def firstslide(self, sectionIndex=None):
        """Alias for FirstSlide"""
        arguments = [sectionIndex]
        return self.FirstSlide(*arguments)

    def first_slide(self, sectionIndex=None):
        """Alias for FirstSlide"""
        arguments = [sectionIndex]
        return self.FirstSlide(*arguments)

    def Move(self, sectionIndex=None, toPos=None):
        arguments = com_arguments([unwrap(a) for a in [sectionIndex, toPos]])
        self.com_object.Move(*arguments)

    def move(self, sectionIndex=None, toPos=None):
        """Alias for Move"""
        arguments = [sectionIndex, toPos]
        return self.Move(*arguments)

    def Name(self, sectionIndex=None):
        arguments = com_arguments([unwrap(a) for a in [sectionIndex]])
        return self.com_object.Name(*arguments)

    def name(self, sectionIndex=None):
        """Alias for Name"""
        arguments = [sectionIndex]
        return self.Name(*arguments)

    def Rename(self, sectionIndex=None, sectionName=None):
        arguments = com_arguments([unwrap(a) for a in [sectionIndex, sectionName]])
        self.com_object.Rename(*arguments)

    def rename(self, sectionIndex=None, sectionName=None):
        """Alias for Rename"""
        arguments = [sectionIndex, sectionName]
        return self.Rename(*arguments)

    def SectionID(self, sectionIndex=None):
        arguments = com_arguments([unwrap(a) for a in [sectionIndex]])
        return self.com_object.SectionID(*arguments)

    def sectionid(self, sectionIndex=None):
        """Alias for SectionID"""
        arguments = [sectionIndex]
        return self.SectionID(*arguments)

    def section_i_d(self, sectionIndex=None):
        """Alias for SectionID"""
        arguments = [sectionIndex]
        return self.SectionID(*arguments)

    def SlidesCount(self, sectionIndex=None):
        arguments = com_arguments([unwrap(a) for a in [sectionIndex]])
        return self.com_object.SlidesCount(*arguments)

    def slidescount(self, sectionIndex=None):
        """Alias for SlidesCount"""
        arguments = [sectionIndex]
        return self.SlidesCount(*arguments)

    def slides_count(self, sectionIndex=None):
        """Alias for SlidesCount"""
        arguments = [sectionIndex]
        return self.SlidesCount(*arguments)


class Selection:

    def __init__(self, selection=None):
        self.com_object= selection

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ChildShapeRange(self):
        return ShapeRange(self.com_object.ChildShapeRange)

    @property
    def childshaperange(self):
        """Alias for ChildShapeRange"""
        return self.ChildShapeRange

    @property
    def child_shape_range(self):
        """Alias for ChildShapeRange"""
        return self.ChildShapeRange

    @property
    def HasChildShapeRange(self):
        return self.com_object.HasChildShapeRange

    @property
    def haschildshaperange(self):
        """Alias for HasChildShapeRange"""
        return self.HasChildShapeRange

    @property
    def has_child_shape_range(self):
        """Alias for HasChildShapeRange"""
        return self.HasChildShapeRange

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ShapeRange(self):
        return ShapeRange(self.com_object.ShapeRange)

    @property
    def shaperange(self):
        """Alias for ShapeRange"""
        return self.ShapeRange

    @property
    def shape_range(self):
        """Alias for ShapeRange"""
        return self.ShapeRange

    @property
    def SlideRange(self):
        return SlideRange(self.com_object.SlideRange)

    @property
    def sliderange(self):
        """Alias for SlideRange"""
        return self.SlideRange

    @property
    def slide_range(self):
        """Alias for SlideRange"""
        return self.SlideRange

    @property
    def TextRange(self):
        return TextRange(self.com_object.TextRange)

    @property
    def textrange(self):
        """Alias for TextRange"""
        return self.TextRange

    @property
    def text_range(self):
        """Alias for TextRange"""
        return self.TextRange

    @property
    def TextRange2(self):
        return TextRange2(self.com_object.TextRange2)

    @property
    def textrange2(self):
        """Alias for TextRange2"""
        return self.TextRange2

    @property
    def text_range2(self):
        """Alias for TextRange2"""
        return self.TextRange2

    @property
    def Type(self):
        return self.com_object.Type

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Cut(self):
        self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Unselect(self):
        self.com_object.Unselect()

    def unselect(self):
        """Alias for Unselect"""
        return self.Unselect()


class Sequence:

    def __init__(self, sequence=None):
        self.com_object= sequence

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def AddEffect(self, Shape=None, effectId=None, Level=None, trigger=None, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Shape, effectId, Level, trigger, Index]])
        return Effect(self.com_object.AddEffect(*arguments))

    def addeffect(self, Shape=None, effectId=None, Level=None, trigger=None, Index=None):
        """Alias for AddEffect"""
        arguments = [Shape, effectId, Level, trigger, Index]
        return self.AddEffect(*arguments)

    def add_effect(self, Shape=None, effectId=None, Level=None, trigger=None, Index=None):
        """Alias for AddEffect"""
        arguments = [Shape, effectId, Level, trigger, Index]
        return self.AddEffect(*arguments)

    def AddTriggerEffect(self, pShape=None, effectId=None, trigger=None, pTriggerShape=None, bookmark=None, Level=None):
        arguments = com_arguments([unwrap(a) for a in [pShape, effectId, trigger, pTriggerShape, bookmark, Level]])
        return Effect(self.com_object.AddTriggerEffect(*arguments))

    def addtriggereffect(self, pShape=None, effectId=None, trigger=None, pTriggerShape=None, bookmark=None, Level=None):
        """Alias for AddTriggerEffect"""
        arguments = [pShape, effectId, trigger, pTriggerShape, bookmark, Level]
        return self.AddTriggerEffect(*arguments)

    def add_trigger_effect(self, pShape=None, effectId=None, trigger=None, pTriggerShape=None, bookmark=None, Level=None):
        """Alias for AddTriggerEffect"""
        arguments = [pShape, effectId, trigger, pTriggerShape, bookmark, Level]
        return self.AddTriggerEffect(*arguments)

    def Clone(self, Effect=None, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Effect, Index]])
        return Effect(self.com_object.Clone(*arguments))

    def clone(self, Effect=None, Index=None):
        """Alias for Clone"""
        arguments = [Effect, Index]
        return self.Clone(*arguments)

    def ConvertToAfterEffect(self, Effect=None, After=None, DimColor=None, DimSchemeColor=None):
        arguments = com_arguments([unwrap(a) for a in [Effect, After, DimColor, DimSchemeColor]])
        return Effect(self.com_object.ConvertToAfterEffect(*arguments))

    def converttoaftereffect(self, Effect=None, After=None, DimColor=None, DimSchemeColor=None):
        """Alias for ConvertToAfterEffect"""
        arguments = [Effect, After, DimColor, DimSchemeColor]
        return self.ConvertToAfterEffect(*arguments)

    def convert_to_after_effect(self, Effect=None, After=None, DimColor=None, DimSchemeColor=None):
        """Alias for ConvertToAfterEffect"""
        arguments = [Effect, After, DimColor, DimSchemeColor]
        return self.ConvertToAfterEffect(*arguments)

    def ConvertToAnimateBackground(self, Effect=None, AnimateBackground=None):
        arguments = com_arguments([unwrap(a) for a in [Effect, AnimateBackground]])
        return Effect(self.com_object.ConvertToAnimateBackground(*arguments))

    def converttoanimatebackground(self, Effect=None, AnimateBackground=None):
        """Alias for ConvertToAnimateBackground"""
        arguments = [Effect, AnimateBackground]
        return self.ConvertToAnimateBackground(*arguments)

    def convert_to_animate_background(self, Effect=None, AnimateBackground=None):
        """Alias for ConvertToAnimateBackground"""
        arguments = [Effect, AnimateBackground]
        return self.ConvertToAnimateBackground(*arguments)

    def ConvertToAnimateInReverse(self, Effect=None, animateInReverse=None):
        arguments = com_arguments([unwrap(a) for a in [Effect, animateInReverse]])
        return Effect(self.com_object.ConvertToAnimateInReverse(*arguments))

    def converttoanimateinreverse(self, Effect=None, animateInReverse=None):
        """Alias for ConvertToAnimateInReverse"""
        arguments = [Effect, animateInReverse]
        return self.ConvertToAnimateInReverse(*arguments)

    def convert_to_animate_in_reverse(self, Effect=None, animateInReverse=None):
        """Alias for ConvertToAnimateInReverse"""
        arguments = [Effect, animateInReverse]
        return self.ConvertToAnimateInReverse(*arguments)

    def ConvertToBuildLevel(self, Effect=None, Level=None):
        arguments = com_arguments([unwrap(a) for a in [Effect, Level]])
        return Effect(self.com_object.ConvertToBuildLevel(*arguments))

    def converttobuildlevel(self, Effect=None, Level=None):
        """Alias for ConvertToBuildLevel"""
        arguments = [Effect, Level]
        return self.ConvertToBuildLevel(*arguments)

    def convert_to_build_level(self, Effect=None, Level=None):
        """Alias for ConvertToBuildLevel"""
        arguments = [Effect, Level]
        return self.ConvertToBuildLevel(*arguments)

    def ConvertToTextUnitEffect(self, Effect=None, unitEffect=None):
        arguments = com_arguments([unwrap(a) for a in [Effect, unitEffect]])
        return Effect(self.com_object.ConvertToTextUnitEffect(*arguments))

    def converttotextuniteffect(self, Effect=None, unitEffect=None):
        """Alias for ConvertToTextUnitEffect"""
        arguments = [Effect, unitEffect]
        return self.ConvertToTextUnitEffect(*arguments)

    def convert_to_text_unit_effect(self, Effect=None, unitEffect=None):
        """Alias for ConvertToTextUnitEffect"""
        arguments = [Effect, unitEffect]
        return self.ConvertToTextUnitEffect(*arguments)

    def FindFirstAnimationFor(self, Shape=None):
        arguments = com_arguments([unwrap(a) for a in [Shape]])
        return Effect(self.com_object.FindFirstAnimationFor(*arguments))

    def findfirstanimationfor(self, Shape=None):
        """Alias for FindFirstAnimationFor"""
        arguments = [Shape]
        return self.FindFirstAnimationFor(*arguments)

    def find_first_animation_for(self, Shape=None):
        """Alias for FindFirstAnimationFor"""
        arguments = [Shape]
        return self.FindFirstAnimationFor(*arguments)

    def FindFirstAnimationForClick(self, click=None):
        arguments = com_arguments([unwrap(a) for a in [click]])
        return Effect(self.com_object.FindFirstAnimationForClick(*arguments))

    def findfirstanimationforclick(self, click=None):
        """Alias for FindFirstAnimationForClick"""
        arguments = [click]
        return self.FindFirstAnimationForClick(*arguments)

    def find_first_animation_for_click(self, click=None):
        """Alias for FindFirstAnimationForClick"""
        arguments = [click]
        return self.FindFirstAnimationForClick(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Effect(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Sequences:

    def __init__(self, sequences=None):
        self.com_object= sequences

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Sequence(self.com_object.Add(*arguments))

    def add(self, Index=None):
        """Alias for Add"""
        arguments = [Index]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Sequence(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Series:

    def __init__(self, series=None):
        self.com_object= series

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ApplyPictToEnd(self):
        return self.com_object.ApplyPictToEnd

    @ApplyPictToEnd.setter
    def ApplyPictToEnd(self, value):
        self.com_object.ApplyPictToEnd = value

    @property
    def applypicttoend(self):
        """Alias for ApplyPictToEnd"""
        return self.ApplyPictToEnd

    @applypicttoend.setter
    def applypicttoend(self, value):
        """Alias for ApplyPictToEnd.setter"""
        self.ApplyPictToEnd = value

    @property
    def apply_pict_to_end(self):
        """Alias for ApplyPictToEnd"""
        return self.ApplyPictToEnd

    @apply_pict_to_end.setter
    def apply_pict_to_end(self, value):
        """Alias for ApplyPictToEnd.setter"""
        self.ApplyPictToEnd = value

    @property
    def ApplyPictToFront(self):
        return self.com_object.ApplyPictToFront

    @ApplyPictToFront.setter
    def ApplyPictToFront(self, value):
        self.com_object.ApplyPictToFront = value

    @property
    def applypicttofront(self):
        """Alias for ApplyPictToFront"""
        return self.ApplyPictToFront

    @applypicttofront.setter
    def applypicttofront(self, value):
        """Alias for ApplyPictToFront.setter"""
        self.ApplyPictToFront = value

    @property
    def apply_pict_to_front(self):
        """Alias for ApplyPictToFront"""
        return self.ApplyPictToFront

    @apply_pict_to_front.setter
    def apply_pict_to_front(self, value):
        """Alias for ApplyPictToFront.setter"""
        self.ApplyPictToFront = value

    @property
    def ApplyPictToSides(self):
        return self.com_object.ApplyPictToSides

    @ApplyPictToSides.setter
    def ApplyPictToSides(self, value):
        self.com_object.ApplyPictToSides = value

    @property
    def applypicttosides(self):
        """Alias for ApplyPictToSides"""
        return self.ApplyPictToSides

    @applypicttosides.setter
    def applypicttosides(self, value):
        """Alias for ApplyPictToSides.setter"""
        self.ApplyPictToSides = value

    @property
    def apply_pict_to_sides(self):
        """Alias for ApplyPictToSides"""
        return self.ApplyPictToSides

    @apply_pict_to_sides.setter
    def apply_pict_to_sides(self, value):
        """Alias for ApplyPictToSides.setter"""
        self.ApplyPictToSides = value

    @property
    def AxisGroup(self):
        return XlAxisGroup(self.com_object.AxisGroup)

    @AxisGroup.setter
    def AxisGroup(self, value):
        self.com_object.AxisGroup = value

    @property
    def axisgroup(self):
        """Alias for AxisGroup"""
        return self.AxisGroup

    @axisgroup.setter
    def axisgroup(self, value):
        """Alias for AxisGroup.setter"""
        self.AxisGroup = value

    @property
    def axis_group(self):
        """Alias for AxisGroup"""
        return self.AxisGroup

    @axis_group.setter
    def axis_group(self, value):
        """Alias for AxisGroup.setter"""
        self.AxisGroup = value

    @property
    def BarShape(self):
        return XlBarShape(self.com_object.BarShape)

    @BarShape.setter
    def BarShape(self, value):
        self.com_object.BarShape = value

    @property
    def barshape(self):
        """Alias for BarShape"""
        return self.BarShape

    @barshape.setter
    def barshape(self, value):
        """Alias for BarShape.setter"""
        self.BarShape = value

    @property
    def bar_shape(self):
        """Alias for BarShape"""
        return self.BarShape

    @bar_shape.setter
    def bar_shape(self, value):
        """Alias for BarShape.setter"""
        self.BarShape = value

    @property
    def BubbleSizes(self):
        return self.com_object.BubbleSizes

    @BubbleSizes.setter
    def BubbleSizes(self, value):
        self.com_object.BubbleSizes = value

    @property
    def bubblesizes(self):
        """Alias for BubbleSizes"""
        return self.BubbleSizes

    @bubblesizes.setter
    def bubblesizes(self, value):
        """Alias for BubbleSizes.setter"""
        self.BubbleSizes = value

    @property
    def bubble_sizes(self):
        """Alias for BubbleSizes"""
        return self.BubbleSizes

    @bubble_sizes.setter
    def bubble_sizes(self, value):
        """Alias for BubbleSizes.setter"""
        self.BubbleSizes = value

    @property
    def ChartType(self):
        return self.com_object.ChartType

    @ChartType.setter
    def ChartType(self, value):
        self.com_object.ChartType = value

    @property
    def charttype(self):
        """Alias for ChartType"""
        return self.ChartType

    @charttype.setter
    def charttype(self, value):
        """Alias for ChartType.setter"""
        self.ChartType = value

    @property
    def chart_type(self):
        """Alias for ChartType"""
        return self.ChartType

    @chart_type.setter
    def chart_type(self, value):
        """Alias for ChartType.setter"""
        self.ChartType = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ErrorBars(self):
        return ErrorBars(self.com_object.ErrorBars)

    @property
    def errorbars(self):
        """Alias for ErrorBars"""
        return self.ErrorBars

    @property
    def error_bars(self):
        """Alias for ErrorBars"""
        return self.ErrorBars

    @property
    def Explosion(self):
        return self.com_object.Explosion

    @Explosion.setter
    def Explosion(self, value):
        self.com_object.Explosion = value

    @property
    def explosion(self):
        """Alias for Explosion"""
        return self.Explosion

    @explosion.setter
    def explosion(self, value):
        """Alias for Explosion.setter"""
        self.Explosion = value

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def FormulaLocal(self):
        return self.com_object.FormulaLocal

    @FormulaLocal.setter
    def FormulaLocal(self, value):
        self.com_object.FormulaLocal = value

    @property
    def formulalocal(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formulalocal.setter
    def formulalocal(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def formula_local(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formula_local.setter
    def formula_local(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def FormulaR1C1(self):
        return self.com_object.FormulaR1C1

    @FormulaR1C1.setter
    def FormulaR1C1(self, value):
        self.com_object.FormulaR1C1 = value

    @property
    def formular1c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formular1c1.setter
    def formular1c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def formula_r1_c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formula_r1_c1.setter
    def formula_r1_c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def FormulaR1C1Local(self):
        return self.com_object.FormulaR1C1Local

    @FormulaR1C1Local.setter
    def FormulaR1C1Local(self, value):
        self.com_object.FormulaR1C1Local = value

    @property
    def formular1c1local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formular1c1local.setter
    def formular1c1local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def formula_r1_c1_local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formula_r1_c1_local.setter
    def formula_r1_c1_local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def Has3DEffect(self):
        return self.com_object.Has3DEffect

    @Has3DEffect.setter
    def Has3DEffect(self, value):
        self.com_object.Has3DEffect = value

    @property
    def has3deffect(self):
        """Alias for Has3DEffect"""
        return self.Has3DEffect

    @has3deffect.setter
    def has3deffect(self, value):
        """Alias for Has3DEffect.setter"""
        self.Has3DEffect = value

    @property
    def has3_d_effect(self):
        """Alias for Has3DEffect"""
        return self.Has3DEffect

    @has3_d_effect.setter
    def has3_d_effect(self, value):
        """Alias for Has3DEffect.setter"""
        self.Has3DEffect = value

    @property
    def HasDataLabels(self):
        return self.com_object.HasDataLabels

    @HasDataLabels.setter
    def HasDataLabels(self, value):
        self.com_object.HasDataLabels = value

    @property
    def hasdatalabels(self):
        """Alias for HasDataLabels"""
        return self.HasDataLabels

    @hasdatalabels.setter
    def hasdatalabels(self, value):
        """Alias for HasDataLabels.setter"""
        self.HasDataLabels = value

    @property
    def has_data_labels(self):
        """Alias for HasDataLabels"""
        return self.HasDataLabels

    @has_data_labels.setter
    def has_data_labels(self, value):
        """Alias for HasDataLabels.setter"""
        self.HasDataLabels = value

    @property
    def HasErrorBars(self):
        return self.com_object.HasErrorBars

    @HasErrorBars.setter
    def HasErrorBars(self, value):
        self.com_object.HasErrorBars = value

    @property
    def haserrorbars(self):
        """Alias for HasErrorBars"""
        return self.HasErrorBars

    @haserrorbars.setter
    def haserrorbars(self, value):
        """Alias for HasErrorBars.setter"""
        self.HasErrorBars = value

    @property
    def has_error_bars(self):
        """Alias for HasErrorBars"""
        return self.HasErrorBars

    @has_error_bars.setter
    def has_error_bars(self, value):
        """Alias for HasErrorBars.setter"""
        self.HasErrorBars = value

    @property
    def HasLeaderLines(self):
        return self.com_object.HasLeaderLines

    @HasLeaderLines.setter
    def HasLeaderLines(self, value):
        self.com_object.HasLeaderLines = value

    @property
    def hasleaderlines(self):
        """Alias for HasLeaderLines"""
        return self.HasLeaderLines

    @hasleaderlines.setter
    def hasleaderlines(self, value):
        """Alias for HasLeaderLines.setter"""
        self.HasLeaderLines = value

    @property
    def has_leader_lines(self):
        """Alias for HasLeaderLines"""
        return self.HasLeaderLines

    @has_leader_lines.setter
    def has_leader_lines(self, value):
        """Alias for HasLeaderLines.setter"""
        self.HasLeaderLines = value

    @property
    def InvertColor(self):
        return self.com_object.InvertColor

    @InvertColor.setter
    def InvertColor(self, value):
        self.com_object.InvertColor = value

    @property
    def invertcolor(self):
        """Alias for InvertColor"""
        return self.InvertColor

    @invertcolor.setter
    def invertcolor(self, value):
        """Alias for InvertColor.setter"""
        self.InvertColor = value

    @property
    def invert_color(self):
        """Alias for InvertColor"""
        return self.InvertColor

    @invert_color.setter
    def invert_color(self, value):
        """Alias for InvertColor.setter"""
        self.InvertColor = value

    @property
    def InvertColorIndex(self):
        return self.com_object.InvertColorIndex

    @InvertColorIndex.setter
    def InvertColorIndex(self, value):
        self.com_object.InvertColorIndex = value

    @property
    def invertcolorindex(self):
        """Alias for InvertColorIndex"""
        return self.InvertColorIndex

    @invertcolorindex.setter
    def invertcolorindex(self, value):
        """Alias for InvertColorIndex.setter"""
        self.InvertColorIndex = value

    @property
    def invert_color_index(self):
        """Alias for InvertColorIndex"""
        return self.InvertColorIndex

    @invert_color_index.setter
    def invert_color_index(self, value):
        """Alias for InvertColorIndex.setter"""
        self.InvertColorIndex = value

    @property
    def InvertIfNegative(self):
        return self.com_object.InvertIfNegative

    @InvertIfNegative.setter
    def InvertIfNegative(self, value):
        self.com_object.InvertIfNegative = value

    @property
    def invertifnegative(self):
        """Alias for InvertIfNegative"""
        return self.InvertIfNegative

    @invertifnegative.setter
    def invertifnegative(self, value):
        """Alias for InvertIfNegative.setter"""
        self.InvertIfNegative = value

    @property
    def invert_if_negative(self):
        """Alias for InvertIfNegative"""
        return self.InvertIfNegative

    @invert_if_negative.setter
    def invert_if_negative(self, value):
        """Alias for InvertIfNegative.setter"""
        self.InvertIfNegative = value

    @property
    def IsFiltered(self):
        return self.com_object.IsFiltered

    @IsFiltered.setter
    def IsFiltered(self, value):
        self.com_object.IsFiltered = value

    @property
    def isfiltered(self):
        """Alias for IsFiltered"""
        return self.IsFiltered

    @isfiltered.setter
    def isfiltered(self, value):
        """Alias for IsFiltered.setter"""
        self.IsFiltered = value

    @property
    def is_filtered(self):
        """Alias for IsFiltered"""
        return self.IsFiltered

    @is_filtered.setter
    def is_filtered(self, value):
        """Alias for IsFiltered.setter"""
        self.IsFiltered = value

    @property
    def LeaderLines(self):
        return LeaderLines(self.com_object.LeaderLines)

    @property
    def leaderlines(self):
        """Alias for LeaderLines"""
        return self.LeaderLines

    @property
    def leader_lines(self):
        """Alias for LeaderLines"""
        return self.LeaderLines

    @property
    def MarkerBackgroundColor(self):
        return self.com_object.MarkerBackgroundColor

    @MarkerBackgroundColor.setter
    def MarkerBackgroundColor(self, value):
        self.com_object.MarkerBackgroundColor = value

    @property
    def markerbackgroundcolor(self):
        """Alias for MarkerBackgroundColor"""
        return self.MarkerBackgroundColor

    @markerbackgroundcolor.setter
    def markerbackgroundcolor(self, value):
        """Alias for MarkerBackgroundColor.setter"""
        self.MarkerBackgroundColor = value

    @property
    def marker_background_color(self):
        """Alias for MarkerBackgroundColor"""
        return self.MarkerBackgroundColor

    @marker_background_color.setter
    def marker_background_color(self, value):
        """Alias for MarkerBackgroundColor.setter"""
        self.MarkerBackgroundColor = value

    @property
    def MarkerBackgroundColorIndex(self):
        return XlColorIndex(self.com_object.MarkerBackgroundColorIndex)

    @MarkerBackgroundColorIndex.setter
    def MarkerBackgroundColorIndex(self, value):
        self.com_object.MarkerBackgroundColorIndex = value

    @property
    def markerbackgroundcolorindex(self):
        """Alias for MarkerBackgroundColorIndex"""
        return self.MarkerBackgroundColorIndex

    @markerbackgroundcolorindex.setter
    def markerbackgroundcolorindex(self, value):
        """Alias for MarkerBackgroundColorIndex.setter"""
        self.MarkerBackgroundColorIndex = value

    @property
    def marker_background_color_index(self):
        """Alias for MarkerBackgroundColorIndex"""
        return self.MarkerBackgroundColorIndex

    @marker_background_color_index.setter
    def marker_background_color_index(self, value):
        """Alias for MarkerBackgroundColorIndex.setter"""
        self.MarkerBackgroundColorIndex = value

    @property
    def MarkerForegroundColor(self):
        return self.com_object.MarkerForegroundColor

    @MarkerForegroundColor.setter
    def MarkerForegroundColor(self, value):
        self.com_object.MarkerForegroundColor = value

    @property
    def markerforegroundcolor(self):
        """Alias for MarkerForegroundColor"""
        return self.MarkerForegroundColor

    @markerforegroundcolor.setter
    def markerforegroundcolor(self, value):
        """Alias for MarkerForegroundColor.setter"""
        self.MarkerForegroundColor = value

    @property
    def marker_foreground_color(self):
        """Alias for MarkerForegroundColor"""
        return self.MarkerForegroundColor

    @marker_foreground_color.setter
    def marker_foreground_color(self, value):
        """Alias for MarkerForegroundColor.setter"""
        self.MarkerForegroundColor = value

    @property
    def MarkerForegroundColorIndex(self):
        return XlColorIndex(self.com_object.MarkerForegroundColorIndex)

    @MarkerForegroundColorIndex.setter
    def MarkerForegroundColorIndex(self, value):
        self.com_object.MarkerForegroundColorIndex = value

    @property
    def markerforegroundcolorindex(self):
        """Alias for MarkerForegroundColorIndex"""
        return self.MarkerForegroundColorIndex

    @markerforegroundcolorindex.setter
    def markerforegroundcolorindex(self, value):
        """Alias for MarkerForegroundColorIndex.setter"""
        self.MarkerForegroundColorIndex = value

    @property
    def marker_foreground_color_index(self):
        """Alias for MarkerForegroundColorIndex"""
        return self.MarkerForegroundColorIndex

    @marker_foreground_color_index.setter
    def marker_foreground_color_index(self, value):
        """Alias for MarkerForegroundColorIndex.setter"""
        self.MarkerForegroundColorIndex = value

    @property
    def MarkerSize(self):
        return self.com_object.MarkerSize

    @MarkerSize.setter
    def MarkerSize(self, value):
        self.com_object.MarkerSize = value

    @property
    def markersize(self):
        """Alias for MarkerSize"""
        return self.MarkerSize

    @markersize.setter
    def markersize(self, value):
        """Alias for MarkerSize.setter"""
        self.MarkerSize = value

    @property
    def marker_size(self):
        """Alias for MarkerSize"""
        return self.MarkerSize

    @marker_size.setter
    def marker_size(self, value):
        """Alias for MarkerSize.setter"""
        self.MarkerSize = value

    @property
    def MarkerStyle(self):
        return XlMarkerStyle(self.com_object.MarkerStyle)

    @MarkerStyle.setter
    def MarkerStyle(self, value):
        self.com_object.MarkerStyle = value

    @property
    def markerstyle(self):
        """Alias for MarkerStyle"""
        return self.MarkerStyle

    @markerstyle.setter
    def markerstyle(self, value):
        """Alias for MarkerStyle.setter"""
        self.MarkerStyle = value

    @property
    def marker_style(self):
        """Alias for MarkerStyle"""
        return self.MarkerStyle

    @marker_style.setter
    def marker_style(self, value):
        """Alias for MarkerStyle.setter"""
        self.MarkerStyle = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ParentDataLabelOption(self):
        return self.com_object.ParentDataLabelOption

    @ParentDataLabelOption.setter
    def ParentDataLabelOption(self, value):
        self.com_object.ParentDataLabelOption = value

    @property
    def parentdatalabeloption(self):
        """Alias for ParentDataLabelOption"""
        return self.ParentDataLabelOption

    @parentdatalabeloption.setter
    def parentdatalabeloption(self, value):
        """Alias for ParentDataLabelOption.setter"""
        self.ParentDataLabelOption = value

    @property
    def parent_data_label_option(self):
        """Alias for ParentDataLabelOption"""
        return self.ParentDataLabelOption

    @parent_data_label_option.setter
    def parent_data_label_option(self, value):
        """Alias for ParentDataLabelOption.setter"""
        self.ParentDataLabelOption = value

    @property
    def PictureType(self):
        return XlChartPictureType(self.com_object.PictureType)

    @PictureType.setter
    def PictureType(self, value):
        self.com_object.PictureType = value

    @property
    def picturetype(self):
        """Alias for PictureType"""
        return self.PictureType

    @picturetype.setter
    def picturetype(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def picture_type(self):
        """Alias for PictureType"""
        return self.PictureType

    @picture_type.setter
    def picture_type(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def PictureUnit2(self):
        return self.com_object.PictureUnit2

    @PictureUnit2.setter
    def PictureUnit2(self, value):
        self.com_object.PictureUnit2 = value

    @property
    def pictureunit2(self):
        """Alias for PictureUnit2"""
        return self.PictureUnit2

    @pictureunit2.setter
    def pictureunit2(self, value):
        """Alias for PictureUnit2.setter"""
        self.PictureUnit2 = value

    @property
    def picture_unit2(self):
        """Alias for PictureUnit2"""
        return self.PictureUnit2

    @picture_unit2.setter
    def picture_unit2(self, value):
        """Alias for PictureUnit2.setter"""
        self.PictureUnit2 = value

    @property
    def PlotColorIndex(self):
        return self.com_object.PlotColorIndex

    @property
    def plotcolorindex(self):
        """Alias for PlotColorIndex"""
        return self.PlotColorIndex

    @property
    def plot_color_index(self):
        """Alias for PlotColorIndex"""
        return self.PlotColorIndex

    @property
    def PlotOrder(self):
        return self.com_object.PlotOrder

    @PlotOrder.setter
    def PlotOrder(self, value):
        self.com_object.PlotOrder = value

    @property
    def plotorder(self):
        """Alias for PlotOrder"""
        return self.PlotOrder

    @plotorder.setter
    def plotorder(self, value):
        """Alias for PlotOrder.setter"""
        self.PlotOrder = value

    @property
    def plot_order(self):
        """Alias for PlotOrder"""
        return self.PlotOrder

    @plot_order.setter
    def plot_order(self, value):
        """Alias for PlotOrder.setter"""
        self.PlotOrder = value

    @property
    def QuartileCalculationInclusiveMedian(self):
        return self.com_object.QuartileCalculationInclusiveMedian

    @QuartileCalculationInclusiveMedian.setter
    def QuartileCalculationInclusiveMedian(self, value):
        self.com_object.QuartileCalculationInclusiveMedian = value

    @property
    def quartilecalculationinclusivemedian(self):
        """Alias for QuartileCalculationInclusiveMedian"""
        return self.QuartileCalculationInclusiveMedian

    @quartilecalculationinclusivemedian.setter
    def quartilecalculationinclusivemedian(self, value):
        """Alias for QuartileCalculationInclusiveMedian.setter"""
        self.QuartileCalculationInclusiveMedian = value

    @property
    def quartile_calculation_inclusive_median(self):
        """Alias for QuartileCalculationInclusiveMedian"""
        return self.QuartileCalculationInclusiveMedian

    @quartile_calculation_inclusive_median.setter
    def quartile_calculation_inclusive_median(self, value):
        """Alias for QuartileCalculationInclusiveMedian.setter"""
        self.QuartileCalculationInclusiveMedian = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Smooth(self):
        return self.com_object.Smooth

    @Smooth.setter
    def Smooth(self, value):
        self.com_object.Smooth = value

    @property
    def smooth(self):
        """Alias for Smooth"""
        return self.Smooth

    @smooth.setter
    def smooth(self, value):
        """Alias for Smooth.setter"""
        self.Smooth = value

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    @property
    def Values(self):
        return self.com_object.Values

    @Values.setter
    def Values(self, value):
        self.com_object.Values = value

    @property
    def values(self):
        """Alias for Values"""
        return self.Values

    @values.setter
    def values(self, value):
        """Alias for Values.setter"""
        self.Values = value

    @property
    def XValues(self):
        return self.com_object.XValues

    @XValues.setter
    def XValues(self, value):
        self.com_object.XValues = value

    @property
    def xvalues(self):
        """Alias for XValues"""
        return self.XValues

    @xvalues.setter
    def xvalues(self, value):
        """Alias for XValues.setter"""
        self.XValues = value

    @property
    def x_values(self):
        """Alias for XValues"""
        return self.XValues

    @x_values.setter
    def x_values(self, value):
        """Alias for XValues.setter"""
        self.XValues = value

    def ApplyDataLabels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        arguments = com_arguments([unwrap(a) for a in [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]])
        self.com_object.ApplyDataLabels(*arguments)

    def applydatalabels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        """Alias for ApplyDataLabels"""
        arguments = [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]
        return self.ApplyDataLabels(*arguments)

    def apply_data_labels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        """Alias for ApplyDataLabels"""
        arguments = [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]
        return self.ApplyDataLabels(*arguments)

    def ClearFormats(self):
        self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def DataLabels(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return DataLabel(self.com_object.DataLabels(*arguments))

    def datalabels(self, Index=None):
        """Alias for DataLabels"""
        arguments = [Index]
        return self.DataLabels(*arguments)

    def data_labels(self, Index=None):
        """Alias for DataLabels"""
        arguments = [Index]
        return self.DataLabels(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def ErrorBar(self, Direction=None, Include=None, Type=None, Amount=None, MinusValues=None):
        arguments = com_arguments([unwrap(a) for a in [Direction, Include, Type, Amount, MinusValues]])
        self.com_object.ErrorBar(*arguments)

    def errorbar(self, Direction=None, Include=None, Type=None, Amount=None, MinusValues=None):
        """Alias for ErrorBar"""
        arguments = [Direction, Include, Type, Amount, MinusValues]
        return self.ErrorBar(*arguments)

    def error_bar(self, Direction=None, Include=None, Type=None, Amount=None, MinusValues=None):
        """Alias for ErrorBar"""
        arguments = [Direction, Include, Type, Amount, MinusValues]
        return self.ErrorBar(*arguments)

    def Paste(self):
        self.com_object.Paste()

    def paste(self):
        """Alias for Paste"""
        return self.Paste()

    def Points(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Points(self.com_object.Points(*arguments))

    def points(self, Index=None):
        """Alias for Points"""
        arguments = [Index]
        return self.Points(*arguments)

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()

    def Trendlines(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Trendlines(self.com_object.Trendlines(*arguments))

    def trendlines(self, Index=None):
        """Alias for Trendlines"""
        arguments = [Index]
        return self.Trendlines(*arguments)


class SeriesCollection:

    def __init__(self, seriescollection=None):
        self.com_object= seriescollection

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Source=None, Rowcol=None, SeriesLabels=None, CategoryLabels=None, Replace=None):
        arguments = com_arguments([unwrap(a) for a in [Source, Rowcol, SeriesLabels, CategoryLabels, Replace]])
        return Series(self.com_object.Add(*arguments))

    def add(self, Source=None, Rowcol=None, SeriesLabels=None, CategoryLabels=None, Replace=None):
        """Alias for Add"""
        arguments = [Source, Rowcol, SeriesLabels, CategoryLabels, Replace]
        return self.Add(*arguments)

    def Extend(self, Source=None, Rowcol=None, CategoryLabels=None):
        arguments = com_arguments([unwrap(a) for a in [Source, Rowcol, CategoryLabels]])
        self.com_object.Extend(*arguments)

    def extend(self, Source=None, Rowcol=None, CategoryLabels=None):
        """Alias for Extend"""
        arguments = [Source, Rowcol, CategoryLabels]
        return self.Extend(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Series(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def NewSeries(self):
        return Series(self.com_object.NewSeries())

    def newseries(self):
        """Alias for NewSeries"""
        return self.NewSeries()

    def new_series(self):
        """Alias for NewSeries"""
        return self.NewSeries()


class SeriesLines:

    def __init__(self, serieslines=None):
        self.com_object= serieslines

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Border(self):
        return ChartBorder(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class SetEffect:

    def __init__(self, seteffect=None):
        self.com_object= seteffect

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Property(self):
        return self.com_object.Property

    @Property.setter
    def Property(self, value):
        self.com_object.Property = value

    @property
    def To(self):
        return self.com_object.To

    @To.setter
    def To(self, value):
        self.com_object.To = value

    @property
    def to(self):
        """Alias for To"""
        return self.To

    @to.setter
    def to(self, value):
        """Alias for To.setter"""
        self.To = value


class ShadowFormat:

    def __init__(self, shadowformat=None):
        self.com_object= shadowformat

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Blur(self):
        return self.com_object.Blur

    @Blur.setter
    def Blur(self, value):
        self.com_object.Blur = value

    @property
    def blur(self):
        """Alias for Blur"""
        return self.Blur

    @blur.setter
    def blur(self, value):
        """Alias for Blur.setter"""
        self.Blur = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ForeColor(self):
        return ColorFormat(self.com_object.ForeColor)

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def Obscured(self):
        return self.com_object.Obscured

    @Obscured.setter
    def Obscured(self, value):
        self.com_object.Obscured = value

    @property
    def obscured(self):
        """Alias for Obscured"""
        return self.Obscured

    @obscured.setter
    def obscured(self, value):
        """Alias for Obscured.setter"""
        self.Obscured = value

    @property
    def OffsetX(self):
        return self.com_object.OffsetX

    @OffsetX.setter
    def OffsetX(self, value):
        self.com_object.OffsetX = value

    @property
    def offsetx(self):
        """Alias for OffsetX"""
        return self.OffsetX

    @offsetx.setter
    def offsetx(self, value):
        """Alias for OffsetX.setter"""
        self.OffsetX = value

    @property
    def offset_x(self):
        """Alias for OffsetX"""
        return self.OffsetX

    @offset_x.setter
    def offset_x(self, value):
        """Alias for OffsetX.setter"""
        self.OffsetX = value

    @property
    def OffsetY(self):
        return self.com_object.OffsetY

    @OffsetY.setter
    def OffsetY(self, value):
        self.com_object.OffsetY = value

    @property
    def offsety(self):
        """Alias for OffsetY"""
        return self.OffsetY

    @offsety.setter
    def offsety(self, value):
        """Alias for OffsetY.setter"""
        self.OffsetY = value

    @property
    def offset_y(self):
        """Alias for OffsetY"""
        return self.OffsetY

    @offset_y.setter
    def offset_y(self, value):
        """Alias for OffsetY.setter"""
        self.OffsetY = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RotateWithShape(self):
        return self.com_object.RotateWithShape

    @RotateWithShape.setter
    def RotateWithShape(self, value):
        self.com_object.RotateWithShape = value

    @property
    def rotatewithshape(self):
        """Alias for RotateWithShape"""
        return self.RotateWithShape

    @rotatewithshape.setter
    def rotatewithshape(self, value):
        """Alias for RotateWithShape.setter"""
        self.RotateWithShape = value

    @property
    def rotate_with_shape(self):
        """Alias for RotateWithShape"""
        return self.RotateWithShape

    @rotate_with_shape.setter
    def rotate_with_shape(self, value):
        """Alias for RotateWithShape.setter"""
        self.RotateWithShape = value

    @property
    def Size(self):
        return self.com_object.Size

    @Size.setter
    def Size(self, value):
        self.com_object.Size = value

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @size.setter
    def size(self, value):
        """Alias for Size.setter"""
        self.Size = value

    @property
    def Style(self):
        return self.com_object.Style

    @Style.setter
    def Style(self, value):
        self.com_object.Style = value

    @property
    def style(self):
        """Alias for Style"""
        return self.Style

    @style.setter
    def style(self, value):
        """Alias for Style.setter"""
        self.Style = value

    @property
    def Transparency(self):
        return self.com_object.Transparency

    @Transparency.setter
    def Transparency(self, value):
        self.com_object.Transparency = value

    @property
    def transparency(self):
        """Alias for Transparency"""
        return self.Transparency

    @transparency.setter
    def transparency(self, value):
        """Alias for Transparency.setter"""
        self.Transparency = value

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    def IncrementOffsetX(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementOffsetX(*arguments)

    def incrementoffsetx(self, Increment=None):
        """Alias for IncrementOffsetX"""
        arguments = [Increment]
        return self.IncrementOffsetX(*arguments)

    def increment_offset_x(self, Increment=None):
        """Alias for IncrementOffsetX"""
        arguments = [Increment]
        return self.IncrementOffsetX(*arguments)

    def IncrementOffsetY(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementOffsetY(*arguments)

    def incrementoffsety(self, Increment=None):
        """Alias for IncrementOffsetY"""
        arguments = [Increment]
        return self.IncrementOffsetY(*arguments)

    def increment_offset_y(self, Increment=None):
        """Alias for IncrementOffsetY"""
        arguments = [Increment]
        return self.IncrementOffsetY(*arguments)


class Shape:

    def __init__(self, shape=None):
        self.com_object= shape

    @property
    def ActionSettings(self):
        return ActionSettings(self.com_object.ActionSettings)

    @property
    def actionsettings(self):
        """Alias for ActionSettings"""
        return self.ActionSettings

    @property
    def action_settings(self):
        """Alias for ActionSettings"""
        return self.ActionSettings

    @property
    def Adjustments(self):
        return Adjustments(self.com_object.Adjustments)

    @property
    def adjustments(self):
        """Alias for Adjustments"""
        return self.Adjustments

    @property
    def AlternativeText(self):
        return self.com_object.AlternativeText

    @AlternativeText.setter
    def AlternativeText(self, value):
        self.com_object.AlternativeText = value

    @property
    def alternativetext(self):
        """Alias for AlternativeText"""
        return self.AlternativeText

    @alternativetext.setter
    def alternativetext(self, value):
        """Alias for AlternativeText.setter"""
        self.AlternativeText = value

    @property
    def alternative_text(self):
        """Alias for AlternativeText"""
        return self.AlternativeText

    @alternative_text.setter
    def alternative_text(self, value):
        """Alias for AlternativeText.setter"""
        self.AlternativeText = value

    @property
    def AnimationSettings(self):
        return AnimationSettings(self.com_object.AnimationSettings)

    @property
    def animationsettings(self):
        """Alias for AnimationSettings"""
        return self.AnimationSettings

    @property
    def animation_settings(self):
        """Alias for AnimationSettings"""
        return self.AnimationSettings

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoShapeType(self):
        return Shape(self.com_object.AutoShapeType)

    @AutoShapeType.setter
    def AutoShapeType(self, value):
        self.com_object.AutoShapeType = value

    @property
    def autoshapetype(self):
        """Alias for AutoShapeType"""
        return self.AutoShapeType

    @autoshapetype.setter
    def autoshapetype(self, value):
        """Alias for AutoShapeType.setter"""
        self.AutoShapeType = value

    @property
    def auto_shape_type(self):
        """Alias for AutoShapeType"""
        return self.AutoShapeType

    @auto_shape_type.setter
    def auto_shape_type(self, value):
        """Alias for AutoShapeType.setter"""
        self.AutoShapeType = value

    @property
    def BackgroundStyle(self):
        return self.com_object.BackgroundStyle

    @BackgroundStyle.setter
    def BackgroundStyle(self, value):
        self.com_object.BackgroundStyle = value

    @property
    def backgroundstyle(self):
        """Alias for BackgroundStyle"""
        return self.BackgroundStyle

    @backgroundstyle.setter
    def backgroundstyle(self, value):
        """Alias for BackgroundStyle.setter"""
        self.BackgroundStyle = value

    @property
    def background_style(self):
        """Alias for BackgroundStyle"""
        return self.BackgroundStyle

    @background_style.setter
    def background_style(self, value):
        """Alias for BackgroundStyle.setter"""
        self.BackgroundStyle = value

    @property
    def BlackWhiteMode(self):
        return self.com_object.BlackWhiteMode

    @BlackWhiteMode.setter
    def BlackWhiteMode(self, value):
        self.com_object.BlackWhiteMode = value

    @property
    def blackwhitemode(self):
        """Alias for BlackWhiteMode"""
        return self.BlackWhiteMode

    @blackwhitemode.setter
    def blackwhitemode(self, value):
        """Alias for BlackWhiteMode.setter"""
        self.BlackWhiteMode = value

    @property
    def black_white_mode(self):
        """Alias for BlackWhiteMode"""
        return self.BlackWhiteMode

    @black_white_mode.setter
    def black_white_mode(self, value):
        """Alias for BlackWhiteMode.setter"""
        self.BlackWhiteMode = value

    @property
    def Callout(self):
        return CalloutFormat(self.com_object.Callout)

    @property
    def callout(self):
        """Alias for Callout"""
        return self.Callout

    @property
    def Chart(self):
        return Chart(self.com_object.Chart)

    @property
    def chart(self):
        """Alias for Chart"""
        return self.Chart

    @property
    def Child(self):
        return self.com_object.Child

    @property
    def child(self):
        """Alias for Child"""
        return self.Child

    @property
    def ConnectionSiteCount(self):
        return self.com_object.ConnectionSiteCount

    @property
    def connectionsitecount(self):
        """Alias for ConnectionSiteCount"""
        return self.ConnectionSiteCount

    @property
    def connection_site_count(self):
        """Alias for ConnectionSiteCount"""
        return self.ConnectionSiteCount

    @property
    def Connector(self):
        return self.com_object.Connector

    @property
    def connector(self):
        """Alias for Connector"""
        return self.Connector

    @property
    def ConnectorFormat(self):
        return ConnectorFormat(self.com_object.ConnectorFormat)

    @property
    def connectorformat(self):
        """Alias for ConnectorFormat"""
        return self.ConnectorFormat

    @property
    def connector_format(self):
        """Alias for ConnectorFormat"""
        return self.ConnectorFormat

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def CustomerData(self):
        return CustomerData(self.com_object.CustomerData)

    @property
    def customerdata(self):
        """Alias for CustomerData"""
        return self.CustomerData

    @property
    def customer_data(self):
        """Alias for CustomerData"""
        return self.CustomerData

    @property
    def Decorative(self):
        return self.com_object.Decorative

    @Decorative.setter
    def Decorative(self, value):
        self.com_object.Decorative = value

    @property
    def decorative(self):
        """Alias for Decorative"""
        return self.Decorative

    @decorative.setter
    def decorative(self, value):
        """Alias for Decorative.setter"""
        self.Decorative = value

    @property
    def Fill(self):
        return FillFormat(self.com_object.Fill)

    @property
    def fill(self):
        """Alias for Fill"""
        return self.Fill

    @property
    def Glow(self):
        return self.com_object.Glow

    @property
    def glow(self):
        """Alias for Glow"""
        return self.Glow

    @property
    def GraphicStyle(self):
        return self.com_object.GraphicStyle

    @GraphicStyle.setter
    def GraphicStyle(self, value):
        self.com_object.GraphicStyle = value

    @property
    def graphicstyle(self):
        """Alias for GraphicStyle"""
        return self.GraphicStyle

    @graphicstyle.setter
    def graphicstyle(self, value):
        """Alias for GraphicStyle.setter"""
        self.GraphicStyle = value

    @property
    def graphic_style(self):
        """Alias for GraphicStyle"""
        return self.GraphicStyle

    @graphic_style.setter
    def graphic_style(self, value):
        """Alias for GraphicStyle.setter"""
        self.GraphicStyle = value

    @property
    def GroupItems(self):
        return GroupShapes(self.com_object.GroupItems)

    @property
    def groupitems(self):
        """Alias for GroupItems"""
        return self.GroupItems

    @property
    def group_items(self):
        """Alias for GroupItems"""
        return self.GroupItems

    @property
    def HasChart(self):
        return self.com_object.HasChart

    @property
    def haschart(self):
        """Alias for HasChart"""
        return self.HasChart

    @property
    def has_chart(self):
        """Alias for HasChart"""
        return self.HasChart

    @property
    def HasInkXML(self):
        return self.com_object.HasInkXML

    @property
    def hasinkxml(self):
        """Alias for HasInkXML"""
        return self.HasInkXML

    @property
    def has_ink_x_m_l(self):
        """Alias for HasInkXML"""
        return self.HasInkXML

    @property
    def HasSmartArt(self):
        return self.com_object.HasSmartArt

    @property
    def hassmartart(self):
        """Alias for HasSmartArt"""
        return self.HasSmartArt

    @property
    def has_smart_art(self):
        """Alias for HasSmartArt"""
        return self.HasSmartArt

    @property
    def HasTable(self):
        return self.com_object.HasTable

    @property
    def hastable(self):
        """Alias for HasTable"""
        return self.HasTable

    @property
    def has_table(self):
        """Alias for HasTable"""
        return self.HasTable

    @property
    def HasTextFrame(self):
        return self.com_object.HasTextFrame

    @property
    def hastextframe(self):
        """Alias for HasTextFrame"""
        return self.HasTextFrame

    @property
    def has_text_frame(self):
        """Alias for HasTextFrame"""
        return self.HasTextFrame

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HorizontalFlip(self):
        return self.com_object.HorizontalFlip

    @property
    def horizontalflip(self):
        """Alias for HorizontalFlip"""
        return self.HorizontalFlip

    @property
    def horizontal_flip(self):
        """Alias for HorizontalFlip"""
        return self.HorizontalFlip

    @property
    def Id(self):
        return self.com_object.Id

    @property
    def id(self):
        """Alias for Id"""
        return self.Id

    @property
    def InkXML(self):
        return self.com_object.InkXML

    @property
    def inkxml(self):
        """Alias for InkXML"""
        return self.InkXML

    @property
    def ink_x_m_l(self):
        """Alias for InkXML"""
        return self.InkXML

    @property
    def IsNarration(self):
        return self.com_object.IsNarration

    @IsNarration.setter
    def IsNarration(self, value):
        self.com_object.IsNarration = value

    @property
    def isnarration(self):
        """Alias for IsNarration"""
        return self.IsNarration

    @isnarration.setter
    def isnarration(self, value):
        """Alias for IsNarration.setter"""
        self.IsNarration = value

    @property
    def is_narration(self):
        """Alias for IsNarration"""
        return self.IsNarration

    @is_narration.setter
    def is_narration(self, value):
        """Alias for IsNarration.setter"""
        self.IsNarration = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Line(self):
        return LineFormat(self.com_object.Line)

    @property
    def line(self):
        """Alias for Line"""
        return self.Line

    @property
    def LinkFormat(self):
        return LinkFormat(self.com_object.LinkFormat)

    @property
    def linkformat(self):
        """Alias for LinkFormat"""
        return self.LinkFormat

    @property
    def link_format(self):
        """Alias for LinkFormat"""
        return self.LinkFormat

    @property
    def LockAspectRatio(self):
        return self.com_object.LockAspectRatio

    @LockAspectRatio.setter
    def LockAspectRatio(self, value):
        self.com_object.LockAspectRatio = value

    @property
    def lockaspectratio(self):
        """Alias for LockAspectRatio"""
        return self.LockAspectRatio

    @lockaspectratio.setter
    def lockaspectratio(self, value):
        """Alias for LockAspectRatio.setter"""
        self.LockAspectRatio = value

    @property
    def lock_aspect_ratio(self):
        """Alias for LockAspectRatio"""
        return self.LockAspectRatio

    @lock_aspect_ratio.setter
    def lock_aspect_ratio(self, value):
        """Alias for LockAspectRatio.setter"""
        self.LockAspectRatio = value

    @property
    def MediaFormat(self):
        return self.com_object.MediaFormat

    @property
    def mediaformat(self):
        """Alias for MediaFormat"""
        return self.MediaFormat

    @property
    def media_format(self):
        """Alias for MediaFormat"""
        return self.MediaFormat

    @property
    def MediaType(self):
        return self.com_object.MediaType

    @property
    def mediatype(self):
        """Alias for MediaType"""
        return self.MediaType

    @property
    def media_type(self):
        """Alias for MediaType"""
        return self.MediaType

    @property
    def Model3D(self):
        return Model3DFormat(self.com_object.Model3D)

    @property
    def model3d(self):
        """Alias for Model3D"""
        return self.Model3D

    @property
    def model3_d(self):
        """Alias for Model3D"""
        return self.Model3D

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Nodes(self):
        return ShapeNodes(self.com_object.Nodes)

    @property
    def nodes(self):
        """Alias for Nodes"""
        return self.Nodes

    @property
    def OLEFormat(self):
        return OLEFormat(self.com_object.OLEFormat)

    @property
    def oleformat(self):
        """Alias for OLEFormat"""
        return self.OLEFormat

    @property
    def o_l_e_format(self):
        """Alias for OLEFormat"""
        return self.OLEFormat

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ParentGroup(self):
        return Shape(self.com_object.ParentGroup)

    @property
    def parentgroup(self):
        """Alias for ParentGroup"""
        return self.ParentGroup

    @property
    def parent_group(self):
        """Alias for ParentGroup"""
        return self.ParentGroup

    @property
    def PictureFormat(self):
        return PictureFormat(self.com_object.PictureFormat)

    @property
    def pictureformat(self):
        """Alias for PictureFormat"""
        return self.PictureFormat

    @property
    def picture_format(self):
        """Alias for PictureFormat"""
        return self.PictureFormat

    @property
    def PlaceholderFormat(self):
        return PlaceholderFormat(self.com_object.PlaceholderFormat)

    @property
    def placeholderformat(self):
        """Alias for PlaceholderFormat"""
        return self.PlaceholderFormat

    @property
    def placeholder_format(self):
        """Alias for PlaceholderFormat"""
        return self.PlaceholderFormat

    @property
    def Reflection(self):
        return self.com_object.Reflection

    @property
    def reflection(self):
        """Alias for Reflection"""
        return self.Reflection

    @property
    def Rotation(self):
        return self.com_object.Rotation

    @Rotation.setter
    def Rotation(self, value):
        self.com_object.Rotation = value

    @property
    def rotation(self):
        """Alias for Rotation"""
        return self.Rotation

    @rotation.setter
    def rotation(self, value):
        """Alias for Rotation.setter"""
        self.Rotation = value

    @property
    def Shadow(self):
        return ShadowFormat(self.com_object.Shadow)

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @property
    def ShapeStyle(self):
        return self.com_object.ShapeStyle

    @ShapeStyle.setter
    def ShapeStyle(self, value):
        self.com_object.ShapeStyle = value

    @property
    def shapestyle(self):
        """Alias for ShapeStyle"""
        return self.ShapeStyle

    @shapestyle.setter
    def shapestyle(self, value):
        """Alias for ShapeStyle.setter"""
        self.ShapeStyle = value

    @property
    def shape_style(self):
        """Alias for ShapeStyle"""
        return self.ShapeStyle

    @shape_style.setter
    def shape_style(self, value):
        """Alias for ShapeStyle.setter"""
        self.ShapeStyle = value

    @property
    def SmartArt(self):
        return Shape(self.com_object.SmartArt)

    @property
    def smartart(self):
        """Alias for SmartArt"""
        return self.SmartArt

    @property
    def smart_art(self):
        """Alias for SmartArt"""
        return self.SmartArt

    @property
    def SoftEdge(self):
        return self.com_object.SoftEdge

    @property
    def softedge(self):
        """Alias for SoftEdge"""
        return self.SoftEdge

    @property
    def soft_edge(self):
        """Alias for SoftEdge"""
        return self.SoftEdge

    @property
    def Table(self):
        return Table(self.com_object.Table)

    @property
    def table(self):
        """Alias for Table"""
        return self.Table

    @property
    def Tags(self):
        return Tags(self.com_object.Tags)

    @property
    def tags(self):
        """Alias for Tags"""
        return self.Tags

    @property
    def TextEffect(self):
        return TextEffectFormat(self.com_object.TextEffect)

    @property
    def texteffect(self):
        """Alias for TextEffect"""
        return self.TextEffect

    @property
    def text_effect(self):
        """Alias for TextEffect"""
        return self.TextEffect

    @property
    def TextFrame(self):
        return TextFrame(self.com_object.TextFrame)

    @property
    def textframe(self):
        """Alias for TextFrame"""
        return self.TextFrame

    @property
    def text_frame(self):
        """Alias for TextFrame"""
        return self.TextFrame

    @property
    def TextFrame2(self):
        return TextFrame2(self.com_object.TextFrame2)

    @property
    def textframe2(self):
        """Alias for TextFrame2"""
        return self.TextFrame2

    @property
    def text_frame2(self):
        """Alias for TextFrame2"""
        return self.TextFrame2

    @property
    def ThreeD(self):
        return ThreeDFormat(self.com_object.ThreeD)

    @property
    def threed(self):
        """Alias for ThreeD"""
        return self.ThreeD

    @property
    def three_d(self):
        """Alias for ThreeD"""
        return self.ThreeD

    @property
    def Title(self):
        return Shape(self.com_object.Title)

    @property
    def title(self):
        """Alias for Title"""
        return self.Title

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def Type(self):
        return self.com_object.Type

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def VerticalFlip(self):
        return self.com_object.VerticalFlip

    @property
    def verticalflip(self):
        """Alias for VerticalFlip"""
        return self.VerticalFlip

    @property
    def vertical_flip(self):
        """Alias for VerticalFlip"""
        return self.VerticalFlip

    @property
    def Vertices(self):
        return self.com_object.Vertices

    @property
    def vertices(self):
        """Alias for Vertices"""
        return self.Vertices

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def ZOrderPosition(self):
        return self.com_object.ZOrderPosition

    @property
    def zorderposition(self):
        """Alias for ZOrderPosition"""
        return self.ZOrderPosition

    @property
    def z_order_position(self):
        """Alias for ZOrderPosition"""
        return self.ZOrderPosition

    def Apply(self):
        self.com_object.Apply()

    def apply(self):
        """Alias for Apply"""
        return self.Apply()

    def ApplyAnimation(self):
        self.com_object.ApplyAnimation()

    def applyanimation(self):
        """Alias for ApplyAnimation"""
        return self.ApplyAnimation()

    def apply_animation(self):
        """Alias for ApplyAnimation"""
        return self.ApplyAnimation()

    def ConvertTextToSmartArt(self, Layout=None):
        arguments = com_arguments([unwrap(a) for a in [Layout]])
        self.com_object.ConvertTextToSmartArt(*arguments)

    def converttexttosmartart(self, Layout=None):
        """Alias for ConvertTextToSmartArt"""
        arguments = [Layout]
        return self.ConvertTextToSmartArt(*arguments)

    def convert_text_to_smart_art(self, Layout=None):
        """Alias for ConvertTextToSmartArt"""
        arguments = [Layout]
        return self.ConvertTextToSmartArt(*arguments)

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Cut(self):
        self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Duplicate(self):
        return ShapeRange(self.com_object.Duplicate())

    def duplicate(self):
        """Alias for Duplicate"""
        return self.Duplicate()

    def Flip(self, FlipCmd=None):
        arguments = com_arguments([unwrap(a) for a in [FlipCmd]])
        self.com_object.Flip(*arguments)

    def flip(self, FlipCmd=None):
        """Alias for Flip"""
        arguments = [FlipCmd]
        return self.Flip(*arguments)

    def IncrementLeft(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementLeft(*arguments)

    def incrementleft(self, Increment=None):
        """Alias for IncrementLeft"""
        arguments = [Increment]
        return self.IncrementLeft(*arguments)

    def increment_left(self, Increment=None):
        """Alias for IncrementLeft"""
        arguments = [Increment]
        return self.IncrementLeft(*arguments)

    def IncrementRotation(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotation(*arguments)

    def incrementrotation(self, Increment=None):
        """Alias for IncrementRotation"""
        arguments = [Increment]
        return self.IncrementRotation(*arguments)

    def increment_rotation(self, Increment=None):
        """Alias for IncrementRotation"""
        arguments = [Increment]
        return self.IncrementRotation(*arguments)

    def IncrementTop(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementTop(*arguments)

    def incrementtop(self, Increment=None):
        """Alias for IncrementTop"""
        arguments = [Increment]
        return self.IncrementTop(*arguments)

    def increment_top(self, Increment=None):
        """Alias for IncrementTop"""
        arguments = [Increment]
        return self.IncrementTop(*arguments)

    def PickUp(self):
        self.com_object.PickUp()

    def pickup(self):
        """Alias for PickUp"""
        return self.PickUp()

    def pick_up(self):
        """Alias for PickUp"""
        return self.PickUp()

    def PickupAnimation(self):
        self.com_object.PickupAnimation()

    def pickupanimation(self):
        """Alias for PickupAnimation"""
        return self.PickupAnimation()

    def pickup_animation(self):
        """Alias for PickupAnimation"""
        return self.PickupAnimation()

    def RerouteConnections(self):
        self.com_object.RerouteConnections()

    def rerouteconnections(self):
        """Alias for RerouteConnections"""
        return self.RerouteConnections()

    def reroute_connections(self):
        """Alias for RerouteConnections"""
        return self.RerouteConnections()

    def ScaleHeight(self, Factor=None, RelativeToOriginalSize=None, fScale=None):
        arguments = com_arguments([unwrap(a) for a in [Factor, RelativeToOriginalSize, fScale]])
        self.com_object.ScaleHeight(*arguments)

    def scaleheight(self, Factor=None, RelativeToOriginalSize=None, fScale=None):
        """Alias for ScaleHeight"""
        arguments = [Factor, RelativeToOriginalSize, fScale]
        return self.ScaleHeight(*arguments)

    def scale_height(self, Factor=None, RelativeToOriginalSize=None, fScale=None):
        """Alias for ScaleHeight"""
        arguments = [Factor, RelativeToOriginalSize, fScale]
        return self.ScaleHeight(*arguments)

    def ScaleWidth(self, Factor=None, RelativeToOriginalSize=None, fScale=None):
        arguments = com_arguments([unwrap(a) for a in [Factor, RelativeToOriginalSize, fScale]])
        self.com_object.ScaleWidth(*arguments)

    def scalewidth(self, Factor=None, RelativeToOriginalSize=None, fScale=None):
        """Alias for ScaleWidth"""
        arguments = [Factor, RelativeToOriginalSize, fScale]
        return self.ScaleWidth(*arguments)

    def scale_width(self, Factor=None, RelativeToOriginalSize=None, fScale=None):
        """Alias for ScaleWidth"""
        arguments = [Factor, RelativeToOriginalSize, fScale]
        return self.ScaleWidth(*arguments)

    def Select(self, Replace=None):
        arguments = com_arguments([unwrap(a) for a in [Replace]])
        self.com_object.Select(*arguments)

    def select(self, Replace=None):
        """Alias for Select"""
        arguments = [Replace]
        return self.Select(*arguments)

    def SetShapesDefaultProperties(self):
        self.com_object.SetShapesDefaultProperties()

    def setshapesdefaultproperties(self):
        """Alias for SetShapesDefaultProperties"""
        return self.SetShapesDefaultProperties()

    def set_shapes_default_properties(self):
        """Alias for SetShapesDefaultProperties"""
        return self.SetShapesDefaultProperties()

    def Ungroup(self):
        return ShapeRange(self.com_object.Ungroup())

    def ungroup(self):
        """Alias for Ungroup"""
        return self.Ungroup()

    def UpgradeMedia(self):
        self.com_object.UpgradeMedia()

    def upgrademedia(self):
        """Alias for UpgradeMedia"""
        return self.UpgradeMedia()

    def upgrade_media(self):
        """Alias for UpgradeMedia"""
        return self.UpgradeMedia()

    def ZOrder(self, ZOrderCmd=None):
        arguments = com_arguments([unwrap(a) for a in [ZOrderCmd]])
        self.com_object.ZOrder(*arguments)

    def zorder(self, ZOrderCmd=None):
        """Alias for ZOrder"""
        arguments = [ZOrderCmd]
        return self.ZOrder(*arguments)

    def z_order(self, ZOrderCmd=None):
        """Alias for ZOrder"""
        arguments = [ZOrderCmd]
        return self.ZOrder(*arguments)


class ShapeNode:

    def __init__(self, shapenode=None):
        self.com_object= shapenode

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def EditingType(self):
        return self.com_object.EditingType

    @property
    def editingtype(self):
        """Alias for EditingType"""
        return self.EditingType

    @property
    def editing_type(self):
        """Alias for EditingType"""
        return self.EditingType

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Points(self):
        return self.com_object.Points

    @property
    def points(self):
        """Alias for Points"""
        return self.Points

    @property
    def SegmentType(self):
        return self.com_object.SegmentType

    @property
    def segmenttype(self):
        """Alias for SegmentType"""
        return self.SegmentType

    @property
    def segment_type(self):
        """Alias for SegmentType"""
        return self.SegmentType


class ShapeNodes:

    def __init__(self, shapenodes=None):
        self.com_object= shapenodes

    def __call__(self, item):
        return ShapeNode(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Delete(*arguments)

    def delete(self, Index=None):
        """Alias for Delete"""
        arguments = [Index]
        return self.Delete(*arguments)

    def Insert(self, Index=None, SegmentType=None, EditingType=None, X1=None, Y1=None, X2=None, Y2=None, X3=None, Y3=None):
        arguments = com_arguments([unwrap(a) for a in [Index, SegmentType, EditingType, X1, Y1, X2, Y2, X3, Y3]])
        self.com_object.Insert(*arguments)

    def insert(self, Index=None, SegmentType=None, EditingType=None, X1=None, Y1=None, X2=None, Y2=None, X3=None, Y3=None):
        """Alias for Insert"""
        arguments = [Index, SegmentType, EditingType, X1, Y1, X2, Y2, X3, Y3]
        return self.Insert(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ShapeNode(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def SetEditingType(self, Index=None, EditingType=None):
        arguments = com_arguments([unwrap(a) for a in [Index, EditingType]])
        self.com_object.SetEditingType(*arguments)

    def seteditingtype(self, Index=None, EditingType=None):
        """Alias for SetEditingType"""
        arguments = [Index, EditingType]
        return self.SetEditingType(*arguments)

    def set_editing_type(self, Index=None, EditingType=None):
        """Alias for SetEditingType"""
        arguments = [Index, EditingType]
        return self.SetEditingType(*arguments)

    def SetPosition(self, Index=None, X1=None, Y1=None):
        arguments = com_arguments([unwrap(a) for a in [Index, X1, Y1]])
        self.com_object.SetPosition(*arguments)

    def setposition(self, Index=None, X1=None, Y1=None):
        """Alias for SetPosition"""
        arguments = [Index, X1, Y1]
        return self.SetPosition(*arguments)

    def set_position(self, Index=None, X1=None, Y1=None):
        """Alias for SetPosition"""
        arguments = [Index, X1, Y1]
        return self.SetPosition(*arguments)

    def SetSegmentType(self, Index=None, SegmentType=None):
        arguments = com_arguments([unwrap(a) for a in [Index, SegmentType]])
        self.com_object.SetSegmentType(*arguments)

    def setsegmenttype(self, Index=None, SegmentType=None):
        """Alias for SetSegmentType"""
        arguments = [Index, SegmentType]
        return self.SetSegmentType(*arguments)

    def set_segment_type(self, Index=None, SegmentType=None):
        """Alias for SetSegmentType"""
        arguments = [Index, SegmentType]
        return self.SetSegmentType(*arguments)


class ShapeRange:

    def __init__(self, shaperange=None):
        self.com_object= shaperange

    @property
    def ActionSettings(self):
        return ActionSettings(self.com_object.ActionSettings)

    @property
    def actionsettings(self):
        """Alias for ActionSettings"""
        return self.ActionSettings

    @property
    def action_settings(self):
        """Alias for ActionSettings"""
        return self.ActionSettings

    @property
    def Adjustments(self):
        return Adjustments(self.com_object.Adjustments)

    @property
    def adjustments(self):
        """Alias for Adjustments"""
        return self.Adjustments

    @property
    def AlternativeText(self):
        return self.com_object.AlternativeText

    @AlternativeText.setter
    def AlternativeText(self, value):
        self.com_object.AlternativeText = value

    @property
    def alternativetext(self):
        """Alias for AlternativeText"""
        return self.AlternativeText

    @alternativetext.setter
    def alternativetext(self, value):
        """Alias for AlternativeText.setter"""
        self.AlternativeText = value

    @property
    def alternative_text(self):
        """Alias for AlternativeText"""
        return self.AlternativeText

    @alternative_text.setter
    def alternative_text(self, value):
        """Alias for AlternativeText.setter"""
        self.AlternativeText = value

    @property
    def AnimationSettings(self):
        return AnimationSettings(self.com_object.AnimationSettings)

    @property
    def animationsettings(self):
        """Alias for AnimationSettings"""
        return self.AnimationSettings

    @property
    def animation_settings(self):
        """Alias for AnimationSettings"""
        return self.AnimationSettings

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoShapeType(self):
        return ShapeRange(self.com_object.AutoShapeType)

    @AutoShapeType.setter
    def AutoShapeType(self, value):
        self.com_object.AutoShapeType = value

    @property
    def autoshapetype(self):
        """Alias for AutoShapeType"""
        return self.AutoShapeType

    @autoshapetype.setter
    def autoshapetype(self, value):
        """Alias for AutoShapeType.setter"""
        self.AutoShapeType = value

    @property
    def auto_shape_type(self):
        """Alias for AutoShapeType"""
        return self.AutoShapeType

    @auto_shape_type.setter
    def auto_shape_type(self, value):
        """Alias for AutoShapeType.setter"""
        self.AutoShapeType = value

    @property
    def BackgroundStyle(self):
        return self.com_object.BackgroundStyle

    @BackgroundStyle.setter
    def BackgroundStyle(self, value):
        self.com_object.BackgroundStyle = value

    @property
    def backgroundstyle(self):
        """Alias for BackgroundStyle"""
        return self.BackgroundStyle

    @backgroundstyle.setter
    def backgroundstyle(self, value):
        """Alias for BackgroundStyle.setter"""
        self.BackgroundStyle = value

    @property
    def background_style(self):
        """Alias for BackgroundStyle"""
        return self.BackgroundStyle

    @background_style.setter
    def background_style(self, value):
        """Alias for BackgroundStyle.setter"""
        self.BackgroundStyle = value

    @property
    def BlackWhiteMode(self):
        return self.com_object.BlackWhiteMode

    @BlackWhiteMode.setter
    def BlackWhiteMode(self, value):
        self.com_object.BlackWhiteMode = value

    @property
    def blackwhitemode(self):
        """Alias for BlackWhiteMode"""
        return self.BlackWhiteMode

    @blackwhitemode.setter
    def blackwhitemode(self, value):
        """Alias for BlackWhiteMode.setter"""
        self.BlackWhiteMode = value

    @property
    def black_white_mode(self):
        """Alias for BlackWhiteMode"""
        return self.BlackWhiteMode

    @black_white_mode.setter
    def black_white_mode(self, value):
        """Alias for BlackWhiteMode.setter"""
        self.BlackWhiteMode = value

    @property
    def Callout(self):
        return CalloutFormat(self.com_object.Callout)

    @property
    def callout(self):
        """Alias for Callout"""
        return self.Callout

    @property
    def Chart(self):
        return Chart(self.com_object.Chart)

    @property
    def chart(self):
        """Alias for Chart"""
        return self.Chart

    @property
    def Child(self):
        return self.com_object.Child

    @property
    def child(self):
        """Alias for Child"""
        return self.Child

    @property
    def ConnectionSiteCount(self):
        return self.com_object.ConnectionSiteCount

    @property
    def connectionsitecount(self):
        """Alias for ConnectionSiteCount"""
        return self.ConnectionSiteCount

    @property
    def connection_site_count(self):
        """Alias for ConnectionSiteCount"""
        return self.ConnectionSiteCount

    @property
    def Connector(self):
        return self.com_object.Connector

    @property
    def connector(self):
        """Alias for Connector"""
        return self.Connector

    @property
    def ConnectorFormat(self):
        return ConnectorFormat(self.com_object.ConnectorFormat)

    @property
    def connectorformat(self):
        """Alias for ConnectorFormat"""
        return self.ConnectorFormat

    @property
    def connector_format(self):
        """Alias for ConnectorFormat"""
        return self.ConnectorFormat

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def CustomerData(self):
        return CustomerData(self.com_object.CustomerData)

    @property
    def customerdata(self):
        """Alias for CustomerData"""
        return self.CustomerData

    @property
    def customer_data(self):
        """Alias for CustomerData"""
        return self.CustomerData

    @property
    def Decorative(self):
        return self.com_object.Decorative

    @Decorative.setter
    def Decorative(self, value):
        self.com_object.Decorative = value

    @property
    def decorative(self):
        """Alias for Decorative"""
        return self.Decorative

    @decorative.setter
    def decorative(self, value):
        """Alias for Decorative.setter"""
        self.Decorative = value

    @property
    def Fill(self):
        return FillFormat(self.com_object.Fill)

    @property
    def fill(self):
        """Alias for Fill"""
        return self.Fill

    @property
    def Glow(self):
        return self.com_object.Glow

    @property
    def glow(self):
        """Alias for Glow"""
        return self.Glow

    @property
    def GraphicStyle(self):
        return self.com_object.GraphicStyle

    @GraphicStyle.setter
    def GraphicStyle(self, value):
        self.com_object.GraphicStyle = value

    @property
    def graphicstyle(self):
        """Alias for GraphicStyle"""
        return self.GraphicStyle

    @graphicstyle.setter
    def graphicstyle(self, value):
        """Alias for GraphicStyle.setter"""
        self.GraphicStyle = value

    @property
    def graphic_style(self):
        """Alias for GraphicStyle"""
        return self.GraphicStyle

    @graphic_style.setter
    def graphic_style(self, value):
        """Alias for GraphicStyle.setter"""
        self.GraphicStyle = value

    @property
    def GroupItems(self):
        return GroupShapes(self.com_object.GroupItems)

    @property
    def groupitems(self):
        """Alias for GroupItems"""
        return self.GroupItems

    @property
    def group_items(self):
        """Alias for GroupItems"""
        return self.GroupItems

    @property
    def HasChart(self):
        return self.com_object.HasChart

    @property
    def haschart(self):
        """Alias for HasChart"""
        return self.HasChart

    @property
    def has_chart(self):
        """Alias for HasChart"""
        return self.HasChart

    @property
    def HasInkXML(self):
        return self.com_object.HasInkXML

    @property
    def hasinkxml(self):
        """Alias for HasInkXML"""
        return self.HasInkXML

    @property
    def has_ink_x_m_l(self):
        """Alias for HasInkXML"""
        return self.HasInkXML

    @property
    def HasSmartArt(self):
        return self.com_object.HasSmartArt

    @property
    def hassmartart(self):
        """Alias for HasSmartArt"""
        return self.HasSmartArt

    @property
    def has_smart_art(self):
        """Alias for HasSmartArt"""
        return self.HasSmartArt

    @property
    def HasTable(self):
        return self.com_object.HasTable

    @property
    def hastable(self):
        """Alias for HasTable"""
        return self.HasTable

    @property
    def has_table(self):
        """Alias for HasTable"""
        return self.HasTable

    @property
    def HasTextFrame(self):
        return self.com_object.HasTextFrame

    @property
    def hastextframe(self):
        """Alias for HasTextFrame"""
        return self.HasTextFrame

    @property
    def has_text_frame(self):
        """Alias for HasTextFrame"""
        return self.HasTextFrame

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HorizontalFlip(self):
        return self.com_object.HorizontalFlip

    @property
    def horizontalflip(self):
        """Alias for HorizontalFlip"""
        return self.HorizontalFlip

    @property
    def horizontal_flip(self):
        """Alias for HorizontalFlip"""
        return self.HorizontalFlip

    @property
    def Id(self):
        return self.com_object.Id

    @property
    def id(self):
        """Alias for Id"""
        return self.Id

    @property
    def InkXML(self):
        return self.com_object.InkXML

    @property
    def inkxml(self):
        """Alias for InkXML"""
        return self.InkXML

    @property
    def ink_x_m_l(self):
        """Alias for InkXML"""
        return self.InkXML

    @property
    def IsNarration(self):
        return self.com_object.IsNarration

    @IsNarration.setter
    def IsNarration(self, value):
        self.com_object.IsNarration = value

    @property
    def isnarration(self):
        """Alias for IsNarration"""
        return self.IsNarration

    @isnarration.setter
    def isnarration(self, value):
        """Alias for IsNarration.setter"""
        self.IsNarration = value

    @property
    def is_narration(self):
        """Alias for IsNarration"""
        return self.IsNarration

    @is_narration.setter
    def is_narration(self, value):
        """Alias for IsNarration.setter"""
        self.IsNarration = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Line(self):
        return LineFormat(self.com_object.Line)

    @property
    def line(self):
        """Alias for Line"""
        return self.Line

    @property
    def LinkFormat(self):
        return LinkFormat(self.com_object.LinkFormat)

    @property
    def linkformat(self):
        """Alias for LinkFormat"""
        return self.LinkFormat

    @property
    def link_format(self):
        """Alias for LinkFormat"""
        return self.LinkFormat

    @property
    def LockAspectRatio(self):
        return self.com_object.LockAspectRatio

    @LockAspectRatio.setter
    def LockAspectRatio(self, value):
        self.com_object.LockAspectRatio = value

    @property
    def lockaspectratio(self):
        """Alias for LockAspectRatio"""
        return self.LockAspectRatio

    @lockaspectratio.setter
    def lockaspectratio(self, value):
        """Alias for LockAspectRatio.setter"""
        self.LockAspectRatio = value

    @property
    def lock_aspect_ratio(self):
        """Alias for LockAspectRatio"""
        return self.LockAspectRatio

    @lock_aspect_ratio.setter
    def lock_aspect_ratio(self, value):
        """Alias for LockAspectRatio.setter"""
        self.LockAspectRatio = value

    @property
    def MediaFormat(self):
        return MediaFormat(self.com_object.MediaFormat)

    @property
    def mediaformat(self):
        """Alias for MediaFormat"""
        return self.MediaFormat

    @property
    def media_format(self):
        """Alias for MediaFormat"""
        return self.MediaFormat

    @property
    def MediaType(self):
        return self.com_object.MediaType

    @property
    def mediatype(self):
        """Alias for MediaType"""
        return self.MediaType

    @property
    def media_type(self):
        """Alias for MediaType"""
        return self.MediaType

    @property
    def Model3D(self):
        return Model3DFormat(self.com_object.Model3D)

    @property
    def model3d(self):
        """Alias for Model3D"""
        return self.Model3D

    @property
    def model3_d(self):
        """Alias for Model3D"""
        return self.Model3D

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Nodes(self):
        return ShapeNodes(self.com_object.Nodes)

    @property
    def nodes(self):
        """Alias for Nodes"""
        return self.Nodes

    @property
    def OLEFormat(self):
        return OLEFormat(self.com_object.OLEFormat)

    @property
    def oleformat(self):
        """Alias for OLEFormat"""
        return self.OLEFormat

    @property
    def o_l_e_format(self):
        """Alias for OLEFormat"""
        return self.OLEFormat

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ParentGroup(self):
        return Shape(self.com_object.ParentGroup)

    @property
    def parentgroup(self):
        """Alias for ParentGroup"""
        return self.ParentGroup

    @property
    def parent_group(self):
        """Alias for ParentGroup"""
        return self.ParentGroup

    @property
    def PictureFormat(self):
        return PictureFormat(self.com_object.PictureFormat)

    @property
    def pictureformat(self):
        """Alias for PictureFormat"""
        return self.PictureFormat

    @property
    def picture_format(self):
        """Alias for PictureFormat"""
        return self.PictureFormat

    @property
    def PlaceholderFormat(self):
        return PlaceholderFormat(self.com_object.PlaceholderFormat)

    @property
    def placeholderformat(self):
        """Alias for PlaceholderFormat"""
        return self.PlaceholderFormat

    @property
    def placeholder_format(self):
        """Alias for PlaceholderFormat"""
        return self.PlaceholderFormat

    @property
    def Reflection(self):
        return self.com_object.Reflection

    @property
    def reflection(self):
        """Alias for Reflection"""
        return self.Reflection

    @property
    def Rotation(self):
        return self.com_object.Rotation

    @Rotation.setter
    def Rotation(self, value):
        self.com_object.Rotation = value

    @property
    def rotation(self):
        """Alias for Rotation"""
        return self.Rotation

    @rotation.setter
    def rotation(self, value):
        """Alias for Rotation.setter"""
        self.Rotation = value

    @property
    def Shadow(self):
        return ShadowFormat(self.com_object.Shadow)

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @property
    def ShapeStyle(self):
        return self.com_object.ShapeStyle

    @property
    def shapestyle(self):
        """Alias for ShapeStyle"""
        return self.ShapeStyle

    @property
    def shape_style(self):
        """Alias for ShapeStyle"""
        return self.ShapeStyle

    @property
    def SmartArt(self):
        return ShapeRange(self.com_object.SmartArt)

    @property
    def smartart(self):
        """Alias for SmartArt"""
        return self.SmartArt

    @property
    def smart_art(self):
        """Alias for SmartArt"""
        return self.SmartArt

    @property
    def SoftEdge(self):
        return self.com_object.SoftEdge

    @property
    def softedge(self):
        """Alias for SoftEdge"""
        return self.SoftEdge

    @property
    def soft_edge(self):
        """Alias for SoftEdge"""
        return self.SoftEdge

    @property
    def Table(self):
        return Table(self.com_object.Table)

    @property
    def table(self):
        """Alias for Table"""
        return self.Table

    @property
    def Tags(self):
        return Tags(self.com_object.Tags)

    @property
    def tags(self):
        """Alias for Tags"""
        return self.Tags

    @property
    def TextEffect(self):
        return TextEffectFormat(self.com_object.TextEffect)

    @property
    def texteffect(self):
        """Alias for TextEffect"""
        return self.TextEffect

    @property
    def text_effect(self):
        """Alias for TextEffect"""
        return self.TextEffect

    @property
    def TextFrame(self):
        return TextFrame(self.com_object.TextFrame)

    @property
    def textframe(self):
        """Alias for TextFrame"""
        return self.TextFrame

    @property
    def text_frame(self):
        """Alias for TextFrame"""
        return self.TextFrame

    @property
    def TextFrame2(self):
        return TextFrame2(self.com_object.TextFrame2)

    @property
    def textframe2(self):
        """Alias for TextFrame2"""
        return self.TextFrame2

    @property
    def text_frame2(self):
        """Alias for TextFrame2"""
        return self.TextFrame2

    @property
    def ThreeD(self):
        return ThreeDFormat(self.com_object.ThreeD)

    @property
    def threed(self):
        """Alias for ThreeD"""
        return self.ThreeD

    @property
    def three_d(self):
        """Alias for ThreeD"""
        return self.ThreeD

    @property
    def Title(self):
        return Shape(self.com_object.Title)

    @property
    def title(self):
        """Alias for Title"""
        return self.Title

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def Type(self):
        return self.com_object.Type

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def VerticalFlip(self):
        return self.com_object.VerticalFlip

    @property
    def verticalflip(self):
        """Alias for VerticalFlip"""
        return self.VerticalFlip

    @property
    def vertical_flip(self):
        """Alias for VerticalFlip"""
        return self.VerticalFlip

    @property
    def Vertices(self):
        return self.com_object.Vertices

    @property
    def vertices(self):
        """Alias for Vertices"""
        return self.Vertices

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def ZOrderPosition(self):
        return self.com_object.ZOrderPosition

    @property
    def zorderposition(self):
        """Alias for ZOrderPosition"""
        return self.ZOrderPosition

    @property
    def z_order_position(self):
        """Alias for ZOrderPosition"""
        return self.ZOrderPosition

    def Align(self, AlignCmd=None, RelativeTo=None):
        arguments = com_arguments([unwrap(a) for a in [AlignCmd, RelativeTo]])
        self.com_object.Align(*arguments)

    def align(self, AlignCmd=None, RelativeTo=None):
        """Alias for Align"""
        arguments = [AlignCmd, RelativeTo]
        return self.Align(*arguments)

    def Apply(self):
        self.com_object.Apply()

    def apply(self):
        """Alias for Apply"""
        return self.Apply()

    def ApplyAnimation(self):
        self.com_object.ApplyAnimation()

    def applyanimation(self):
        """Alias for ApplyAnimation"""
        return self.ApplyAnimation()

    def apply_animation(self):
        """Alias for ApplyAnimation"""
        return self.ApplyAnimation()

    def ConvertTextToSmartArt(self, Layout=None):
        arguments = com_arguments([unwrap(a) for a in [Layout]])
        return self.com_object.ConvertTextToSmartArt(*arguments)

    def converttexttosmartart(self, Layout=None):
        """Alias for ConvertTextToSmartArt"""
        arguments = [Layout]
        return self.ConvertTextToSmartArt(*arguments)

    def convert_text_to_smart_art(self, Layout=None):
        """Alias for ConvertTextToSmartArt"""
        arguments = [Layout]
        return self.ConvertTextToSmartArt(*arguments)

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Cut(self):
        self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Distribute(self, DistributeCmd=None, RelativeTo=None):
        arguments = com_arguments([unwrap(a) for a in [DistributeCmd, RelativeTo]])
        return self.com_object.Distribute(*arguments)

    def distribute(self, DistributeCmd=None, RelativeTo=None):
        """Alias for Distribute"""
        arguments = [DistributeCmd, RelativeTo]
        return self.Distribute(*arguments)

    def Duplicate(self):
        return ShapeRange(self.com_object.Duplicate())

    def duplicate(self):
        """Alias for Duplicate"""
        return self.Duplicate()

    def Flip(self, FlipCmd=None):
        arguments = com_arguments([unwrap(a) for a in [FlipCmd]])
        self.com_object.Flip(*arguments)

    def flip(self, FlipCmd=None):
        """Alias for Flip"""
        arguments = [FlipCmd]
        return self.Flip(*arguments)

    def Group(self):
        return Shape(self.com_object.Group())

    def group(self):
        """Alias for Group"""
        return self.Group()

    def IncrementLeft(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementLeft(*arguments)

    def incrementleft(self, Increment=None):
        """Alias for IncrementLeft"""
        arguments = [Increment]
        return self.IncrementLeft(*arguments)

    def increment_left(self, Increment=None):
        """Alias for IncrementLeft"""
        arguments = [Increment]
        return self.IncrementLeft(*arguments)

    def IncrementRotation(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotation(*arguments)

    def incrementrotation(self, Increment=None):
        """Alias for IncrementRotation"""
        arguments = [Increment]
        return self.IncrementRotation(*arguments)

    def increment_rotation(self, Increment=None):
        """Alias for IncrementRotation"""
        arguments = [Increment]
        return self.IncrementRotation(*arguments)

    def IncrementTop(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementTop(*arguments)

    def incrementtop(self, Increment=None):
        """Alias for IncrementTop"""
        arguments = [Increment]
        return self.IncrementTop(*arguments)

    def increment_top(self, Increment=None):
        """Alias for IncrementTop"""
        arguments = [Increment]
        return self.IncrementTop(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Shape(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def MergeShapes(self):
        return self.com_object.MergeShapes()

    def mergeshapes(self):
        """Alias for MergeShapes"""
        return self.MergeShapes()

    def merge_shapes(self):
        """Alias for MergeShapes"""
        return self.MergeShapes()

    def PickUp(self):
        self.com_object.PickUp()

    def pickup(self):
        """Alias for PickUp"""
        return self.PickUp()

    def pick_up(self):
        """Alias for PickUp"""
        return self.PickUp()

    def PickupAnimation(self):
        self.com_object.PickupAnimation()

    def pickupanimation(self):
        """Alias for PickupAnimation"""
        return self.PickupAnimation()

    def pickup_animation(self):
        """Alias for PickupAnimation"""
        return self.PickupAnimation()

    def Regroup(self):
        return Shape(self.com_object.Regroup())

    def regroup(self):
        """Alias for Regroup"""
        return self.Regroup()

    def RerouteConnections(self):
        self.com_object.RerouteConnections()

    def rerouteconnections(self):
        """Alias for RerouteConnections"""
        return self.RerouteConnections()

    def reroute_connections(self):
        """Alias for RerouteConnections"""
        return self.RerouteConnections()

    def ScaleHeight(self, Factor=None, RelativeToOriginalSize=None, fScale=None):
        arguments = com_arguments([unwrap(a) for a in [Factor, RelativeToOriginalSize, fScale]])
        return self.com_object.ScaleHeight(*arguments)

    def scaleheight(self, Factor=None, RelativeToOriginalSize=None, fScale=None):
        """Alias for ScaleHeight"""
        arguments = [Factor, RelativeToOriginalSize, fScale]
        return self.ScaleHeight(*arguments)

    def scale_height(self, Factor=None, RelativeToOriginalSize=None, fScale=None):
        """Alias for ScaleHeight"""
        arguments = [Factor, RelativeToOriginalSize, fScale]
        return self.ScaleHeight(*arguments)

    def ScaleWidth(self, Factor=None, RelativeToOriginalSize=None, fScale=None):
        arguments = com_arguments([unwrap(a) for a in [Factor, RelativeToOriginalSize, fScale]])
        self.com_object.ScaleWidth(*arguments)

    def scalewidth(self, Factor=None, RelativeToOriginalSize=None, fScale=None):
        """Alias for ScaleWidth"""
        arguments = [Factor, RelativeToOriginalSize, fScale]
        return self.ScaleWidth(*arguments)

    def scale_width(self, Factor=None, RelativeToOriginalSize=None, fScale=None):
        """Alias for ScaleWidth"""
        arguments = [Factor, RelativeToOriginalSize, fScale]
        return self.ScaleWidth(*arguments)

    def Select(self, Replace=None):
        arguments = com_arguments([unwrap(a) for a in [Replace]])
        self.com_object.Select(*arguments)

    def select(self, Replace=None):
        """Alias for Select"""
        arguments = [Replace]
        return self.Select(*arguments)

    def SetShapesDefaultProperties(self):
        self.com_object.SetShapesDefaultProperties()

    def setshapesdefaultproperties(self):
        """Alias for SetShapesDefaultProperties"""
        return self.SetShapesDefaultProperties()

    def set_shapes_default_properties(self):
        """Alias for SetShapesDefaultProperties"""
        return self.SetShapesDefaultProperties()

    def Ungroup(self):
        return ShapeRange(self.com_object.Ungroup())

    def ungroup(self):
        """Alias for Ungroup"""
        return self.Ungroup()

    def UpgradeMedia(self):
        self.com_object.UpgradeMedia()

    def upgrademedia(self):
        """Alias for UpgradeMedia"""
        return self.UpgradeMedia()

    def upgrade_media(self):
        """Alias for UpgradeMedia"""
        return self.UpgradeMedia()

    def ZOrder(self, ZOrderCmd=None):
        arguments = com_arguments([unwrap(a) for a in [ZOrderCmd]])
        self.com_object.ZOrder(*arguments)

    def zorder(self, ZOrderCmd=None):
        """Alias for ZOrder"""
        arguments = [ZOrderCmd]
        return self.ZOrder(*arguments)

    def z_order(self, ZOrderCmd=None):
        """Alias for ZOrder"""
        arguments = [ZOrderCmd]
        return self.ZOrder(*arguments)


class Shapes:

    def __init__(self, shapes=None):
        self.com_object= shapes

    def __call__(self, item):
        return Shape(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def HasTitle(self):
        return self.com_object.HasTitle

    @property
    def hastitle(self):
        """Alias for HasTitle"""
        return self.HasTitle

    @property
    def has_title(self):
        """Alias for HasTitle"""
        return self.HasTitle

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Placeholders(self):
        return Placeholders(self.com_object.Placeholders)

    @property
    def placeholders(self):
        """Alias for Placeholders"""
        return self.Placeholders

    @property
    def Title(self):
        return Shape(self.com_object.Title)

    @property
    def title(self):
        """Alias for Title"""
        return self.Title

    def Add3DModel(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height]])
        return Shape(self.com_object.Add3DModel(*arguments))

    def add3dmodel(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for Add3DModel"""
        arguments = [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height]
        return self.Add3DModel(*arguments)

    def add3_d_model(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for Add3DModel"""
        arguments = [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height]
        return self.Add3DModel(*arguments)

    def AddCallout(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Left, Top, Width, Height]])
        return Shape(self.com_object.AddCallout(*arguments))

    def addcallout(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddCallout"""
        arguments = [Type, Left, Top, Width, Height]
        return self.AddCallout(*arguments)

    def add_callout(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddCallout"""
        arguments = [Type, Left, Top, Width, Height]
        return self.AddCallout(*arguments)

    def AddChart2(self):
        return SHAPE(self.com_object.AddChart2())

    def addchart2(self):
        """Alias for AddChart2"""
        return self.AddChart2()

    def add_chart2(self):
        """Alias for AddChart2"""
        return self.AddChart2()

    def AddConnector(self, Type=None, BeginX=None, BeginY=None, EndX=None, EndY=None):
        arguments = com_arguments([unwrap(a) for a in [Type, BeginX, BeginY, EndX, EndY]])
        return Shape(self.com_object.AddConnector(*arguments))

    def addconnector(self, Type=None, BeginX=None, BeginY=None, EndX=None, EndY=None):
        """Alias for AddConnector"""
        arguments = [Type, BeginX, BeginY, EndX, EndY]
        return self.AddConnector(*arguments)

    def add_connector(self, Type=None, BeginX=None, BeginY=None, EndX=None, EndY=None):
        """Alias for AddConnector"""
        arguments = [Type, BeginX, BeginY, EndX, EndY]
        return self.AddConnector(*arguments)

    def AddCurve(self, SafeArrayOfPoints=None):
        arguments = com_arguments([unwrap(a) for a in [SafeArrayOfPoints]])
        return Shape(self.com_object.AddCurve(*arguments))

    def addcurve(self, SafeArrayOfPoints=None):
        """Alias for AddCurve"""
        arguments = [SafeArrayOfPoints]
        return self.AddCurve(*arguments)

    def add_curve(self, SafeArrayOfPoints=None):
        """Alias for AddCurve"""
        arguments = [SafeArrayOfPoints]
        return self.AddCurve(*arguments)

    def AddInkShapeFromXML(self, InkXML=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [InkXML, Left, Top, Width, Height]])
        return self.com_object.AddInkShapeFromXML(*arguments)

    def addinkshapefromxml(self, InkXML=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddInkShapeFromXML"""
        arguments = [InkXML, Left, Top, Width, Height]
        return self.AddInkShapeFromXML(*arguments)

    def add_ink_shape_from_x_m_l(self, InkXML=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddInkShapeFromXML"""
        arguments = [InkXML, Left, Top, Width, Height]
        return self.AddInkShapeFromXML(*arguments)

    def AddLabel(self, Orientation=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Orientation, Left, Top, Width, Height]])
        return Shape(self.com_object.AddLabel(*arguments))

    def addlabel(self, Orientation=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddLabel"""
        arguments = [Orientation, Left, Top, Width, Height]
        return self.AddLabel(*arguments)

    def add_label(self, Orientation=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddLabel"""
        arguments = [Orientation, Left, Top, Width, Height]
        return self.AddLabel(*arguments)

    def AddLine(self, BeginX=None, BeginY=None, EndX=None, EndY=None):
        arguments = com_arguments([unwrap(a) for a in [BeginX, BeginY, EndX, EndY]])
        return Shape(self.com_object.AddLine(*arguments))

    def addline(self, BeginX=None, BeginY=None, EndX=None, EndY=None):
        """Alias for AddLine"""
        arguments = [BeginX, BeginY, EndX, EndY]
        return self.AddLine(*arguments)

    def add_line(self, BeginX=None, BeginY=None, EndX=None, EndY=None):
        """Alias for AddLine"""
        arguments = [BeginX, BeginY, EndX, EndY]
        return self.AddLine(*arguments)

    def AddMediaObject(self, FileName=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, Left, Top, Width, Height]])
        return Shape(self.com_object.AddMediaObject(*arguments))

    def addmediaobject(self, FileName=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddMediaObject"""
        arguments = [FileName, Left, Top, Width, Height]
        return self.AddMediaObject(*arguments)

    def add_media_object(self, FileName=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddMediaObject"""
        arguments = [FileName, Left, Top, Width, Height]
        return self.AddMediaObject(*arguments)

    def AddMediaObject2(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height]])
        return Shape(self.com_object.AddMediaObject2(*arguments))

    def addmediaobject2(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddMediaObject2"""
        arguments = [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height]
        return self.AddMediaObject2(*arguments)

    def add_media_object2(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddMediaObject2"""
        arguments = [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height]
        return self.AddMediaObject2(*arguments)

    def AddMediaObjectFromEmbedTag(self, EmbedTag=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [EmbedTag, Left, Top, Width, Height]])
        return Shape(self.com_object.AddMediaObjectFromEmbedTag(*arguments))

    def addmediaobjectfromembedtag(self, EmbedTag=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddMediaObjectFromEmbedTag"""
        arguments = [EmbedTag, Left, Top, Width, Height]
        return self.AddMediaObjectFromEmbedTag(*arguments)

    def add_media_object_from_embed_tag(self, EmbedTag=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddMediaObjectFromEmbedTag"""
        arguments = [EmbedTag, Left, Top, Width, Height]
        return self.AddMediaObjectFromEmbedTag(*arguments)

    def AddOLEObject(self, Left=None, Top=None, Width=None, Height=None, ClassName=None, FileName=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, Link=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height, ClassName, FileName, DisplayAsIcon, IconFileName, IconIndex, IconLabel, Link]])
        return Shape(self.com_object.AddOLEObject(*arguments))

    def addoleobject(self, Left=None, Top=None, Width=None, Height=None, ClassName=None, FileName=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, Link=None):
        """Alias for AddOLEObject"""
        arguments = [Left, Top, Width, Height, ClassName, FileName, DisplayAsIcon, IconFileName, IconIndex, IconLabel, Link]
        return self.AddOLEObject(*arguments)

    def add_o_l_e_object(self, Left=None, Top=None, Width=None, Height=None, ClassName=None, FileName=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, Link=None):
        """Alias for AddOLEObject"""
        arguments = [Left, Top, Width, Height, ClassName, FileName, DisplayAsIcon, IconFileName, IconIndex, IconLabel, Link]
        return self.AddOLEObject(*arguments)

    def AddPicture(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height]])
        return Shape(self.com_object.AddPicture(*arguments))

    def addpicture(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddPicture"""
        arguments = [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height]
        return self.AddPicture(*arguments)

    def add_picture(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddPicture"""
        arguments = [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height]
        return self.AddPicture(*arguments)

    def AddPicture2(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None, compress=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height, compress]])
        return Shape(self.com_object.AddPicture2(*arguments))

    def addpicture2(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None, compress=None):
        """Alias for AddPicture2"""
        arguments = [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height, compress]
        return self.AddPicture2(*arguments)

    def add_picture2(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None, compress=None):
        """Alias for AddPicture2"""
        arguments = [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height, compress]
        return self.AddPicture2(*arguments)

    def AddPlaceholder(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Left, Top, Width, Height]])
        return Shape(self.com_object.AddPlaceholder(*arguments))

    def addplaceholder(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddPlaceholder"""
        arguments = [Type, Left, Top, Width, Height]
        return self.AddPlaceholder(*arguments)

    def add_placeholder(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddPlaceholder"""
        arguments = [Type, Left, Top, Width, Height]
        return self.AddPlaceholder(*arguments)

    def AddPolyline(self, SafeArrayOfPoints=None):
        arguments = com_arguments([unwrap(a) for a in [SafeArrayOfPoints]])
        return Shape(self.com_object.AddPolyline(*arguments))

    def addpolyline(self, SafeArrayOfPoints=None):
        """Alias for AddPolyline"""
        arguments = [SafeArrayOfPoints]
        return self.AddPolyline(*arguments)

    def add_polyline(self, SafeArrayOfPoints=None):
        """Alias for AddPolyline"""
        arguments = [SafeArrayOfPoints]
        return self.AddPolyline(*arguments)

    def AddShape(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Left, Top, Width, Height]])
        return Shape(self.com_object.AddShape(*arguments))

    def addshape(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddShape"""
        arguments = [Type, Left, Top, Width, Height]
        return self.AddShape(*arguments)

    def add_shape(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddShape"""
        arguments = [Type, Left, Top, Width, Height]
        return self.AddShape(*arguments)

    def AddSmartArt(self, Layout=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Layout, Left, Top, Width, Height]])
        return Shape(self.com_object.AddSmartArt(*arguments))

    def addsmartart(self, Layout=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddSmartArt"""
        arguments = [Layout, Left, Top, Width, Height]
        return self.AddSmartArt(*arguments)

    def add_smart_art(self, Layout=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddSmartArt"""
        arguments = [Layout, Left, Top, Width, Height]
        return self.AddSmartArt(*arguments)

    def AddTable(self, NumRows=None, NumColumns=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [NumRows, NumColumns, Left, Top, Width, Height]])
        return Shape(self.com_object.AddTable(*arguments))

    def addtable(self, NumRows=None, NumColumns=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddTable"""
        arguments = [NumRows, NumColumns, Left, Top, Width, Height]
        return self.AddTable(*arguments)

    def add_table(self, NumRows=None, NumColumns=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddTable"""
        arguments = [NumRows, NumColumns, Left, Top, Width, Height]
        return self.AddTable(*arguments)

    def AddTextbox(self, Orientation=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Orientation, Left, Top, Width, Height]])
        return Shape(self.com_object.AddTextbox(*arguments))

    def addtextbox(self, Orientation=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddTextbox"""
        arguments = [Orientation, Left, Top, Width, Height]
        return self.AddTextbox(*arguments)

    def add_textbox(self, Orientation=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddTextbox"""
        arguments = [Orientation, Left, Top, Width, Height]
        return self.AddTextbox(*arguments)

    def AddTextEffect(self, PresetTextEffect=None, Text=None, FontName=None, FontSize=None, FontBold=None, FontItalic=None, Left=None, Top=None):
        arguments = com_arguments([unwrap(a) for a in [PresetTextEffect, Text, FontName, FontSize, FontBold, FontItalic, Left, Top]])
        return Shape(self.com_object.AddTextEffect(*arguments))

    def addtexteffect(self, PresetTextEffect=None, Text=None, FontName=None, FontSize=None, FontBold=None, FontItalic=None, Left=None, Top=None):
        """Alias for AddTextEffect"""
        arguments = [PresetTextEffect, Text, FontName, FontSize, FontBold, FontItalic, Left, Top]
        return self.AddTextEffect(*arguments)

    def add_text_effect(self, PresetTextEffect=None, Text=None, FontName=None, FontSize=None, FontBold=None, FontItalic=None, Left=None, Top=None):
        """Alias for AddTextEffect"""
        arguments = [PresetTextEffect, Text, FontName, FontSize, FontBold, FontItalic, Left, Top]
        return self.AddTextEffect(*arguments)

    def AddTitle(self):
        return Shape(self.com_object.AddTitle())

    def addtitle(self):
        """Alias for AddTitle"""
        return self.AddTitle()

    def add_title(self):
        """Alias for AddTitle"""
        return self.AddTitle()

    def BuildFreeform(self, EditingType=None, X1=None, Y1=None):
        arguments = com_arguments([unwrap(a) for a in [EditingType, X1, Y1]])
        return FreeformBuilder(self.com_object.BuildFreeform(*arguments))

    def buildfreeform(self, EditingType=None, X1=None, Y1=None):
        """Alias for BuildFreeform"""
        arguments = [EditingType, X1, Y1]
        return self.BuildFreeform(*arguments)

    def build_freeform(self, EditingType=None, X1=None, Y1=None):
        """Alias for BuildFreeform"""
        arguments = [EditingType, X1, Y1]
        return self.BuildFreeform(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Shape(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Paste(self):
        return ShapeRange(self.com_object.Paste())

    def paste(self):
        """Alias for Paste"""
        return self.Paste()

    def PasteSpecial(self, DataType=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, Link=None):
        arguments = com_arguments([unwrap(a) for a in [DataType, DisplayAsIcon, IconFileName, IconIndex, IconLabel, Link]])
        return ShapeRange(self.com_object.PasteSpecial(*arguments))

    def pastespecial(self, DataType=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, Link=None):
        """Alias for PasteSpecial"""
        arguments = [DataType, DisplayAsIcon, IconFileName, IconIndex, IconLabel, Link]
        return self.PasteSpecial(*arguments)

    def paste_special(self, DataType=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, Link=None):
        """Alias for PasteSpecial"""
        arguments = [DataType, DisplayAsIcon, IconFileName, IconIndex, IconLabel, Link]
        return self.PasteSpecial(*arguments)

    def Range(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ShapeRange(self.com_object.Range(*arguments))

    def range(self, Index=None):
        """Alias for Range"""
        arguments = [Index]
        return self.Range(*arguments)

    def SelectAll(self):
        self.com_object.SelectAll()

    def selectall(self):
        """Alias for SelectAll"""
        return self.SelectAll()

    def select_all(self):
        """Alias for SelectAll"""
        return self.SelectAll()


class Slide:

    def __init__(self, slide=None):
        self.com_object= slide

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Background(self):
        return ShapeRange(self.com_object.Background)

    @property
    def background(self):
        """Alias for Background"""
        return self.Background

    @property
    def BackgroundStyle(self):
        return self.com_object.BackgroundStyle

    @BackgroundStyle.setter
    def BackgroundStyle(self, value):
        self.com_object.BackgroundStyle = value

    @property
    def backgroundstyle(self):
        """Alias for BackgroundStyle"""
        return self.BackgroundStyle

    @backgroundstyle.setter
    def backgroundstyle(self, value):
        """Alias for BackgroundStyle.setter"""
        self.BackgroundStyle = value

    @property
    def background_style(self):
        """Alias for BackgroundStyle"""
        return self.BackgroundStyle

    @background_style.setter
    def background_style(self, value):
        """Alias for BackgroundStyle.setter"""
        self.BackgroundStyle = value

    @property
    def ColorScheme(self):
        return ColorScheme(self.com_object.ColorScheme)

    @ColorScheme.setter
    def ColorScheme(self, value):
        self.com_object.ColorScheme = value

    @property
    def colorscheme(self):
        """Alias for ColorScheme"""
        return self.ColorScheme

    @colorscheme.setter
    def colorscheme(self, value):
        """Alias for ColorScheme.setter"""
        self.ColorScheme = value

    @property
    def color_scheme(self):
        """Alias for ColorScheme"""
        return self.ColorScheme

    @color_scheme.setter
    def color_scheme(self, value):
        """Alias for ColorScheme.setter"""
        self.ColorScheme = value

    @property
    def Comments(self):
        return Comments(self.com_object.Comments)

    @property
    def comments(self):
        """Alias for Comments"""
        return self.Comments

    @property
    def CustomerData(self):
        return CustomerData(self.com_object.CustomerData)

    @property
    def customerdata(self):
        """Alias for CustomerData"""
        return self.CustomerData

    @property
    def customer_data(self):
        """Alias for CustomerData"""
        return self.CustomerData

    @property
    def CustomLayout(self):
        return CustomLayout(self.com_object.CustomLayout)

    @property
    def customlayout(self):
        """Alias for CustomLayout"""
        return self.CustomLayout

    @property
    def custom_layout(self):
        """Alias for CustomLayout"""
        return self.CustomLayout

    @property
    def Design(self):
        return Design(self.com_object.Design)

    @property
    def design(self):
        """Alias for Design"""
        return self.Design

    @property
    def DisplayMasterShapes(self):
        return self.com_object.DisplayMasterShapes

    @DisplayMasterShapes.setter
    def DisplayMasterShapes(self, value):
        self.com_object.DisplayMasterShapes = value

    @property
    def displaymastershapes(self):
        """Alias for DisplayMasterShapes"""
        return self.DisplayMasterShapes

    @displaymastershapes.setter
    def displaymastershapes(self, value):
        """Alias for DisplayMasterShapes.setter"""
        self.DisplayMasterShapes = value

    @property
    def display_master_shapes(self):
        """Alias for DisplayMasterShapes"""
        return self.DisplayMasterShapes

    @display_master_shapes.setter
    def display_master_shapes(self, value):
        """Alias for DisplayMasterShapes.setter"""
        self.DisplayMasterShapes = value

    @property
    def FollowMasterBackground(self):
        return self.com_object.FollowMasterBackground

    @FollowMasterBackground.setter
    def FollowMasterBackground(self, value):
        self.com_object.FollowMasterBackground = value

    @property
    def followmasterbackground(self):
        """Alias for FollowMasterBackground"""
        return self.FollowMasterBackground

    @followmasterbackground.setter
    def followmasterbackground(self, value):
        """Alias for FollowMasterBackground.setter"""
        self.FollowMasterBackground = value

    @property
    def follow_master_background(self):
        """Alias for FollowMasterBackground"""
        return self.FollowMasterBackground

    @follow_master_background.setter
    def follow_master_background(self, value):
        """Alias for FollowMasterBackground.setter"""
        self.FollowMasterBackground = value

    @property
    def HasNotesPage(self):
        return self.com_object.HasNotesPage

    @property
    def hasnotespage(self):
        """Alias for HasNotesPage"""
        return self.HasNotesPage

    @property
    def has_notes_page(self):
        """Alias for HasNotesPage"""
        return self.HasNotesPage

    @property
    def HeadersFooters(self):
        return HeadersFooters(self.com_object.HeadersFooters)

    @property
    def headersfooters(self):
        """Alias for HeadersFooters"""
        return self.HeadersFooters

    @property
    def headers_footers(self):
        """Alias for HeadersFooters"""
        return self.HeadersFooters

    @property
    def Hyperlinks(self):
        return Hyperlinks(self.com_object.Hyperlinks)

    @property
    def hyperlinks(self):
        """Alias for Hyperlinks"""
        return self.Hyperlinks

    @property
    def Layout(self):
        return PpSlideLayout(self.com_object.Layout)

    @Layout.setter
    def Layout(self, value):
        self.com_object.Layout = value

    @property
    def layout(self):
        """Alias for Layout"""
        return self.Layout

    @layout.setter
    def layout(self, value):
        """Alias for Layout.setter"""
        self.Layout = value

    @property
    def Master(self):
        return Master(self.com_object.Master)

    @property
    def master(self):
        """Alias for Master"""
        return self.Master

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NotesPage(self):
        return SlideRange(self.com_object.NotesPage)

    @property
    def notespage(self):
        """Alias for NotesPage"""
        return self.NotesPage

    @property
    def notes_page(self):
        """Alias for NotesPage"""
        return self.NotesPage

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PrintSteps(self):
        return self.com_object.PrintSteps

    @property
    def printsteps(self):
        """Alias for PrintSteps"""
        return self.PrintSteps

    @property
    def print_steps(self):
        """Alias for PrintSteps"""
        return self.PrintSteps

    @property
    def sectionIndex(self):
        return Slide(self.com_object.sectionIndex)

    @property
    def sectionindex(self):
        """Alias for sectionIndex"""
        return self.sectionIndex

    @property
    def section_index(self):
        """Alias for sectionIndex"""
        return self.sectionIndex

    @property
    def Shapes(self):
        return Shapes(self.com_object.Shapes)

    @property
    def shapes(self):
        """Alias for Shapes"""
        return self.Shapes

    @property
    def SlideID(self):
        return self.com_object.SlideID

    @property
    def slideid(self):
        """Alias for SlideID"""
        return self.SlideID

    @property
    def slide_i_d(self):
        """Alias for SlideID"""
        return self.SlideID

    @property
    def SlideIndex(self):
        return Slides(self.com_object.SlideIndex)

    @property
    def slideindex(self):
        """Alias for SlideIndex"""
        return self.SlideIndex

    @property
    def slide_index(self):
        """Alias for SlideIndex"""
        return self.SlideIndex

    @property
    def SlideNumber(self):
        return self.com_object.SlideNumber

    @property
    def slidenumber(self):
        """Alias for SlideNumber"""
        return self.SlideNumber

    @property
    def slide_number(self):
        """Alias for SlideNumber"""
        return self.SlideNumber

    @property
    def SlideShowTransition(self):
        return SlideShowTransition(self.com_object.SlideShowTransition)

    @property
    def slideshowtransition(self):
        """Alias for SlideShowTransition"""
        return self.SlideShowTransition

    @property
    def slide_show_transition(self):
        """Alias for SlideShowTransition"""
        return self.SlideShowTransition

    @property
    def Tags(self):
        return Tags(self.com_object.Tags)

    @property
    def tags(self):
        """Alias for Tags"""
        return self.Tags

    @property
    def ThemeColorScheme(self):
        return self.com_object.ThemeColorScheme

    @property
    def themecolorscheme(self):
        """Alias for ThemeColorScheme"""
        return self.ThemeColorScheme

    @property
    def theme_color_scheme(self):
        """Alias for ThemeColorScheme"""
        return self.ThemeColorScheme

    @property
    def TimeLine(self):
        return TimeLine(self.com_object.TimeLine)

    @property
    def timeline(self):
        """Alias for TimeLine"""
        return self.TimeLine

    @property
    def time_line(self):
        """Alias for TimeLine"""
        return self.TimeLine

    def ApplyTemplate(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        self.com_object.ApplyTemplate(*arguments)

    def applytemplate(self, FileName=None):
        """Alias for ApplyTemplate"""
        arguments = [FileName]
        return self.ApplyTemplate(*arguments)

    def apply_template(self, FileName=None):
        """Alias for ApplyTemplate"""
        arguments = [FileName]
        return self.ApplyTemplate(*arguments)

    def ApplyTemplate2(self):
        return self.com_object.ApplyTemplate2()

    def applytemplate2(self):
        """Alias for ApplyTemplate2"""
        return self.ApplyTemplate2()

    def apply_template2(self):
        """Alias for ApplyTemplate2"""
        return self.ApplyTemplate2()

    def ApplyTheme(self, themeName=None):
        arguments = com_arguments([unwrap(a) for a in [themeName]])
        self.com_object.ApplyTheme(*arguments)

    def applytheme(self, themeName=None):
        """Alias for ApplyTheme"""
        arguments = [themeName]
        return self.ApplyTheme(*arguments)

    def apply_theme(self, themeName=None):
        """Alias for ApplyTheme"""
        arguments = [themeName]
        return self.ApplyTheme(*arguments)

    def ApplyThemeColorScheme(self, themeColorSchemeName=None):
        arguments = com_arguments([unwrap(a) for a in [themeColorSchemeName]])
        self.com_object.ApplyThemeColorScheme(*arguments)

    def applythemecolorscheme(self, themeColorSchemeName=None):
        """Alias for ApplyThemeColorScheme"""
        arguments = [themeColorSchemeName]
        return self.ApplyThemeColorScheme(*arguments)

    def apply_theme_color_scheme(self, themeColorSchemeName=None):
        """Alias for ApplyThemeColorScheme"""
        arguments = [themeColorSchemeName]
        return self.ApplyThemeColorScheme(*arguments)

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Cut(self):
        self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Duplicate(self):
        return SlideRange(self.com_object.Duplicate())

    def duplicate(self):
        """Alias for Duplicate"""
        return self.Duplicate()

    def Export(self, FileName=None, FilterName=None, ScaleWidth=None, ScaleHeight=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, FilterName, ScaleWidth, ScaleHeight]])
        self.com_object.Export(*arguments)

    def export(self, FileName=None, FilterName=None, ScaleWidth=None, ScaleHeight=None):
        """Alias for Export"""
        arguments = [FileName, FilterName, ScaleWidth, ScaleHeight]
        return self.Export(*arguments)

    def MoveTo(self, toPos=None):
        arguments = com_arguments([unwrap(a) for a in [toPos]])
        self.com_object.MoveTo(*arguments)

    def moveto(self, toPos=None):
        """Alias for MoveTo"""
        arguments = [toPos]
        return self.MoveTo(*arguments)

    def move_to(self, toPos=None):
        """Alias for MoveTo"""
        arguments = [toPos]
        return self.MoveTo(*arguments)

    def MoveToSectionStart(self, toSection=None):
        arguments = com_arguments([unwrap(a) for a in [toSection]])
        self.com_object.MoveToSectionStart(*arguments)

    def movetosectionstart(self, toSection=None):
        """Alias for MoveToSectionStart"""
        arguments = [toSection]
        return self.MoveToSectionStart(*arguments)

    def move_to_section_start(self, toSection=None):
        """Alias for MoveToSectionStart"""
        arguments = [toSection]
        return self.MoveToSectionStart(*arguments)

    def PublishSlides(self, SlideLibraryUrl=None, Overwrite=None, UseSlideOrder=None):
        arguments = com_arguments([unwrap(a) for a in [SlideLibraryUrl, Overwrite, UseSlideOrder]])
        return self.com_object.PublishSlides(*arguments)

    def publishslides(self, SlideLibraryUrl=None, Overwrite=None, UseSlideOrder=None):
        """Alias for PublishSlides"""
        arguments = [SlideLibraryUrl, Overwrite, UseSlideOrder]
        return self.PublishSlides(*arguments)

    def publish_slides(self, SlideLibraryUrl=None, Overwrite=None, UseSlideOrder=None):
        """Alias for PublishSlides"""
        arguments = [SlideLibraryUrl, Overwrite, UseSlideOrder]
        return self.PublishSlides(*arguments)

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class SlideNavigation:

    def __init__(self, slidenavigation=None):
        self.com_object= slidenavigation

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value


class SlideRange:

    def __init__(self, sliderange=None):
        self.com_object= sliderange

    def __call__(self, item):
        return SlideRange(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Background(self):
        return ShapeRange(self.com_object.Background)

    @property
    def background(self):
        """Alias for Background"""
        return self.Background

    @property
    def BackgroundStyle(self):
        return self.com_object.BackgroundStyle

    @BackgroundStyle.setter
    def BackgroundStyle(self, value):
        self.com_object.BackgroundStyle = value

    @property
    def backgroundstyle(self):
        """Alias for BackgroundStyle"""
        return self.BackgroundStyle

    @backgroundstyle.setter
    def backgroundstyle(self, value):
        """Alias for BackgroundStyle.setter"""
        self.BackgroundStyle = value

    @property
    def background_style(self):
        """Alias for BackgroundStyle"""
        return self.BackgroundStyle

    @background_style.setter
    def background_style(self, value):
        """Alias for BackgroundStyle.setter"""
        self.BackgroundStyle = value

    @property
    def ColorScheme(self):
        return ColorScheme(self.com_object.ColorScheme)

    @ColorScheme.setter
    def ColorScheme(self, value):
        self.com_object.ColorScheme = value

    @property
    def colorscheme(self):
        """Alias for ColorScheme"""
        return self.ColorScheme

    @colorscheme.setter
    def colorscheme(self, value):
        """Alias for ColorScheme.setter"""
        self.ColorScheme = value

    @property
    def color_scheme(self):
        """Alias for ColorScheme"""
        return self.ColorScheme

    @color_scheme.setter
    def color_scheme(self, value):
        """Alias for ColorScheme.setter"""
        self.ColorScheme = value

    @property
    def Comments(self):
        return Comments(self.com_object.Comments)

    @property
    def comments(self):
        """Alias for Comments"""
        return self.Comments

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def CustomerData(self):
        return CustomerData(self.com_object.CustomerData)

    @property
    def customerdata(self):
        """Alias for CustomerData"""
        return self.CustomerData

    @property
    def customer_data(self):
        """Alias for CustomerData"""
        return self.CustomerData

    @property
    def CustomLayout(self):
        return CustomLayout(self.com_object.CustomLayout)

    @property
    def customlayout(self):
        """Alias for CustomLayout"""
        return self.CustomLayout

    @property
    def custom_layout(self):
        """Alias for CustomLayout"""
        return self.CustomLayout

    @property
    def Design(self):
        return Design(self.com_object.Design)

    @property
    def design(self):
        """Alias for Design"""
        return self.Design

    @property
    def DisplayMasterShapes(self):
        return self.com_object.DisplayMasterShapes

    @DisplayMasterShapes.setter
    def DisplayMasterShapes(self, value):
        self.com_object.DisplayMasterShapes = value

    @property
    def displaymastershapes(self):
        """Alias for DisplayMasterShapes"""
        return self.DisplayMasterShapes

    @displaymastershapes.setter
    def displaymastershapes(self, value):
        """Alias for DisplayMasterShapes.setter"""
        self.DisplayMasterShapes = value

    @property
    def display_master_shapes(self):
        """Alias for DisplayMasterShapes"""
        return self.DisplayMasterShapes

    @display_master_shapes.setter
    def display_master_shapes(self, value):
        """Alias for DisplayMasterShapes.setter"""
        self.DisplayMasterShapes = value

    @property
    def FollowMasterBackground(self):
        return self.com_object.FollowMasterBackground

    @FollowMasterBackground.setter
    def FollowMasterBackground(self, value):
        self.com_object.FollowMasterBackground = value

    @property
    def followmasterbackground(self):
        """Alias for FollowMasterBackground"""
        return self.FollowMasterBackground

    @followmasterbackground.setter
    def followmasterbackground(self, value):
        """Alias for FollowMasterBackground.setter"""
        self.FollowMasterBackground = value

    @property
    def follow_master_background(self):
        """Alias for FollowMasterBackground"""
        return self.FollowMasterBackground

    @follow_master_background.setter
    def follow_master_background(self, value):
        """Alias for FollowMasterBackground.setter"""
        self.FollowMasterBackground = value

    @property
    def HasNotesPage(self):
        return self.com_object.HasNotesPage

    @property
    def hasnotespage(self):
        """Alias for HasNotesPage"""
        return self.HasNotesPage

    @property
    def has_notes_page(self):
        """Alias for HasNotesPage"""
        return self.HasNotesPage

    @property
    def HeadersFooters(self):
        return HeadersFooters(self.com_object.HeadersFooters)

    @property
    def headersfooters(self):
        """Alias for HeadersFooters"""
        return self.HeadersFooters

    @property
    def headers_footers(self):
        """Alias for HeadersFooters"""
        return self.HeadersFooters

    @property
    def Hyperlinks(self):
        return Hyperlinks(self.com_object.Hyperlinks)

    @property
    def hyperlinks(self):
        """Alias for Hyperlinks"""
        return self.Hyperlinks

    @property
    def Layout(self):
        return PpSlideLayout(self.com_object.Layout)

    @Layout.setter
    def Layout(self, value):
        self.com_object.Layout = value

    @property
    def layout(self):
        """Alias for Layout"""
        return self.Layout

    @layout.setter
    def layout(self, value):
        """Alias for Layout.setter"""
        self.Layout = value

    @property
    def Master(self):
        return Master(self.com_object.Master)

    @property
    def master(self):
        """Alias for Master"""
        return self.Master

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def NotesPage(self):
        return SlideRange(self.com_object.NotesPage)

    @property
    def notespage(self):
        """Alias for NotesPage"""
        return self.NotesPage

    @property
    def notes_page(self):
        """Alias for NotesPage"""
        return self.NotesPage

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PrintSteps(self):
        return self.com_object.PrintSteps

    @property
    def printsteps(self):
        """Alias for PrintSteps"""
        return self.PrintSteps

    @property
    def print_steps(self):
        """Alias for PrintSteps"""
        return self.PrintSteps

    @property
    def sectionIndex(self):
        return SlideRange(self.com_object.sectionIndex)

    @property
    def sectionindex(self):
        """Alias for sectionIndex"""
        return self.sectionIndex

    @property
    def section_index(self):
        """Alias for sectionIndex"""
        return self.sectionIndex

    @property
    def Shapes(self):
        return Shapes(self.com_object.Shapes)

    @property
    def shapes(self):
        """Alias for Shapes"""
        return self.Shapes

    @property
    def SlideID(self):
        return self.com_object.SlideID

    @property
    def slideid(self):
        """Alias for SlideID"""
        return self.SlideID

    @property
    def slide_i_d(self):
        """Alias for SlideID"""
        return self.SlideID

    @property
    def SlideIndex(self):
        return Slides(self.com_object.SlideIndex)

    @property
    def slideindex(self):
        """Alias for SlideIndex"""
        return self.SlideIndex

    @property
    def slide_index(self):
        """Alias for SlideIndex"""
        return self.SlideIndex

    @property
    def SlideNumber(self):
        return self.com_object.SlideNumber

    @property
    def slidenumber(self):
        """Alias for SlideNumber"""
        return self.SlideNumber

    @property
    def slide_number(self):
        """Alias for SlideNumber"""
        return self.SlideNumber

    @property
    def SlideShowTransition(self):
        return SlideShowTransition(self.com_object.SlideShowTransition)

    @property
    def slideshowtransition(self):
        """Alias for SlideShowTransition"""
        return self.SlideShowTransition

    @property
    def slide_show_transition(self):
        """Alias for SlideShowTransition"""
        return self.SlideShowTransition

    @property
    def Tags(self):
        return Tags(self.com_object.Tags)

    @property
    def tags(self):
        """Alias for Tags"""
        return self.Tags

    @property
    def ThemeColorScheme(self):
        return self.com_object.ThemeColorScheme

    @property
    def themecolorscheme(self):
        """Alias for ThemeColorScheme"""
        return self.ThemeColorScheme

    @property
    def theme_color_scheme(self):
        """Alias for ThemeColorScheme"""
        return self.ThemeColorScheme

    @property
    def TimeLine(self):
        return TimeLine(self.com_object.TimeLine)

    @property
    def timeline(self):
        """Alias for TimeLine"""
        return self.TimeLine

    @property
    def time_line(self):
        """Alias for TimeLine"""
        return self.TimeLine

    def ApplyTemplate(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        self.com_object.ApplyTemplate(*arguments)

    def applytemplate(self, FileName=None):
        """Alias for ApplyTemplate"""
        arguments = [FileName]
        return self.ApplyTemplate(*arguments)

    def apply_template(self, FileName=None):
        """Alias for ApplyTemplate"""
        arguments = [FileName]
        return self.ApplyTemplate(*arguments)

    def ApplyTemplate2(self):
        return self.com_object.ApplyTemplate2()

    def applytemplate2(self):
        """Alias for ApplyTemplate2"""
        return self.ApplyTemplate2()

    def apply_template2(self):
        """Alias for ApplyTemplate2"""
        return self.ApplyTemplate2()

    def ApplyTheme(self, themeName=None):
        arguments = com_arguments([unwrap(a) for a in [themeName]])
        self.com_object.ApplyTheme(*arguments)

    def applytheme(self, themeName=None):
        """Alias for ApplyTheme"""
        arguments = [themeName]
        return self.ApplyTheme(*arguments)

    def apply_theme(self, themeName=None):
        """Alias for ApplyTheme"""
        arguments = [themeName]
        return self.ApplyTheme(*arguments)

    def ApplyThemeColorScheme(self, themeColorSchemeName=None):
        arguments = com_arguments([unwrap(a) for a in [themeColorSchemeName]])
        self.com_object.ApplyThemeColorScheme(*arguments)

    def applythemecolorscheme(self, themeColorSchemeName=None):
        """Alias for ApplyThemeColorScheme"""
        arguments = [themeColorSchemeName]
        return self.ApplyThemeColorScheme(*arguments)

    def apply_theme_color_scheme(self, themeColorSchemeName=None):
        """Alias for ApplyThemeColorScheme"""
        arguments = [themeColorSchemeName]
        return self.ApplyThemeColorScheme(*arguments)

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Cut(self):
        self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Duplicate(self):
        return SlideRange(self.com_object.Duplicate())

    def duplicate(self):
        """Alias for Duplicate"""
        return self.Duplicate()

    def Export(self, FileName=None, FilterName=None, ScaleWidth=None, ScaleHeight=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, FilterName, ScaleWidth, ScaleHeight]])
        self.com_object.Export(*arguments)

    def export(self, FileName=None, FilterName=None, ScaleWidth=None, ScaleHeight=None):
        """Alias for Export"""
        arguments = [FileName, FilterName, ScaleWidth, ScaleHeight]
        return self.Export(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Slide(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def MoveTo(self, toPos=None):
        arguments = com_arguments([unwrap(a) for a in [toPos]])
        self.com_object.MoveTo(*arguments)

    def moveto(self, toPos=None):
        """Alias for MoveTo"""
        arguments = [toPos]
        return self.MoveTo(*arguments)

    def move_to(self, toPos=None):
        """Alias for MoveTo"""
        arguments = [toPos]
        return self.MoveTo(*arguments)

    def MoveToSectionStart(self, toSection=None):
        arguments = com_arguments([unwrap(a) for a in [toSection]])
        self.com_object.MoveToSectionStart(*arguments)

    def movetosectionstart(self, toSection=None):
        """Alias for MoveToSectionStart"""
        arguments = [toSection]
        return self.MoveToSectionStart(*arguments)

    def move_to_section_start(self, toSection=None):
        """Alias for MoveToSectionStart"""
        arguments = [toSection]
        return self.MoveToSectionStart(*arguments)

    def PublishSlides(self, SlideLibraryUrl=None, Overwrite=None):
        arguments = com_arguments([unwrap(a) for a in [SlideLibraryUrl, Overwrite]])
        self.com_object.PublishSlides(*arguments)

    def publishslides(self, SlideLibraryUrl=None, Overwrite=None):
        """Alias for PublishSlides"""
        arguments = [SlideLibraryUrl, Overwrite]
        return self.PublishSlides(*arguments)

    def publish_slides(self, SlideLibraryUrl=None, Overwrite=None):
        """Alias for PublishSlides"""
        arguments = [SlideLibraryUrl, Overwrite]
        return self.PublishSlides(*arguments)

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Slides:

    def __init__(self, slides=None):
        self.com_object= slides

    def __call__(self, item):
        return Slide(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Index=None, Layout=None):
        arguments = com_arguments([unwrap(a) for a in [Index, Layout]])
        return Slide(self.com_object.Add(*arguments))

    def add(self, Index=None, Layout=None):
        """Alias for Add"""
        arguments = [Index, Layout]
        return self.Add(*arguments)

    def AddSlide(self, Index=None, pCustomLayout=None):
        arguments = com_arguments([unwrap(a) for a in [Index, pCustomLayout]])
        return Slide(self.com_object.AddSlide(*arguments))

    def addslide(self, Index=None, pCustomLayout=None):
        """Alias for AddSlide"""
        arguments = [Index, pCustomLayout]
        return self.AddSlide(*arguments)

    def add_slide(self, Index=None, pCustomLayout=None):
        """Alias for AddSlide"""
        arguments = [Index, pCustomLayout]
        return self.AddSlide(*arguments)

    def FindBySlideID(self, SlideID=None):
        arguments = com_arguments([unwrap(a) for a in [SlideID]])
        return Slide(self.com_object.FindBySlideID(*arguments))

    def findbyslideid(self, SlideID=None):
        """Alias for FindBySlideID"""
        arguments = [SlideID]
        return self.FindBySlideID(*arguments)

    def find_by_slide_i_d(self, SlideID=None):
        """Alias for FindBySlideID"""
        arguments = [SlideID]
        return self.FindBySlideID(*arguments)

    def InsertFromFile(self, FileName=None, Index=None, SlideStart=None, SlideEnd=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, Index, SlideStart, SlideEnd]])
        return self.com_object.InsertFromFile(*arguments)

    def insertfromfile(self, FileName=None, Index=None, SlideStart=None, SlideEnd=None):
        """Alias for InsertFromFile"""
        arguments = [FileName, Index, SlideStart, SlideEnd]
        return self.InsertFromFile(*arguments)

    def insert_from_file(self, FileName=None, Index=None, SlideStart=None, SlideEnd=None):
        """Alias for InsertFromFile"""
        arguments = [FileName, Index, SlideStart, SlideEnd]
        return self.InsertFromFile(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Slide(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Paste(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return SlideRange(self.com_object.Paste(*arguments))

    def paste(self, Index=None):
        """Alias for Paste"""
        arguments = [Index]
        return self.Paste(*arguments)

    def Range(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return SlideRange(self.com_object.Range(*arguments))

    def range(self, Index=None):
        """Alias for Range"""
        arguments = [Index]
        return self.Range(*arguments)


class SlideShowSettings:

    def __init__(self, slideshowsettings=None):
        self.com_object= slideshowsettings

    @property
    def AdvanceMode(self):
        return self.com_object.AdvanceMode

    @AdvanceMode.setter
    def AdvanceMode(self, value):
        self.com_object.AdvanceMode = value

    @property
    def advancemode(self):
        """Alias for AdvanceMode"""
        return self.AdvanceMode

    @advancemode.setter
    def advancemode(self, value):
        """Alias for AdvanceMode.setter"""
        self.AdvanceMode = value

    @property
    def advance_mode(self):
        """Alias for AdvanceMode"""
        return self.AdvanceMode

    @advance_mode.setter
    def advance_mode(self, value):
        """Alias for AdvanceMode.setter"""
        self.AdvanceMode = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def EndingSlide(self):
        return self.com_object.EndingSlide

    @EndingSlide.setter
    def EndingSlide(self, value):
        self.com_object.EndingSlide = value

    @property
    def endingslide(self):
        """Alias for EndingSlide"""
        return self.EndingSlide

    @endingslide.setter
    def endingslide(self, value):
        """Alias for EndingSlide.setter"""
        self.EndingSlide = value

    @property
    def ending_slide(self):
        """Alias for EndingSlide"""
        return self.EndingSlide

    @ending_slide.setter
    def ending_slide(self, value):
        """Alias for EndingSlide.setter"""
        self.EndingSlide = value

    @property
    def LoopUntilStopped(self):
        return self.com_object.LoopUntilStopped

    @LoopUntilStopped.setter
    def LoopUntilStopped(self, value):
        self.com_object.LoopUntilStopped = value

    @property
    def loopuntilstopped(self):
        """Alias for LoopUntilStopped"""
        return self.LoopUntilStopped

    @loopuntilstopped.setter
    def loopuntilstopped(self, value):
        """Alias for LoopUntilStopped.setter"""
        self.LoopUntilStopped = value

    @property
    def loop_until_stopped(self):
        """Alias for LoopUntilStopped"""
        return self.LoopUntilStopped

    @loop_until_stopped.setter
    def loop_until_stopped(self, value):
        """Alias for LoopUntilStopped.setter"""
        self.LoopUntilStopped = value

    @property
    def NamedSlideShows(self):
        return NamedSlideShows(self.com_object.NamedSlideShows)

    @property
    def namedslideshows(self):
        """Alias for NamedSlideShows"""
        return self.NamedSlideShows

    @property
    def named_slide_shows(self):
        """Alias for NamedSlideShows"""
        return self.NamedSlideShows

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PointerColor(self):
        return ColorFormat(self.com_object.PointerColor)

    @property
    def pointercolor(self):
        """Alias for PointerColor"""
        return self.PointerColor

    @property
    def pointer_color(self):
        """Alias for PointerColor"""
        return self.PointerColor

    @property
    def RangeType(self):
        return self.com_object.RangeType

    @RangeType.setter
    def RangeType(self, value):
        self.com_object.RangeType = value

    @property
    def rangetype(self):
        """Alias for RangeType"""
        return self.RangeType

    @rangetype.setter
    def rangetype(self, value):
        """Alias for RangeType.setter"""
        self.RangeType = value

    @property
    def range_type(self):
        """Alias for RangeType"""
        return self.RangeType

    @range_type.setter
    def range_type(self, value):
        """Alias for RangeType.setter"""
        self.RangeType = value

    @property
    def ShowMediaControls(self):
        return self.com_object.ShowMediaControls

    @ShowMediaControls.setter
    def ShowMediaControls(self, value):
        self.com_object.ShowMediaControls = value

    @property
    def showmediacontrols(self):
        """Alias for ShowMediaControls"""
        return self.ShowMediaControls

    @showmediacontrols.setter
    def showmediacontrols(self, value):
        """Alias for ShowMediaControls.setter"""
        self.ShowMediaControls = value

    @property
    def show_media_controls(self):
        """Alias for ShowMediaControls"""
        return self.ShowMediaControls

    @show_media_controls.setter
    def show_media_controls(self, value):
        """Alias for ShowMediaControls.setter"""
        self.ShowMediaControls = value

    @property
    def ShowPresenterView(self):
        return SlideShowSettings(self.com_object.ShowPresenterView)

    @ShowPresenterView.setter
    def ShowPresenterView(self, value):
        self.com_object.ShowPresenterView = value

    @property
    def showpresenterview(self):
        """Alias for ShowPresenterView"""
        return self.ShowPresenterView

    @showpresenterview.setter
    def showpresenterview(self, value):
        """Alias for ShowPresenterView.setter"""
        self.ShowPresenterView = value

    @property
    def show_presenter_view(self):
        """Alias for ShowPresenterView"""
        return self.ShowPresenterView

    @show_presenter_view.setter
    def show_presenter_view(self, value):
        """Alias for ShowPresenterView.setter"""
        self.ShowPresenterView = value

    @property
    def ShowScrollbar(self):
        return self.com_object.ShowScrollbar

    @ShowScrollbar.setter
    def ShowScrollbar(self, value):
        self.com_object.ShowScrollbar = value

    @property
    def showscrollbar(self):
        """Alias for ShowScrollbar"""
        return self.ShowScrollbar

    @showscrollbar.setter
    def showscrollbar(self, value):
        """Alias for ShowScrollbar.setter"""
        self.ShowScrollbar = value

    @property
    def show_scrollbar(self):
        """Alias for ShowScrollbar"""
        return self.ShowScrollbar

    @show_scrollbar.setter
    def show_scrollbar(self, value):
        """Alias for ShowScrollbar.setter"""
        self.ShowScrollbar = value

    @property
    def ShowType(self):
        return self.com_object.ShowType

    @ShowType.setter
    def ShowType(self, value):
        self.com_object.ShowType = value

    @property
    def showtype(self):
        """Alias for ShowType"""
        return self.ShowType

    @showtype.setter
    def showtype(self, value):
        """Alias for ShowType.setter"""
        self.ShowType = value

    @property
    def show_type(self):
        """Alias for ShowType"""
        return self.ShowType

    @show_type.setter
    def show_type(self, value):
        """Alias for ShowType.setter"""
        self.ShowType = value

    @property
    def ShowWithAnimation(self):
        return self.com_object.ShowWithAnimation

    @ShowWithAnimation.setter
    def ShowWithAnimation(self, value):
        self.com_object.ShowWithAnimation = value

    @property
    def showwithanimation(self):
        """Alias for ShowWithAnimation"""
        return self.ShowWithAnimation

    @showwithanimation.setter
    def showwithanimation(self, value):
        """Alias for ShowWithAnimation.setter"""
        self.ShowWithAnimation = value

    @property
    def show_with_animation(self):
        """Alias for ShowWithAnimation"""
        return self.ShowWithAnimation

    @show_with_animation.setter
    def show_with_animation(self, value):
        """Alias for ShowWithAnimation.setter"""
        self.ShowWithAnimation = value

    @property
    def ShowWithNarration(self):
        return self.com_object.ShowWithNarration

    @ShowWithNarration.setter
    def ShowWithNarration(self, value):
        self.com_object.ShowWithNarration = value

    @property
    def showwithnarration(self):
        """Alias for ShowWithNarration"""
        return self.ShowWithNarration

    @showwithnarration.setter
    def showwithnarration(self, value):
        """Alias for ShowWithNarration.setter"""
        self.ShowWithNarration = value

    @property
    def show_with_narration(self):
        """Alias for ShowWithNarration"""
        return self.ShowWithNarration

    @show_with_narration.setter
    def show_with_narration(self, value):
        """Alias for ShowWithNarration.setter"""
        self.ShowWithNarration = value

    @property
    def SlideShowName(self):
        return self.com_object.SlideShowName

    @SlideShowName.setter
    def SlideShowName(self, value):
        self.com_object.SlideShowName = value

    @property
    def slideshowname(self):
        """Alias for SlideShowName"""
        return self.SlideShowName

    @slideshowname.setter
    def slideshowname(self, value):
        """Alias for SlideShowName.setter"""
        self.SlideShowName = value

    @property
    def slide_show_name(self):
        """Alias for SlideShowName"""
        return self.SlideShowName

    @slide_show_name.setter
    def slide_show_name(self, value):
        """Alias for SlideShowName.setter"""
        self.SlideShowName = value

    @property
    def StartingSlide(self):
        return self.com_object.StartingSlide

    @StartingSlide.setter
    def StartingSlide(self, value):
        self.com_object.StartingSlide = value

    @property
    def startingslide(self):
        """Alias for StartingSlide"""
        return self.StartingSlide

    @startingslide.setter
    def startingslide(self, value):
        """Alias for StartingSlide.setter"""
        self.StartingSlide = value

    @property
    def starting_slide(self):
        """Alias for StartingSlide"""
        return self.StartingSlide

    @starting_slide.setter
    def starting_slide(self, value):
        """Alias for StartingSlide.setter"""
        self.StartingSlide = value

    def Run(self):
        return SlideShowWindow(self.com_object.Run())

    def run(self):
        """Alias for Run"""
        return self.Run()


class SlideShowTransition:

    def __init__(self, slideshowtransition=None):
        self.com_object= slideshowtransition

    @property
    def AdvanceOnClick(self):
        return self.com_object.AdvanceOnClick

    @AdvanceOnClick.setter
    def AdvanceOnClick(self, value):
        self.com_object.AdvanceOnClick = value

    @property
    def advanceonclick(self):
        """Alias for AdvanceOnClick"""
        return self.AdvanceOnClick

    @advanceonclick.setter
    def advanceonclick(self, value):
        """Alias for AdvanceOnClick.setter"""
        self.AdvanceOnClick = value

    @property
    def advance_on_click(self):
        """Alias for AdvanceOnClick"""
        return self.AdvanceOnClick

    @advance_on_click.setter
    def advance_on_click(self, value):
        """Alias for AdvanceOnClick.setter"""
        self.AdvanceOnClick = value

    @property
    def AdvanceOnTime(self):
        return self.com_object.AdvanceOnTime

    @AdvanceOnTime.setter
    def AdvanceOnTime(self, value):
        self.com_object.AdvanceOnTime = value

    @property
    def advanceontime(self):
        """Alias for AdvanceOnTime"""
        return self.AdvanceOnTime

    @advanceontime.setter
    def advanceontime(self, value):
        """Alias for AdvanceOnTime.setter"""
        self.AdvanceOnTime = value

    @property
    def advance_on_time(self):
        """Alias for AdvanceOnTime"""
        return self.AdvanceOnTime

    @advance_on_time.setter
    def advance_on_time(self, value):
        """Alias for AdvanceOnTime.setter"""
        self.AdvanceOnTime = value

    @property
    def AdvanceTime(self):
        return self.com_object.AdvanceTime

    @AdvanceTime.setter
    def AdvanceTime(self, value):
        self.com_object.AdvanceTime = value

    @property
    def advancetime(self):
        """Alias for AdvanceTime"""
        return self.AdvanceTime

    @advancetime.setter
    def advancetime(self, value):
        """Alias for AdvanceTime.setter"""
        self.AdvanceTime = value

    @property
    def advance_time(self):
        """Alias for AdvanceTime"""
        return self.AdvanceTime

    @advance_time.setter
    def advance_time(self, value):
        """Alias for AdvanceTime.setter"""
        self.AdvanceTime = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Duration(self):
        return self.com_object.Duration

    @Duration.setter
    def Duration(self, value):
        self.com_object.Duration = value

    @property
    def duration(self):
        """Alias for Duration"""
        return self.Duration

    @duration.setter
    def duration(self, value):
        """Alias for Duration.setter"""
        self.Duration = value

    @property
    def EntryEffect(self):
        return self.com_object.EntryEffect

    @EntryEffect.setter
    def EntryEffect(self, value):
        self.com_object.EntryEffect = value

    @property
    def entryeffect(self):
        """Alias for EntryEffect"""
        return self.EntryEffect

    @entryeffect.setter
    def entryeffect(self, value):
        """Alias for EntryEffect.setter"""
        self.EntryEffect = value

    @property
    def entry_effect(self):
        """Alias for EntryEffect"""
        return self.EntryEffect

    @entry_effect.setter
    def entry_effect(self, value):
        """Alias for EntryEffect.setter"""
        self.EntryEffect = value

    @property
    def Hidden(self):
        return self.com_object.Hidden

    @Hidden.setter
    def Hidden(self, value):
        self.com_object.Hidden = value

    @property
    def hidden(self):
        """Alias for Hidden"""
        return self.Hidden

    @hidden.setter
    def hidden(self, value):
        """Alias for Hidden.setter"""
        self.Hidden = value

    @property
    def LoopSoundUntilNext(self):
        return self.com_object.LoopSoundUntilNext

    @LoopSoundUntilNext.setter
    def LoopSoundUntilNext(self, value):
        self.com_object.LoopSoundUntilNext = value

    @property
    def loopsounduntilnext(self):
        """Alias for LoopSoundUntilNext"""
        return self.LoopSoundUntilNext

    @loopsounduntilnext.setter
    def loopsounduntilnext(self, value):
        """Alias for LoopSoundUntilNext.setter"""
        self.LoopSoundUntilNext = value

    @property
    def loop_sound_until_next(self):
        """Alias for LoopSoundUntilNext"""
        return self.LoopSoundUntilNext

    @loop_sound_until_next.setter
    def loop_sound_until_next(self, value):
        """Alias for LoopSoundUntilNext.setter"""
        self.LoopSoundUntilNext = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SoundEffect(self):
        return SoundEffect(self.com_object.SoundEffect)

    @property
    def soundeffect(self):
        """Alias for SoundEffect"""
        return self.SoundEffect

    @property
    def sound_effect(self):
        """Alias for SoundEffect"""
        return self.SoundEffect

    @property
    def Speed(self):
        return self.com_object.Speed

    @Speed.setter
    def Speed(self, value):
        self.com_object.Speed = value

    @property
    def speed(self):
        """Alias for Speed"""
        return self.Speed

    @speed.setter
    def speed(self, value):
        """Alias for Speed.setter"""
        self.Speed = value


class SlideShowView:

    def __init__(self, slideshowview=None):
        self.com_object= slideshowview

    @property
    def AcceleratorsEnabled(self):
        return self.com_object.AcceleratorsEnabled

    @AcceleratorsEnabled.setter
    def AcceleratorsEnabled(self, value):
        self.com_object.AcceleratorsEnabled = value

    @property
    def acceleratorsenabled(self):
        """Alias for AcceleratorsEnabled"""
        return self.AcceleratorsEnabled

    @acceleratorsenabled.setter
    def acceleratorsenabled(self, value):
        """Alias for AcceleratorsEnabled.setter"""
        self.AcceleratorsEnabled = value

    @property
    def accelerators_enabled(self):
        """Alias for AcceleratorsEnabled"""
        return self.AcceleratorsEnabled

    @accelerators_enabled.setter
    def accelerators_enabled(self, value):
        """Alias for AcceleratorsEnabled.setter"""
        self.AcceleratorsEnabled = value

    @property
    def AdvanceMode(self):
        return self.com_object.AdvanceMode

    @property
    def advancemode(self):
        """Alias for AdvanceMode"""
        return self.AdvanceMode

    @property
    def advance_mode(self):
        """Alias for AdvanceMode"""
        return self.AdvanceMode

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def CurrentShowPosition(self):
        return self.com_object.CurrentShowPosition

    @property
    def currentshowposition(self):
        """Alias for CurrentShowPosition"""
        return self.CurrentShowPosition

    @property
    def current_show_position(self):
        """Alias for CurrentShowPosition"""
        return self.CurrentShowPosition

    @property
    def IsNamedShow(self):
        return self.com_object.IsNamedShow

    @property
    def isnamedshow(self):
        """Alias for IsNamedShow"""
        return self.IsNamedShow

    @property
    def is_named_show(self):
        """Alias for IsNamedShow"""
        return self.IsNamedShow

    @property
    def LaserPointerEnabled(self):
        return self.com_object.LaserPointerEnabled

    @LaserPointerEnabled.setter
    def LaserPointerEnabled(self, value):
        self.com_object.LaserPointerEnabled = value

    @property
    def laserpointerenabled(self):
        """Alias for LaserPointerEnabled"""
        return self.LaserPointerEnabled

    @laserpointerenabled.setter
    def laserpointerenabled(self, value):
        """Alias for LaserPointerEnabled.setter"""
        self.LaserPointerEnabled = value

    @property
    def laser_pointer_enabled(self):
        """Alias for LaserPointerEnabled"""
        return self.LaserPointerEnabled

    @laser_pointer_enabled.setter
    def laser_pointer_enabled(self, value):
        """Alias for LaserPointerEnabled.setter"""
        self.LaserPointerEnabled = value

    @property
    def LastSlideViewed(self):
        return Slide(self.com_object.LastSlideViewed)

    @property
    def lastslideviewed(self):
        """Alias for LastSlideViewed"""
        return self.LastSlideViewed

    @property
    def last_slide_viewed(self):
        """Alias for LastSlideViewed"""
        return self.LastSlideViewed

    @property
    def MediaControlsHeight(self):
        return self.com_object.MediaControlsHeight

    @property
    def mediacontrolsheight(self):
        """Alias for MediaControlsHeight"""
        return self.MediaControlsHeight

    @property
    def media_controls_height(self):
        """Alias for MediaControlsHeight"""
        return self.MediaControlsHeight

    @property
    def MediaControlsLeft(self):
        return Slide(self.com_object.MediaControlsLeft)

    @property
    def mediacontrolsleft(self):
        """Alias for MediaControlsLeft"""
        return self.MediaControlsLeft

    @property
    def media_controls_left(self):
        """Alias for MediaControlsLeft"""
        return self.MediaControlsLeft

    @property
    def MediaControlsTop(self):
        return Slide(self.com_object.MediaControlsTop)

    @property
    def mediacontrolstop(self):
        """Alias for MediaControlsTop"""
        return self.MediaControlsTop

    @property
    def media_controls_top(self):
        """Alias for MediaControlsTop"""
        return self.MediaControlsTop

    @property
    def MediaControlsVisible(self):
        return self.com_object.MediaControlsVisible

    @property
    def mediacontrolsvisible(self):
        """Alias for MediaControlsVisible"""
        return self.MediaControlsVisible

    @property
    def media_controls_visible(self):
        """Alias for MediaControlsVisible"""
        return self.MediaControlsVisible

    @property
    def MediaControlsWidth(self):
        return self.com_object.MediaControlsWidth

    @property
    def mediacontrolswidth(self):
        """Alias for MediaControlsWidth"""
        return self.MediaControlsWidth

    @property
    def media_controls_width(self):
        """Alias for MediaControlsWidth"""
        return self.MediaControlsWidth

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PointerColor(self):
        return ColorFormat(self.com_object.PointerColor)

    @property
    def pointercolor(self):
        """Alias for PointerColor"""
        return self.PointerColor

    @property
    def pointer_color(self):
        """Alias for PointerColor"""
        return self.PointerColor

    @property
    def PointerType(self):
        return self.com_object.PointerType

    @PointerType.setter
    def PointerType(self, value):
        self.com_object.PointerType = value

    @property
    def pointertype(self):
        """Alias for PointerType"""
        return self.PointerType

    @pointertype.setter
    def pointertype(self, value):
        """Alias for PointerType.setter"""
        self.PointerType = value

    @property
    def pointer_type(self):
        """Alias for PointerType"""
        return self.PointerType

    @pointer_type.setter
    def pointer_type(self, value):
        """Alias for PointerType.setter"""
        self.PointerType = value

    @property
    def PresentationElapsedTime(self):
        return self.com_object.PresentationElapsedTime

    @property
    def presentationelapsedtime(self):
        """Alias for PresentationElapsedTime"""
        return self.PresentationElapsedTime

    @property
    def presentation_elapsed_time(self):
        """Alias for PresentationElapsedTime"""
        return self.PresentationElapsedTime

    @property
    def Slide(self):
        return Slide(self.com_object.Slide)

    @property
    def slide(self):
        """Alias for Slide"""
        return self.Slide

    @property
    def SlideElapsedTime(self):
        return self.com_object.SlideElapsedTime

    @SlideElapsedTime.setter
    def SlideElapsedTime(self, value):
        self.com_object.SlideElapsedTime = value

    @property
    def slideelapsedtime(self):
        """Alias for SlideElapsedTime"""
        return self.SlideElapsedTime

    @slideelapsedtime.setter
    def slideelapsedtime(self, value):
        """Alias for SlideElapsedTime.setter"""
        self.SlideElapsedTime = value

    @property
    def slide_elapsed_time(self):
        """Alias for SlideElapsedTime"""
        return self.SlideElapsedTime

    @slide_elapsed_time.setter
    def slide_elapsed_time(self, value):
        """Alias for SlideElapsedTime.setter"""
        self.SlideElapsedTime = value

    @property
    def SlideShowName(self):
        return self.com_object.SlideShowName

    @property
    def slideshowname(self):
        """Alias for SlideShowName"""
        return self.SlideShowName

    @property
    def slide_show_name(self):
        """Alias for SlideShowName"""
        return self.SlideShowName

    @property
    def State(self):
        return self.com_object.State

    @State.setter
    def State(self, value):
        self.com_object.State = value

    @property
    def state(self):
        """Alias for State"""
        return self.State

    @state.setter
    def state(self, value):
        """Alias for State.setter"""
        self.State = value

    @property
    def Zoom(self):
        return self.com_object.Zoom

    @property
    def zoom(self):
        """Alias for Zoom"""
        return self.Zoom

    def DrawLine(self, BeginX=None, BeginY=None, EndX=None, EndY=None):
        arguments = com_arguments([unwrap(a) for a in [BeginX, BeginY, EndX, EndY]])
        self.com_object.DrawLine(*arguments)

    def drawline(self, BeginX=None, BeginY=None, EndX=None, EndY=None):
        """Alias for DrawLine"""
        arguments = [BeginX, BeginY, EndX, EndY]
        return self.DrawLine(*arguments)

    def draw_line(self, BeginX=None, BeginY=None, EndX=None, EndY=None):
        """Alias for DrawLine"""
        arguments = [BeginX, BeginY, EndX, EndY]
        return self.DrawLine(*arguments)

    def EndNamedShow(self):
        self.com_object.EndNamedShow()

    def endnamedshow(self):
        """Alias for EndNamedShow"""
        return self.EndNamedShow()

    def end_named_show(self):
        """Alias for EndNamedShow"""
        return self.EndNamedShow()

    def EraseDrawing(self):
        self.com_object.EraseDrawing()

    def erasedrawing(self):
        """Alias for EraseDrawing"""
        return self.EraseDrawing()

    def erase_drawing(self):
        """Alias for EraseDrawing"""
        return self.EraseDrawing()

    def Exit(self):
        self.com_object.Exit()

    def exit(self):
        """Alias for Exit"""
        return self.Exit()

    def First(self):
        return self.com_object.First()

    def first(self):
        """Alias for First"""
        return self.First()

    def FirstAnimationIsAutomatic(self):
        return self.com_object.FirstAnimationIsAutomatic()

    def firstanimationisautomatic(self):
        """Alias for FirstAnimationIsAutomatic"""
        return self.FirstAnimationIsAutomatic()

    def first_animation_is_automatic(self):
        """Alias for FirstAnimationIsAutomatic"""
        return self.FirstAnimationIsAutomatic()

    def GetClickCount(self):
        return self.com_object.GetClickCount()

    def getclickcount(self):
        """Alias for GetClickCount"""
        return self.GetClickCount()

    def get_click_count(self):
        """Alias for GetClickCount"""
        return self.GetClickCount()

    def GetClickIndex(self):
        return self.com_object.GetClickIndex()

    def getclickindex(self):
        """Alias for GetClickIndex"""
        return self.GetClickIndex()

    def get_click_index(self):
        """Alias for GetClickIndex"""
        return self.GetClickIndex()

    def GotoClick(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.GotoClick(*arguments)

    def gotoclick(self, Index=None):
        """Alias for GotoClick"""
        arguments = [Index]
        return self.GotoClick(*arguments)

    def goto_click(self, Index=None):
        """Alias for GotoClick"""
        arguments = [Index]
        return self.GotoClick(*arguments)

    def GotoNamedShow(self, SlideShowName=None):
        arguments = com_arguments([unwrap(a) for a in [SlideShowName]])
        self.com_object.GotoNamedShow(*arguments)

    def gotonamedshow(self, SlideShowName=None):
        """Alias for GotoNamedShow"""
        arguments = [SlideShowName]
        return self.GotoNamedShow(*arguments)

    def goto_named_show(self, SlideShowName=None):
        """Alias for GotoNamedShow"""
        arguments = [SlideShowName]
        return self.GotoNamedShow(*arguments)

    def GotoSlide(self, Index=None, ResetSlide=None):
        arguments = com_arguments([unwrap(a) for a in [Index, ResetSlide]])
        self.com_object.GotoSlide(*arguments)

    def gotoslide(self, Index=None, ResetSlide=None):
        """Alias for GotoSlide"""
        arguments = [Index, ResetSlide]
        return self.GotoSlide(*arguments)

    def goto_slide(self, Index=None, ResetSlide=None):
        """Alias for GotoSlide"""
        arguments = [Index, ResetSlide]
        return self.GotoSlide(*arguments)

    def Last(self):
        self.com_object.Last()

    def last(self):
        """Alias for Last"""
        return self.Last()

    def Next(self):
        self.com_object.Next()

    def next(self):
        """Alias for Next"""
        return self.Next()

    def Player(self, ShapeId=None):
        arguments = com_arguments([unwrap(a) for a in [ShapeId]])
        return Player(self.com_object.Player(*arguments))

    def player(self, ShapeId=None):
        """Alias for Player"""
        arguments = [ShapeId]
        return self.Player(*arguments)

    def Previous(self):
        self.com_object.Previous()

    def previous(self):
        """Alias for Previous"""
        return self.Previous()

    def ResetSlideTime(self):
        self.com_object.ResetSlideTime()

    def resetslidetime(self):
        """Alias for ResetSlideTime"""
        return self.ResetSlideTime()

    def reset_slide_time(self):
        """Alias for ResetSlideTime"""
        return self.ResetSlideTime()


class SlideShowWindow:

    def __init__(self, slideshowwindow=None):
        self.com_object= slideshowwindow

    @property
    def Active(self):
        return self.com_object.Active

    @property
    def active(self):
        """Alias for Active"""
        return self.Active

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def IsFullScreen(self):
        return self.com_object.IsFullScreen

    @property
    def isfullscreen(self):
        """Alias for IsFullScreen"""
        return self.IsFullScreen

    @property
    def is_full_screen(self):
        """Alias for IsFullScreen"""
        return self.IsFullScreen

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Presentation(self):
        return Presentation(self.com_object.Presentation)

    @property
    def presentation(self):
        """Alias for Presentation"""
        return self.Presentation

    @property
    def SlideNavigation(self):
        return SlideNavigation(self.com_object.SlideNavigation)

    @property
    def slidenavigation(self):
        """Alias for SlideNavigation"""
        return self.SlideNavigation

    @property
    def slide_navigation(self):
        """Alias for SlideNavigation"""
        return self.SlideNavigation

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def View(self):
        return SlideShowView(self.com_object.View)

    @property
    def view(self):
        """Alias for View"""
        return self.View

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Activate(self):
        self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()


class SlideShowWindows:

    def __init__(self, slideshowwindows=None):
        self.com_object= slideshowwindows

    def __call__(self, item):
        return SlideShowWindow(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return SlideShowWindow(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class SoundEffect:

    def __init__(self, soundeffect=None):
        self.com_object= soundeffect

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    def ImportFromFile(self, FullName=None):
        arguments = com_arguments([unwrap(a) for a in [FullName]])
        self.com_object.ImportFromFile(*arguments)

    def importfromfile(self, FullName=None):
        """Alias for ImportFromFile"""
        arguments = [FullName]
        return self.ImportFromFile(*arguments)

    def import_from_file(self, FullName=None):
        """Alias for ImportFromFile"""
        arguments = [FullName]
        return self.ImportFromFile(*arguments)

    def Play(self):
        self.com_object.Play()

    def play(self):
        """Alias for Play"""
        return self.Play()


class Table:

    def __init__(self, table=None):
        self.com_object= table

    @property
    def AlternativeText(self):
        return self.com_object.AlternativeText

    @AlternativeText.setter
    def AlternativeText(self, value):
        self.com_object.AlternativeText = value

    @property
    def alternativetext(self):
        """Alias for AlternativeText"""
        return self.AlternativeText

    @alternativetext.setter
    def alternativetext(self, value):
        """Alias for AlternativeText.setter"""
        self.AlternativeText = value

    @property
    def alternative_text(self):
        """Alias for AlternativeText"""
        return self.AlternativeText

    @alternative_text.setter
    def alternative_text(self, value):
        """Alias for AlternativeText.setter"""
        self.AlternativeText = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Background(self):
        return TableBackground(self.com_object.Background)

    @property
    def background(self):
        """Alias for Background"""
        return self.Background

    @property
    def Columns(self):
        return Columns(self.com_object.Columns)

    @property
    def columns(self):
        """Alias for Columns"""
        return self.Columns

    @property
    def FirstCol(self):
        return self.com_object.FirstCol

    @FirstCol.setter
    def FirstCol(self, value):
        self.com_object.FirstCol = value

    @property
    def firstcol(self):
        """Alias for FirstCol"""
        return self.FirstCol

    @firstcol.setter
    def firstcol(self, value):
        """Alias for FirstCol.setter"""
        self.FirstCol = value

    @property
    def first_col(self):
        """Alias for FirstCol"""
        return self.FirstCol

    @first_col.setter
    def first_col(self, value):
        """Alias for FirstCol.setter"""
        self.FirstCol = value

    @property
    def FirstRow(self):
        return self.com_object.FirstRow

    @FirstRow.setter
    def FirstRow(self, value):
        self.com_object.FirstRow = value

    @property
    def firstrow(self):
        """Alias for FirstRow"""
        return self.FirstRow

    @firstrow.setter
    def firstrow(self, value):
        """Alias for FirstRow.setter"""
        self.FirstRow = value

    @property
    def first_row(self):
        """Alias for FirstRow"""
        return self.FirstRow

    @first_row.setter
    def first_row(self, value):
        """Alias for FirstRow.setter"""
        self.FirstRow = value

    @property
    def HorizBanding(self):
        return self.com_object.HorizBanding

    @HorizBanding.setter
    def HorizBanding(self, value):
        self.com_object.HorizBanding = value

    @property
    def horizbanding(self):
        """Alias for HorizBanding"""
        return self.HorizBanding

    @horizbanding.setter
    def horizbanding(self, value):
        """Alias for HorizBanding.setter"""
        self.HorizBanding = value

    @property
    def horiz_banding(self):
        """Alias for HorizBanding"""
        return self.HorizBanding

    @horiz_banding.setter
    def horiz_banding(self, value):
        """Alias for HorizBanding.setter"""
        self.HorizBanding = value

    @property
    def LastCol(self):
        return self.com_object.LastCol

    @LastCol.setter
    def LastCol(self, value):
        self.com_object.LastCol = value

    @property
    def lastcol(self):
        """Alias for LastCol"""
        return self.LastCol

    @lastcol.setter
    def lastcol(self, value):
        """Alias for LastCol.setter"""
        self.LastCol = value

    @property
    def last_col(self):
        """Alias for LastCol"""
        return self.LastCol

    @last_col.setter
    def last_col(self, value):
        """Alias for LastCol.setter"""
        self.LastCol = value

    @property
    def LastRow(self):
        return self.com_object.LastRow

    @LastRow.setter
    def LastRow(self, value):
        self.com_object.LastRow = value

    @property
    def lastrow(self):
        """Alias for LastRow"""
        return self.LastRow

    @lastrow.setter
    def lastrow(self, value):
        """Alias for LastRow.setter"""
        self.LastRow = value

    @property
    def last_row(self):
        """Alias for LastRow"""
        return self.LastRow

    @last_row.setter
    def last_row(self, value):
        """Alias for LastRow.setter"""
        self.LastRow = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Rows(self):
        return Rows(self.com_object.Rows)

    @property
    def rows(self):
        """Alias for Rows"""
        return self.Rows

    @property
    def Style(self):
        return TableStyle(self.com_object.Style)

    @property
    def style(self):
        """Alias for Style"""
        return self.Style

    @property
    def TableDirection(self):
        return self.com_object.TableDirection

    @TableDirection.setter
    def TableDirection(self, value):
        self.com_object.TableDirection = value

    @property
    def tabledirection(self):
        """Alias for TableDirection"""
        return self.TableDirection

    @tabledirection.setter
    def tabledirection(self, value):
        """Alias for TableDirection.setter"""
        self.TableDirection = value

    @property
    def table_direction(self):
        """Alias for TableDirection"""
        return self.TableDirection

    @table_direction.setter
    def table_direction(self, value):
        """Alias for TableDirection.setter"""
        self.TableDirection = value

    @property
    def Title(self):
        return Table(self.com_object.Title)

    @Title.setter
    def Title(self, value):
        self.com_object.Title = value

    @property
    def title(self):
        """Alias for Title"""
        return self.Title

    @title.setter
    def title(self, value):
        """Alias for Title.setter"""
        self.Title = value

    @property
    def VertBanding(self):
        return self.com_object.VertBanding

    @VertBanding.setter
    def VertBanding(self, value):
        self.com_object.VertBanding = value

    @property
    def vertbanding(self):
        """Alias for VertBanding"""
        return self.VertBanding

    @vertbanding.setter
    def vertbanding(self, value):
        """Alias for VertBanding.setter"""
        self.VertBanding = value

    @property
    def vert_banding(self):
        """Alias for VertBanding"""
        return self.VertBanding

    @vert_banding.setter
    def vert_banding(self, value):
        """Alias for VertBanding.setter"""
        self.VertBanding = value

    def ApplyStyle(self, StyleID=None, SaveFormatting=None):
        arguments = com_arguments([unwrap(a) for a in [StyleID, SaveFormatting]])
        self.com_object.ApplyStyle(*arguments)

    def applystyle(self, StyleID=None, SaveFormatting=None):
        """Alias for ApplyStyle"""
        arguments = [StyleID, SaveFormatting]
        return self.ApplyStyle(*arguments)

    def apply_style(self, StyleID=None, SaveFormatting=None):
        """Alias for ApplyStyle"""
        arguments = [StyleID, SaveFormatting]
        return self.ApplyStyle(*arguments)

    def Cell(self, Row=None, Column=None):
        arguments = com_arguments([unwrap(a) for a in [Row, Column]])
        return Cell(self.com_object.Cell(*arguments))

    def cell(self, Row=None, Column=None):
        """Alias for Cell"""
        arguments = [Row, Column]
        return self.Cell(*arguments)

    def ScaleProportionally(self, scale=None):
        arguments = com_arguments([unwrap(a) for a in [scale]])
        self.com_object.ScaleProportionally(*arguments)

    def scaleproportionally(self, scale=None):
        """Alias for ScaleProportionally"""
        arguments = [scale]
        return self.ScaleProportionally(*arguments)

    def scale_proportionally(self, scale=None):
        """Alias for ScaleProportionally"""
        arguments = [scale]
        return self.ScaleProportionally(*arguments)


class TableBackground:

    def __init__(self, tablebackground=None):
        self.com_object= tablebackground

    @property
    def Fill(self):
        return FillFormat(self.com_object.Fill)

    @property
    def fill(self):
        """Alias for Fill"""
        return self.Fill

    @property
    def Picture(self):
        return PictureFormat(self.com_object.Picture)

    @property
    def picture(self):
        """Alias for Picture"""
        return self.Picture

    @property
    def Reflection(self):
        return self.com_object.Reflection

    @property
    def reflection(self):
        """Alias for Reflection"""
        return self.Reflection

    @property
    def Shadow(self):
        return ShadowFormat(self.com_object.Shadow)

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow


class TableStyle:

    def __init__(self, tablestyle=None):
        self.com_object= tablestyle

    @property
    def Id(self):
        return self.com_object.Id

    @property
    def id(self):
        """Alias for Id"""
        return self.Id

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name


class TabStop:

    def __init__(self, tabstop=None):
        self.com_object= tabstop

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return self.com_object.Position

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    def Clear(self):
        self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()


class TabStops:

    def __init__(self, tabstops=None):
        self.com_object= tabstops

    def __call__(self, item):
        return TabStop(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def DefaultSpacing(self):
        return self.com_object.DefaultSpacing

    @DefaultSpacing.setter
    def DefaultSpacing(self, value):
        self.com_object.DefaultSpacing = value

    @property
    def defaultspacing(self):
        """Alias for DefaultSpacing"""
        return self.DefaultSpacing

    @defaultspacing.setter
    def defaultspacing(self, value):
        """Alias for DefaultSpacing.setter"""
        self.DefaultSpacing = value

    @property
    def default_spacing(self):
        """Alias for DefaultSpacing"""
        return self.DefaultSpacing

    @default_spacing.setter
    def default_spacing(self, value):
        """Alias for DefaultSpacing.setter"""
        self.DefaultSpacing = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Type=None, Position=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Position]])
        return TabStop(self.com_object.Add(*arguments))

    def add(self, Type=None, Position=None):
        """Alias for Add"""
        arguments = [Type, Position]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return TabStop(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Tags:

    def __init__(self, tags=None):
        self.com_object= tags

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, Value=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Value]])
        self.com_object.Add(*arguments)

    def add(self, Name=None, Value=None):
        """Alias for Add"""
        arguments = [Name, Value]
        return self.Add(*arguments)

    def Delete(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        self.com_object.Delete(*arguments)

    def delete(self, Name=None):
        """Alias for Delete"""
        arguments = [Name]
        return self.Delete(*arguments)

    def Item(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        return self.com_object.Item(*arguments)

    def item(self, Name=None):
        """Alias for Item"""
        arguments = [Name]
        return self.Item(*arguments)

    def Name(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Name(*arguments)

    def name(self, Index=None):
        """Alias for Name"""
        arguments = [Index]
        return self.Name(*arguments)

    def Value(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Value(*arguments)

    def value(self, Index=None):
        """Alias for Value"""
        arguments = [Index]
        return self.Value(*arguments)


class TextEffectFormat:

    def __init__(self, texteffectformat=None):
        self.com_object= texteffectformat

    @property
    def Alignment(self):
        return self.com_object.Alignment

    @Alignment.setter
    def Alignment(self, value):
        self.com_object.Alignment = value

    @property
    def alignment(self):
        """Alias for Alignment"""
        return self.Alignment

    @alignment.setter
    def alignment(self, value):
        """Alias for Alignment.setter"""
        self.Alignment = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def FontBold(self):
        return self.com_object.FontBold

    @FontBold.setter
    def FontBold(self, value):
        self.com_object.FontBold = value

    @property
    def fontbold(self):
        """Alias for FontBold"""
        return self.FontBold

    @fontbold.setter
    def fontbold(self, value):
        """Alias for FontBold.setter"""
        self.FontBold = value

    @property
    def font_bold(self):
        """Alias for FontBold"""
        return self.FontBold

    @font_bold.setter
    def font_bold(self, value):
        """Alias for FontBold.setter"""
        self.FontBold = value

    @property
    def FontItalic(self):
        return self.com_object.FontItalic

    @FontItalic.setter
    def FontItalic(self, value):
        self.com_object.FontItalic = value

    @property
    def fontitalic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @fontitalic.setter
    def fontitalic(self, value):
        """Alias for FontItalic.setter"""
        self.FontItalic = value

    @property
    def font_italic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @font_italic.setter
    def font_italic(self, value):
        """Alias for FontItalic.setter"""
        self.FontItalic = value

    @property
    def FontName(self):
        return self.com_object.FontName

    @FontName.setter
    def FontName(self, value):
        self.com_object.FontName = value

    @property
    def fontname(self):
        """Alias for FontName"""
        return self.FontName

    @fontname.setter
    def fontname(self, value):
        """Alias for FontName.setter"""
        self.FontName = value

    @property
    def font_name(self):
        """Alias for FontName"""
        return self.FontName

    @font_name.setter
    def font_name(self, value):
        """Alias for FontName.setter"""
        self.FontName = value

    @property
    def FontSize(self):
        return self.com_object.FontSize

    @FontSize.setter
    def FontSize(self, value):
        self.com_object.FontSize = value

    @property
    def fontsize(self):
        """Alias for FontSize"""
        return self.FontSize

    @fontsize.setter
    def fontsize(self, value):
        """Alias for FontSize.setter"""
        self.FontSize = value

    @property
    def font_size(self):
        """Alias for FontSize"""
        return self.FontSize

    @font_size.setter
    def font_size(self, value):
        """Alias for FontSize.setter"""
        self.FontSize = value

    @property
    def KernedPairs(self):
        return self.com_object.KernedPairs

    @KernedPairs.setter
    def KernedPairs(self, value):
        self.com_object.KernedPairs = value

    @property
    def kernedpairs(self):
        """Alias for KernedPairs"""
        return self.KernedPairs

    @kernedpairs.setter
    def kernedpairs(self, value):
        """Alias for KernedPairs.setter"""
        self.KernedPairs = value

    @property
    def kerned_pairs(self):
        """Alias for KernedPairs"""
        return self.KernedPairs

    @kerned_pairs.setter
    def kerned_pairs(self, value):
        """Alias for KernedPairs.setter"""
        self.KernedPairs = value

    @property
    def NormalizedHeight(self):
        return self.com_object.NormalizedHeight

    @NormalizedHeight.setter
    def NormalizedHeight(self, value):
        self.com_object.NormalizedHeight = value

    @property
    def normalizedheight(self):
        """Alias for NormalizedHeight"""
        return self.NormalizedHeight

    @normalizedheight.setter
    def normalizedheight(self, value):
        """Alias for NormalizedHeight.setter"""
        self.NormalizedHeight = value

    @property
    def normalized_height(self):
        """Alias for NormalizedHeight"""
        return self.NormalizedHeight

    @normalized_height.setter
    def normalized_height(self, value):
        """Alias for NormalizedHeight.setter"""
        self.NormalizedHeight = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PresetShape(self):
        return self.com_object.PresetShape

    @PresetShape.setter
    def PresetShape(self, value):
        self.com_object.PresetShape = value

    @property
    def presetshape(self):
        """Alias for PresetShape"""
        return self.PresetShape

    @presetshape.setter
    def presetshape(self, value):
        """Alias for PresetShape.setter"""
        self.PresetShape = value

    @property
    def preset_shape(self):
        """Alias for PresetShape"""
        return self.PresetShape

    @preset_shape.setter
    def preset_shape(self, value):
        """Alias for PresetShape.setter"""
        self.PresetShape = value

    @property
    def PresetTextEffect(self):
        return self.com_object.PresetTextEffect

    @PresetTextEffect.setter
    def PresetTextEffect(self, value):
        self.com_object.PresetTextEffect = value

    @property
    def presettexteffect(self):
        """Alias for PresetTextEffect"""
        return self.PresetTextEffect

    @presettexteffect.setter
    def presettexteffect(self, value):
        """Alias for PresetTextEffect.setter"""
        self.PresetTextEffect = value

    @property
    def preset_text_effect(self):
        """Alias for PresetTextEffect"""
        return self.PresetTextEffect

    @preset_text_effect.setter
    def preset_text_effect(self, value):
        """Alias for PresetTextEffect.setter"""
        self.PresetTextEffect = value

    @property
    def RotatedChars(self):
        return self.com_object.RotatedChars

    @RotatedChars.setter
    def RotatedChars(self, value):
        self.com_object.RotatedChars = value

    @property
    def rotatedchars(self):
        """Alias for RotatedChars"""
        return self.RotatedChars

    @rotatedchars.setter
    def rotatedchars(self, value):
        """Alias for RotatedChars.setter"""
        self.RotatedChars = value

    @property
    def rotated_chars(self):
        """Alias for RotatedChars"""
        return self.RotatedChars

    @rotated_chars.setter
    def rotated_chars(self, value):
        """Alias for RotatedChars.setter"""
        self.RotatedChars = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def Tracking(self):
        return self.com_object.Tracking

    @Tracking.setter
    def Tracking(self, value):
        self.com_object.Tracking = value

    @property
    def tracking(self):
        """Alias for Tracking"""
        return self.Tracking

    @tracking.setter
    def tracking(self, value):
        """Alias for Tracking.setter"""
        self.Tracking = value

    def ToggleVerticalText(self):
        self.com_object.ToggleVerticalText()

    def toggleverticaltext(self):
        """Alias for ToggleVerticalText"""
        return self.ToggleVerticalText()

    def toggle_vertical_text(self):
        """Alias for ToggleVerticalText"""
        return self.ToggleVerticalText()


class TextFrame:

    def __init__(self, textframe=None):
        self.com_object= textframe

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoSize(self):
        return self.com_object.AutoSize

    @AutoSize.setter
    def AutoSize(self, value):
        self.com_object.AutoSize = value

    @property
    def autosize(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @autosize.setter
    def autosize(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def auto_size(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @auto_size.setter
    def auto_size(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def HasText(self):
        return self.com_object.HasText

    @property
    def hastext(self):
        """Alias for HasText"""
        return self.HasText

    @property
    def has_text(self):
        """Alias for HasText"""
        return self.HasText

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def MarginBottom(self):
        return self.com_object.MarginBottom

    @MarginBottom.setter
    def MarginBottom(self, value):
        self.com_object.MarginBottom = value

    @property
    def marginbottom(self):
        """Alias for MarginBottom"""
        return self.MarginBottom

    @marginbottom.setter
    def marginbottom(self, value):
        """Alias for MarginBottom.setter"""
        self.MarginBottom = value

    @property
    def margin_bottom(self):
        """Alias for MarginBottom"""
        return self.MarginBottom

    @margin_bottom.setter
    def margin_bottom(self, value):
        """Alias for MarginBottom.setter"""
        self.MarginBottom = value

    @property
    def MarginLeft(self):
        return self.com_object.MarginLeft

    @MarginLeft.setter
    def MarginLeft(self, value):
        self.com_object.MarginLeft = value

    @property
    def marginleft(self):
        """Alias for MarginLeft"""
        return self.MarginLeft

    @marginleft.setter
    def marginleft(self, value):
        """Alias for MarginLeft.setter"""
        self.MarginLeft = value

    @property
    def margin_left(self):
        """Alias for MarginLeft"""
        return self.MarginLeft

    @margin_left.setter
    def margin_left(self, value):
        """Alias for MarginLeft.setter"""
        self.MarginLeft = value

    @property
    def MarginRight(self):
        return self.com_object.MarginRight

    @MarginRight.setter
    def MarginRight(self, value):
        self.com_object.MarginRight = value

    @property
    def marginright(self):
        """Alias for MarginRight"""
        return self.MarginRight

    @marginright.setter
    def marginright(self, value):
        """Alias for MarginRight.setter"""
        self.MarginRight = value

    @property
    def margin_right(self):
        """Alias for MarginRight"""
        return self.MarginRight

    @margin_right.setter
    def margin_right(self, value):
        """Alias for MarginRight.setter"""
        self.MarginRight = value

    @property
    def MarginTop(self):
        return self.com_object.MarginTop

    @MarginTop.setter
    def MarginTop(self, value):
        self.com_object.MarginTop = value

    @property
    def margintop(self):
        """Alias for MarginTop"""
        return self.MarginTop

    @margintop.setter
    def margintop(self, value):
        """Alias for MarginTop.setter"""
        self.MarginTop = value

    @property
    def margin_top(self):
        """Alias for MarginTop"""
        return self.MarginTop

    @margin_top.setter
    def margin_top(self, value):
        """Alias for MarginTop.setter"""
        self.MarginTop = value

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Ruler(self):
        return Ruler(self.com_object.Ruler)

    @property
    def ruler(self):
        """Alias for Ruler"""
        return self.Ruler

    @property
    def TextRange(self):
        return TextRange(self.com_object.TextRange)

    @property
    def textrange(self):
        """Alias for TextRange"""
        return self.TextRange

    @property
    def text_range(self):
        """Alias for TextRange"""
        return self.TextRange

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def WordWrap(self):
        return self.com_object.WordWrap

    @WordWrap.setter
    def WordWrap(self, value):
        self.com_object.WordWrap = value

    @property
    def wordwrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @wordwrap.setter
    def wordwrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value

    @property
    def word_wrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @word_wrap.setter
    def word_wrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value

    def DeleteText(self):
        self.com_object.DeleteText()

    def deletetext(self):
        """Alias for DeleteText"""
        return self.DeleteText()

    def delete_text(self):
        """Alias for DeleteText"""
        return self.DeleteText()


class TextFrame2:

    def __init__(self, textframe2=None):
        self.com_object= textframe2

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoSize(self):
        return self.com_object.AutoSize

    @AutoSize.setter
    def AutoSize(self, value):
        self.com_object.AutoSize = value

    @property
    def autosize(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @autosize.setter
    def autosize(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def auto_size(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @auto_size.setter
    def auto_size(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def Column(self):
        return Column(self.com_object.Column)

    @property
    def column(self):
        """Alias for Column"""
        return self.Column

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def HasText(self):
        return self.com_object.HasText

    @property
    def hastext(self):
        """Alias for HasText"""
        return self.HasText

    @property
    def has_text(self):
        """Alias for HasText"""
        return self.HasText

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def MarginBottom(self):
        return self.com_object.MarginBottom

    @MarginBottom.setter
    def MarginBottom(self, value):
        self.com_object.MarginBottom = value

    @property
    def marginbottom(self):
        """Alias for MarginBottom"""
        return self.MarginBottom

    @marginbottom.setter
    def marginbottom(self, value):
        """Alias for MarginBottom.setter"""
        self.MarginBottom = value

    @property
    def margin_bottom(self):
        """Alias for MarginBottom"""
        return self.MarginBottom

    @margin_bottom.setter
    def margin_bottom(self, value):
        """Alias for MarginBottom.setter"""
        self.MarginBottom = value

    @property
    def MarginLeft(self):
        return self.com_object.MarginLeft

    @MarginLeft.setter
    def MarginLeft(self, value):
        self.com_object.MarginLeft = value

    @property
    def marginleft(self):
        """Alias for MarginLeft"""
        return self.MarginLeft

    @marginleft.setter
    def marginleft(self, value):
        """Alias for MarginLeft.setter"""
        self.MarginLeft = value

    @property
    def margin_left(self):
        """Alias for MarginLeft"""
        return self.MarginLeft

    @margin_left.setter
    def margin_left(self, value):
        """Alias for MarginLeft.setter"""
        self.MarginLeft = value

    @property
    def MarginRight(self):
        return self.com_object.MarginRight

    @MarginRight.setter
    def MarginRight(self, value):
        self.com_object.MarginRight = value

    @property
    def marginright(self):
        """Alias for MarginRight"""
        return self.MarginRight

    @marginright.setter
    def marginright(self, value):
        """Alias for MarginRight.setter"""
        self.MarginRight = value

    @property
    def margin_right(self):
        """Alias for MarginRight"""
        return self.MarginRight

    @margin_right.setter
    def margin_right(self, value):
        """Alias for MarginRight.setter"""
        self.MarginRight = value

    @property
    def MarginTop(self):
        return self.com_object.MarginTop

    @MarginTop.setter
    def MarginTop(self, value):
        self.com_object.MarginTop = value

    @property
    def margintop(self):
        """Alias for MarginTop"""
        return self.MarginTop

    @margintop.setter
    def margintop(self, value):
        """Alias for MarginTop.setter"""
        self.MarginTop = value

    @property
    def margin_top(self):
        """Alias for MarginTop"""
        return self.MarginTop

    @margin_top.setter
    def margin_top(self, value):
        """Alias for MarginTop.setter"""
        self.MarginTop = value

    @property
    def NoTextRotation(self):
        return self.com_object.NoTextRotation

    @NoTextRotation.setter
    def NoTextRotation(self, value):
        self.com_object.NoTextRotation = value

    @property
    def notextrotation(self):
        """Alias for NoTextRotation"""
        return self.NoTextRotation

    @notextrotation.setter
    def notextrotation(self, value):
        """Alias for NoTextRotation.setter"""
        self.NoTextRotation = value

    @property
    def no_text_rotation(self):
        """Alias for NoTextRotation"""
        return self.NoTextRotation

    @no_text_rotation.setter
    def no_text_rotation(self, value):
        """Alias for NoTextRotation.setter"""
        self.NoTextRotation = value

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PathFormat(self):
        return self.com_object.PathFormat

    @PathFormat.setter
    def PathFormat(self, value):
        self.com_object.PathFormat = value

    @property
    def pathformat(self):
        """Alias for PathFormat"""
        return self.PathFormat

    @pathformat.setter
    def pathformat(self, value):
        """Alias for PathFormat.setter"""
        self.PathFormat = value

    @property
    def path_format(self):
        """Alias for PathFormat"""
        return self.PathFormat

    @path_format.setter
    def path_format(self, value):
        """Alias for PathFormat.setter"""
        self.PathFormat = value

    @property
    def Ruler(self):
        return self.com_object.Ruler

    @property
    def ruler(self):
        """Alias for Ruler"""
        return self.Ruler

    @property
    def TextRange(self):
        return self.com_object.TextRange

    @property
    def textrange(self):
        """Alias for TextRange"""
        return self.TextRange

    @property
    def text_range(self):
        """Alias for TextRange"""
        return self.TextRange

    @property
    def ThreeD(self):
        return ThreeDFormat(self.com_object.ThreeD)

    @property
    def threed(self):
        """Alias for ThreeD"""
        return self.ThreeD

    @property
    def three_d(self):
        """Alias for ThreeD"""
        return self.ThreeD

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def WarpFormat(self):
        return self.com_object.WarpFormat

    @WarpFormat.setter
    def WarpFormat(self, value):
        self.com_object.WarpFormat = value

    @property
    def warpformat(self):
        """Alias for WarpFormat"""
        return self.WarpFormat

    @warpformat.setter
    def warpformat(self, value):
        """Alias for WarpFormat.setter"""
        self.WarpFormat = value

    @property
    def warp_format(self):
        """Alias for WarpFormat"""
        return self.WarpFormat

    @warp_format.setter
    def warp_format(self, value):
        """Alias for WarpFormat.setter"""
        self.WarpFormat = value

    @property
    def WordArtFormat(self):
        return self.com_object.WordArtFormat

    @WordArtFormat.setter
    def WordArtFormat(self, value):
        self.com_object.WordArtFormat = value

    @property
    def wordartformat(self):
        """Alias for WordArtFormat"""
        return self.WordArtFormat

    @wordartformat.setter
    def wordartformat(self, value):
        """Alias for WordArtFormat.setter"""
        self.WordArtFormat = value

    @property
    def word_art_format(self):
        """Alias for WordArtFormat"""
        return self.WordArtFormat

    @word_art_format.setter
    def word_art_format(self, value):
        """Alias for WordArtFormat.setter"""
        self.WordArtFormat = value

    @property
    def WordWrap(self):
        return self.com_object.WordWrap

    @WordWrap.setter
    def WordWrap(self, value):
        self.com_object.WordWrap = value

    @property
    def wordwrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @wordwrap.setter
    def wordwrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value

    @property
    def word_wrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @word_wrap.setter
    def word_wrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value

    def DeleteText(self):
        return self.com_object.DeleteText()

    def deletetext(self):
        """Alias for DeleteText"""
        return self.DeleteText()

    def delete_text(self):
        """Alias for DeleteText"""
        return self.DeleteText()


class TextRange:

    def __init__(self, textrange=None):
        self.com_object= textrange

    @property
    def ActionSettings(self):
        return ActionSettings(self.com_object.ActionSettings)

    @property
    def actionsettings(self):
        """Alias for ActionSettings"""
        return self.ActionSettings

    @property
    def action_settings(self):
        """Alias for ActionSettings"""
        return self.ActionSettings

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BoundHeight(self):
        return self.com_object.BoundHeight

    @property
    def boundheight(self):
        """Alias for BoundHeight"""
        return self.BoundHeight

    @property
    def bound_height(self):
        """Alias for BoundHeight"""
        return self.BoundHeight

    @property
    def BoundLeft(self):
        return self.com_object.BoundLeft

    @property
    def boundleft(self):
        """Alias for BoundLeft"""
        return self.BoundLeft

    @property
    def bound_left(self):
        """Alias for BoundLeft"""
        return self.BoundLeft

    @property
    def BoundTop(self):
        return self.com_object.BoundTop

    @property
    def boundtop(self):
        """Alias for BoundTop"""
        return self.BoundTop

    @property
    def bound_top(self):
        """Alias for BoundTop"""
        return self.BoundTop

    @property
    def BoundWidth(self):
        return self.com_object.BoundWidth

    @property
    def boundwidth(self):
        """Alias for BoundWidth"""
        return self.BoundWidth

    @property
    def bound_width(self):
        """Alias for BoundWidth"""
        return self.BoundWidth

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def IndentLevel(self):
        return self.com_object.IndentLevel

    @IndentLevel.setter
    def IndentLevel(self, value):
        self.com_object.IndentLevel = value

    @property
    def indentlevel(self):
        """Alias for IndentLevel"""
        return self.IndentLevel

    @indentlevel.setter
    def indentlevel(self, value):
        """Alias for IndentLevel.setter"""
        self.IndentLevel = value

    @property
    def indent_level(self):
        """Alias for IndentLevel"""
        return self.IndentLevel

    @indent_level.setter
    def indent_level(self, value):
        """Alias for IndentLevel.setter"""
        self.IndentLevel = value

    @property
    def LanguageID(self):
        return self.com_object.LanguageID

    @LanguageID.setter
    def LanguageID(self, value):
        self.com_object.LanguageID = value

    @property
    def languageid(self):
        """Alias for LanguageID"""
        return self.LanguageID

    @languageid.setter
    def languageid(self, value):
        """Alias for LanguageID.setter"""
        self.LanguageID = value

    @property
    def language_i_d(self):
        """Alias for LanguageID"""
        return self.LanguageID

    @language_i_d.setter
    def language_i_d(self, value):
        """Alias for LanguageID.setter"""
        self.LanguageID = value

    @property
    def Length(self):
        return self.com_object.Length

    @property
    def length(self):
        """Alias for Length"""
        return self.Length

    @property
    def ParagraphFormat(self):
        return ParagraphFormat(self.com_object.ParagraphFormat)

    @property
    def paragraphformat(self):
        """Alias for ParagraphFormat"""
        return self.ParagraphFormat

    @property
    def paragraph_format(self):
        """Alias for ParagraphFormat"""
        return self.ParagraphFormat

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Start(self):
        return self.com_object.Start

    @property
    def start(self):
        """Alias for Start"""
        return self.Start

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    def AddPeriods(self):
        self.com_object.AddPeriods()

    def addperiods(self):
        """Alias for AddPeriods"""
        return self.AddPeriods()

    def add_periods(self):
        """Alias for AddPeriods"""
        return self.AddPeriods()

    def ChangeCase(self, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Type]])
        self.com_object.ChangeCase(*arguments)

    def changecase(self, Type=None):
        """Alias for ChangeCase"""
        arguments = [Type]
        return self.ChangeCase(*arguments)

    def change_case(self, Type=None):
        """Alias for ChangeCase"""
        arguments = [Type]
        return self.ChangeCase(*arguments)

    def Characters(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        return TextRange(self.com_object.Characters(*arguments))

    def characters(self, Start=None, Length=None):
        """Alias for Characters"""
        arguments = [Start, Length]
        return self.Characters(*arguments)

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Cut(self):
        self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Find(self, FindWhat=None, After=None, MatchCase=None, WholeWords=None):
        arguments = com_arguments([unwrap(a) for a in [FindWhat, After, MatchCase, WholeWords]])
        return TextRange(self.com_object.Find(*arguments))

    def find(self, FindWhat=None, After=None, MatchCase=None, WholeWords=None):
        """Alias for Find"""
        arguments = [FindWhat, After, MatchCase, WholeWords]
        return self.Find(*arguments)

    def InsertAfter(self, NewText=None):
        arguments = com_arguments([unwrap(a) for a in [NewText]])
        self.com_object.InsertAfter(*arguments)

    def insertafter(self, NewText=None):
        """Alias for InsertAfter"""
        arguments = [NewText]
        return self.InsertAfter(*arguments)

    def insert_after(self, NewText=None):
        """Alias for InsertAfter"""
        arguments = [NewText]
        return self.InsertAfter(*arguments)

    def InsertBefore(self, NewText=None):
        arguments = com_arguments([unwrap(a) for a in [NewText]])
        self.com_object.InsertBefore(*arguments)

    def insertbefore(self, NewText=None):
        """Alias for InsertBefore"""
        arguments = [NewText]
        return self.InsertBefore(*arguments)

    def insert_before(self, NewText=None):
        """Alias for InsertBefore"""
        arguments = [NewText]
        return self.InsertBefore(*arguments)

    def InsertDateTime(self, DateTimeFormat=None, InsertAsField=None):
        arguments = com_arguments([unwrap(a) for a in [DateTimeFormat, InsertAsField]])
        return TextRange(self.com_object.InsertDateTime(*arguments))

    def insertdatetime(self, DateTimeFormat=None, InsertAsField=None):
        """Alias for InsertDateTime"""
        arguments = [DateTimeFormat, InsertAsField]
        return self.InsertDateTime(*arguments)

    def insert_date_time(self, DateTimeFormat=None, InsertAsField=None):
        """Alias for InsertDateTime"""
        arguments = [DateTimeFormat, InsertAsField]
        return self.InsertDateTime(*arguments)

    def InsertSlideNumber(self):
        return TextRange(self.com_object.InsertSlideNumber())

    def insertslidenumber(self):
        """Alias for InsertSlideNumber"""
        return self.InsertSlideNumber()

    def insert_slide_number(self):
        """Alias for InsertSlideNumber"""
        return self.InsertSlideNumber()

    def InsertSymbol(self, FontName=None, CharNumber=None, UniCode=None):
        arguments = com_arguments([unwrap(a) for a in [FontName, CharNumber, UniCode]])
        return TextRange(self.com_object.InsertSymbol(*arguments))

    def insertsymbol(self, FontName=None, CharNumber=None, UniCode=None):
        """Alias for InsertSymbol"""
        arguments = [FontName, CharNumber, UniCode]
        return self.InsertSymbol(*arguments)

    def insert_symbol(self, FontName=None, CharNumber=None, UniCode=None):
        """Alias for InsertSymbol"""
        arguments = [FontName, CharNumber, UniCode]
        return self.InsertSymbol(*arguments)

    def Lines(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        return TextRange(self.com_object.Lines(*arguments))

    def lines(self, Start=None, Length=None):
        """Alias for Lines"""
        arguments = [Start, Length]
        return self.Lines(*arguments)

    def LtrRun(self):
        self.com_object.LtrRun()

    def ltrrun(self):
        """Alias for LtrRun"""
        return self.LtrRun()

    def ltr_run(self):
        """Alias for LtrRun"""
        return self.LtrRun()

    def Paragraphs(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        return TextRange(self.com_object.Paragraphs(*arguments))

    def paragraphs(self, Start=None, Length=None):
        """Alias for Paragraphs"""
        arguments = [Start, Length]
        return self.Paragraphs(*arguments)

    def Paste(self):
        return TextRange(self.com_object.Paste())

    def paste(self):
        """Alias for Paste"""
        return self.Paste()

    def PasteSpecial(self, DataType=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, Link=None):
        arguments = com_arguments([unwrap(a) for a in [DataType, DisplayAsIcon, IconFileName, IconIndex, IconLabel, Link]])
        return TextRange(self.com_object.PasteSpecial(*arguments))

    def pastespecial(self, DataType=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, Link=None):
        """Alias for PasteSpecial"""
        arguments = [DataType, DisplayAsIcon, IconFileName, IconIndex, IconLabel, Link]
        return self.PasteSpecial(*arguments)

    def paste_special(self, DataType=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, Link=None):
        """Alias for PasteSpecial"""
        arguments = [DataType, DisplayAsIcon, IconFileName, IconIndex, IconLabel, Link]
        return self.PasteSpecial(*arguments)

    def RemovePeriods(self):
        self.com_object.RemovePeriods()

    def removeperiods(self):
        """Alias for RemovePeriods"""
        return self.RemovePeriods()

    def remove_periods(self):
        """Alias for RemovePeriods"""
        return self.RemovePeriods()

    def Replace(self, FindWhat=None, ReplaceWhat=None, After=None, MatchCase=None, WholeWords=None):
        arguments = com_arguments([unwrap(a) for a in [FindWhat, ReplaceWhat, After, MatchCase, WholeWords]])
        return TextRange(self.com_object.Replace(*arguments))

    def replace(self, FindWhat=None, ReplaceWhat=None, After=None, MatchCase=None, WholeWords=None):
        """Alias for Replace"""
        arguments = [FindWhat, ReplaceWhat, After, MatchCase, WholeWords]
        return self.Replace(*arguments)

    def RotatedBounds(self, X1=None, Y1=None, X2=None, Y2=None, X3=None, Y3=None, X4=None, Y4=None):
        arguments = com_arguments([unwrap(a) for a in [X1, Y1, X2, Y2, X3, Y3, X4, Y4]])
        self.com_object.RotatedBounds(*arguments)

    def rotatedbounds(self, X1=None, Y1=None, X2=None, Y2=None, X3=None, Y3=None, X4=None, Y4=None):
        """Alias for RotatedBounds"""
        arguments = [X1, Y1, X2, Y2, X3, Y3, X4, Y4]
        return self.RotatedBounds(*arguments)

    def rotated_bounds(self, X1=None, Y1=None, X2=None, Y2=None, X3=None, Y3=None, X4=None, Y4=None):
        """Alias for RotatedBounds"""
        arguments = [X1, Y1, X2, Y2, X3, Y3, X4, Y4]
        return self.RotatedBounds(*arguments)

    def RtlRun(self):
        self.com_object.RtlRun()

    def rtlrun(self):
        """Alias for RtlRun"""
        return self.RtlRun()

    def rtl_run(self):
        """Alias for RtlRun"""
        return self.RtlRun()

    def Runs(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        return TextRange(self.com_object.Runs(*arguments))

    def runs(self, Start=None, Length=None):
        """Alias for Runs"""
        arguments = [Start, Length]
        return self.Runs(*arguments)

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()

    def Sentences(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        return TextRange(self.com_object.Sentences(*arguments))

    def sentences(self, Start=None, Length=None):
        """Alias for Sentences"""
        arguments = [Start, Length]
        return self.Sentences(*arguments)

    def TrimText(self):
        return TextRange(self.com_object.TrimText())

    def trimtext(self):
        """Alias for TrimText"""
        return self.TrimText()

    def trim_text(self):
        """Alias for TrimText"""
        return self.TrimText()

    def Words(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        return TextRange(self.com_object.Words(*arguments))

    def words(self, Start=None, Length=None):
        """Alias for Words"""
        arguments = [Start, Length]
        return self.Words(*arguments)


class TextRange2:

    def __init__(self, textrange2=None):
        self.com_object= textrange2

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BoundHeight(self):
        return self.com_object.BoundHeight

    @property
    def boundheight(self):
        """Alias for BoundHeight"""
        return self.BoundHeight

    @property
    def bound_height(self):
        """Alias for BoundHeight"""
        return self.BoundHeight

    @property
    def BoundLeft(self):
        return self.com_object.BoundLeft

    @property
    def boundleft(self):
        """Alias for BoundLeft"""
        return self.BoundLeft

    @property
    def bound_left(self):
        """Alias for BoundLeft"""
        return self.BoundLeft

    @property
    def BoundTop(self):
        return self.com_object.BoundTop

    @property
    def boundtop(self):
        """Alias for BoundTop"""
        return self.BoundTop

    @property
    def bound_top(self):
        """Alias for BoundTop"""
        return self.BoundTop

    @property
    def BoundWidth(self):
        return self.com_object.BoundWidth

    @property
    def boundwidth(self):
        """Alias for BoundWidth"""
        return self.BoundWidth

    @property
    def bound_width(self):
        """Alias for BoundWidth"""
        return self.BoundWidth

    def Characters(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        if hasattr(self.com_object, "GetCharacters"):
            return self.com_object.GetCharacters(*arguments)
        else:
            return self.com_object.Characters(*arguments)

    def characters(self, Start=None, Length=None):
        """Alias for Characters"""
        arguments = [Start, Length]
        return self.Characters(*arguments)

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def LanguageID(self):
        return self.com_object.LanguageID

    @LanguageID.setter
    def LanguageID(self, value):
        self.com_object.LanguageID = value

    @property
    def languageid(self):
        """Alias for LanguageID"""
        return self.LanguageID

    @languageid.setter
    def languageid(self, value):
        """Alias for LanguageID.setter"""
        self.LanguageID = value

    @property
    def language_i_d(self):
        """Alias for LanguageID"""
        return self.LanguageID

    @language_i_d.setter
    def language_i_d(self, value):
        """Alias for LanguageID.setter"""
        self.LanguageID = value

    @property
    def Length(self):
        return self.com_object.Length

    @property
    def length(self):
        """Alias for Length"""
        return self.Length

    def Lines(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        if hasattr(self.com_object, "GetLines"):
            return self.com_object.GetLines(*arguments)
        else:
            return self.com_object.Lines(*arguments)

    def lines(self, Start=None, Length=None):
        """Alias for Lines"""
        arguments = [Start, Length]
        return self.Lines(*arguments)

    def MathZones(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        if hasattr(self.com_object, "GetMathZones"):
            return self.com_object.GetMathZones(*arguments)
        else:
            return self.com_object.MathZones(*arguments)

    def mathzones(self, Start=None, Length=None):
        """Alias for MathZones"""
        arguments = [Start, Length]
        return self.MathZones(*arguments)

    def math_zones(self, Start=None, Length=None):
        """Alias for MathZones"""
        arguments = [Start, Length]
        return self.MathZones(*arguments)

    @property
    def ParagraphFormat(self):
        return ParagraphFormat(self.com_object.ParagraphFormat)

    @property
    def paragraphformat(self):
        """Alias for ParagraphFormat"""
        return self.ParagraphFormat

    @property
    def paragraph_format(self):
        """Alias for ParagraphFormat"""
        return self.ParagraphFormat

    def Paragraphs(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        if hasattr(self.com_object, "GetParagraphs"):
            return self.com_object.GetParagraphs(*arguments)
        else:
            return self.com_object.Paragraphs(*arguments)

    def paragraphs(self, Start=None, Length=None):
        """Alias for Paragraphs"""
        arguments = [Start, Length]
        return self.Paragraphs(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Runs(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        if hasattr(self.com_object, "GetRuns"):
            return self.com_object.GetRuns(*arguments)
        else:
            return self.com_object.Runs(*arguments)

    def runs(self, Start=None, Length=None):
        """Alias for Runs"""
        arguments = [Start, Length]
        return self.Runs(*arguments)

    def Sentences(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        if hasattr(self.com_object, "GetSentences"):
            return TextRange2(self.com_object.GetSentences(*arguments))
        else:
            return TextRange2(self.com_object.Sentences(*arguments))

    def sentences(self, Start=None, Length=None):
        """Alias for Sentences"""
        arguments = [Start, Length]
        return self.Sentences(*arguments)

    @property
    def Start(self):
        return self.com_object.Start

    @property
    def start(self):
        """Alias for Start"""
        return self.Start

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    def Words(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        if hasattr(self.com_object, "GetWords"):
            return self.com_object.GetWords(*arguments)
        else:
            return self.com_object.Words(*arguments)

    def words(self, Start=None, Length=None):
        """Alias for Words"""
        arguments = [Start, Length]
        return self.Words(*arguments)

    def AddPeriods(self):
        self.com_object.AddPeriods()

    def addperiods(self):
        """Alias for AddPeriods"""
        return self.AddPeriods()

    def add_periods(self):
        """Alias for AddPeriods"""
        return self.AddPeriods()

    def ChangeCase(self, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Type]])
        self.com_object.ChangeCase(*arguments)

    def changecase(self, Type=None):
        """Alias for ChangeCase"""
        arguments = [Type]
        return self.ChangeCase(*arguments)

    def change_case(self, Type=None):
        """Alias for ChangeCase"""
        arguments = [Type]
        return self.ChangeCase(*arguments)

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Cut(self):
        self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Find(self, FindWhat=None, After=None, MatchCase=None, WholeWords=None):
        arguments = com_arguments([unwrap(a) for a in [FindWhat, After, MatchCase, WholeWords]])
        return TextRange2(self.com_object.Find(*arguments))

    def find(self, FindWhat=None, After=None, MatchCase=None, WholeWords=None):
        """Alias for Find"""
        arguments = [FindWhat, After, MatchCase, WholeWords]
        return self.Find(*arguments)

    def InsertAfter(self, NewText=None):
        arguments = com_arguments([unwrap(a) for a in [NewText]])
        return TextRange2(self.com_object.InsertAfter(*arguments))

    def insertafter(self, NewText=None):
        """Alias for InsertAfter"""
        arguments = [NewText]
        return self.InsertAfter(*arguments)

    def insert_after(self, NewText=None):
        """Alias for InsertAfter"""
        arguments = [NewText]
        return self.InsertAfter(*arguments)

    def InsertBefore(self, NewText=None):
        arguments = com_arguments([unwrap(a) for a in [NewText]])
        return TextRange2(self.com_object.InsertBefore(*arguments))

    def insertbefore(self, NewText=None):
        """Alias for InsertBefore"""
        arguments = [NewText]
        return self.InsertBefore(*arguments)

    def insert_before(self, NewText=None):
        """Alias for InsertBefore"""
        arguments = [NewText]
        return self.InsertBefore(*arguments)

    def InsertChartField(self):
        return self.com_object.InsertChartField()

    def insertchartfield(self):
        """Alias for InsertChartField"""
        return self.InsertChartField()

    def insert_chart_field(self):
        """Alias for InsertChartField"""
        return self.InsertChartField()

    def InsertSymbol(self, FontName=None, CharNumber=None, Unicode=None):
        arguments = com_arguments([unwrap(a) for a in [FontName, CharNumber, Unicode]])
        return TextRange2(self.com_object.InsertSymbol(*arguments))

    def insertsymbol(self, FontName=None, CharNumber=None, Unicode=None):
        """Alias for InsertSymbol"""
        arguments = [FontName, CharNumber, Unicode]
        return self.InsertSymbol(*arguments)

    def insert_symbol(self, FontName=None, CharNumber=None, Unicode=None):
        """Alias for InsertSymbol"""
        arguments = [FontName, CharNumber, Unicode]
        return self.InsertSymbol(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return TextRange2(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def LtrRun(self):
        self.com_object.LtrRun()

    def ltrrun(self):
        """Alias for LtrRun"""
        return self.LtrRun()

    def ltr_run(self):
        """Alias for LtrRun"""
        return self.LtrRun()

    def Paste(self):
        return TextRange2(self.com_object.Paste())

    def paste(self):
        """Alias for Paste"""
        return self.Paste()

    def PasteSpecial(self, Format=None):
        arguments = com_arguments([unwrap(a) for a in [Format]])
        return TextRange2(self.com_object.PasteSpecial(*arguments))

    def pastespecial(self, Format=None):
        """Alias for PasteSpecial"""
        arguments = [Format]
        return self.PasteSpecial(*arguments)

    def paste_special(self, Format=None):
        """Alias for PasteSpecial"""
        arguments = [Format]
        return self.PasteSpecial(*arguments)

    def RemovePeriods(self):
        self.com_object.RemovePeriods()

    def removeperiods(self):
        """Alias for RemovePeriods"""
        return self.RemovePeriods()

    def remove_periods(self):
        """Alias for RemovePeriods"""
        return self.RemovePeriods()

    def Replace(self, FindWhat=None, ReplaceWhat=None, After=None, MatchCase=None, WholeWords=None):
        arguments = com_arguments([unwrap(a) for a in [FindWhat, ReplaceWhat, After, MatchCase, WholeWords]])
        return TextRange2(self.com_object.Replace(*arguments))

    def replace(self, FindWhat=None, ReplaceWhat=None, After=None, MatchCase=None, WholeWords=None):
        """Alias for Replace"""
        arguments = [FindWhat, ReplaceWhat, After, MatchCase, WholeWords]
        return self.Replace(*arguments)

    def RotatedBounds(self, X1=None, Y1=None, X2=None, Y2=None, X3=None, Y3=None, x4=None, y4=None):
        arguments = com_arguments([unwrap(a) for a in [X1, Y1, X2, Y2, X3, Y3, x4, y4]])
        self.com_object.RotatedBounds(*arguments)

    def rotatedbounds(self, X1=None, Y1=None, X2=None, Y2=None, X3=None, Y3=None, x4=None, y4=None):
        """Alias for RotatedBounds"""
        arguments = [X1, Y1, X2, Y2, X3, Y3, x4, y4]
        return self.RotatedBounds(*arguments)

    def rotated_bounds(self, X1=None, Y1=None, X2=None, Y2=None, X3=None, Y3=None, x4=None, y4=None):
        """Alias for RotatedBounds"""
        arguments = [X1, Y1, X2, Y2, X3, Y3, x4, y4]
        return self.RotatedBounds(*arguments)

    def RtlRun(self):
        self.com_object.RtlRun()

    def rtlrun(self):
        """Alias for RtlRun"""
        return self.RtlRun()

    def rtl_run(self):
        """Alias for RtlRun"""
        return self.RtlRun()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()

    def TrimText(self):
        return TextRange2(self.com_object.TrimText())

    def trimtext(self):
        """Alias for TrimText"""
        return self.TrimText()

    def trim_text(self):
        """Alias for TrimText"""
        return self.TrimText()


class TextStyle:

    def __init__(self, textstyle=None):
        self.com_object= textstyle

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Levels(self):
        return TextStyleLevels(self.com_object.Levels)

    @property
    def levels(self):
        """Alias for Levels"""
        return self.Levels

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Ruler(self):
        return Ruler(self.com_object.Ruler)

    @property
    def ruler(self):
        """Alias for Ruler"""
        return self.Ruler

    @property
    def TextFrame(self):
        return TextFrame(self.com_object.TextFrame)

    @property
    def textframe(self):
        """Alias for TextFrame"""
        return self.TextFrame

    @property
    def text_frame(self):
        """Alias for TextFrame"""
        return self.TextFrame


class TextStyleLevel:

    def __init__(self, textstylelevel=None):
        self.com_object= textstylelevel

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def ParagraphFormat(self):
        return ParagraphFormat(self.com_object.ParagraphFormat)

    @property
    def paragraphformat(self):
        """Alias for ParagraphFormat"""
        return self.ParagraphFormat

    @property
    def paragraph_format(self):
        """Alias for ParagraphFormat"""
        return self.ParagraphFormat

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class TextStyleLevels:

    def __init__(self, textstylelevels=None):
        self.com_object= textstylelevels

    def __call__(self, item):
        return TextStyleLevel(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return TextStyleLevel(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class TextStyles:

    def __init__(self, textstyles=None):
        self.com_object= textstyles

    def __call__(self, item):
        return TextStyle(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Type]])
        return TextStyle(self.com_object.Item(*arguments))

    def item(self, Type=None):
        """Alias for Item"""
        arguments = [Type]
        return self.Item(*arguments)


class Theme:

    def __init__(self, theme=None):
        self.com_object= theme

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ThemeVariants(self):
        return ThemeVariants(self.com_object.ThemeVariants)

    @property
    def themevariants(self):
        """Alias for ThemeVariants"""
        return self.ThemeVariants

    @property
    def theme_variants(self):
        """Alias for ThemeVariants"""
        return self.ThemeVariants


class ThemeVariant:

    def __init__(self, themevariant=None):
        self.com_object= themevariant

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def Id(self):
        return self.com_object.Id

    @property
    def id(self):
        """Alias for Id"""
        return self.Id

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width


class ThemeVariants:

    def __init__(self, themevariants=None):
        self.com_object= themevariants

    def __call__(self, item):
        return ThemeVariant(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ThemeVariant(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ThreeDFormat:

    def __init__(self, threedformat=None):
        self.com_object= threedformat

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BevelBottomDepth(self):
        return ThreeDFormat(self.com_object.BevelBottomDepth)

    @BevelBottomDepth.setter
    def BevelBottomDepth(self, value):
        self.com_object.BevelBottomDepth = value

    @property
    def bevelbottomdepth(self):
        """Alias for BevelBottomDepth"""
        return self.BevelBottomDepth

    @bevelbottomdepth.setter
    def bevelbottomdepth(self, value):
        """Alias for BevelBottomDepth.setter"""
        self.BevelBottomDepth = value

    @property
    def bevel_bottom_depth(self):
        """Alias for BevelBottomDepth"""
        return self.BevelBottomDepth

    @bevel_bottom_depth.setter
    def bevel_bottom_depth(self, value):
        """Alias for BevelBottomDepth.setter"""
        self.BevelBottomDepth = value

    @property
    def BevelBottomInset(self):
        return ThreeDFormat(self.com_object.BevelBottomInset)

    @BevelBottomInset.setter
    def BevelBottomInset(self, value):
        self.com_object.BevelBottomInset = value

    @property
    def bevelbottominset(self):
        """Alias for BevelBottomInset"""
        return self.BevelBottomInset

    @bevelbottominset.setter
    def bevelbottominset(self, value):
        """Alias for BevelBottomInset.setter"""
        self.BevelBottomInset = value

    @property
    def bevel_bottom_inset(self):
        """Alias for BevelBottomInset"""
        return self.BevelBottomInset

    @bevel_bottom_inset.setter
    def bevel_bottom_inset(self, value):
        """Alias for BevelBottomInset.setter"""
        self.BevelBottomInset = value

    @property
    def BevelBottomType(self):
        return self.com_object.BevelBottomType

    @BevelBottomType.setter
    def BevelBottomType(self, value):
        self.com_object.BevelBottomType = value

    @property
    def bevelbottomtype(self):
        """Alias for BevelBottomType"""
        return self.BevelBottomType

    @bevelbottomtype.setter
    def bevelbottomtype(self, value):
        """Alias for BevelBottomType.setter"""
        self.BevelBottomType = value

    @property
    def bevel_bottom_type(self):
        """Alias for BevelBottomType"""
        return self.BevelBottomType

    @bevel_bottom_type.setter
    def bevel_bottom_type(self, value):
        """Alias for BevelBottomType.setter"""
        self.BevelBottomType = value

    @property
    def BevelTopDepth(self):
        return ThreeDFormat(self.com_object.BevelTopDepth)

    @BevelTopDepth.setter
    def BevelTopDepth(self, value):
        self.com_object.BevelTopDepth = value

    @property
    def beveltopdepth(self):
        """Alias for BevelTopDepth"""
        return self.BevelTopDepth

    @beveltopdepth.setter
    def beveltopdepth(self, value):
        """Alias for BevelTopDepth.setter"""
        self.BevelTopDepth = value

    @property
    def bevel_top_depth(self):
        """Alias for BevelTopDepth"""
        return self.BevelTopDepth

    @bevel_top_depth.setter
    def bevel_top_depth(self, value):
        """Alias for BevelTopDepth.setter"""
        self.BevelTopDepth = value

    @property
    def BevelTopInset(self):
        return ThreeDFormat(self.com_object.BevelTopInset)

    @BevelTopInset.setter
    def BevelTopInset(self, value):
        self.com_object.BevelTopInset = value

    @property
    def beveltopinset(self):
        """Alias for BevelTopInset"""
        return self.BevelTopInset

    @beveltopinset.setter
    def beveltopinset(self, value):
        """Alias for BevelTopInset.setter"""
        self.BevelTopInset = value

    @property
    def bevel_top_inset(self):
        """Alias for BevelTopInset"""
        return self.BevelTopInset

    @bevel_top_inset.setter
    def bevel_top_inset(self, value):
        """Alias for BevelTopInset.setter"""
        self.BevelTopInset = value

    @property
    def BevelTopType(self):
        return self.com_object.BevelTopType

    @BevelTopType.setter
    def BevelTopType(self, value):
        self.com_object.BevelTopType = value

    @property
    def beveltoptype(self):
        """Alias for BevelTopType"""
        return self.BevelTopType

    @beveltoptype.setter
    def beveltoptype(self, value):
        """Alias for BevelTopType.setter"""
        self.BevelTopType = value

    @property
    def bevel_top_type(self):
        """Alias for BevelTopType"""
        return self.BevelTopType

    @bevel_top_type.setter
    def bevel_top_type(self, value):
        """Alias for BevelTopType.setter"""
        self.BevelTopType = value

    @property
    def ContourColor(self):
        return ColorFormat(self.com_object.ContourColor)

    @property
    def contourcolor(self):
        """Alias for ContourColor"""
        return self.ContourColor

    @property
    def contour_color(self):
        """Alias for ContourColor"""
        return self.ContourColor

    @property
    def ContourWidth(self):
        return ThreeDFormat(self.com_object.ContourWidth)

    @ContourWidth.setter
    def ContourWidth(self, value):
        self.com_object.ContourWidth = value

    @property
    def contourwidth(self):
        """Alias for ContourWidth"""
        return self.ContourWidth

    @contourwidth.setter
    def contourwidth(self, value):
        """Alias for ContourWidth.setter"""
        self.ContourWidth = value

    @property
    def contour_width(self):
        """Alias for ContourWidth"""
        return self.ContourWidth

    @contour_width.setter
    def contour_width(self, value):
        """Alias for ContourWidth.setter"""
        self.ContourWidth = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Depth(self):
        return self.com_object.Depth

    @Depth.setter
    def Depth(self, value):
        self.com_object.Depth = value

    @property
    def depth(self):
        """Alias for Depth"""
        return self.Depth

    @depth.setter
    def depth(self, value):
        """Alias for Depth.setter"""
        self.Depth = value

    @property
    def ExtrusionColor(self):
        return ColorFormat(self.com_object.ExtrusionColor)

    @property
    def extrusioncolor(self):
        """Alias for ExtrusionColor"""
        return self.ExtrusionColor

    @property
    def extrusion_color(self):
        """Alias for ExtrusionColor"""
        return self.ExtrusionColor

    @property
    def ExtrusionColorType(self):
        return self.com_object.ExtrusionColorType

    @ExtrusionColorType.setter
    def ExtrusionColorType(self, value):
        self.com_object.ExtrusionColorType = value

    @property
    def extrusioncolortype(self):
        """Alias for ExtrusionColorType"""
        return self.ExtrusionColorType

    @extrusioncolortype.setter
    def extrusioncolortype(self, value):
        """Alias for ExtrusionColorType.setter"""
        self.ExtrusionColorType = value

    @property
    def extrusion_color_type(self):
        """Alias for ExtrusionColorType"""
        return self.ExtrusionColorType

    @extrusion_color_type.setter
    def extrusion_color_type(self, value):
        """Alias for ExtrusionColorType.setter"""
        self.ExtrusionColorType = value

    @property
    def FieldOfView(self):
        return ThreeDFormat(self.com_object.FieldOfView)

    @FieldOfView.setter
    def FieldOfView(self, value):
        self.com_object.FieldOfView = value

    @property
    def fieldofview(self):
        """Alias for FieldOfView"""
        return self.FieldOfView

    @fieldofview.setter
    def fieldofview(self, value):
        """Alias for FieldOfView.setter"""
        self.FieldOfView = value

    @property
    def field_of_view(self):
        """Alias for FieldOfView"""
        return self.FieldOfView

    @field_of_view.setter
    def field_of_view(self, value):
        """Alias for FieldOfView.setter"""
        self.FieldOfView = value

    @property
    def LightAngle(self):
        return self.com_object.LightAngle

    @LightAngle.setter
    def LightAngle(self, value):
        self.com_object.LightAngle = value

    @property
    def lightangle(self):
        """Alias for LightAngle"""
        return self.LightAngle

    @lightangle.setter
    def lightangle(self, value):
        """Alias for LightAngle.setter"""
        self.LightAngle = value

    @property
    def light_angle(self):
        """Alias for LightAngle"""
        return self.LightAngle

    @light_angle.setter
    def light_angle(self, value):
        """Alias for LightAngle.setter"""
        self.LightAngle = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Perspective(self):
        return self.com_object.Perspective

    @Perspective.setter
    def Perspective(self, value):
        self.com_object.Perspective = value

    @property
    def perspective(self):
        """Alias for Perspective"""
        return self.Perspective

    @perspective.setter
    def perspective(self, value):
        """Alias for Perspective.setter"""
        self.Perspective = value

    @property
    def PresetCamera(self):
        return ThreeDFormat(self.com_object.PresetCamera)

    @property
    def presetcamera(self):
        """Alias for PresetCamera"""
        return self.PresetCamera

    @property
    def preset_camera(self):
        """Alias for PresetCamera"""
        return self.PresetCamera

    @property
    def PresetExtrusionDirection(self):
        return self.com_object.PresetExtrusionDirection

    @property
    def presetextrusiondirection(self):
        """Alias for PresetExtrusionDirection"""
        return self.PresetExtrusionDirection

    @property
    def preset_extrusion_direction(self):
        """Alias for PresetExtrusionDirection"""
        return self.PresetExtrusionDirection

    @property
    def PresetLighting(self):
        return ThreeDFormat(self.com_object.PresetLighting)

    @PresetLighting.setter
    def PresetLighting(self, value):
        self.com_object.PresetLighting = value

    @property
    def presetlighting(self):
        """Alias for PresetLighting"""
        return self.PresetLighting

    @presetlighting.setter
    def presetlighting(self, value):
        """Alias for PresetLighting.setter"""
        self.PresetLighting = value

    @property
    def preset_lighting(self):
        """Alias for PresetLighting"""
        return self.PresetLighting

    @preset_lighting.setter
    def preset_lighting(self, value):
        """Alias for PresetLighting.setter"""
        self.PresetLighting = value

    @property
    def PresetLightingDirection(self):
        return self.com_object.PresetLightingDirection

    @PresetLightingDirection.setter
    def PresetLightingDirection(self, value):
        self.com_object.PresetLightingDirection = value

    @property
    def presetlightingdirection(self):
        """Alias for PresetLightingDirection"""
        return self.PresetLightingDirection

    @presetlightingdirection.setter
    def presetlightingdirection(self, value):
        """Alias for PresetLightingDirection.setter"""
        self.PresetLightingDirection = value

    @property
    def preset_lighting_direction(self):
        """Alias for PresetLightingDirection"""
        return self.PresetLightingDirection

    @preset_lighting_direction.setter
    def preset_lighting_direction(self, value):
        """Alias for PresetLightingDirection.setter"""
        self.PresetLightingDirection = value

    @property
    def PresetLightingSoftness(self):
        return self.com_object.PresetLightingSoftness

    @PresetLightingSoftness.setter
    def PresetLightingSoftness(self, value):
        self.com_object.PresetLightingSoftness = value

    @property
    def presetlightingsoftness(self):
        """Alias for PresetLightingSoftness"""
        return self.PresetLightingSoftness

    @presetlightingsoftness.setter
    def presetlightingsoftness(self, value):
        """Alias for PresetLightingSoftness.setter"""
        self.PresetLightingSoftness = value

    @property
    def preset_lighting_softness(self):
        """Alias for PresetLightingSoftness"""
        return self.PresetLightingSoftness

    @preset_lighting_softness.setter
    def preset_lighting_softness(self, value):
        """Alias for PresetLightingSoftness.setter"""
        self.PresetLightingSoftness = value

    @property
    def PresetMaterial(self):
        return self.com_object.PresetMaterial

    @PresetMaterial.setter
    def PresetMaterial(self, value):
        self.com_object.PresetMaterial = value

    @property
    def presetmaterial(self):
        """Alias for PresetMaterial"""
        return self.PresetMaterial

    @presetmaterial.setter
    def presetmaterial(self, value):
        """Alias for PresetMaterial.setter"""
        self.PresetMaterial = value

    @property
    def preset_material(self):
        """Alias for PresetMaterial"""
        return self.PresetMaterial

    @preset_material.setter
    def preset_material(self, value):
        """Alias for PresetMaterial.setter"""
        self.PresetMaterial = value

    @property
    def PresetThreeDFormat(self):
        return self.com_object.PresetThreeDFormat

    @property
    def presetthreedformat(self):
        """Alias for PresetThreeDFormat"""
        return self.PresetThreeDFormat

    @property
    def preset_three_d_format(self):
        """Alias for PresetThreeDFormat"""
        return self.PresetThreeDFormat

    @property
    def ProjectText(self):
        return self.com_object.ProjectText

    @ProjectText.setter
    def ProjectText(self, value):
        self.com_object.ProjectText = value

    @property
    def projecttext(self):
        """Alias for ProjectText"""
        return self.ProjectText

    @projecttext.setter
    def projecttext(self, value):
        """Alias for ProjectText.setter"""
        self.ProjectText = value

    @property
    def project_text(self):
        """Alias for ProjectText"""
        return self.ProjectText

    @project_text.setter
    def project_text(self, value):
        """Alias for ProjectText.setter"""
        self.ProjectText = value

    @property
    def RotationX(self):
        return self.com_object.RotationX

    @RotationX.setter
    def RotationX(self, value):
        self.com_object.RotationX = value

    @property
    def rotationx(self):
        """Alias for RotationX"""
        return self.RotationX

    @rotationx.setter
    def rotationx(self, value):
        """Alias for RotationX.setter"""
        self.RotationX = value

    @property
    def rotation_x(self):
        """Alias for RotationX"""
        return self.RotationX

    @rotation_x.setter
    def rotation_x(self, value):
        """Alias for RotationX.setter"""
        self.RotationX = value

    @property
    def RotationY(self):
        return self.com_object.RotationY

    @RotationY.setter
    def RotationY(self, value):
        self.com_object.RotationY = value

    @property
    def rotationy(self):
        """Alias for RotationY"""
        return self.RotationY

    @rotationy.setter
    def rotationy(self, value):
        """Alias for RotationY.setter"""
        self.RotationY = value

    @property
    def rotation_y(self):
        """Alias for RotationY"""
        return self.RotationY

    @rotation_y.setter
    def rotation_y(self, value):
        """Alias for RotationY.setter"""
        self.RotationY = value

    @property
    def RotationZ(self):
        return ThreeDFormat(self.com_object.RotationZ)

    @RotationZ.setter
    def RotationZ(self, value):
        self.com_object.RotationZ = value

    @property
    def rotationz(self):
        """Alias for RotationZ"""
        return self.RotationZ

    @rotationz.setter
    def rotationz(self, value):
        """Alias for RotationZ.setter"""
        self.RotationZ = value

    @property
    def rotation_z(self):
        """Alias for RotationZ"""
        return self.RotationZ

    @rotation_z.setter
    def rotation_z(self, value):
        """Alias for RotationZ.setter"""
        self.RotationZ = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Z(self):
        return ThreeDFormat(self.com_object.Z)

    @Z.setter
    def Z(self, value):
        self.com_object.Z = value

    @property
    def z(self):
        """Alias for Z"""
        return self.Z

    @z.setter
    def z(self, value):
        """Alias for Z.setter"""
        self.Z = value

    def IncrementRotationHorizontal(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotationHorizontal(*arguments)

    def incrementrotationhorizontal(self, Increment=None):
        """Alias for IncrementRotationHorizontal"""
        arguments = [Increment]
        return self.IncrementRotationHorizontal(*arguments)

    def increment_rotation_horizontal(self, Increment=None):
        """Alias for IncrementRotationHorizontal"""
        arguments = [Increment]
        return self.IncrementRotationHorizontal(*arguments)

    def IncrementRotationVertical(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotationVertical(*arguments)

    def incrementrotationvertical(self, Increment=None):
        """Alias for IncrementRotationVertical"""
        arguments = [Increment]
        return self.IncrementRotationVertical(*arguments)

    def increment_rotation_vertical(self, Increment=None):
        """Alias for IncrementRotationVertical"""
        arguments = [Increment]
        return self.IncrementRotationVertical(*arguments)

    def IncrementRotationX(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotationX(*arguments)

    def incrementrotationx(self, Increment=None):
        """Alias for IncrementRotationX"""
        arguments = [Increment]
        return self.IncrementRotationX(*arguments)

    def increment_rotation_x(self, Increment=None):
        """Alias for IncrementRotationX"""
        arguments = [Increment]
        return self.IncrementRotationX(*arguments)

    def IncrementRotationY(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotationY(*arguments)

    def incrementrotationy(self, Increment=None):
        """Alias for IncrementRotationY"""
        arguments = [Increment]
        return self.IncrementRotationY(*arguments)

    def increment_rotation_y(self, Increment=None):
        """Alias for IncrementRotationY"""
        arguments = [Increment]
        return self.IncrementRotationY(*arguments)

    def IncrementRotationZ(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotationZ(*arguments)

    def incrementrotationz(self, Increment=None):
        """Alias for IncrementRotationZ"""
        arguments = [Increment]
        return self.IncrementRotationZ(*arguments)

    def increment_rotation_z(self, Increment=None):
        """Alias for IncrementRotationZ"""
        arguments = [Increment]
        return self.IncrementRotationZ(*arguments)

    def ResetRotation(self):
        self.com_object.ResetRotation()

    def resetrotation(self):
        """Alias for ResetRotation"""
        return self.ResetRotation()

    def reset_rotation(self):
        """Alias for ResetRotation"""
        return self.ResetRotation()

    def SetExtrusionDirection(self, PresetExtrusionDirection=None):
        arguments = com_arguments([unwrap(a) for a in [PresetExtrusionDirection]])
        self.com_object.SetExtrusionDirection(*arguments)

    def setextrusiondirection(self, PresetExtrusionDirection=None):
        """Alias for SetExtrusionDirection"""
        arguments = [PresetExtrusionDirection]
        return self.SetExtrusionDirection(*arguments)

    def set_extrusion_direction(self, PresetExtrusionDirection=None):
        """Alias for SetExtrusionDirection"""
        arguments = [PresetExtrusionDirection]
        return self.SetExtrusionDirection(*arguments)

    def SetPresetCamera(self, PresetCamera=None):
        arguments = com_arguments([unwrap(a) for a in [PresetCamera]])
        self.com_object.SetPresetCamera(*arguments)

    def setpresetcamera(self, PresetCamera=None):
        """Alias for SetPresetCamera"""
        arguments = [PresetCamera]
        return self.SetPresetCamera(*arguments)

    def set_preset_camera(self, PresetCamera=None):
        """Alias for SetPresetCamera"""
        arguments = [PresetCamera]
        return self.SetPresetCamera(*arguments)

    def SetThreeDFormat(self, PresetThreeDFormat=None):
        arguments = com_arguments([unwrap(a) for a in [PresetThreeDFormat]])
        self.com_object.SetThreeDFormat(*arguments)

    def setthreedformat(self, PresetThreeDFormat=None):
        """Alias for SetThreeDFormat"""
        arguments = [PresetThreeDFormat]
        return self.SetThreeDFormat(*arguments)

    def set_three_d_format(self, PresetThreeDFormat=None):
        """Alias for SetThreeDFormat"""
        arguments = [PresetThreeDFormat]
        return self.SetThreeDFormat(*arguments)


class TickLabels:

    def __init__(self, ticklabels=None):
        self.com_object= ticklabels

    @property
    def Alignment(self):
        return self.com_object.Alignment

    @Alignment.setter
    def Alignment(self, value):
        self.com_object.Alignment = value

    @property
    def alignment(self):
        """Alias for Alignment"""
        return self.Alignment

    @alignment.setter
    def alignment(self, value):
        """Alias for Alignment.setter"""
        self.Alignment = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Depth(self):
        return self.com_object.Depth

    @property
    def depth(self):
        """Alias for Depth"""
        return self.Depth

    @property
    def Font(self):
        return ChartFont(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def MultiLevel(self):
        return self.com_object.MultiLevel

    @MultiLevel.setter
    def MultiLevel(self, value):
        self.com_object.MultiLevel = value

    @property
    def multilevel(self):
        """Alias for MultiLevel"""
        return self.MultiLevel

    @multilevel.setter
    def multilevel(self, value):
        """Alias for MultiLevel.setter"""
        self.MultiLevel = value

    @property
    def multi_level(self):
        """Alias for MultiLevel"""
        return self.MultiLevel

    @multi_level.setter
    def multi_level(self, value):
        """Alias for MultiLevel.setter"""
        self.MultiLevel = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NumberFormat(self):
        return self.com_object.NumberFormat

    @NumberFormat.setter
    def NumberFormat(self, value):
        self.com_object.NumberFormat = value

    @property
    def numberformat(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @numberformat.setter
    def numberformat(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def number_format(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @number_format.setter
    def number_format(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def NumberFormatLinked(self):
        return self.com_object.NumberFormatLinked

    @NumberFormatLinked.setter
    def NumberFormatLinked(self, value):
        self.com_object.NumberFormatLinked = value

    @property
    def numberformatlinked(self):
        """Alias for NumberFormatLinked"""
        return self.NumberFormatLinked

    @numberformatlinked.setter
    def numberformatlinked(self, value):
        """Alias for NumberFormatLinked.setter"""
        self.NumberFormatLinked = value

    @property
    def number_format_linked(self):
        """Alias for NumberFormatLinked"""
        return self.NumberFormatLinked

    @number_format_linked.setter
    def number_format_linked(self, value):
        """Alias for NumberFormatLinked.setter"""
        self.NumberFormatLinked = value

    @property
    def NumberFormatLocal(self):
        return self.com_object.NumberFormatLocal

    @NumberFormatLocal.setter
    def NumberFormatLocal(self, value):
        self.com_object.NumberFormatLocal = value

    @property
    def numberformatlocal(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @numberformatlocal.setter
    def numberformatlocal(self, value):
        """Alias for NumberFormatLocal.setter"""
        self.NumberFormatLocal = value

    @property
    def number_format_local(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @number_format_local.setter
    def number_format_local(self, value):
        """Alias for NumberFormatLocal.setter"""
        self.NumberFormatLocal = value

    @property
    def Offset(self):
        return self.com_object.Offset

    @Offset.setter
    def Offset(self, value):
        self.com_object.Offset = value

    @property
    def offset(self):
        """Alias for Offset"""
        return self.Offset

    @offset.setter
    def offset(self, value):
        """Alias for Offset.setter"""
        self.Offset = value

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ReadingOrder(self):
        return XlReadingOrder(self.com_object.ReadingOrder)

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class TimeLine:

    def __init__(self, timeline=None):
        self.com_object= timeline

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def InteractiveSequences(self):
        return Sequences(self.com_object.InteractiveSequences)

    @property
    def interactivesequences(self):
        """Alias for InteractiveSequences"""
        return self.InteractiveSequences

    @property
    def interactive_sequences(self):
        """Alias for InteractiveSequences"""
        return self.InteractiveSequences

    @property
    def MainSequence(self):
        return Sequence(self.com_object.MainSequence)

    @property
    def mainsequence(self):
        """Alias for MainSequence"""
        return self.MainSequence

    @property
    def main_sequence(self):
        """Alias for MainSequence"""
        return self.MainSequence

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class Timing:

    def __init__(self, timing=None):
        self.com_object= timing

    @property
    def Accelerate(self):
        return self.com_object.Accelerate

    @Accelerate.setter
    def Accelerate(self, value):
        self.com_object.Accelerate = value

    @property
    def accelerate(self):
        """Alias for Accelerate"""
        return self.Accelerate

    @accelerate.setter
    def accelerate(self, value):
        """Alias for Accelerate.setter"""
        self.Accelerate = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoReverse(self):
        return self.com_object.AutoReverse

    @AutoReverse.setter
    def AutoReverse(self, value):
        self.com_object.AutoReverse = value

    @property
    def autoreverse(self):
        """Alias for AutoReverse"""
        return self.AutoReverse

    @autoreverse.setter
    def autoreverse(self, value):
        """Alias for AutoReverse.setter"""
        self.AutoReverse = value

    @property
    def auto_reverse(self):
        """Alias for AutoReverse"""
        return self.AutoReverse

    @auto_reverse.setter
    def auto_reverse(self, value):
        """Alias for AutoReverse.setter"""
        self.AutoReverse = value

    @property
    def BounceEnd(self):
        return self.com_object.BounceEnd

    @BounceEnd.setter
    def BounceEnd(self, value):
        self.com_object.BounceEnd = value

    @property
    def bounceend(self):
        """Alias for BounceEnd"""
        return self.BounceEnd

    @bounceend.setter
    def bounceend(self, value):
        """Alias for BounceEnd.setter"""
        self.BounceEnd = value

    @property
    def bounce_end(self):
        """Alias for BounceEnd"""
        return self.BounceEnd

    @bounce_end.setter
    def bounce_end(self, value):
        """Alias for BounceEnd.setter"""
        self.BounceEnd = value

    @property
    def BounceEndIntensity(self):
        return self.com_object.BounceEndIntensity

    @BounceEndIntensity.setter
    def BounceEndIntensity(self, value):
        self.com_object.BounceEndIntensity = value

    @property
    def bounceendintensity(self):
        """Alias for BounceEndIntensity"""
        return self.BounceEndIntensity

    @bounceendintensity.setter
    def bounceendintensity(self, value):
        """Alias for BounceEndIntensity.setter"""
        self.BounceEndIntensity = value

    @property
    def bounce_end_intensity(self):
        """Alias for BounceEndIntensity"""
        return self.BounceEndIntensity

    @bounce_end_intensity.setter
    def bounce_end_intensity(self, value):
        """Alias for BounceEndIntensity.setter"""
        self.BounceEndIntensity = value

    @property
    def Decelerate(self):
        return self.com_object.Decelerate

    @Decelerate.setter
    def Decelerate(self, value):
        self.com_object.Decelerate = value

    @property
    def decelerate(self):
        """Alias for Decelerate"""
        return self.Decelerate

    @decelerate.setter
    def decelerate(self, value):
        """Alias for Decelerate.setter"""
        self.Decelerate = value

    @property
    def Duration(self):
        return self.com_object.Duration

    @Duration.setter
    def Duration(self, value):
        self.com_object.Duration = value

    @property
    def duration(self):
        """Alias for Duration"""
        return self.Duration

    @duration.setter
    def duration(self, value):
        """Alias for Duration.setter"""
        self.Duration = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RepeatCount(self):
        return self.com_object.RepeatCount

    @RepeatCount.setter
    def RepeatCount(self, value):
        self.com_object.RepeatCount = value

    @property
    def repeatcount(self):
        """Alias for RepeatCount"""
        return self.RepeatCount

    @repeatcount.setter
    def repeatcount(self, value):
        """Alias for RepeatCount.setter"""
        self.RepeatCount = value

    @property
    def repeat_count(self):
        """Alias for RepeatCount"""
        return self.RepeatCount

    @repeat_count.setter
    def repeat_count(self, value):
        """Alias for RepeatCount.setter"""
        self.RepeatCount = value

    @property
    def RepeatDuration(self):
        return self.com_object.RepeatDuration

    @RepeatDuration.setter
    def RepeatDuration(self, value):
        self.com_object.RepeatDuration = value

    @property
    def repeatduration(self):
        """Alias for RepeatDuration"""
        return self.RepeatDuration

    @repeatduration.setter
    def repeatduration(self, value):
        """Alias for RepeatDuration.setter"""
        self.RepeatDuration = value

    @property
    def repeat_duration(self):
        """Alias for RepeatDuration"""
        return self.RepeatDuration

    @repeat_duration.setter
    def repeat_duration(self, value):
        """Alias for RepeatDuration.setter"""
        self.RepeatDuration = value

    @property
    def Restart(self):
        return self.com_object.Restart

    @Restart.setter
    def Restart(self, value):
        self.com_object.Restart = value

    @property
    def restart(self):
        """Alias for Restart"""
        return self.Restart

    @restart.setter
    def restart(self, value):
        """Alias for Restart.setter"""
        self.Restart = value

    @property
    def RewindAtEnd(self):
        return self.com_object.RewindAtEnd

    @RewindAtEnd.setter
    def RewindAtEnd(self, value):
        self.com_object.RewindAtEnd = value

    @property
    def rewindatend(self):
        """Alias for RewindAtEnd"""
        return self.RewindAtEnd

    @rewindatend.setter
    def rewindatend(self, value):
        """Alias for RewindAtEnd.setter"""
        self.RewindAtEnd = value

    @property
    def rewind_at_end(self):
        """Alias for RewindAtEnd"""
        return self.RewindAtEnd

    @rewind_at_end.setter
    def rewind_at_end(self, value):
        """Alias for RewindAtEnd.setter"""
        self.RewindAtEnd = value

    @property
    def SmoothEnd(self):
        return self.com_object.SmoothEnd

    @SmoothEnd.setter
    def SmoothEnd(self, value):
        self.com_object.SmoothEnd = value

    @property
    def smoothend(self):
        """Alias for SmoothEnd"""
        return self.SmoothEnd

    @smoothend.setter
    def smoothend(self, value):
        """Alias for SmoothEnd.setter"""
        self.SmoothEnd = value

    @property
    def smooth_end(self):
        """Alias for SmoothEnd"""
        return self.SmoothEnd

    @smooth_end.setter
    def smooth_end(self, value):
        """Alias for SmoothEnd.setter"""
        self.SmoothEnd = value

    @property
    def SmoothStart(self):
        return self.com_object.SmoothStart

    @SmoothStart.setter
    def SmoothStart(self, value):
        self.com_object.SmoothStart = value

    @property
    def smoothstart(self):
        """Alias for SmoothStart"""
        return self.SmoothStart

    @smoothstart.setter
    def smoothstart(self, value):
        """Alias for SmoothStart.setter"""
        self.SmoothStart = value

    @property
    def smooth_start(self):
        """Alias for SmoothStart"""
        return self.SmoothStart

    @smooth_start.setter
    def smooth_start(self, value):
        """Alias for SmoothStart.setter"""
        self.SmoothStart = value

    @property
    def Speed(self):
        return self.com_object.Speed

    @Speed.setter
    def Speed(self, value):
        self.com_object.Speed = value

    @property
    def speed(self):
        """Alias for Speed"""
        return self.Speed

    @speed.setter
    def speed(self, value):
        """Alias for Speed.setter"""
        self.Speed = value

    @property
    def TriggerBookmark(self):
        return self.com_object.TriggerBookmark

    @TriggerBookmark.setter
    def TriggerBookmark(self, value):
        self.com_object.TriggerBookmark = value

    @property
    def triggerbookmark(self):
        """Alias for TriggerBookmark"""
        return self.TriggerBookmark

    @triggerbookmark.setter
    def triggerbookmark(self, value):
        """Alias for TriggerBookmark.setter"""
        self.TriggerBookmark = value

    @property
    def trigger_bookmark(self):
        """Alias for TriggerBookmark"""
        return self.TriggerBookmark

    @trigger_bookmark.setter
    def trigger_bookmark(self, value):
        """Alias for TriggerBookmark.setter"""
        self.TriggerBookmark = value

    @property
    def TriggerDelayTime(self):
        return self.com_object.TriggerDelayTime

    @TriggerDelayTime.setter
    def TriggerDelayTime(self, value):
        self.com_object.TriggerDelayTime = value

    @property
    def triggerdelaytime(self):
        """Alias for TriggerDelayTime"""
        return self.TriggerDelayTime

    @triggerdelaytime.setter
    def triggerdelaytime(self, value):
        """Alias for TriggerDelayTime.setter"""
        self.TriggerDelayTime = value

    @property
    def trigger_delay_time(self):
        """Alias for TriggerDelayTime"""
        return self.TriggerDelayTime

    @trigger_delay_time.setter
    def trigger_delay_time(self, value):
        """Alias for TriggerDelayTime.setter"""
        self.TriggerDelayTime = value

    @property
    def TriggerShape(self):
        return self.com_object.TriggerShape

    @TriggerShape.setter
    def TriggerShape(self, value):
        self.com_object.TriggerShape = value

    @property
    def triggershape(self):
        """Alias for TriggerShape"""
        return self.TriggerShape

    @triggershape.setter
    def triggershape(self, value):
        """Alias for TriggerShape.setter"""
        self.TriggerShape = value

    @property
    def trigger_shape(self):
        """Alias for TriggerShape"""
        return self.TriggerShape

    @trigger_shape.setter
    def trigger_shape(self, value):
        """Alias for TriggerShape.setter"""
        self.TriggerShape = value

    @property
    def TriggerType(self):
        return self.com_object.TriggerType

    @TriggerType.setter
    def TriggerType(self, value):
        self.com_object.TriggerType = value

    @property
    def triggertype(self):
        """Alias for TriggerType"""
        return self.TriggerType

    @triggertype.setter
    def triggertype(self, value):
        """Alias for TriggerType.setter"""
        self.TriggerType = value

    @property
    def trigger_type(self):
        """Alias for TriggerType"""
        return self.TriggerType

    @trigger_type.setter
    def trigger_type(self, value):
        """Alias for TriggerType.setter"""
        self.TriggerType = value


class Trendline:

    def __init__(self, trendline=None):
        self.com_object= trendline

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Backward2(self):
        return self.com_object.Backward2

    @Backward2.setter
    def Backward2(self, value):
        self.com_object.Backward2 = value

    @property
    def backward2(self):
        """Alias for Backward2"""
        return self.Backward2

    @backward2.setter
    def backward2(self, value):
        """Alias for Backward2.setter"""
        self.Backward2 = value

    @property
    def Border(self):
        return ChartBorder(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DataLabel(self):
        return DataLabel(self.com_object.DataLabel)

    @property
    def datalabel(self):
        """Alias for DataLabel"""
        return self.DataLabel

    @property
    def data_label(self):
        """Alias for DataLabel"""
        return self.DataLabel

    @property
    def DisplayEquation(self):
        return self.com_object.DisplayEquation

    @DisplayEquation.setter
    def DisplayEquation(self, value):
        self.com_object.DisplayEquation = value

    @property
    def displayequation(self):
        """Alias for DisplayEquation"""
        return self.DisplayEquation

    @displayequation.setter
    def displayequation(self, value):
        """Alias for DisplayEquation.setter"""
        self.DisplayEquation = value

    @property
    def display_equation(self):
        """Alias for DisplayEquation"""
        return self.DisplayEquation

    @display_equation.setter
    def display_equation(self, value):
        """Alias for DisplayEquation.setter"""
        self.DisplayEquation = value

    @property
    def DisplayRSquared(self):
        return self.com_object.DisplayRSquared

    @DisplayRSquared.setter
    def DisplayRSquared(self, value):
        self.com_object.DisplayRSquared = value

    @property
    def displayrsquared(self):
        """Alias for DisplayRSquared"""
        return self.DisplayRSquared

    @displayrsquared.setter
    def displayrsquared(self, value):
        """Alias for DisplayRSquared.setter"""
        self.DisplayRSquared = value

    @property
    def display_r_squared(self):
        """Alias for DisplayRSquared"""
        return self.DisplayRSquared

    @display_r_squared.setter
    def display_r_squared(self, value):
        """Alias for DisplayRSquared.setter"""
        self.DisplayRSquared = value

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Forward2(self):
        return self.com_object.Forward2

    @Forward2.setter
    def Forward2(self, value):
        self.com_object.Forward2 = value

    @property
    def forward2(self):
        """Alias for Forward2"""
        return self.Forward2

    @forward2.setter
    def forward2(self, value):
        """Alias for Forward2.setter"""
        self.Forward2 = value

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Intercept(self):
        return self.com_object.Intercept

    @Intercept.setter
    def Intercept(self, value):
        self.com_object.Intercept = value

    @property
    def intercept(self):
        """Alias for Intercept"""
        return self.Intercept

    @intercept.setter
    def intercept(self, value):
        """Alias for Intercept.setter"""
        self.Intercept = value

    @property
    def InterceptIsAuto(self):
        return self.com_object.InterceptIsAuto

    @InterceptIsAuto.setter
    def InterceptIsAuto(self, value):
        self.com_object.InterceptIsAuto = value

    @property
    def interceptisauto(self):
        """Alias for InterceptIsAuto"""
        return self.InterceptIsAuto

    @interceptisauto.setter
    def interceptisauto(self, value):
        """Alias for InterceptIsAuto.setter"""
        self.InterceptIsAuto = value

    @property
    def intercept_is_auto(self):
        """Alias for InterceptIsAuto"""
        return self.InterceptIsAuto

    @intercept_is_auto.setter
    def intercept_is_auto(self, value):
        """Alias for InterceptIsAuto.setter"""
        self.InterceptIsAuto = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def NameIsAuto(self):
        return self.com_object.NameIsAuto

    @NameIsAuto.setter
    def NameIsAuto(self, value):
        self.com_object.NameIsAuto = value

    @property
    def nameisauto(self):
        """Alias for NameIsAuto"""
        return self.NameIsAuto

    @nameisauto.setter
    def nameisauto(self, value):
        """Alias for NameIsAuto.setter"""
        self.NameIsAuto = value

    @property
    def name_is_auto(self):
        """Alias for NameIsAuto"""
        return self.NameIsAuto

    @name_is_auto.setter
    def name_is_auto(self, value):
        """Alias for NameIsAuto.setter"""
        self.NameIsAuto = value

    @property
    def Order(self):
        return self.com_object.Order

    @Order.setter
    def Order(self, value):
        self.com_object.Order = value

    @property
    def order(self):
        """Alias for Order"""
        return self.Order

    @order.setter
    def order(self, value):
        """Alias for Order.setter"""
        self.Order = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Period(self):
        return self.com_object.Period

    @Period.setter
    def Period(self, value):
        self.com_object.Period = value

    @property
    def period(self):
        """Alias for Period"""
        return self.Period

    @period.setter
    def period(self, value):
        """Alias for Period.setter"""
        self.Period = value

    @property
    def Type(self):
        return XlTrendlineType(self.com_object.Type)

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    def ClearFormats(self):
        self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Trendlines:

    def __init__(self, trendlines=None):
        self.com_object= trendlines

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Type=None, Order=None, Period=None, Forward=None, Backward=None, Intercept=None, DisplayEquation=None, DisplayRSquared=None, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Order, Period, Forward, Backward, Intercept, DisplayEquation, DisplayRSquared, Name]])
        return Trendline(self.com_object.Add(*arguments))

    def add(self, Type=None, Order=None, Period=None, Forward=None, Backward=None, Intercept=None, DisplayEquation=None, DisplayRSquared=None, Name=None):
        """Alias for Add"""
        arguments = [Type, Order, Period, Forward, Backward, Intercept, DisplayEquation, DisplayRSquared, Name]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Trendline(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class UpBars:

    def __init__(self, upbars=None):
        self.com_object= upbars

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Fill(self):
        return FillFormat(self.com_object.Fill)

    @property
    def fill(self):
        """Alias for Fill"""
        return self.Fill

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class View:

    def __init__(self, view=None):
        self.com_object= view

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def DisplaySlideMiniature(self):
        return self.com_object.DisplaySlideMiniature

    @DisplaySlideMiniature.setter
    def DisplaySlideMiniature(self, value):
        self.com_object.DisplaySlideMiniature = value

    @property
    def displayslideminiature(self):
        """Alias for DisplaySlideMiniature"""
        return self.DisplaySlideMiniature

    @displayslideminiature.setter
    def displayslideminiature(self, value):
        """Alias for DisplaySlideMiniature.setter"""
        self.DisplaySlideMiniature = value

    @property
    def display_slide_miniature(self):
        """Alias for DisplaySlideMiniature"""
        return self.DisplaySlideMiniature

    @display_slide_miniature.setter
    def display_slide_miniature(self, value):
        """Alias for DisplaySlideMiniature.setter"""
        self.DisplaySlideMiniature = value

    @property
    def MediaControlsHeight(self):
        return self.com_object.MediaControlsHeight

    @property
    def mediacontrolsheight(self):
        """Alias for MediaControlsHeight"""
        return self.MediaControlsHeight

    @property
    def media_controls_height(self):
        """Alias for MediaControlsHeight"""
        return self.MediaControlsHeight

    @property
    def MediaControlsLeft(self):
        return self.com_object.MediaControlsLeft

    @property
    def mediacontrolsleft(self):
        """Alias for MediaControlsLeft"""
        return self.MediaControlsLeft

    @property
    def media_controls_left(self):
        """Alias for MediaControlsLeft"""
        return self.MediaControlsLeft

    @property
    def MediaControlsTop(self):
        return self.com_object.MediaControlsTop

    @property
    def mediacontrolstop(self):
        """Alias for MediaControlsTop"""
        return self.MediaControlsTop

    @property
    def media_controls_top(self):
        """Alias for MediaControlsTop"""
        return self.MediaControlsTop

    @property
    def MediaControlsVisible(self):
        return self.com_object.MediaControlsVisible

    @property
    def mediacontrolsvisible(self):
        """Alias for MediaControlsVisible"""
        return self.MediaControlsVisible

    @property
    def media_controls_visible(self):
        """Alias for MediaControlsVisible"""
        return self.MediaControlsVisible

    @property
    def MediaControlsWidth(self):
        return self.com_object.MediaControlsWidth

    @property
    def mediacontrolswidth(self):
        """Alias for MediaControlsWidth"""
        return self.MediaControlsWidth

    @property
    def media_controls_width(self):
        """Alias for MediaControlsWidth"""
        return self.MediaControlsWidth

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PrintOptions(self):
        return PrintOptions(self.com_object.PrintOptions)

    @property
    def printoptions(self):
        """Alias for PrintOptions"""
        return self.PrintOptions

    @property
    def print_options(self):
        """Alias for PrintOptions"""
        return self.PrintOptions

    @property
    def Slide(self):
        return Slide(self.com_object.Slide)

    @Slide.setter
    def Slide(self, value):
        self.com_object.Slide = value

    @property
    def slide(self):
        """Alias for Slide"""
        return self.Slide

    @slide.setter
    def slide(self, value):
        """Alias for Slide.setter"""
        self.Slide = value

    @property
    def Type(self):
        return self.com_object.Type

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def Zoom(self):
        return self.com_object.Zoom

    @Zoom.setter
    def Zoom(self, value):
        self.com_object.Zoom = value

    @property
    def zoom(self):
        """Alias for Zoom"""
        return self.Zoom

    @zoom.setter
    def zoom(self, value):
        """Alias for Zoom.setter"""
        self.Zoom = value

    @property
    def ZoomToFit(self):
        return self.com_object.ZoomToFit

    @ZoomToFit.setter
    def ZoomToFit(self, value):
        self.com_object.ZoomToFit = value

    @property
    def zoomtofit(self):
        """Alias for ZoomToFit"""
        return self.ZoomToFit

    @zoomtofit.setter
    def zoomtofit(self, value):
        """Alias for ZoomToFit.setter"""
        self.ZoomToFit = value

    @property
    def zoom_to_fit(self):
        """Alias for ZoomToFit"""
        return self.ZoomToFit

    @zoom_to_fit.setter
    def zoom_to_fit(self, value):
        """Alias for ZoomToFit.setter"""
        self.ZoomToFit = value

    def GotoSlide(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.GotoSlide(*arguments)

    def gotoslide(self, Index=None):
        """Alias for GotoSlide"""
        arguments = [Index]
        return self.GotoSlide(*arguments)

    def goto_slide(self, Index=None):
        """Alias for GotoSlide"""
        arguments = [Index]
        return self.GotoSlide(*arguments)

    def Paste(self):
        self.com_object.Paste()

    def paste(self):
        """Alias for Paste"""
        return self.Paste()

    def PasteSpecial(self, DataType=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, Link=None):
        arguments = com_arguments([unwrap(a) for a in [DataType, DisplayAsIcon, IconFileName, IconIndex, IconLabel, Link]])
        self.com_object.PasteSpecial(*arguments)

    def pastespecial(self, DataType=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, Link=None):
        """Alias for PasteSpecial"""
        arguments = [DataType, DisplayAsIcon, IconFileName, IconIndex, IconLabel, Link]
        return self.PasteSpecial(*arguments)

    def paste_special(self, DataType=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, Link=None):
        """Alias for PasteSpecial"""
        arguments = [DataType, DisplayAsIcon, IconFileName, IconIndex, IconLabel, Link]
        return self.PasteSpecial(*arguments)

    def Player(self, ShapeId=None):
        arguments = com_arguments([unwrap(a) for a in [ShapeId]])
        return Player(self.com_object.Player(*arguments))

    def player(self, ShapeId=None):
        """Alias for Player"""
        arguments = [ShapeId]
        return self.Player(*arguments)

    def PrintOut(self, From=None, To=None, PrintToFile=None, Copies=None, Collate=None):
        arguments = com_arguments([unwrap(a) for a in [From, To, PrintToFile, Copies, Collate]])
        self.com_object.PrintOut(*arguments)

    def printout(self, From=None, To=None, PrintToFile=None, Copies=None, Collate=None):
        """Alias for PrintOut"""
        arguments = [From, To, PrintToFile, Copies, Collate]
        return self.PrintOut(*arguments)

    def print_out(self, From=None, To=None, PrintToFile=None, Copies=None, Collate=None):
        """Alias for PrintOut"""
        arguments = [From, To, PrintToFile, Copies, Collate]
        return self.PrintOut(*arguments)


class Walls:

    def __init__(self, walls=None):
        self.com_object= walls

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PictureType(self):
        return self.com_object.PictureType

    @PictureType.setter
    def PictureType(self, value):
        self.com_object.PictureType = value

    @property
    def picturetype(self):
        """Alias for PictureType"""
        return self.PictureType

    @picturetype.setter
    def picturetype(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def picture_type(self):
        """Alias for PictureType"""
        return self.PictureType

    @picture_type.setter
    def picture_type(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def PictureUnit(self):
        return self.com_object.PictureUnit

    @PictureUnit.setter
    def PictureUnit(self, value):
        self.com_object.PictureUnit = value

    @property
    def pictureunit(self):
        """Alias for PictureUnit"""
        return self.PictureUnit

    @pictureunit.setter
    def pictureunit(self, value):
        """Alias for PictureUnit.setter"""
        self.PictureUnit = value

    @property
    def picture_unit(self):
        """Alias for PictureUnit"""
        return self.PictureUnit

    @picture_unit.setter
    def picture_unit(self, value):
        """Alias for PictureUnit.setter"""
        self.PictureUnit = value

    @property
    def Thickness(self):
        return self.com_object.Thickness

    @Thickness.setter
    def Thickness(self, value):
        self.com_object.Thickness = value

    @property
    def thickness(self):
        """Alias for Thickness"""
        return self.Thickness

    @thickness.setter
    def thickness(self, value):
        """Alias for Thickness.setter"""
        self.Thickness = value

    def ClearFormats(self):
        self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Paste(self):
        self.com_object.Paste()

    def paste(self):
        """Alias for Paste"""
        return self.Paste()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


# XlAxisCrosses enumeration
xlAxisCrossesAutomatic = -4105
xlAxisCrossesCustom = -4114
xlAxisCrossesMaximum = 2
xlAxisCrossesMinimum = 4

# XlAxisGroup enumeration
xlPrimary = 1
xlSecondary = 2

# XlAxisType enumeration
xlCategory = 1
xlSeriesAxis = 3
xlValue = 2

# XlBackground enumeration
xlBackgroundAutomatic = -4105
xlBackgroundOpaque = 3
xlBackgroundTransparent = 2

# XlBarShape enumeration
xlBox = 0
xlConeToMax = 5
xlConeToPoint = 4
xlCylinder = 3
xlPyramidToMax = 2
xlPyramidToPoint = 1

# XlBinsType enumeration
xlBinsTypeAutomatic = 0
xlBinsTypeCategorical = 1
xlBinsTypeManual = 2
xlBinsTypeBinSize = 3
xlBinsTypeBinCount = 4

# XlBorderWeight enumeration
xlHairline = 1
xlMedium = -4138
xlThick = 4
xlThin = 2

# XlCategoryType enumeration
xlAutomaticScale = -4105
xlCategoryScale = 2
xlTimeScale = 3

# XlChartElementPosition enumeration
xlChartElementPositionAutomatic = -4105
xlChartElementPositionCustom = -4114

# XlChartGallery enumeration
xlAnyGallery = 23
xlBuiltIn = 21
xlUserDefined = 22

# XlChartItem enumeration
xlAxis = 21
xlAxisTitle = 17
xlChartArea = 2
xlChartTitle = 4
xlCorners = 6
xlDataLabel = 0
xlDataTable = 7
xlDisplayUnitLabel = 30
xlDownBars = 20
xlDropLines = 26
xlErrorBars = 9
xlFloor = 23
xlHiLoLines = 25
xlLeaderLines = 29
xlLegend = 24
xlLegendEntry = 12
xlLegendKey = 13
xlMajorGridlines = 15
xlMinorGridlines = 16
xlNothing = 28
xlPivotChartDropZone = 32
xlPivotChartFieldButton = 31
xlPlotArea = 19
xlRadarAxisLabels = 27
xlSeries = 3
xlSeriesLines = 22
xlShape = 14
xlTrendline = 8
xlUpBars = 18
xlWalls = 5
xlXErrorBars = 10
xlYErrorBars = 11

# XlChartPicturePlacement enumeration
xlAllFaces = 7
xlEnd = 2
xlEndSides = 3
xlFront = 4
xlFrontEnd = 6
xlFrontSides = 5
xlSides = 1

# XlChartPictureType enumeration
xlStack = 2
xlStackScale = 3
xlStretch = 1

# XlChartSplitType enumeration
xlSplitByCustomSplit = 4
xlSplitByPercentValue = 3
xlSplitByPosition = 1
xlSplitByValue = 2

# XlColorIndex enumeration
xlColorIndexAutomatic = -4105
xlColorIndexNone = -4142

# XlConstants enumeration
xl3DBar = -4099
xl3DSurface = -4103
xlAbove = 0
xlAutomatic = -4105
xlBar = 2
xlBelow = 1
xlBoth = 1
xlBottom = -4107
xlCenter = -4108
xlChecker = 9
xlCircle = 8
xlColumn = 3
xlCombination = -4111
xlCorner = 2
xlCrissCross = 16
xlCross = 4
xlCustom = -4114
xlDefaultAutoFormat = -1
xlDiamond = 2
xlDistributed = -4117
xlFill = 5
xlFixedValue = 1
xlGeneral = 1
xlGray16 = 17
xlGray25 = -4124
xlGray50 = -4125
xlGray75 = -4126
xlGray8 = 18
xlGrid = 15
xlHigh = -4127
xlInside = 2
xlJustify = -4130
xlLeft = -4131
xlLightDown = 13
xlLightHorizontal = 11
xlLightUp = 14
xlLightVertical = 12
xlLow = -4134
xlMaximum = 2
xlMinimum = 4
xlMinusValues = 3
xlNextToAxis = 4
xlNone = -4142
xlOpaque = 3
xlOutside = 3
xlPercent = 2
xlPlus = 9
xlPlusValues = 2
xlRight = -4152
xlScale = 3
xlSemiGray75 = 10
xlShowLabel = 4
xlShowLabelAndPercent = 5
xlShowPercent = 3
xlShowValue = 2
xlSingle = 2
xlSolid = 1
xlSquare = 1
xlStar = 5
xlStError = 4
xlTop = -4160
xlTransparent = 2
xlTriangle = 3

# XlCopyPictureFormat enumeration
xlBitmap = 2
xlPicture = -4147

# XlDataLabelPosition enumeration
xlLabelPositionAbove = 0
xlLabelPositionBelow = 1
xlLabelPositionBestFit = 5
xlLabelPositionCenter = -4108
xlLabelPositionCustom = 7
xlLabelPositionInsideBase = 4
xlLabelPositionInsideEnd = 3
xlLabelPositionLeft = -4131
xlLabelPositionMixed = 6
xlLabelPositionOutsideEnd = 2
xlLabelPositionRight = -4152

# XlDataLabelSeparator enumeration
xlDataLabelSeparatorDefault = 1

# XlDataLabelsType enumeration
xlDataLabelsShowBubbleSizes = 6
xlDataLabelsShowLabel = 4
xlDataLabelsShowLabelAndPercent = 5
xlDataLabelsShowNone = -4142
xlDataLabelsShowPercent = 3
xlDataLabelsShowValue = 2

# XlDisplayBlanksAs enumeration
xlInterpolated = 3
xlNotPlotted = 1
xlZero = 2

# XlDisplayUnit enumeration
xlHundredMillions = -8
xlHundreds = -2
xlHundredThousands = -5
xlMillionMillions = -10
xlMillions = -6
xlTenMillions = -7
xlTenThousands = -4
xlThousandMillions = -9
xlThousands = -3

# XlEndStyleCap enumeration
xlCap = 1
xlNoCap = 2

# XlErrorBarDirection enumeration
xlChartX = -4168
xlChartY = 1

# XlErrorBarInclude enumeration
xlErrorBarIncludeBoth = 1
xlErrorBarIncludeMinusValues = 3
xlErrorBarIncludeNone = -4142
xlErrorBarIncludePlusValues = 2

# XlErrorBarType enumeration
xlErrorBarTypeCustom = -4114
xlErrorBarTypeFixedValue = 1
xlErrorBarTypePercent = 2
xlErrorBarTypeStDev = -4155
xlErrorBarTypeStError = 4

# XlHAlign enumeration
xlHAlignCenter = -4108
xlHAlignCenterAcrossSelection = 7
xlHAlignDistributed = -4117
xlHAlignFill = 5
xlHAlignGeneral = 1
xlHAlignJustify = -4130
xlHAlignLeft = -4131
xlHAlignRight = -4152

# XlLegendPosition enumeration
xlLegendPositionBottom = -4107
xlLegendPositionCorner = 2
xlLegendPositionCustom = -4161
xlLegendPositionLeft = -4131
xlLegendPositionRight = -4152
xlLegendPositionTop = -4160

# XlLineStyle enumeration
xlContinuous = 1
xlDash = -4115
xlDashDot = 4
xlDashDotDot = 5
xlDot = -4118
xlDouble = -4119
xlLineStyleNone = -4142
xlSlantDashDot = 13

# XlMarkerStyle enumeration
xlMarkerStyleAutomatic = -4105
xlMarkerStyleCircle = 8
xlMarkerStyleDash = -4115
xlMarkerStyleDiamond = 2
xlMarkerStyleDot = -4118
xlMarkerStyleNone = -4142
xlMarkerStylePicture = -4147
xlMarkerStylePlus = 9
xlMarkerStyleSquare = 1
xlMarkerStyleStar = 5
xlMarkerStyleTriangle = 3
xlMarkerStyleX = -4168

# XlOrientation enumeration
xlDownward = -4170
xlHorizontal = -4128
xlUpward = -4171
xlVertical = -4166

# XlParentDataLabelOptions enumeration
xlParentDataLabelOptionsNone = 0
xlParentDataLabelOptionsBanner = 1
xlParentDataLabelOptionsOverlapping = 2

# XlPattern enumeration
xlPatternAutomatic = -4105
xlPatternChecker = 9
xlPatternCrissCross = 16
xlPatternDown = -4121
xlPatternGray16 = 17
xlPatternGray25 = -4124
xlPatternGray50 = -4125
xlPatternGray75 = -4126
xlPatternGray8 = 18
xlPatternGrid = 15
xlPatternHorizontal = -4128
xlPatternLightDown = 13
xlPatternLightHorizontal = 11
xlPatternLightUp = 14
xlPatternLightVertical = 12
xlPatternLinearGradient = 4000
xlPatternNone = -4142
xlPatternRectangularGradient = 4001
xlPatternSemiGray75 = 10
xlPatternSolid = 1
xlPatternUp = -4162
xlPatternVertical = -4166

# XlPictureAppearance enumeration
xlPrinter = 2
xlScreen = 1

# XlPieSliceIndex enumeration
xlCenterPoint = 5
xlInnerCenterPoint = 8
xlInnerClockwisePoint = 7
xlInnerCounterClockwisePoint = 9
xlMidClockwiseRadiusPoint = 4
xlMidCounterClockwiseRadiusPoint = 6
xlOuterCenterPoint = 2
xlOuterClockwisePoint = 3
xlOuterCounterClockwisePoint = 1

# XlPieSliceLocation enumeration
xlCenterPoint = 5
xlInnerCenterPoint = 8
xlInnerClockwisePoint = 7
xlInnerCounterClockwisePoint = 9
xlMidClockwiseRadiusPoint = 4
xlMidCounterClockwiseRadiusPoint = 6
xlOuterCenterPoint = 2
xlOuterClockwisePoint = 3
xlOuterCounterClockwisePoint = 1

# XlPivotFieldOrientation enumeration
xlColumnField = 2
xlDataField = 4
xlHidden = 0
xlPageField = 3
xlRowField = 1

# XlReadingOrder enumeration
xlContext = -5002
xlLTR = -5003
xlRTL = -5004

# XlRgbColor enumeration
xlAliceBlue = 16775408
xlAntiqueWhite = 14150650
xlAqua = 16776960
xlAquamarine = 13959039
xlAzure = 16777200
xlBeige = 14480885
xlBisque = 12903679
xlBlack = 0
xlBlanchedAlmond = 13495295
xlBlue = 16711680
xlBlueViolet = 14822282
xlBrown = 2763429
xlBurlyWood = 8894686
xlCadetBlue = 10526303
xlChartreuse = 65407
xlCoral = 5275647
xlCornflowerBlue = 15570276
xlCornsilk = 14481663
xlCrimson = 3937500
xlDarkBlue = 9109504
xlDarkCyan = 9145088
xlDarkGoldenrod = 755384
xlDarkGray = 11119017
xlDarkGreen = 25600
xlDarkGrey = 11119017
xlDarkKhaki = 7059389
xlDarkMagenta = 9109643
xlDarkOliveGreen = 3107669
xlDarkOrange = 36095
xlDarkOrchid = 13382297
xlDarkRed = 139
xlDarkSalmon = 8034025
xlDarkSeaGreen = 9419919
xlDarkSlateBlue = 9125192
xlDarkSlateGray = 5197615
xlDarkSlateGrey = 5197615
xlDarkTurquoise = 13749760
xlDarkViolet = 13828244
xlDeepPink = 9639167
xlDeepSkyBlue = 16760576
xlDimGray = 6908265
xlDimGrey = 6908265
xlDodgerBlue = 16748574
xlFireBrick = 2237106
xlFloralWhite = 15792895
xlForestGreen = 2263842
xlFuchsia = 16711935
xlGainsboro = 14474460
xlGhostWhite = 16775416
xlGold = 55295
xlGoldenrod = 2139610
xlGray = 8421504
xlGreen = 32768
xlGreenYellow = 3145645
xlGrey = 8421504
xlHoneydew = 15794160
xlHotPink = 11823615
xlIndianRed = 6053069
xlIndigo = 8519755
xlIvory = 15794175
xlKhaki = 9234160
xlLavender = 16443110
xlLavenderBlush = 16118015
xlLawnGreen = 64636
xlLemonChiffon = 13499135
xlLightBlue = 15128749
xlLightCoral = 8421616
xlLightCyan = 9145088
xlLightGoldenrodYellow = 13826810
xlLightGray = 13882323
xlLightGreen = 9498256
xlLightGrey = 13882323
xlLightPink = 12695295
xlLightSalmon = 8036607
xlLightSeaGreen = 11186720
xlLightSkyBlue = 16436871
xlLightSlateGray = 10061943
xlLightSlateGrey = 10061943
xlLightSteelBlue = 14599344
xlLightYellow = 14745599
xlLime = 65280
xlLimeGreen = 3329330
xlLinen = 15134970
xlMaroon = 128
xlMediumAquamarine = 11206502
xlMediumBlue = 13434880
xlMediumOrchid = 13850042
xlMediumPurple = 14381203
xlMediumSeaGreen = 7451452
xlMediumSlateBlue = 15624315
xlMediumSpringGreen = 10156544
xlMediumTurquoise = 13422920
xlMediumVioletRed = 8721863
xlMidnightBlue = 7346457
xlMintCream = 16449525
xlMistyRose = 14804223
xlMoccasin = 11920639
xlNavajoWhite = 11394815
xlNavy = 8388608
xlNavyBlue = 8388608
xlOldLace = 15136253
xlOlive = 32896
xlOliveDrab = 2330219
xlOrange = 42495
xlOrangeRed = 17919
xlOrchid = 14053594
xlPaleGoldenrod = 7071982
xlPaleGreen = 10025880
xlPaleTurquoise = 15658671
xlPaleVioletRed = 9662683
xlPapayaWhip = 14020607
xlPeachPuff = 12180223
xlPeru = 4163021
xlPink = 13353215
xlPlum = 14524637
xlPowderBlue = 15130800
xlPurple = 8388736
xlRed = 255
xlRosyBrown = 9408444
xlRoyalBlue = 14772545
xlSalmon = 7504122
xlSandyBrown = 6333684
xlSeaGreen = 5737262
xlSeashell = 15660543
xlSienna = 2970272
xlSilver = 12632256
xlSkyBlue = 15453831
xlSlateBlue = 13458026
xlSlateGray = 9470064
xlSlateGrey = 9470064
xlSnow = 16448255
xlSpringGreen = 8388352
xlSteelBlue = 11829830
xlTan = 9221330
xlTeal = 8421376
xlThistle = 14204888
xlTomato = 4678655
xlTurquoise = 13688896
xlViolet = 15631086
xlWheat = 11788021
xlWhite = 16777215
xlWhiteSmoke = 16119285
xlYellow = 65535
xlYellowGreen = 3329434

# XlRowCol enumeration
xlColumns = 2
xlRows = 1

# XlScaleType enumeration
xlScaleLinear = -4132
xlScaleLogarithmic = -4133

# XlSizeRepresents enumeration
xlSizeIsArea = 1
xlSizeIsWidth = 2

# XlTickLabelOrientation enumeration
xlTickLabelOrientationAutomatic = -4105
xlTickLabelOrientationDownward = -4170
xlTickLabelOrientationHorizontal = -4128
xlTickLabelOrientationUpward = -4171
xlTickLabelOrientationVertical = -4166

# XlTickLabelPosition enumeration
xlTickLabelPositionHigh = -4127
xlTickLabelPositionLow = -4134
xlTickLabelPositionNextToAxis = 4
xlTickLabelPositionNone = -4142

# XlTickMark enumeration
xlTickMarkCross = 4
xlTickMarkInside = 2
xlTickMarkNone = -4142
xlTickMarkOutside = 3

# XlTimeUnit enumeration
xlDays = 0
xlMonths = 1
xlYears = 2

# XlTrendlineType enumeration
xlExponential = 5
xlLinear = -4132
xlLogarithmic = -4133
xlMovingAvg = 6
xlPolynomial = 3
xlPower = 4

# XlUnderlineStyle enumeration
xlUnderlineStyleDouble = -4119
xlUnderlineStyleDoubleAccounting = 5
xlUnderlineStyleNone = -4142
xlUnderlineStyleSingle = 2
xlUnderlineStyleSingleAccounting = 4

# XlVAlign enumeration
xlVAlignBottom = -4107
xlVAlignCenter = -4108
xlVAlignDistributed = -4117
xlVAlignJustify = -4130
xlVAlignTop = -4160
