from . import com_arguments, unwrap
from .office import *

import win32com.client

class AddIn:

    def __init__(self, addin=None):
        self.com_object= addin

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Autoload(self):
        return self.com_object.Autoload

    @property
    def autoload(self):
        """Alias for Autoload"""
        return self.Autoload

    @property
    def Compiled(self):
        return self.com_object.Compiled

    @property
    def compiled(self):
        """Alias for Compiled"""
        return self.Compiled

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Installed(self):
        return self.com_object.Installed

    @Installed.setter
    def Installed(self, value):
        self.com_object.Installed = value

    @property
    def installed(self):
        """Alias for Installed"""
        return self.Installed

    @installed.setter
    def installed(self, value):
        """Alias for Installed.setter"""
        self.Installed = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Path(self):
        return self.com_object.Path

    @property
    def path(self):
        """Alias for Path"""
        return self.Path

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class AddIns:

    def __init__(self, addins=None):
        self.com_object= addins

    def __call__(self, item):
        return AddIn(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return AddIn(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return Application(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, FileName=None, Install=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, Install]])
        self.com_object.Add(*arguments)

    def add(self, FileName=None, Install=None):
        """Alias for Add"""
        arguments = [FileName, Install]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Unload(self, RemoveFromList=None):
        arguments = com_arguments([unwrap(a) for a in [RemoveFromList]])
        self.com_object.Unload(*arguments)

    def unload(self, RemoveFromList=None):
        """Alias for Unload"""
        arguments = [RemoveFromList]
        return self.Unload(*arguments)


class Adjustments:

    def __init__(self, adjustments=None):
        self.com_object= adjustments

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return Adjustments(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Item(self):
        return self.com_object.Item

    @Item.setter
    def Item(self, value):
        self.com_object.Item = value

    @property
    def item(self):
        """Alias for Item"""
        return self.Item

    @item.setter
    def item(self, value):
        """Alias for Item.setter"""
        self.Item = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class Application:

    def __init__(self, application=None):
        if application is None:
            self.com_object = win32com.client.gencache.EnsureDispatch("Word.Application")
        else:
            self.com_object = application

    @property
    def ActiveDocument(self):
        return Document(self.com_object.ActiveDocument)

    @property
    def activedocument(self):
        """Alias for ActiveDocument"""
        return self.ActiveDocument

    @property
    def active_document(self):
        """Alias for ActiveDocument"""
        return self.ActiveDocument

    @property
    def ActiveEncryptionSession(self):
        return self.com_object.ActiveEncryptionSession

    @property
    def activeencryptionsession(self):
        """Alias for ActiveEncryptionSession"""
        return self.ActiveEncryptionSession

    @property
    def active_encryption_session(self):
        """Alias for ActiveEncryptionSession"""
        return self.ActiveEncryptionSession

    @property
    def ActivePrinter(self):
        return self.com_object.ActivePrinter

    @ActivePrinter.setter
    def ActivePrinter(self, value):
        self.com_object.ActivePrinter = value

    @property
    def activeprinter(self):
        """Alias for ActivePrinter"""
        return self.ActivePrinter

    @activeprinter.setter
    def activeprinter(self, value):
        """Alias for ActivePrinter.setter"""
        self.ActivePrinter = value

    @property
    def active_printer(self):
        """Alias for ActivePrinter"""
        return self.ActivePrinter

    @active_printer.setter
    def active_printer(self, value):
        """Alias for ActivePrinter.setter"""
        self.ActivePrinter = value

    @property
    def ActiveProtectedViewWindow(self):
        return self.com_object.ActiveProtectedViewWindow

    @property
    def activeprotectedviewwindow(self):
        """Alias for ActiveProtectedViewWindow"""
        return self.ActiveProtectedViewWindow

    @property
    def active_protected_view_window(self):
        """Alias for ActiveProtectedViewWindow"""
        return self.ActiveProtectedViewWindow

    @property
    def ActiveWindow(self):
        return Window(self.com_object.ActiveWindow)

    @property
    def activewindow(self):
        """Alias for ActiveWindow"""
        return self.ActiveWindow

    @property
    def active_window(self):
        """Alias for ActiveWindow"""
        return self.ActiveWindow

    @property
    def AddIns(self):
        return AddIns(self.com_object.AddIns)

    @property
    def addins(self):
        """Alias for AddIns"""
        return self.AddIns

    @property
    def add_ins(self):
        """Alias for AddIns"""
        return self.AddIns

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ArbitraryXMLSupportAvailable(self):
        return self.com_object.ArbitraryXMLSupportAvailable

    @property
    def arbitraryxmlsupportavailable(self):
        """Alias for ArbitraryXMLSupportAvailable"""
        return self.ArbitraryXMLSupportAvailable

    @property
    def arbitrary_x_m_l_support_available(self):
        """Alias for ArbitraryXMLSupportAvailable"""
        return self.ArbitraryXMLSupportAvailable

    @property
    def Assistance(self):
        return self.com_object.Assistance

    @property
    def assistance(self):
        """Alias for Assistance"""
        return self.Assistance

    @property
    def AutoCaptions(self):
        return AutoCaptions(self.com_object.AutoCaptions)

    @property
    def autocaptions(self):
        """Alias for AutoCaptions"""
        return self.AutoCaptions

    @property
    def auto_captions(self):
        """Alias for AutoCaptions"""
        return self.AutoCaptions

    @property
    def AutoCorrect(self):
        return AutoCorrect(self.com_object.AutoCorrect)

    @property
    def autocorrect(self):
        """Alias for AutoCorrect"""
        return self.AutoCorrect

    @property
    def auto_correct(self):
        """Alias for AutoCorrect"""
        return self.AutoCorrect

    @property
    def AutoCorrectEmail(self):
        return AutoCorrect(self.com_object.AutoCorrectEmail)

    @property
    def autocorrectemail(self):
        """Alias for AutoCorrectEmail"""
        return self.AutoCorrectEmail

    @property
    def auto_correct_email(self):
        """Alias for AutoCorrectEmail"""
        return self.AutoCorrectEmail

    @property
    def AutomationSecurity(self):
        return self.com_object.AutomationSecurity

    @AutomationSecurity.setter
    def AutomationSecurity(self, value):
        self.com_object.AutomationSecurity = value

    @property
    def automationsecurity(self):
        """Alias for AutomationSecurity"""
        return self.AutomationSecurity

    @automationsecurity.setter
    def automationsecurity(self, value):
        """Alias for AutomationSecurity.setter"""
        self.AutomationSecurity = value

    @property
    def automation_security(self):
        """Alias for AutomationSecurity"""
        return self.AutomationSecurity

    @automation_security.setter
    def automation_security(self, value):
        """Alias for AutomationSecurity.setter"""
        self.AutomationSecurity = value

    @property
    def BackgroundPrintingStatus(self):
        return self.com_object.BackgroundPrintingStatus

    @property
    def backgroundprintingstatus(self):
        """Alias for BackgroundPrintingStatus"""
        return self.BackgroundPrintingStatus

    @property
    def background_printing_status(self):
        """Alias for BackgroundPrintingStatus"""
        return self.BackgroundPrintingStatus

    @property
    def BackgroundSavingStatus(self):
        return self.com_object.BackgroundSavingStatus

    @property
    def backgroundsavingstatus(self):
        """Alias for BackgroundSavingStatus"""
        return self.BackgroundSavingStatus

    @property
    def background_saving_status(self):
        """Alias for BackgroundSavingStatus"""
        return self.BackgroundSavingStatus

    @property
    def Bibliography(self):
        return Bibliography(self.com_object.Bibliography)

    @property
    def bibliography(self):
        """Alias for Bibliography"""
        return self.Bibliography

    @property
    def BrowseExtraFileTypes(self):
        return self.com_object.BrowseExtraFileTypes

    @BrowseExtraFileTypes.setter
    def BrowseExtraFileTypes(self, value):
        self.com_object.BrowseExtraFileTypes = value

    @property
    def browseextrafiletypes(self):
        """Alias for BrowseExtraFileTypes"""
        return self.BrowseExtraFileTypes

    @browseextrafiletypes.setter
    def browseextrafiletypes(self, value):
        """Alias for BrowseExtraFileTypes.setter"""
        self.BrowseExtraFileTypes = value

    @property
    def browse_extra_file_types(self):
        """Alias for BrowseExtraFileTypes"""
        return self.BrowseExtraFileTypes

    @browse_extra_file_types.setter
    def browse_extra_file_types(self, value):
        """Alias for BrowseExtraFileTypes.setter"""
        self.BrowseExtraFileTypes = value

    @property
    def Browser(self):
        return Browser(self.com_object.Browser)

    @property
    def browser(self):
        """Alias for Browser"""
        return self.Browser

    @property
    def Build(self):
        return self.com_object.Build

    @property
    def build(self):
        """Alias for Build"""
        return self.Build

    @property
    def CapsLock(self):
        return self.com_object.CapsLock

    @property
    def capslock(self):
        """Alias for CapsLock"""
        return self.CapsLock

    @property
    def caps_lock(self):
        """Alias for CapsLock"""
        return self.CapsLock

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    @property
    def CaptionLabels(self):
        return CaptionLabels(self.com_object.CaptionLabels)

    @property
    def captionlabels(self):
        """Alias for CaptionLabels"""
        return self.CaptionLabels

    @property
    def caption_labels(self):
        """Alias for CaptionLabels"""
        return self.CaptionLabels

    @property
    def ChartDataPointTrack(self):
        return self.com_object.ChartDataPointTrack

    @ChartDataPointTrack.setter
    def ChartDataPointTrack(self, value):
        self.com_object.ChartDataPointTrack = value

    @property
    def chartdatapointtrack(self):
        """Alias for ChartDataPointTrack"""
        return self.ChartDataPointTrack

    @chartdatapointtrack.setter
    def chartdatapointtrack(self, value):
        """Alias for ChartDataPointTrack.setter"""
        self.ChartDataPointTrack = value

    @property
    def chart_data_point_track(self):
        """Alias for ChartDataPointTrack"""
        return self.ChartDataPointTrack

    @chart_data_point_track.setter
    def chart_data_point_track(self, value):
        """Alias for ChartDataPointTrack.setter"""
        self.ChartDataPointTrack = value

    @property
    def CheckLanguage(self):
        return self.com_object.CheckLanguage

    @CheckLanguage.setter
    def CheckLanguage(self, value):
        self.com_object.CheckLanguage = value

    @property
    def checklanguage(self):
        """Alias for CheckLanguage"""
        return self.CheckLanguage

    @checklanguage.setter
    def checklanguage(self, value):
        """Alias for CheckLanguage.setter"""
        self.CheckLanguage = value

    @property
    def check_language(self):
        """Alias for CheckLanguage"""
        return self.CheckLanguage

    @check_language.setter
    def check_language(self, value):
        """Alias for CheckLanguage.setter"""
        self.CheckLanguage = value

    @property
    def COMAddIns(self):
        return self.com_object.COMAddIns

    @property
    def comaddins(self):
        """Alias for COMAddIns"""
        return self.COMAddIns

    @property
    def c_o_m_add_ins(self):
        """Alias for COMAddIns"""
        return self.COMAddIns

    @property
    def CommandBars(self):
        return self.com_object.CommandBars

    @property
    def commandbars(self):
        """Alias for CommandBars"""
        return self.CommandBars

    @property
    def command_bars(self):
        """Alias for CommandBars"""
        return self.CommandBars

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def CustomDictionaries(self):
        return Dictionaries(self.com_object.CustomDictionaries)

    @property
    def customdictionaries(self):
        """Alias for CustomDictionaries"""
        return self.CustomDictionaries

    @property
    def custom_dictionaries(self):
        """Alias for CustomDictionaries"""
        return self.CustomDictionaries

    @property
    def CustomizationContext(self):
        return Template(self.com_object.CustomizationContext)

    @CustomizationContext.setter
    def CustomizationContext(self, value):
        self.com_object.CustomizationContext = value

    @property
    def customizationcontext(self):
        """Alias for CustomizationContext"""
        return self.CustomizationContext

    @customizationcontext.setter
    def customizationcontext(self, value):
        """Alias for CustomizationContext.setter"""
        self.CustomizationContext = value

    @property
    def customization_context(self):
        """Alias for CustomizationContext"""
        return self.CustomizationContext

    @customization_context.setter
    def customization_context(self, value):
        """Alias for CustomizationContext.setter"""
        self.CustomizationContext = value

    @property
    def DefaultLegalBlackline(self):
        return self.com_object.DefaultLegalBlackline

    @DefaultLegalBlackline.setter
    def DefaultLegalBlackline(self, value):
        self.com_object.DefaultLegalBlackline = value

    @property
    def defaultlegalblackline(self):
        """Alias for DefaultLegalBlackline"""
        return self.DefaultLegalBlackline

    @defaultlegalblackline.setter
    def defaultlegalblackline(self, value):
        """Alias for DefaultLegalBlackline.setter"""
        self.DefaultLegalBlackline = value

    @property
    def default_legal_blackline(self):
        """Alias for DefaultLegalBlackline"""
        return self.DefaultLegalBlackline

    @default_legal_blackline.setter
    def default_legal_blackline(self, value):
        """Alias for DefaultLegalBlackline.setter"""
        self.DefaultLegalBlackline = value

    @property
    def DefaultSaveFormat(self):
        return self.com_object.DefaultSaveFormat

    @DefaultSaveFormat.setter
    def DefaultSaveFormat(self, value):
        self.com_object.DefaultSaveFormat = value

    @property
    def defaultsaveformat(self):
        """Alias for DefaultSaveFormat"""
        return self.DefaultSaveFormat

    @defaultsaveformat.setter
    def defaultsaveformat(self, value):
        """Alias for DefaultSaveFormat.setter"""
        self.DefaultSaveFormat = value

    @property
    def default_save_format(self):
        """Alias for DefaultSaveFormat"""
        return self.DefaultSaveFormat

    @default_save_format.setter
    def default_save_format(self, value):
        """Alias for DefaultSaveFormat.setter"""
        self.DefaultSaveFormat = value

    @property
    def DefaultTableSeparator(self):
        return self.com_object.DefaultTableSeparator

    @DefaultTableSeparator.setter
    def DefaultTableSeparator(self, value):
        self.com_object.DefaultTableSeparator = value

    @property
    def defaulttableseparator(self):
        """Alias for DefaultTableSeparator"""
        return self.DefaultTableSeparator

    @defaulttableseparator.setter
    def defaulttableseparator(self, value):
        """Alias for DefaultTableSeparator.setter"""
        self.DefaultTableSeparator = value

    @property
    def default_table_separator(self):
        """Alias for DefaultTableSeparator"""
        return self.DefaultTableSeparator

    @default_table_separator.setter
    def default_table_separator(self, value):
        """Alias for DefaultTableSeparator.setter"""
        self.DefaultTableSeparator = value

    @property
    def Dialogs(self):
        return Dialogs(self.com_object.Dialogs)

    @property
    def dialogs(self):
        """Alias for Dialogs"""
        return self.Dialogs

    @property
    def DisplayAlerts(self):
        return WdAlertLevel(self.com_object.DisplayAlerts)

    @DisplayAlerts.setter
    def DisplayAlerts(self, value):
        self.com_object.DisplayAlerts = value

    @property
    def displayalerts(self):
        """Alias for DisplayAlerts"""
        return self.DisplayAlerts

    @displayalerts.setter
    def displayalerts(self, value):
        """Alias for DisplayAlerts.setter"""
        self.DisplayAlerts = value

    @property
    def display_alerts(self):
        """Alias for DisplayAlerts"""
        return self.DisplayAlerts

    @display_alerts.setter
    def display_alerts(self, value):
        """Alias for DisplayAlerts.setter"""
        self.DisplayAlerts = value

    @property
    def DisplayAutoCompleteTips(self):
        return self.com_object.DisplayAutoCompleteTips

    @DisplayAutoCompleteTips.setter
    def DisplayAutoCompleteTips(self, value):
        self.com_object.DisplayAutoCompleteTips = value

    @property
    def displayautocompletetips(self):
        """Alias for DisplayAutoCompleteTips"""
        return self.DisplayAutoCompleteTips

    @displayautocompletetips.setter
    def displayautocompletetips(self, value):
        """Alias for DisplayAutoCompleteTips.setter"""
        self.DisplayAutoCompleteTips = value

    @property
    def display_auto_complete_tips(self):
        """Alias for DisplayAutoCompleteTips"""
        return self.DisplayAutoCompleteTips

    @display_auto_complete_tips.setter
    def display_auto_complete_tips(self, value):
        """Alias for DisplayAutoCompleteTips.setter"""
        self.DisplayAutoCompleteTips = value

    @property
    def DisplayDocumentInformationPanel(self):
        return self.com_object.DisplayDocumentInformationPanel

    @DisplayDocumentInformationPanel.setter
    def DisplayDocumentInformationPanel(self, value):
        self.com_object.DisplayDocumentInformationPanel = value

    @property
    def displaydocumentinformationpanel(self):
        """Alias for DisplayDocumentInformationPanel"""
        return self.DisplayDocumentInformationPanel

    @displaydocumentinformationpanel.setter
    def displaydocumentinformationpanel(self, value):
        """Alias for DisplayDocumentInformationPanel.setter"""
        self.DisplayDocumentInformationPanel = value

    @property
    def display_document_information_panel(self):
        """Alias for DisplayDocumentInformationPanel"""
        return self.DisplayDocumentInformationPanel

    @display_document_information_panel.setter
    def display_document_information_panel(self, value):
        """Alias for DisplayDocumentInformationPanel.setter"""
        self.DisplayDocumentInformationPanel = value

    @property
    def DisplayRecentFiles(self):
        return self.com_object.DisplayRecentFiles

    @DisplayRecentFiles.setter
    def DisplayRecentFiles(self, value):
        self.com_object.DisplayRecentFiles = value

    @property
    def displayrecentfiles(self):
        """Alias for DisplayRecentFiles"""
        return self.DisplayRecentFiles

    @displayrecentfiles.setter
    def displayrecentfiles(self, value):
        """Alias for DisplayRecentFiles.setter"""
        self.DisplayRecentFiles = value

    @property
    def display_recent_files(self):
        """Alias for DisplayRecentFiles"""
        return self.DisplayRecentFiles

    @display_recent_files.setter
    def display_recent_files(self, value):
        """Alias for DisplayRecentFiles.setter"""
        self.DisplayRecentFiles = value

    @property
    def DisplayScreenTips(self):
        return self.com_object.DisplayScreenTips

    @DisplayScreenTips.setter
    def DisplayScreenTips(self, value):
        self.com_object.DisplayScreenTips = value

    @property
    def displayscreentips(self):
        """Alias for DisplayScreenTips"""
        return self.DisplayScreenTips

    @displayscreentips.setter
    def displayscreentips(self, value):
        """Alias for DisplayScreenTips.setter"""
        self.DisplayScreenTips = value

    @property
    def display_screen_tips(self):
        """Alias for DisplayScreenTips"""
        return self.DisplayScreenTips

    @display_screen_tips.setter
    def display_screen_tips(self, value):
        """Alias for DisplayScreenTips.setter"""
        self.DisplayScreenTips = value

    @property
    def DisplayScrollBars(self):
        return self.com_object.DisplayScrollBars

    @DisplayScrollBars.setter
    def DisplayScrollBars(self, value):
        self.com_object.DisplayScrollBars = value

    @property
    def displayscrollbars(self):
        """Alias for DisplayScrollBars"""
        return self.DisplayScrollBars

    @displayscrollbars.setter
    def displayscrollbars(self, value):
        """Alias for DisplayScrollBars.setter"""
        self.DisplayScrollBars = value

    @property
    def display_scroll_bars(self):
        """Alias for DisplayScrollBars"""
        return self.DisplayScrollBars

    @display_scroll_bars.setter
    def display_scroll_bars(self, value):
        """Alias for DisplayScrollBars.setter"""
        self.DisplayScrollBars = value

    @property
    def Documents(self):
        return Documents(self.com_object.Documents)

    @property
    def documents(self):
        """Alias for Documents"""
        return self.Documents

    @property
    def DontResetInsertionPointProperties(self):
        return self.com_object.DontResetInsertionPointProperties

    @DontResetInsertionPointProperties.setter
    def DontResetInsertionPointProperties(self, value):
        self.com_object.DontResetInsertionPointProperties = value

    @property
    def dontresetinsertionpointproperties(self):
        """Alias for DontResetInsertionPointProperties"""
        return self.DontResetInsertionPointProperties

    @dontresetinsertionpointproperties.setter
    def dontresetinsertionpointproperties(self, value):
        """Alias for DontResetInsertionPointProperties.setter"""
        self.DontResetInsertionPointProperties = value

    @property
    def dont_reset_insertion_point_properties(self):
        """Alias for DontResetInsertionPointProperties"""
        return self.DontResetInsertionPointProperties

    @dont_reset_insertion_point_properties.setter
    def dont_reset_insertion_point_properties(self, value):
        """Alias for DontResetInsertionPointProperties.setter"""
        self.DontResetInsertionPointProperties = value

    @property
    def EmailOptions(self):
        return EmailOptions(self.com_object.EmailOptions)

    @property
    def emailoptions(self):
        """Alias for EmailOptions"""
        return self.EmailOptions

    @property
    def email_options(self):
        """Alias for EmailOptions"""
        return self.EmailOptions

    @property
    def EmailTemplate(self):
        return self.com_object.EmailTemplate

    @EmailTemplate.setter
    def EmailTemplate(self, value):
        self.com_object.EmailTemplate = value

    @property
    def emailtemplate(self):
        """Alias for EmailTemplate"""
        return self.EmailTemplate

    @emailtemplate.setter
    def emailtemplate(self, value):
        """Alias for EmailTemplate.setter"""
        self.EmailTemplate = value

    @property
    def email_template(self):
        """Alias for EmailTemplate"""
        return self.EmailTemplate

    @email_template.setter
    def email_template(self, value):
        """Alias for EmailTemplate.setter"""
        self.EmailTemplate = value

    @property
    def EnableCancelKey(self):
        return WdEnableCancelKey(self.com_object.EnableCancelKey)

    @EnableCancelKey.setter
    def EnableCancelKey(self, value):
        self.com_object.EnableCancelKey = value

    @property
    def enablecancelkey(self):
        """Alias for EnableCancelKey"""
        return self.EnableCancelKey

    @enablecancelkey.setter
    def enablecancelkey(self, value):
        """Alias for EnableCancelKey.setter"""
        self.EnableCancelKey = value

    @property
    def enable_cancel_key(self):
        """Alias for EnableCancelKey"""
        return self.EnableCancelKey

    @enable_cancel_key.setter
    def enable_cancel_key(self, value):
        """Alias for EnableCancelKey.setter"""
        self.EnableCancelKey = value

    @property
    def FeatureInstall(self):
        return self.com_object.FeatureInstall

    @FeatureInstall.setter
    def FeatureInstall(self, value):
        self.com_object.FeatureInstall = value

    @property
    def featureinstall(self):
        """Alias for FeatureInstall"""
        return self.FeatureInstall

    @featureinstall.setter
    def featureinstall(self, value):
        """Alias for FeatureInstall.setter"""
        self.FeatureInstall = value

    @property
    def feature_install(self):
        """Alias for FeatureInstall"""
        return self.FeatureInstall

    @feature_install.setter
    def feature_install(self, value):
        """Alias for FeatureInstall.setter"""
        self.FeatureInstall = value

    @property
    def FileConverters(self):
        return FileConverters(self.com_object.FileConverters)

    @property
    def fileconverters(self):
        """Alias for FileConverters"""
        return self.FileConverters

    @property
    def file_converters(self):
        """Alias for FileConverters"""
        return self.FileConverters

    def FileDialog(self, FileDialogType=None):
        arguments = com_arguments([unwrap(a) for a in [FileDialogType]])
        if hasattr(self.com_object, "GetFileDialog"):
            return self.com_object.GetFileDialog(*arguments)
        else:
            return self.com_object.FileDialog(*arguments)

    def filedialog(self, FileDialogType=None):
        """Alias for FileDialog"""
        arguments = [FileDialogType]
        return self.FileDialog(*arguments)

    def file_dialog(self, FileDialogType=None):
        """Alias for FileDialog"""
        arguments = [FileDialogType]
        return self.FileDialog(*arguments)

    @property
    def FileValidation(self):
        return self.com_object.FileValidation

    @FileValidation.setter
    def FileValidation(self, value):
        self.com_object.FileValidation = value

    @property
    def filevalidation(self):
        """Alias for FileValidation"""
        return self.FileValidation

    @filevalidation.setter
    def filevalidation(self, value):
        """Alias for FileValidation.setter"""
        self.FileValidation = value

    @property
    def file_validation(self):
        """Alias for FileValidation"""
        return self.FileValidation

    @file_validation.setter
    def file_validation(self, value):
        """Alias for FileValidation.setter"""
        self.FileValidation = value

    def FindKey(self, KeyCode=None, KeyCode2=None):
        arguments = com_arguments([unwrap(a) for a in [KeyCode, KeyCode2]])
        if hasattr(self.com_object, "GetFindKey"):
            return KeyBinding(self.com_object.GetFindKey(*arguments))
        else:
            return KeyBinding(self.com_object.FindKey(*arguments))

    def findkey(self, KeyCode=None, KeyCode2=None):
        """Alias for FindKey"""
        arguments = [KeyCode, KeyCode2]
        return self.FindKey(*arguments)

    def find_key(self, KeyCode=None, KeyCode2=None):
        """Alias for FindKey"""
        arguments = [KeyCode, KeyCode2]
        return self.FindKey(*arguments)

    @property
    def FocusInMailHeader(self):
        return self.com_object.FocusInMailHeader

    @property
    def focusinmailheader(self):
        """Alias for FocusInMailHeader"""
        return self.FocusInMailHeader

    @property
    def focus_in_mail_header(self):
        """Alias for FocusInMailHeader"""
        return self.FocusInMailHeader

    @property
    def FontNames(self):
        return FontNames(self.com_object.FontNames)

    @property
    def fontnames(self):
        """Alias for FontNames"""
        return self.FontNames

    @property
    def font_names(self):
        """Alias for FontNames"""
        return self.FontNames

    @property
    def HangulHanjaDictionaries(self):
        return HangulHanjaConversionDictionaries(self.com_object.HangulHanjaDictionaries)

    @property
    def hangulhanjadictionaries(self):
        """Alias for HangulHanjaDictionaries"""
        return self.HangulHanjaDictionaries

    @property
    def hangul_hanja_dictionaries(self):
        """Alias for HangulHanjaDictionaries"""
        return self.HangulHanjaDictionaries

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    def International(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetInternational"):
            return self.com_object.GetInternational(*arguments)
        else:
            return self.com_object.International(*arguments)

    def international(self, Index=None):
        """Alias for International"""
        arguments = [Index]
        return self.International(*arguments)

    def IsObjectValid(self, Object=None):
        arguments = com_arguments([unwrap(a) for a in [Object]])
        if hasattr(self.com_object, "GetIsObjectValid"):
            return self.com_object.GetIsObjectValid(*arguments)
        else:
            return self.com_object.IsObjectValid(*arguments)

    def isobjectvalid(self, Object=None):
        """Alias for IsObjectValid"""
        arguments = [Object]
        return self.IsObjectValid(*arguments)

    def is_object_valid(self, Object=None):
        """Alias for IsObjectValid"""
        arguments = [Object]
        return self.IsObjectValid(*arguments)

    @property
    def IsSandboxed(self):
        return self.com_object.IsSandboxed

    @property
    def issandboxed(self):
        """Alias for IsSandboxed"""
        return self.IsSandboxed

    @property
    def is_sandboxed(self):
        """Alias for IsSandboxed"""
        return self.IsSandboxed

    @property
    def KeyBindings(self):
        return KeyBindings(self.com_object.KeyBindings)

    @property
    def keybindings(self):
        """Alias for KeyBindings"""
        return self.KeyBindings

    @property
    def key_bindings(self):
        """Alias for KeyBindings"""
        return self.KeyBindings

    def KeysBoundTo(self, KeyCategory=None, Command=None, CommandParameter=None):
        arguments = com_arguments([unwrap(a) for a in [KeyCategory, Command, CommandParameter]])
        if hasattr(self.com_object, "GetKeysBoundTo"):
            return KeysBoundTo(self.com_object.GetKeysBoundTo(*arguments))
        else:
            return KeysBoundTo(self.com_object.KeysBoundTo(*arguments))

    def keysboundto(self, KeyCategory=None, Command=None, CommandParameter=None):
        """Alias for KeysBoundTo"""
        arguments = [KeyCategory, Command, CommandParameter]
        return self.KeysBoundTo(*arguments)

    def keys_bound_to(self, KeyCategory=None, Command=None, CommandParameter=None):
        """Alias for KeysBoundTo"""
        arguments = [KeyCategory, Command, CommandParameter]
        return self.KeysBoundTo(*arguments)

    @property
    def LandscapeFontNames(self):
        return FontNames(self.com_object.LandscapeFontNames)

    @property
    def landscapefontnames(self):
        """Alias for LandscapeFontNames"""
        return self.LandscapeFontNames

    @property
    def landscape_font_names(self):
        """Alias for LandscapeFontNames"""
        return self.LandscapeFontNames

    @property
    def Language(self):
        return self.com_object.Language

    @property
    def language(self):
        """Alias for Language"""
        return self.Language

    @property
    def Languages(self):
        return Languages(self.com_object.Languages)

    @property
    def languages(self):
        """Alias for Languages"""
        return self.Languages

    @property
    def LanguageSettings(self):
        return self.com_object.LanguageSettings

    @property
    def languagesettings(self):
        """Alias for LanguageSettings"""
        return self.LanguageSettings

    @property
    def language_settings(self):
        """Alias for LanguageSettings"""
        return self.LanguageSettings

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def ListGalleries(self):
        return ListGalleries(self.com_object.ListGalleries)

    @property
    def listgalleries(self):
        """Alias for ListGalleries"""
        return self.ListGalleries

    @property
    def list_galleries(self):
        """Alias for ListGalleries"""
        return self.ListGalleries

    @property
    def MacroContainer(self):
        return Template(self.com_object.MacroContainer)

    @property
    def macrocontainer(self):
        """Alias for MacroContainer"""
        return self.MacroContainer

    @property
    def macro_container(self):
        """Alias for MacroContainer"""
        return self.MacroContainer

    @property
    def MailingLabel(self):
        return MailingLabel(self.com_object.MailingLabel)

    @property
    def mailinglabel(self):
        """Alias for MailingLabel"""
        return self.MailingLabel

    @property
    def mailing_label(self):
        """Alias for MailingLabel"""
        return self.MailingLabel

    @property
    def MailMessage(self):
        return MailMessage(self.com_object.MailMessage)

    @property
    def mailmessage(self):
        """Alias for MailMessage"""
        return self.MailMessage

    @property
    def mail_message(self):
        """Alias for MailMessage"""
        return self.MailMessage

    @property
    def MailSystem(self):
        return WdMailSystem(self.com_object.MailSystem)

    @property
    def mailsystem(self):
        """Alias for MailSystem"""
        return self.MailSystem

    @property
    def mail_system(self):
        """Alias for MailSystem"""
        return self.MailSystem

    @property
    def MAPIAvailable(self):
        return self.com_object.MAPIAvailable

    @property
    def mapiavailable(self):
        """Alias for MAPIAvailable"""
        return self.MAPIAvailable

    @property
    def m_a_p_i_available(self):
        """Alias for MAPIAvailable"""
        return self.MAPIAvailable

    @property
    def MathCoprocessorAvailable(self):
        return self.com_object.MathCoprocessorAvailable

    @property
    def mathcoprocessoravailable(self):
        """Alias for MathCoprocessorAvailable"""
        return self.MathCoprocessorAvailable

    @property
    def math_coprocessor_available(self):
        """Alias for MathCoprocessorAvailable"""
        return self.MathCoprocessorAvailable

    @property
    def MouseAvailable(self):
        return self.com_object.MouseAvailable

    @property
    def mouseavailable(self):
        """Alias for MouseAvailable"""
        return self.MouseAvailable

    @property
    def mouse_available(self):
        """Alias for MouseAvailable"""
        return self.MouseAvailable

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NewDocument(self):
        return self.com_object.NewDocument

    @property
    def newdocument(self):
        """Alias for NewDocument"""
        return self.NewDocument

    @property
    def new_document(self):
        """Alias for NewDocument"""
        return self.NewDocument

    @property
    def NormalTemplate(self):
        return Template(self.com_object.NormalTemplate)

    @property
    def normaltemplate(self):
        """Alias for NormalTemplate"""
        return self.NormalTemplate

    @property
    def normal_template(self):
        """Alias for NormalTemplate"""
        return self.NormalTemplate

    @property
    def NumLock(self):
        return self.com_object.NumLock

    @property
    def numlock(self):
        """Alias for NumLock"""
        return self.NumLock

    @property
    def num_lock(self):
        """Alias for NumLock"""
        return self.NumLock

    @property
    def OMathAutoCorrect(self):
        return OMathAutoCorrect(self.com_object.OMathAutoCorrect)

    @property
    def omathautocorrect(self):
        """Alias for OMathAutoCorrect"""
        return self.OMathAutoCorrect

    @property
    def o_math_auto_correct(self):
        """Alias for OMathAutoCorrect"""
        return self.OMathAutoCorrect

    @property
    def OpenAttachmentsInFullScreen(self):
        return self.com_object.OpenAttachmentsInFullScreen

    @OpenAttachmentsInFullScreen.setter
    def OpenAttachmentsInFullScreen(self, value):
        self.com_object.OpenAttachmentsInFullScreen = value

    @property
    def openattachmentsinfullscreen(self):
        """Alias for OpenAttachmentsInFullScreen"""
        return self.OpenAttachmentsInFullScreen

    @openattachmentsinfullscreen.setter
    def openattachmentsinfullscreen(self, value):
        """Alias for OpenAttachmentsInFullScreen.setter"""
        self.OpenAttachmentsInFullScreen = value

    @property
    def open_attachments_in_full_screen(self):
        """Alias for OpenAttachmentsInFullScreen"""
        return self.OpenAttachmentsInFullScreen

    @open_attachments_in_full_screen.setter
    def open_attachments_in_full_screen(self, value):
        """Alias for OpenAttachmentsInFullScreen.setter"""
        self.OpenAttachmentsInFullScreen = value

    @property
    def Options(self):
        return Options(self.com_object.Options)

    @property
    def options(self):
        """Alias for Options"""
        return self.Options

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Path(self):
        return self.com_object.Path

    @property
    def path(self):
        """Alias for Path"""
        return self.Path

    @property
    def PathSeparator(self):
        return self.com_object.PathSeparator

    @property
    def pathseparator(self):
        """Alias for PathSeparator"""
        return self.PathSeparator

    @property
    def path_separator(self):
        """Alias for PathSeparator"""
        return self.PathSeparator

    @property
    def PickerDialog(self):
        return self.com_object.PickerDialog

    @property
    def pickerdialog(self):
        """Alias for PickerDialog"""
        return self.PickerDialog

    @property
    def picker_dialog(self):
        """Alias for PickerDialog"""
        return self.PickerDialog

    @property
    def PortraitFontNames(self):
        return FontNames(self.com_object.PortraitFontNames)

    @property
    def portraitfontnames(self):
        """Alias for PortraitFontNames"""
        return self.PortraitFontNames

    @property
    def portrait_font_names(self):
        """Alias for PortraitFontNames"""
        return self.PortraitFontNames

    @property
    def PrintPreview(self):
        return self.com_object.PrintPreview

    @PrintPreview.setter
    def PrintPreview(self, value):
        self.com_object.PrintPreview = value

    @property
    def printpreview(self):
        """Alias for PrintPreview"""
        return self.PrintPreview

    @printpreview.setter
    def printpreview(self, value):
        """Alias for PrintPreview.setter"""
        self.PrintPreview = value

    @property
    def print_preview(self):
        """Alias for PrintPreview"""
        return self.PrintPreview

    @print_preview.setter
    def print_preview(self, value):
        """Alias for PrintPreview.setter"""
        self.PrintPreview = value

    @property
    def ProtectedViewWindows(self):
        return self.com_object.ProtectedViewWindows

    @property
    def protectedviewwindows(self):
        """Alias for ProtectedViewWindows"""
        return self.ProtectedViewWindows

    @property
    def protected_view_windows(self):
        """Alias for ProtectedViewWindows"""
        return self.ProtectedViewWindows

    @property
    def RecentFiles(self):
        return RecentFiles(self.com_object.RecentFiles)

    @property
    def recentfiles(self):
        """Alias for RecentFiles"""
        return self.RecentFiles

    @property
    def recent_files(self):
        """Alias for RecentFiles"""
        return self.RecentFiles

    @property
    def RestrictLinkedStyles(self):
        return self.com_object.RestrictLinkedStyles

    @RestrictLinkedStyles.setter
    def RestrictLinkedStyles(self, value):
        self.com_object.RestrictLinkedStyles = value

    @property
    def restrictlinkedstyles(self):
        """Alias for RestrictLinkedStyles"""
        return self.RestrictLinkedStyles

    @restrictlinkedstyles.setter
    def restrictlinkedstyles(self, value):
        """Alias for RestrictLinkedStyles.setter"""
        self.RestrictLinkedStyles = value

    @property
    def restrict_linked_styles(self):
        """Alias for RestrictLinkedStyles"""
        return self.RestrictLinkedStyles

    @restrict_linked_styles.setter
    def restrict_linked_styles(self, value):
        """Alias for RestrictLinkedStyles.setter"""
        self.RestrictLinkedStyles = value

    @property
    def ScreenUpdating(self):
        return self.com_object.ScreenUpdating

    @ScreenUpdating.setter
    def ScreenUpdating(self, value):
        self.com_object.ScreenUpdating = value

    @property
    def screenupdating(self):
        """Alias for ScreenUpdating"""
        return self.ScreenUpdating

    @screenupdating.setter
    def screenupdating(self, value):
        """Alias for ScreenUpdating.setter"""
        self.ScreenUpdating = value

    @property
    def screen_updating(self):
        """Alias for ScreenUpdating"""
        return self.ScreenUpdating

    @screen_updating.setter
    def screen_updating(self, value):
        """Alias for ScreenUpdating.setter"""
        self.ScreenUpdating = value

    @property
    def Selection(self):
        return Selection(self.com_object.Selection)

    @property
    def selection(self):
        """Alias for Selection"""
        return self.Selection

    @property
    def SensitivityLabelPolicy(self):
        return self.com_object.SensitivityLabelPolicy

    @property
    def sensitivitylabelpolicy(self):
        """Alias for SensitivityLabelPolicy"""
        return self.SensitivityLabelPolicy

    @property
    def sensitivity_label_policy(self):
        """Alias for SensitivityLabelPolicy"""
        return self.SensitivityLabelPolicy

    @property
    def ShowAnimation(self):
        return self.com_object.ShowAnimation

    @property
    def showanimation(self):
        """Alias for ShowAnimation"""
        return self.ShowAnimation

    @property
    def show_animation(self):
        """Alias for ShowAnimation"""
        return self.ShowAnimation

    @property
    def ShowStartupDialog(self):
        return self.com_object.ShowStartupDialog

    @ShowStartupDialog.setter
    def ShowStartupDialog(self, value):
        self.com_object.ShowStartupDialog = value

    @property
    def showstartupdialog(self):
        """Alias for ShowStartupDialog"""
        return self.ShowStartupDialog

    @showstartupdialog.setter
    def showstartupdialog(self, value):
        """Alias for ShowStartupDialog.setter"""
        self.ShowStartupDialog = value

    @property
    def show_startup_dialog(self):
        """Alias for ShowStartupDialog"""
        return self.ShowStartupDialog

    @show_startup_dialog.setter
    def show_startup_dialog(self, value):
        """Alias for ShowStartupDialog.setter"""
        self.ShowStartupDialog = value

    @property
    def ShowStylePreviews(self):
        return self.com_object.ShowStylePreviews

    @ShowStylePreviews.setter
    def ShowStylePreviews(self, value):
        self.com_object.ShowStylePreviews = value

    @property
    def showstylepreviews(self):
        """Alias for ShowStylePreviews"""
        return self.ShowStylePreviews

    @showstylepreviews.setter
    def showstylepreviews(self, value):
        """Alias for ShowStylePreviews.setter"""
        self.ShowStylePreviews = value

    @property
    def show_style_previews(self):
        """Alias for ShowStylePreviews"""
        return self.ShowStylePreviews

    @show_style_previews.setter
    def show_style_previews(self, value):
        """Alias for ShowStylePreviews.setter"""
        self.ShowStylePreviews = value

    @property
    def ShowVisualBasicEditor(self):
        return self.com_object.ShowVisualBasicEditor

    @ShowVisualBasicEditor.setter
    def ShowVisualBasicEditor(self, value):
        self.com_object.ShowVisualBasicEditor = value

    @property
    def showvisualbasiceditor(self):
        """Alias for ShowVisualBasicEditor"""
        return self.ShowVisualBasicEditor

    @showvisualbasiceditor.setter
    def showvisualbasiceditor(self, value):
        """Alias for ShowVisualBasicEditor.setter"""
        self.ShowVisualBasicEditor = value

    @property
    def show_visual_basic_editor(self):
        """Alias for ShowVisualBasicEditor"""
        return self.ShowVisualBasicEditor

    @show_visual_basic_editor.setter
    def show_visual_basic_editor(self, value):
        """Alias for ShowVisualBasicEditor.setter"""
        self.ShowVisualBasicEditor = value

    @property
    def SmartArtColors(self):
        return self.com_object.SmartArtColors

    @property
    def smartartcolors(self):
        """Alias for SmartArtColors"""
        return self.SmartArtColors

    @property
    def smart_art_colors(self):
        """Alias for SmartArtColors"""
        return self.SmartArtColors

    @property
    def SmartArtLayouts(self):
        return self.com_object.SmartArtLayouts

    @property
    def smartartlayouts(self):
        """Alias for SmartArtLayouts"""
        return self.SmartArtLayouts

    @property
    def smart_art_layouts(self):
        """Alias for SmartArtLayouts"""
        return self.SmartArtLayouts

    @property
    def SmartArtQuickStyles(self):
        return self.com_object.SmartArtQuickStyles

    @property
    def smartartquickstyles(self):
        """Alias for SmartArtQuickStyles"""
        return self.SmartArtQuickStyles

    @property
    def smart_art_quick_styles(self):
        """Alias for SmartArtQuickStyles"""
        return self.SmartArtQuickStyles

    @property
    def SpecialMode(self):
        return self.com_object.SpecialMode

    @property
    def specialmode(self):
        """Alias for SpecialMode"""
        return self.SpecialMode

    @property
    def special_mode(self):
        """Alias for SpecialMode"""
        return self.SpecialMode

    @property
    def StartupPath(self):
        return self.com_object.StartupPath

    @StartupPath.setter
    def StartupPath(self, value):
        self.com_object.StartupPath = value

    @property
    def startuppath(self):
        """Alias for StartupPath"""
        return self.StartupPath

    @startuppath.setter
    def startuppath(self, value):
        """Alias for StartupPath.setter"""
        self.StartupPath = value

    @property
    def startup_path(self):
        """Alias for StartupPath"""
        return self.StartupPath

    @startup_path.setter
    def startup_path(self, value):
        """Alias for StartupPath.setter"""
        self.StartupPath = value

    @property
    def StatusBar(self):
        return self.com_object.StatusBar

    @property
    def statusbar(self):
        """Alias for StatusBar"""
        return self.StatusBar

    @property
    def status_bar(self):
        """Alias for StatusBar"""
        return self.StatusBar

    def SynonymInfo(self, Word=None, LanguageID=None):
        arguments = com_arguments([unwrap(a) for a in [Word, LanguageID]])
        if hasattr(self.com_object, "GetSynonymInfo"):
            return SynonymInfo(self.com_object.GetSynonymInfo(*arguments))
        else:
            return SynonymInfo(self.com_object.SynonymInfo(*arguments))

    def synonyminfo(self, Word=None, LanguageID=None):
        """Alias for SynonymInfo"""
        arguments = [Word, LanguageID]
        return self.SynonymInfo(*arguments)

    def synonym_info(self, Word=None, LanguageID=None):
        """Alias for SynonymInfo"""
        arguments = [Word, LanguageID]
        return self.SynonymInfo(*arguments)

    @property
    def System(self):
        return System(self.com_object.System)

    @property
    def system(self):
        """Alias for System"""
        return self.System

    @property
    def TaskPanes(self):
        return TaskPanes(self.com_object.TaskPanes)

    @property
    def taskpanes(self):
        """Alias for TaskPanes"""
        return self.TaskPanes

    @property
    def task_panes(self):
        """Alias for TaskPanes"""
        return self.TaskPanes

    @property
    def Tasks(self):
        return Tasks(self.com_object.Tasks)

    @property
    def tasks(self):
        """Alias for Tasks"""
        return self.Tasks

    @property
    def Templates(self):
        return Templates(self.com_object.Templates)

    @property
    def templates(self):
        """Alias for Templates"""
        return self.Templates

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def UndoRecord(self):
        return self.com_object.UndoRecord

    @property
    def undorecord(self):
        """Alias for UndoRecord"""
        return self.UndoRecord

    @property
    def undo_record(self):
        """Alias for UndoRecord"""
        return self.UndoRecord

    @property
    def UsableHeight(self):
        return self.com_object.UsableHeight

    @property
    def usableheight(self):
        """Alias for UsableHeight"""
        return self.UsableHeight

    @property
    def usable_height(self):
        """Alias for UsableHeight"""
        return self.UsableHeight

    @property
    def UsableWidth(self):
        return self.com_object.UsableWidth

    @property
    def usablewidth(self):
        """Alias for UsableWidth"""
        return self.UsableWidth

    @property
    def usable_width(self):
        """Alias for UsableWidth"""
        return self.UsableWidth

    @property
    def UserAddress(self):
        return self.com_object.UserAddress

    @UserAddress.setter
    def UserAddress(self, value):
        self.com_object.UserAddress = value

    @property
    def useraddress(self):
        """Alias for UserAddress"""
        return self.UserAddress

    @useraddress.setter
    def useraddress(self, value):
        """Alias for UserAddress.setter"""
        self.UserAddress = value

    @property
    def user_address(self):
        """Alias for UserAddress"""
        return self.UserAddress

    @user_address.setter
    def user_address(self, value):
        """Alias for UserAddress.setter"""
        self.UserAddress = value

    @property
    def UserControl(self):
        return self.com_object.UserControl

    @property
    def usercontrol(self):
        """Alias for UserControl"""
        return self.UserControl

    @property
    def user_control(self):
        """Alias for UserControl"""
        return self.UserControl

    @property
    def UserInitials(self):
        return self.com_object.UserInitials

    @UserInitials.setter
    def UserInitials(self, value):
        self.com_object.UserInitials = value

    @property
    def userinitials(self):
        """Alias for UserInitials"""
        return self.UserInitials

    @userinitials.setter
    def userinitials(self, value):
        """Alias for UserInitials.setter"""
        self.UserInitials = value

    @property
    def user_initials(self):
        """Alias for UserInitials"""
        return self.UserInitials

    @user_initials.setter
    def user_initials(self, value):
        """Alias for UserInitials.setter"""
        self.UserInitials = value

    @property
    def UserName(self):
        return self.com_object.UserName

    @UserName.setter
    def UserName(self, value):
        self.com_object.UserName = value

    @property
    def username(self):
        """Alias for UserName"""
        return self.UserName

    @username.setter
    def username(self, value):
        """Alias for UserName.setter"""
        self.UserName = value

    @property
    def user_name(self):
        """Alias for UserName"""
        return self.UserName

    @user_name.setter
    def user_name(self, value):
        """Alias for UserName.setter"""
        self.UserName = value

    @property
    def VBE(self):
        return self.com_object.VBE

    @property
    def vbe(self):
        """Alias for VBE"""
        return self.VBE

    @property
    def v_b_e(self):
        """Alias for VBE"""
        return self.VBE

    @property
    def Version(self):
        return self.com_object.Version

    @property
    def version(self):
        """Alias for Version"""
        return self.Version

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def Windows(self):
        return Windows(self.com_object.Windows)

    @property
    def windows(self):
        """Alias for Windows"""
        return self.Windows

    @property
    def WindowState(self):
        return WdWindowState(self.com_object.WindowState)

    @WindowState.setter
    def WindowState(self, value):
        self.com_object.WindowState = value

    @property
    def windowstate(self):
        """Alias for WindowState"""
        return self.WindowState

    @windowstate.setter
    def windowstate(self, value):
        """Alias for WindowState.setter"""
        self.WindowState = value

    @property
    def window_state(self):
        """Alias for WindowState"""
        return self.WindowState

    @window_state.setter
    def window_state(self, value):
        """Alias for WindowState.setter"""
        self.WindowState = value

    @property
    def WordBasic(self):
        return self.com_object.WordBasic

    @property
    def wordbasic(self):
        """Alias for WordBasic"""
        return self.WordBasic

    @property
    def word_basic(self):
        """Alias for WordBasic"""
        return self.WordBasic

    @property
    def XMLNamespaces(self):
        return self.com_object.XMLNamespaces

    @property
    def xmlnamespaces(self):
        """Alias for XMLNamespaces"""
        return self.XMLNamespaces

    @property
    def x_m_l_namespaces(self):
        """Alias for XMLNamespaces"""
        return self.XMLNamespaces

    def Activate(self):
        self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()

    def AddAddress(self, TagID=None, Value=None):
        arguments = com_arguments([unwrap(a) for a in [TagID, Value]])
        self.com_object.AddAddress(*arguments)

    def addaddress(self, TagID=None, Value=None):
        """Alias for AddAddress"""
        arguments = [TagID, Value]
        return self.AddAddress(*arguments)

    def add_address(self, TagID=None, Value=None):
        """Alias for AddAddress"""
        arguments = [TagID, Value]
        return self.AddAddress(*arguments)

    def NextLetter(self):
        self.com_object.NextLetter()

    def nextletter(self):
        """Alias for NextLetter"""
        return self.NextLetter()

    def next_letter(self):
        """Alias for NextLetter"""
        return self.NextLetter()

    def AutomaticChange(self):
        self.com_object.AutomaticChange()

    def automaticchange(self):
        """Alias for AutomaticChange"""
        return self.AutomaticChange()

    def automatic_change(self):
        """Alias for AutomaticChange"""
        return self.AutomaticChange()

    def BuildKeyCode(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        self.com_object.BuildKeyCode(*arguments)

    def buildkeycode(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for BuildKeyCode"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.BuildKeyCode(*arguments)

    def build_key_code(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for BuildKeyCode"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.BuildKeyCode(*arguments)

    def CentimetersToPoints(self, Centimeters=None):
        arguments = com_arguments([unwrap(a) for a in [Centimeters]])
        self.com_object.CentimetersToPoints(*arguments)

    def centimeterstopoints(self, Centimeters=None):
        """Alias for CentimetersToPoints"""
        arguments = [Centimeters]
        return self.CentimetersToPoints(*arguments)

    def centimeters_to_points(self, Centimeters=None):
        """Alias for CentimetersToPoints"""
        arguments = [Centimeters]
        return self.CentimetersToPoints(*arguments)

    def ChangeFileOpenDirectory(self, Path=None):
        arguments = com_arguments([unwrap(a) for a in [Path]])
        self.com_object.ChangeFileOpenDirectory(*arguments)

    def changefileopendirectory(self, Path=None):
        """Alias for ChangeFileOpenDirectory"""
        arguments = [Path]
        return self.ChangeFileOpenDirectory(*arguments)

    def change_file_open_directory(self, Path=None):
        """Alias for ChangeFileOpenDirectory"""
        arguments = [Path]
        return self.ChangeFileOpenDirectory(*arguments)

    def CheckGrammar(self, String=None):
        arguments = com_arguments([unwrap(a) for a in [String]])
        return self.com_object.CheckGrammar(*arguments)

    def checkgrammar(self, String=None):
        """Alias for CheckGrammar"""
        arguments = [String]
        return self.CheckGrammar(*arguments)

    def check_grammar(self, String=None):
        """Alias for CheckGrammar"""
        arguments = [String]
        return self.CheckGrammar(*arguments)

    def CheckSpelling(self, Word=None, CustomDictionary=None, IgnoreUppercase=None, MainDictionary=None, CustomDictionary2=None, CustomDictionary3=None, CustomDictionary4=None, CustomDictionary5=None, CustomDictionary6=None, CustomDictionary7=None, CustomDictionary8=None, CustomDictionary9=None, CustomDictionary10=None):
        arguments = com_arguments([unwrap(a) for a in [Word, CustomDictionary, IgnoreUppercase, MainDictionary, CustomDictionary2, CustomDictionary3, CustomDictionary4, CustomDictionary5, CustomDictionary6, CustomDictionary7, CustomDictionary8, CustomDictionary9, CustomDictionary10]])
        return self.com_object.CheckSpelling(*arguments)

    def checkspelling(self, Word=None, CustomDictionary=None, IgnoreUppercase=None, MainDictionary=None, CustomDictionary2=None, CustomDictionary3=None, CustomDictionary4=None, CustomDictionary5=None, CustomDictionary6=None, CustomDictionary7=None, CustomDictionary8=None, CustomDictionary9=None, CustomDictionary10=None):
        """Alias for CheckSpelling"""
        arguments = [Word, CustomDictionary, IgnoreUppercase, MainDictionary, CustomDictionary2, CustomDictionary3, CustomDictionary4, CustomDictionary5, CustomDictionary6, CustomDictionary7, CustomDictionary8, CustomDictionary9, CustomDictionary10]
        return self.CheckSpelling(*arguments)

    def check_spelling(self, Word=None, CustomDictionary=None, IgnoreUppercase=None, MainDictionary=None, CustomDictionary2=None, CustomDictionary3=None, CustomDictionary4=None, CustomDictionary5=None, CustomDictionary6=None, CustomDictionary7=None, CustomDictionary8=None, CustomDictionary9=None, CustomDictionary10=None):
        """Alias for CheckSpelling"""
        arguments = [Word, CustomDictionary, IgnoreUppercase, MainDictionary, CustomDictionary2, CustomDictionary3, CustomDictionary4, CustomDictionary5, CustomDictionary6, CustomDictionary7, CustomDictionary8, CustomDictionary9, CustomDictionary10]
        return self.CheckSpelling(*arguments)

    def CleanString(self, String=None):
        arguments = com_arguments([unwrap(a) for a in [String]])
        self.com_object.CleanString(*arguments)

    def cleanstring(self, String=None):
        """Alias for CleanString"""
        arguments = [String]
        return self.CleanString(*arguments)

    def clean_string(self, String=None):
        """Alias for CleanString"""
        arguments = [String]
        return self.CleanString(*arguments)

    def CompareDocuments(self, OriginalDocument=None, RevisedDocument=None, Destination=None, Granularity=None, CompareFormatting=None, CompareCaseChanges=None, CompareWhitespace=None, CompareTables=None, CompareHeaders=None, CompareFootnotes=None, CompareTextboxes=None, CompareFields=None, CompareComments=None, CompareMoves=None, RevisedAuthor=None, IgnoreAllComparisonWarnings=None):
        arguments = com_arguments([unwrap(a) for a in [OriginalDocument, RevisedDocument, Destination, Granularity, CompareFormatting, CompareCaseChanges, CompareWhitespace, CompareTables, CompareHeaders, CompareFootnotes, CompareTextboxes, CompareFields, CompareComments, CompareMoves, RevisedAuthor, IgnoreAllComparisonWarnings]])
        return Document(self.com_object.CompareDocuments(*arguments))

    def comparedocuments(self, OriginalDocument=None, RevisedDocument=None, Destination=None, Granularity=None, CompareFormatting=None, CompareCaseChanges=None, CompareWhitespace=None, CompareTables=None, CompareHeaders=None, CompareFootnotes=None, CompareTextboxes=None, CompareFields=None, CompareComments=None, CompareMoves=None, RevisedAuthor=None, IgnoreAllComparisonWarnings=None):
        """Alias for CompareDocuments"""
        arguments = [OriginalDocument, RevisedDocument, Destination, Granularity, CompareFormatting, CompareCaseChanges, CompareWhitespace, CompareTables, CompareHeaders, CompareFootnotes, CompareTextboxes, CompareFields, CompareComments, CompareMoves, RevisedAuthor, IgnoreAllComparisonWarnings]
        return self.CompareDocuments(*arguments)

    def compare_documents(self, OriginalDocument=None, RevisedDocument=None, Destination=None, Granularity=None, CompareFormatting=None, CompareCaseChanges=None, CompareWhitespace=None, CompareTables=None, CompareHeaders=None, CompareFootnotes=None, CompareTextboxes=None, CompareFields=None, CompareComments=None, CompareMoves=None, RevisedAuthor=None, IgnoreAllComparisonWarnings=None):
        """Alias for CompareDocuments"""
        arguments = [OriginalDocument, RevisedDocument, Destination, Granularity, CompareFormatting, CompareCaseChanges, CompareWhitespace, CompareTables, CompareHeaders, CompareFootnotes, CompareTextboxes, CompareFields, CompareComments, CompareMoves, RevisedAuthor, IgnoreAllComparisonWarnings]
        return self.CompareDocuments(*arguments)

    def DDEInitiate(self, App=None, Topic=None):
        arguments = com_arguments([unwrap(a) for a in [App, Topic]])
        self.com_object.DDEInitiate(*arguments)

    def ddeinitiate(self, App=None, Topic=None):
        """Alias for DDEInitiate"""
        arguments = [App, Topic]
        return self.DDEInitiate(*arguments)

    def d_d_e_initiate(self, App=None, Topic=None):
        """Alias for DDEInitiate"""
        arguments = [App, Topic]
        return self.DDEInitiate(*arguments)

    def DDEPoke(self, Channel=None, Item=None, Data=None):
        arguments = com_arguments([unwrap(a) for a in [Channel, Item, Data]])
        self.com_object.DDEPoke(*arguments)

    def ddepoke(self, Channel=None, Item=None, Data=None):
        """Alias for DDEPoke"""
        arguments = [Channel, Item, Data]
        return self.DDEPoke(*arguments)

    def d_d_e_poke(self, Channel=None, Item=None, Data=None):
        """Alias for DDEPoke"""
        arguments = [Channel, Item, Data]
        return self.DDEPoke(*arguments)

    def DDERequest(self, Channel=None, Item=None):
        arguments = com_arguments([unwrap(a) for a in [Channel, Item]])
        self.com_object.DDERequest(*arguments)

    def dderequest(self, Channel=None, Item=None):
        """Alias for DDERequest"""
        arguments = [Channel, Item]
        return self.DDERequest(*arguments)

    def d_d_e_request(self, Channel=None, Item=None):
        """Alias for DDERequest"""
        arguments = [Channel, Item]
        return self.DDERequest(*arguments)

    def DDETerminate(self, Channel=None):
        arguments = com_arguments([unwrap(a) for a in [Channel]])
        self.com_object.DDETerminate(*arguments)

    def ddeterminate(self, Channel=None):
        """Alias for DDETerminate"""
        arguments = [Channel]
        return self.DDETerminate(*arguments)

    def d_d_e_terminate(self, Channel=None):
        """Alias for DDETerminate"""
        arguments = [Channel]
        return self.DDETerminate(*arguments)

    def DDETerminateAll(self):
        self.com_object.DDETerminateAll()

    def ddeterminateall(self):
        """Alias for DDETerminateAll"""
        return self.DDETerminateAll()

    def d_d_e_terminate_all(self):
        """Alias for DDETerminateAll"""
        return self.DDETerminateAll()

    def DefaultWebOptions(self):
        return DefaultWebOptions(self.com_object.DefaultWebOptions())

    def defaultweboptions(self):
        """Alias for DefaultWebOptions"""
        return self.DefaultWebOptions()

    def default_web_options(self):
        """Alias for DefaultWebOptions"""
        return self.DefaultWebOptions()

    def GetAddress(self, Name=None, AddressProperties=None, UseAutoText=None, DisplaySelectDialog=None, SelectDialog=None, CheckNamesDialog=None, RecentAddressesChoice=None, UpdateRecentAddresses=None):
        arguments = com_arguments([unwrap(a) for a in [Name, AddressProperties, UseAutoText, DisplaySelectDialog, SelectDialog, CheckNamesDialog, RecentAddressesChoice, UpdateRecentAddresses]])
        return self.com_object.GetAddress(*arguments)

    def getaddress(self, Name=None, AddressProperties=None, UseAutoText=None, DisplaySelectDialog=None, SelectDialog=None, CheckNamesDialog=None, RecentAddressesChoice=None, UpdateRecentAddresses=None):
        """Alias for GetAddress"""
        arguments = [Name, AddressProperties, UseAutoText, DisplaySelectDialog, SelectDialog, CheckNamesDialog, RecentAddressesChoice, UpdateRecentAddresses]
        return self.GetAddress(*arguments)

    def get_address(self, Name=None, AddressProperties=None, UseAutoText=None, DisplaySelectDialog=None, SelectDialog=None, CheckNamesDialog=None, RecentAddressesChoice=None, UpdateRecentAddresses=None):
        """Alias for GetAddress"""
        arguments = [Name, AddressProperties, UseAutoText, DisplaySelectDialog, SelectDialog, CheckNamesDialog, RecentAddressesChoice, UpdateRecentAddresses]
        return self.GetAddress(*arguments)

    def GetDefaultTheme(self, DocumentType=None):
        arguments = com_arguments([unwrap(a) for a in [DocumentType]])
        self.com_object.GetDefaultTheme(*arguments)

    def getdefaulttheme(self, DocumentType=None):
        """Alias for GetDefaultTheme"""
        arguments = [DocumentType]
        return self.GetDefaultTheme(*arguments)

    def get_default_theme(self, DocumentType=None):
        """Alias for GetDefaultTheme"""
        arguments = [DocumentType]
        return self.GetDefaultTheme(*arguments)

    def GetSpellingSuggestions(self, Word=None, CustomDictionary=None, IgnoreUppercase=None, MainDictionary=None, SuggestionMode=None, CustomDictionary2=None, CustomDictionary3=None, CustomDictionary4=None, CustomDictionary5=None, CustomDictionary6=None, CustomDictionary7=None, CustomDictionary8=None, CustomDictionary9=None, CustomDictionary10=None):
        arguments = com_arguments([unwrap(a) for a in [Word, CustomDictionary, IgnoreUppercase, MainDictionary, SuggestionMode, CustomDictionary2, CustomDictionary3, CustomDictionary4, CustomDictionary5, CustomDictionary6, CustomDictionary7, CustomDictionary8, CustomDictionary9, CustomDictionary10]])
        self.com_object.GetSpellingSuggestions(*arguments)

    def getspellingsuggestions(self, Word=None, CustomDictionary=None, IgnoreUppercase=None, MainDictionary=None, SuggestionMode=None, CustomDictionary2=None, CustomDictionary3=None, CustomDictionary4=None, CustomDictionary5=None, CustomDictionary6=None, CustomDictionary7=None, CustomDictionary8=None, CustomDictionary9=None, CustomDictionary10=None):
        """Alias for GetSpellingSuggestions"""
        arguments = [Word, CustomDictionary, IgnoreUppercase, MainDictionary, SuggestionMode, CustomDictionary2, CustomDictionary3, CustomDictionary4, CustomDictionary5, CustomDictionary6, CustomDictionary7, CustomDictionary8, CustomDictionary9, CustomDictionary10]
        return self.GetSpellingSuggestions(*arguments)

    def get_spelling_suggestions(self, Word=None, CustomDictionary=None, IgnoreUppercase=None, MainDictionary=None, SuggestionMode=None, CustomDictionary2=None, CustomDictionary3=None, CustomDictionary4=None, CustomDictionary5=None, CustomDictionary6=None, CustomDictionary7=None, CustomDictionary8=None, CustomDictionary9=None, CustomDictionary10=None):
        """Alias for GetSpellingSuggestions"""
        arguments = [Word, CustomDictionary, IgnoreUppercase, MainDictionary, SuggestionMode, CustomDictionary2, CustomDictionary3, CustomDictionary4, CustomDictionary5, CustomDictionary6, CustomDictionary7, CustomDictionary8, CustomDictionary9, CustomDictionary10]
        return self.GetSpellingSuggestions(*arguments)

    def GoBack(self):
        self.com_object.GoBack()

    def goback(self):
        """Alias for GoBack"""
        return self.GoBack()

    def go_back(self):
        """Alias for GoBack"""
        return self.GoBack()

    def GoForward(self):
        self.com_object.GoForward()

    def goforward(self):
        """Alias for GoForward"""
        return self.GoForward()

    def go_forward(self):
        """Alias for GoForward"""
        return self.GoForward()

    def Help(self, HelpType=None):
        arguments = com_arguments([unwrap(a) for a in [HelpType]])
        self.com_object.Help(*arguments)

    def help(self, HelpType=None):
        """Alias for Help"""
        arguments = [HelpType]
        return self.Help(*arguments)

    def HelpTool(self):
        self.com_object.HelpTool()

    def helptool(self):
        """Alias for HelpTool"""
        return self.HelpTool()

    def help_tool(self):
        """Alias for HelpTool"""
        return self.HelpTool()

    def InchesToPoints(self, Inches=None):
        arguments = com_arguments([unwrap(a) for a in [Inches]])
        self.com_object.InchesToPoints(*arguments)

    def inchestopoints(self, Inches=None):
        """Alias for InchesToPoints"""
        arguments = [Inches]
        return self.InchesToPoints(*arguments)

    def inches_to_points(self, Inches=None):
        """Alias for InchesToPoints"""
        arguments = [Inches]
        return self.InchesToPoints(*arguments)

    def Keyboard(self, LangId=None):
        arguments = com_arguments([unwrap(a) for a in [LangId]])
        self.com_object.Keyboard(*arguments)

    def keyboard(self, LangId=None):
        """Alias for Keyboard"""
        arguments = [LangId]
        return self.Keyboard(*arguments)

    def KeyboardBidi(self):
        self.com_object.KeyboardBidi()

    def keyboardbidi(self):
        """Alias for KeyboardBidi"""
        return self.KeyboardBidi()

    def keyboard_bidi(self):
        """Alias for KeyboardBidi"""
        return self.KeyboardBidi()

    def KeyboardLatin(self):
        self.com_object.KeyboardLatin()

    def keyboardlatin(self):
        """Alias for KeyboardLatin"""
        return self.KeyboardLatin()

    def keyboard_latin(self):
        """Alias for KeyboardLatin"""
        return self.KeyboardLatin()

    def KeyString(self, KeyCode=None, KeyCode2=None):
        arguments = com_arguments([unwrap(a) for a in [KeyCode, KeyCode2]])
        return self.com_object.KeyString(*arguments)

    def keystring(self, KeyCode=None, KeyCode2=None):
        """Alias for KeyString"""
        arguments = [KeyCode, KeyCode2]
        return self.KeyString(*arguments)

    def key_string(self, KeyCode=None, KeyCode2=None):
        """Alias for KeyString"""
        arguments = [KeyCode, KeyCode2]
        return self.KeyString(*arguments)

    def LinesToPoints(self, Lines=None):
        arguments = com_arguments([unwrap(a) for a in [Lines]])
        return self.com_object.LinesToPoints(*arguments)

    def linestopoints(self, Lines=None):
        """Alias for LinesToPoints"""
        arguments = [Lines]
        return self.LinesToPoints(*arguments)

    def lines_to_points(self, Lines=None):
        """Alias for LinesToPoints"""
        arguments = [Lines]
        return self.LinesToPoints(*arguments)

    def ListCommands(self, ListAllCommands=None):
        arguments = com_arguments([unwrap(a) for a in [ListAllCommands]])
        self.com_object.ListCommands(*arguments)

    def listcommands(self, ListAllCommands=None):
        """Alias for ListCommands"""
        arguments = [ListAllCommands]
        return self.ListCommands(*arguments)

    def list_commands(self, ListAllCommands=None):
        """Alias for ListCommands"""
        arguments = [ListAllCommands]
        return self.ListCommands(*arguments)

    def LoadMasterList(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        self.com_object.LoadMasterList(*arguments)

    def loadmasterlist(self, FileName=None):
        """Alias for LoadMasterList"""
        arguments = [FileName]
        return self.LoadMasterList(*arguments)

    def load_master_list(self, FileName=None):
        """Alias for LoadMasterList"""
        arguments = [FileName]
        return self.LoadMasterList(*arguments)

    def LookupNameProperties(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        self.com_object.LookupNameProperties(*arguments)

    def lookupnameproperties(self, Name=None):
        """Alias for LookupNameProperties"""
        arguments = [Name]
        return self.LookupNameProperties(*arguments)

    def lookup_name_properties(self, Name=None):
        """Alias for LookupNameProperties"""
        arguments = [Name]
        return self.LookupNameProperties(*arguments)

    def MergeDocuments(self, OriginalDocument=None, RevisedDocument=None, Destination=None, Granularity=None, CompareFormatting=None, CompareCaseChanges=None, CompareWhitespace=None, CompareTables=None, CompareHeaders=None, CompareFootnotes=None, CompareTextboxes=None, CompareFields=None, CompareComments=None, OriginalAuthor=None, RevisedAuthor=None, FormatFrom=None):
        arguments = com_arguments([unwrap(a) for a in [OriginalDocument, RevisedDocument, Destination, Granularity, CompareFormatting, CompareCaseChanges, CompareWhitespace, CompareTables, CompareHeaders, CompareFootnotes, CompareTextboxes, CompareFields, CompareComments, OriginalAuthor, RevisedAuthor, FormatFrom]])
        return Document(self.com_object.MergeDocuments(*arguments))

    def mergedocuments(self, OriginalDocument=None, RevisedDocument=None, Destination=None, Granularity=None, CompareFormatting=None, CompareCaseChanges=None, CompareWhitespace=None, CompareTables=None, CompareHeaders=None, CompareFootnotes=None, CompareTextboxes=None, CompareFields=None, CompareComments=None, OriginalAuthor=None, RevisedAuthor=None, FormatFrom=None):
        """Alias for MergeDocuments"""
        arguments = [OriginalDocument, RevisedDocument, Destination, Granularity, CompareFormatting, CompareCaseChanges, CompareWhitespace, CompareTables, CompareHeaders, CompareFootnotes, CompareTextboxes, CompareFields, CompareComments, OriginalAuthor, RevisedAuthor, FormatFrom]
        return self.MergeDocuments(*arguments)

    def merge_documents(self, OriginalDocument=None, RevisedDocument=None, Destination=None, Granularity=None, CompareFormatting=None, CompareCaseChanges=None, CompareWhitespace=None, CompareTables=None, CompareHeaders=None, CompareFootnotes=None, CompareTextboxes=None, CompareFields=None, CompareComments=None, OriginalAuthor=None, RevisedAuthor=None, FormatFrom=None):
        """Alias for MergeDocuments"""
        arguments = [OriginalDocument, RevisedDocument, Destination, Granularity, CompareFormatting, CompareCaseChanges, CompareWhitespace, CompareTables, CompareHeaders, CompareFootnotes, CompareTextboxes, CompareFields, CompareComments, OriginalAuthor, RevisedAuthor, FormatFrom]
        return self.MergeDocuments(*arguments)

    def MillimetersToPoints(self, Millimeters=None):
        arguments = com_arguments([unwrap(a) for a in [Millimeters]])
        return self.com_object.MillimetersToPoints(*arguments)

    def millimeterstopoints(self, Millimeters=None):
        """Alias for MillimetersToPoints"""
        arguments = [Millimeters]
        return self.MillimetersToPoints(*arguments)

    def millimeters_to_points(self, Millimeters=None):
        """Alias for MillimetersToPoints"""
        arguments = [Millimeters]
        return self.MillimetersToPoints(*arguments)

    def Move(self, Left=None, Top=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None):
        """Alias for Move"""
        arguments = [Left, Top]
        return self.Move(*arguments)

    def NewWindow(self):
        return Window(self.com_object.NewWindow())

    def newwindow(self):
        """Alias for NewWindow"""
        return self.NewWindow()

    def new_window(self):
        """Alias for NewWindow"""
        return self.NewWindow()

    def OnTime(self, When=None, Name=None, Tolerance=None):
        arguments = com_arguments([unwrap(a) for a in [When, Name, Tolerance]])
        self.com_object.OnTime(*arguments)

    def ontime(self, When=None, Name=None, Tolerance=None):
        """Alias for OnTime"""
        arguments = [When, Name, Tolerance]
        return self.OnTime(*arguments)

    def on_time(self, When=None, Name=None, Tolerance=None):
        """Alias for OnTime"""
        arguments = [When, Name, Tolerance]
        return self.OnTime(*arguments)

    def OrganizerCopy(self, Source=None, Destination=None, Name=None, Object=None):
        arguments = com_arguments([unwrap(a) for a in [Source, Destination, Name, Object]])
        self.com_object.OrganizerCopy(*arguments)

    def organizercopy(self, Source=None, Destination=None, Name=None, Object=None):
        """Alias for OrganizerCopy"""
        arguments = [Source, Destination, Name, Object]
        return self.OrganizerCopy(*arguments)

    def organizer_copy(self, Source=None, Destination=None, Name=None, Object=None):
        """Alias for OrganizerCopy"""
        arguments = [Source, Destination, Name, Object]
        return self.OrganizerCopy(*arguments)

    def OrganizerDelete(self, Source=None, Name=None, Object=None):
        arguments = com_arguments([unwrap(a) for a in [Source, Name, Object]])
        self.com_object.OrganizerDelete(*arguments)

    def organizerdelete(self, Source=None, Name=None, Object=None):
        """Alias for OrganizerDelete"""
        arguments = [Source, Name, Object]
        return self.OrganizerDelete(*arguments)

    def organizer_delete(self, Source=None, Name=None, Object=None):
        """Alias for OrganizerDelete"""
        arguments = [Source, Name, Object]
        return self.OrganizerDelete(*arguments)

    def OrganizerRename(self, Source=None, Name=None, NewName=None, Object=None):
        arguments = com_arguments([unwrap(a) for a in [Source, Name, NewName, Object]])
        self.com_object.OrganizerRename(*arguments)

    def organizerrename(self, Source=None, Name=None, NewName=None, Object=None):
        """Alias for OrganizerRename"""
        arguments = [Source, Name, NewName, Object]
        return self.OrganizerRename(*arguments)

    def organizer_rename(self, Source=None, Name=None, NewName=None, Object=None):
        """Alias for OrganizerRename"""
        arguments = [Source, Name, NewName, Object]
        return self.OrganizerRename(*arguments)

    def PicasToPoints(self, Picas=None):
        arguments = com_arguments([unwrap(a) for a in [Picas]])
        return self.com_object.PicasToPoints(*arguments)

    def picastopoints(self, Picas=None):
        """Alias for PicasToPoints"""
        arguments = [Picas]
        return self.PicasToPoints(*arguments)

    def picas_to_points(self, Picas=None):
        """Alias for PicasToPoints"""
        arguments = [Picas]
        return self.PicasToPoints(*arguments)

    def PixelsToPoints(self, Pixels=None, fVertical=None):
        arguments = com_arguments([unwrap(a) for a in [Pixels, fVertical]])
        return self.com_object.PixelsToPoints(*arguments)

    def pixelstopoints(self, Pixels=None, fVertical=None):
        """Alias for PixelsToPoints"""
        arguments = [Pixels, fVertical]
        return self.PixelsToPoints(*arguments)

    def pixels_to_points(self, Pixels=None, fVertical=None):
        """Alias for PixelsToPoints"""
        arguments = [Pixels, fVertical]
        return self.PixelsToPoints(*arguments)

    def PointsToCentimeters(self, Points=None):
        arguments = com_arguments([unwrap(a) for a in [Points]])
        return self.com_object.PointsToCentimeters(*arguments)

    def pointstocentimeters(self, Points=None):
        """Alias for PointsToCentimeters"""
        arguments = [Points]
        return self.PointsToCentimeters(*arguments)

    def points_to_centimeters(self, Points=None):
        """Alias for PointsToCentimeters"""
        arguments = [Points]
        return self.PointsToCentimeters(*arguments)

    def PointsToInches(self, Points=None):
        arguments = com_arguments([unwrap(a) for a in [Points]])
        return self.com_object.PointsToInches(*arguments)

    def pointstoinches(self, Points=None):
        """Alias for PointsToInches"""
        arguments = [Points]
        return self.PointsToInches(*arguments)

    def points_to_inches(self, Points=None):
        """Alias for PointsToInches"""
        arguments = [Points]
        return self.PointsToInches(*arguments)

    def PointsToLines(self, Points=None):
        arguments = com_arguments([unwrap(a) for a in [Points]])
        return self.com_object.PointsToLines(*arguments)

    def pointstolines(self, Points=None):
        """Alias for PointsToLines"""
        arguments = [Points]
        return self.PointsToLines(*arguments)

    def points_to_lines(self, Points=None):
        """Alias for PointsToLines"""
        arguments = [Points]
        return self.PointsToLines(*arguments)

    def PointsToMillimeters(self, Points=None):
        arguments = com_arguments([unwrap(a) for a in [Points]])
        return self.com_object.PointsToMillimeters(*arguments)

    def pointstomillimeters(self, Points=None):
        """Alias for PointsToMillimeters"""
        arguments = [Points]
        return self.PointsToMillimeters(*arguments)

    def points_to_millimeters(self, Points=None):
        """Alias for PointsToMillimeters"""
        arguments = [Points]
        return self.PointsToMillimeters(*arguments)

    def PointsToPicas(self, Points=None):
        arguments = com_arguments([unwrap(a) for a in [Points]])
        return self.com_object.PointsToPicas(*arguments)

    def pointstopicas(self, Points=None):
        """Alias for PointsToPicas"""
        arguments = [Points]
        return self.PointsToPicas(*arguments)

    def points_to_picas(self, Points=None):
        """Alias for PointsToPicas"""
        arguments = [Points]
        return self.PointsToPicas(*arguments)

    def PointsToPixels(self, Points=None, fVertical=None):
        arguments = com_arguments([unwrap(a) for a in [Points, fVertical]])
        return self.com_object.PointsToPixels(*arguments)

    def pointstopixels(self, Points=None, fVertical=None):
        """Alias for PointsToPixels"""
        arguments = [Points, fVertical]
        return self.PointsToPixels(*arguments)

    def points_to_pixels(self, Points=None, fVertical=None):
        """Alias for PointsToPixels"""
        arguments = [Points, fVertical]
        return self.PointsToPixels(*arguments)

    def PrintOut(self, Background=None, Append=None, Range=None, OutputFileName=None, From=None, To=None, Item=None, Copies=None, Pages=None, PageType=None, PrintToFile=None, Collate=None, FileName=None, ActivePrinterMacGX=None, ManualDuplexPrint=None, PrintZoomColumn=None, PrintZoomRow=None, PrintZoomPaperWidth=None, PrintZoomPaperHeight=None):
        arguments = com_arguments([unwrap(a) for a in [Background, Append, Range, OutputFileName, From, To, Item, Copies, Pages, PageType, PrintToFile, Collate, FileName, ActivePrinterMacGX, ManualDuplexPrint, PrintZoomColumn, PrintZoomRow, PrintZoomPaperWidth, PrintZoomPaperHeight]])
        self.com_object.PrintOut(*arguments)

    def printout(self, Background=None, Append=None, Range=None, OutputFileName=None, From=None, To=None, Item=None, Copies=None, Pages=None, PageType=None, PrintToFile=None, Collate=None, FileName=None, ActivePrinterMacGX=None, ManualDuplexPrint=None, PrintZoomColumn=None, PrintZoomRow=None, PrintZoomPaperWidth=None, PrintZoomPaperHeight=None):
        """Alias for PrintOut"""
        arguments = [Background, Append, Range, OutputFileName, From, To, Item, Copies, Pages, PageType, PrintToFile, Collate, FileName, ActivePrinterMacGX, ManualDuplexPrint, PrintZoomColumn, PrintZoomRow, PrintZoomPaperWidth, PrintZoomPaperHeight]
        return self.PrintOut(*arguments)

    def print_out(self, Background=None, Append=None, Range=None, OutputFileName=None, From=None, To=None, Item=None, Copies=None, Pages=None, PageType=None, PrintToFile=None, Collate=None, FileName=None, ActivePrinterMacGX=None, ManualDuplexPrint=None, PrintZoomColumn=None, PrintZoomRow=None, PrintZoomPaperWidth=None, PrintZoomPaperHeight=None):
        """Alias for PrintOut"""
        arguments = [Background, Append, Range, OutputFileName, From, To, Item, Copies, Pages, PageType, PrintToFile, Collate, FileName, ActivePrinterMacGX, ManualDuplexPrint, PrintZoomColumn, PrintZoomRow, PrintZoomPaperWidth, PrintZoomPaperHeight]
        return self.PrintOut(*arguments)

    def ProductCode(self):
        return self.com_object.ProductCode()

    def productcode(self):
        """Alias for ProductCode"""
        return self.ProductCode()

    def product_code(self):
        """Alias for ProductCode"""
        return self.ProductCode()

    def PutFocusInMailHeader(self):
        self.com_object.PutFocusInMailHeader()

    def putfocusinmailheader(self):
        """Alias for PutFocusInMailHeader"""
        return self.PutFocusInMailHeader()

    def put_focus_in_mail_header(self):
        """Alias for PutFocusInMailHeader"""
        return self.PutFocusInMailHeader()

    def Quit(self, SaveChanges=None, OriginalFormat=None, RouteDocument=None):
        arguments = com_arguments([unwrap(a) for a in [SaveChanges, OriginalFormat, RouteDocument]])
        self.com_object.Quit(*arguments)

    def quit(self, SaveChanges=None, OriginalFormat=None, RouteDocument=None):
        """Alias for Quit"""
        arguments = [SaveChanges, OriginalFormat, RouteDocument]
        return self.Quit(*arguments)

    def Repeat(self, Times=None):
        arguments = com_arguments([unwrap(a) for a in [Times]])
        return self.com_object.Repeat(*arguments)

    def repeat(self, Times=None):
        """Alias for Repeat"""
        arguments = [Times]
        return self.Repeat(*arguments)

    def ResetIgnoreAll(self):
        self.com_object.ResetIgnoreAll()

    def resetignoreall(self):
        """Alias for ResetIgnoreAll"""
        return self.ResetIgnoreAll()

    def reset_ignore_all(self):
        """Alias for ResetIgnoreAll"""
        return self.ResetIgnoreAll()

    def Resize(self, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Width, Height]])
        self.com_object.Resize(*arguments)

    def resize(self, Width=None, Height=None):
        """Alias for Resize"""
        arguments = [Width, Height]
        return self.Resize(*arguments)

    def Run(self, MacroName=None, varg1=None, varg2=None, varg3=None, varg4=None, varg5=None, varg6=None, varg7=None, varg8=None, varg9=None, varg10=None, varg11=None, varg12=None, varg13=None, varg14=None, varg15=None, varg16=None, varg17=None, varg18=None, varg19=None, varg20=None, varg21=None, varg22=None, varg23=None, varg24=None, varg25=None, varg26=None, varg27=None, varg28=None, varg29=None, varg30=None):
        arguments = com_arguments([unwrap(a) for a in [MacroName, varg1, varg2, varg3, varg4, varg5, varg6, varg7, varg8, varg9, varg10, varg11, varg12, varg13, varg14, varg15, varg16, varg17, varg18, varg19, varg20, varg21, varg22, varg23, varg24, varg25, varg26, varg27, varg28, varg29, varg30]])
        self.com_object.Run(*arguments)

    def run(self, MacroName=None, varg1=None, varg2=None, varg3=None, varg4=None, varg5=None, varg6=None, varg7=None, varg8=None, varg9=None, varg10=None, varg11=None, varg12=None, varg13=None, varg14=None, varg15=None, varg16=None, varg17=None, varg18=None, varg19=None, varg20=None, varg21=None, varg22=None, varg23=None, varg24=None, varg25=None, varg26=None, varg27=None, varg28=None, varg29=None, varg30=None):
        """Alias for Run"""
        arguments = [MacroName, varg1, varg2, varg3, varg4, varg5, varg6, varg7, varg8, varg9, varg10, varg11, varg12, varg13, varg14, varg15, varg16, varg17, varg18, varg19, varg20, varg21, varg22, varg23, varg24, varg25, varg26, varg27, varg28, varg29, varg30]
        return self.Run(*arguments)

    def ScreenRefresh(self):
        self.com_object.ScreenRefresh()

    def screenrefresh(self):
        """Alias for ScreenRefresh"""
        return self.ScreenRefresh()

    def screen_refresh(self):
        """Alias for ScreenRefresh"""
        return self.ScreenRefresh()

    def SetDefaultTheme(self, Name=None, DocumentType=None):
        arguments = com_arguments([unwrap(a) for a in [Name, DocumentType]])
        self.com_object.SetDefaultTheme(*arguments)

    def setdefaulttheme(self, Name=None, DocumentType=None):
        """Alias for SetDefaultTheme"""
        arguments = [Name, DocumentType]
        return self.SetDefaultTheme(*arguments)

    def set_default_theme(self, Name=None, DocumentType=None):
        """Alias for SetDefaultTheme"""
        arguments = [Name, DocumentType]
        return self.SetDefaultTheme(*arguments)

    def ShowClipboard(self):
        self.com_object.ShowClipboard()

    def showclipboard(self):
        """Alias for ShowClipboard"""
        return self.ShowClipboard()

    def show_clipboard(self):
        """Alias for ShowClipboard"""
        return self.ShowClipboard()

    def ShowMe(self):
        self.com_object.ShowMe()

    def showme(self):
        """Alias for ShowMe"""
        return self.ShowMe()

    def show_me(self):
        """Alias for ShowMe"""
        return self.ShowMe()

    def SubstituteFont(self, UnavailableFont=None, SubstituteFont=None):
        arguments = com_arguments([unwrap(a) for a in [UnavailableFont, SubstituteFont]])
        self.com_object.SubstituteFont(*arguments)

    def substitutefont(self, UnavailableFont=None, SubstituteFont=None):
        """Alias for SubstituteFont"""
        arguments = [UnavailableFont, SubstituteFont]
        return self.SubstituteFont(*arguments)

    def substitute_font(self, UnavailableFont=None, SubstituteFont=None):
        """Alias for SubstituteFont"""
        arguments = [UnavailableFont, SubstituteFont]
        return self.SubstituteFont(*arguments)

    def ToggleKeyboard(self):
        self.com_object.ToggleKeyboard()

    def togglekeyboard(self):
        """Alias for ToggleKeyboard"""
        return self.ToggleKeyboard()

    def toggle_keyboard(self):
        """Alias for ToggleKeyboard"""
        return self.ToggleKeyboard()


class AutoCaption:

    def __init__(self, autocaption=None):
        self.com_object= autocaption

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoInsert(self):
        return self.com_object.AutoInsert

    @AutoInsert.setter
    def AutoInsert(self, value):
        self.com_object.AutoInsert = value

    @property
    def autoinsert(self):
        """Alias for AutoInsert"""
        return self.AutoInsert

    @autoinsert.setter
    def autoinsert(self, value):
        """Alias for AutoInsert.setter"""
        self.AutoInsert = value

    @property
    def auto_insert(self):
        """Alias for AutoInsert"""
        return self.AutoInsert

    @auto_insert.setter
    def auto_insert(self, value):
        """Alias for AutoInsert.setter"""
        self.AutoInsert = value

    @property
    def CaptionLabel(self):
        return self.com_object.CaptionLabel

    @CaptionLabel.setter
    def CaptionLabel(self, value):
        self.com_object.CaptionLabel = value

    @property
    def captionlabel(self):
        """Alias for CaptionLabel"""
        return self.CaptionLabel

    @captionlabel.setter
    def captionlabel(self, value):
        """Alias for CaptionLabel.setter"""
        self.CaptionLabel = value

    @property
    def caption_label(self):
        """Alias for CaptionLabel"""
        return self.CaptionLabel

    @caption_label.setter
    def caption_label(self, value):
        """Alias for CaptionLabel.setter"""
        self.CaptionLabel = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class AutoCaptions:

    def __init__(self, autocaptions=None):
        self.com_object= autocaptions

    def __call__(self, item):
        return AutoCaption(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return AutoCaptions(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def CancelAutoInsert(self):
        self.com_object.CancelAutoInsert()

    def cancelautoinsert(self):
        """Alias for CancelAutoInsert"""
        return self.CancelAutoInsert()

    def cancel_auto_insert(self):
        """Alias for CancelAutoInsert"""
        return self.CancelAutoInsert()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return AutoCaption(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class AutoCorrect:

    def __init__(self, autocorrect=None):
        self.com_object= autocorrect

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def CorrectCapsLock(self):
        return self.com_object.CorrectCapsLock

    @CorrectCapsLock.setter
    def CorrectCapsLock(self, value):
        self.com_object.CorrectCapsLock = value

    @property
    def correctcapslock(self):
        """Alias for CorrectCapsLock"""
        return self.CorrectCapsLock

    @correctcapslock.setter
    def correctcapslock(self, value):
        """Alias for CorrectCapsLock.setter"""
        self.CorrectCapsLock = value

    @property
    def correct_caps_lock(self):
        """Alias for CorrectCapsLock"""
        return self.CorrectCapsLock

    @correct_caps_lock.setter
    def correct_caps_lock(self, value):
        """Alias for CorrectCapsLock.setter"""
        self.CorrectCapsLock = value

    @property
    def CorrectDays(self):
        return self.com_object.CorrectDays

    @CorrectDays.setter
    def CorrectDays(self, value):
        self.com_object.CorrectDays = value

    @property
    def correctdays(self):
        """Alias for CorrectDays"""
        return self.CorrectDays

    @correctdays.setter
    def correctdays(self, value):
        """Alias for CorrectDays.setter"""
        self.CorrectDays = value

    @property
    def correct_days(self):
        """Alias for CorrectDays"""
        return self.CorrectDays

    @correct_days.setter
    def correct_days(self, value):
        """Alias for CorrectDays.setter"""
        self.CorrectDays = value

    @property
    def CorrectHangulAndAlphabet(self):
        return self.com_object.CorrectHangulAndAlphabet

    @CorrectHangulAndAlphabet.setter
    def CorrectHangulAndAlphabet(self, value):
        self.com_object.CorrectHangulAndAlphabet = value

    @property
    def correcthangulandalphabet(self):
        """Alias for CorrectHangulAndAlphabet"""
        return self.CorrectHangulAndAlphabet

    @correcthangulandalphabet.setter
    def correcthangulandalphabet(self, value):
        """Alias for CorrectHangulAndAlphabet.setter"""
        self.CorrectHangulAndAlphabet = value

    @property
    def correct_hangul_and_alphabet(self):
        """Alias for CorrectHangulAndAlphabet"""
        return self.CorrectHangulAndAlphabet

    @correct_hangul_and_alphabet.setter
    def correct_hangul_and_alphabet(self, value):
        """Alias for CorrectHangulAndAlphabet.setter"""
        self.CorrectHangulAndAlphabet = value

    @property
    def CorrectInitialCaps(self):
        return self.com_object.CorrectInitialCaps

    @CorrectInitialCaps.setter
    def CorrectInitialCaps(self, value):
        self.com_object.CorrectInitialCaps = value

    @property
    def correctinitialcaps(self):
        """Alias for CorrectInitialCaps"""
        return self.CorrectInitialCaps

    @correctinitialcaps.setter
    def correctinitialcaps(self, value):
        """Alias for CorrectInitialCaps.setter"""
        self.CorrectInitialCaps = value

    @property
    def correct_initial_caps(self):
        """Alias for CorrectInitialCaps"""
        return self.CorrectInitialCaps

    @correct_initial_caps.setter
    def correct_initial_caps(self, value):
        """Alias for CorrectInitialCaps.setter"""
        self.CorrectInitialCaps = value

    @property
    def CorrectKeyboardSetting(self):
        return self.com_object.CorrectKeyboardSetting

    @CorrectKeyboardSetting.setter
    def CorrectKeyboardSetting(self, value):
        self.com_object.CorrectKeyboardSetting = value

    @property
    def correctkeyboardsetting(self):
        """Alias for CorrectKeyboardSetting"""
        return self.CorrectKeyboardSetting

    @correctkeyboardsetting.setter
    def correctkeyboardsetting(self, value):
        """Alias for CorrectKeyboardSetting.setter"""
        self.CorrectKeyboardSetting = value

    @property
    def correct_keyboard_setting(self):
        """Alias for CorrectKeyboardSetting"""
        return self.CorrectKeyboardSetting

    @correct_keyboard_setting.setter
    def correct_keyboard_setting(self, value):
        """Alias for CorrectKeyboardSetting.setter"""
        self.CorrectKeyboardSetting = value

    @property
    def CorrectSentenceCaps(self):
        return self.com_object.CorrectSentenceCaps

    @CorrectSentenceCaps.setter
    def CorrectSentenceCaps(self, value):
        self.com_object.CorrectSentenceCaps = value

    @property
    def correctsentencecaps(self):
        """Alias for CorrectSentenceCaps"""
        return self.CorrectSentenceCaps

    @correctsentencecaps.setter
    def correctsentencecaps(self, value):
        """Alias for CorrectSentenceCaps.setter"""
        self.CorrectSentenceCaps = value

    @property
    def correct_sentence_caps(self):
        """Alias for CorrectSentenceCaps"""
        return self.CorrectSentenceCaps

    @correct_sentence_caps.setter
    def correct_sentence_caps(self, value):
        """Alias for CorrectSentenceCaps.setter"""
        self.CorrectSentenceCaps = value

    @property
    def CorrectTableCells(self):
        return self.com_object.CorrectTableCells

    @CorrectTableCells.setter
    def CorrectTableCells(self, value):
        self.com_object.CorrectTableCells = value

    @property
    def correcttablecells(self):
        """Alias for CorrectTableCells"""
        return self.CorrectTableCells

    @correcttablecells.setter
    def correcttablecells(self, value):
        """Alias for CorrectTableCells.setter"""
        self.CorrectTableCells = value

    @property
    def correct_table_cells(self):
        """Alias for CorrectTableCells"""
        return self.CorrectTableCells

    @correct_table_cells.setter
    def correct_table_cells(self, value):
        """Alias for CorrectTableCells.setter"""
        self.CorrectTableCells = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DisplayAutoCorrectOptions(self):
        return self.com_object.DisplayAutoCorrectOptions

    @DisplayAutoCorrectOptions.setter
    def DisplayAutoCorrectOptions(self, value):
        self.com_object.DisplayAutoCorrectOptions = value

    @property
    def displayautocorrectoptions(self):
        """Alias for DisplayAutoCorrectOptions"""
        return self.DisplayAutoCorrectOptions

    @displayautocorrectoptions.setter
    def displayautocorrectoptions(self, value):
        """Alias for DisplayAutoCorrectOptions.setter"""
        self.DisplayAutoCorrectOptions = value

    @property
    def display_auto_correct_options(self):
        """Alias for DisplayAutoCorrectOptions"""
        return self.DisplayAutoCorrectOptions

    @display_auto_correct_options.setter
    def display_auto_correct_options(self, value):
        """Alias for DisplayAutoCorrectOptions.setter"""
        self.DisplayAutoCorrectOptions = value

    @property
    def Entries(self):
        return AutoCorrectEntries(self.com_object.Entries)

    @property
    def entries(self):
        """Alias for Entries"""
        return self.Entries

    @property
    def FirstLetterAutoAdd(self):
        return self.com_object.FirstLetterAutoAdd

    @FirstLetterAutoAdd.setter
    def FirstLetterAutoAdd(self, value):
        self.com_object.FirstLetterAutoAdd = value

    @property
    def firstletterautoadd(self):
        """Alias for FirstLetterAutoAdd"""
        return self.FirstLetterAutoAdd

    @firstletterautoadd.setter
    def firstletterautoadd(self, value):
        """Alias for FirstLetterAutoAdd.setter"""
        self.FirstLetterAutoAdd = value

    @property
    def first_letter_auto_add(self):
        """Alias for FirstLetterAutoAdd"""
        return self.FirstLetterAutoAdd

    @first_letter_auto_add.setter
    def first_letter_auto_add(self, value):
        """Alias for FirstLetterAutoAdd.setter"""
        self.FirstLetterAutoAdd = value

    @property
    def FirstLetterExceptions(self):
        return FirstLetterExceptions(self.com_object.FirstLetterExceptions)

    @property
    def firstletterexceptions(self):
        """Alias for FirstLetterExceptions"""
        return self.FirstLetterExceptions

    @property
    def first_letter_exceptions(self):
        """Alias for FirstLetterExceptions"""
        return self.FirstLetterExceptions

    @property
    def HangulAndAlphabetAutoAdd(self):
        return self.com_object.HangulAndAlphabetAutoAdd

    @HangulAndAlphabetAutoAdd.setter
    def HangulAndAlphabetAutoAdd(self, value):
        self.com_object.HangulAndAlphabetAutoAdd = value

    @property
    def hangulandalphabetautoadd(self):
        """Alias for HangulAndAlphabetAutoAdd"""
        return self.HangulAndAlphabetAutoAdd

    @hangulandalphabetautoadd.setter
    def hangulandalphabetautoadd(self, value):
        """Alias for HangulAndAlphabetAutoAdd.setter"""
        self.HangulAndAlphabetAutoAdd = value

    @property
    def hangul_and_alphabet_auto_add(self):
        """Alias for HangulAndAlphabetAutoAdd"""
        return self.HangulAndAlphabetAutoAdd

    @hangul_and_alphabet_auto_add.setter
    def hangul_and_alphabet_auto_add(self, value):
        """Alias for HangulAndAlphabetAutoAdd.setter"""
        self.HangulAndAlphabetAutoAdd = value

    @property
    def HangulAndAlphabetExceptions(self):
        return HangulAndAlphabetExceptions(self.com_object.HangulAndAlphabetExceptions)

    @property
    def hangulandalphabetexceptions(self):
        """Alias for HangulAndAlphabetExceptions"""
        return self.HangulAndAlphabetExceptions

    @property
    def hangul_and_alphabet_exceptions(self):
        """Alias for HangulAndAlphabetExceptions"""
        return self.HangulAndAlphabetExceptions

    @property
    def OtherCorrectionsAutoAdd(self):
        return self.com_object.OtherCorrectionsAutoAdd

    @OtherCorrectionsAutoAdd.setter
    def OtherCorrectionsAutoAdd(self, value):
        self.com_object.OtherCorrectionsAutoAdd = value

    @property
    def othercorrectionsautoadd(self):
        """Alias for OtherCorrectionsAutoAdd"""
        return self.OtherCorrectionsAutoAdd

    @othercorrectionsautoadd.setter
    def othercorrectionsautoadd(self, value):
        """Alias for OtherCorrectionsAutoAdd.setter"""
        self.OtherCorrectionsAutoAdd = value

    @property
    def other_corrections_auto_add(self):
        """Alias for OtherCorrectionsAutoAdd"""
        return self.OtherCorrectionsAutoAdd

    @other_corrections_auto_add.setter
    def other_corrections_auto_add(self, value):
        """Alias for OtherCorrectionsAutoAdd.setter"""
        self.OtherCorrectionsAutoAdd = value

    @property
    def OtherCorrectionsExceptions(self):
        return OtherCorrectionsExceptions(self.com_object.OtherCorrectionsExceptions)

    @property
    def othercorrectionsexceptions(self):
        """Alias for OtherCorrectionsExceptions"""
        return self.OtherCorrectionsExceptions

    @property
    def other_corrections_exceptions(self):
        """Alias for OtherCorrectionsExceptions"""
        return self.OtherCorrectionsExceptions

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ReplaceText(self):
        return self.com_object.ReplaceText

    @ReplaceText.setter
    def ReplaceText(self, value):
        self.com_object.ReplaceText = value

    @property
    def replacetext(self):
        """Alias for ReplaceText"""
        return self.ReplaceText

    @replacetext.setter
    def replacetext(self, value):
        """Alias for ReplaceText.setter"""
        self.ReplaceText = value

    @property
    def replace_text(self):
        """Alias for ReplaceText"""
        return self.ReplaceText

    @replace_text.setter
    def replace_text(self, value):
        """Alias for ReplaceText.setter"""
        self.ReplaceText = value

    @property
    def ReplaceTextFromSpellingChecker(self):
        return self.com_object.ReplaceTextFromSpellingChecker

    @ReplaceTextFromSpellingChecker.setter
    def ReplaceTextFromSpellingChecker(self, value):
        self.com_object.ReplaceTextFromSpellingChecker = value

    @property
    def replacetextfromspellingchecker(self):
        """Alias for ReplaceTextFromSpellingChecker"""
        return self.ReplaceTextFromSpellingChecker

    @replacetextfromspellingchecker.setter
    def replacetextfromspellingchecker(self, value):
        """Alias for ReplaceTextFromSpellingChecker.setter"""
        self.ReplaceTextFromSpellingChecker = value

    @property
    def replace_text_from_spelling_checker(self):
        """Alias for ReplaceTextFromSpellingChecker"""
        return self.ReplaceTextFromSpellingChecker

    @replace_text_from_spelling_checker.setter
    def replace_text_from_spelling_checker(self, value):
        """Alias for ReplaceTextFromSpellingChecker.setter"""
        self.ReplaceTextFromSpellingChecker = value

    @property
    def TwoInitialCapsAutoAdd(self):
        return self.com_object.TwoInitialCapsAutoAdd

    @TwoInitialCapsAutoAdd.setter
    def TwoInitialCapsAutoAdd(self, value):
        self.com_object.TwoInitialCapsAutoAdd = value

    @property
    def twoinitialcapsautoadd(self):
        """Alias for TwoInitialCapsAutoAdd"""
        return self.TwoInitialCapsAutoAdd

    @twoinitialcapsautoadd.setter
    def twoinitialcapsautoadd(self, value):
        """Alias for TwoInitialCapsAutoAdd.setter"""
        self.TwoInitialCapsAutoAdd = value

    @property
    def two_initial_caps_auto_add(self):
        """Alias for TwoInitialCapsAutoAdd"""
        return self.TwoInitialCapsAutoAdd

    @two_initial_caps_auto_add.setter
    def two_initial_caps_auto_add(self, value):
        """Alias for TwoInitialCapsAutoAdd.setter"""
        self.TwoInitialCapsAutoAdd = value

    @property
    def TwoInitialCapsExceptions(self):
        return TwoInitialCapsExceptions(self.com_object.TwoInitialCapsExceptions)

    @property
    def twoinitialcapsexceptions(self):
        """Alias for TwoInitialCapsExceptions"""
        return self.TwoInitialCapsExceptions

    @property
    def two_initial_caps_exceptions(self):
        """Alias for TwoInitialCapsExceptions"""
        return self.TwoInitialCapsExceptions


class AutoCorrectEntries:

    def __init__(self, autocorrectentries=None):
        self.com_object= autocorrectentries

    def __call__(self, item):
        return AutoCorrectEntrie(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return AutoCorrectEntries(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return AutoCorrect(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, Value=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Value]])
        self.com_object.Add(*arguments)

    def add(self, Name=None, Value=None):
        """Alias for Add"""
        arguments = [Name, Value]
        return self.Add(*arguments)

    def AddRichText(self, Name=None, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Range]])
        return AutoCorrectEntry(self.com_object.AddRichText(*arguments))

    def addrichtext(self, Name=None, Range=None):
        """Alias for AddRichText"""
        arguments = [Name, Range]
        return self.AddRichText(*arguments)

    def add_rich_text(self, Name=None, Range=None):
        """Alias for AddRichText"""
        arguments = [Name, Range]
        return self.AddRichText(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return AutoCorrectEntry(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class AutoCorrectEntry:

    def __init__(self, autocorrectentry=None):
        self.com_object= autocorrectentry

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RichText(self):
        return self.com_object.RichText

    @property
    def richtext(self):
        """Alias for RichText"""
        return self.RichText

    @property
    def rich_text(self):
        """Alias for RichText"""
        return self.RichText

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    def Apply(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        self.com_object.Apply(*arguments)

    def apply(self, Range=None):
        """Alias for Apply"""
        arguments = [Range]
        return self.Apply(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class AutoTextEntries:

    def __init__(self, autotextentries=None):
        self.com_object= autotextentries

    def __call__(self, item):
        return AutoTextEntrie(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return AutoTextEntries(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Range]])
        self.com_object.Add(*arguments)

    def add(self, Name=None, Range=None):
        """Alias for Add"""
        arguments = [Name, Range]
        return self.Add(*arguments)

    def AppendToSpike(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        return AutoTextEntry(self.com_object.AppendToSpike(*arguments))

    def appendtospike(self, Range=None):
        """Alias for AppendToSpike"""
        arguments = [Range]
        return self.AppendToSpike(*arguments)

    def append_to_spike(self, Range=None):
        """Alias for AppendToSpike"""
        arguments = [Range]
        return self.AppendToSpike(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return AutoTextEntry(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class AutoTextEntry:

    def __init__(self, autotextentry=None):
        self.com_object= autotextentry

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return AutoTextEntries(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def StyleName(self):
        return self.com_object.StyleName

    @property
    def stylename(self):
        """Alias for StyleName"""
        return self.StyleName

    @property
    def style_name(self):
        """Alias for StyleName"""
        return self.StyleName

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Insert(self, Where=None, RichText=None):
        arguments = com_arguments([unwrap(a) for a in [Where, RichText]])
        return Range(self.com_object.Insert(*arguments))

    def insert(self, Where=None, RichText=None):
        """Alias for Insert"""
        arguments = [Where, RichText]
        return self.Insert(*arguments)


class Axes:

    def __init__(self, axes=None):
        self.com_object= axes

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Type=None, AxisGroup=None):
        arguments = com_arguments([unwrap(a) for a in [Type, AxisGroup]])
        self.com_object.Item(*arguments)

    def item(self, Type=None, AxisGroup=None):
        """Alias for Item"""
        arguments = [Type, AxisGroup]
        return self.Item(*arguments)


class Axis:

    def __init__(self, axis=None):
        self.com_object= axis

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AxisBetweenCategories(self):
        return self.com_object.AxisBetweenCategories

    @AxisBetweenCategories.setter
    def AxisBetweenCategories(self, value):
        self.com_object.AxisBetweenCategories = value

    @property
    def axisbetweencategories(self):
        """Alias for AxisBetweenCategories"""
        return self.AxisBetweenCategories

    @axisbetweencategories.setter
    def axisbetweencategories(self, value):
        """Alias for AxisBetweenCategories.setter"""
        self.AxisBetweenCategories = value

    @property
    def axis_between_categories(self):
        """Alias for AxisBetweenCategories"""
        return self.AxisBetweenCategories

    @axis_between_categories.setter
    def axis_between_categories(self, value):
        """Alias for AxisBetweenCategories.setter"""
        self.AxisBetweenCategories = value

    @property
    def AxisGroup(self):
        return XlAxisGroup(self.com_object.AxisGroup)

    @property
    def axisgroup(self):
        """Alias for AxisGroup"""
        return self.AxisGroup

    @property
    def axis_group(self):
        """Alias for AxisGroup"""
        return self.AxisGroup

    @property
    def AxisTitle(self):
        return AxisTitle(self.com_object.AxisTitle)

    @property
    def axistitle(self):
        """Alias for AxisTitle"""
        return self.AxisTitle

    @property
    def axis_title(self):
        """Alias for AxisTitle"""
        return self.AxisTitle

    @property
    def BaseUnit(self):
        return XlTimeUnit(self.com_object.BaseUnit)

    @BaseUnit.setter
    def BaseUnit(self, value):
        self.com_object.BaseUnit = value

    @property
    def baseunit(self):
        """Alias for BaseUnit"""
        return self.BaseUnit

    @baseunit.setter
    def baseunit(self, value):
        """Alias for BaseUnit.setter"""
        self.BaseUnit = value

    @property
    def base_unit(self):
        """Alias for BaseUnit"""
        return self.BaseUnit

    @base_unit.setter
    def base_unit(self, value):
        """Alias for BaseUnit.setter"""
        self.BaseUnit = value

    @property
    def BaseUnitIsAuto(self):
        return self.com_object.BaseUnitIsAuto

    @BaseUnitIsAuto.setter
    def BaseUnitIsAuto(self, value):
        self.com_object.BaseUnitIsAuto = value

    @property
    def baseunitisauto(self):
        """Alias for BaseUnitIsAuto"""
        return self.BaseUnitIsAuto

    @baseunitisauto.setter
    def baseunitisauto(self, value):
        """Alias for BaseUnitIsAuto.setter"""
        self.BaseUnitIsAuto = value

    @property
    def base_unit_is_auto(self):
        """Alias for BaseUnitIsAuto"""
        return self.BaseUnitIsAuto

    @base_unit_is_auto.setter
    def base_unit_is_auto(self, value):
        """Alias for BaseUnitIsAuto.setter"""
        self.BaseUnitIsAuto = value

    @property
    def Border(self):
        return ChartBorder(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def CategoryNames(self):
        return self.com_object.CategoryNames

    @CategoryNames.setter
    def CategoryNames(self, value):
        self.com_object.CategoryNames = value

    @property
    def categorynames(self):
        """Alias for CategoryNames"""
        return self.CategoryNames

    @categorynames.setter
    def categorynames(self, value):
        """Alias for CategoryNames.setter"""
        self.CategoryNames = value

    @property
    def category_names(self):
        """Alias for CategoryNames"""
        return self.CategoryNames

    @category_names.setter
    def category_names(self, value):
        """Alias for CategoryNames.setter"""
        self.CategoryNames = value

    @property
    def CategoryType(self):
        return XlCategoryType(self.com_object.CategoryType)

    @CategoryType.setter
    def CategoryType(self, value):
        self.com_object.CategoryType = value

    @property
    def categorytype(self):
        """Alias for CategoryType"""
        return self.CategoryType

    @categorytype.setter
    def categorytype(self, value):
        """Alias for CategoryType.setter"""
        self.CategoryType = value

    @property
    def category_type(self):
        """Alias for CategoryType"""
        return self.CategoryType

    @category_type.setter
    def category_type(self, value):
        """Alias for CategoryType.setter"""
        self.CategoryType = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Crosses(self):
        return self.com_object.Crosses

    @Crosses.setter
    def Crosses(self, value):
        self.com_object.Crosses = value

    @property
    def crosses(self):
        """Alias for Crosses"""
        return self.Crosses

    @crosses.setter
    def crosses(self, value):
        """Alias for Crosses.setter"""
        self.Crosses = value

    @property
    def CrossesAt(self):
        return self.com_object.CrossesAt

    @CrossesAt.setter
    def CrossesAt(self, value):
        self.com_object.CrossesAt = value

    @property
    def crossesat(self):
        """Alias for CrossesAt"""
        return self.CrossesAt

    @crossesat.setter
    def crossesat(self, value):
        """Alias for CrossesAt.setter"""
        self.CrossesAt = value

    @property
    def crosses_at(self):
        """Alias for CrossesAt"""
        return self.CrossesAt

    @crosses_at.setter
    def crosses_at(self, value):
        """Alias for CrossesAt.setter"""
        self.CrossesAt = value

    @property
    def DisplayUnit(self):
        return XlDisplayUnit(self.com_object.DisplayUnit)

    @DisplayUnit.setter
    def DisplayUnit(self, value):
        self.com_object.DisplayUnit = value

    @property
    def displayunit(self):
        """Alias for DisplayUnit"""
        return self.DisplayUnit

    @displayunit.setter
    def displayunit(self, value):
        """Alias for DisplayUnit.setter"""
        self.DisplayUnit = value

    @property
    def display_unit(self):
        """Alias for DisplayUnit"""
        return self.DisplayUnit

    @display_unit.setter
    def display_unit(self, value):
        """Alias for DisplayUnit.setter"""
        self.DisplayUnit = value

    @property
    def DisplayUnitCustom(self):
        return self.com_object.DisplayUnitCustom

    @DisplayUnitCustom.setter
    def DisplayUnitCustom(self, value):
        self.com_object.DisplayUnitCustom = value

    @property
    def displayunitcustom(self):
        """Alias for DisplayUnitCustom"""
        return self.DisplayUnitCustom

    @displayunitcustom.setter
    def displayunitcustom(self, value):
        """Alias for DisplayUnitCustom.setter"""
        self.DisplayUnitCustom = value

    @property
    def display_unit_custom(self):
        """Alias for DisplayUnitCustom"""
        return self.DisplayUnitCustom

    @display_unit_custom.setter
    def display_unit_custom(self, value):
        """Alias for DisplayUnitCustom.setter"""
        self.DisplayUnitCustom = value

    @property
    def DisplayUnitLabel(self):
        return DisplayUnitLabel(self.com_object.DisplayUnitLabel)

    @property
    def displayunitlabel(self):
        """Alias for DisplayUnitLabel"""
        return self.DisplayUnitLabel

    @property
    def display_unit_label(self):
        """Alias for DisplayUnitLabel"""
        return self.DisplayUnitLabel

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def HasDisplayUnitLabel(self):
        return self.com_object.HasDisplayUnitLabel

    @HasDisplayUnitLabel.setter
    def HasDisplayUnitLabel(self, value):
        self.com_object.HasDisplayUnitLabel = value

    @property
    def hasdisplayunitlabel(self):
        """Alias for HasDisplayUnitLabel"""
        return self.HasDisplayUnitLabel

    @hasdisplayunitlabel.setter
    def hasdisplayunitlabel(self, value):
        """Alias for HasDisplayUnitLabel.setter"""
        self.HasDisplayUnitLabel = value

    @property
    def has_display_unit_label(self):
        """Alias for HasDisplayUnitLabel"""
        return self.HasDisplayUnitLabel

    @has_display_unit_label.setter
    def has_display_unit_label(self, value):
        """Alias for HasDisplayUnitLabel.setter"""
        self.HasDisplayUnitLabel = value

    @property
    def HasMajorGridlines(self):
        return self.com_object.HasMajorGridlines

    @HasMajorGridlines.setter
    def HasMajorGridlines(self, value):
        self.com_object.HasMajorGridlines = value

    @property
    def hasmajorgridlines(self):
        """Alias for HasMajorGridlines"""
        return self.HasMajorGridlines

    @hasmajorgridlines.setter
    def hasmajorgridlines(self, value):
        """Alias for HasMajorGridlines.setter"""
        self.HasMajorGridlines = value

    @property
    def has_major_gridlines(self):
        """Alias for HasMajorGridlines"""
        return self.HasMajorGridlines

    @has_major_gridlines.setter
    def has_major_gridlines(self, value):
        """Alias for HasMajorGridlines.setter"""
        self.HasMajorGridlines = value

    @property
    def HasMinorGridlines(self):
        return self.com_object.HasMinorGridlines

    @HasMinorGridlines.setter
    def HasMinorGridlines(self, value):
        self.com_object.HasMinorGridlines = value

    @property
    def hasminorgridlines(self):
        """Alias for HasMinorGridlines"""
        return self.HasMinorGridlines

    @hasminorgridlines.setter
    def hasminorgridlines(self, value):
        """Alias for HasMinorGridlines.setter"""
        self.HasMinorGridlines = value

    @property
    def has_minor_gridlines(self):
        """Alias for HasMinorGridlines"""
        return self.HasMinorGridlines

    @has_minor_gridlines.setter
    def has_minor_gridlines(self, value):
        """Alias for HasMinorGridlines.setter"""
        self.HasMinorGridlines = value

    @property
    def HasTitle(self):
        return self.com_object.HasTitle

    @HasTitle.setter
    def HasTitle(self, value):
        self.com_object.HasTitle = value

    @property
    def hastitle(self):
        """Alias for HasTitle"""
        return self.HasTitle

    @hastitle.setter
    def hastitle(self, value):
        """Alias for HasTitle.setter"""
        self.HasTitle = value

    @property
    def has_title(self):
        """Alias for HasTitle"""
        return self.HasTitle

    @has_title.setter
    def has_title(self, value):
        """Alias for HasTitle.setter"""
        self.HasTitle = value

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def Left(self):
        return self.com_object.Left

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @property
    def LogBase(self):
        return self.com_object.LogBase

    @LogBase.setter
    def LogBase(self, value):
        self.com_object.LogBase = value

    @property
    def logbase(self):
        """Alias for LogBase"""
        return self.LogBase

    @logbase.setter
    def logbase(self, value):
        """Alias for LogBase.setter"""
        self.LogBase = value

    @property
    def log_base(self):
        """Alias for LogBase"""
        return self.LogBase

    @log_base.setter
    def log_base(self, value):
        """Alias for LogBase.setter"""
        self.LogBase = value

    @property
    def MajorGridlines(self):
        return Gridlines(self.com_object.MajorGridlines)

    @property
    def majorgridlines(self):
        """Alias for MajorGridlines"""
        return self.MajorGridlines

    @property
    def major_gridlines(self):
        """Alias for MajorGridlines"""
        return self.MajorGridlines

    @property
    def MajorTickMark(self):
        return XlTickMark(self.com_object.MajorTickMark)

    @MajorTickMark.setter
    def MajorTickMark(self, value):
        self.com_object.MajorTickMark = value

    @property
    def majortickmark(self):
        """Alias for MajorTickMark"""
        return self.MajorTickMark

    @majortickmark.setter
    def majortickmark(self, value):
        """Alias for MajorTickMark.setter"""
        self.MajorTickMark = value

    @property
    def major_tick_mark(self):
        """Alias for MajorTickMark"""
        return self.MajorTickMark

    @major_tick_mark.setter
    def major_tick_mark(self, value):
        """Alias for MajorTickMark.setter"""
        self.MajorTickMark = value

    @property
    def MajorUnit(self):
        return self.com_object.MajorUnit

    @MajorUnit.setter
    def MajorUnit(self, value):
        self.com_object.MajorUnit = value

    @property
    def majorunit(self):
        """Alias for MajorUnit"""
        return self.MajorUnit

    @majorunit.setter
    def majorunit(self, value):
        """Alias for MajorUnit.setter"""
        self.MajorUnit = value

    @property
    def major_unit(self):
        """Alias for MajorUnit"""
        return self.MajorUnit

    @major_unit.setter
    def major_unit(self, value):
        """Alias for MajorUnit.setter"""
        self.MajorUnit = value

    @property
    def MajorUnitIsAuto(self):
        return self.com_object.MajorUnitIsAuto

    @MajorUnitIsAuto.setter
    def MajorUnitIsAuto(self, value):
        self.com_object.MajorUnitIsAuto = value

    @property
    def majorunitisauto(self):
        """Alias for MajorUnitIsAuto"""
        return self.MajorUnitIsAuto

    @majorunitisauto.setter
    def majorunitisauto(self, value):
        """Alias for MajorUnitIsAuto.setter"""
        self.MajorUnitIsAuto = value

    @property
    def major_unit_is_auto(self):
        """Alias for MajorUnitIsAuto"""
        return self.MajorUnitIsAuto

    @major_unit_is_auto.setter
    def major_unit_is_auto(self, value):
        """Alias for MajorUnitIsAuto.setter"""
        self.MajorUnitIsAuto = value

    @property
    def MajorUnitScale(self):
        return self.com_object.MajorUnitScale

    @MajorUnitScale.setter
    def MajorUnitScale(self, value):
        self.com_object.MajorUnitScale = value

    @property
    def majorunitscale(self):
        """Alias for MajorUnitScale"""
        return self.MajorUnitScale

    @majorunitscale.setter
    def majorunitscale(self, value):
        """Alias for MajorUnitScale.setter"""
        self.MajorUnitScale = value

    @property
    def major_unit_scale(self):
        """Alias for MajorUnitScale"""
        return self.MajorUnitScale

    @major_unit_scale.setter
    def major_unit_scale(self, value):
        """Alias for MajorUnitScale.setter"""
        self.MajorUnitScale = value

    @property
    def MaximumScale(self):
        return self.com_object.MaximumScale

    @MaximumScale.setter
    def MaximumScale(self, value):
        self.com_object.MaximumScale = value

    @property
    def maximumscale(self):
        """Alias for MaximumScale"""
        return self.MaximumScale

    @maximumscale.setter
    def maximumscale(self, value):
        """Alias for MaximumScale.setter"""
        self.MaximumScale = value

    @property
    def maximum_scale(self):
        """Alias for MaximumScale"""
        return self.MaximumScale

    @maximum_scale.setter
    def maximum_scale(self, value):
        """Alias for MaximumScale.setter"""
        self.MaximumScale = value

    @property
    def MaximumScaleIsAuto(self):
        return self.com_object.MaximumScaleIsAuto

    @MaximumScaleIsAuto.setter
    def MaximumScaleIsAuto(self, value):
        self.com_object.MaximumScaleIsAuto = value

    @property
    def maximumscaleisauto(self):
        """Alias for MaximumScaleIsAuto"""
        return self.MaximumScaleIsAuto

    @maximumscaleisauto.setter
    def maximumscaleisauto(self, value):
        """Alias for MaximumScaleIsAuto.setter"""
        self.MaximumScaleIsAuto = value

    @property
    def maximum_scale_is_auto(self):
        """Alias for MaximumScaleIsAuto"""
        return self.MaximumScaleIsAuto

    @maximum_scale_is_auto.setter
    def maximum_scale_is_auto(self, value):
        """Alias for MaximumScaleIsAuto.setter"""
        self.MaximumScaleIsAuto = value

    @property
    def MinimumScale(self):
        return self.com_object.MinimumScale

    @MinimumScale.setter
    def MinimumScale(self, value):
        self.com_object.MinimumScale = value

    @property
    def minimumscale(self):
        """Alias for MinimumScale"""
        return self.MinimumScale

    @minimumscale.setter
    def minimumscale(self, value):
        """Alias for MinimumScale.setter"""
        self.MinimumScale = value

    @property
    def minimum_scale(self):
        """Alias for MinimumScale"""
        return self.MinimumScale

    @minimum_scale.setter
    def minimum_scale(self, value):
        """Alias for MinimumScale.setter"""
        self.MinimumScale = value

    @property
    def MinimumScaleIsAuto(self):
        return self.com_object.MinimumScaleIsAuto

    @MinimumScaleIsAuto.setter
    def MinimumScaleIsAuto(self, value):
        self.com_object.MinimumScaleIsAuto = value

    @property
    def minimumscaleisauto(self):
        """Alias for MinimumScaleIsAuto"""
        return self.MinimumScaleIsAuto

    @minimumscaleisauto.setter
    def minimumscaleisauto(self, value):
        """Alias for MinimumScaleIsAuto.setter"""
        self.MinimumScaleIsAuto = value

    @property
    def minimum_scale_is_auto(self):
        """Alias for MinimumScaleIsAuto"""
        return self.MinimumScaleIsAuto

    @minimum_scale_is_auto.setter
    def minimum_scale_is_auto(self, value):
        """Alias for MinimumScaleIsAuto.setter"""
        self.MinimumScaleIsAuto = value

    @property
    def MinorGridlines(self):
        return Gridlines(self.com_object.MinorGridlines)

    @property
    def minorgridlines(self):
        """Alias for MinorGridlines"""
        return self.MinorGridlines

    @property
    def minor_gridlines(self):
        """Alias for MinorGridlines"""
        return self.MinorGridlines

    @property
    def MinorTickMark(self):
        return XlTickMark(self.com_object.MinorTickMark)

    @MinorTickMark.setter
    def MinorTickMark(self, value):
        self.com_object.MinorTickMark = value

    @property
    def minortickmark(self):
        """Alias for MinorTickMark"""
        return self.MinorTickMark

    @minortickmark.setter
    def minortickmark(self, value):
        """Alias for MinorTickMark.setter"""
        self.MinorTickMark = value

    @property
    def minor_tick_mark(self):
        """Alias for MinorTickMark"""
        return self.MinorTickMark

    @minor_tick_mark.setter
    def minor_tick_mark(self, value):
        """Alias for MinorTickMark.setter"""
        self.MinorTickMark = value

    @property
    def MinorUnit(self):
        return self.com_object.MinorUnit

    @MinorUnit.setter
    def MinorUnit(self, value):
        self.com_object.MinorUnit = value

    @property
    def minorunit(self):
        """Alias for MinorUnit"""
        return self.MinorUnit

    @minorunit.setter
    def minorunit(self, value):
        """Alias for MinorUnit.setter"""
        self.MinorUnit = value

    @property
    def minor_unit(self):
        """Alias for MinorUnit"""
        return self.MinorUnit

    @minor_unit.setter
    def minor_unit(self, value):
        """Alias for MinorUnit.setter"""
        self.MinorUnit = value

    @property
    def MinorUnitIsAuto(self):
        return self.com_object.MinorUnitIsAuto

    @MinorUnitIsAuto.setter
    def MinorUnitIsAuto(self, value):
        self.com_object.MinorUnitIsAuto = value

    @property
    def minorunitisauto(self):
        """Alias for MinorUnitIsAuto"""
        return self.MinorUnitIsAuto

    @minorunitisauto.setter
    def minorunitisauto(self, value):
        """Alias for MinorUnitIsAuto.setter"""
        self.MinorUnitIsAuto = value

    @property
    def minor_unit_is_auto(self):
        """Alias for MinorUnitIsAuto"""
        return self.MinorUnitIsAuto

    @minor_unit_is_auto.setter
    def minor_unit_is_auto(self, value):
        """Alias for MinorUnitIsAuto.setter"""
        self.MinorUnitIsAuto = value

    @property
    def MinorUnitScale(self):
        return self.com_object.MinorUnitScale

    @MinorUnitScale.setter
    def MinorUnitScale(self, value):
        self.com_object.MinorUnitScale = value

    @property
    def minorunitscale(self):
        """Alias for MinorUnitScale"""
        return self.MinorUnitScale

    @minorunitscale.setter
    def minorunitscale(self, value):
        """Alias for MinorUnitScale.setter"""
        self.MinorUnitScale = value

    @property
    def minor_unit_scale(self):
        """Alias for MinorUnitScale"""
        return self.MinorUnitScale

    @minor_unit_scale.setter
    def minor_unit_scale(self, value):
        """Alias for MinorUnitScale.setter"""
        self.MinorUnitScale = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ReversePlotOrder(self):
        return self.com_object.ReversePlotOrder

    @ReversePlotOrder.setter
    def ReversePlotOrder(self, value):
        self.com_object.ReversePlotOrder = value

    @property
    def reverseplotorder(self):
        """Alias for ReversePlotOrder"""
        return self.ReversePlotOrder

    @reverseplotorder.setter
    def reverseplotorder(self, value):
        """Alias for ReversePlotOrder.setter"""
        self.ReversePlotOrder = value

    @property
    def reverse_plot_order(self):
        """Alias for ReversePlotOrder"""
        return self.ReversePlotOrder

    @reverse_plot_order.setter
    def reverse_plot_order(self, value):
        """Alias for ReversePlotOrder.setter"""
        self.ReversePlotOrder = value

    @property
    def ScaleType(self):
        return XlScaleType(self.com_object.ScaleType)

    @ScaleType.setter
    def ScaleType(self, value):
        self.com_object.ScaleType = value

    @property
    def scaletype(self):
        """Alias for ScaleType"""
        return self.ScaleType

    @scaletype.setter
    def scaletype(self, value):
        """Alias for ScaleType.setter"""
        self.ScaleType = value

    @property
    def scale_type(self):
        """Alias for ScaleType"""
        return self.ScaleType

    @scale_type.setter
    def scale_type(self, value):
        """Alias for ScaleType.setter"""
        self.ScaleType = value

    @property
    def TickLabelPosition(self):
        return self.com_object.TickLabelPosition

    @TickLabelPosition.setter
    def TickLabelPosition(self, value):
        self.com_object.TickLabelPosition = value

    @property
    def ticklabelposition(self):
        """Alias for TickLabelPosition"""
        return self.TickLabelPosition

    @ticklabelposition.setter
    def ticklabelposition(self, value):
        """Alias for TickLabelPosition.setter"""
        self.TickLabelPosition = value

    @property
    def tick_label_position(self):
        """Alias for TickLabelPosition"""
        return self.TickLabelPosition

    @tick_label_position.setter
    def tick_label_position(self, value):
        """Alias for TickLabelPosition.setter"""
        self.TickLabelPosition = value

    @property
    def TickLabels(self):
        return TickLabels(self.com_object.TickLabels)

    @property
    def ticklabels(self):
        """Alias for TickLabels"""
        return self.TickLabels

    @property
    def tick_labels(self):
        """Alias for TickLabels"""
        return self.TickLabels

    @property
    def TickLabelSpacing(self):
        return self.com_object.TickLabelSpacing

    @TickLabelSpacing.setter
    def TickLabelSpacing(self, value):
        self.com_object.TickLabelSpacing = value

    @property
    def ticklabelspacing(self):
        """Alias for TickLabelSpacing"""
        return self.TickLabelSpacing

    @ticklabelspacing.setter
    def ticklabelspacing(self, value):
        """Alias for TickLabelSpacing.setter"""
        self.TickLabelSpacing = value

    @property
    def tick_label_spacing(self):
        """Alias for TickLabelSpacing"""
        return self.TickLabelSpacing

    @tick_label_spacing.setter
    def tick_label_spacing(self, value):
        """Alias for TickLabelSpacing.setter"""
        self.TickLabelSpacing = value

    @property
    def TickLabelSpacingIsAuto(self):
        return self.com_object.TickLabelSpacingIsAuto

    @TickLabelSpacingIsAuto.setter
    def TickLabelSpacingIsAuto(self, value):
        self.com_object.TickLabelSpacingIsAuto = value

    @property
    def ticklabelspacingisauto(self):
        """Alias for TickLabelSpacingIsAuto"""
        return self.TickLabelSpacingIsAuto

    @ticklabelspacingisauto.setter
    def ticklabelspacingisauto(self, value):
        """Alias for TickLabelSpacingIsAuto.setter"""
        self.TickLabelSpacingIsAuto = value

    @property
    def tick_label_spacing_is_auto(self):
        """Alias for TickLabelSpacingIsAuto"""
        return self.TickLabelSpacingIsAuto

    @tick_label_spacing_is_auto.setter
    def tick_label_spacing_is_auto(self, value):
        """Alias for TickLabelSpacingIsAuto.setter"""
        self.TickLabelSpacingIsAuto = value

    @property
    def TickMarkSpacing(self):
        return self.com_object.TickMarkSpacing

    @TickMarkSpacing.setter
    def TickMarkSpacing(self, value):
        self.com_object.TickMarkSpacing = value

    @property
    def tickmarkspacing(self):
        """Alias for TickMarkSpacing"""
        return self.TickMarkSpacing

    @tickmarkspacing.setter
    def tickmarkspacing(self, value):
        """Alias for TickMarkSpacing.setter"""
        self.TickMarkSpacing = value

    @property
    def tick_mark_spacing(self):
        """Alias for TickMarkSpacing"""
        return self.TickMarkSpacing

    @tick_mark_spacing.setter
    def tick_mark_spacing(self, value):
        """Alias for TickMarkSpacing.setter"""
        self.TickMarkSpacing = value

    @property
    def Top(self):
        return self.com_object.Top

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @property
    def Type(self):
        return XlAxisType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class AxisTitle:

    def __init__(self, axistitle=None):
        self.com_object= axistitle

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    def Characters(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        if hasattr(self.com_object, "GetCharacters"):
            return ChartCharacters(self.com_object.GetCharacters(*arguments))
        else:
            return ChartCharacters(self.com_object.Characters(*arguments))

    def characters(self, Start=None, Length=None):
        """Alias for Characters"""
        arguments = [Start, Length]
        return self.Characters(*arguments)

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def FormulaLocal(self):
        return self.com_object.FormulaLocal

    @FormulaLocal.setter
    def FormulaLocal(self, value):
        self.com_object.FormulaLocal = value

    @property
    def formulalocal(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formulalocal.setter
    def formulalocal(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def formula_local(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formula_local.setter
    def formula_local(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def FormulaR1C1(self):
        return self.com_object.FormulaR1C1

    @FormulaR1C1.setter
    def FormulaR1C1(self, value):
        self.com_object.FormulaR1C1 = value

    @property
    def formular1c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formular1c1.setter
    def formular1c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def formula_r1_c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formula_r1_c1.setter
    def formula_r1_c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def FormulaR1C1Local(self):
        return self.com_object.FormulaR1C1Local

    @FormulaR1C1Local.setter
    def FormulaR1C1Local(self, value):
        self.com_object.FormulaR1C1Local = value

    @property
    def formular1c1local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formular1c1local.setter
    def formular1c1local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def formula_r1_c1_local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formula_r1_c1_local.setter
    def formula_r1_c1_local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def HorizontalAlignment(self):
        return self.com_object.HorizontalAlignment

    @HorizontalAlignment.setter
    def HorizontalAlignment(self, value):
        self.com_object.HorizontalAlignment = value

    @property
    def horizontalalignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontalalignment.setter
    def horizontalalignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def horizontal_alignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def IncludeInLayout(self):
        return self.com_object.IncludeInLayout

    @IncludeInLayout.setter
    def IncludeInLayout(self, value):
        self.com_object.IncludeInLayout = value

    @property
    def includeinlayout(self):
        """Alias for IncludeInLayout"""
        return self.IncludeInLayout

    @includeinlayout.setter
    def includeinlayout(self, value):
        """Alias for IncludeInLayout.setter"""
        self.IncludeInLayout = value

    @property
    def include_in_layout(self):
        """Alias for IncludeInLayout"""
        return self.IncludeInLayout

    @include_in_layout.setter
    def include_in_layout(self, value):
        """Alias for IncludeInLayout.setter"""
        self.IncludeInLayout = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return XlChartElementPosition(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def ReadingOrder(self):
        return XlReadingOrder(self.com_object.ReadingOrder)

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def VerticalAlignment(self):
        return self.com_object.VerticalAlignment

    @VerticalAlignment.setter
    def VerticalAlignment(self, value):
        self.com_object.VerticalAlignment = value

    @property
    def verticalalignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @verticalalignment.setter
    def verticalalignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def vertical_alignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @vertical_alignment.setter
    def vertical_alignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Bibliography:

    def __init__(self, bibliography=None):
        self.com_object= bibliography

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BibliographyStyle(self):
        return self.com_object.BibliographyStyle

    @BibliographyStyle.setter
    def BibliographyStyle(self, value):
        self.com_object.BibliographyStyle = value

    @property
    def bibliographystyle(self):
        """Alias for BibliographyStyle"""
        return self.BibliographyStyle

    @bibliographystyle.setter
    def bibliographystyle(self, value):
        """Alias for BibliographyStyle.setter"""
        self.BibliographyStyle = value

    @property
    def bibliography_style(self):
        """Alias for BibliographyStyle"""
        return self.BibliographyStyle

    @bibliography_style.setter
    def bibliography_style(self, value):
        """Alias for BibliographyStyle.setter"""
        self.BibliographyStyle = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Sources(self):
        return Sources(self.com_object.Sources)

    @property
    def sources(self):
        """Alias for Sources"""
        return self.Sources

    def GenerateUniqueTag(self):
        return self.com_object.GenerateUniqueTag()

    def generateuniquetag(self):
        """Alias for GenerateUniqueTag"""
        return self.GenerateUniqueTag()

    def generate_unique_tag(self):
        """Alias for GenerateUniqueTag"""
        return self.GenerateUniqueTag()


class Bookmark:

    def __init__(self, bookmark=None):
        self.com_object= bookmark

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Column(self):
        return self.com_object.Column

    @property
    def column(self):
        """Alias for Column"""
        return self.Column

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Empty(self):
        return self.com_object.Empty

    @property
    def empty(self):
        """Alias for Empty"""
        return self.Empty

    @property
    def End(self):
        return self.com_object.End

    @End.setter
    def End(self, value):
        self.com_object.End = value

    @property
    def end(self):
        """Alias for End"""
        return self.End

    @end.setter
    def end(self, value):
        """Alias for End.setter"""
        self.End = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def Start(self):
        return self.com_object.Start

    @Start.setter
    def Start(self, value):
        self.com_object.Start = value

    @property
    def start(self):
        """Alias for Start"""
        return self.Start

    @start.setter
    def start(self, value):
        """Alias for Start.setter"""
        self.Start = value

    @property
    def StoryType(self):
        return WdStoryType(self.com_object.StoryType)

    @property
    def storytype(self):
        """Alias for StoryType"""
        return self.StoryType

    @property
    def story_type(self):
        """Alias for StoryType"""
        return self.StoryType

    def Copy(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        self.com_object.Copy(*arguments)

    def copy(self, Name=None):
        """Alias for Copy"""
        arguments = [Name]
        return self.Copy(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Bookmarks:

    def __init__(self, bookmarks=None):
        self.com_object= bookmarks

    def __call__(self, item):
        return Bookmark(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return Bookmarks(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DefaultSorting(self):
        return Bookmark(self.com_object.DefaultSorting)

    @DefaultSorting.setter
    def DefaultSorting(self, value):
        self.com_object.DefaultSorting = value

    @property
    def defaultsorting(self):
        """Alias for DefaultSorting"""
        return self.DefaultSorting

    @defaultsorting.setter
    def defaultsorting(self, value):
        """Alias for DefaultSorting.setter"""
        self.DefaultSorting = value

    @property
    def default_sorting(self):
        """Alias for DefaultSorting"""
        return self.DefaultSorting

    @default_sorting.setter
    def default_sorting(self, value):
        """Alias for DefaultSorting.setter"""
        self.DefaultSorting = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ShowHidden(self):
        return self.com_object.ShowHidden

    @ShowHidden.setter
    def ShowHidden(self, value):
        self.com_object.ShowHidden = value

    @property
    def showhidden(self):
        """Alias for ShowHidden"""
        return self.ShowHidden

    @showhidden.setter
    def showhidden(self, value):
        """Alias for ShowHidden.setter"""
        self.ShowHidden = value

    @property
    def show_hidden(self):
        """Alias for ShowHidden"""
        return self.ShowHidden

    @show_hidden.setter
    def show_hidden(self, value):
        """Alias for ShowHidden.setter"""
        self.ShowHidden = value

    def Add(self, Name=None, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Range]])
        return Bookmark(self.com_object.Add(*arguments))

    def add(self, Name=None, Range=None):
        """Alias for Add"""
        arguments = [Name, Range]
        return self.Add(*arguments)

    def Exists(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        self.com_object.Exists(*arguments)

    def exists(self, Name=None):
        """Alias for Exists"""
        arguments = [Name]
        return self.Exists(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Bookmark(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Border:

    def __init__(self, border=None):
        self.com_object= border

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ArtStyle(self):
        return WdPageBorderArt(self.com_object.ArtStyle)

    @ArtStyle.setter
    def ArtStyle(self, value):
        self.com_object.ArtStyle = value

    @property
    def artstyle(self):
        """Alias for ArtStyle"""
        return self.ArtStyle

    @artstyle.setter
    def artstyle(self, value):
        """Alias for ArtStyle.setter"""
        self.ArtStyle = value

    @property
    def art_style(self):
        """Alias for ArtStyle"""
        return self.ArtStyle

    @art_style.setter
    def art_style(self, value):
        """Alias for ArtStyle.setter"""
        self.ArtStyle = value

    @property
    def ArtWidth(self):
        return self.com_object.ArtWidth

    @ArtWidth.setter
    def ArtWidth(self, value):
        self.com_object.ArtWidth = value

    @property
    def artwidth(self):
        """Alias for ArtWidth"""
        return self.ArtWidth

    @artwidth.setter
    def artwidth(self, value):
        """Alias for ArtWidth.setter"""
        self.ArtWidth = value

    @property
    def art_width(self):
        """Alias for ArtWidth"""
        return self.ArtWidth

    @art_width.setter
    def art_width(self, value):
        """Alias for ArtWidth.setter"""
        self.ArtWidth = value

    @property
    def Color(self):
        return Border(self.com_object.Color)

    @Color.setter
    def Color(self, value):
        self.com_object.Color = value

    @property
    def color(self):
        """Alias for Color"""
        return self.Color

    @color.setter
    def color(self, value):
        """Alias for Color.setter"""
        self.Color = value

    @property
    def ColorIndex(self):
        return WdColorIndex(self.com_object.ColorIndex)

    @ColorIndex.setter
    def ColorIndex(self, value):
        self.com_object.ColorIndex = value

    @property
    def colorindex(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @colorindex.setter
    def colorindex(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def color_index(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @color_index.setter
    def color_index(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Inside(self):
        return self.com_object.Inside

    @property
    def inside(self):
        """Alias for Inside"""
        return self.Inside

    @property
    def LineStyle(self):
        return WdLineStyle(self.com_object.LineStyle)

    @LineStyle.setter
    def LineStyle(self, value):
        self.com_object.LineStyle = value

    @property
    def linestyle(self):
        """Alias for LineStyle"""
        return self.LineStyle

    @linestyle.setter
    def linestyle(self, value):
        """Alias for LineStyle.setter"""
        self.LineStyle = value

    @property
    def line_style(self):
        """Alias for LineStyle"""
        return self.LineStyle

    @line_style.setter
    def line_style(self, value):
        """Alias for LineStyle.setter"""
        self.LineStyle = value

    @property
    def LineWidth(self):
        return self.com_object.LineWidth

    @LineWidth.setter
    def LineWidth(self, value):
        self.com_object.LineWidth = value

    @property
    def linewidth(self):
        """Alias for LineWidth"""
        return self.LineWidth

    @linewidth.setter
    def linewidth(self, value):
        """Alias for LineWidth.setter"""
        self.LineWidth = value

    @property
    def line_width(self):
        """Alias for LineWidth"""
        return self.LineWidth

    @line_width.setter
    def line_width(self, value):
        """Alias for LineWidth.setter"""
        self.LineWidth = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value


class Borders:

    def __init__(self, borders=None):
        self.com_object= borders

    def __call__(self, item):
        return Border(self.com_object(item))

    @property
    def AlwaysInFront(self):
        return self.com_object.AlwaysInFront

    @AlwaysInFront.setter
    def AlwaysInFront(self, value):
        self.com_object.AlwaysInFront = value

    @property
    def alwaysinfront(self):
        """Alias for AlwaysInFront"""
        return self.AlwaysInFront

    @alwaysinfront.setter
    def alwaysinfront(self, value):
        """Alias for AlwaysInFront.setter"""
        self.AlwaysInFront = value

    @property
    def always_in_front(self):
        """Alias for AlwaysInFront"""
        return self.AlwaysInFront

    @always_in_front.setter
    def always_in_front(self, value):
        """Alias for AlwaysInFront.setter"""
        self.AlwaysInFront = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return Borders(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DistanceFrom(self):
        return WdBorderDistanceFrom(self.com_object.DistanceFrom)

    @DistanceFrom.setter
    def DistanceFrom(self, value):
        self.com_object.DistanceFrom = value

    @property
    def distancefrom(self):
        """Alias for DistanceFrom"""
        return self.DistanceFrom

    @distancefrom.setter
    def distancefrom(self, value):
        """Alias for DistanceFrom.setter"""
        self.DistanceFrom = value

    @property
    def distance_from(self):
        """Alias for DistanceFrom"""
        return self.DistanceFrom

    @distance_from.setter
    def distance_from(self, value):
        """Alias for DistanceFrom.setter"""
        self.DistanceFrom = value

    @property
    def DistanceFromBottom(self):
        return self.com_object.DistanceFromBottom

    @DistanceFromBottom.setter
    def DistanceFromBottom(self, value):
        self.com_object.DistanceFromBottom = value

    @property
    def distancefrombottom(self):
        """Alias for DistanceFromBottom"""
        return self.DistanceFromBottom

    @distancefrombottom.setter
    def distancefrombottom(self, value):
        """Alias for DistanceFromBottom.setter"""
        self.DistanceFromBottom = value

    @property
    def distance_from_bottom(self):
        """Alias for DistanceFromBottom"""
        return self.DistanceFromBottom

    @distance_from_bottom.setter
    def distance_from_bottom(self, value):
        """Alias for DistanceFromBottom.setter"""
        self.DistanceFromBottom = value

    @property
    def DistanceFromLeft(self):
        return self.com_object.DistanceFromLeft

    @DistanceFromLeft.setter
    def DistanceFromLeft(self, value):
        self.com_object.DistanceFromLeft = value

    @property
    def distancefromleft(self):
        """Alias for DistanceFromLeft"""
        return self.DistanceFromLeft

    @distancefromleft.setter
    def distancefromleft(self, value):
        """Alias for DistanceFromLeft.setter"""
        self.DistanceFromLeft = value

    @property
    def distance_from_left(self):
        """Alias for DistanceFromLeft"""
        return self.DistanceFromLeft

    @distance_from_left.setter
    def distance_from_left(self, value):
        """Alias for DistanceFromLeft.setter"""
        self.DistanceFromLeft = value

    @property
    def DistanceFromRight(self):
        return self.com_object.DistanceFromRight

    @DistanceFromRight.setter
    def DistanceFromRight(self, value):
        self.com_object.DistanceFromRight = value

    @property
    def distancefromright(self):
        """Alias for DistanceFromRight"""
        return self.DistanceFromRight

    @distancefromright.setter
    def distancefromright(self, value):
        """Alias for DistanceFromRight.setter"""
        self.DistanceFromRight = value

    @property
    def distance_from_right(self):
        """Alias for DistanceFromRight"""
        return self.DistanceFromRight

    @distance_from_right.setter
    def distance_from_right(self, value):
        """Alias for DistanceFromRight.setter"""
        self.DistanceFromRight = value

    @property
    def DistanceFromTop(self):
        return self.com_object.DistanceFromTop

    @DistanceFromTop.setter
    def DistanceFromTop(self, value):
        self.com_object.DistanceFromTop = value

    @property
    def distancefromtop(self):
        """Alias for DistanceFromTop"""
        return self.DistanceFromTop

    @distancefromtop.setter
    def distancefromtop(self, value):
        """Alias for DistanceFromTop.setter"""
        self.DistanceFromTop = value

    @property
    def distance_from_top(self):
        """Alias for DistanceFromTop"""
        return self.DistanceFromTop

    @distance_from_top.setter
    def distance_from_top(self, value):
        """Alias for DistanceFromTop.setter"""
        self.DistanceFromTop = value

    @property
    def Enable(self):
        return self.com_object.Enable

    @Enable.setter
    def Enable(self, value):
        self.com_object.Enable = value

    @property
    def enable(self):
        """Alias for Enable"""
        return self.Enable

    @enable.setter
    def enable(self, value):
        """Alias for Enable.setter"""
        self.Enable = value

    @property
    def EnableFirstPageInSection(self):
        return self.com_object.EnableFirstPageInSection

    @EnableFirstPageInSection.setter
    def EnableFirstPageInSection(self, value):
        self.com_object.EnableFirstPageInSection = value

    @property
    def enablefirstpageinsection(self):
        """Alias for EnableFirstPageInSection"""
        return self.EnableFirstPageInSection

    @enablefirstpageinsection.setter
    def enablefirstpageinsection(self, value):
        """Alias for EnableFirstPageInSection.setter"""
        self.EnableFirstPageInSection = value

    @property
    def enable_first_page_in_section(self):
        """Alias for EnableFirstPageInSection"""
        return self.EnableFirstPageInSection

    @enable_first_page_in_section.setter
    def enable_first_page_in_section(self, value):
        """Alias for EnableFirstPageInSection.setter"""
        self.EnableFirstPageInSection = value

    @property
    def EnableOtherPagesInSection(self):
        return self.com_object.EnableOtherPagesInSection

    @EnableOtherPagesInSection.setter
    def EnableOtherPagesInSection(self, value):
        self.com_object.EnableOtherPagesInSection = value

    @property
    def enableotherpagesinsection(self):
        """Alias for EnableOtherPagesInSection"""
        return self.EnableOtherPagesInSection

    @enableotherpagesinsection.setter
    def enableotherpagesinsection(self, value):
        """Alias for EnableOtherPagesInSection.setter"""
        self.EnableOtherPagesInSection = value

    @property
    def enable_other_pages_in_section(self):
        """Alias for EnableOtherPagesInSection"""
        return self.EnableOtherPagesInSection

    @enable_other_pages_in_section.setter
    def enable_other_pages_in_section(self, value):
        """Alias for EnableOtherPagesInSection.setter"""
        self.EnableOtherPagesInSection = value

    @property
    def HasHorizontal(self):
        return self.com_object.HasHorizontal

    @property
    def hashorizontal(self):
        """Alias for HasHorizontal"""
        return self.HasHorizontal

    @property
    def has_horizontal(self):
        """Alias for HasHorizontal"""
        return self.HasHorizontal

    @property
    def HasVertical(self):
        return self.com_object.HasVertical

    @property
    def hasvertical(self):
        """Alias for HasVertical"""
        return self.HasVertical

    @property
    def has_vertical(self):
        """Alias for HasVertical"""
        return self.HasVertical

    @property
    def InsideColor(self):
        return self.com_object.InsideColor

    @InsideColor.setter
    def InsideColor(self, value):
        self.com_object.InsideColor = value

    @property
    def insidecolor(self):
        """Alias for InsideColor"""
        return self.InsideColor

    @insidecolor.setter
    def insidecolor(self, value):
        """Alias for InsideColor.setter"""
        self.InsideColor = value

    @property
    def inside_color(self):
        """Alias for InsideColor"""
        return self.InsideColor

    @inside_color.setter
    def inside_color(self, value):
        """Alias for InsideColor.setter"""
        self.InsideColor = value

    @property
    def InsideColorIndex(self):
        return WdColorIndex(self.com_object.InsideColorIndex)

    @InsideColorIndex.setter
    def InsideColorIndex(self, value):
        self.com_object.InsideColorIndex = value

    @property
    def insidecolorindex(self):
        """Alias for InsideColorIndex"""
        return self.InsideColorIndex

    @insidecolorindex.setter
    def insidecolorindex(self, value):
        """Alias for InsideColorIndex.setter"""
        self.InsideColorIndex = value

    @property
    def inside_color_index(self):
        """Alias for InsideColorIndex"""
        return self.InsideColorIndex

    @inside_color_index.setter
    def inside_color_index(self, value):
        """Alias for InsideColorIndex.setter"""
        self.InsideColorIndex = value

    @property
    def InsideLineStyle(self):
        return self.com_object.InsideLineStyle

    @InsideLineStyle.setter
    def InsideLineStyle(self, value):
        self.com_object.InsideLineStyle = value

    @property
    def insidelinestyle(self):
        """Alias for InsideLineStyle"""
        return self.InsideLineStyle

    @insidelinestyle.setter
    def insidelinestyle(self, value):
        """Alias for InsideLineStyle.setter"""
        self.InsideLineStyle = value

    @property
    def inside_line_style(self):
        """Alias for InsideLineStyle"""
        return self.InsideLineStyle

    @inside_line_style.setter
    def inside_line_style(self, value):
        """Alias for InsideLineStyle.setter"""
        self.InsideLineStyle = value

    @property
    def InsideLineWidth(self):
        return self.com_object.InsideLineWidth

    @InsideLineWidth.setter
    def InsideLineWidth(self, value):
        self.com_object.InsideLineWidth = value

    @property
    def insidelinewidth(self):
        """Alias for InsideLineWidth"""
        return self.InsideLineWidth

    @insidelinewidth.setter
    def insidelinewidth(self, value):
        """Alias for InsideLineWidth.setter"""
        self.InsideLineWidth = value

    @property
    def inside_line_width(self):
        """Alias for InsideLineWidth"""
        return self.InsideLineWidth

    @inside_line_width.setter
    def inside_line_width(self, value):
        """Alias for InsideLineWidth.setter"""
        self.InsideLineWidth = value

    @property
    def JoinBorders(self):
        return self.com_object.JoinBorders

    @JoinBorders.setter
    def JoinBorders(self, value):
        self.com_object.JoinBorders = value

    @property
    def joinborders(self):
        """Alias for JoinBorders"""
        return self.JoinBorders

    @joinborders.setter
    def joinborders(self, value):
        """Alias for JoinBorders.setter"""
        self.JoinBorders = value

    @property
    def join_borders(self):
        """Alias for JoinBorders"""
        return self.JoinBorders

    @join_borders.setter
    def join_borders(self, value):
        """Alias for JoinBorders.setter"""
        self.JoinBorders = value

    @property
    def OutsideColor(self):
        return self.com_object.OutsideColor

    @OutsideColor.setter
    def OutsideColor(self, value):
        self.com_object.OutsideColor = value

    @property
    def outsidecolor(self):
        """Alias for OutsideColor"""
        return self.OutsideColor

    @outsidecolor.setter
    def outsidecolor(self, value):
        """Alias for OutsideColor.setter"""
        self.OutsideColor = value

    @property
    def outside_color(self):
        """Alias for OutsideColor"""
        return self.OutsideColor

    @outside_color.setter
    def outside_color(self, value):
        """Alias for OutsideColor.setter"""
        self.OutsideColor = value

    @property
    def OutsideColorIndex(self):
        return WdColorIndex(self.com_object.OutsideColorIndex)

    @OutsideColorIndex.setter
    def OutsideColorIndex(self, value):
        self.com_object.OutsideColorIndex = value

    @property
    def outsidecolorindex(self):
        """Alias for OutsideColorIndex"""
        return self.OutsideColorIndex

    @outsidecolorindex.setter
    def outsidecolorindex(self, value):
        """Alias for OutsideColorIndex.setter"""
        self.OutsideColorIndex = value

    @property
    def outside_color_index(self):
        """Alias for OutsideColorIndex"""
        return self.OutsideColorIndex

    @outside_color_index.setter
    def outside_color_index(self, value):
        """Alias for OutsideColorIndex.setter"""
        self.OutsideColorIndex = value

    @property
    def OutsideLineStyle(self):
        return self.com_object.OutsideLineStyle

    @OutsideLineStyle.setter
    def OutsideLineStyle(self, value):
        self.com_object.OutsideLineStyle = value

    @property
    def outsidelinestyle(self):
        """Alias for OutsideLineStyle"""
        return self.OutsideLineStyle

    @outsidelinestyle.setter
    def outsidelinestyle(self, value):
        """Alias for OutsideLineStyle.setter"""
        self.OutsideLineStyle = value

    @property
    def outside_line_style(self):
        """Alias for OutsideLineStyle"""
        return self.OutsideLineStyle

    @outside_line_style.setter
    def outside_line_style(self, value):
        """Alias for OutsideLineStyle.setter"""
        self.OutsideLineStyle = value

    @property
    def OutsideLineWidth(self):
        return self.com_object.OutsideLineWidth

    @OutsideLineWidth.setter
    def OutsideLineWidth(self, value):
        self.com_object.OutsideLineWidth = value

    @property
    def outsidelinewidth(self):
        """Alias for OutsideLineWidth"""
        return self.OutsideLineWidth

    @outsidelinewidth.setter
    def outsidelinewidth(self, value):
        """Alias for OutsideLineWidth.setter"""
        self.OutsideLineWidth = value

    @property
    def outside_line_width(self):
        """Alias for OutsideLineWidth"""
        return self.OutsideLineWidth

    @outside_line_width.setter
    def outside_line_width(self, value):
        """Alias for OutsideLineWidth.setter"""
        self.OutsideLineWidth = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def SurroundFooter(self):
        return self.com_object.SurroundFooter

    @SurroundFooter.setter
    def SurroundFooter(self, value):
        self.com_object.SurroundFooter = value

    @property
    def surroundfooter(self):
        """Alias for SurroundFooter"""
        return self.SurroundFooter

    @surroundfooter.setter
    def surroundfooter(self, value):
        """Alias for SurroundFooter.setter"""
        self.SurroundFooter = value

    @property
    def surround_footer(self):
        """Alias for SurroundFooter"""
        return self.SurroundFooter

    @surround_footer.setter
    def surround_footer(self, value):
        """Alias for SurroundFooter.setter"""
        self.SurroundFooter = value

    @property
    def SurroundHeader(self):
        return self.com_object.SurroundHeader

    @SurroundHeader.setter
    def SurroundHeader(self, value):
        self.com_object.SurroundHeader = value

    @property
    def surroundheader(self):
        """Alias for SurroundHeader"""
        return self.SurroundHeader

    @surroundheader.setter
    def surroundheader(self, value):
        """Alias for SurroundHeader.setter"""
        self.SurroundHeader = value

    @property
    def surround_header(self):
        """Alias for SurroundHeader"""
        return self.SurroundHeader

    @surround_header.setter
    def surround_header(self, value):
        """Alias for SurroundHeader.setter"""
        self.SurroundHeader = value

    def ApplyPageBordersToAllSections(self):
        self.com_object.ApplyPageBordersToAllSections()

    def applypageborderstoallsections(self):
        """Alias for ApplyPageBordersToAllSections"""
        return self.ApplyPageBordersToAllSections()

    def apply_page_borders_to_all_sections(self):
        """Alias for ApplyPageBordersToAllSections"""
        return self.ApplyPageBordersToAllSections()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Border(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Breaks:

    def __init__(self, breaks=None):
        self.com_object= breaks

    def __call__(self, item):
        return Break(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return Breaks(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Broadcast:

    def __init__(self, broadcast=None):
        self.com_object= broadcast

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AttendeeUrl(self):
        return self.com_object.AttendeeUrl

    @property
    def attendeeurl(self):
        """Alias for AttendeeUrl"""
        return self.AttendeeUrl

    @property
    def attendee_url(self):
        """Alias for AttendeeUrl"""
        return self.AttendeeUrl

    @property
    def Capabilities(self):
        return self.com_object.Capabilities

    @property
    def capabilities(self):
        """Alias for Capabilities"""
        return self.Capabilities

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PresenterServiceUrl(self):
        return self.com_object.PresenterServiceUrl

    @property
    def presenterserviceurl(self):
        """Alias for PresenterServiceUrl"""
        return self.PresenterServiceUrl

    @property
    def presenter_service_url(self):
        """Alias for PresenterServiceUrl"""
        return self.PresenterServiceUrl

    @property
    def SessionID(self):
        return self.com_object.SessionID

    @property
    def sessionid(self):
        """Alias for SessionID"""
        return self.SessionID

    @property
    def session_i_d(self):
        """Alias for SessionID"""
        return self.SessionID

    @property
    def State(self):
        return self.com_object.State

    @property
    def state(self):
        """Alias for State"""
        return self.State

    def AddMeetingNotes(self, notesUrl=None, notesWacUrl=None):
        arguments = com_arguments([unwrap(a) for a in [notesUrl, notesWacUrl]])
        return self.com_object.AddMeetingNotes(*arguments)

    def addmeetingnotes(self, notesUrl=None, notesWacUrl=None):
        """Alias for AddMeetingNotes"""
        arguments = [notesUrl, notesWacUrl]
        return self.AddMeetingNotes(*arguments)

    def add_meeting_notes(self, notesUrl=None, notesWacUrl=None):
        """Alias for AddMeetingNotes"""
        arguments = [notesUrl, notesWacUrl]
        return self.AddMeetingNotes(*arguments)

    def End(self):
        return self.com_object.End()

    def end(self):
        """Alias for End"""
        return self.End()

    def Pause(self):
        return self.com_object.Pause()

    def pause(self):
        """Alias for Pause"""
        return self.Pause()

    def Resume(self):
        return self.com_object.Resume()

    def resume(self):
        """Alias for Resume"""
        return self.Resume()

    def Start(self, serverUrl=None):
        arguments = com_arguments([unwrap(a) for a in [serverUrl]])
        return self.com_object.Start(*arguments)

    def start(self, serverUrl=None):
        """Alias for Start"""
        arguments = [serverUrl]
        return self.Start(*arguments)


class Browser:

    def __init__(self, browser=None):
        self.com_object= browser

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Target(self):
        return self.com_object.Target

    @Target.setter
    def Target(self, value):
        self.com_object.Target = value

    @property
    def target(self):
        """Alias for Target"""
        return self.Target

    @target.setter
    def target(self, value):
        """Alias for Target.setter"""
        self.Target = value

    def Next(self):
        self.com_object.Next()

    def next(self):
        """Alias for Next"""
        return self.Next()

    def Previous(self):
        self.com_object.Previous()

    def previous(self):
        """Alias for Previous"""
        return self.Previous()


class BuildingBlock:

    def __init__(self, buildingblock=None):
        self.com_object= buildingblock

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Category(self):
        return Category(self.com_object.Category)

    @property
    def category(self):
        """Alias for Category"""
        return self.Category

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Description(self):
        return self.com_object.Description

    @Description.setter
    def Description(self, value):
        self.com_object.Description = value

    @property
    def description(self):
        """Alias for Description"""
        return self.Description

    @description.setter
    def description(self, value):
        """Alias for Description.setter"""
        self.Description = value

    @property
    def ID(self):
        return self.com_object.ID

    @property
    def id(self):
        """Alias for ID"""
        return self.ID

    @property
    def i_d(self):
        """Alias for ID"""
        return self.ID

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def InsertOptions(self):
        return self.com_object.InsertOptions

    @InsertOptions.setter
    def InsertOptions(self, value):
        self.com_object.InsertOptions = value

    @property
    def insertoptions(self):
        """Alias for InsertOptions"""
        return self.InsertOptions

    @insertoptions.setter
    def insertoptions(self, value):
        """Alias for InsertOptions.setter"""
        self.InsertOptions = value

    @property
    def insert_options(self):
        """Alias for InsertOptions"""
        return self.InsertOptions

    @insert_options.setter
    def insert_options(self, value):
        """Alias for InsertOptions.setter"""
        self.InsertOptions = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Type(self):
        return BuildingBlockType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Insert(self, Where=None, RichText=None):
        arguments = com_arguments([unwrap(a) for a in [Where, RichText]])
        return Range(self.com_object.Insert(*arguments))

    def insert(self, Where=None, RichText=None):
        """Alias for Insert"""
        arguments = [Where, RichText]
        return self.Insert(*arguments)


class BuildingBlockEntries:

    def __init__(self, buildingblockentries=None):
        self.com_object= buildingblockentries

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return BuildingBlockEntries(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, Type=None, Category=None, Range=None, Description=None, InsertOptions=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Type, Category, Range, Description, InsertOptions]])
        return BuildingBlock(self.com_object.Add(*arguments))

    def add(self, Name=None, Type=None, Category=None, Range=None, Description=None, InsertOptions=None):
        """Alias for Add"""
        arguments = [Name, Type, Category, Range, Description, InsertOptions]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return BuildingBlock(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class BuildingBlocks:

    def __init__(self, buildingblocks=None):
        self.com_object= buildingblocks

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return BuildingBlocks(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, Range=None, Description=None, InsertOptions=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Range, Description, InsertOptions]])
        return BuildingBlock(self.com_object.Add(*arguments))

    def add(self, Name=None, Range=None, Description=None, InsertOptions=None):
        """Alias for Add"""
        arguments = [Name, Range, Description, InsertOptions]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return BuildingBlock(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class BuildingBlockType:

    def __init__(self, buildingblocktype=None):
        self.com_object= buildingblocktype

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Categories(self):
        return Categories(self.com_object.Categories)

    @property
    def categories(self):
        """Alias for Categories"""
        return self.Categories

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class BuildingBlockTypes:

    def __init__(self, buildingblocktypes=None):
        self.com_object= buildingblocktypes

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return BuildingBlockTypes(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return BuildingBlockType(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class CalloutFormat:

    def __init__(self, calloutformat=None):
        self.com_object= calloutformat

    @property
    def Accent(self):
        return self.com_object.Accent

    @Accent.setter
    def Accent(self, value):
        self.com_object.Accent = value

    @property
    def accent(self):
        """Alias for Accent"""
        return self.Accent

    @accent.setter
    def accent(self, value):
        """Alias for Accent.setter"""
        self.Accent = value

    @property
    def Angle(self):
        return self.com_object.Angle

    @Angle.setter
    def Angle(self, value):
        self.com_object.Angle = value

    @property
    def angle(self):
        """Alias for Angle"""
        return self.Angle

    @angle.setter
    def angle(self, value):
        """Alias for Angle.setter"""
        self.Angle = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoLength(self):
        return self.com_object.AutoLength

    @property
    def autolength(self):
        """Alias for AutoLength"""
        return self.AutoLength

    @property
    def auto_length(self):
        """Alias for AutoLength"""
        return self.AutoLength

    @property
    def Border(self):
        return self.com_object.Border

    @Border.setter
    def Border(self, value):
        self.com_object.Border = value

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @border.setter
    def border(self, value):
        """Alias for Border.setter"""
        self.Border = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Drop(self):
        return self.com_object.Drop

    @property
    def drop(self):
        """Alias for Drop"""
        return self.Drop

    @property
    def DropType(self):
        return self.com_object.DropType

    @property
    def droptype(self):
        """Alias for DropType"""
        return self.DropType

    @property
    def drop_type(self):
        """Alias for DropType"""
        return self.DropType

    @property
    def Gap(self):
        return self.com_object.Gap

    @Gap.setter
    def Gap(self, value):
        self.com_object.Gap = value

    @property
    def gap(self):
        """Alias for Gap"""
        return self.Gap

    @gap.setter
    def gap(self, value):
        """Alias for Gap.setter"""
        self.Gap = value

    @property
    def Length(self):
        return self.com_object.Length

    @property
    def length(self):
        """Alias for Length"""
        return self.Length

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    def CustomDrop(self, Drop=None):
        arguments = com_arguments([unwrap(a) for a in [Drop]])
        self.com_object.CustomDrop(*arguments)

    def customdrop(self, Drop=None):
        """Alias for CustomDrop"""
        arguments = [Drop]
        return self.CustomDrop(*arguments)

    def custom_drop(self, Drop=None):
        """Alias for CustomDrop"""
        arguments = [Drop]
        return self.CustomDrop(*arguments)

    def CustomLength(self, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Length]])
        self.com_object.CustomLength(*arguments)

    def customlength(self, Length=None):
        """Alias for CustomLength"""
        arguments = [Length]
        return self.CustomLength(*arguments)

    def custom_length(self, Length=None):
        """Alias for CustomLength"""
        arguments = [Length]
        return self.CustomLength(*arguments)

    def PresetDrop(self, DropType=None):
        arguments = com_arguments([unwrap(a) for a in [DropType]])
        self.com_object.PresetDrop(*arguments)

    def presetdrop(self, DropType=None):
        """Alias for PresetDrop"""
        arguments = [DropType]
        return self.PresetDrop(*arguments)

    def preset_drop(self, DropType=None):
        """Alias for PresetDrop"""
        arguments = [DropType]
        return self.PresetDrop(*arguments)


class CanvasShapes:

    def __init__(self, canvasshapes=None):
        self.com_object= canvasshapes

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def AddCallout(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Left, Top, Width, Height]])
        self.com_object.AddCallout(*arguments)

    def addcallout(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddCallout"""
        arguments = [Type, Left, Top, Width, Height]
        return self.AddCallout(*arguments)

    def add_callout(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddCallout"""
        arguments = [Type, Left, Top, Width, Height]
        return self.AddCallout(*arguments)

    def AddConnector(self, Type=None, BeginX=None, BeginY=None, EndX=None, EndY=None):
        arguments = com_arguments([unwrap(a) for a in [Type, BeginX, BeginY, EndX, EndY]])
        self.com_object.AddConnector(*arguments)

    def addconnector(self, Type=None, BeginX=None, BeginY=None, EndX=None, EndY=None):
        """Alias for AddConnector"""
        arguments = [Type, BeginX, BeginY, EndX, EndY]
        return self.AddConnector(*arguments)

    def add_connector(self, Type=None, BeginX=None, BeginY=None, EndX=None, EndY=None):
        """Alias for AddConnector"""
        arguments = [Type, BeginX, BeginY, EndX, EndY]
        return self.AddConnector(*arguments)

    def AddCurve(self, SafeArrayOfPoints=None):
        arguments = com_arguments([unwrap(a) for a in [SafeArrayOfPoints]])
        self.com_object.AddCurve(*arguments)

    def addcurve(self, SafeArrayOfPoints=None):
        """Alias for AddCurve"""
        arguments = [SafeArrayOfPoints]
        return self.AddCurve(*arguments)

    def add_curve(self, SafeArrayOfPoints=None):
        """Alias for AddCurve"""
        arguments = [SafeArrayOfPoints]
        return self.AddCurve(*arguments)

    def AddLabel(self, Orientation=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Orientation, Left, Top, Width, Height]])
        self.com_object.AddLabel(*arguments)

    def addlabel(self, Orientation=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddLabel"""
        arguments = [Orientation, Left, Top, Width, Height]
        return self.AddLabel(*arguments)

    def add_label(self, Orientation=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddLabel"""
        arguments = [Orientation, Left, Top, Width, Height]
        return self.AddLabel(*arguments)

    def AddLine(self, BeginX=None, BeginY=None, EndX=None, EndY=None):
        arguments = com_arguments([unwrap(a) for a in [BeginX, BeginY, EndX, EndY]])
        self.com_object.AddLine(*arguments)

    def addline(self, BeginX=None, BeginY=None, EndX=None, EndY=None):
        """Alias for AddLine"""
        arguments = [BeginX, BeginY, EndX, EndY]
        return self.AddLine(*arguments)

    def add_line(self, BeginX=None, BeginY=None, EndX=None, EndY=None):
        """Alias for AddLine"""
        arguments = [BeginX, BeginY, EndX, EndY]
        return self.AddLine(*arguments)

    def AddPicture(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height]])
        self.com_object.AddPicture(*arguments)

    def addpicture(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddPicture"""
        arguments = [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height]
        return self.AddPicture(*arguments)

    def add_picture(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddPicture"""
        arguments = [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height]
        return self.AddPicture(*arguments)

    def AddPolyline(self, SafeArrayOfPoints=None):
        arguments = com_arguments([unwrap(a) for a in [SafeArrayOfPoints]])
        self.com_object.AddPolyline(*arguments)

    def addpolyline(self, SafeArrayOfPoints=None):
        """Alias for AddPolyline"""
        arguments = [SafeArrayOfPoints]
        return self.AddPolyline(*arguments)

    def add_polyline(self, SafeArrayOfPoints=None):
        """Alias for AddPolyline"""
        arguments = [SafeArrayOfPoints]
        return self.AddPolyline(*arguments)

    def AddShape(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Left, Top, Width, Height]])
        self.com_object.AddShape(*arguments)

    def addshape(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddShape"""
        arguments = [Type, Left, Top, Width, Height]
        return self.AddShape(*arguments)

    def add_shape(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddShape"""
        arguments = [Type, Left, Top, Width, Height]
        return self.AddShape(*arguments)

    def AddTextbox(self, Orientation=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Orientation, Left, Top, Width, Height]])
        self.com_object.AddTextbox(*arguments)

    def addtextbox(self, Orientation=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddTextbox"""
        arguments = [Orientation, Left, Top, Width, Height]
        return self.AddTextbox(*arguments)

    def add_textbox(self, Orientation=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddTextbox"""
        arguments = [Orientation, Left, Top, Width, Height]
        return self.AddTextbox(*arguments)

    def AddTextEffect(self, PresetTextEffect=None, Text=None, FontName=None, FontSize=None, FontBold=None, FontItalic=None, Left=None, Top=None):
        arguments = com_arguments([unwrap(a) for a in [PresetTextEffect, Text, FontName, FontSize, FontBold, FontItalic, Left, Top]])
        self.com_object.AddTextEffect(*arguments)

    def addtexteffect(self, PresetTextEffect=None, Text=None, FontName=None, FontSize=None, FontBold=None, FontItalic=None, Left=None, Top=None):
        """Alias for AddTextEffect"""
        arguments = [PresetTextEffect, Text, FontName, FontSize, FontBold, FontItalic, Left, Top]
        return self.AddTextEffect(*arguments)

    def add_text_effect(self, PresetTextEffect=None, Text=None, FontName=None, FontSize=None, FontBold=None, FontItalic=None, Left=None, Top=None):
        """Alias for AddTextEffect"""
        arguments = [PresetTextEffect, Text, FontName, FontSize, FontBold, FontItalic, Left, Top]
        return self.AddTextEffect(*arguments)

    def BuildFreeform(self, EditingType=None, X1=None, Y1=None):
        arguments = com_arguments([unwrap(a) for a in [EditingType, X1, Y1]])
        self.com_object.BuildFreeform(*arguments)

    def buildfreeform(self, EditingType=None, X1=None, Y1=None):
        """Alias for BuildFreeform"""
        arguments = [EditingType, X1, Y1]
        return self.BuildFreeform(*arguments)

    def build_freeform(self, EditingType=None, X1=None, Y1=None):
        """Alias for BuildFreeform"""
        arguments = [EditingType, X1, Y1]
        return self.BuildFreeform(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Shape(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Range(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ShapeRange(self.com_object.Range(*arguments))

    def range(self, Index=None):
        """Alias for Range"""
        arguments = [Index]
        return self.Range(*arguments)

    def SelectAll(self):
        self.com_object.SelectAll()

    def selectall(self):
        """Alias for SelectAll"""
        return self.SelectAll()

    def select_all(self):
        """Alias for SelectAll"""
        return self.SelectAll()


class CaptionLabel:

    def __init__(self, captionlabel=None):
        self.com_object= captionlabel

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BuiltIn(self):
        return self.com_object.BuiltIn

    @property
    def builtin(self):
        """Alias for BuiltIn"""
        return self.BuiltIn

    @property
    def built_in(self):
        """Alias for BuiltIn"""
        return self.BuiltIn

    @property
    def ChapterStyleLevel(self):
        return self.com_object.ChapterStyleLevel

    @ChapterStyleLevel.setter
    def ChapterStyleLevel(self, value):
        self.com_object.ChapterStyleLevel = value

    @property
    def chapterstylelevel(self):
        """Alias for ChapterStyleLevel"""
        return self.ChapterStyleLevel

    @chapterstylelevel.setter
    def chapterstylelevel(self, value):
        """Alias for ChapterStyleLevel.setter"""
        self.ChapterStyleLevel = value

    @property
    def chapter_style_level(self):
        """Alias for ChapterStyleLevel"""
        return self.ChapterStyleLevel

    @chapter_style_level.setter
    def chapter_style_level(self, value):
        """Alias for ChapterStyleLevel.setter"""
        self.ChapterStyleLevel = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ID(self):
        return WdCaptionLabelID(self.com_object.ID)

    @property
    def id(self):
        """Alias for ID"""
        return self.ID

    @property
    def i_d(self):
        """Alias for ID"""
        return self.ID

    @property
    def IncludeChapterNumber(self):
        return self.com_object.IncludeChapterNumber

    @IncludeChapterNumber.setter
    def IncludeChapterNumber(self, value):
        self.com_object.IncludeChapterNumber = value

    @property
    def includechapternumber(self):
        """Alias for IncludeChapterNumber"""
        return self.IncludeChapterNumber

    @includechapternumber.setter
    def includechapternumber(self, value):
        """Alias for IncludeChapterNumber.setter"""
        self.IncludeChapterNumber = value

    @property
    def include_chapter_number(self):
        """Alias for IncludeChapterNumber"""
        return self.IncludeChapterNumber

    @include_chapter_number.setter
    def include_chapter_number(self, value):
        """Alias for IncludeChapterNumber.setter"""
        self.IncludeChapterNumber = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NumberStyle(self):
        return CaptionLabel(self.com_object.NumberStyle)

    @NumberStyle.setter
    def NumberStyle(self, value):
        self.com_object.NumberStyle = value

    @property
    def numberstyle(self):
        """Alias for NumberStyle"""
        return self.NumberStyle

    @numberstyle.setter
    def numberstyle(self, value):
        """Alias for NumberStyle.setter"""
        self.NumberStyle = value

    @property
    def number_style(self):
        """Alias for NumberStyle"""
        return self.NumberStyle

    @number_style.setter
    def number_style(self, value):
        """Alias for NumberStyle.setter"""
        self.NumberStyle = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return WdCaptionPosition(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def Separator(self):
        return WdSeparatorType(self.com_object.Separator)

    @Separator.setter
    def Separator(self, value):
        self.com_object.Separator = value

    @property
    def separator(self):
        """Alias for Separator"""
        return self.Separator

    @separator.setter
    def separator(self, value):
        """Alias for Separator.setter"""
        self.Separator = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class CaptionLabels:

    def __init__(self, captionlabels=None):
        self.com_object= captionlabels

    def __call__(self, item):
        return CaptionLabel(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        return CaptionLabel(self.com_object.Add(*arguments))

    def add(self, Name=None):
        """Alias for Add"""
        arguments = [Name]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return CaptionLabel(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Categories:

    def __init__(self, categories=None):
        self.com_object= categories

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return Categories(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Category(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Category:

    def __init__(self, category=None):
        self.com_object= category

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BuildingBlocks(self):
        return BuildingBlocks(self.com_object.BuildingBlocks)

    @property
    def buildingblocks(self):
        """Alias for BuildingBlocks"""
        return self.BuildingBlocks

    @property
    def building_blocks(self):
        """Alias for BuildingBlocks"""
        return self.BuildingBlocks

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Type(self):
        return BuildingBlockType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type


class CategoryCollection:

    def __init__(self, categorycollection=None):
        self.com_object= categorycollection

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return CHARTCATEGORY(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Cell:

    def __init__(self, cell=None):
        self.com_object= cell

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def BottomPadding(self):
        return self.com_object.BottomPadding

    @BottomPadding.setter
    def BottomPadding(self, value):
        self.com_object.BottomPadding = value

    @property
    def bottompadding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottompadding.setter
    def bottompadding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def bottom_padding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottom_padding.setter
    def bottom_padding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def Column(self):
        return Column(self.com_object.Column)

    @property
    def column(self):
        """Alias for Column"""
        return self.Column

    @property
    def ColumnIndex(self):
        return self.com_object.ColumnIndex

    @property
    def columnindex(self):
        """Alias for ColumnIndex"""
        return self.ColumnIndex

    @property
    def column_index(self):
        """Alias for ColumnIndex"""
        return self.ColumnIndex

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def FitText(self):
        return self.com_object.FitText

    @FitText.setter
    def FitText(self, value):
        self.com_object.FitText = value

    @property
    def fittext(self):
        """Alias for FitText"""
        return self.FitText

    @fittext.setter
    def fittext(self, value):
        """Alias for FitText.setter"""
        self.FitText = value

    @property
    def fit_text(self):
        """Alias for FitText"""
        return self.FitText

    @fit_text.setter
    def fit_text(self, value):
        """Alias for FitText.setter"""
        self.FitText = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HeightRule(self):
        return WdRowHeightRule(self.com_object.HeightRule)

    @HeightRule.setter
    def HeightRule(self, value):
        self.com_object.HeightRule = value

    @property
    def heightrule(self):
        """Alias for HeightRule"""
        return self.HeightRule

    @heightrule.setter
    def heightrule(self, value):
        """Alias for HeightRule.setter"""
        self.HeightRule = value

    @property
    def height_rule(self):
        """Alias for HeightRule"""
        return self.HeightRule

    @height_rule.setter
    def height_rule(self, value):
        """Alias for HeightRule.setter"""
        self.HeightRule = value

    @property
    def ID(self):
        return self.com_object.ID

    @ID.setter
    def ID(self, value):
        self.com_object.ID = value

    @property
    def id(self):
        """Alias for ID"""
        return self.ID

    @id.setter
    def id(self, value):
        """Alias for ID.setter"""
        self.ID = value

    @property
    def i_d(self):
        """Alias for ID"""
        return self.ID

    @i_d.setter
    def i_d(self, value):
        """Alias for ID.setter"""
        self.ID = value

    @property
    def LeftPadding(self):
        return self.com_object.LeftPadding

    @LeftPadding.setter
    def LeftPadding(self, value):
        self.com_object.LeftPadding = value

    @property
    def leftpadding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @leftpadding.setter
    def leftpadding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def left_padding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @left_padding.setter
    def left_padding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def NestingLevel(self):
        return self.com_object.NestingLevel

    @property
    def nestinglevel(self):
        """Alias for NestingLevel"""
        return self.NestingLevel

    @property
    def nesting_level(self):
        """Alias for NestingLevel"""
        return self.NestingLevel

    @property
    def Next(self):
        return Cell(self.com_object.Next)

    @property
    def next(self):
        """Alias for Next"""
        return self.Next

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PreferredWidth(self):
        return self.com_object.PreferredWidth

    @PreferredWidth.setter
    def PreferredWidth(self, value):
        self.com_object.PreferredWidth = value

    @property
    def preferredwidth(self):
        """Alias for PreferredWidth"""
        return self.PreferredWidth

    @preferredwidth.setter
    def preferredwidth(self, value):
        """Alias for PreferredWidth.setter"""
        self.PreferredWidth = value

    @property
    def preferred_width(self):
        """Alias for PreferredWidth"""
        return self.PreferredWidth

    @preferred_width.setter
    def preferred_width(self, value):
        """Alias for PreferredWidth.setter"""
        self.PreferredWidth = value

    @property
    def PreferredWidthType(self):
        return WdPreferredWidthType(self.com_object.PreferredWidthType)

    @PreferredWidthType.setter
    def PreferredWidthType(self, value):
        self.com_object.PreferredWidthType = value

    @property
    def preferredwidthtype(self):
        """Alias for PreferredWidthType"""
        return self.PreferredWidthType

    @preferredwidthtype.setter
    def preferredwidthtype(self, value):
        """Alias for PreferredWidthType.setter"""
        self.PreferredWidthType = value

    @property
    def preferred_width_type(self):
        """Alias for PreferredWidthType"""
        return self.PreferredWidthType

    @preferred_width_type.setter
    def preferred_width_type(self, value):
        """Alias for PreferredWidthType.setter"""
        self.PreferredWidthType = value

    @property
    def Previous(self):
        return Cells(self.com_object.Previous)

    @property
    def previous(self):
        """Alias for Previous"""
        return self.Previous

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def RightPadding(self):
        return self.com_object.RightPadding

    @RightPadding.setter
    def RightPadding(self, value):
        self.com_object.RightPadding = value

    @property
    def rightpadding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @rightpadding.setter
    def rightpadding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def right_padding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @right_padding.setter
    def right_padding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def Row(self):
        return Row(self.com_object.Row)

    @property
    def row(self):
        """Alias for Row"""
        return self.Row

    @property
    def RowIndex(self):
        return self.com_object.RowIndex

    @property
    def rowindex(self):
        """Alias for RowIndex"""
        return self.RowIndex

    @property
    def row_index(self):
        """Alias for RowIndex"""
        return self.RowIndex

    @property
    def Shading(self):
        return Shading(self.com_object.Shading)

    @property
    def shading(self):
        """Alias for Shading"""
        return self.Shading

    @property
    def Tables(self):
        return Tables(self.com_object.Tables)

    @property
    def tables(self):
        """Alias for Tables"""
        return self.Tables

    @property
    def TopPadding(self):
        return self.com_object.TopPadding

    @TopPadding.setter
    def TopPadding(self, value):
        self.com_object.TopPadding = value

    @property
    def toppadding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @toppadding.setter
    def toppadding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def top_padding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @top_padding.setter
    def top_padding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def VerticalAlignment(self):
        return WdCellVerticalAlignment(self.com_object.VerticalAlignment)

    @VerticalAlignment.setter
    def VerticalAlignment(self, value):
        self.com_object.VerticalAlignment = value

    @property
    def verticalalignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @verticalalignment.setter
    def verticalalignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def vertical_alignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @vertical_alignment.setter
    def vertical_alignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def WordWrap(self):
        return self.com_object.WordWrap

    @WordWrap.setter
    def WordWrap(self, value):
        self.com_object.WordWrap = value

    @property
    def wordwrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @wordwrap.setter
    def wordwrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value

    @property
    def word_wrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @word_wrap.setter
    def word_wrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value

    def AutoSum(self):
        self.com_object.AutoSum()

    def autosum(self):
        """Alias for AutoSum"""
        return self.AutoSum()

    def auto_sum(self):
        """Alias for AutoSum"""
        return self.AutoSum()

    def Delete(self, ShiftCells=None):
        arguments = com_arguments([unwrap(a) for a in [ShiftCells]])
        self.com_object.Delete(*arguments)

    def delete(self, ShiftCells=None):
        """Alias for Delete"""
        arguments = [ShiftCells]
        return self.Delete(*arguments)

    def Formula(self, Formula=None, NumFormat=None):
        arguments = com_arguments([unwrap(a) for a in [Formula, NumFormat]])
        self.com_object.Formula(*arguments)

    def formula(self, Formula=None, NumFormat=None):
        """Alias for Formula"""
        arguments = [Formula, NumFormat]
        return self.Formula(*arguments)

    def Merge(self, MergeTo=None):
        arguments = com_arguments([unwrap(a) for a in [MergeTo]])
        self.com_object.Merge(*arguments)

    def merge(self, MergeTo=None):
        """Alias for Merge"""
        arguments = [MergeTo]
        return self.Merge(*arguments)

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()

    def SetHeight(self, RowHeight=None, HeightRule=None):
        arguments = com_arguments([unwrap(a) for a in [RowHeight, HeightRule]])
        self.com_object.SetHeight(*arguments)

    def setheight(self, RowHeight=None, HeightRule=None):
        """Alias for SetHeight"""
        arguments = [RowHeight, HeightRule]
        return self.SetHeight(*arguments)

    def set_height(self, RowHeight=None, HeightRule=None):
        """Alias for SetHeight"""
        arguments = [RowHeight, HeightRule]
        return self.SetHeight(*arguments)

    def SetWidth(self, ColumnWidth=None, RulerStyle=None):
        arguments = com_arguments([unwrap(a) for a in [ColumnWidth, RulerStyle]])
        self.com_object.SetWidth(*arguments)

    def setwidth(self, ColumnWidth=None, RulerStyle=None):
        """Alias for SetWidth"""
        arguments = [ColumnWidth, RulerStyle]
        return self.SetWidth(*arguments)

    def set_width(self, ColumnWidth=None, RulerStyle=None):
        """Alias for SetWidth"""
        arguments = [ColumnWidth, RulerStyle]
        return self.SetWidth(*arguments)

    def Split(self, NumRows=None, NumColumns=None):
        arguments = com_arguments([unwrap(a) for a in [NumRows, NumColumns]])
        self.com_object.Split(*arguments)

    def split(self, NumRows=None, NumColumns=None):
        """Alias for Split"""
        arguments = [NumRows, NumColumns]
        return self.Split(*arguments)


class Cells:

    def __init__(self, cells=None):
        self.com_object= cells

    def __call__(self, item):
        return Cell(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def Count(self):
        return Cells(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HeightRule(self):
        return WdRowHeightRule(self.com_object.HeightRule)

    @HeightRule.setter
    def HeightRule(self, value):
        self.com_object.HeightRule = value

    @property
    def heightrule(self):
        """Alias for HeightRule"""
        return self.HeightRule

    @heightrule.setter
    def heightrule(self, value):
        """Alias for HeightRule.setter"""
        self.HeightRule = value

    @property
    def height_rule(self):
        """Alias for HeightRule"""
        return self.HeightRule

    @height_rule.setter
    def height_rule(self, value):
        """Alias for HeightRule.setter"""
        self.HeightRule = value

    @property
    def NestingLevel(self):
        return self.com_object.NestingLevel

    @property
    def nestinglevel(self):
        """Alias for NestingLevel"""
        return self.NestingLevel

    @property
    def nesting_level(self):
        """Alias for NestingLevel"""
        return self.NestingLevel

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PreferredWidth(self):
        return self.com_object.PreferredWidth

    @PreferredWidth.setter
    def PreferredWidth(self, value):
        self.com_object.PreferredWidth = value

    @property
    def preferredwidth(self):
        """Alias for PreferredWidth"""
        return self.PreferredWidth

    @preferredwidth.setter
    def preferredwidth(self, value):
        """Alias for PreferredWidth.setter"""
        self.PreferredWidth = value

    @property
    def preferred_width(self):
        """Alias for PreferredWidth"""
        return self.PreferredWidth

    @preferred_width.setter
    def preferred_width(self, value):
        """Alias for PreferredWidth.setter"""
        self.PreferredWidth = value

    @property
    def PreferredWidthType(self):
        return WdPreferredWidthType(self.com_object.PreferredWidthType)

    @PreferredWidthType.setter
    def PreferredWidthType(self, value):
        self.com_object.PreferredWidthType = value

    @property
    def preferredwidthtype(self):
        """Alias for PreferredWidthType"""
        return self.PreferredWidthType

    @preferredwidthtype.setter
    def preferredwidthtype(self, value):
        """Alias for PreferredWidthType.setter"""
        self.PreferredWidthType = value

    @property
    def preferred_width_type(self):
        """Alias for PreferredWidthType"""
        return self.PreferredWidthType

    @preferred_width_type.setter
    def preferred_width_type(self, value):
        """Alias for PreferredWidthType.setter"""
        self.PreferredWidthType = value

    @property
    def Shading(self):
        return Shading(self.com_object.Shading)

    @property
    def shading(self):
        """Alias for Shading"""
        return self.Shading

    @property
    def VerticalAlignment(self):
        return WdCellVerticalAlignment(self.com_object.VerticalAlignment)

    @VerticalAlignment.setter
    def VerticalAlignment(self, value):
        self.com_object.VerticalAlignment = value

    @property
    def verticalalignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @verticalalignment.setter
    def verticalalignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def vertical_alignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @vertical_alignment.setter
    def vertical_alignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Add(self, BeforeCell=None):
        arguments = com_arguments([unwrap(a) for a in [BeforeCell]])
        return Cell(self.com_object.Add(*arguments))

    def add(self, BeforeCell=None):
        """Alias for Add"""
        arguments = [BeforeCell]
        return self.Add(*arguments)

    def AutoFit(self):
        self.com_object.AutoFit()

    def autofit(self):
        """Alias for AutoFit"""
        return self.AutoFit()

    def auto_fit(self):
        """Alias for AutoFit"""
        return self.AutoFit()

    def Delete(self, ShiftCells=None):
        arguments = com_arguments([unwrap(a) for a in [ShiftCells]])
        self.com_object.Delete(*arguments)

    def delete(self, ShiftCells=None):
        """Alias for Delete"""
        arguments = [ShiftCells]
        return self.Delete(*arguments)

    def DistributeHeight(self):
        self.com_object.DistributeHeight()

    def distributeheight(self):
        """Alias for DistributeHeight"""
        return self.DistributeHeight()

    def distribute_height(self):
        """Alias for DistributeHeight"""
        return self.DistributeHeight()

    def DistributeWidth(self):
        self.com_object.DistributeWidth()

    def distributewidth(self):
        """Alias for DistributeWidth"""
        return self.DistributeWidth()

    def distribute_width(self):
        """Alias for DistributeWidth"""
        return self.DistributeWidth()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Cell(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Merge(self):
        self.com_object.Merge()

    def merge(self):
        """Alias for Merge"""
        return self.Merge()

    def SetHeight(self, RowHeight=None, HeightRule=None):
        arguments = com_arguments([unwrap(a) for a in [RowHeight, HeightRule]])
        self.com_object.SetHeight(*arguments)

    def setheight(self, RowHeight=None, HeightRule=None):
        """Alias for SetHeight"""
        arguments = [RowHeight, HeightRule]
        return self.SetHeight(*arguments)

    def set_height(self, RowHeight=None, HeightRule=None):
        """Alias for SetHeight"""
        arguments = [RowHeight, HeightRule]
        return self.SetHeight(*arguments)

    def SetWidth(self, ColumnWidth=None, RulerStyle=None):
        arguments = com_arguments([unwrap(a) for a in [ColumnWidth, RulerStyle]])
        self.com_object.SetWidth(*arguments)

    def setwidth(self, ColumnWidth=None, RulerStyle=None):
        """Alias for SetWidth"""
        arguments = [ColumnWidth, RulerStyle]
        return self.SetWidth(*arguments)

    def set_width(self, ColumnWidth=None, RulerStyle=None):
        """Alias for SetWidth"""
        arguments = [ColumnWidth, RulerStyle]
        return self.SetWidth(*arguments)

    def Split(self, NumRows=None, NumColumns=None, MergeBeforeSplit=None):
        arguments = com_arguments([unwrap(a) for a in [NumRows, NumColumns, MergeBeforeSplit]])
        self.com_object.Split(*arguments)

    def split(self, NumRows=None, NumColumns=None, MergeBeforeSplit=None):
        """Alias for Split"""
        arguments = [NumRows, NumColumns, MergeBeforeSplit]
        return self.Split(*arguments)


class Characters:

    def __init__(self, characters=None):
        self.com_object= characters

    def __call__(self, item):
        return Character(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return Characters(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def First(self):
        return Range(self.com_object.First)

    @property
    def first(self):
        """Alias for First"""
        return self.First

    @property
    def Last(self):
        return Range(self.com_object.Last)

    @property
    def last(self):
        """Alias for Last"""
        return self.Last

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Range(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Chart:

    def __init__(self, chart=None):
        self.com_object= chart

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoScaling(self):
        return self.com_object.AutoScaling

    @AutoScaling.setter
    def AutoScaling(self, value):
        self.com_object.AutoScaling = value

    @property
    def autoscaling(self):
        """Alias for AutoScaling"""
        return self.AutoScaling

    @autoscaling.setter
    def autoscaling(self, value):
        """Alias for AutoScaling.setter"""
        self.AutoScaling = value

    @property
    def auto_scaling(self):
        """Alias for AutoScaling"""
        return self.AutoScaling

    @auto_scaling.setter
    def auto_scaling(self, value):
        """Alias for AutoScaling.setter"""
        self.AutoScaling = value

    @property
    def BackWall(self):
        return Walls(self.com_object.BackWall)

    @property
    def backwall(self):
        """Alias for BackWall"""
        return self.BackWall

    @property
    def back_wall(self):
        """Alias for BackWall"""
        return self.BackWall

    @property
    def BarShape(self):
        return XlBarShape(self.com_object.BarShape)

    @BarShape.setter
    def BarShape(self, value):
        self.com_object.BarShape = value

    @property
    def barshape(self):
        """Alias for BarShape"""
        return self.BarShape

    @barshape.setter
    def barshape(self, value):
        """Alias for BarShape.setter"""
        self.BarShape = value

    @property
    def bar_shape(self):
        """Alias for BarShape"""
        return self.BarShape

    @bar_shape.setter
    def bar_shape(self, value):
        """Alias for BarShape.setter"""
        self.BarShape = value

    @property
    def CategoryLabelLevel(self):
        return self.com_object.CategoryLabelLevel

    @CategoryLabelLevel.setter
    def CategoryLabelLevel(self, value):
        self.com_object.CategoryLabelLevel = value

    @property
    def categorylabellevel(self):
        """Alias for CategoryLabelLevel"""
        return self.CategoryLabelLevel

    @categorylabellevel.setter
    def categorylabellevel(self, value):
        """Alias for CategoryLabelLevel.setter"""
        self.CategoryLabelLevel = value

    @property
    def category_label_level(self):
        """Alias for CategoryLabelLevel"""
        return self.CategoryLabelLevel

    @category_label_level.setter
    def category_label_level(self, value):
        """Alias for CategoryLabelLevel.setter"""
        self.CategoryLabelLevel = value

    @property
    def ChartArea(self):
        return ChartArea(self.com_object.ChartArea)

    @property
    def chartarea(self):
        """Alias for ChartArea"""
        return self.ChartArea

    @property
    def chart_area(self):
        """Alias for ChartArea"""
        return self.ChartArea

    @property
    def ChartColor(self):
        return self.com_object.ChartColor

    @ChartColor.setter
    def ChartColor(self, value):
        self.com_object.ChartColor = value

    @property
    def chartcolor(self):
        """Alias for ChartColor"""
        return self.ChartColor

    @chartcolor.setter
    def chartcolor(self, value):
        """Alias for ChartColor.setter"""
        self.ChartColor = value

    @property
    def chart_color(self):
        """Alias for ChartColor"""
        return self.ChartColor

    @chart_color.setter
    def chart_color(self, value):
        """Alias for ChartColor.setter"""
        self.ChartColor = value

    @property
    def ChartData(self):
        return ChartData(self.com_object.ChartData)

    @property
    def chartdata(self):
        """Alias for ChartData"""
        return self.ChartData

    @property
    def chart_data(self):
        """Alias for ChartData"""
        return self.ChartData

    def ChartGroups(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetChartGroups"):
            return self.com_object.GetChartGroups(*arguments)
        else:
            return self.com_object.ChartGroups(*arguments)

    def chartgroups(self, Index=None):
        """Alias for ChartGroups"""
        arguments = [Index]
        return self.ChartGroups(*arguments)

    def chart_groups(self, Index=None):
        """Alias for ChartGroups"""
        arguments = [Index]
        return self.ChartGroups(*arguments)

    @property
    def ChartStyle(self):
        return self.com_object.ChartStyle

    @ChartStyle.setter
    def ChartStyle(self, value):
        self.com_object.ChartStyle = value

    @property
    def chartstyle(self):
        """Alias for ChartStyle"""
        return self.ChartStyle

    @chartstyle.setter
    def chartstyle(self, value):
        """Alias for ChartStyle.setter"""
        self.ChartStyle = value

    @property
    def chart_style(self):
        """Alias for ChartStyle"""
        return self.ChartStyle

    @chart_style.setter
    def chart_style(self, value):
        """Alias for ChartStyle.setter"""
        self.ChartStyle = value

    @property
    def ChartTitle(self):
        return ChartTitle(self.com_object.ChartTitle)

    @property
    def charttitle(self):
        """Alias for ChartTitle"""
        return self.ChartTitle

    @property
    def chart_title(self):
        """Alias for ChartTitle"""
        return self.ChartTitle

    @property
    def ChartType(self):
        return self.com_object.ChartType

    @ChartType.setter
    def ChartType(self, value):
        self.com_object.ChartType = value

    @property
    def charttype(self):
        """Alias for ChartType"""
        return self.ChartType

    @charttype.setter
    def charttype(self, value):
        """Alias for ChartType.setter"""
        self.ChartType = value

    @property
    def chart_type(self):
        """Alias for ChartType"""
        return self.ChartType

    @chart_type.setter
    def chart_type(self, value):
        """Alias for ChartType.setter"""
        self.ChartType = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DataTable(self):
        return DataTable(self.com_object.DataTable)

    @property
    def datatable(self):
        """Alias for DataTable"""
        return self.DataTable

    @property
    def data_table(self):
        """Alias for DataTable"""
        return self.DataTable

    @property
    def DepthPercent(self):
        return self.com_object.DepthPercent

    @DepthPercent.setter
    def DepthPercent(self, value):
        self.com_object.DepthPercent = value

    @property
    def depthpercent(self):
        """Alias for DepthPercent"""
        return self.DepthPercent

    @depthpercent.setter
    def depthpercent(self, value):
        """Alias for DepthPercent.setter"""
        self.DepthPercent = value

    @property
    def depth_percent(self):
        """Alias for DepthPercent"""
        return self.DepthPercent

    @depth_percent.setter
    def depth_percent(self, value):
        """Alias for DepthPercent.setter"""
        self.DepthPercent = value

    @property
    def DisplayBlanksAs(self):
        return XlDisplayBlanksAs(self.com_object.DisplayBlanksAs)

    @DisplayBlanksAs.setter
    def DisplayBlanksAs(self, value):
        self.com_object.DisplayBlanksAs = value

    @property
    def displayblanksas(self):
        """Alias for DisplayBlanksAs"""
        return self.DisplayBlanksAs

    @displayblanksas.setter
    def displayblanksas(self, value):
        """Alias for DisplayBlanksAs.setter"""
        self.DisplayBlanksAs = value

    @property
    def display_blanks_as(self):
        """Alias for DisplayBlanksAs"""
        return self.DisplayBlanksAs

    @display_blanks_as.setter
    def display_blanks_as(self, value):
        """Alias for DisplayBlanksAs.setter"""
        self.DisplayBlanksAs = value

    @property
    def Elevation(self):
        return self.com_object.Elevation

    @Elevation.setter
    def Elevation(self, value):
        self.com_object.Elevation = value

    @property
    def elevation(self):
        """Alias for Elevation"""
        return self.Elevation

    @elevation.setter
    def elevation(self, value):
        """Alias for Elevation.setter"""
        self.Elevation = value

    @property
    def Floor(self):
        return Floor(self.com_object.Floor)

    @property
    def floor(self):
        """Alias for Floor"""
        return self.Floor

    @property
    def GapDepth(self):
        return self.com_object.GapDepth

    @GapDepth.setter
    def GapDepth(self, value):
        self.com_object.GapDepth = value

    @property
    def gapdepth(self):
        """Alias for GapDepth"""
        return self.GapDepth

    @gapdepth.setter
    def gapdepth(self, value):
        """Alias for GapDepth.setter"""
        self.GapDepth = value

    @property
    def gap_depth(self):
        """Alias for GapDepth"""
        return self.GapDepth

    @gap_depth.setter
    def gap_depth(self, value):
        """Alias for GapDepth.setter"""
        self.GapDepth = value

    @property
    def HasAxis(self):
        return self.com_object.HasAxis

    @HasAxis.setter
    def HasAxis(self, value):
        self.com_object.HasAxis = value

    @property
    def hasaxis(self):
        """Alias for HasAxis"""
        return self.HasAxis

    @hasaxis.setter
    def hasaxis(self, value):
        """Alias for HasAxis.setter"""
        self.HasAxis = value

    @property
    def has_axis(self):
        """Alias for HasAxis"""
        return self.HasAxis

    @has_axis.setter
    def has_axis(self, value):
        """Alias for HasAxis.setter"""
        self.HasAxis = value

    @property
    def HasDataTable(self):
        return self.com_object.HasDataTable

    @HasDataTable.setter
    def HasDataTable(self, value):
        self.com_object.HasDataTable = value

    @property
    def hasdatatable(self):
        """Alias for HasDataTable"""
        return self.HasDataTable

    @hasdatatable.setter
    def hasdatatable(self, value):
        """Alias for HasDataTable.setter"""
        self.HasDataTable = value

    @property
    def has_data_table(self):
        """Alias for HasDataTable"""
        return self.HasDataTable

    @has_data_table.setter
    def has_data_table(self, value):
        """Alias for HasDataTable.setter"""
        self.HasDataTable = value

    @property
    def HasLegend(self):
        return self.com_object.HasLegend

    @HasLegend.setter
    def HasLegend(self, value):
        self.com_object.HasLegend = value

    @property
    def haslegend(self):
        """Alias for HasLegend"""
        return self.HasLegend

    @haslegend.setter
    def haslegend(self, value):
        """Alias for HasLegend.setter"""
        self.HasLegend = value

    @property
    def has_legend(self):
        """Alias for HasLegend"""
        return self.HasLegend

    @has_legend.setter
    def has_legend(self, value):
        """Alias for HasLegend.setter"""
        self.HasLegend = value

    @property
    def HasTitle(self):
        return self.com_object.HasTitle

    @HasTitle.setter
    def HasTitle(self, value):
        self.com_object.HasTitle = value

    @property
    def hastitle(self):
        """Alias for HasTitle"""
        return self.HasTitle

    @hastitle.setter
    def hastitle(self, value):
        """Alias for HasTitle.setter"""
        self.HasTitle = value

    @property
    def has_title(self):
        """Alias for HasTitle"""
        return self.HasTitle

    @has_title.setter
    def has_title(self, value):
        """Alias for HasTitle.setter"""
        self.HasTitle = value

    @property
    def HeightPercent(self):
        return self.com_object.HeightPercent

    @HeightPercent.setter
    def HeightPercent(self, value):
        self.com_object.HeightPercent = value

    @property
    def heightpercent(self):
        """Alias for HeightPercent"""
        return self.HeightPercent

    @heightpercent.setter
    def heightpercent(self, value):
        """Alias for HeightPercent.setter"""
        self.HeightPercent = value

    @property
    def height_percent(self):
        """Alias for HeightPercent"""
        return self.HeightPercent

    @height_percent.setter
    def height_percent(self, value):
        """Alias for HeightPercent.setter"""
        self.HeightPercent = value

    @property
    def Legend(self):
        return Legend(self.com_object.Legend)

    @property
    def legend(self):
        """Alias for Legend"""
        return self.Legend

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Perspective(self):
        return self.com_object.Perspective

    @Perspective.setter
    def Perspective(self, value):
        self.com_object.Perspective = value

    @property
    def perspective(self):
        """Alias for Perspective"""
        return self.Perspective

    @perspective.setter
    def perspective(self, value):
        """Alias for Perspective.setter"""
        self.Perspective = value

    @property
    def PivotLayout(self):
        return self.com_object.PivotLayout

    @property
    def pivotlayout(self):
        """Alias for PivotLayout"""
        return self.PivotLayout

    @property
    def pivot_layout(self):
        """Alias for PivotLayout"""
        return self.PivotLayout

    @property
    def PlotArea(self):
        return PlotArea(self.com_object.PlotArea)

    @property
    def plotarea(self):
        """Alias for PlotArea"""
        return self.PlotArea

    @property
    def plot_area(self):
        """Alias for PlotArea"""
        return self.PlotArea

    @property
    def PlotBy(self):
        return self.com_object.PlotBy

    @PlotBy.setter
    def PlotBy(self, value):
        self.com_object.PlotBy = value

    @property
    def plotby(self):
        """Alias for PlotBy"""
        return self.PlotBy

    @plotby.setter
    def plotby(self, value):
        """Alias for PlotBy.setter"""
        self.PlotBy = value

    @property
    def plot_by(self):
        """Alias for PlotBy"""
        return self.PlotBy

    @plot_by.setter
    def plot_by(self, value):
        """Alias for PlotBy.setter"""
        self.PlotBy = value

    @property
    def PlotVisibleOnly(self):
        return self.com_object.PlotVisibleOnly

    @PlotVisibleOnly.setter
    def PlotVisibleOnly(self, value):
        self.com_object.PlotVisibleOnly = value

    @property
    def plotvisibleonly(self):
        """Alias for PlotVisibleOnly"""
        return self.PlotVisibleOnly

    @plotvisibleonly.setter
    def plotvisibleonly(self, value):
        """Alias for PlotVisibleOnly.setter"""
        self.PlotVisibleOnly = value

    @property
    def plot_visible_only(self):
        """Alias for PlotVisibleOnly"""
        return self.PlotVisibleOnly

    @plot_visible_only.setter
    def plot_visible_only(self, value):
        """Alias for PlotVisibleOnly.setter"""
        self.PlotVisibleOnly = value

    @property
    def RightAngleAxes(self):
        return self.com_object.RightAngleAxes

    @RightAngleAxes.setter
    def RightAngleAxes(self, value):
        self.com_object.RightAngleAxes = value

    @property
    def rightangleaxes(self):
        """Alias for RightAngleAxes"""
        return self.RightAngleAxes

    @rightangleaxes.setter
    def rightangleaxes(self, value):
        """Alias for RightAngleAxes.setter"""
        self.RightAngleAxes = value

    @property
    def right_angle_axes(self):
        """Alias for RightAngleAxes"""
        return self.RightAngleAxes

    @right_angle_axes.setter
    def right_angle_axes(self, value):
        """Alias for RightAngleAxes.setter"""
        self.RightAngleAxes = value

    @property
    def Rotation(self):
        return self.com_object.Rotation

    @Rotation.setter
    def Rotation(self, value):
        self.com_object.Rotation = value

    @property
    def rotation(self):
        """Alias for Rotation"""
        return self.Rotation

    @rotation.setter
    def rotation(self, value):
        """Alias for Rotation.setter"""
        self.Rotation = value

    @property
    def SeriesNameLevel(self):
        return self.com_object.SeriesNameLevel

    @SeriesNameLevel.setter
    def SeriesNameLevel(self, value):
        self.com_object.SeriesNameLevel = value

    @property
    def seriesnamelevel(self):
        """Alias for SeriesNameLevel"""
        return self.SeriesNameLevel

    @seriesnamelevel.setter
    def seriesnamelevel(self, value):
        """Alias for SeriesNameLevel.setter"""
        self.SeriesNameLevel = value

    @property
    def series_name_level(self):
        """Alias for SeriesNameLevel"""
        return self.SeriesNameLevel

    @series_name_level.setter
    def series_name_level(self, value):
        """Alias for SeriesNameLevel.setter"""
        self.SeriesNameLevel = value

    @property
    def Shapes(self):
        return Shapes(self.com_object.Shapes)

    @property
    def shapes(self):
        """Alias for Shapes"""
        return self.Shapes

    @property
    def ShowAllFieldButtons(self):
        return self.com_object.ShowAllFieldButtons

    @ShowAllFieldButtons.setter
    def ShowAllFieldButtons(self, value):
        self.com_object.ShowAllFieldButtons = value

    @property
    def showallfieldbuttons(self):
        """Alias for ShowAllFieldButtons"""
        return self.ShowAllFieldButtons

    @showallfieldbuttons.setter
    def showallfieldbuttons(self, value):
        """Alias for ShowAllFieldButtons.setter"""
        self.ShowAllFieldButtons = value

    @property
    def show_all_field_buttons(self):
        """Alias for ShowAllFieldButtons"""
        return self.ShowAllFieldButtons

    @show_all_field_buttons.setter
    def show_all_field_buttons(self, value):
        """Alias for ShowAllFieldButtons.setter"""
        self.ShowAllFieldButtons = value

    @property
    def ShowAxisFieldButtons(self):
        return self.com_object.ShowAxisFieldButtons

    @ShowAxisFieldButtons.setter
    def ShowAxisFieldButtons(self, value):
        self.com_object.ShowAxisFieldButtons = value

    @property
    def showaxisfieldbuttons(self):
        """Alias for ShowAxisFieldButtons"""
        return self.ShowAxisFieldButtons

    @showaxisfieldbuttons.setter
    def showaxisfieldbuttons(self, value):
        """Alias for ShowAxisFieldButtons.setter"""
        self.ShowAxisFieldButtons = value

    @property
    def show_axis_field_buttons(self):
        """Alias for ShowAxisFieldButtons"""
        return self.ShowAxisFieldButtons

    @show_axis_field_buttons.setter
    def show_axis_field_buttons(self, value):
        """Alias for ShowAxisFieldButtons.setter"""
        self.ShowAxisFieldButtons = value

    @property
    def ShowDataLabelsOverMaximum(self):
        return self.com_object.ShowDataLabelsOverMaximum

    @ShowDataLabelsOverMaximum.setter
    def ShowDataLabelsOverMaximum(self, value):
        self.com_object.ShowDataLabelsOverMaximum = value

    @property
    def showdatalabelsovermaximum(self):
        """Alias for ShowDataLabelsOverMaximum"""
        return self.ShowDataLabelsOverMaximum

    @showdatalabelsovermaximum.setter
    def showdatalabelsovermaximum(self, value):
        """Alias for ShowDataLabelsOverMaximum.setter"""
        self.ShowDataLabelsOverMaximum = value

    @property
    def show_data_labels_over_maximum(self):
        """Alias for ShowDataLabelsOverMaximum"""
        return self.ShowDataLabelsOverMaximum

    @show_data_labels_over_maximum.setter
    def show_data_labels_over_maximum(self, value):
        """Alias for ShowDataLabelsOverMaximum.setter"""
        self.ShowDataLabelsOverMaximum = value

    @property
    def ShowLegendFieldButtons(self):
        return self.com_object.ShowLegendFieldButtons

    @ShowLegendFieldButtons.setter
    def ShowLegendFieldButtons(self, value):
        self.com_object.ShowLegendFieldButtons = value

    @property
    def showlegendfieldbuttons(self):
        """Alias for ShowLegendFieldButtons"""
        return self.ShowLegendFieldButtons

    @showlegendfieldbuttons.setter
    def showlegendfieldbuttons(self, value):
        """Alias for ShowLegendFieldButtons.setter"""
        self.ShowLegendFieldButtons = value

    @property
    def show_legend_field_buttons(self):
        """Alias for ShowLegendFieldButtons"""
        return self.ShowLegendFieldButtons

    @show_legend_field_buttons.setter
    def show_legend_field_buttons(self, value):
        """Alias for ShowLegendFieldButtons.setter"""
        self.ShowLegendFieldButtons = value

    @property
    def ShowReportFilterFieldButtons(self):
        return self.com_object.ShowReportFilterFieldButtons

    @ShowReportFilterFieldButtons.setter
    def ShowReportFilterFieldButtons(self, value):
        self.com_object.ShowReportFilterFieldButtons = value

    @property
    def showreportfilterfieldbuttons(self):
        """Alias for ShowReportFilterFieldButtons"""
        return self.ShowReportFilterFieldButtons

    @showreportfilterfieldbuttons.setter
    def showreportfilterfieldbuttons(self, value):
        """Alias for ShowReportFilterFieldButtons.setter"""
        self.ShowReportFilterFieldButtons = value

    @property
    def show_report_filter_field_buttons(self):
        """Alias for ShowReportFilterFieldButtons"""
        return self.ShowReportFilterFieldButtons

    @show_report_filter_field_buttons.setter
    def show_report_filter_field_buttons(self, value):
        """Alias for ShowReportFilterFieldButtons.setter"""
        self.ShowReportFilterFieldButtons = value

    @property
    def ShowValueFieldButtons(self):
        return self.com_object.ShowValueFieldButtons

    @ShowValueFieldButtons.setter
    def ShowValueFieldButtons(self, value):
        self.com_object.ShowValueFieldButtons = value

    @property
    def showvaluefieldbuttons(self):
        """Alias for ShowValueFieldButtons"""
        return self.ShowValueFieldButtons

    @showvaluefieldbuttons.setter
    def showvaluefieldbuttons(self, value):
        """Alias for ShowValueFieldButtons.setter"""
        self.ShowValueFieldButtons = value

    @property
    def show_value_field_buttons(self):
        """Alias for ShowValueFieldButtons"""
        return self.ShowValueFieldButtons

    @show_value_field_buttons.setter
    def show_value_field_buttons(self, value):
        """Alias for ShowValueFieldButtons.setter"""
        self.ShowValueFieldButtons = value

    @property
    def SideWall(self):
        return Walls(self.com_object.SideWall)

    @property
    def sidewall(self):
        """Alias for SideWall"""
        return self.SideWall

    @property
    def side_wall(self):
        """Alias for SideWall"""
        return self.SideWall

    @property
    def Walls(self):
        return Walls(self.com_object.Walls)

    @property
    def walls(self):
        """Alias for Walls"""
        return self.Walls

    def ApplyChartTemplate(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        self.com_object.ApplyChartTemplate(*arguments)

    def applycharttemplate(self, FileName=None):
        """Alias for ApplyChartTemplate"""
        arguments = [FileName]
        return self.ApplyChartTemplate(*arguments)

    def apply_chart_template(self, FileName=None):
        """Alias for ApplyChartTemplate"""
        arguments = [FileName]
        return self.ApplyChartTemplate(*arguments)

    def ApplyDataLabels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        arguments = com_arguments([unwrap(a) for a in [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]])
        self.com_object.ApplyDataLabels(*arguments)

    def applydatalabels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        """Alias for ApplyDataLabels"""
        arguments = [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]
        return self.ApplyDataLabels(*arguments)

    def apply_data_labels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        """Alias for ApplyDataLabels"""
        arguments = [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]
        return self.ApplyDataLabels(*arguments)

    def ApplyLayout(self, Layout=None, ChartType=None):
        arguments = com_arguments([unwrap(a) for a in [Layout, ChartType]])
        self.com_object.ApplyLayout(*arguments)

    def applylayout(self, Layout=None, ChartType=None):
        """Alias for ApplyLayout"""
        arguments = [Layout, ChartType]
        return self.ApplyLayout(*arguments)

    def apply_layout(self, Layout=None, ChartType=None):
        """Alias for ApplyLayout"""
        arguments = [Layout, ChartType]
        return self.ApplyLayout(*arguments)

    def Axes(self, Type=None, AxisGroup=None):
        arguments = com_arguments([unwrap(a) for a in [Type, AxisGroup]])
        return self.com_object.Axes(*arguments)

    def axes(self, Type=None, AxisGroup=None):
        """Alias for Axes"""
        arguments = [Type, AxisGroup]
        return self.Axes(*arguments)

    def ChartWizard(self, Source=None, Gallery=None, Format=None, PlotBy=None, CategoryLabels=None, SeriesLabels=None, HasLegend=None, Title=None, CategoryTitle=None, ValueTitle=None, ExtraTitle=None):
        arguments = com_arguments([unwrap(a) for a in [Source, Gallery, Format, PlotBy, CategoryLabels, SeriesLabels, HasLegend, Title, CategoryTitle, ValueTitle, ExtraTitle]])
        self.com_object.ChartWizard(*arguments)

    def chartwizard(self, Source=None, Gallery=None, Format=None, PlotBy=None, CategoryLabels=None, SeriesLabels=None, HasLegend=None, Title=None, CategoryTitle=None, ValueTitle=None, ExtraTitle=None):
        """Alias for ChartWizard"""
        arguments = [Source, Gallery, Format, PlotBy, CategoryLabels, SeriesLabels, HasLegend, Title, CategoryTitle, ValueTitle, ExtraTitle]
        return self.ChartWizard(*arguments)

    def chart_wizard(self, Source=None, Gallery=None, Format=None, PlotBy=None, CategoryLabels=None, SeriesLabels=None, HasLegend=None, Title=None, CategoryTitle=None, ValueTitle=None, ExtraTitle=None):
        """Alias for ChartWizard"""
        arguments = [Source, Gallery, Format, PlotBy, CategoryLabels, SeriesLabels, HasLegend, Title, CategoryTitle, ValueTitle, ExtraTitle]
        return self.ChartWizard(*arguments)

    def ClearToMatchColorStyle(self):
        return self.com_object.ClearToMatchColorStyle()

    def cleartomatchcolorstyle(self):
        """Alias for ClearToMatchColorStyle"""
        return self.ClearToMatchColorStyle()

    def clear_to_match_color_style(self):
        """Alias for ClearToMatchColorStyle"""
        return self.ClearToMatchColorStyle()

    def ClearToMatchStyle(self):
        self.com_object.ClearToMatchStyle()

    def cleartomatchstyle(self):
        """Alias for ClearToMatchStyle"""
        return self.ClearToMatchStyle()

    def clear_to_match_style(self):
        """Alias for ClearToMatchStyle"""
        return self.ClearToMatchStyle()

    def Copy(self, Before=None, After=None):
        arguments = com_arguments([unwrap(a) for a in [Before, After]])
        self.com_object.Copy(*arguments)

    def copy(self, Before=None, After=None):
        """Alias for Copy"""
        arguments = [Before, After]
        return self.Copy(*arguments)

    def CopyPicture(self, Appearance=None, Format=None, Size=None):
        arguments = com_arguments([unwrap(a) for a in [Appearance, Format, Size]])
        self.com_object.CopyPicture(*arguments)

    def copypicture(self, Appearance=None, Format=None, Size=None):
        """Alias for CopyPicture"""
        arguments = [Appearance, Format, Size]
        return self.CopyPicture(*arguments)

    def copy_picture(self, Appearance=None, Format=None, Size=None):
        """Alias for CopyPicture"""
        arguments = [Appearance, Format, Size]
        return self.CopyPicture(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Export(self, FileName=None, FilterName=None, Interactive=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, FilterName, Interactive]])
        return self.com_object.Export(*arguments)

    def export(self, FileName=None, FilterName=None, Interactive=None):
        """Alias for Export"""
        arguments = [FileName, FilterName, Interactive]
        return self.Export(*arguments)

    def FullSeriesCollection(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.FullSeriesCollection(*arguments)

    def fullseriescollection(self, Index=None):
        """Alias for FullSeriesCollection"""
        arguments = [Index]
        return self.FullSeriesCollection(*arguments)

    def full_series_collection(self, Index=None):
        """Alias for FullSeriesCollection"""
        arguments = [Index]
        return self.FullSeriesCollection(*arguments)

    def GetChartElement(self, x=None, y=None, ElementID=None, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [x, y, ElementID, Arg1, Arg2]])
        self.com_object.GetChartElement(*arguments)

    def getchartelement(self, x=None, y=None, ElementID=None, Arg1=None, Arg2=None):
        """Alias for GetChartElement"""
        arguments = [x, y, ElementID, Arg1, Arg2]
        return self.GetChartElement(*arguments)

    def get_chart_element(self, x=None, y=None, ElementID=None, Arg1=None, Arg2=None):
        """Alias for GetChartElement"""
        arguments = [x, y, ElementID, Arg1, Arg2]
        return self.GetChartElement(*arguments)

    def Paste(self, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Type]])
        self.com_object.Paste(*arguments)

    def paste(self, Type=None):
        """Alias for Paste"""
        arguments = [Type]
        return self.Paste(*arguments)

    def Refresh(self):
        self.com_object.Refresh()

    def refresh(self):
        """Alias for Refresh"""
        return self.Refresh()

    def SaveChartTemplate(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        self.com_object.SaveChartTemplate(*arguments)

    def savecharttemplate(self, FileName=None):
        """Alias for SaveChartTemplate"""
        arguments = [FileName]
        return self.SaveChartTemplate(*arguments)

    def save_chart_template(self, FileName=None):
        """Alias for SaveChartTemplate"""
        arguments = [FileName]
        return self.SaveChartTemplate(*arguments)

    def Select(self, Replace=None):
        arguments = com_arguments([unwrap(a) for a in [Replace]])
        self.com_object.Select(*arguments)

    def select(self, Replace=None):
        """Alias for Select"""
        arguments = [Replace]
        return self.Select(*arguments)

    def SeriesCollection(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return SeriesCollection(self.com_object.SeriesCollection(*arguments))

    def seriescollection(self, Index=None):
        """Alias for SeriesCollection"""
        arguments = [Index]
        return self.SeriesCollection(*arguments)

    def series_collection(self, Index=None):
        """Alias for SeriesCollection"""
        arguments = [Index]
        return self.SeriesCollection(*arguments)

    def SetBackgroundPicture(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        self.com_object.SetBackgroundPicture(*arguments)

    def setbackgroundpicture(self, FileName=None):
        """Alias for SetBackgroundPicture"""
        arguments = [FileName]
        return self.SetBackgroundPicture(*arguments)

    def set_background_picture(self, FileName=None):
        """Alias for SetBackgroundPicture"""
        arguments = [FileName]
        return self.SetBackgroundPicture(*arguments)

    def SetDefaultChart(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        self.com_object.SetDefaultChart(*arguments)

    def setdefaultchart(self, Name=None):
        """Alias for SetDefaultChart"""
        arguments = [Name]
        return self.SetDefaultChart(*arguments)

    def set_default_chart(self, Name=None):
        """Alias for SetDefaultChart"""
        arguments = [Name]
        return self.SetDefaultChart(*arguments)

    def SetElement(self, Element=None):
        arguments = com_arguments([unwrap(a) for a in [Element]])
        self.com_object.SetElement(*arguments)

    def setelement(self, Element=None):
        """Alias for SetElement"""
        arguments = [Element]
        return self.SetElement(*arguments)

    def set_element(self, Element=None):
        """Alias for SetElement"""
        arguments = [Element]
        return self.SetElement(*arguments)

    def SetSourceData(self, Source=None, PlotBy=None):
        arguments = com_arguments([unwrap(a) for a in [Source, PlotBy]])
        self.com_object.SetSourceData(*arguments)

    def setsourcedata(self, Source=None, PlotBy=None):
        """Alias for SetSourceData"""
        arguments = [Source, PlotBy]
        return self.SetSourceData(*arguments)

    def set_source_data(self, Source=None, PlotBy=None):
        """Alias for SetSourceData"""
        arguments = [Source, PlotBy]
        return self.SetSourceData(*arguments)


class ChartArea:

    def __init__(self, chartarea=None):
        self.com_object= chartarea

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Clear(self):
        self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()

    def ClearContents(self):
        self.com_object.ClearContents()

    def clearcontents(self):
        """Alias for ClearContents"""
        return self.ClearContents()

    def clear_contents(self):
        """Alias for ClearContents"""
        return self.ClearContents()

    def ClearFormats(self):
        self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class ChartBorder:

    def __init__(self, chartborder=None):
        self.com_object= chartborder

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Color(self):
        return self.com_object.Color

    @Color.setter
    def Color(self, value):
        self.com_object.Color = value

    @property
    def color(self):
        """Alias for Color"""
        return self.Color

    @color.setter
    def color(self, value):
        """Alias for Color.setter"""
        self.Color = value

    @property
    def ColorIndex(self):
        return self.com_object.ColorIndex

    @ColorIndex.setter
    def ColorIndex(self, value):
        self.com_object.ColorIndex = value

    @property
    def colorindex(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @colorindex.setter
    def colorindex(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def color_index(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @color_index.setter
    def color_index(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def LineStyle(self):
        return XlLineStyle(self.com_object.LineStyle)

    @LineStyle.setter
    def LineStyle(self, value):
        self.com_object.LineStyle = value

    @property
    def linestyle(self):
        """Alias for LineStyle"""
        return self.LineStyle

    @linestyle.setter
    def linestyle(self, value):
        """Alias for LineStyle.setter"""
        self.LineStyle = value

    @property
    def line_style(self):
        """Alias for LineStyle"""
        return self.LineStyle

    @line_style.setter
    def line_style(self, value):
        """Alias for LineStyle.setter"""
        self.LineStyle = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Weight(self):
        return XlBorderWeight(self.com_object.Weight)

    @Weight.setter
    def Weight(self, value):
        self.com_object.Weight = value

    @property
    def weight(self):
        """Alias for Weight"""
        return self.Weight

    @weight.setter
    def weight(self, value):
        """Alias for Weight.setter"""
        self.Weight = value


class ChartCategory:

    def __init__(self, chartcategory=None):
        self.com_object= chartcategory

    @property
    def IsFiltered(self):
        return self.com_object.IsFiltered

    @IsFiltered.setter
    def IsFiltered(self, value):
        self.com_object.IsFiltered = value

    @property
    def isfiltered(self):
        """Alias for IsFiltered"""
        return self.IsFiltered

    @isfiltered.setter
    def isfiltered(self, value):
        """Alias for IsFiltered.setter"""
        self.IsFiltered = value

    @property
    def is_filtered(self):
        """Alias for IsFiltered"""
        return self.IsFiltered

    @is_filtered.setter
    def is_filtered(self, value):
        """Alias for IsFiltered.setter"""
        self.IsFiltered = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class ChartCharacters:

    def __init__(self, chartcharacters=None):
        self.com_object= chartcharacters

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Caption(self):
        return self.com_object.Caption

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Font(self):
        return ChartFont(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PhoneticCharacters(self):
        return self.com_object.PhoneticCharacters

    @PhoneticCharacters.setter
    def PhoneticCharacters(self, value):
        self.com_object.PhoneticCharacters = value

    @property
    def phoneticcharacters(self):
        """Alias for PhoneticCharacters"""
        return self.PhoneticCharacters

    @phoneticcharacters.setter
    def phoneticcharacters(self, value):
        """Alias for PhoneticCharacters.setter"""
        self.PhoneticCharacters = value

    @property
    def phonetic_characters(self):
        """Alias for PhoneticCharacters"""
        return self.PhoneticCharacters

    @phonetic_characters.setter
    def phonetic_characters(self, value):
        """Alias for PhoneticCharacters.setter"""
        self.PhoneticCharacters = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Insert(self, String=None):
        arguments = com_arguments([unwrap(a) for a in [String]])
        self.com_object.Insert(*arguments)

    def insert(self, String=None):
        """Alias for Insert"""
        arguments = [String]
        return self.Insert(*arguments)


class ChartColorFormat:

    def __init__(self, chartcolorformat=None):
        self.com_object= chartcolorformat

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RGB(self):
        return self.com_object.RGB

    @property
    def rgb(self):
        """Alias for RGB"""
        return self.RGB

    @property
    def r_g_b(self):
        """Alias for RGB"""
        return self.RGB

    @property
    def SchemeColor(self):
        return self.com_object.SchemeColor

    @SchemeColor.setter
    def SchemeColor(self, value):
        self.com_object.SchemeColor = value

    @property
    def schemecolor(self):
        """Alias for SchemeColor"""
        return self.SchemeColor

    @schemecolor.setter
    def schemecolor(self, value):
        """Alias for SchemeColor.setter"""
        self.SchemeColor = value

    @property
    def scheme_color(self):
        """Alias for SchemeColor"""
        return self.SchemeColor

    @scheme_color.setter
    def scheme_color(self, value):
        """Alias for SchemeColor.setter"""
        self.SchemeColor = value

    @property
    def Type(self):
        return self.com_object.Type

    @property
    def type(self):
        """Alias for Type"""
        return self.Type


class ChartData:

    def __init__(self, chartdata=None):
        self.com_object= chartdata

    @property
    def IsLinked(self):
        return self.com_object.IsLinked

    @property
    def islinked(self):
        """Alias for IsLinked"""
        return self.IsLinked

    @property
    def is_linked(self):
        """Alias for IsLinked"""
        return self.IsLinked

    @property
    def Workbook(self):
        return self.com_object.Workbook

    @property
    def workbook(self):
        """Alias for Workbook"""
        return self.Workbook

    def Activate(self):
        self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()

    def ActivateChartDataWindow(self):
        return self.com_object.ActivateChartDataWindow()

    def activatechartdatawindow(self):
        """Alias for ActivateChartDataWindow"""
        return self.ActivateChartDataWindow()

    def activate_chart_data_window(self):
        """Alias for ActivateChartDataWindow"""
        return self.ActivateChartDataWindow()

    def BreakLink(self):
        self.com_object.BreakLink()

    def breaklink(self):
        """Alias for BreakLink"""
        return self.BreakLink()

    def break_link(self):
        """Alias for BreakLink"""
        return self.BreakLink()


class ChartFont:

    def __init__(self, chartfont=None):
        self.com_object= chartfont

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Background(self):
        return XlBackground(self.com_object.Background)

    @Background.setter
    def Background(self, value):
        self.com_object.Background = value

    @property
    def background(self):
        """Alias for Background"""
        return self.Background

    @background.setter
    def background(self, value):
        """Alias for Background.setter"""
        self.Background = value

    @property
    def Bold(self):
        return self.com_object.Bold

    @Bold.setter
    def Bold(self, value):
        self.com_object.Bold = value

    @property
    def bold(self):
        """Alias for Bold"""
        return self.Bold

    @bold.setter
    def bold(self, value):
        """Alias for Bold.setter"""
        self.Bold = value

    @property
    def Color(self):
        return self.com_object.Color

    @Color.setter
    def Color(self, value):
        self.com_object.Color = value

    @property
    def color(self):
        """Alias for Color"""
        return self.Color

    @color.setter
    def color(self, value):
        """Alias for Color.setter"""
        self.Color = value

    @property
    def ColorIndex(self):
        return self.com_object.ColorIndex

    @ColorIndex.setter
    def ColorIndex(self, value):
        self.com_object.ColorIndex = value

    @property
    def colorindex(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @colorindex.setter
    def colorindex(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def color_index(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @color_index.setter
    def color_index(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def FontStyle(self):
        return self.com_object.FontStyle

    @FontStyle.setter
    def FontStyle(self, value):
        self.com_object.FontStyle = value

    @property
    def fontstyle(self):
        """Alias for FontStyle"""
        return self.FontStyle

    @fontstyle.setter
    def fontstyle(self, value):
        """Alias for FontStyle.setter"""
        self.FontStyle = value

    @property
    def font_style(self):
        """Alias for FontStyle"""
        return self.FontStyle

    @font_style.setter
    def font_style(self, value):
        """Alias for FontStyle.setter"""
        self.FontStyle = value

    @property
    def Italic(self):
        return self.com_object.Italic

    @Italic.setter
    def Italic(self, value):
        self.com_object.Italic = value

    @property
    def italic(self):
        """Alias for Italic"""
        return self.Italic

    @italic.setter
    def italic(self, value):
        """Alias for Italic.setter"""
        self.Italic = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Size(self):
        return self.com_object.Size

    @Size.setter
    def Size(self, value):
        self.com_object.Size = value

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @size.setter
    def size(self, value):
        """Alias for Size.setter"""
        self.Size = value

    @property
    def StrikeThrough(self):
        return self.com_object.StrikeThrough

    @StrikeThrough.setter
    def StrikeThrough(self, value):
        self.com_object.StrikeThrough = value

    @property
    def strikethrough(self):
        """Alias for StrikeThrough"""
        return self.StrikeThrough

    @strikethrough.setter
    def strikethrough(self, value):
        """Alias for StrikeThrough.setter"""
        self.StrikeThrough = value

    @property
    def strike_through(self):
        """Alias for StrikeThrough"""
        return self.StrikeThrough

    @strike_through.setter
    def strike_through(self, value):
        """Alias for StrikeThrough.setter"""
        self.StrikeThrough = value

    @property
    def Subscript(self):
        return self.com_object.Subscript

    @Subscript.setter
    def Subscript(self, value):
        self.com_object.Subscript = value

    @property
    def subscript(self):
        """Alias for Subscript"""
        return self.Subscript

    @subscript.setter
    def subscript(self, value):
        """Alias for Subscript.setter"""
        self.Subscript = value

    @property
    def Superscript(self):
        return self.com_object.Superscript

    @Superscript.setter
    def Superscript(self, value):
        self.com_object.Superscript = value

    @property
    def superscript(self):
        """Alias for Superscript"""
        return self.Superscript

    @superscript.setter
    def superscript(self, value):
        """Alias for Superscript.setter"""
        self.Superscript = value

    @property
    def Underline(self):
        return XlUnderlineStyle(self.com_object.Underline)

    @Underline.setter
    def Underline(self, value):
        self.com_object.Underline = value

    @property
    def underline(self):
        """Alias for Underline"""
        return self.Underline

    @underline.setter
    def underline(self, value):
        """Alias for Underline.setter"""
        self.Underline = value


class ChartFormat:

    def __init__(self, chartformat=None):
        self.com_object= chartformat

    @property
    def Adjustments(self):
        return self.com_object.Adjustments

    @property
    def adjustments(self):
        """Alias for Adjustments"""
        return self.Adjustments

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoShapeType(self):
        return self.com_object.AutoShapeType

    @AutoShapeType.setter
    def AutoShapeType(self, value):
        self.com_object.AutoShapeType = value

    @property
    def autoshapetype(self):
        """Alias for AutoShapeType"""
        return self.AutoShapeType

    @autoshapetype.setter
    def autoshapetype(self, value):
        """Alias for AutoShapeType.setter"""
        self.AutoShapeType = value

    @property
    def auto_shape_type(self):
        """Alias for AutoShapeType"""
        return self.AutoShapeType

    @auto_shape_type.setter
    def auto_shape_type(self, value):
        """Alias for AutoShapeType.setter"""
        self.AutoShapeType = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Fill(self):
        return FillFormat(self.com_object.Fill)

    @property
    def fill(self):
        """Alias for Fill"""
        return self.Fill

    @property
    def Glow(self):
        return GlowFormat(self.com_object.Glow)

    @property
    def glow(self):
        """Alias for Glow"""
        return self.Glow

    @property
    def Line(self):
        return LineFormat(self.com_object.Line)

    @property
    def line(self):
        """Alias for Line"""
        return self.Line

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PictureFormat(self):
        return PictureFormat(self.com_object.PictureFormat)

    @property
    def pictureformat(self):
        """Alias for PictureFormat"""
        return self.PictureFormat

    @property
    def picture_format(self):
        """Alias for PictureFormat"""
        return self.PictureFormat

    @property
    def Shadow(self):
        return ShadowFormat(self.com_object.Shadow)

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @property
    def SoftEdge(self):
        return SoftEdgeFormat(self.com_object.SoftEdge)

    @property
    def softedge(self):
        """Alias for SoftEdge"""
        return self.SoftEdge

    @property
    def soft_edge(self):
        """Alias for SoftEdge"""
        return self.SoftEdge

    @property
    def TextFrame2(self):
        return self.com_object.TextFrame2

    @property
    def textframe2(self):
        """Alias for TextFrame2"""
        return self.TextFrame2

    @property
    def text_frame2(self):
        """Alias for TextFrame2"""
        return self.TextFrame2

    @property
    def ThreeD(self):
        return ThreeDFormat(self.com_object.ThreeD)

    @property
    def threed(self):
        """Alias for ThreeD"""
        return self.ThreeD

    @property
    def three_d(self):
        """Alias for ThreeD"""
        return self.ThreeD


class ChartGroup:

    def __init__(self, chartgroup=None):
        self.com_object= chartgroup

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AxisGroup(self):
        return XlAxisGroup(self.com_object.AxisGroup)

    @AxisGroup.setter
    def AxisGroup(self, value):
        self.com_object.AxisGroup = value

    @property
    def axisgroup(self):
        """Alias for AxisGroup"""
        return self.AxisGroup

    @axisgroup.setter
    def axisgroup(self, value):
        """Alias for AxisGroup.setter"""
        self.AxisGroup = value

    @property
    def axis_group(self):
        """Alias for AxisGroup"""
        return self.AxisGroup

    @axis_group.setter
    def axis_group(self, value):
        """Alias for AxisGroup.setter"""
        self.AxisGroup = value

    @property
    def BinsCountValue(self):
        return self.com_object.BinsCountValue

    @BinsCountValue.setter
    def BinsCountValue(self, value):
        self.com_object.BinsCountValue = value

    @property
    def binscountvalue(self):
        """Alias for BinsCountValue"""
        return self.BinsCountValue

    @binscountvalue.setter
    def binscountvalue(self, value):
        """Alias for BinsCountValue.setter"""
        self.BinsCountValue = value

    @property
    def bins_count_value(self):
        """Alias for BinsCountValue"""
        return self.BinsCountValue

    @bins_count_value.setter
    def bins_count_value(self, value):
        """Alias for BinsCountValue.setter"""
        self.BinsCountValue = value

    @property
    def BinsOverflowEnabled(self):
        return self.com_object.BinsOverflowEnabled

    @BinsOverflowEnabled.setter
    def BinsOverflowEnabled(self, value):
        self.com_object.BinsOverflowEnabled = value

    @property
    def binsoverflowenabled(self):
        """Alias for BinsOverflowEnabled"""
        return self.BinsOverflowEnabled

    @binsoverflowenabled.setter
    def binsoverflowenabled(self, value):
        """Alias for BinsOverflowEnabled.setter"""
        self.BinsOverflowEnabled = value

    @property
    def bins_overflow_enabled(self):
        """Alias for BinsOverflowEnabled"""
        return self.BinsOverflowEnabled

    @bins_overflow_enabled.setter
    def bins_overflow_enabled(self, value):
        """Alias for BinsOverflowEnabled.setter"""
        self.BinsOverflowEnabled = value

    @property
    def BinsOverflowValue(self):
        return self.com_object.BinsOverflowValue

    @BinsOverflowValue.setter
    def BinsOverflowValue(self, value):
        self.com_object.BinsOverflowValue = value

    @property
    def binsoverflowvalue(self):
        """Alias for BinsOverflowValue"""
        return self.BinsOverflowValue

    @binsoverflowvalue.setter
    def binsoverflowvalue(self, value):
        """Alias for BinsOverflowValue.setter"""
        self.BinsOverflowValue = value

    @property
    def bins_overflow_value(self):
        """Alias for BinsOverflowValue"""
        return self.BinsOverflowValue

    @bins_overflow_value.setter
    def bins_overflow_value(self, value):
        """Alias for BinsOverflowValue.setter"""
        self.BinsOverflowValue = value

    @property
    def BinsType(self):
        return self.com_object.BinsType

    @BinsType.setter
    def BinsType(self, value):
        self.com_object.BinsType = value

    @property
    def binstype(self):
        """Alias for BinsType"""
        return self.BinsType

    @binstype.setter
    def binstype(self, value):
        """Alias for BinsType.setter"""
        self.BinsType = value

    @property
    def bins_type(self):
        """Alias for BinsType"""
        return self.BinsType

    @bins_type.setter
    def bins_type(self, value):
        """Alias for BinsType.setter"""
        self.BinsType = value

    @property
    def BinsUnderflowEnabled(self):
        return self.com_object.BinsUnderflowEnabled

    @BinsUnderflowEnabled.setter
    def BinsUnderflowEnabled(self, value):
        self.com_object.BinsUnderflowEnabled = value

    @property
    def binsunderflowenabled(self):
        """Alias for BinsUnderflowEnabled"""
        return self.BinsUnderflowEnabled

    @binsunderflowenabled.setter
    def binsunderflowenabled(self, value):
        """Alias for BinsUnderflowEnabled.setter"""
        self.BinsUnderflowEnabled = value

    @property
    def bins_underflow_enabled(self):
        """Alias for BinsUnderflowEnabled"""
        return self.BinsUnderflowEnabled

    @bins_underflow_enabled.setter
    def bins_underflow_enabled(self, value):
        """Alias for BinsUnderflowEnabled.setter"""
        self.BinsUnderflowEnabled = value

    @property
    def BinsUnderflowValue(self):
        return self.com_object.BinsUnderflowValue

    @BinsUnderflowValue.setter
    def BinsUnderflowValue(self, value):
        self.com_object.BinsUnderflowValue = value

    @property
    def binsunderflowvalue(self):
        """Alias for BinsUnderflowValue"""
        return self.BinsUnderflowValue

    @binsunderflowvalue.setter
    def binsunderflowvalue(self, value):
        """Alias for BinsUnderflowValue.setter"""
        self.BinsUnderflowValue = value

    @property
    def bins_underflow_value(self):
        """Alias for BinsUnderflowValue"""
        return self.BinsUnderflowValue

    @bins_underflow_value.setter
    def bins_underflow_value(self, value):
        """Alias for BinsUnderflowValue.setter"""
        self.BinsUnderflowValue = value

    @property
    def BinWidthValue(self):
        return self.com_object.BinWidthValue

    @BinWidthValue.setter
    def BinWidthValue(self, value):
        self.com_object.BinWidthValue = value

    @property
    def binwidthvalue(self):
        """Alias for BinWidthValue"""
        return self.BinWidthValue

    @binwidthvalue.setter
    def binwidthvalue(self, value):
        """Alias for BinWidthValue.setter"""
        self.BinWidthValue = value

    @property
    def bin_width_value(self):
        """Alias for BinWidthValue"""
        return self.BinWidthValue

    @bin_width_value.setter
    def bin_width_value(self, value):
        """Alias for BinWidthValue.setter"""
        self.BinWidthValue = value

    @property
    def BubbleScale(self):
        return self.com_object.BubbleScale

    @BubbleScale.setter
    def BubbleScale(self, value):
        self.com_object.BubbleScale = value

    @property
    def bubblescale(self):
        """Alias for BubbleScale"""
        return self.BubbleScale

    @bubblescale.setter
    def bubblescale(self, value):
        """Alias for BubbleScale.setter"""
        self.BubbleScale = value

    @property
    def bubble_scale(self):
        """Alias for BubbleScale"""
        return self.BubbleScale

    @bubble_scale.setter
    def bubble_scale(self, value):
        """Alias for BubbleScale.setter"""
        self.BubbleScale = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DoughnutHoleSize(self):
        return self.com_object.DoughnutHoleSize

    @DoughnutHoleSize.setter
    def DoughnutHoleSize(self, value):
        self.com_object.DoughnutHoleSize = value

    @property
    def doughnutholesize(self):
        """Alias for DoughnutHoleSize"""
        return self.DoughnutHoleSize

    @doughnutholesize.setter
    def doughnutholesize(self, value):
        """Alias for DoughnutHoleSize.setter"""
        self.DoughnutHoleSize = value

    @property
    def doughnut_hole_size(self):
        """Alias for DoughnutHoleSize"""
        return self.DoughnutHoleSize

    @doughnut_hole_size.setter
    def doughnut_hole_size(self, value):
        """Alias for DoughnutHoleSize.setter"""
        self.DoughnutHoleSize = value

    @property
    def DownBars(self):
        return DownBars(self.com_object.DownBars)

    @property
    def downbars(self):
        """Alias for DownBars"""
        return self.DownBars

    @property
    def down_bars(self):
        """Alias for DownBars"""
        return self.DownBars

    @property
    def DropLines(self):
        return DropLines(self.com_object.DropLines)

    @property
    def droplines(self):
        """Alias for DropLines"""
        return self.DropLines

    @property
    def drop_lines(self):
        """Alias for DropLines"""
        return self.DropLines

    @property
    def FirstSliceAngle(self):
        return self.com_object.FirstSliceAngle

    @FirstSliceAngle.setter
    def FirstSliceAngle(self, value):
        self.com_object.FirstSliceAngle = value

    @property
    def firstsliceangle(self):
        """Alias for FirstSliceAngle"""
        return self.FirstSliceAngle

    @firstsliceangle.setter
    def firstsliceangle(self, value):
        """Alias for FirstSliceAngle.setter"""
        self.FirstSliceAngle = value

    @property
    def first_slice_angle(self):
        """Alias for FirstSliceAngle"""
        return self.FirstSliceAngle

    @first_slice_angle.setter
    def first_slice_angle(self, value):
        """Alias for FirstSliceAngle.setter"""
        self.FirstSliceAngle = value

    @property
    def GapWidth(self):
        return self.com_object.GapWidth

    @GapWidth.setter
    def GapWidth(self, value):
        self.com_object.GapWidth = value

    @property
    def gapwidth(self):
        """Alias for GapWidth"""
        return self.GapWidth

    @gapwidth.setter
    def gapwidth(self, value):
        """Alias for GapWidth.setter"""
        self.GapWidth = value

    @property
    def gap_width(self):
        """Alias for GapWidth"""
        return self.GapWidth

    @gap_width.setter
    def gap_width(self, value):
        """Alias for GapWidth.setter"""
        self.GapWidth = value

    @property
    def Has3DShading(self):
        return self.com_object.Has3DShading

    @Has3DShading.setter
    def Has3DShading(self, value):
        self.com_object.Has3DShading = value

    @property
    def has3dshading(self):
        """Alias for Has3DShading"""
        return self.Has3DShading

    @has3dshading.setter
    def has3dshading(self, value):
        """Alias for Has3DShading.setter"""
        self.Has3DShading = value

    @property
    def has3_d_shading(self):
        """Alias for Has3DShading"""
        return self.Has3DShading

    @has3_d_shading.setter
    def has3_d_shading(self, value):
        """Alias for Has3DShading.setter"""
        self.Has3DShading = value

    @property
    def HasDropLines(self):
        return self.com_object.HasDropLines

    @HasDropLines.setter
    def HasDropLines(self, value):
        self.com_object.HasDropLines = value

    @property
    def hasdroplines(self):
        """Alias for HasDropLines"""
        return self.HasDropLines

    @hasdroplines.setter
    def hasdroplines(self, value):
        """Alias for HasDropLines.setter"""
        self.HasDropLines = value

    @property
    def has_drop_lines(self):
        """Alias for HasDropLines"""
        return self.HasDropLines

    @has_drop_lines.setter
    def has_drop_lines(self, value):
        """Alias for HasDropLines.setter"""
        self.HasDropLines = value

    @property
    def HasHiLoLines(self):
        return self.com_object.HasHiLoLines

    @HasHiLoLines.setter
    def HasHiLoLines(self, value):
        self.com_object.HasHiLoLines = value

    @property
    def hashilolines(self):
        """Alias for HasHiLoLines"""
        return self.HasHiLoLines

    @hashilolines.setter
    def hashilolines(self, value):
        """Alias for HasHiLoLines.setter"""
        self.HasHiLoLines = value

    @property
    def has_hi_lo_lines(self):
        """Alias for HasHiLoLines"""
        return self.HasHiLoLines

    @has_hi_lo_lines.setter
    def has_hi_lo_lines(self, value):
        """Alias for HasHiLoLines.setter"""
        self.HasHiLoLines = value

    @property
    def HasRadarAxisLabels(self):
        return self.com_object.HasRadarAxisLabels

    @HasRadarAxisLabels.setter
    def HasRadarAxisLabels(self, value):
        self.com_object.HasRadarAxisLabels = value

    @property
    def hasradaraxislabels(self):
        """Alias for HasRadarAxisLabels"""
        return self.HasRadarAxisLabels

    @hasradaraxislabels.setter
    def hasradaraxislabels(self, value):
        """Alias for HasRadarAxisLabels.setter"""
        self.HasRadarAxisLabels = value

    @property
    def has_radar_axis_labels(self):
        """Alias for HasRadarAxisLabels"""
        return self.HasRadarAxisLabels

    @has_radar_axis_labels.setter
    def has_radar_axis_labels(self, value):
        """Alias for HasRadarAxisLabels.setter"""
        self.HasRadarAxisLabels = value

    @property
    def HasSeriesLines(self):
        return self.com_object.HasSeriesLines

    @HasSeriesLines.setter
    def HasSeriesLines(self, value):
        self.com_object.HasSeriesLines = value

    @property
    def hasserieslines(self):
        """Alias for HasSeriesLines"""
        return self.HasSeriesLines

    @hasserieslines.setter
    def hasserieslines(self, value):
        """Alias for HasSeriesLines.setter"""
        self.HasSeriesLines = value

    @property
    def has_series_lines(self):
        """Alias for HasSeriesLines"""
        return self.HasSeriesLines

    @has_series_lines.setter
    def has_series_lines(self, value):
        """Alias for HasSeriesLines.setter"""
        self.HasSeriesLines = value

    @property
    def HasUpDownBars(self):
        return self.com_object.HasUpDownBars

    @HasUpDownBars.setter
    def HasUpDownBars(self, value):
        self.com_object.HasUpDownBars = value

    @property
    def hasupdownbars(self):
        """Alias for HasUpDownBars"""
        return self.HasUpDownBars

    @hasupdownbars.setter
    def hasupdownbars(self, value):
        """Alias for HasUpDownBars.setter"""
        self.HasUpDownBars = value

    @property
    def has_up_down_bars(self):
        """Alias for HasUpDownBars"""
        return self.HasUpDownBars

    @has_up_down_bars.setter
    def has_up_down_bars(self, value):
        """Alias for HasUpDownBars.setter"""
        self.HasUpDownBars = value

    @property
    def HiLoLines(self):
        return HiLoLines(self.com_object.HiLoLines)

    @property
    def hilolines(self):
        """Alias for HiLoLines"""
        return self.HiLoLines

    @property
    def hi_lo_lines(self):
        """Alias for HiLoLines"""
        return self.HiLoLines

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Overlap(self):
        return self.com_object.Overlap

    @Overlap.setter
    def Overlap(self, value):
        self.com_object.Overlap = value

    @property
    def overlap(self):
        """Alias for Overlap"""
        return self.Overlap

    @overlap.setter
    def overlap(self, value):
        """Alias for Overlap.setter"""
        self.Overlap = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RadarAxisLabels(self):
        return TickLabels(self.com_object.RadarAxisLabels)

    @property
    def radaraxislabels(self):
        """Alias for RadarAxisLabels"""
        return self.RadarAxisLabels

    @property
    def radar_axis_labels(self):
        """Alias for RadarAxisLabels"""
        return self.RadarAxisLabels

    @property
    def SecondPlotSize(self):
        return self.com_object.SecondPlotSize

    @SecondPlotSize.setter
    def SecondPlotSize(self, value):
        self.com_object.SecondPlotSize = value

    @property
    def secondplotsize(self):
        """Alias for SecondPlotSize"""
        return self.SecondPlotSize

    @secondplotsize.setter
    def secondplotsize(self, value):
        """Alias for SecondPlotSize.setter"""
        self.SecondPlotSize = value

    @property
    def second_plot_size(self):
        """Alias for SecondPlotSize"""
        return self.SecondPlotSize

    @second_plot_size.setter
    def second_plot_size(self, value):
        """Alias for SecondPlotSize.setter"""
        self.SecondPlotSize = value

    @property
    def SeriesLines(self):
        return SeriesLines(self.com_object.SeriesLines)

    @property
    def serieslines(self):
        """Alias for SeriesLines"""
        return self.SeriesLines

    @property
    def series_lines(self):
        """Alias for SeriesLines"""
        return self.SeriesLines

    @property
    def ShowNegativeBubbles(self):
        return self.com_object.ShowNegativeBubbles

    @ShowNegativeBubbles.setter
    def ShowNegativeBubbles(self, value):
        self.com_object.ShowNegativeBubbles = value

    @property
    def shownegativebubbles(self):
        """Alias for ShowNegativeBubbles"""
        return self.ShowNegativeBubbles

    @shownegativebubbles.setter
    def shownegativebubbles(self, value):
        """Alias for ShowNegativeBubbles.setter"""
        self.ShowNegativeBubbles = value

    @property
    def show_negative_bubbles(self):
        """Alias for ShowNegativeBubbles"""
        return self.ShowNegativeBubbles

    @show_negative_bubbles.setter
    def show_negative_bubbles(self, value):
        """Alias for ShowNegativeBubbles.setter"""
        self.ShowNegativeBubbles = value

    @property
    def SizeRepresents(self):
        return self.com_object.SizeRepresents

    @SizeRepresents.setter
    def SizeRepresents(self, value):
        self.com_object.SizeRepresents = value

    @property
    def sizerepresents(self):
        """Alias for SizeRepresents"""
        return self.SizeRepresents

    @sizerepresents.setter
    def sizerepresents(self, value):
        """Alias for SizeRepresents.setter"""
        self.SizeRepresents = value

    @property
    def size_represents(self):
        """Alias for SizeRepresents"""
        return self.SizeRepresents

    @size_represents.setter
    def size_represents(self, value):
        """Alias for SizeRepresents.setter"""
        self.SizeRepresents = value

    @property
    def SplitType(self):
        return XlChartSplitType(self.com_object.SplitType)

    @SplitType.setter
    def SplitType(self, value):
        self.com_object.SplitType = value

    @property
    def splittype(self):
        """Alias for SplitType"""
        return self.SplitType

    @splittype.setter
    def splittype(self, value):
        """Alias for SplitType.setter"""
        self.SplitType = value

    @property
    def split_type(self):
        """Alias for SplitType"""
        return self.SplitType

    @split_type.setter
    def split_type(self, value):
        """Alias for SplitType.setter"""
        self.SplitType = value

    @property
    def SplitValue(self):
        return self.com_object.SplitValue

    @SplitValue.setter
    def SplitValue(self, value):
        self.com_object.SplitValue = value

    @property
    def splitvalue(self):
        """Alias for SplitValue"""
        return self.SplitValue

    @splitvalue.setter
    def splitvalue(self, value):
        """Alias for SplitValue.setter"""
        self.SplitValue = value

    @property
    def split_value(self):
        """Alias for SplitValue"""
        return self.SplitValue

    @split_value.setter
    def split_value(self, value):
        """Alias for SplitValue.setter"""
        self.SplitValue = value

    @property
    def UpBars(self):
        return UpBars(self.com_object.UpBars)

    @property
    def upbars(self):
        """Alias for UpBars"""
        return self.UpBars

    @property
    def up_bars(self):
        """Alias for UpBars"""
        return self.UpBars

    @property
    def VaryByCategories(self):
        return self.com_object.VaryByCategories

    @VaryByCategories.setter
    def VaryByCategories(self, value):
        self.com_object.VaryByCategories = value

    @property
    def varybycategories(self):
        """Alias for VaryByCategories"""
        return self.VaryByCategories

    @varybycategories.setter
    def varybycategories(self, value):
        """Alias for VaryByCategories.setter"""
        self.VaryByCategories = value

    @property
    def vary_by_categories(self):
        """Alias for VaryByCategories"""
        return self.VaryByCategories

    @vary_by_categories.setter
    def vary_by_categories(self, value):
        """Alias for VaryByCategories.setter"""
        self.VaryByCategories = value

    def CategoryCollection(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.CategoryCollection(*arguments)

    def categorycollection(self, Index=None):
        """Alias for CategoryCollection"""
        arguments = [Index]
        return self.CategoryCollection(*arguments)

    def category_collection(self, Index=None):
        """Alias for CategoryCollection"""
        arguments = [Index]
        return self.CategoryCollection(*arguments)

    def FullCategoryCollection(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.FullCategoryCollection(*arguments)

    def fullcategorycollection(self, Index=None):
        """Alias for FullCategoryCollection"""
        arguments = [Index]
        return self.FullCategoryCollection(*arguments)

    def full_category_collection(self, Index=None):
        """Alias for FullCategoryCollection"""
        arguments = [Index]
        return self.FullCategoryCollection(*arguments)

    def SeriesCollection(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return SeriesCollection(self.com_object.SeriesCollection(*arguments))

    def seriescollection(self, Index=None):
        """Alias for SeriesCollection"""
        arguments = [Index]
        return self.SeriesCollection(*arguments)

    def series_collection(self, Index=None):
        """Alias for SeriesCollection"""
        arguments = [Index]
        return self.SeriesCollection(*arguments)


class ChartGroups:

    def __init__(self, chartgroups=None):
        self.com_object= chartgroups

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ChartGroup(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ChartTitle:

    def __init__(self, charttitle=None):
        self.com_object= charttitle

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    def Characters(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        if hasattr(self.com_object, "GetCharacters"):
            return ChartCharacters(self.com_object.GetCharacters(*arguments))
        else:
            return ChartCharacters(self.com_object.Characters(*arguments))

    def characters(self, Start=None, Length=None):
        """Alias for Characters"""
        arguments = [Start, Length]
        return self.Characters(*arguments)

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def FormulaLocal(self):
        return self.com_object.FormulaLocal

    @FormulaLocal.setter
    def FormulaLocal(self, value):
        self.com_object.FormulaLocal = value

    @property
    def formulalocal(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formulalocal.setter
    def formulalocal(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def formula_local(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formula_local.setter
    def formula_local(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def FormulaR1C1(self):
        return self.com_object.FormulaR1C1

    @FormulaR1C1.setter
    def FormulaR1C1(self, value):
        self.com_object.FormulaR1C1 = value

    @property
    def formular1c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formular1c1.setter
    def formular1c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def formula_r1_c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formula_r1_c1.setter
    def formula_r1_c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def FormulaR1C1Local(self):
        return self.com_object.FormulaR1C1Local

    @FormulaR1C1Local.setter
    def FormulaR1C1Local(self, value):
        self.com_object.FormulaR1C1Local = value

    @property
    def formular1c1local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formular1c1local.setter
    def formular1c1local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def formula_r1_c1_local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formula_r1_c1_local.setter
    def formula_r1_c1_local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def HorizontalAlignment(self):
        return self.com_object.HorizontalAlignment

    @HorizontalAlignment.setter
    def HorizontalAlignment(self, value):
        self.com_object.HorizontalAlignment = value

    @property
    def horizontalalignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontalalignment.setter
    def horizontalalignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def horizontal_alignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def IncludeInLayout(self):
        return self.com_object.IncludeInLayout

    @IncludeInLayout.setter
    def IncludeInLayout(self, value):
        self.com_object.IncludeInLayout = value

    @property
    def includeinlayout(self):
        """Alias for IncludeInLayout"""
        return self.IncludeInLayout

    @includeinlayout.setter
    def includeinlayout(self, value):
        """Alias for IncludeInLayout.setter"""
        self.IncludeInLayout = value

    @property
    def include_in_layout(self):
        """Alias for IncludeInLayout"""
        return self.IncludeInLayout

    @include_in_layout.setter
    def include_in_layout(self, value):
        """Alias for IncludeInLayout.setter"""
        self.IncludeInLayout = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return XlChartElementPosition(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def ReadingOrder(self):
        return XlReadingOrder(self.com_object.ReadingOrder)

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def VerticalAlignment(self):
        return self.com_object.VerticalAlignment

    @VerticalAlignment.setter
    def VerticalAlignment(self, value):
        self.com_object.VerticalAlignment = value

    @property
    def verticalalignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @verticalalignment.setter
    def verticalalignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def vertical_alignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @vertical_alignment.setter
    def vertical_alignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class CheckBox:

    def __init__(self, checkbox=None):
        self.com_object= checkbox

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoSize(self):
        return self.com_object.AutoSize

    @AutoSize.setter
    def AutoSize(self, value):
        self.com_object.AutoSize = value

    @property
    def autosize(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @autosize.setter
    def autosize(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def auto_size(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @auto_size.setter
    def auto_size(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Default(self):
        return self.com_object.Default

    @Default.setter
    def Default(self, value):
        self.com_object.Default = value

    @property
    def default(self):
        """Alias for Default"""
        return self.Default

    @default.setter
    def default(self, value):
        """Alias for Default.setter"""
        self.Default = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Size(self):
        return self.com_object.Size

    @Size.setter
    def Size(self, value):
        self.com_object.Size = value

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @size.setter
    def size(self, value):
        """Alias for Size.setter"""
        self.Size = value

    @property
    def Valid(self):
        return self.com_object.Valid

    @property
    def valid(self):
        """Alias for Valid"""
        return self.Valid

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value


class CoAuthLock:

    def __init__(self, coauthlock=None):
        self.com_object= coauthlock

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def HeaderFooter(self):
        return self.com_object.HeaderFooter

    @property
    def headerfooter(self):
        """Alias for HeaderFooter"""
        return self.HeaderFooter

    @property
    def header_footer(self):
        """Alias for HeaderFooter"""
        return self.HeaderFooter

    @property
    def Parent(self):
        return CoAuthLock(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return self.com_object.Range

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def Type(self):
        return self.com_object.Type

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def Owner(self):
        return CoAuthor(self.com_object.Owner)

    @property
    def owner(self):
        """Alias for Owner"""
        return self.Owner

    def Unlock(self):
        return self.com_object.Unlock()

    def unlock(self):
        """Alias for Unlock"""
        return self.Unlock()


class CoAuthLocks:

    def __init__(self, coauthlocks=None):
        self.com_object= coauthlocks

    def __call__(self, item):
        return CoAuthLock(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return CoAuthLocks(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return CoAuthLocks(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Range=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Range, Type]])
        return CoAuthLock(self.com_object.Add(*arguments))

    def add(self, Range=None, Type=None):
        """Alias for Add"""
        arguments = [Range, Type]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return CoAuthLock(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def RemoveEphemeralLocks(self):
        return self.com_object.RemoveEphemeralLocks()

    def removeephemerallocks(self):
        """Alias for RemoveEphemeralLocks"""
        return self.RemoveEphemeralLocks()

    def remove_ephemeral_locks(self):
        """Alias for RemoveEphemeralLocks"""
        return self.RemoveEphemeralLocks()


class CoAuthor:

    def __init__(self, coauthor=None):
        self.com_object= coauthor

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def EmailAddress(self):
        return self.com_object.EmailAddress

    @property
    def emailaddress(self):
        """Alias for EmailAddress"""
        return self.EmailAddress

    @property
    def email_address(self):
        """Alias for EmailAddress"""
        return self.EmailAddress

    @property
    def ID(self):
        return self.com_object.ID

    @property
    def id(self):
        """Alias for ID"""
        return self.ID

    @property
    def i_d(self):
        """Alias for ID"""
        return self.ID

    @property
    def IsMe(self):
        return self.com_object.IsMe

    @property
    def isme(self):
        """Alias for IsMe"""
        return self.IsMe

    @property
    def is_me(self):
        """Alias for IsMe"""
        return self.IsMe

    @property
    def Locks(self):
        return self.com_object.Locks

    @property
    def locks(self):
        """Alias for Locks"""
        return self.Locks

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class CoAuthoring:

    def __init__(self, coauthoring=None):
        self.com_object= coauthoring

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Authors(self):
        return CoAuthors(self.com_object.Authors)

    @property
    def authors(self):
        """Alias for Authors"""
        return self.Authors

    @property
    def CanMerge(self):
        return self.com_object.CanMerge

    @property
    def canmerge(self):
        """Alias for CanMerge"""
        return self.CanMerge

    @property
    def can_merge(self):
        """Alias for CanMerge"""
        return self.CanMerge

    @property
    def CanShare(self):
        return self.com_object.CanShare

    @property
    def canshare(self):
        """Alias for CanShare"""
        return self.CanShare

    @property
    def can_share(self):
        """Alias for CanShare"""
        return self.CanShare

    @property
    def Conflicts(self):
        return Conflicts(self.com_object.Conflicts)

    @property
    def conflicts(self):
        """Alias for Conflicts"""
        return self.Conflicts

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Locks(self):
        return CoAuthLocks(self.com_object.Locks)

    @property
    def locks(self):
        """Alias for Locks"""
        return self.Locks

    @property
    def Me(self):
        return CoAuthor(self.com_object.Me)

    @property
    def me(self):
        """Alias for Me"""
        return self.Me

    @property
    def Parent(self):
        return CoAuthoring(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PendingUpdates(self):
        return self.com_object.PendingUpdates

    @property
    def pendingupdates(self):
        """Alias for PendingUpdates"""
        return self.PendingUpdates

    @property
    def pending_updates(self):
        """Alias for PendingUpdates"""
        return self.PendingUpdates

    @property
    def Updates(self):
        return CoAuthUpdates(self.com_object.Updates)

    @property
    def updates(self):
        """Alias for Updates"""
        return self.Updates


class CoAuthors:

    def __init__(self, coauthors=None):
        self.com_object= coauthors

    def __call__(self, item):
        return CoAuthor(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return CoAuthor(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class CoAuthUpdate:

    def __init__(self, coauthupdate=None):
        self.com_object= coauthupdate

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return self.com_object.Range

    @property
    def range(self):
        """Alias for Range"""
        return self.Range


class CoAuthUpdates:

    def __init__(self, coauthupdates=None):
        self.com_object= coauthupdates

    def __call__(self, item):
        return CoAuthUpdate(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return CoAuthUpdate(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ColorFormat:

    def __init__(self, colorformat=None):
        self.com_object= colorformat

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Brightness(self):
        return self.com_object.Brightness

    @Brightness.setter
    def Brightness(self, value):
        self.com_object.Brightness = value

    @property
    def brightness(self):
        """Alias for Brightness"""
        return self.Brightness

    @brightness.setter
    def brightness(self, value):
        """Alias for Brightness.setter"""
        self.Brightness = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ObjectThemeColor(self):
        return WdThemeColorIndex(self.com_object.ObjectThemeColor)

    @ObjectThemeColor.setter
    def ObjectThemeColor(self, value):
        self.com_object.ObjectThemeColor = value

    @property
    def objectthemecolor(self):
        """Alias for ObjectThemeColor"""
        return self.ObjectThemeColor

    @objectthemecolor.setter
    def objectthemecolor(self, value):
        """Alias for ObjectThemeColor.setter"""
        self.ObjectThemeColor = value

    @property
    def object_theme_color(self):
        """Alias for ObjectThemeColor"""
        return self.ObjectThemeColor

    @object_theme_color.setter
    def object_theme_color(self, value):
        """Alias for ObjectThemeColor.setter"""
        self.ObjectThemeColor = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RGB(self):
        return self.com_object.RGB

    @RGB.setter
    def RGB(self, value):
        self.com_object.RGB = value

    @property
    def rgb(self):
        """Alias for RGB"""
        return self.RGB

    @rgb.setter
    def rgb(self, value):
        """Alias for RGB.setter"""
        self.RGB = value

    @property
    def r_g_b(self):
        """Alias for RGB"""
        return self.RGB

    @r_g_b.setter
    def r_g_b(self, value):
        """Alias for RGB.setter"""
        self.RGB = value

    @property
    def TintAndShade(self):
        return self.com_object.TintAndShade

    @TintAndShade.setter
    def TintAndShade(self, value):
        self.com_object.TintAndShade = value

    @property
    def tintandshade(self):
        """Alias for TintAndShade"""
        return self.TintAndShade

    @tintandshade.setter
    def tintandshade(self, value):
        """Alias for TintAndShade.setter"""
        self.TintAndShade = value

    @property
    def tint_and_shade(self):
        """Alias for TintAndShade"""
        return self.TintAndShade

    @tint_and_shade.setter
    def tint_and_shade(self, value):
        """Alias for TintAndShade.setter"""
        self.TintAndShade = value

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value


class Column:

    def __init__(self, column=None):
        self.com_object= column

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    def Cells(self, RowIndex=None, ColumnIndex=None):
        arguments = com_arguments([unwrap(a) for a in [RowIndex, ColumnIndex]])
        if hasattr(self.com_object, "GetCells"):
            return Cells(self.com_object.GetCells(*arguments))
        else:
            return Cells(self.com_object.Cells(*arguments))

    def cells(self, RowIndex=None, ColumnIndex=None):
        """Alias for Cells"""
        arguments = [RowIndex, ColumnIndex]
        return self.Cells(*arguments)

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def IsFirst(self):
        return self.com_object.IsFirst

    @property
    def isfirst(self):
        """Alias for IsFirst"""
        return self.IsFirst

    @property
    def is_first(self):
        """Alias for IsFirst"""
        return self.IsFirst

    @property
    def IsLast(self):
        return self.com_object.IsLast

    @property
    def islast(self):
        """Alias for IsLast"""
        return self.IsLast

    @property
    def is_last(self):
        """Alias for IsLast"""
        return self.IsLast

    @property
    def NestingLevel(self):
        return self.com_object.NestingLevel

    @property
    def nestinglevel(self):
        """Alias for NestingLevel"""
        return self.NestingLevel

    @property
    def nesting_level(self):
        """Alias for NestingLevel"""
        return self.NestingLevel

    @property
    def Next(self):
        return self.com_object.Next

    @property
    def next(self):
        """Alias for Next"""
        return self.Next

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PreferredWidth(self):
        return self.com_object.PreferredWidth

    @PreferredWidth.setter
    def PreferredWidth(self, value):
        self.com_object.PreferredWidth = value

    @property
    def preferredwidth(self):
        """Alias for PreferredWidth"""
        return self.PreferredWidth

    @preferredwidth.setter
    def preferredwidth(self, value):
        """Alias for PreferredWidth.setter"""
        self.PreferredWidth = value

    @property
    def preferred_width(self):
        """Alias for PreferredWidth"""
        return self.PreferredWidth

    @preferred_width.setter
    def preferred_width(self, value):
        """Alias for PreferredWidth.setter"""
        self.PreferredWidth = value

    @property
    def PreferredWidthType(self):
        return WdPreferredWidthType(self.com_object.PreferredWidthType)

    @PreferredWidthType.setter
    def PreferredWidthType(self, value):
        self.com_object.PreferredWidthType = value

    @property
    def preferredwidthtype(self):
        """Alias for PreferredWidthType"""
        return self.PreferredWidthType

    @preferredwidthtype.setter
    def preferredwidthtype(self, value):
        """Alias for PreferredWidthType.setter"""
        self.PreferredWidthType = value

    @property
    def preferred_width_type(self):
        """Alias for PreferredWidthType"""
        return self.PreferredWidthType

    @preferred_width_type.setter
    def preferred_width_type(self, value):
        """Alias for PreferredWidthType.setter"""
        self.PreferredWidthType = value

    @property
    def Previous(self):
        return self.com_object.Previous

    @property
    def previous(self):
        """Alias for Previous"""
        return self.Previous

    @property
    def Shading(self):
        return Shading(self.com_object.Shading)

    @property
    def shading(self):
        """Alias for Shading"""
        return self.Shading

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def AutoFit(self):
        self.com_object.AutoFit()

    def autofit(self):
        """Alias for AutoFit"""
        return self.AutoFit()

    def auto_fit(self):
        """Alias for AutoFit"""
        return self.AutoFit()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()

    def SetWidth(self, ColumnWidth=None, RulerStyle=None):
        arguments = com_arguments([unwrap(a) for a in [ColumnWidth, RulerStyle]])
        self.com_object.SetWidth(*arguments)

    def setwidth(self, ColumnWidth=None, RulerStyle=None):
        """Alias for SetWidth"""
        arguments = [ColumnWidth, RulerStyle]
        return self.SetWidth(*arguments)

    def set_width(self, ColumnWidth=None, RulerStyle=None):
        """Alias for SetWidth"""
        arguments = [ColumnWidth, RulerStyle]
        return self.SetWidth(*arguments)

    def Sort(self, ExcludeHeader=None, SortFieldType=None, SortOrder=None, CaseSensitive=None, BidiSort=None, IgnoreThe=None, IgnoreKashida=None, IgnoreDiacritics=None, IgnoreHe=None, LanguageID=None):
        arguments = com_arguments([unwrap(a) for a in [ExcludeHeader, SortFieldType, SortOrder, CaseSensitive, BidiSort, IgnoreThe, IgnoreKashida, IgnoreDiacritics, IgnoreHe, LanguageID]])
        self.com_object.Sort(*arguments)

    def sort(self, ExcludeHeader=None, SortFieldType=None, SortOrder=None, CaseSensitive=None, BidiSort=None, IgnoreThe=None, IgnoreKashida=None, IgnoreDiacritics=None, IgnoreHe=None, LanguageID=None):
        """Alias for Sort"""
        arguments = [ExcludeHeader, SortFieldType, SortOrder, CaseSensitive, BidiSort, IgnoreThe, IgnoreKashida, IgnoreDiacritics, IgnoreHe, LanguageID]
        return self.Sort(*arguments)


class Columns:

    def __init__(self, columns=None):
        self.com_object= columns

    def __call__(self, item):
        return Column(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def First(self):
        return Column(self.com_object.First)

    @property
    def first(self):
        """Alias for First"""
        return self.First

    @property
    def Last(self):
        return Column(self.com_object.Last)

    @property
    def last(self):
        """Alias for Last"""
        return self.Last

    @property
    def NestingLevel(self):
        return self.com_object.NestingLevel

    @property
    def nestinglevel(self):
        """Alias for NestingLevel"""
        return self.NestingLevel

    @property
    def nesting_level(self):
        """Alias for NestingLevel"""
        return self.NestingLevel

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PreferredWidth(self):
        return self.com_object.PreferredWidth

    @PreferredWidth.setter
    def PreferredWidth(self, value):
        self.com_object.PreferredWidth = value

    @property
    def preferredwidth(self):
        """Alias for PreferredWidth"""
        return self.PreferredWidth

    @preferredwidth.setter
    def preferredwidth(self, value):
        """Alias for PreferredWidth.setter"""
        self.PreferredWidth = value

    @property
    def preferred_width(self):
        """Alias for PreferredWidth"""
        return self.PreferredWidth

    @preferred_width.setter
    def preferred_width(self, value):
        """Alias for PreferredWidth.setter"""
        self.PreferredWidth = value

    @property
    def PreferredWidthType(self):
        return WdPreferredWidthType(self.com_object.PreferredWidthType)

    @PreferredWidthType.setter
    def PreferredWidthType(self, value):
        self.com_object.PreferredWidthType = value

    @property
    def preferredwidthtype(self):
        """Alias for PreferredWidthType"""
        return self.PreferredWidthType

    @preferredwidthtype.setter
    def preferredwidthtype(self, value):
        """Alias for PreferredWidthType.setter"""
        self.PreferredWidthType = value

    @property
    def preferred_width_type(self):
        """Alias for PreferredWidthType"""
        return self.PreferredWidthType

    @preferred_width_type.setter
    def preferred_width_type(self, value):
        """Alias for PreferredWidthType.setter"""
        self.PreferredWidthType = value

    @property
    def Shading(self):
        return Shading(self.com_object.Shading)

    @property
    def shading(self):
        """Alias for Shading"""
        return self.Shading

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Add(self, BeforeColumn=None):
        arguments = com_arguments([unwrap(a) for a in [BeforeColumn]])
        return Column(self.com_object.Add(*arguments))

    def add(self, BeforeColumn=None):
        """Alias for Add"""
        arguments = [BeforeColumn]
        return self.Add(*arguments)

    def AutoFit(self):
        self.com_object.AutoFit()

    def autofit(self):
        """Alias for AutoFit"""
        return self.AutoFit()

    def auto_fit(self):
        """Alias for AutoFit"""
        return self.AutoFit()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def DistributeWidth(self):
        self.com_object.DistributeWidth()

    def distributewidth(self):
        """Alias for DistributeWidth"""
        return self.DistributeWidth()

    def distribute_width(self):
        """Alias for DistributeWidth"""
        return self.DistributeWidth()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Column(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()

    def SetWidth(self, ColumnWidth=None, RulerStyle=None):
        arguments = com_arguments([unwrap(a) for a in [ColumnWidth, RulerStyle]])
        self.com_object.SetWidth(*arguments)

    def setwidth(self, ColumnWidth=None, RulerStyle=None):
        """Alias for SetWidth"""
        arguments = [ColumnWidth, RulerStyle]
        return self.SetWidth(*arguments)

    def set_width(self, ColumnWidth=None, RulerStyle=None):
        """Alias for SetWidth"""
        arguments = [ColumnWidth, RulerStyle]
        return self.SetWidth(*arguments)


class Comment:

    def __init__(self, comment=None):
        self.com_object= comment

    @property
    def Ancestor(self):
        return self.com_object.Ancestor

    @property
    def ancestor(self):
        """Alias for Ancestor"""
        return self.Ancestor

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Contact(self):
        return self.com_object.Contact

    @property
    def contact(self):
        """Alias for Contact"""
        return self.Contact

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Date(self):
        return self.com_object.Date

    @property
    def date(self):
        """Alias for Date"""
        return self.Date

    @property
    def Done(self):
        return self.com_object.Done

    @Done.setter
    def Done(self, value):
        self.com_object.Done = value

    @property
    def done(self):
        """Alias for Done"""
        return self.Done

    @done.setter
    def done(self, value):
        """Alias for Done.setter"""
        self.Done = value

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def IsInk(self):
        return self.com_object.IsInk

    @property
    def isink(self):
        """Alias for IsInk"""
        return self.IsInk

    @property
    def is_ink(self):
        """Alias for IsInk"""
        return self.IsInk

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def Reference(self):
        return Range(self.com_object.Reference)

    @property
    def reference(self):
        """Alias for Reference"""
        return self.Reference

    @property
    def Replies(self):
        return Comment(self.com_object.Replies)

    @property
    def replies(self):
        """Alias for Replies"""
        return self.Replies

    @property
    def Scope(self):
        return Range(self.com_object.Scope)

    @property
    def scope(self):
        """Alias for Scope"""
        return self.Scope

    def DeleteRecursively(self):
        return self.com_object.DeleteRecursively()

    def deleterecursively(self):
        """Alias for DeleteRecursively"""
        return self.DeleteRecursively()

    def delete_recursively(self):
        """Alias for DeleteRecursively"""
        return self.DeleteRecursively()

    def Edit(self):
        self.com_object.Edit()

    def edit(self):
        """Alias for Edit"""
        return self.Edit()


class Comments:

    def __init__(self, comments=None):
        self.com_object= comments

    def __call__(self, item):
        return Comment(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ShowBy(self):
        return self.com_object.ShowBy

    @ShowBy.setter
    def ShowBy(self, value):
        self.com_object.ShowBy = value

    @property
    def showby(self):
        """Alias for ShowBy"""
        return self.ShowBy

    @showby.setter
    def showby(self, value):
        """Alias for ShowBy.setter"""
        self.ShowBy = value

    @property
    def show_by(self):
        """Alias for ShowBy"""
        return self.ShowBy

    @show_by.setter
    def show_by(self, value):
        """Alias for ShowBy.setter"""
        self.ShowBy = value

    def Add(self, Range=None, Text=None):
        arguments = com_arguments([unwrap(a) for a in [Range, Text]])
        return Comment(self.com_object.Add(*arguments))

    def add(self, Range=None, Text=None):
        """Alias for Add"""
        arguments = [Range, Text]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Comment(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ConditionalStyle:

    def __init__(self, conditionalstyle=None):
        self.com_object= conditionalstyle

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def BottomPadding(self):
        return self.com_object.BottomPadding

    @BottomPadding.setter
    def BottomPadding(self, value):
        self.com_object.BottomPadding = value

    @property
    def bottompadding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottompadding.setter
    def bottompadding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def bottom_padding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottom_padding.setter
    def bottom_padding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @Font.setter
    def Font(self, value):
        self.com_object.Font = value

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @font.setter
    def font(self, value):
        """Alias for Font.setter"""
        self.Font = value

    @property
    def LeftPadding(self):
        return self.com_object.LeftPadding

    @LeftPadding.setter
    def LeftPadding(self, value):
        self.com_object.LeftPadding = value

    @property
    def leftpadding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @leftpadding.setter
    def leftpadding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def left_padding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @left_padding.setter
    def left_padding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def ParagraphFormat(self):
        return ParagraphFormat(self.com_object.ParagraphFormat)

    @ParagraphFormat.setter
    def ParagraphFormat(self, value):
        self.com_object.ParagraphFormat = value

    @property
    def paragraphformat(self):
        """Alias for ParagraphFormat"""
        return self.ParagraphFormat

    @paragraphformat.setter
    def paragraphformat(self, value):
        """Alias for ParagraphFormat.setter"""
        self.ParagraphFormat = value

    @property
    def paragraph_format(self):
        """Alias for ParagraphFormat"""
        return self.ParagraphFormat

    @paragraph_format.setter
    def paragraph_format(self, value):
        """Alias for ParagraphFormat.setter"""
        self.ParagraphFormat = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RightPadding(self):
        return self.com_object.RightPadding

    @RightPadding.setter
    def RightPadding(self, value):
        self.com_object.RightPadding = value

    @property
    def rightpadding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @rightpadding.setter
    def rightpadding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def right_padding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @right_padding.setter
    def right_padding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def Shading(self):
        return Shading(self.com_object.Shading)

    @property
    def shading(self):
        """Alias for Shading"""
        return self.Shading

    @property
    def TopPadding(self):
        return self.com_object.TopPadding

    @TopPadding.setter
    def TopPadding(self, value):
        self.com_object.TopPadding = value

    @property
    def toppadding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @toppadding.setter
    def toppadding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def top_padding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @top_padding.setter
    def top_padding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value


class Conflict:

    def __init__(self, conflict=None):
        self.com_object= conflict

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return self.com_object.Range

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def Type(self):
        return self.com_object.Type

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def Accept(self):
        return self.com_object.Accept()

    def accept(self):
        """Alias for Accept"""
        return self.Accept()

    def Reject(self):
        return self.com_object.Reject()

    def reject(self):
        """Alias for Reject"""
        return self.Reject()


class Conflicts:

    def __init__(self, conflicts=None):
        self.com_object= conflicts

    def __call__(self, item):
        return Conflict(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return Conflicts(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def AcceptAll(self):
        return self.com_object.AcceptAll()

    def acceptall(self):
        """Alias for AcceptAll"""
        return self.AcceptAll()

    def accept_all(self):
        """Alias for AcceptAll"""
        return self.AcceptAll()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Conflict(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def RejectAll(self):
        return self.com_object.RejectAll()

    def rejectall(self):
        """Alias for RejectAll"""
        return self.RejectAll()

    def reject_all(self):
        """Alias for RejectAll"""
        return self.RejectAll()


class ContentControl:

    def __init__(self, contentcontrol=None):
        self.com_object= contentcontrol

    @property
    def AllowInsertDeleteSection(self):
        return self.com_object.AllowInsertDeleteSection

    @property
    def allowinsertdeletesection(self):
        """Alias for AllowInsertDeleteSection"""
        return self.AllowInsertDeleteSection

    @property
    def allow_insert_delete_section(self):
        """Alias for AllowInsertDeleteSection"""
        return self.AllowInsertDeleteSection

    @property
    def Appearance(self):
        return self.com_object.Appearance

    @Appearance.setter
    def Appearance(self, value):
        self.com_object.Appearance = value

    @property
    def appearance(self):
        """Alias for Appearance"""
        return self.Appearance

    @appearance.setter
    def appearance(self, value):
        """Alias for Appearance.setter"""
        self.Appearance = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BuildingBlockCategory(self):
        return self.com_object.BuildingBlockCategory

    @BuildingBlockCategory.setter
    def BuildingBlockCategory(self, value):
        self.com_object.BuildingBlockCategory = value

    @property
    def buildingblockcategory(self):
        """Alias for BuildingBlockCategory"""
        return self.BuildingBlockCategory

    @buildingblockcategory.setter
    def buildingblockcategory(self, value):
        """Alias for BuildingBlockCategory.setter"""
        self.BuildingBlockCategory = value

    @property
    def building_block_category(self):
        """Alias for BuildingBlockCategory"""
        return self.BuildingBlockCategory

    @building_block_category.setter
    def building_block_category(self, value):
        """Alias for BuildingBlockCategory.setter"""
        self.BuildingBlockCategory = value

    @property
    def BuildingBlockType(self):
        return WdBuildingBlockTypes(self.com_object.BuildingBlockType)

    @BuildingBlockType.setter
    def BuildingBlockType(self, value):
        self.com_object.BuildingBlockType = value

    @property
    def buildingblocktype(self):
        """Alias for BuildingBlockType"""
        return self.BuildingBlockType

    @buildingblocktype.setter
    def buildingblocktype(self, value):
        """Alias for BuildingBlockType.setter"""
        self.BuildingBlockType = value

    @property
    def building_block_type(self):
        """Alias for BuildingBlockType"""
        return self.BuildingBlockType

    @building_block_type.setter
    def building_block_type(self, value):
        """Alias for BuildingBlockType.setter"""
        self.BuildingBlockType = value

    @property
    def Checked(self):
        return self.com_object.Checked

    @Checked.setter
    def Checked(self, value):
        self.com_object.Checked = value

    @property
    def checked(self):
        """Alias for Checked"""
        return self.Checked

    @checked.setter
    def checked(self, value):
        """Alias for Checked.setter"""
        self.Checked = value

    @property
    def Color(self):
        return self.com_object.Color

    @Color.setter
    def Color(self, value):
        self.com_object.Color = value

    @property
    def color(self):
        """Alias for Color"""
        return self.Color

    @color.setter
    def color(self, value):
        """Alias for Color.setter"""
        self.Color = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DateCalendarType(self):
        return WdCalendarType(self.com_object.DateCalendarType)

    @DateCalendarType.setter
    def DateCalendarType(self, value):
        self.com_object.DateCalendarType = value

    @property
    def datecalendartype(self):
        """Alias for DateCalendarType"""
        return self.DateCalendarType

    @datecalendartype.setter
    def datecalendartype(self, value):
        """Alias for DateCalendarType.setter"""
        self.DateCalendarType = value

    @property
    def date_calendar_type(self):
        """Alias for DateCalendarType"""
        return self.DateCalendarType

    @date_calendar_type.setter
    def date_calendar_type(self, value):
        """Alias for DateCalendarType.setter"""
        self.DateCalendarType = value

    @property
    def DateDisplayFormat(self):
        return self.com_object.DateDisplayFormat

    @DateDisplayFormat.setter
    def DateDisplayFormat(self, value):
        self.com_object.DateDisplayFormat = value

    @property
    def datedisplayformat(self):
        """Alias for DateDisplayFormat"""
        return self.DateDisplayFormat

    @datedisplayformat.setter
    def datedisplayformat(self, value):
        """Alias for DateDisplayFormat.setter"""
        self.DateDisplayFormat = value

    @property
    def date_display_format(self):
        """Alias for DateDisplayFormat"""
        return self.DateDisplayFormat

    @date_display_format.setter
    def date_display_format(self, value):
        """Alias for DateDisplayFormat.setter"""
        self.DateDisplayFormat = value

    @property
    def DateDisplayLocale(self):
        return WdLanguageID(self.com_object.DateDisplayLocale)

    @DateDisplayLocale.setter
    def DateDisplayLocale(self, value):
        self.com_object.DateDisplayLocale = value

    @property
    def datedisplaylocale(self):
        """Alias for DateDisplayLocale"""
        return self.DateDisplayLocale

    @datedisplaylocale.setter
    def datedisplaylocale(self, value):
        """Alias for DateDisplayLocale.setter"""
        self.DateDisplayLocale = value

    @property
    def date_display_locale(self):
        """Alias for DateDisplayLocale"""
        return self.DateDisplayLocale

    @date_display_locale.setter
    def date_display_locale(self, value):
        """Alias for DateDisplayLocale.setter"""
        self.DateDisplayLocale = value

    @property
    def DateStorageFormat(self):
        return WdContentControlDateStorageFormat(self.com_object.DateStorageFormat)

    @DateStorageFormat.setter
    def DateStorageFormat(self, value):
        self.com_object.DateStorageFormat = value

    @property
    def datestorageformat(self):
        """Alias for DateStorageFormat"""
        return self.DateStorageFormat

    @datestorageformat.setter
    def datestorageformat(self, value):
        """Alias for DateStorageFormat.setter"""
        self.DateStorageFormat = value

    @property
    def date_storage_format(self):
        """Alias for DateStorageFormat"""
        return self.DateStorageFormat

    @date_storage_format.setter
    def date_storage_format(self, value):
        """Alias for DateStorageFormat.setter"""
        self.DateStorageFormat = value

    @property
    def DefaultTextStyle(self):
        return self.com_object.DefaultTextStyle

    @DefaultTextStyle.setter
    def DefaultTextStyle(self, value):
        self.com_object.DefaultTextStyle = value

    @property
    def defaulttextstyle(self):
        """Alias for DefaultTextStyle"""
        return self.DefaultTextStyle

    @defaulttextstyle.setter
    def defaulttextstyle(self, value):
        """Alias for DefaultTextStyle.setter"""
        self.DefaultTextStyle = value

    @property
    def default_text_style(self):
        """Alias for DefaultTextStyle"""
        return self.DefaultTextStyle

    @default_text_style.setter
    def default_text_style(self, value):
        """Alias for DefaultTextStyle.setter"""
        self.DefaultTextStyle = value

    @property
    def DropdownListEntries(self):
        return ContentControlListEntries(self.com_object.DropdownListEntries)

    @property
    def dropdownlistentries(self):
        """Alias for DropdownListEntries"""
        return self.DropdownListEntries

    @property
    def dropdown_list_entries(self):
        """Alias for DropdownListEntries"""
        return self.DropdownListEntries

    @property
    def ID(self):
        return self.com_object.ID

    @property
    def id(self):
        """Alias for ID"""
        return self.ID

    @property
    def i_d(self):
        """Alias for ID"""
        return self.ID

    @property
    def Level(self):
        return self.com_object.Level

    @property
    def level(self):
        """Alias for Level"""
        return self.Level

    @property
    def LockContentControl(self):
        return self.com_object.LockContentControl

    @LockContentControl.setter
    def LockContentControl(self, value):
        self.com_object.LockContentControl = value

    @property
    def lockcontentcontrol(self):
        """Alias for LockContentControl"""
        return self.LockContentControl

    @lockcontentcontrol.setter
    def lockcontentcontrol(self, value):
        """Alias for LockContentControl.setter"""
        self.LockContentControl = value

    @property
    def lock_content_control(self):
        """Alias for LockContentControl"""
        return self.LockContentControl

    @lock_content_control.setter
    def lock_content_control(self, value):
        """Alias for LockContentControl.setter"""
        self.LockContentControl = value

    @property
    def LockContents(self):
        return self.com_object.LockContents

    @LockContents.setter
    def LockContents(self, value):
        self.com_object.LockContents = value

    @property
    def lockcontents(self):
        """Alias for LockContents"""
        return self.LockContents

    @lockcontents.setter
    def lockcontents(self, value):
        """Alias for LockContents.setter"""
        self.LockContents = value

    @property
    def lock_contents(self):
        """Alias for LockContents"""
        return self.LockContents

    @lock_contents.setter
    def lock_contents(self, value):
        """Alias for LockContents.setter"""
        self.LockContents = value

    @property
    def MultiLine(self):
        return self.com_object.MultiLine

    @MultiLine.setter
    def MultiLine(self, value):
        self.com_object.MultiLine = value

    @property
    def multiline(self):
        """Alias for MultiLine"""
        return self.MultiLine

    @multiline.setter
    def multiline(self, value):
        """Alias for MultiLine.setter"""
        self.MultiLine = value

    @property
    def multi_line(self):
        """Alias for MultiLine"""
        return self.MultiLine

    @multi_line.setter
    def multi_line(self, value):
        """Alias for MultiLine.setter"""
        self.MultiLine = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ParentContentControl(self):
        return ContentControl(self.com_object.ParentContentControl)

    @property
    def parentcontentcontrol(self):
        """Alias for ParentContentControl"""
        return self.ParentContentControl

    @property
    def parent_content_control(self):
        """Alias for ParentContentControl"""
        return self.ParentContentControl

    @property
    def PlaceholderText(self):
        return BuildingBlock(self.com_object.PlaceholderText)

    @property
    def placeholdertext(self):
        """Alias for PlaceholderText"""
        return self.PlaceholderText

    @property
    def placeholder_text(self):
        """Alias for PlaceholderText"""
        return self.PlaceholderText

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def RepeatingSectionItems(self):
        return self.com_object.RepeatingSectionItems

    @property
    def repeatingsectionitems(self):
        """Alias for RepeatingSectionItems"""
        return self.RepeatingSectionItems

    @property
    def repeating_section_items(self):
        """Alias for RepeatingSectionItems"""
        return self.RepeatingSectionItems

    @property
    def RepeatingSectionItemTitle(self):
        return self.com_object.RepeatingSectionItemTitle

    @RepeatingSectionItemTitle.setter
    def RepeatingSectionItemTitle(self, value):
        self.com_object.RepeatingSectionItemTitle = value

    @property
    def repeatingsectionitemtitle(self):
        """Alias for RepeatingSectionItemTitle"""
        return self.RepeatingSectionItemTitle

    @repeatingsectionitemtitle.setter
    def repeatingsectionitemtitle(self, value):
        """Alias for RepeatingSectionItemTitle.setter"""
        self.RepeatingSectionItemTitle = value

    @property
    def repeating_section_item_title(self):
        """Alias for RepeatingSectionItemTitle"""
        return self.RepeatingSectionItemTitle

    @repeating_section_item_title.setter
    def repeating_section_item_title(self, value):
        """Alias for RepeatingSectionItemTitle.setter"""
        self.RepeatingSectionItemTitle = value

    @property
    def ShowingPlaceholderText(self):
        return self.com_object.ShowingPlaceholderText

    @property
    def showingplaceholdertext(self):
        """Alias for ShowingPlaceholderText"""
        return self.ShowingPlaceholderText

    @property
    def showing_placeholder_text(self):
        """Alias for ShowingPlaceholderText"""
        return self.ShowingPlaceholderText

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def Temporary(self):
        return self.com_object.Temporary

    @Temporary.setter
    def Temporary(self, value):
        self.com_object.Temporary = value

    @property
    def temporary(self):
        """Alias for Temporary"""
        return self.Temporary

    @temporary.setter
    def temporary(self, value):
        """Alias for Temporary.setter"""
        self.Temporary = value

    @property
    def Title(self):
        return self.com_object.Title

    @Title.setter
    def Title(self, value):
        self.com_object.Title = value

    @property
    def title(self):
        """Alias for Title"""
        return self.Title

    @title.setter
    def title(self, value):
        """Alias for Title.setter"""
        self.Title = value

    @property
    def Type(self):
        return WdContentControlType(self.com_object.Type)

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    @property
    def XMLMapping(self):
        return XMLMapping(self.com_object.XMLMapping)

    @property
    def xmlmapping(self):
        """Alias for XMLMapping"""
        return self.XMLMapping

    @property
    def x_m_l_mapping(self):
        """Alias for XMLMapping"""
        return self.XMLMapping

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Cut(self):
        self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def Delete(self, DeleteContents=None):
        arguments = com_arguments([unwrap(a) for a in [DeleteContents]])
        self.com_object.Delete(*arguments)

    def delete(self, DeleteContents=None):
        """Alias for Delete"""
        arguments = [DeleteContents]
        return self.Delete(*arguments)

    def SetCheckedSymbol(self, CharacterNumber=None, Font=None):
        arguments = com_arguments([unwrap(a) for a in [CharacterNumber, Font]])
        self.com_object.SetCheckedSymbol(*arguments)

    def setcheckedsymbol(self, CharacterNumber=None, Font=None):
        """Alias for SetCheckedSymbol"""
        arguments = [CharacterNumber, Font]
        return self.SetCheckedSymbol(*arguments)

    def set_checked_symbol(self, CharacterNumber=None, Font=None):
        """Alias for SetCheckedSymbol"""
        arguments = [CharacterNumber, Font]
        return self.SetCheckedSymbol(*arguments)

    def SetPlaceholderText(self, BuildingBlock=None, Range=None, Text=None):
        arguments = com_arguments([unwrap(a) for a in [BuildingBlock, Range, Text]])
        self.com_object.SetPlaceholderText(*arguments)

    def setplaceholdertext(self, BuildingBlock=None, Range=None, Text=None):
        """Alias for SetPlaceholderText"""
        arguments = [BuildingBlock, Range, Text]
        return self.SetPlaceholderText(*arguments)

    def set_placeholder_text(self, BuildingBlock=None, Range=None, Text=None):
        """Alias for SetPlaceholderText"""
        arguments = [BuildingBlock, Range, Text]
        return self.SetPlaceholderText(*arguments)

    def SetUncheckedSymbol(self, CharacterNumber=None, Font=None):
        arguments = com_arguments([unwrap(a) for a in [CharacterNumber, Font]])
        self.com_object.SetUncheckedSymbol(*arguments)

    def setuncheckedsymbol(self, CharacterNumber=None, Font=None):
        """Alias for SetUncheckedSymbol"""
        arguments = [CharacterNumber, Font]
        return self.SetUncheckedSymbol(*arguments)

    def set_unchecked_symbol(self, CharacterNumber=None, Font=None):
        """Alias for SetUncheckedSymbol"""
        arguments = [CharacterNumber, Font]
        return self.SetUncheckedSymbol(*arguments)

    def Ungroup(self):
        self.com_object.Ungroup()

    def ungroup(self):
        """Alias for Ungroup"""
        return self.Ungroup()


class ContentControlListEntries:

    def __init__(self, contentcontrollistentries=None):
        self.com_object= contentcontrollistentries

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return ContentControlListEntries(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Text=None, Value=None, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Text, Value, Index]])
        return ContentControlListEntry(self.com_object.Add(*arguments))

    def add(self, Text=None, Value=None, Index=None):
        """Alias for Add"""
        arguments = [Text, Value, Index]
        return self.Add(*arguments)

    def Clear(self):
        self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ContentControlListEntry(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ContentControlListEntry:

    def __init__(self, contentcontrollistentry=None):
        self.com_object= contentcontrollistentry

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @Index.setter
    def Index(self, value):
        self.com_object.Index = value

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @index.setter
    def index(self, value):
        """Alias for Index.setter"""
        self.Index = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def MoveDown(self):
        self.com_object.MoveDown()

    def movedown(self):
        """Alias for MoveDown"""
        return self.MoveDown()

    def move_down(self):
        """Alias for MoveDown"""
        return self.MoveDown()

    def MoveUp(self):
        self.com_object.MoveUp()

    def moveup(self):
        """Alias for MoveUp"""
        return self.MoveUp()

    def move_up(self):
        """Alias for MoveUp"""
        return self.MoveUp()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class ContentControls:

    def __init__(self, contentcontrols=None):
        self.com_object= contentcontrols

    def __call__(self, item):
        return ContentControl(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return ContentControls(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Type=None, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Range]])
        return ContentControl(self.com_object.Add(*arguments))

    def add(self, Type=None, Range=None):
        """Alias for Add"""
        arguments = [Type, Range]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ContentControl(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class CustomLabel:

    def __init__(self, customlabel=None):
        self.com_object= customlabel

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DotMatrix(self):
        return self.com_object.DotMatrix

    @property
    def dotmatrix(self):
        """Alias for DotMatrix"""
        return self.DotMatrix

    @property
    def dot_matrix(self):
        """Alias for DotMatrix"""
        return self.DotMatrix

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HorizontalPitch(self):
        return self.com_object.HorizontalPitch

    @HorizontalPitch.setter
    def HorizontalPitch(self, value):
        self.com_object.HorizontalPitch = value

    @property
    def horizontalpitch(self):
        """Alias for HorizontalPitch"""
        return self.HorizontalPitch

    @horizontalpitch.setter
    def horizontalpitch(self, value):
        """Alias for HorizontalPitch.setter"""
        self.HorizontalPitch = value

    @property
    def horizontal_pitch(self):
        """Alias for HorizontalPitch"""
        return self.HorizontalPitch

    @horizontal_pitch.setter
    def horizontal_pitch(self, value):
        """Alias for HorizontalPitch.setter"""
        self.HorizontalPitch = value

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return CustomLabel(self.com_object.Name)

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def NumberAcross(self):
        return self.com_object.NumberAcross

    @NumberAcross.setter
    def NumberAcross(self, value):
        self.com_object.NumberAcross = value

    @property
    def numberacross(self):
        """Alias for NumberAcross"""
        return self.NumberAcross

    @numberacross.setter
    def numberacross(self, value):
        """Alias for NumberAcross.setter"""
        self.NumberAcross = value

    @property
    def number_across(self):
        """Alias for NumberAcross"""
        return self.NumberAcross

    @number_across.setter
    def number_across(self, value):
        """Alias for NumberAcross.setter"""
        self.NumberAcross = value

    @property
    def NumberDown(self):
        return self.com_object.NumberDown

    @NumberDown.setter
    def NumberDown(self, value):
        self.com_object.NumberDown = value

    @property
    def numberdown(self):
        """Alias for NumberDown"""
        return self.NumberDown

    @numberdown.setter
    def numberdown(self, value):
        """Alias for NumberDown.setter"""
        self.NumberDown = value

    @property
    def number_down(self):
        """Alias for NumberDown"""
        return self.NumberDown

    @number_down.setter
    def number_down(self, value):
        """Alias for NumberDown.setter"""
        self.NumberDown = value

    @property
    def PageSize(self):
        return WdCustomLabelPageSize(self.com_object.PageSize)

    @PageSize.setter
    def PageSize(self, value):
        self.com_object.PageSize = value

    @property
    def pagesize(self):
        """Alias for PageSize"""
        return self.PageSize

    @pagesize.setter
    def pagesize(self, value):
        """Alias for PageSize.setter"""
        self.PageSize = value

    @property
    def page_size(self):
        """Alias for PageSize"""
        return self.PageSize

    @page_size.setter
    def page_size(self, value):
        """Alias for PageSize.setter"""
        self.PageSize = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SideMargin(self):
        return self.com_object.SideMargin

    @SideMargin.setter
    def SideMargin(self, value):
        self.com_object.SideMargin = value

    @property
    def sidemargin(self):
        """Alias for SideMargin"""
        return self.SideMargin

    @sidemargin.setter
    def sidemargin(self, value):
        """Alias for SideMargin.setter"""
        self.SideMargin = value

    @property
    def side_margin(self):
        """Alias for SideMargin"""
        return self.SideMargin

    @side_margin.setter
    def side_margin(self, value):
        """Alias for SideMargin.setter"""
        self.SideMargin = value

    @property
    def TopMargin(self):
        return self.com_object.TopMargin

    @TopMargin.setter
    def TopMargin(self, value):
        self.com_object.TopMargin = value

    @property
    def topmargin(self):
        """Alias for TopMargin"""
        return self.TopMargin

    @topmargin.setter
    def topmargin(self, value):
        """Alias for TopMargin.setter"""
        self.TopMargin = value

    @property
    def top_margin(self):
        """Alias for TopMargin"""
        return self.TopMargin

    @top_margin.setter
    def top_margin(self, value):
        """Alias for TopMargin.setter"""
        self.TopMargin = value

    @property
    def Valid(self):
        return self.com_object.Valid

    @property
    def valid(self):
        """Alias for Valid"""
        return self.Valid

    @property
    def VerticalPitch(self):
        return self.com_object.VerticalPitch

    @VerticalPitch.setter
    def VerticalPitch(self, value):
        self.com_object.VerticalPitch = value

    @property
    def verticalpitch(self):
        """Alias for VerticalPitch"""
        return self.VerticalPitch

    @verticalpitch.setter
    def verticalpitch(self, value):
        """Alias for VerticalPitch.setter"""
        self.VerticalPitch = value

    @property
    def vertical_pitch(self):
        """Alias for VerticalPitch"""
        return self.VerticalPitch

    @vertical_pitch.setter
    def vertical_pitch(self, value):
        """Alias for VerticalPitch.setter"""
        self.VerticalPitch = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class CustomLabels:

    def __init__(self, customlabels=None):
        self.com_object= customlabels

    def __call__(self, item):
        return CustomLabel(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, DotMatrix=None):
        arguments = com_arguments([unwrap(a) for a in [Name, DotMatrix]])
        return CustomLabel(self.com_object.Add(*arguments))

    def add(self, Name=None, DotMatrix=None):
        """Alias for Add"""
        arguments = [Name, DotMatrix]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return CustomLabel(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class CustomProperties:

    def __init__(self, customproperties=None):
        self.com_object= customproperties

    def __call__(self, item):
        return CustomPropertie(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, Value=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Value]])
        return CustomProperty(self.com_object.Add(*arguments))

    def add(self, Name=None, Value=None):
        """Alias for Add"""
        arguments = [Name, Value]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return CustomProperty(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class CustomProperty:

    def __init__(self, customproperty=None):
        self.com_object= customproperty

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class DataLabel:

    def __init__(self, datalabel=None):
        self.com_object= datalabel

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoText(self):
        return self.com_object.AutoText

    @AutoText.setter
    def AutoText(self, value):
        self.com_object.AutoText = value

    @property
    def autotext(self):
        """Alias for AutoText"""
        return self.AutoText

    @autotext.setter
    def autotext(self, value):
        """Alias for AutoText.setter"""
        self.AutoText = value

    @property
    def auto_text(self):
        """Alias for AutoText"""
        return self.AutoText

    @auto_text.setter
    def auto_text(self, value):
        """Alias for AutoText.setter"""
        self.AutoText = value

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    def Characters(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        if hasattr(self.com_object, "GetCharacters"):
            return ChartCharacters(self.com_object.GetCharacters(*arguments))
        else:
            return ChartCharacters(self.com_object.Characters(*arguments))

    def characters(self, Start=None, Length=None):
        """Alias for Characters"""
        arguments = [Start, Length]
        return self.Characters(*arguments)

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def FormulaLocal(self):
        return self.com_object.FormulaLocal

    @FormulaLocal.setter
    def FormulaLocal(self, value):
        self.com_object.FormulaLocal = value

    @property
    def formulalocal(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formulalocal.setter
    def formulalocal(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def formula_local(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formula_local.setter
    def formula_local(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def FormulaR1C1(self):
        return self.com_object.FormulaR1C1

    @FormulaR1C1.setter
    def FormulaR1C1(self, value):
        self.com_object.FormulaR1C1 = value

    @property
    def formular1c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formular1c1.setter
    def formular1c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def formula_r1_c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formula_r1_c1.setter
    def formula_r1_c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def FormulaR1C1Local(self):
        return self.com_object.FormulaR1C1Local

    @FormulaR1C1Local.setter
    def FormulaR1C1Local(self, value):
        self.com_object.FormulaR1C1Local = value

    @property
    def formular1c1local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formular1c1local.setter
    def formular1c1local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def formula_r1_c1_local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formula_r1_c1_local.setter
    def formula_r1_c1_local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HorizontalAlignment(self):
        return self.com_object.HorizontalAlignment

    @HorizontalAlignment.setter
    def HorizontalAlignment(self, value):
        self.com_object.HorizontalAlignment = value

    @property
    def horizontalalignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontalalignment.setter
    def horizontalalignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def horizontal_alignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NumberFormat(self):
        return self.com_object.NumberFormat

    @NumberFormat.setter
    def NumberFormat(self, value):
        self.com_object.NumberFormat = value

    @property
    def numberformat(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @numberformat.setter
    def numberformat(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def number_format(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @number_format.setter
    def number_format(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def NumberFormatLinked(self):
        return self.com_object.NumberFormatLinked

    @NumberFormatLinked.setter
    def NumberFormatLinked(self, value):
        self.com_object.NumberFormatLinked = value

    @property
    def numberformatlinked(self):
        """Alias for NumberFormatLinked"""
        return self.NumberFormatLinked

    @numberformatlinked.setter
    def numberformatlinked(self, value):
        """Alias for NumberFormatLinked.setter"""
        self.NumberFormatLinked = value

    @property
    def number_format_linked(self):
        """Alias for NumberFormatLinked"""
        return self.NumberFormatLinked

    @number_format_linked.setter
    def number_format_linked(self, value):
        """Alias for NumberFormatLinked.setter"""
        self.NumberFormatLinked = value

    @property
    def NumberFormatLocal(self):
        return self.com_object.NumberFormatLocal

    @NumberFormatLocal.setter
    def NumberFormatLocal(self, value):
        self.com_object.NumberFormatLocal = value

    @property
    def numberformatlocal(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @numberformatlocal.setter
    def numberformatlocal(self, value):
        """Alias for NumberFormatLocal.setter"""
        self.NumberFormatLocal = value

    @property
    def number_format_local(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @number_format_local.setter
    def number_format_local(self, value):
        """Alias for NumberFormatLocal.setter"""
        self.NumberFormatLocal = value

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return XlDataLabelPosition(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def ReadingOrder(self):
        return XlReadingOrder(self.com_object.ReadingOrder)

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def Separator(self):
        return self.com_object.Separator

    @Separator.setter
    def Separator(self, value):
        self.com_object.Separator = value

    @property
    def separator(self):
        """Alias for Separator"""
        return self.Separator

    @separator.setter
    def separator(self, value):
        """Alias for Separator.setter"""
        self.Separator = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def ShowBubbleSize(self):
        return self.com_object.ShowBubbleSize

    @ShowBubbleSize.setter
    def ShowBubbleSize(self, value):
        self.com_object.ShowBubbleSize = value

    @property
    def showbubblesize(self):
        """Alias for ShowBubbleSize"""
        return self.ShowBubbleSize

    @showbubblesize.setter
    def showbubblesize(self, value):
        """Alias for ShowBubbleSize.setter"""
        self.ShowBubbleSize = value

    @property
    def show_bubble_size(self):
        """Alias for ShowBubbleSize"""
        return self.ShowBubbleSize

    @show_bubble_size.setter
    def show_bubble_size(self, value):
        """Alias for ShowBubbleSize.setter"""
        self.ShowBubbleSize = value

    @property
    def ShowCategoryName(self):
        return self.com_object.ShowCategoryName

    @ShowCategoryName.setter
    def ShowCategoryName(self, value):
        self.com_object.ShowCategoryName = value

    @property
    def showcategoryname(self):
        """Alias for ShowCategoryName"""
        return self.ShowCategoryName

    @showcategoryname.setter
    def showcategoryname(self, value):
        """Alias for ShowCategoryName.setter"""
        self.ShowCategoryName = value

    @property
    def show_category_name(self):
        """Alias for ShowCategoryName"""
        return self.ShowCategoryName

    @show_category_name.setter
    def show_category_name(self, value):
        """Alias for ShowCategoryName.setter"""
        self.ShowCategoryName = value

    @property
    def ShowLegendKey(self):
        return self.com_object.ShowLegendKey

    @ShowLegendKey.setter
    def ShowLegendKey(self, value):
        self.com_object.ShowLegendKey = value

    @property
    def showlegendkey(self):
        """Alias for ShowLegendKey"""
        return self.ShowLegendKey

    @showlegendkey.setter
    def showlegendkey(self, value):
        """Alias for ShowLegendKey.setter"""
        self.ShowLegendKey = value

    @property
    def show_legend_key(self):
        """Alias for ShowLegendKey"""
        return self.ShowLegendKey

    @show_legend_key.setter
    def show_legend_key(self, value):
        """Alias for ShowLegendKey.setter"""
        self.ShowLegendKey = value

    @property
    def ShowPercentage(self):
        return self.com_object.ShowPercentage

    @ShowPercentage.setter
    def ShowPercentage(self, value):
        self.com_object.ShowPercentage = value

    @property
    def showpercentage(self):
        """Alias for ShowPercentage"""
        return self.ShowPercentage

    @showpercentage.setter
    def showpercentage(self, value):
        """Alias for ShowPercentage.setter"""
        self.ShowPercentage = value

    @property
    def show_percentage(self):
        """Alias for ShowPercentage"""
        return self.ShowPercentage

    @show_percentage.setter
    def show_percentage(self, value):
        """Alias for ShowPercentage.setter"""
        self.ShowPercentage = value

    @property
    def ShowRange(self):
        return self.com_object.ShowRange

    @ShowRange.setter
    def ShowRange(self, value):
        self.com_object.ShowRange = value

    @property
    def showrange(self):
        """Alias for ShowRange"""
        return self.ShowRange

    @showrange.setter
    def showrange(self, value):
        """Alias for ShowRange.setter"""
        self.ShowRange = value

    @property
    def show_range(self):
        """Alias for ShowRange"""
        return self.ShowRange

    @show_range.setter
    def show_range(self, value):
        """Alias for ShowRange.setter"""
        self.ShowRange = value

    @property
    def ShowSeriesName(self):
        return self.com_object.ShowSeriesName

    @ShowSeriesName.setter
    def ShowSeriesName(self, value):
        self.com_object.ShowSeriesName = value

    @property
    def showseriesname(self):
        """Alias for ShowSeriesName"""
        return self.ShowSeriesName

    @showseriesname.setter
    def showseriesname(self, value):
        """Alias for ShowSeriesName.setter"""
        self.ShowSeriesName = value

    @property
    def show_series_name(self):
        """Alias for ShowSeriesName"""
        return self.ShowSeriesName

    @show_series_name.setter
    def show_series_name(self, value):
        """Alias for ShowSeriesName.setter"""
        self.ShowSeriesName = value

    @property
    def ShowValue(self):
        return self.com_object.ShowValue

    @ShowValue.setter
    def ShowValue(self, value):
        self.com_object.ShowValue = value

    @property
    def showvalue(self):
        """Alias for ShowValue"""
        return self.ShowValue

    @showvalue.setter
    def showvalue(self, value):
        """Alias for ShowValue.setter"""
        self.ShowValue = value

    @property
    def show_value(self):
        """Alias for ShowValue"""
        return self.ShowValue

    @show_value.setter
    def show_value(self, value):
        """Alias for ShowValue.setter"""
        self.ShowValue = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def VerticalAlignment(self):
        return self.com_object.VerticalAlignment

    @VerticalAlignment.setter
    def VerticalAlignment(self, value):
        self.com_object.VerticalAlignment = value

    @property
    def verticalalignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @verticalalignment.setter
    def verticalalignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def vertical_alignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @vertical_alignment.setter
    def vertical_alignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class DataLabels:

    def __init__(self, datalabels=None):
        self.com_object= datalabels

    def __call__(self, item):
        return DataLabel(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoText(self):
        return self.com_object.AutoText

    @AutoText.setter
    def AutoText(self, value):
        self.com_object.AutoText = value

    @property
    def autotext(self):
        """Alias for AutoText"""
        return self.AutoText

    @autotext.setter
    def autotext(self, value):
        """Alias for AutoText.setter"""
        self.AutoText = value

    @property
    def auto_text(self):
        """Alias for AutoText"""
        return self.AutoText

    @auto_text.setter
    def auto_text(self, value):
        """Alias for AutoText.setter"""
        self.AutoText = value

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def HorizontalAlignment(self):
        return self.com_object.HorizontalAlignment

    @HorizontalAlignment.setter
    def HorizontalAlignment(self, value):
        self.com_object.HorizontalAlignment = value

    @property
    def horizontalalignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontalalignment.setter
    def horizontalalignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def horizontal_alignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NumberFormat(self):
        return self.com_object.NumberFormat

    @NumberFormat.setter
    def NumberFormat(self, value):
        self.com_object.NumberFormat = value

    @property
    def numberformat(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @numberformat.setter
    def numberformat(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def number_format(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @number_format.setter
    def number_format(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def NumberFormatLinked(self):
        return self.com_object.NumberFormatLinked

    @NumberFormatLinked.setter
    def NumberFormatLinked(self, value):
        self.com_object.NumberFormatLinked = value

    @property
    def numberformatlinked(self):
        """Alias for NumberFormatLinked"""
        return self.NumberFormatLinked

    @numberformatlinked.setter
    def numberformatlinked(self, value):
        """Alias for NumberFormatLinked.setter"""
        self.NumberFormatLinked = value

    @property
    def number_format_linked(self):
        """Alias for NumberFormatLinked"""
        return self.NumberFormatLinked

    @number_format_linked.setter
    def number_format_linked(self, value):
        """Alias for NumberFormatLinked.setter"""
        self.NumberFormatLinked = value

    @property
    def NumberFormatLocal(self):
        return self.com_object.NumberFormatLocal

    @NumberFormatLocal.setter
    def NumberFormatLocal(self, value):
        self.com_object.NumberFormatLocal = value

    @property
    def numberformatlocal(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @numberformatlocal.setter
    def numberformatlocal(self, value):
        """Alias for NumberFormatLocal.setter"""
        self.NumberFormatLocal = value

    @property
    def number_format_local(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @number_format_local.setter
    def number_format_local(self, value):
        """Alias for NumberFormatLocal.setter"""
        self.NumberFormatLocal = value

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return XlDataLabelPosition(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def ReadingOrder(self):
        return XlReadingOrder(self.com_object.ReadingOrder)

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def Separator(self):
        return self.com_object.Separator

    @Separator.setter
    def Separator(self, value):
        self.com_object.Separator = value

    @property
    def separator(self):
        """Alias for Separator"""
        return self.Separator

    @separator.setter
    def separator(self, value):
        """Alias for Separator.setter"""
        self.Separator = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def ShowBubbleSize(self):
        return self.com_object.ShowBubbleSize

    @ShowBubbleSize.setter
    def ShowBubbleSize(self, value):
        self.com_object.ShowBubbleSize = value

    @property
    def showbubblesize(self):
        """Alias for ShowBubbleSize"""
        return self.ShowBubbleSize

    @showbubblesize.setter
    def showbubblesize(self, value):
        """Alias for ShowBubbleSize.setter"""
        self.ShowBubbleSize = value

    @property
    def show_bubble_size(self):
        """Alias for ShowBubbleSize"""
        return self.ShowBubbleSize

    @show_bubble_size.setter
    def show_bubble_size(self, value):
        """Alias for ShowBubbleSize.setter"""
        self.ShowBubbleSize = value

    @property
    def ShowCategoryName(self):
        return self.com_object.ShowCategoryName

    @ShowCategoryName.setter
    def ShowCategoryName(self, value):
        self.com_object.ShowCategoryName = value

    @property
    def showcategoryname(self):
        """Alias for ShowCategoryName"""
        return self.ShowCategoryName

    @showcategoryname.setter
    def showcategoryname(self, value):
        """Alias for ShowCategoryName.setter"""
        self.ShowCategoryName = value

    @property
    def show_category_name(self):
        """Alias for ShowCategoryName"""
        return self.ShowCategoryName

    @show_category_name.setter
    def show_category_name(self, value):
        """Alias for ShowCategoryName.setter"""
        self.ShowCategoryName = value

    @property
    def ShowLegendKey(self):
        return self.com_object.ShowLegendKey

    @ShowLegendKey.setter
    def ShowLegendKey(self, value):
        self.com_object.ShowLegendKey = value

    @property
    def showlegendkey(self):
        """Alias for ShowLegendKey"""
        return self.ShowLegendKey

    @showlegendkey.setter
    def showlegendkey(self, value):
        """Alias for ShowLegendKey.setter"""
        self.ShowLegendKey = value

    @property
    def show_legend_key(self):
        """Alias for ShowLegendKey"""
        return self.ShowLegendKey

    @show_legend_key.setter
    def show_legend_key(self, value):
        """Alias for ShowLegendKey.setter"""
        self.ShowLegendKey = value

    @property
    def ShowPercentage(self):
        return self.com_object.ShowPercentage

    @ShowPercentage.setter
    def ShowPercentage(self, value):
        self.com_object.ShowPercentage = value

    @property
    def showpercentage(self):
        """Alias for ShowPercentage"""
        return self.ShowPercentage

    @showpercentage.setter
    def showpercentage(self, value):
        """Alias for ShowPercentage.setter"""
        self.ShowPercentage = value

    @property
    def show_percentage(self):
        """Alias for ShowPercentage"""
        return self.ShowPercentage

    @show_percentage.setter
    def show_percentage(self, value):
        """Alias for ShowPercentage.setter"""
        self.ShowPercentage = value

    @property
    def ShowRange(self):
        return self.com_object.ShowRange

    @ShowRange.setter
    def ShowRange(self, value):
        self.com_object.ShowRange = value

    @property
    def showrange(self):
        """Alias for ShowRange"""
        return self.ShowRange

    @showrange.setter
    def showrange(self, value):
        """Alias for ShowRange.setter"""
        self.ShowRange = value

    @property
    def show_range(self):
        """Alias for ShowRange"""
        return self.ShowRange

    @show_range.setter
    def show_range(self, value):
        """Alias for ShowRange.setter"""
        self.ShowRange = value

    @property
    def ShowSeriesName(self):
        return self.com_object.ShowSeriesName

    @ShowSeriesName.setter
    def ShowSeriesName(self, value):
        self.com_object.ShowSeriesName = value

    @property
    def showseriesname(self):
        """Alias for ShowSeriesName"""
        return self.ShowSeriesName

    @showseriesname.setter
    def showseriesname(self, value):
        """Alias for ShowSeriesName.setter"""
        self.ShowSeriesName = value

    @property
    def show_series_name(self):
        """Alias for ShowSeriesName"""
        return self.ShowSeriesName

    @show_series_name.setter
    def show_series_name(self, value):
        """Alias for ShowSeriesName.setter"""
        self.ShowSeriesName = value

    @property
    def ShowValue(self):
        return self.com_object.ShowValue

    @ShowValue.setter
    def ShowValue(self, value):
        self.com_object.ShowValue = value

    @property
    def showvalue(self):
        """Alias for ShowValue"""
        return self.ShowValue

    @showvalue.setter
    def showvalue(self, value):
        """Alias for ShowValue.setter"""
        self.ShowValue = value

    @property
    def show_value(self):
        """Alias for ShowValue"""
        return self.ShowValue

    @show_value.setter
    def show_value(self, value):
        """Alias for ShowValue.setter"""
        self.ShowValue = value

    @property
    def VerticalAlignment(self):
        return self.com_object.VerticalAlignment

    @VerticalAlignment.setter
    def VerticalAlignment(self, value):
        self.com_object.VerticalAlignment = value

    @property
    def verticalalignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @verticalalignment.setter
    def verticalalignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def vertical_alignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @vertical_alignment.setter
    def vertical_alignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return DataLabel(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Propagate(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Propagate(*arguments)

    def propagate(self, Index=None):
        """Alias for Propagate"""
        arguments = [Index]
        return self.Propagate(*arguments)

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class DataTable:

    def __init__(self, datatable=None):
        self.com_object= datatable

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Border(self):
        return ChartBorder(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Font(self):
        return ChartFont(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def HasBorderHorizontal(self):
        return self.com_object.HasBorderHorizontal

    @HasBorderHorizontal.setter
    def HasBorderHorizontal(self, value):
        self.com_object.HasBorderHorizontal = value

    @property
    def hasborderhorizontal(self):
        """Alias for HasBorderHorizontal"""
        return self.HasBorderHorizontal

    @hasborderhorizontal.setter
    def hasborderhorizontal(self, value):
        """Alias for HasBorderHorizontal.setter"""
        self.HasBorderHorizontal = value

    @property
    def has_border_horizontal(self):
        """Alias for HasBorderHorizontal"""
        return self.HasBorderHorizontal

    @has_border_horizontal.setter
    def has_border_horizontal(self, value):
        """Alias for HasBorderHorizontal.setter"""
        self.HasBorderHorizontal = value

    @property
    def HasBorderOutline(self):
        return self.com_object.HasBorderOutline

    @HasBorderOutline.setter
    def HasBorderOutline(self, value):
        self.com_object.HasBorderOutline = value

    @property
    def hasborderoutline(self):
        """Alias for HasBorderOutline"""
        return self.HasBorderOutline

    @hasborderoutline.setter
    def hasborderoutline(self, value):
        """Alias for HasBorderOutline.setter"""
        self.HasBorderOutline = value

    @property
    def has_border_outline(self):
        """Alias for HasBorderOutline"""
        return self.HasBorderOutline

    @has_border_outline.setter
    def has_border_outline(self, value):
        """Alias for HasBorderOutline.setter"""
        self.HasBorderOutline = value

    @property
    def HasBorderVertical(self):
        return self.com_object.HasBorderVertical

    @HasBorderVertical.setter
    def HasBorderVertical(self, value):
        self.com_object.HasBorderVertical = value

    @property
    def hasbordervertical(self):
        """Alias for HasBorderVertical"""
        return self.HasBorderVertical

    @hasbordervertical.setter
    def hasbordervertical(self, value):
        """Alias for HasBorderVertical.setter"""
        self.HasBorderVertical = value

    @property
    def has_border_vertical(self):
        """Alias for HasBorderVertical"""
        return self.HasBorderVertical

    @has_border_vertical.setter
    def has_border_vertical(self, value):
        """Alias for HasBorderVertical.setter"""
        self.HasBorderVertical = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ShowLegendKey(self):
        return self.com_object.ShowLegendKey

    @ShowLegendKey.setter
    def ShowLegendKey(self, value):
        self.com_object.ShowLegendKey = value

    @property
    def showlegendkey(self):
        """Alias for ShowLegendKey"""
        return self.ShowLegendKey

    @showlegendkey.setter
    def showlegendkey(self, value):
        """Alias for ShowLegendKey.setter"""
        self.ShowLegendKey = value

    @property
    def show_legend_key(self):
        """Alias for ShowLegendKey"""
        return self.ShowLegendKey

    @show_legend_key.setter
    def show_legend_key(self, value):
        """Alias for ShowLegendKey.setter"""
        self.ShowLegendKey = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class DefaultWebOptions:

    def __init__(self, defaultweboptions=None):
        self.com_object= defaultweboptions

    @property
    def AllowPNG(self):
        return self.com_object.AllowPNG

    @AllowPNG.setter
    def AllowPNG(self, value):
        self.com_object.AllowPNG = value

    @property
    def allowpng(self):
        """Alias for AllowPNG"""
        return self.AllowPNG

    @allowpng.setter
    def allowpng(self, value):
        """Alias for AllowPNG.setter"""
        self.AllowPNG = value

    @property
    def allow_p_n_g(self):
        """Alias for AllowPNG"""
        return self.AllowPNG

    @allow_p_n_g.setter
    def allow_p_n_g(self, value):
        """Alias for AllowPNG.setter"""
        self.AllowPNG = value

    @property
    def AlwaysSaveInDefaultEncoding(self):
        return self.com_object.AlwaysSaveInDefaultEncoding

    @AlwaysSaveInDefaultEncoding.setter
    def AlwaysSaveInDefaultEncoding(self, value):
        self.com_object.AlwaysSaveInDefaultEncoding = value

    @property
    def alwayssaveindefaultencoding(self):
        """Alias for AlwaysSaveInDefaultEncoding"""
        return self.AlwaysSaveInDefaultEncoding

    @alwayssaveindefaultencoding.setter
    def alwayssaveindefaultencoding(self, value):
        """Alias for AlwaysSaveInDefaultEncoding.setter"""
        self.AlwaysSaveInDefaultEncoding = value

    @property
    def always_save_in_default_encoding(self):
        """Alias for AlwaysSaveInDefaultEncoding"""
        return self.AlwaysSaveInDefaultEncoding

    @always_save_in_default_encoding.setter
    def always_save_in_default_encoding(self, value):
        """Alias for AlwaysSaveInDefaultEncoding.setter"""
        self.AlwaysSaveInDefaultEncoding = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BrowserLevel(self):
        return WdBrowserLevel(self.com_object.BrowserLevel)

    @BrowserLevel.setter
    def BrowserLevel(self, value):
        self.com_object.BrowserLevel = value

    @property
    def browserlevel(self):
        """Alias for BrowserLevel"""
        return self.BrowserLevel

    @browserlevel.setter
    def browserlevel(self, value):
        """Alias for BrowserLevel.setter"""
        self.BrowserLevel = value

    @property
    def browser_level(self):
        """Alias for BrowserLevel"""
        return self.BrowserLevel

    @browser_level.setter
    def browser_level(self, value):
        """Alias for BrowserLevel.setter"""
        self.BrowserLevel = value

    @property
    def CheckIfOfficeIsHTMLEditor(self):
        return self.com_object.CheckIfOfficeIsHTMLEditor

    @CheckIfOfficeIsHTMLEditor.setter
    def CheckIfOfficeIsHTMLEditor(self, value):
        self.com_object.CheckIfOfficeIsHTMLEditor = value

    @property
    def checkifofficeishtmleditor(self):
        """Alias for CheckIfOfficeIsHTMLEditor"""
        return self.CheckIfOfficeIsHTMLEditor

    @checkifofficeishtmleditor.setter
    def checkifofficeishtmleditor(self, value):
        """Alias for CheckIfOfficeIsHTMLEditor.setter"""
        self.CheckIfOfficeIsHTMLEditor = value

    @property
    def check_if_office_is_h_t_m_l_editor(self):
        """Alias for CheckIfOfficeIsHTMLEditor"""
        return self.CheckIfOfficeIsHTMLEditor

    @check_if_office_is_h_t_m_l_editor.setter
    def check_if_office_is_h_t_m_l_editor(self, value):
        """Alias for CheckIfOfficeIsHTMLEditor.setter"""
        self.CheckIfOfficeIsHTMLEditor = value

    @property
    def CheckIfWordIsDefaultHTMLEditor(self):
        return self.com_object.CheckIfWordIsDefaultHTMLEditor

    @CheckIfWordIsDefaultHTMLEditor.setter
    def CheckIfWordIsDefaultHTMLEditor(self, value):
        self.com_object.CheckIfWordIsDefaultHTMLEditor = value

    @property
    def checkifwordisdefaulthtmleditor(self):
        """Alias for CheckIfWordIsDefaultHTMLEditor"""
        return self.CheckIfWordIsDefaultHTMLEditor

    @checkifwordisdefaulthtmleditor.setter
    def checkifwordisdefaulthtmleditor(self, value):
        """Alias for CheckIfWordIsDefaultHTMLEditor.setter"""
        self.CheckIfWordIsDefaultHTMLEditor = value

    @property
    def check_if_word_is_default_h_t_m_l_editor(self):
        """Alias for CheckIfWordIsDefaultHTMLEditor"""
        return self.CheckIfWordIsDefaultHTMLEditor

    @check_if_word_is_default_h_t_m_l_editor.setter
    def check_if_word_is_default_h_t_m_l_editor(self, value):
        """Alias for CheckIfWordIsDefaultHTMLEditor.setter"""
        self.CheckIfWordIsDefaultHTMLEditor = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Encoding(self):
        return self.com_object.Encoding

    @Encoding.setter
    def Encoding(self, value):
        self.com_object.Encoding = value

    @property
    def encoding(self):
        """Alias for Encoding"""
        return self.Encoding

    @encoding.setter
    def encoding(self, value):
        """Alias for Encoding.setter"""
        self.Encoding = value

    @property
    def FolderSuffix(self):
        return self.com_object.FolderSuffix

    @property
    def foldersuffix(self):
        """Alias for FolderSuffix"""
        return self.FolderSuffix

    @property
    def folder_suffix(self):
        """Alias for FolderSuffix"""
        return self.FolderSuffix

    @property
    def Fonts(self):
        return self.com_object.Fonts

    @property
    def fonts(self):
        """Alias for Fonts"""
        return self.Fonts

    @property
    def OptimizeForBrowser(self):
        return self.com_object.OptimizeForBrowser

    @OptimizeForBrowser.setter
    def OptimizeForBrowser(self, value):
        self.com_object.OptimizeForBrowser = value

    @property
    def optimizeforbrowser(self):
        """Alias for OptimizeForBrowser"""
        return self.OptimizeForBrowser

    @optimizeforbrowser.setter
    def optimizeforbrowser(self, value):
        """Alias for OptimizeForBrowser.setter"""
        self.OptimizeForBrowser = value

    @property
    def optimize_for_browser(self):
        """Alias for OptimizeForBrowser"""
        return self.OptimizeForBrowser

    @optimize_for_browser.setter
    def optimize_for_browser(self, value):
        """Alias for OptimizeForBrowser.setter"""
        self.OptimizeForBrowser = value

    @property
    def OrganizeInFolder(self):
        return self.com_object.OrganizeInFolder

    @OrganizeInFolder.setter
    def OrganizeInFolder(self, value):
        self.com_object.OrganizeInFolder = value

    @property
    def organizeinfolder(self):
        """Alias for OrganizeInFolder"""
        return self.OrganizeInFolder

    @organizeinfolder.setter
    def organizeinfolder(self, value):
        """Alias for OrganizeInFolder.setter"""
        self.OrganizeInFolder = value

    @property
    def organize_in_folder(self):
        """Alias for OrganizeInFolder"""
        return self.OrganizeInFolder

    @organize_in_folder.setter
    def organize_in_folder(self, value):
        """Alias for OrganizeInFolder.setter"""
        self.OrganizeInFolder = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PixelsPerInch(self):
        return self.com_object.PixelsPerInch

    @PixelsPerInch.setter
    def PixelsPerInch(self, value):
        self.com_object.PixelsPerInch = value

    @property
    def pixelsperinch(self):
        """Alias for PixelsPerInch"""
        return self.PixelsPerInch

    @pixelsperinch.setter
    def pixelsperinch(self, value):
        """Alias for PixelsPerInch.setter"""
        self.PixelsPerInch = value

    @property
    def pixels_per_inch(self):
        """Alias for PixelsPerInch"""
        return self.PixelsPerInch

    @pixels_per_inch.setter
    def pixels_per_inch(self, value):
        """Alias for PixelsPerInch.setter"""
        self.PixelsPerInch = value

    @property
    def RelyOnCSS(self):
        return self.com_object.RelyOnCSS

    @RelyOnCSS.setter
    def RelyOnCSS(self, value):
        self.com_object.RelyOnCSS = value

    @property
    def relyoncss(self):
        """Alias for RelyOnCSS"""
        return self.RelyOnCSS

    @relyoncss.setter
    def relyoncss(self, value):
        """Alias for RelyOnCSS.setter"""
        self.RelyOnCSS = value

    @property
    def rely_on_c_s_s(self):
        """Alias for RelyOnCSS"""
        return self.RelyOnCSS

    @rely_on_c_s_s.setter
    def rely_on_c_s_s(self, value):
        """Alias for RelyOnCSS.setter"""
        self.RelyOnCSS = value

    @property
    def RelyOnVML(self):
        return self.com_object.RelyOnVML

    @RelyOnVML.setter
    def RelyOnVML(self, value):
        self.com_object.RelyOnVML = value

    @property
    def relyonvml(self):
        """Alias for RelyOnVML"""
        return self.RelyOnVML

    @relyonvml.setter
    def relyonvml(self, value):
        """Alias for RelyOnVML.setter"""
        self.RelyOnVML = value

    @property
    def rely_on_v_m_l(self):
        """Alias for RelyOnVML"""
        return self.RelyOnVML

    @rely_on_v_m_l.setter
    def rely_on_v_m_l(self, value):
        """Alias for RelyOnVML.setter"""
        self.RelyOnVML = value

    @property
    def SaveNewWebPagesAsWebArchives(self):
        return self.com_object.SaveNewWebPagesAsWebArchives

    @SaveNewWebPagesAsWebArchives.setter
    def SaveNewWebPagesAsWebArchives(self, value):
        self.com_object.SaveNewWebPagesAsWebArchives = value

    @property
    def savenewwebpagesaswebarchives(self):
        """Alias for SaveNewWebPagesAsWebArchives"""
        return self.SaveNewWebPagesAsWebArchives

    @savenewwebpagesaswebarchives.setter
    def savenewwebpagesaswebarchives(self, value):
        """Alias for SaveNewWebPagesAsWebArchives.setter"""
        self.SaveNewWebPagesAsWebArchives = value

    @property
    def save_new_web_pages_as_web_archives(self):
        """Alias for SaveNewWebPagesAsWebArchives"""
        return self.SaveNewWebPagesAsWebArchives

    @save_new_web_pages_as_web_archives.setter
    def save_new_web_pages_as_web_archives(self, value):
        """Alias for SaveNewWebPagesAsWebArchives.setter"""
        self.SaveNewWebPagesAsWebArchives = value

    @property
    def ScreenSize(self):
        return self.com_object.ScreenSize

    @ScreenSize.setter
    def ScreenSize(self, value):
        self.com_object.ScreenSize = value

    @property
    def screensize(self):
        """Alias for ScreenSize"""
        return self.ScreenSize

    @screensize.setter
    def screensize(self, value):
        """Alias for ScreenSize.setter"""
        self.ScreenSize = value

    @property
    def screen_size(self):
        """Alias for ScreenSize"""
        return self.ScreenSize

    @screen_size.setter
    def screen_size(self, value):
        """Alias for ScreenSize.setter"""
        self.ScreenSize = value

    @property
    def TargetBrowser(self):
        return self.com_object.TargetBrowser

    @TargetBrowser.setter
    def TargetBrowser(self, value):
        self.com_object.TargetBrowser = value

    @property
    def targetbrowser(self):
        """Alias for TargetBrowser"""
        return self.TargetBrowser

    @targetbrowser.setter
    def targetbrowser(self, value):
        """Alias for TargetBrowser.setter"""
        self.TargetBrowser = value

    @property
    def target_browser(self):
        """Alias for TargetBrowser"""
        return self.TargetBrowser

    @target_browser.setter
    def target_browser(self, value):
        """Alias for TargetBrowser.setter"""
        self.TargetBrowser = value

    @property
    def UpdateLinksOnSave(self):
        return self.com_object.UpdateLinksOnSave

    @UpdateLinksOnSave.setter
    def UpdateLinksOnSave(self, value):
        self.com_object.UpdateLinksOnSave = value

    @property
    def updatelinksonsave(self):
        """Alias for UpdateLinksOnSave"""
        return self.UpdateLinksOnSave

    @updatelinksonsave.setter
    def updatelinksonsave(self, value):
        """Alias for UpdateLinksOnSave.setter"""
        self.UpdateLinksOnSave = value

    @property
    def update_links_on_save(self):
        """Alias for UpdateLinksOnSave"""
        return self.UpdateLinksOnSave

    @update_links_on_save.setter
    def update_links_on_save(self, value):
        """Alias for UpdateLinksOnSave.setter"""
        self.UpdateLinksOnSave = value

    @property
    def UseLongFileNames(self):
        return self.com_object.UseLongFileNames

    @UseLongFileNames.setter
    def UseLongFileNames(self, value):
        self.com_object.UseLongFileNames = value

    @property
    def uselongfilenames(self):
        """Alias for UseLongFileNames"""
        return self.UseLongFileNames

    @uselongfilenames.setter
    def uselongfilenames(self, value):
        """Alias for UseLongFileNames.setter"""
        self.UseLongFileNames = value

    @property
    def use_long_file_names(self):
        """Alias for UseLongFileNames"""
        return self.UseLongFileNames

    @use_long_file_names.setter
    def use_long_file_names(self, value):
        """Alias for UseLongFileNames.setter"""
        self.UseLongFileNames = value


class Dialog:

    def __init__(self, dialog=None):
        self.com_object= dialog

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def CommandBarId(self):
        return self.com_object.CommandBarId

    @property
    def commandbarid(self):
        """Alias for CommandBarId"""
        return self.CommandBarId

    @property
    def command_bar_id(self):
        """Alias for CommandBarId"""
        return self.CommandBarId

    @property
    def CommandName(self):
        return self.com_object.CommandName

    @property
    def commandname(self):
        """Alias for CommandName"""
        return self.CommandName

    @property
    def command_name(self):
        """Alias for CommandName"""
        return self.CommandName

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DefaultTab(self):
        return WdWordDialogTab(self.com_object.DefaultTab)

    @DefaultTab.setter
    def DefaultTab(self, value):
        self.com_object.DefaultTab = value

    @property
    def defaulttab(self):
        """Alias for DefaultTab"""
        return self.DefaultTab

    @defaulttab.setter
    def defaulttab(self, value):
        """Alias for DefaultTab.setter"""
        self.DefaultTab = value

    @property
    def default_tab(self):
        """Alias for DefaultTab"""
        return self.DefaultTab

    @default_tab.setter
    def default_tab(self, value):
        """Alias for DefaultTab.setter"""
        self.DefaultTab = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Type(self):
        return WdWordDialog(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def Display(self, TimeOut=None):
        arguments = com_arguments([unwrap(a) for a in [TimeOut]])
        return self.com_object.Display(*arguments)

    def display(self, TimeOut=None):
        """Alias for Display"""
        arguments = [TimeOut]
        return self.Display(*arguments)

    def Execute(self):
        self.com_object.Execute()

    def execute(self):
        """Alias for Execute"""
        return self.Execute()

    def Show(self, TimeOut=None):
        arguments = com_arguments([unwrap(a) for a in [TimeOut]])
        return self.com_object.Show(*arguments)

    def show(self, TimeOut=None):
        """Alias for Show"""
        arguments = [TimeOut]
        return self.Show(*arguments)

    def Update(self):
        self.com_object.Update()

    def update(self):
        """Alias for Update"""
        return self.Update()


class Dialogs:

    def __init__(self, dialogs=None):
        self.com_object= dialogs

    def __call__(self, item):
        return Dialog(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Dialog(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Dictionaries:

    def __init__(self, dictionaries=None):
        self.com_object= dictionaries

    def __call__(self, item):
        return Dictionarie(self.com_object(item))

    @property
    def ActiveCustomDictionary(self):
        return Dictionary(self.com_object.ActiveCustomDictionary)

    @ActiveCustomDictionary.setter
    def ActiveCustomDictionary(self, value):
        self.com_object.ActiveCustomDictionary = value

    @property
    def activecustomdictionary(self):
        """Alias for ActiveCustomDictionary"""
        return self.ActiveCustomDictionary

    @activecustomdictionary.setter
    def activecustomdictionary(self, value):
        """Alias for ActiveCustomDictionary.setter"""
        self.ActiveCustomDictionary = value

    @property
    def active_custom_dictionary(self):
        """Alias for ActiveCustomDictionary"""
        return self.ActiveCustomDictionary

    @active_custom_dictionary.setter
    def active_custom_dictionary(self, value):
        """Alias for ActiveCustomDictionary.setter"""
        self.ActiveCustomDictionary = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Maximum(self):
        return self.com_object.Maximum

    @property
    def maximum(self):
        """Alias for Maximum"""
        return self.Maximum

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        return Dictionary(self.com_object.Add(*arguments))

    def add(self, FileName=None):
        """Alias for Add"""
        arguments = [FileName]
        return self.Add(*arguments)

    def ClearAll(self):
        self.com_object.ClearAll()

    def clearall(self):
        """Alias for ClearAll"""
        return self.ClearAll()

    def clear_all(self):
        """Alias for ClearAll"""
        return self.ClearAll()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Dictionary(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Dictionary:

    def __init__(self, dictionary=None):
        self.com_object= dictionary

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def LanguageID(self):
        return WdLanguageID(self.com_object.LanguageID)

    @LanguageID.setter
    def LanguageID(self, value):
        self.com_object.LanguageID = value

    @property
    def languageid(self):
        """Alias for LanguageID"""
        return self.LanguageID

    @languageid.setter
    def languageid(self, value):
        """Alias for LanguageID.setter"""
        self.LanguageID = value

    @property
    def language_i_d(self):
        """Alias for LanguageID"""
        return self.LanguageID

    @language_i_d.setter
    def language_i_d(self, value):
        """Alias for LanguageID.setter"""
        self.LanguageID = value

    @property
    def LanguageSpecific(self):
        return self.com_object.LanguageSpecific

    @LanguageSpecific.setter
    def LanguageSpecific(self, value):
        self.com_object.LanguageSpecific = value

    @property
    def languagespecific(self):
        """Alias for LanguageSpecific"""
        return self.LanguageSpecific

    @languagespecific.setter
    def languagespecific(self, value):
        """Alias for LanguageSpecific.setter"""
        self.LanguageSpecific = value

    @property
    def language_specific(self):
        """Alias for LanguageSpecific"""
        return self.LanguageSpecific

    @language_specific.setter
    def language_specific(self, value):
        """Alias for LanguageSpecific.setter"""
        self.LanguageSpecific = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Path(self):
        return self.com_object.Path

    @property
    def path(self):
        """Alias for Path"""
        return self.Path

    @property
    def ReadOnly(self):
        return self.com_object.ReadOnly

    @property
    def readonly(self):
        """Alias for ReadOnly"""
        return self.ReadOnly

    @property
    def read_only(self):
        """Alias for ReadOnly"""
        return self.ReadOnly

    @property
    def Type(self):
        return WdDictionaryType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class DisplayUnitLabel:

    def __init__(self, displayunitlabel=None):
        self.com_object= displayunitlabel

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    def Characters(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        if hasattr(self.com_object, "GetCharacters"):
            return ChartCharacters(self.com_object.GetCharacters(*arguments))
        else:
            return ChartCharacters(self.com_object.Characters(*arguments))

    def characters(self, Start=None, Length=None):
        """Alias for Characters"""
        arguments = [Start, Length]
        return self.Characters(*arguments)

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def FormulaLocal(self):
        return self.com_object.FormulaLocal

    @FormulaLocal.setter
    def FormulaLocal(self, value):
        self.com_object.FormulaLocal = value

    @property
    def formulalocal(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formulalocal.setter
    def formulalocal(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def formula_local(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formula_local.setter
    def formula_local(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def FormulaR1C1(self):
        return self.com_object.FormulaR1C1

    @FormulaR1C1.setter
    def FormulaR1C1(self, value):
        self.com_object.FormulaR1C1 = value

    @property
    def formular1c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formular1c1.setter
    def formular1c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def formula_r1_c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formula_r1_c1.setter
    def formula_r1_c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def FormulaR1C1Local(self):
        return self.com_object.FormulaR1C1Local

    @FormulaR1C1Local.setter
    def FormulaR1C1Local(self, value):
        self.com_object.FormulaR1C1Local = value

    @property
    def formular1c1local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formular1c1local.setter
    def formular1c1local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def formula_r1_c1_local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formula_r1_c1_local.setter
    def formula_r1_c1_local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def HorizontalAlignment(self):
        return self.com_object.HorizontalAlignment

    @HorizontalAlignment.setter
    def HorizontalAlignment(self, value):
        self.com_object.HorizontalAlignment = value

    @property
    def horizontalalignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontalalignment.setter
    def horizontalalignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def horizontal_alignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def IncludeInLayout(self):
        return self.com_object.IncludeInLayout

    @IncludeInLayout.setter
    def IncludeInLayout(self, value):
        self.com_object.IncludeInLayout = value

    @property
    def includeinlayout(self):
        """Alias for IncludeInLayout"""
        return self.IncludeInLayout

    @includeinlayout.setter
    def includeinlayout(self, value):
        """Alias for IncludeInLayout.setter"""
        self.IncludeInLayout = value

    @property
    def include_in_layout(self):
        """Alias for IncludeInLayout"""
        return self.IncludeInLayout

    @include_in_layout.setter
    def include_in_layout(self, value):
        """Alias for IncludeInLayout.setter"""
        self.IncludeInLayout = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return XlChartElementPosition(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def ReadingOrder(self):
        return XlReadingOrder(self.com_object.ReadingOrder)

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def VerticalAlignment(self):
        return self.com_object.VerticalAlignment

    @VerticalAlignment.setter
    def VerticalAlignment(self, value):
        self.com_object.VerticalAlignment = value

    @property
    def verticalalignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @verticalalignment.setter
    def verticalalignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def vertical_alignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @vertical_alignment.setter
    def vertical_alignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Document:

    def __init__(self, document=None):
        self.com_object= document

    @property
    def ActiveTheme(self):
        return self.com_object.ActiveTheme

    @property
    def activetheme(self):
        """Alias for ActiveTheme"""
        return self.ActiveTheme

    @property
    def active_theme(self):
        """Alias for ActiveTheme"""
        return self.ActiveTheme

    @property
    def ActiveThemeDisplayName(self):
        return self.com_object.ActiveThemeDisplayName

    @property
    def activethemedisplayname(self):
        """Alias for ActiveThemeDisplayName"""
        return self.ActiveThemeDisplayName

    @property
    def active_theme_display_name(self):
        """Alias for ActiveThemeDisplayName"""
        return self.ActiveThemeDisplayName

    @property
    def ActiveWindow(self):
        return Window(self.com_object.ActiveWindow)

    @property
    def activewindow(self):
        """Alias for ActiveWindow"""
        return self.ActiveWindow

    @property
    def active_window(self):
        """Alias for ActiveWindow"""
        return self.ActiveWindow

    @property
    def ActiveWritingStyle(self):
        return self.com_object.ActiveWritingStyle

    @ActiveWritingStyle.setter
    def ActiveWritingStyle(self, value):
        self.com_object.ActiveWritingStyle = value

    @property
    def activewritingstyle(self):
        """Alias for ActiveWritingStyle"""
        return self.ActiveWritingStyle

    @activewritingstyle.setter
    def activewritingstyle(self, value):
        """Alias for ActiveWritingStyle.setter"""
        self.ActiveWritingStyle = value

    @property
    def active_writing_style(self):
        """Alias for ActiveWritingStyle"""
        return self.ActiveWritingStyle

    @active_writing_style.setter
    def active_writing_style(self, value):
        """Alias for ActiveWritingStyle.setter"""
        self.ActiveWritingStyle = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AttachedTemplate(self):
        return Template(self.com_object.AttachedTemplate)

    @AttachedTemplate.setter
    def AttachedTemplate(self, value):
        self.com_object.AttachedTemplate = value

    @property
    def attachedtemplate(self):
        """Alias for AttachedTemplate"""
        return self.AttachedTemplate

    @attachedtemplate.setter
    def attachedtemplate(self, value):
        """Alias for AttachedTemplate.setter"""
        self.AttachedTemplate = value

    @property
    def attached_template(self):
        """Alias for AttachedTemplate"""
        return self.AttachedTemplate

    @attached_template.setter
    def attached_template(self, value):
        """Alias for AttachedTemplate.setter"""
        self.AttachedTemplate = value

    @property
    def AutoFormatOverride(self):
        return self.com_object.AutoFormatOverride

    @AutoFormatOverride.setter
    def AutoFormatOverride(self, value):
        self.com_object.AutoFormatOverride = value

    @property
    def autoformatoverride(self):
        """Alias for AutoFormatOverride"""
        return self.AutoFormatOverride

    @autoformatoverride.setter
    def autoformatoverride(self, value):
        """Alias for AutoFormatOverride.setter"""
        self.AutoFormatOverride = value

    @property
    def auto_format_override(self):
        """Alias for AutoFormatOverride"""
        return self.AutoFormatOverride

    @auto_format_override.setter
    def auto_format_override(self, value):
        """Alias for AutoFormatOverride.setter"""
        self.AutoFormatOverride = value

    @property
    def AutoHyphenation(self):
        return self.com_object.AutoHyphenation

    @AutoHyphenation.setter
    def AutoHyphenation(self, value):
        self.com_object.AutoHyphenation = value

    @property
    def autohyphenation(self):
        """Alias for AutoHyphenation"""
        return self.AutoHyphenation

    @autohyphenation.setter
    def autohyphenation(self, value):
        """Alias for AutoHyphenation.setter"""
        self.AutoHyphenation = value

    @property
    def auto_hyphenation(self):
        """Alias for AutoHyphenation"""
        return self.AutoHyphenation

    @auto_hyphenation.setter
    def auto_hyphenation(self, value):
        """Alias for AutoHyphenation.setter"""
        self.AutoHyphenation = value

    @property
    def AutoSaveOn(self):
        return self.com_object.AutoSaveOn

    @AutoSaveOn.setter
    def AutoSaveOn(self, value):
        self.com_object.AutoSaveOn = value

    @property
    def autosaveon(self):
        """Alias for AutoSaveOn"""
        return self.AutoSaveOn

    @autosaveon.setter
    def autosaveon(self, value):
        """Alias for AutoSaveOn.setter"""
        self.AutoSaveOn = value

    @property
    def auto_save_on(self):
        """Alias for AutoSaveOn"""
        return self.AutoSaveOn

    @auto_save_on.setter
    def auto_save_on(self, value):
        """Alias for AutoSaveOn.setter"""
        self.AutoSaveOn = value

    @property
    def Background(self):
        return Shape(self.com_object.Background)

    @property
    def background(self):
        """Alias for Background"""
        return self.Background

    @property
    def Bibliography(self):
        return Bibliography(self.com_object.Bibliography)

    @property
    def bibliography(self):
        """Alias for Bibliography"""
        return self.Bibliography

    @property
    def Bookmarks(self):
        return Bookmarks(self.com_object.Bookmarks)

    @property
    def bookmarks(self):
        """Alias for Bookmarks"""
        return self.Bookmarks

    @property
    def Broadcast(self):
        return self.com_object.Broadcast

    @property
    def broadcast(self):
        """Alias for Broadcast"""
        return self.Broadcast

    @property
    def BuiltInDocumentProperties(self):
        return self.com_object.BuiltInDocumentProperties

    @property
    def builtindocumentproperties(self):
        """Alias for BuiltInDocumentProperties"""
        return self.BuiltInDocumentProperties

    @property
    def built_in_document_properties(self):
        """Alias for BuiltInDocumentProperties"""
        return self.BuiltInDocumentProperties

    @property
    def Characters(self):
        return Characters(self.com_object.Characters)

    @property
    def characters(self):
        """Alias for Characters"""
        return self.Characters

    @property
    def ChartDataPointTrack(self):
        return self.com_object.ChartDataPointTrack

    @ChartDataPointTrack.setter
    def ChartDataPointTrack(self, value):
        self.com_object.ChartDataPointTrack = value

    @property
    def chartdatapointtrack(self):
        """Alias for ChartDataPointTrack"""
        return self.ChartDataPointTrack

    @chartdatapointtrack.setter
    def chartdatapointtrack(self, value):
        """Alias for ChartDataPointTrack.setter"""
        self.ChartDataPointTrack = value

    @property
    def chart_data_point_track(self):
        """Alias for ChartDataPointTrack"""
        return self.ChartDataPointTrack

    @chart_data_point_track.setter
    def chart_data_point_track(self, value):
        """Alias for ChartDataPointTrack.setter"""
        self.ChartDataPointTrack = value

    @property
    def ClickAndTypeParagraphStyle(self):
        return self.com_object.ClickAndTypeParagraphStyle

    @ClickAndTypeParagraphStyle.setter
    def ClickAndTypeParagraphStyle(self, value):
        self.com_object.ClickAndTypeParagraphStyle = value

    @property
    def clickandtypeparagraphstyle(self):
        """Alias for ClickAndTypeParagraphStyle"""
        return self.ClickAndTypeParagraphStyle

    @clickandtypeparagraphstyle.setter
    def clickandtypeparagraphstyle(self, value):
        """Alias for ClickAndTypeParagraphStyle.setter"""
        self.ClickAndTypeParagraphStyle = value

    @property
    def click_and_type_paragraph_style(self):
        """Alias for ClickAndTypeParagraphStyle"""
        return self.ClickAndTypeParagraphStyle

    @click_and_type_paragraph_style.setter
    def click_and_type_paragraph_style(self, value):
        """Alias for ClickAndTypeParagraphStyle.setter"""
        self.ClickAndTypeParagraphStyle = value

    @property
    def CoAuthoring(self):
        return self.com_object.CoAuthoring

    @property
    def coauthoring(self):
        """Alias for CoAuthoring"""
        return self.CoAuthoring

    @property
    def co_authoring(self):
        """Alias for CoAuthoring"""
        return self.CoAuthoring

    @property
    def CodeName(self):
        return self.com_object.CodeName

    @property
    def codename(self):
        """Alias for CodeName"""
        return self.CodeName

    @property
    def code_name(self):
        """Alias for CodeName"""
        return self.CodeName

    @property
    def CommandBars(self):
        return self.com_object.CommandBars

    @property
    def commandbars(self):
        """Alias for CommandBars"""
        return self.CommandBars

    @property
    def command_bars(self):
        """Alias for CommandBars"""
        return self.CommandBars

    @property
    def Comments(self):
        return Comments(self.com_object.Comments)

    @property
    def comments(self):
        """Alias for Comments"""
        return self.Comments

    @property
    def Compatibility(self):
        return self.com_object.Compatibility

    @Compatibility.setter
    def Compatibility(self, value):
        self.com_object.Compatibility = value

    @property
    def compatibility(self):
        """Alias for Compatibility"""
        return self.Compatibility

    @compatibility.setter
    def compatibility(self, value):
        """Alias for Compatibility.setter"""
        self.Compatibility = value

    @property
    def CompatibilityMode(self):
        return self.com_object.CompatibilityMode

    @property
    def compatibilitymode(self):
        """Alias for CompatibilityMode"""
        return self.CompatibilityMode

    @property
    def compatibility_mode(self):
        """Alias for CompatibilityMode"""
        return self.CompatibilityMode

    @property
    def ConsecutiveHyphensLimit(self):
        return self.com_object.ConsecutiveHyphensLimit

    @ConsecutiveHyphensLimit.setter
    def ConsecutiveHyphensLimit(self, value):
        self.com_object.ConsecutiveHyphensLimit = value

    @property
    def consecutivehyphenslimit(self):
        """Alias for ConsecutiveHyphensLimit"""
        return self.ConsecutiveHyphensLimit

    @consecutivehyphenslimit.setter
    def consecutivehyphenslimit(self, value):
        """Alias for ConsecutiveHyphensLimit.setter"""
        self.ConsecutiveHyphensLimit = value

    @property
    def consecutive_hyphens_limit(self):
        """Alias for ConsecutiveHyphensLimit"""
        return self.ConsecutiveHyphensLimit

    @consecutive_hyphens_limit.setter
    def consecutive_hyphens_limit(self, value):
        """Alias for ConsecutiveHyphensLimit.setter"""
        self.ConsecutiveHyphensLimit = value

    @property
    def Container(self):
        return self.com_object.Container

    @property
    def container(self):
        """Alias for Container"""
        return self.Container

    @property
    def Content(self):
        return Range(self.com_object.Content)

    @property
    def content(self):
        """Alias for Content"""
        return self.Content

    @property
    def ContentControls(self):
        return ContentControls(self.com_object.ContentControls)

    @property
    def contentcontrols(self):
        """Alias for ContentControls"""
        return self.ContentControls

    @property
    def content_controls(self):
        """Alias for ContentControls"""
        return self.ContentControls

    @property
    def ContentTypeProperties(self):
        return self.com_object.ContentTypeProperties

    @property
    def contenttypeproperties(self):
        """Alias for ContentTypeProperties"""
        return self.ContentTypeProperties

    @property
    def content_type_properties(self):
        """Alias for ContentTypeProperties"""
        return self.ContentTypeProperties

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def CurrentRsid(self):
        return self.com_object.CurrentRsid

    @property
    def currentrsid(self):
        """Alias for CurrentRsid"""
        return self.CurrentRsid

    @property
    def current_rsid(self):
        """Alias for CurrentRsid"""
        return self.CurrentRsid

    @property
    def CustomDocumentProperties(self):
        return self.com_object.CustomDocumentProperties

    @property
    def customdocumentproperties(self):
        """Alias for CustomDocumentProperties"""
        return self.CustomDocumentProperties

    @property
    def custom_document_properties(self):
        """Alias for CustomDocumentProperties"""
        return self.CustomDocumentProperties

    @property
    def CustomXMLParts(self):
        return self.com_object.CustomXMLParts

    @property
    def customxmlparts(self):
        """Alias for CustomXMLParts"""
        return self.CustomXMLParts

    @property
    def custom_x_m_l_parts(self):
        """Alias for CustomXMLParts"""
        return self.CustomXMLParts

    @property
    def DefaultTableStyle(self):
        return self.com_object.DefaultTableStyle

    @property
    def defaulttablestyle(self):
        """Alias for DefaultTableStyle"""
        return self.DefaultTableStyle

    @property
    def default_table_style(self):
        """Alias for DefaultTableStyle"""
        return self.DefaultTableStyle

    @property
    def DefaultTabStop(self):
        return self.com_object.DefaultTabStop

    @DefaultTabStop.setter
    def DefaultTabStop(self, value):
        self.com_object.DefaultTabStop = value

    @property
    def defaulttabstop(self):
        """Alias for DefaultTabStop"""
        return self.DefaultTabStop

    @defaulttabstop.setter
    def defaulttabstop(self, value):
        """Alias for DefaultTabStop.setter"""
        self.DefaultTabStop = value

    @property
    def default_tab_stop(self):
        """Alias for DefaultTabStop"""
        return self.DefaultTabStop

    @default_tab_stop.setter
    def default_tab_stop(self, value):
        """Alias for DefaultTabStop.setter"""
        self.DefaultTabStop = value

    @property
    def DefaultTargetFrame(self):
        return self.com_object.DefaultTargetFrame

    @DefaultTargetFrame.setter
    def DefaultTargetFrame(self, value):
        self.com_object.DefaultTargetFrame = value

    @property
    def defaulttargetframe(self):
        """Alias for DefaultTargetFrame"""
        return self.DefaultTargetFrame

    @defaulttargetframe.setter
    def defaulttargetframe(self, value):
        """Alias for DefaultTargetFrame.setter"""
        self.DefaultTargetFrame = value

    @property
    def default_target_frame(self):
        """Alias for DefaultTargetFrame"""
        return self.DefaultTargetFrame

    @default_target_frame.setter
    def default_target_frame(self, value):
        """Alias for DefaultTargetFrame.setter"""
        self.DefaultTargetFrame = value

    @property
    def DisableFeatures(self):
        return self.com_object.DisableFeatures

    @DisableFeatures.setter
    def DisableFeatures(self, value):
        self.com_object.DisableFeatures = value

    @property
    def disablefeatures(self):
        """Alias for DisableFeatures"""
        return self.DisableFeatures

    @disablefeatures.setter
    def disablefeatures(self, value):
        """Alias for DisableFeatures.setter"""
        self.DisableFeatures = value

    @property
    def disable_features(self):
        """Alias for DisableFeatures"""
        return self.DisableFeatures

    @disable_features.setter
    def disable_features(self, value):
        """Alias for DisableFeatures.setter"""
        self.DisableFeatures = value

    @property
    def DisableFeaturesIntroducedAfter(self):
        return self.com_object.DisableFeaturesIntroducedAfter

    @DisableFeaturesIntroducedAfter.setter
    def DisableFeaturesIntroducedAfter(self, value):
        self.com_object.DisableFeaturesIntroducedAfter = value

    @property
    def disablefeaturesintroducedafter(self):
        """Alias for DisableFeaturesIntroducedAfter"""
        return self.DisableFeaturesIntroducedAfter

    @disablefeaturesintroducedafter.setter
    def disablefeaturesintroducedafter(self, value):
        """Alias for DisableFeaturesIntroducedAfter.setter"""
        self.DisableFeaturesIntroducedAfter = value

    @property
    def disable_features_introduced_after(self):
        """Alias for DisableFeaturesIntroducedAfter"""
        return self.DisableFeaturesIntroducedAfter

    @disable_features_introduced_after.setter
    def disable_features_introduced_after(self, value):
        """Alias for DisableFeaturesIntroducedAfter.setter"""
        self.DisableFeaturesIntroducedAfter = value

    @property
    def DocumentInspectors(self):
        return self.com_object.DocumentInspectors

    @property
    def documentinspectors(self):
        """Alias for DocumentInspectors"""
        return self.DocumentInspectors

    @property
    def document_inspectors(self):
        """Alias for DocumentInspectors"""
        return self.DocumentInspectors

    @property
    def DocumentLibraryVersions(self):
        return self.com_object.DocumentLibraryVersions

    @property
    def documentlibraryversions(self):
        """Alias for DocumentLibraryVersions"""
        return self.DocumentLibraryVersions

    @property
    def document_library_versions(self):
        """Alias for DocumentLibraryVersions"""
        return self.DocumentLibraryVersions

    @property
    def DocumentTheme(self):
        return self.com_object.DocumentTheme

    @property
    def documenttheme(self):
        """Alias for DocumentTheme"""
        return self.DocumentTheme

    @property
    def document_theme(self):
        """Alias for DocumentTheme"""
        return self.DocumentTheme

    @property
    def DoNotEmbedSystemFonts(self):
        return self.com_object.DoNotEmbedSystemFonts

    @DoNotEmbedSystemFonts.setter
    def DoNotEmbedSystemFonts(self, value):
        self.com_object.DoNotEmbedSystemFonts = value

    @property
    def donotembedsystemfonts(self):
        """Alias for DoNotEmbedSystemFonts"""
        return self.DoNotEmbedSystemFonts

    @donotembedsystemfonts.setter
    def donotembedsystemfonts(self, value):
        """Alias for DoNotEmbedSystemFonts.setter"""
        self.DoNotEmbedSystemFonts = value

    @property
    def do_not_embed_system_fonts(self):
        """Alias for DoNotEmbedSystemFonts"""
        return self.DoNotEmbedSystemFonts

    @do_not_embed_system_fonts.setter
    def do_not_embed_system_fonts(self, value):
        """Alias for DoNotEmbedSystemFonts.setter"""
        self.DoNotEmbedSystemFonts = value

    @property
    def Email(self):
        return Email(self.com_object.Email)

    @property
    def email(self):
        """Alias for Email"""
        return self.Email

    @property
    def EmbedLinguisticData(self):
        return self.com_object.EmbedLinguisticData

    @EmbedLinguisticData.setter
    def EmbedLinguisticData(self, value):
        self.com_object.EmbedLinguisticData = value

    @property
    def embedlinguisticdata(self):
        """Alias for EmbedLinguisticData"""
        return self.EmbedLinguisticData

    @embedlinguisticdata.setter
    def embedlinguisticdata(self, value):
        """Alias for EmbedLinguisticData.setter"""
        self.EmbedLinguisticData = value

    @property
    def embed_linguistic_data(self):
        """Alias for EmbedLinguisticData"""
        return self.EmbedLinguisticData

    @embed_linguistic_data.setter
    def embed_linguistic_data(self, value):
        """Alias for EmbedLinguisticData.setter"""
        self.EmbedLinguisticData = value

    @property
    def EmbedTrueTypeFonts(self):
        return self.com_object.EmbedTrueTypeFonts

    @EmbedTrueTypeFonts.setter
    def EmbedTrueTypeFonts(self, value):
        self.com_object.EmbedTrueTypeFonts = value

    @property
    def embedtruetypefonts(self):
        """Alias for EmbedTrueTypeFonts"""
        return self.EmbedTrueTypeFonts

    @embedtruetypefonts.setter
    def embedtruetypefonts(self, value):
        """Alias for EmbedTrueTypeFonts.setter"""
        self.EmbedTrueTypeFonts = value

    @property
    def embed_true_type_fonts(self):
        """Alias for EmbedTrueTypeFonts"""
        return self.EmbedTrueTypeFonts

    @embed_true_type_fonts.setter
    def embed_true_type_fonts(self, value):
        """Alias for EmbedTrueTypeFonts.setter"""
        self.EmbedTrueTypeFonts = value

    @property
    def EncryptionProvider(self):
        return self.com_object.EncryptionProvider

    @EncryptionProvider.setter
    def EncryptionProvider(self, value):
        self.com_object.EncryptionProvider = value

    @property
    def encryptionprovider(self):
        """Alias for EncryptionProvider"""
        return self.EncryptionProvider

    @encryptionprovider.setter
    def encryptionprovider(self, value):
        """Alias for EncryptionProvider.setter"""
        self.EncryptionProvider = value

    @property
    def encryption_provider(self):
        """Alias for EncryptionProvider"""
        return self.EncryptionProvider

    @encryption_provider.setter
    def encryption_provider(self, value):
        """Alias for EncryptionProvider.setter"""
        self.EncryptionProvider = value

    @property
    def Endnotes(self):
        return Endnotes(self.com_object.Endnotes)

    @property
    def endnotes(self):
        """Alias for Endnotes"""
        return self.Endnotes

    @property
    def EnforceStyle(self):
        return self.com_object.EnforceStyle

    @EnforceStyle.setter
    def EnforceStyle(self, value):
        self.com_object.EnforceStyle = value

    @property
    def enforcestyle(self):
        """Alias for EnforceStyle"""
        return self.EnforceStyle

    @enforcestyle.setter
    def enforcestyle(self, value):
        """Alias for EnforceStyle.setter"""
        self.EnforceStyle = value

    @property
    def enforce_style(self):
        """Alias for EnforceStyle"""
        return self.EnforceStyle

    @enforce_style.setter
    def enforce_style(self, value):
        """Alias for EnforceStyle.setter"""
        self.EnforceStyle = value

    @property
    def Envelope(self):
        return Envelope(self.com_object.Envelope)

    @property
    def envelope(self):
        """Alias for Envelope"""
        return self.Envelope

    @property
    def FarEastLineBreakLanguage(self):
        return WdFarEastLineBreakLanguageID(self.com_object.FarEastLineBreakLanguage)

    @FarEastLineBreakLanguage.setter
    def FarEastLineBreakLanguage(self, value):
        self.com_object.FarEastLineBreakLanguage = value

    @property
    def fareastlinebreaklanguage(self):
        """Alias for FarEastLineBreakLanguage"""
        return self.FarEastLineBreakLanguage

    @fareastlinebreaklanguage.setter
    def fareastlinebreaklanguage(self, value):
        """Alias for FarEastLineBreakLanguage.setter"""
        self.FarEastLineBreakLanguage = value

    @property
    def far_east_line_break_language(self):
        """Alias for FarEastLineBreakLanguage"""
        return self.FarEastLineBreakLanguage

    @far_east_line_break_language.setter
    def far_east_line_break_language(self, value):
        """Alias for FarEastLineBreakLanguage.setter"""
        self.FarEastLineBreakLanguage = value

    @property
    def FarEastLineBreakLevel(self):
        return WdFarEastLineBreakLevel(self.com_object.FarEastLineBreakLevel)

    @FarEastLineBreakLevel.setter
    def FarEastLineBreakLevel(self, value):
        self.com_object.FarEastLineBreakLevel = value

    @property
    def fareastlinebreaklevel(self):
        """Alias for FarEastLineBreakLevel"""
        return self.FarEastLineBreakLevel

    @fareastlinebreaklevel.setter
    def fareastlinebreaklevel(self, value):
        """Alias for FarEastLineBreakLevel.setter"""
        self.FarEastLineBreakLevel = value

    @property
    def far_east_line_break_level(self):
        """Alias for FarEastLineBreakLevel"""
        return self.FarEastLineBreakLevel

    @far_east_line_break_level.setter
    def far_east_line_break_level(self, value):
        """Alias for FarEastLineBreakLevel.setter"""
        self.FarEastLineBreakLevel = value

    @property
    def Fields(self):
        return Fields(self.com_object.Fields)

    @property
    def fields(self):
        """Alias for Fields"""
        return self.Fields

    @property
    def Final(self):
        return self.com_object.Final

    @Final.setter
    def Final(self, value):
        self.com_object.Final = value

    @property
    def final(self):
        """Alias for Final"""
        return self.Final

    @final.setter
    def final(self, value):
        """Alias for Final.setter"""
        self.Final = value

    @property
    def Footnotes(self):
        return Footnotes(self.com_object.Footnotes)

    @property
    def footnotes(self):
        """Alias for Footnotes"""
        return self.Footnotes

    @property
    def FormattingShowClear(self):
        return self.com_object.FormattingShowClear

    @FormattingShowClear.setter
    def FormattingShowClear(self, value):
        self.com_object.FormattingShowClear = value

    @property
    def formattingshowclear(self):
        """Alias for FormattingShowClear"""
        return self.FormattingShowClear

    @formattingshowclear.setter
    def formattingshowclear(self, value):
        """Alias for FormattingShowClear.setter"""
        self.FormattingShowClear = value

    @property
    def formatting_show_clear(self):
        """Alias for FormattingShowClear"""
        return self.FormattingShowClear

    @formatting_show_clear.setter
    def formatting_show_clear(self, value):
        """Alias for FormattingShowClear.setter"""
        self.FormattingShowClear = value

    @property
    def FormattingShowFilter(self):
        return self.com_object.FormattingShowFilter

    @FormattingShowFilter.setter
    def FormattingShowFilter(self, value):
        self.com_object.FormattingShowFilter = value

    @property
    def formattingshowfilter(self):
        """Alias for FormattingShowFilter"""
        return self.FormattingShowFilter

    @formattingshowfilter.setter
    def formattingshowfilter(self, value):
        """Alias for FormattingShowFilter.setter"""
        self.FormattingShowFilter = value

    @property
    def formatting_show_filter(self):
        """Alias for FormattingShowFilter"""
        return self.FormattingShowFilter

    @formatting_show_filter.setter
    def formatting_show_filter(self, value):
        """Alias for FormattingShowFilter.setter"""
        self.FormattingShowFilter = value

    @property
    def FormattingShowFont(self):
        return self.com_object.FormattingShowFont

    @FormattingShowFont.setter
    def FormattingShowFont(self, value):
        self.com_object.FormattingShowFont = value

    @property
    def formattingshowfont(self):
        """Alias for FormattingShowFont"""
        return self.FormattingShowFont

    @formattingshowfont.setter
    def formattingshowfont(self, value):
        """Alias for FormattingShowFont.setter"""
        self.FormattingShowFont = value

    @property
    def formatting_show_font(self):
        """Alias for FormattingShowFont"""
        return self.FormattingShowFont

    @formatting_show_font.setter
    def formatting_show_font(self, value):
        """Alias for FormattingShowFont.setter"""
        self.FormattingShowFont = value

    @property
    def FormattingShowNextLevel(self):
        return self.com_object.FormattingShowNextLevel

    @FormattingShowNextLevel.setter
    def FormattingShowNextLevel(self, value):
        self.com_object.FormattingShowNextLevel = value

    @property
    def formattingshownextlevel(self):
        """Alias for FormattingShowNextLevel"""
        return self.FormattingShowNextLevel

    @formattingshownextlevel.setter
    def formattingshownextlevel(self, value):
        """Alias for FormattingShowNextLevel.setter"""
        self.FormattingShowNextLevel = value

    @property
    def formatting_show_next_level(self):
        """Alias for FormattingShowNextLevel"""
        return self.FormattingShowNextLevel

    @formatting_show_next_level.setter
    def formatting_show_next_level(self, value):
        """Alias for FormattingShowNextLevel.setter"""
        self.FormattingShowNextLevel = value

    @property
    def FormattingShowNumbering(self):
        return self.com_object.FormattingShowNumbering

    @FormattingShowNumbering.setter
    def FormattingShowNumbering(self, value):
        self.com_object.FormattingShowNumbering = value

    @property
    def formattingshownumbering(self):
        """Alias for FormattingShowNumbering"""
        return self.FormattingShowNumbering

    @formattingshownumbering.setter
    def formattingshownumbering(self, value):
        """Alias for FormattingShowNumbering.setter"""
        self.FormattingShowNumbering = value

    @property
    def formatting_show_numbering(self):
        """Alias for FormattingShowNumbering"""
        return self.FormattingShowNumbering

    @formatting_show_numbering.setter
    def formatting_show_numbering(self, value):
        """Alias for FormattingShowNumbering.setter"""
        self.FormattingShowNumbering = value

    @property
    def FormattingShowParagraph(self):
        return self.com_object.FormattingShowParagraph

    @FormattingShowParagraph.setter
    def FormattingShowParagraph(self, value):
        self.com_object.FormattingShowParagraph = value

    @property
    def formattingshowparagraph(self):
        """Alias for FormattingShowParagraph"""
        return self.FormattingShowParagraph

    @formattingshowparagraph.setter
    def formattingshowparagraph(self, value):
        """Alias for FormattingShowParagraph.setter"""
        self.FormattingShowParagraph = value

    @property
    def formatting_show_paragraph(self):
        """Alias for FormattingShowParagraph"""
        return self.FormattingShowParagraph

    @formatting_show_paragraph.setter
    def formatting_show_paragraph(self, value):
        """Alias for FormattingShowParagraph.setter"""
        self.FormattingShowParagraph = value

    @property
    def FormattingShowUserStyleName(self):
        return self.com_object.FormattingShowUserStyleName

    @FormattingShowUserStyleName.setter
    def FormattingShowUserStyleName(self, value):
        self.com_object.FormattingShowUserStyleName = value

    @property
    def formattingshowuserstylename(self):
        """Alias for FormattingShowUserStyleName"""
        return self.FormattingShowUserStyleName

    @formattingshowuserstylename.setter
    def formattingshowuserstylename(self, value):
        """Alias for FormattingShowUserStyleName.setter"""
        self.FormattingShowUserStyleName = value

    @property
    def formatting_show_user_style_name(self):
        """Alias for FormattingShowUserStyleName"""
        return self.FormattingShowUserStyleName

    @formatting_show_user_style_name.setter
    def formatting_show_user_style_name(self, value):
        """Alias for FormattingShowUserStyleName.setter"""
        self.FormattingShowUserStyleName = value

    @property
    def FormFields(self):
        return FormFields(self.com_object.FormFields)

    @property
    def formfields(self):
        """Alias for FormFields"""
        return self.FormFields

    @property
    def form_fields(self):
        """Alias for FormFields"""
        return self.FormFields

    @property
    def FormsDesign(self):
        return self.com_object.FormsDesign

    @property
    def formsdesign(self):
        """Alias for FormsDesign"""
        return self.FormsDesign

    @property
    def forms_design(self):
        """Alias for FormsDesign"""
        return self.FormsDesign

    @property
    def Frames(self):
        return Frames(self.com_object.Frames)

    @property
    def frames(self):
        """Alias for Frames"""
        return self.Frames

    @property
    def Frameset(self):
        return Frameset(self.com_object.Frameset)

    @property
    def frameset(self):
        """Alias for Frameset"""
        return self.Frameset

    @property
    def FullName(self):
        return self.com_object.FullName

    @property
    def fullname(self):
        """Alias for FullName"""
        return self.FullName

    @property
    def full_name(self):
        """Alias for FullName"""
        return self.FullName

    @property
    def GrammarChecked(self):
        return self.com_object.GrammarChecked

    @GrammarChecked.setter
    def GrammarChecked(self, value):
        self.com_object.GrammarChecked = value

    @property
    def grammarchecked(self):
        """Alias for GrammarChecked"""
        return self.GrammarChecked

    @grammarchecked.setter
    def grammarchecked(self, value):
        """Alias for GrammarChecked.setter"""
        self.GrammarChecked = value

    @property
    def grammar_checked(self):
        """Alias for GrammarChecked"""
        return self.GrammarChecked

    @grammar_checked.setter
    def grammar_checked(self, value):
        """Alias for GrammarChecked.setter"""
        self.GrammarChecked = value

    @property
    def GrammaticalErrors(self):
        return ProofreadingErrors(self.com_object.GrammaticalErrors)

    @property
    def grammaticalerrors(self):
        """Alias for GrammaticalErrors"""
        return self.GrammaticalErrors

    @property
    def grammatical_errors(self):
        """Alias for GrammaticalErrors"""
        return self.GrammaticalErrors

    @property
    def GridDistanceHorizontal(self):
        return self.com_object.GridDistanceHorizontal

    @GridDistanceHorizontal.setter
    def GridDistanceHorizontal(self, value):
        self.com_object.GridDistanceHorizontal = value

    @property
    def griddistancehorizontal(self):
        """Alias for GridDistanceHorizontal"""
        return self.GridDistanceHorizontal

    @griddistancehorizontal.setter
    def griddistancehorizontal(self, value):
        """Alias for GridDistanceHorizontal.setter"""
        self.GridDistanceHorizontal = value

    @property
    def grid_distance_horizontal(self):
        """Alias for GridDistanceHorizontal"""
        return self.GridDistanceHorizontal

    @grid_distance_horizontal.setter
    def grid_distance_horizontal(self, value):
        """Alias for GridDistanceHorizontal.setter"""
        self.GridDistanceHorizontal = value

    @property
    def GridDistanceVertical(self):
        return self.com_object.GridDistanceVertical

    @GridDistanceVertical.setter
    def GridDistanceVertical(self, value):
        self.com_object.GridDistanceVertical = value

    @property
    def griddistancevertical(self):
        """Alias for GridDistanceVertical"""
        return self.GridDistanceVertical

    @griddistancevertical.setter
    def griddistancevertical(self, value):
        """Alias for GridDistanceVertical.setter"""
        self.GridDistanceVertical = value

    @property
    def grid_distance_vertical(self):
        """Alias for GridDistanceVertical"""
        return self.GridDistanceVertical

    @grid_distance_vertical.setter
    def grid_distance_vertical(self, value):
        """Alias for GridDistanceVertical.setter"""
        self.GridDistanceVertical = value

    @property
    def GridOriginFromMargin(self):
        return self.com_object.GridOriginFromMargin

    @GridOriginFromMargin.setter
    def GridOriginFromMargin(self, value):
        self.com_object.GridOriginFromMargin = value

    @property
    def gridoriginfrommargin(self):
        """Alias for GridOriginFromMargin"""
        return self.GridOriginFromMargin

    @gridoriginfrommargin.setter
    def gridoriginfrommargin(self, value):
        """Alias for GridOriginFromMargin.setter"""
        self.GridOriginFromMargin = value

    @property
    def grid_origin_from_margin(self):
        """Alias for GridOriginFromMargin"""
        return self.GridOriginFromMargin

    @grid_origin_from_margin.setter
    def grid_origin_from_margin(self, value):
        """Alias for GridOriginFromMargin.setter"""
        self.GridOriginFromMargin = value

    @property
    def GridOriginHorizontal(self):
        return self.com_object.GridOriginHorizontal

    @GridOriginHorizontal.setter
    def GridOriginHorizontal(self, value):
        self.com_object.GridOriginHorizontal = value

    @property
    def gridoriginhorizontal(self):
        """Alias for GridOriginHorizontal"""
        return self.GridOriginHorizontal

    @gridoriginhorizontal.setter
    def gridoriginhorizontal(self, value):
        """Alias for GridOriginHorizontal.setter"""
        self.GridOriginHorizontal = value

    @property
    def grid_origin_horizontal(self):
        """Alias for GridOriginHorizontal"""
        return self.GridOriginHorizontal

    @grid_origin_horizontal.setter
    def grid_origin_horizontal(self, value):
        """Alias for GridOriginHorizontal.setter"""
        self.GridOriginHorizontal = value

    @property
    def GridOriginVertical(self):
        return self.com_object.GridOriginVertical

    @GridOriginVertical.setter
    def GridOriginVertical(self, value):
        self.com_object.GridOriginVertical = value

    @property
    def gridoriginvertical(self):
        """Alias for GridOriginVertical"""
        return self.GridOriginVertical

    @gridoriginvertical.setter
    def gridoriginvertical(self, value):
        """Alias for GridOriginVertical.setter"""
        self.GridOriginVertical = value

    @property
    def grid_origin_vertical(self):
        """Alias for GridOriginVertical"""
        return self.GridOriginVertical

    @grid_origin_vertical.setter
    def grid_origin_vertical(self, value):
        """Alias for GridOriginVertical.setter"""
        self.GridOriginVertical = value

    @property
    def GridSpaceBetweenHorizontalLines(self):
        return self.com_object.GridSpaceBetweenHorizontalLines

    @GridSpaceBetweenHorizontalLines.setter
    def GridSpaceBetweenHorizontalLines(self, value):
        self.com_object.GridSpaceBetweenHorizontalLines = value

    @property
    def gridspacebetweenhorizontallines(self):
        """Alias for GridSpaceBetweenHorizontalLines"""
        return self.GridSpaceBetweenHorizontalLines

    @gridspacebetweenhorizontallines.setter
    def gridspacebetweenhorizontallines(self, value):
        """Alias for GridSpaceBetweenHorizontalLines.setter"""
        self.GridSpaceBetweenHorizontalLines = value

    @property
    def grid_space_between_horizontal_lines(self):
        """Alias for GridSpaceBetweenHorizontalLines"""
        return self.GridSpaceBetweenHorizontalLines

    @grid_space_between_horizontal_lines.setter
    def grid_space_between_horizontal_lines(self, value):
        """Alias for GridSpaceBetweenHorizontalLines.setter"""
        self.GridSpaceBetweenHorizontalLines = value

    @property
    def GridSpaceBetweenVerticalLines(self):
        return self.com_object.GridSpaceBetweenVerticalLines

    @GridSpaceBetweenVerticalLines.setter
    def GridSpaceBetweenVerticalLines(self, value):
        self.com_object.GridSpaceBetweenVerticalLines = value

    @property
    def gridspacebetweenverticallines(self):
        """Alias for GridSpaceBetweenVerticalLines"""
        return self.GridSpaceBetweenVerticalLines

    @gridspacebetweenverticallines.setter
    def gridspacebetweenverticallines(self, value):
        """Alias for GridSpaceBetweenVerticalLines.setter"""
        self.GridSpaceBetweenVerticalLines = value

    @property
    def grid_space_between_vertical_lines(self):
        """Alias for GridSpaceBetweenVerticalLines"""
        return self.GridSpaceBetweenVerticalLines

    @grid_space_between_vertical_lines.setter
    def grid_space_between_vertical_lines(self, value):
        """Alias for GridSpaceBetweenVerticalLines.setter"""
        self.GridSpaceBetweenVerticalLines = value

    @property
    def HasPassword(self):
        return self.com_object.HasPassword

    @property
    def haspassword(self):
        """Alias for HasPassword"""
        return self.HasPassword

    @property
    def has_password(self):
        """Alias for HasPassword"""
        return self.HasPassword

    @property
    def HasVBProject(self):
        return self.com_object.HasVBProject

    @property
    def hasvbproject(self):
        """Alias for HasVBProject"""
        return self.HasVBProject

    @property
    def has_v_b_project(self):
        """Alias for HasVBProject"""
        return self.HasVBProject

    @property
    def HTMLDivisions(self):
        return HTMLDivisions(self.com_object.HTMLDivisions)

    @property
    def htmldivisions(self):
        """Alias for HTMLDivisions"""
        return self.HTMLDivisions

    @property
    def h_t_m_l_divisions(self):
        """Alias for HTMLDivisions"""
        return self.HTMLDivisions

    @property
    def Hyperlinks(self):
        return Hyperlinks(self.com_object.Hyperlinks)

    @property
    def hyperlinks(self):
        """Alias for Hyperlinks"""
        return self.Hyperlinks

    @property
    def HyphenateCaps(self):
        return self.com_object.HyphenateCaps

    @HyphenateCaps.setter
    def HyphenateCaps(self, value):
        self.com_object.HyphenateCaps = value

    @property
    def hyphenatecaps(self):
        """Alias for HyphenateCaps"""
        return self.HyphenateCaps

    @hyphenatecaps.setter
    def hyphenatecaps(self, value):
        """Alias for HyphenateCaps.setter"""
        self.HyphenateCaps = value

    @property
    def hyphenate_caps(self):
        """Alias for HyphenateCaps"""
        return self.HyphenateCaps

    @hyphenate_caps.setter
    def hyphenate_caps(self, value):
        """Alias for HyphenateCaps.setter"""
        self.HyphenateCaps = value

    @property
    def HyphenationZone(self):
        return self.com_object.HyphenationZone

    @HyphenationZone.setter
    def HyphenationZone(self, value):
        self.com_object.HyphenationZone = value

    @property
    def hyphenationzone(self):
        """Alias for HyphenationZone"""
        return self.HyphenationZone

    @hyphenationzone.setter
    def hyphenationzone(self, value):
        """Alias for HyphenationZone.setter"""
        self.HyphenationZone = value

    @property
    def hyphenation_zone(self):
        """Alias for HyphenationZone"""
        return self.HyphenationZone

    @hyphenation_zone.setter
    def hyphenation_zone(self, value):
        """Alias for HyphenationZone.setter"""
        self.HyphenationZone = value

    @property
    def Indexes(self):
        return Indexes(self.com_object.Indexes)

    @property
    def indexes(self):
        """Alias for Indexes"""
        return self.Indexes

    @property
    def InlineShapes(self):
        return InlineShapes(self.com_object.InlineShapes)

    @property
    def inlineshapes(self):
        """Alias for InlineShapes"""
        return self.InlineShapes

    @property
    def inline_shapes(self):
        """Alias for InlineShapes"""
        return self.InlineShapes

    @property
    def IsInAutosave(self):
        return self.com_object.IsInAutosave

    @property
    def isinautosave(self):
        """Alias for IsInAutosave"""
        return self.IsInAutosave

    @property
    def is_in_autosave(self):
        """Alias for IsInAutosave"""
        return self.IsInAutosave

    @property
    def IsMasterDocument(self):
        return self.com_object.IsMasterDocument

    @property
    def ismasterdocument(self):
        """Alias for IsMasterDocument"""
        return self.IsMasterDocument

    @property
    def is_master_document(self):
        """Alias for IsMasterDocument"""
        return self.IsMasterDocument

    @property
    def IsSubdocument(self):
        return self.com_object.IsSubdocument

    @property
    def issubdocument(self):
        """Alias for IsSubdocument"""
        return self.IsSubdocument

    @property
    def is_subdocument(self):
        """Alias for IsSubdocument"""
        return self.IsSubdocument

    @property
    def JustificationMode(self):
        return WdJustificationMode(self.com_object.JustificationMode)

    @JustificationMode.setter
    def JustificationMode(self, value):
        self.com_object.JustificationMode = value

    @property
    def justificationmode(self):
        """Alias for JustificationMode"""
        return self.JustificationMode

    @justificationmode.setter
    def justificationmode(self, value):
        """Alias for JustificationMode.setter"""
        self.JustificationMode = value

    @property
    def justification_mode(self):
        """Alias for JustificationMode"""
        return self.JustificationMode

    @justification_mode.setter
    def justification_mode(self, value):
        """Alias for JustificationMode.setter"""
        self.JustificationMode = value

    @property
    def KerningByAlgorithm(self):
        return self.com_object.KerningByAlgorithm

    @KerningByAlgorithm.setter
    def KerningByAlgorithm(self, value):
        self.com_object.KerningByAlgorithm = value

    @property
    def kerningbyalgorithm(self):
        """Alias for KerningByAlgorithm"""
        return self.KerningByAlgorithm

    @kerningbyalgorithm.setter
    def kerningbyalgorithm(self, value):
        """Alias for KerningByAlgorithm.setter"""
        self.KerningByAlgorithm = value

    @property
    def kerning_by_algorithm(self):
        """Alias for KerningByAlgorithm"""
        return self.KerningByAlgorithm

    @kerning_by_algorithm.setter
    def kerning_by_algorithm(self, value):
        """Alias for KerningByAlgorithm.setter"""
        self.KerningByAlgorithm = value

    @property
    def Kind(self):
        return WdDocumentKind(self.com_object.Kind)

    @Kind.setter
    def Kind(self, value):
        self.com_object.Kind = value

    @property
    def kind(self):
        """Alias for Kind"""
        return self.Kind

    @kind.setter
    def kind(self, value):
        """Alias for Kind.setter"""
        self.Kind = value

    @property
    def LanguageDetected(self):
        return self.com_object.LanguageDetected

    @LanguageDetected.setter
    def LanguageDetected(self, value):
        self.com_object.LanguageDetected = value

    @property
    def languagedetected(self):
        """Alias for LanguageDetected"""
        return self.LanguageDetected

    @languagedetected.setter
    def languagedetected(self, value):
        """Alias for LanguageDetected.setter"""
        self.LanguageDetected = value

    @property
    def language_detected(self):
        """Alias for LanguageDetected"""
        return self.LanguageDetected

    @language_detected.setter
    def language_detected(self, value):
        """Alias for LanguageDetected.setter"""
        self.LanguageDetected = value

    @property
    def ListParagraphs(self):
        return ListParagraphs(self.com_object.ListParagraphs)

    @property
    def listparagraphs(self):
        """Alias for ListParagraphs"""
        return self.ListParagraphs

    @property
    def list_paragraphs(self):
        """Alias for ListParagraphs"""
        return self.ListParagraphs

    @property
    def Lists(self):
        return Lists(self.com_object.Lists)

    @property
    def lists(self):
        """Alias for Lists"""
        return self.Lists

    @property
    def ListTemplates(self):
        return ListTemplates(self.com_object.ListTemplates)

    @property
    def listtemplates(self):
        """Alias for ListTemplates"""
        return self.ListTemplates

    @property
    def list_templates(self):
        """Alias for ListTemplates"""
        return self.ListTemplates

    @property
    def LockQuickStyleSet(self):
        return self.com_object.LockQuickStyleSet

    @LockQuickStyleSet.setter
    def LockQuickStyleSet(self, value):
        self.com_object.LockQuickStyleSet = value

    @property
    def lockquickstyleset(self):
        """Alias for LockQuickStyleSet"""
        return self.LockQuickStyleSet

    @lockquickstyleset.setter
    def lockquickstyleset(self, value):
        """Alias for LockQuickStyleSet.setter"""
        self.LockQuickStyleSet = value

    @property
    def lock_quick_style_set(self):
        """Alias for LockQuickStyleSet"""
        return self.LockQuickStyleSet

    @lock_quick_style_set.setter
    def lock_quick_style_set(self, value):
        """Alias for LockQuickStyleSet.setter"""
        self.LockQuickStyleSet = value

    @property
    def LockTheme(self):
        return self.com_object.LockTheme

    @LockTheme.setter
    def LockTheme(self, value):
        self.com_object.LockTheme = value

    @property
    def locktheme(self):
        """Alias for LockTheme"""
        return self.LockTheme

    @locktheme.setter
    def locktheme(self, value):
        """Alias for LockTheme.setter"""
        self.LockTheme = value

    @property
    def lock_theme(self):
        """Alias for LockTheme"""
        return self.LockTheme

    @lock_theme.setter
    def lock_theme(self, value):
        """Alias for LockTheme.setter"""
        self.LockTheme = value

    @property
    def MailEnvelope(self):
        return self.com_object.MailEnvelope

    @property
    def mailenvelope(self):
        """Alias for MailEnvelope"""
        return self.MailEnvelope

    @property
    def mail_envelope(self):
        """Alias for MailEnvelope"""
        return self.MailEnvelope

    @property
    def MailMerge(self):
        return MailMerge(self.com_object.MailMerge)

    @property
    def mailmerge(self):
        """Alias for MailMerge"""
        return self.MailMerge

    @property
    def mail_merge(self):
        """Alias for MailMerge"""
        return self.MailMerge

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NoLineBreakAfter(self):
        return self.com_object.NoLineBreakAfter

    @NoLineBreakAfter.setter
    def NoLineBreakAfter(self, value):
        self.com_object.NoLineBreakAfter = value

    @property
    def nolinebreakafter(self):
        """Alias for NoLineBreakAfter"""
        return self.NoLineBreakAfter

    @nolinebreakafter.setter
    def nolinebreakafter(self, value):
        """Alias for NoLineBreakAfter.setter"""
        self.NoLineBreakAfter = value

    @property
    def no_line_break_after(self):
        """Alias for NoLineBreakAfter"""
        return self.NoLineBreakAfter

    @no_line_break_after.setter
    def no_line_break_after(self, value):
        """Alias for NoLineBreakAfter.setter"""
        self.NoLineBreakAfter = value

    @property
    def NoLineBreakBefore(self):
        return self.com_object.NoLineBreakBefore

    @NoLineBreakBefore.setter
    def NoLineBreakBefore(self, value):
        self.com_object.NoLineBreakBefore = value

    @property
    def nolinebreakbefore(self):
        """Alias for NoLineBreakBefore"""
        return self.NoLineBreakBefore

    @nolinebreakbefore.setter
    def nolinebreakbefore(self, value):
        """Alias for NoLineBreakBefore.setter"""
        self.NoLineBreakBefore = value

    @property
    def no_line_break_before(self):
        """Alias for NoLineBreakBefore"""
        return self.NoLineBreakBefore

    @no_line_break_before.setter
    def no_line_break_before(self, value):
        """Alias for NoLineBreakBefore.setter"""
        self.NoLineBreakBefore = value

    @property
    def OMathBreakBin(self):
        return WdOMathBreakBin(self.com_object.OMathBreakBin)

    @OMathBreakBin.setter
    def OMathBreakBin(self, value):
        self.com_object.OMathBreakBin = value

    @property
    def omathbreakbin(self):
        """Alias for OMathBreakBin"""
        return self.OMathBreakBin

    @omathbreakbin.setter
    def omathbreakbin(self, value):
        """Alias for OMathBreakBin.setter"""
        self.OMathBreakBin = value

    @property
    def o_math_break_bin(self):
        """Alias for OMathBreakBin"""
        return self.OMathBreakBin

    @o_math_break_bin.setter
    def o_math_break_bin(self, value):
        """Alias for OMathBreakBin.setter"""
        self.OMathBreakBin = value

    @property
    def OMathBreakSub(self):
        return WdOMathBreakSub(self.com_object.OMathBreakSub)

    @OMathBreakSub.setter
    def OMathBreakSub(self, value):
        self.com_object.OMathBreakSub = value

    @property
    def omathbreaksub(self):
        """Alias for OMathBreakSub"""
        return self.OMathBreakSub

    @omathbreaksub.setter
    def omathbreaksub(self, value):
        """Alias for OMathBreakSub.setter"""
        self.OMathBreakSub = value

    @property
    def o_math_break_sub(self):
        """Alias for OMathBreakSub"""
        return self.OMathBreakSub

    @o_math_break_sub.setter
    def o_math_break_sub(self, value):
        """Alias for OMathBreakSub.setter"""
        self.OMathBreakSub = value

    @property
    def OMathFontName(self):
        return self.com_object.OMathFontName

    @OMathFontName.setter
    def OMathFontName(self, value):
        self.com_object.OMathFontName = value

    @property
    def omathfontname(self):
        """Alias for OMathFontName"""
        return self.OMathFontName

    @omathfontname.setter
    def omathfontname(self, value):
        """Alias for OMathFontName.setter"""
        self.OMathFontName = value

    @property
    def o_math_font_name(self):
        """Alias for OMathFontName"""
        return self.OMathFontName

    @o_math_font_name.setter
    def o_math_font_name(self, value):
        """Alias for OMathFontName.setter"""
        self.OMathFontName = value

    @property
    def OMathIntSubSupLim(self):
        return self.com_object.OMathIntSubSupLim

    @OMathIntSubSupLim.setter
    def OMathIntSubSupLim(self, value):
        self.com_object.OMathIntSubSupLim = value

    @property
    def omathintsubsuplim(self):
        """Alias for OMathIntSubSupLim"""
        return self.OMathIntSubSupLim

    @omathintsubsuplim.setter
    def omathintsubsuplim(self, value):
        """Alias for OMathIntSubSupLim.setter"""
        self.OMathIntSubSupLim = value

    @property
    def o_math_int_sub_sup_lim(self):
        """Alias for OMathIntSubSupLim"""
        return self.OMathIntSubSupLim

    @o_math_int_sub_sup_lim.setter
    def o_math_int_sub_sup_lim(self, value):
        """Alias for OMathIntSubSupLim.setter"""
        self.OMathIntSubSupLim = value

    @property
    def OMathJc(self):
        return WdOMathJc(self.com_object.OMathJc)

    @OMathJc.setter
    def OMathJc(self, value):
        self.com_object.OMathJc = value

    @property
    def omathjc(self):
        """Alias for OMathJc"""
        return self.OMathJc

    @omathjc.setter
    def omathjc(self, value):
        """Alias for OMathJc.setter"""
        self.OMathJc = value

    @property
    def o_math_jc(self):
        """Alias for OMathJc"""
        return self.OMathJc

    @o_math_jc.setter
    def o_math_jc(self, value):
        """Alias for OMathJc.setter"""
        self.OMathJc = value

    @property
    def OMathLeftMargin(self):
        return self.com_object.OMathLeftMargin

    @OMathLeftMargin.setter
    def OMathLeftMargin(self, value):
        self.com_object.OMathLeftMargin = value

    @property
    def omathleftmargin(self):
        """Alias for OMathLeftMargin"""
        return self.OMathLeftMargin

    @omathleftmargin.setter
    def omathleftmargin(self, value):
        """Alias for OMathLeftMargin.setter"""
        self.OMathLeftMargin = value

    @property
    def o_math_left_margin(self):
        """Alias for OMathLeftMargin"""
        return self.OMathLeftMargin

    @o_math_left_margin.setter
    def o_math_left_margin(self, value):
        """Alias for OMathLeftMargin.setter"""
        self.OMathLeftMargin = value

    @property
    def OMathNarySupSubLim(self):
        return self.com_object.OMathNarySupSubLim

    @OMathNarySupSubLim.setter
    def OMathNarySupSubLim(self, value):
        self.com_object.OMathNarySupSubLim = value

    @property
    def omathnarysupsublim(self):
        """Alias for OMathNarySupSubLim"""
        return self.OMathNarySupSubLim

    @omathnarysupsublim.setter
    def omathnarysupsublim(self, value):
        """Alias for OMathNarySupSubLim.setter"""
        self.OMathNarySupSubLim = value

    @property
    def o_math_nary_sup_sub_lim(self):
        """Alias for OMathNarySupSubLim"""
        return self.OMathNarySupSubLim

    @o_math_nary_sup_sub_lim.setter
    def o_math_nary_sup_sub_lim(self, value):
        """Alias for OMathNarySupSubLim.setter"""
        self.OMathNarySupSubLim = value

    @property
    def OMathRightMargin(self):
        return self.com_object.OMathRightMargin

    @OMathRightMargin.setter
    def OMathRightMargin(self, value):
        self.com_object.OMathRightMargin = value

    @property
    def omathrightmargin(self):
        """Alias for OMathRightMargin"""
        return self.OMathRightMargin

    @omathrightmargin.setter
    def omathrightmargin(self, value):
        """Alias for OMathRightMargin.setter"""
        self.OMathRightMargin = value

    @property
    def o_math_right_margin(self):
        """Alias for OMathRightMargin"""
        return self.OMathRightMargin

    @o_math_right_margin.setter
    def o_math_right_margin(self, value):
        """Alias for OMathRightMargin.setter"""
        self.OMathRightMargin = value

    @property
    def OMaths(self):
        return OMaths(self.com_object.OMaths)

    @property
    def omaths(self):
        """Alias for OMaths"""
        return self.OMaths

    @property
    def o_maths(self):
        """Alias for OMaths"""
        return self.OMaths

    @property
    def OMathSmallFrac(self):
        return self.com_object.OMathSmallFrac

    @OMathSmallFrac.setter
    def OMathSmallFrac(self, value):
        self.com_object.OMathSmallFrac = value

    @property
    def omathsmallfrac(self):
        """Alias for OMathSmallFrac"""
        return self.OMathSmallFrac

    @omathsmallfrac.setter
    def omathsmallfrac(self, value):
        """Alias for OMathSmallFrac.setter"""
        self.OMathSmallFrac = value

    @property
    def o_math_small_frac(self):
        """Alias for OMathSmallFrac"""
        return self.OMathSmallFrac

    @o_math_small_frac.setter
    def o_math_small_frac(self, value):
        """Alias for OMathSmallFrac.setter"""
        self.OMathSmallFrac = value

    @property
    def OMathWrap(self):
        return self.com_object.OMathWrap

    @OMathWrap.setter
    def OMathWrap(self, value):
        self.com_object.OMathWrap = value

    @property
    def omathwrap(self):
        """Alias for OMathWrap"""
        return self.OMathWrap

    @omathwrap.setter
    def omathwrap(self, value):
        """Alias for OMathWrap.setter"""
        self.OMathWrap = value

    @property
    def o_math_wrap(self):
        """Alias for OMathWrap"""
        return self.OMathWrap

    @o_math_wrap.setter
    def o_math_wrap(self, value):
        """Alias for OMathWrap.setter"""
        self.OMathWrap = value

    @property
    def OpenEncoding(self):
        return self.com_object.OpenEncoding

    @property
    def openencoding(self):
        """Alias for OpenEncoding"""
        return self.OpenEncoding

    @property
    def open_encoding(self):
        """Alias for OpenEncoding"""
        return self.OpenEncoding

    @property
    def OptimizeForWord97(self):
        return self.com_object.OptimizeForWord97

    @OptimizeForWord97.setter
    def OptimizeForWord97(self, value):
        self.com_object.OptimizeForWord97 = value

    @property
    def optimizeforword97(self):
        """Alias for OptimizeForWord97"""
        return self.OptimizeForWord97

    @optimizeforword97.setter
    def optimizeforword97(self, value):
        """Alias for OptimizeForWord97.setter"""
        self.OptimizeForWord97 = value

    @property
    def optimize_for_word97(self):
        """Alias for OptimizeForWord97"""
        return self.OptimizeForWord97

    @optimize_for_word97.setter
    def optimize_for_word97(self, value):
        """Alias for OptimizeForWord97.setter"""
        self.OptimizeForWord97 = value

    @property
    def OriginalDocumentTitle(self):
        return self.com_object.OriginalDocumentTitle

    @property
    def originaldocumenttitle(self):
        """Alias for OriginalDocumentTitle"""
        return self.OriginalDocumentTitle

    @property
    def original_document_title(self):
        """Alias for OriginalDocumentTitle"""
        return self.OriginalDocumentTitle

    @property
    def PageSetup(self):
        return PageSetup(self.com_object.PageSetup)

    @property
    def pagesetup(self):
        """Alias for PageSetup"""
        return self.PageSetup

    @property
    def page_setup(self):
        """Alias for PageSetup"""
        return self.PageSetup

    @property
    def Paragraphs(self):
        return Paragraphs(self.com_object.Paragraphs)

    @property
    def paragraphs(self):
        """Alias for Paragraphs"""
        return self.Paragraphs

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Password(self):
        return self.com_object.Password

    @property
    def password(self):
        """Alias for Password"""
        return self.Password

    @property
    def PasswordEncryptionAlgorithm(self):
        return self.com_object.PasswordEncryptionAlgorithm

    @property
    def passwordencryptionalgorithm(self):
        """Alias for PasswordEncryptionAlgorithm"""
        return self.PasswordEncryptionAlgorithm

    @property
    def password_encryption_algorithm(self):
        """Alias for PasswordEncryptionAlgorithm"""
        return self.PasswordEncryptionAlgorithm

    @property
    def PasswordEncryptionFileProperties(self):
        return self.com_object.PasswordEncryptionFileProperties

    @property
    def passwordencryptionfileproperties(self):
        """Alias for PasswordEncryptionFileProperties"""
        return self.PasswordEncryptionFileProperties

    @property
    def password_encryption_file_properties(self):
        """Alias for PasswordEncryptionFileProperties"""
        return self.PasswordEncryptionFileProperties

    @property
    def PasswordEncryptionKeyLength(self):
        return self.com_object.PasswordEncryptionKeyLength

    @property
    def passwordencryptionkeylength(self):
        """Alias for PasswordEncryptionKeyLength"""
        return self.PasswordEncryptionKeyLength

    @property
    def password_encryption_key_length(self):
        """Alias for PasswordEncryptionKeyLength"""
        return self.PasswordEncryptionKeyLength

    @property
    def PasswordEncryptionProvider(self):
        return self.com_object.PasswordEncryptionProvider

    @property
    def passwordencryptionprovider(self):
        """Alias for PasswordEncryptionProvider"""
        return self.PasswordEncryptionProvider

    @property
    def password_encryption_provider(self):
        """Alias for PasswordEncryptionProvider"""
        return self.PasswordEncryptionProvider

    @property
    def Path(self):
        return self.com_object.Path

    @property
    def path(self):
        """Alias for Path"""
        return self.Path

    @property
    def Permission(self):
        return self.com_object.Permission

    @property
    def permission(self):
        """Alias for Permission"""
        return self.Permission

    @property
    def PrintFormsData(self):
        return self.com_object.PrintFormsData

    @PrintFormsData.setter
    def PrintFormsData(self, value):
        self.com_object.PrintFormsData = value

    @property
    def printformsdata(self):
        """Alias for PrintFormsData"""
        return self.PrintFormsData

    @printformsdata.setter
    def printformsdata(self, value):
        """Alias for PrintFormsData.setter"""
        self.PrintFormsData = value

    @property
    def print_forms_data(self):
        """Alias for PrintFormsData"""
        return self.PrintFormsData

    @print_forms_data.setter
    def print_forms_data(self, value):
        """Alias for PrintFormsData.setter"""
        self.PrintFormsData = value

    @property
    def PrintPostScriptOverText(self):
        return self.com_object.PrintPostScriptOverText

    @PrintPostScriptOverText.setter
    def PrintPostScriptOverText(self, value):
        self.com_object.PrintPostScriptOverText = value

    @property
    def printpostscriptovertext(self):
        """Alias for PrintPostScriptOverText"""
        return self.PrintPostScriptOverText

    @printpostscriptovertext.setter
    def printpostscriptovertext(self, value):
        """Alias for PrintPostScriptOverText.setter"""
        self.PrintPostScriptOverText = value

    @property
    def print_post_script_over_text(self):
        """Alias for PrintPostScriptOverText"""
        return self.PrintPostScriptOverText

    @print_post_script_over_text.setter
    def print_post_script_over_text(self, value):
        """Alias for PrintPostScriptOverText.setter"""
        self.PrintPostScriptOverText = value

    @property
    def PrintRevisions(self):
        return self.com_object.PrintRevisions

    @PrintRevisions.setter
    def PrintRevisions(self, value):
        self.com_object.PrintRevisions = value

    @property
    def printrevisions(self):
        """Alias for PrintRevisions"""
        return self.PrintRevisions

    @printrevisions.setter
    def printrevisions(self, value):
        """Alias for PrintRevisions.setter"""
        self.PrintRevisions = value

    @property
    def print_revisions(self):
        """Alias for PrintRevisions"""
        return self.PrintRevisions

    @print_revisions.setter
    def print_revisions(self, value):
        """Alias for PrintRevisions.setter"""
        self.PrintRevisions = value

    @property
    def ProtectionType(self):
        return WdProtectionType(self.com_object.ProtectionType)

    @property
    def protectiontype(self):
        """Alias for ProtectionType"""
        return self.ProtectionType

    @property
    def protection_type(self):
        """Alias for ProtectionType"""
        return self.ProtectionType

    @property
    def ReadabilityStatistics(self):
        return ReadabilityStatistics(self.com_object.ReadabilityStatistics)

    @property
    def readabilitystatistics(self):
        """Alias for ReadabilityStatistics"""
        return self.ReadabilityStatistics

    @property
    def readability_statistics(self):
        """Alias for ReadabilityStatistics"""
        return self.ReadabilityStatistics

    @property
    def ReadingLayoutSizeX(self):
        return self.com_object.ReadingLayoutSizeX

    @property
    def readinglayoutsizex(self):
        """Alias for ReadingLayoutSizeX"""
        return self.ReadingLayoutSizeX

    @property
    def reading_layout_size_x(self):
        """Alias for ReadingLayoutSizeX"""
        return self.ReadingLayoutSizeX

    @property
    def ReadingLayoutSizeY(self):
        return self.com_object.ReadingLayoutSizeY

    @property
    def readinglayoutsizey(self):
        """Alias for ReadingLayoutSizeY"""
        return self.ReadingLayoutSizeY

    @property
    def reading_layout_size_y(self):
        """Alias for ReadingLayoutSizeY"""
        return self.ReadingLayoutSizeY

    @property
    def ReadingModeLayoutFrozen(self):
        return self.com_object.ReadingModeLayoutFrozen

    @property
    def readingmodelayoutfrozen(self):
        """Alias for ReadingModeLayoutFrozen"""
        return self.ReadingModeLayoutFrozen

    @property
    def reading_mode_layout_frozen(self):
        """Alias for ReadingModeLayoutFrozen"""
        return self.ReadingModeLayoutFrozen

    @property
    def ReadOnly(self):
        return self.com_object.ReadOnly

    @property
    def readonly(self):
        """Alias for ReadOnly"""
        return self.ReadOnly

    @property
    def read_only(self):
        """Alias for ReadOnly"""
        return self.ReadOnly

    @property
    def ReadOnlyRecommended(self):
        return self.com_object.ReadOnlyRecommended

    @ReadOnlyRecommended.setter
    def ReadOnlyRecommended(self, value):
        self.com_object.ReadOnlyRecommended = value

    @property
    def readonlyrecommended(self):
        """Alias for ReadOnlyRecommended"""
        return self.ReadOnlyRecommended

    @readonlyrecommended.setter
    def readonlyrecommended(self, value):
        """Alias for ReadOnlyRecommended.setter"""
        self.ReadOnlyRecommended = value

    @property
    def read_only_recommended(self):
        """Alias for ReadOnlyRecommended"""
        return self.ReadOnlyRecommended

    @read_only_recommended.setter
    def read_only_recommended(self, value):
        """Alias for ReadOnlyRecommended.setter"""
        self.ReadOnlyRecommended = value

    @property
    def RemoveDateAndTime(self):
        return self.com_object.RemoveDateAndTime

    @property
    def removedateandtime(self):
        """Alias for RemoveDateAndTime"""
        return self.RemoveDateAndTime

    @property
    def remove_date_and_time(self):
        """Alias for RemoveDateAndTime"""
        return self.RemoveDateAndTime

    @property
    def RemovePersonalInformation(self):
        return self.com_object.RemovePersonalInformation

    @RemovePersonalInformation.setter
    def RemovePersonalInformation(self, value):
        self.com_object.RemovePersonalInformation = value

    @property
    def removepersonalinformation(self):
        """Alias for RemovePersonalInformation"""
        return self.RemovePersonalInformation

    @removepersonalinformation.setter
    def removepersonalinformation(self, value):
        """Alias for RemovePersonalInformation.setter"""
        self.RemovePersonalInformation = value

    @property
    def remove_personal_information(self):
        """Alias for RemovePersonalInformation"""
        return self.RemovePersonalInformation

    @remove_personal_information.setter
    def remove_personal_information(self, value):
        """Alias for RemovePersonalInformation.setter"""
        self.RemovePersonalInformation = value

    @property
    def Research(self):
        return Research(self.com_object.Research)

    @property
    def research(self):
        """Alias for Research"""
        return self.Research

    @property
    def RevisedDocumentTitle(self):
        return self.com_object.RevisedDocumentTitle

    @property
    def reviseddocumenttitle(self):
        """Alias for RevisedDocumentTitle"""
        return self.RevisedDocumentTitle

    @property
    def revised_document_title(self):
        """Alias for RevisedDocumentTitle"""
        return self.RevisedDocumentTitle

    @property
    def Revisions(self):
        return Revisions(self.com_object.Revisions)

    @property
    def revisions(self):
        """Alias for Revisions"""
        return self.Revisions

    @property
    def Saved(self):
        return self.com_object.Saved

    @Saved.setter
    def Saved(self, value):
        self.com_object.Saved = value

    @property
    def saved(self):
        """Alias for Saved"""
        return self.Saved

    @saved.setter
    def saved(self, value):
        """Alias for Saved.setter"""
        self.Saved = value

    @property
    def SaveEncoding(self):
        return self.com_object.SaveEncoding

    @SaveEncoding.setter
    def SaveEncoding(self, value):
        self.com_object.SaveEncoding = value

    @property
    def saveencoding(self):
        """Alias for SaveEncoding"""
        return self.SaveEncoding

    @saveencoding.setter
    def saveencoding(self, value):
        """Alias for SaveEncoding.setter"""
        self.SaveEncoding = value

    @property
    def save_encoding(self):
        """Alias for SaveEncoding"""
        return self.SaveEncoding

    @save_encoding.setter
    def save_encoding(self, value):
        """Alias for SaveEncoding.setter"""
        self.SaveEncoding = value

    @property
    def SaveFormat(self):
        return self.com_object.SaveFormat

    @property
    def saveformat(self):
        """Alias for SaveFormat"""
        return self.SaveFormat

    @property
    def save_format(self):
        """Alias for SaveFormat"""
        return self.SaveFormat

    @property
    def SaveFormsData(self):
        return self.com_object.SaveFormsData

    @SaveFormsData.setter
    def SaveFormsData(self, value):
        self.com_object.SaveFormsData = value

    @property
    def saveformsdata(self):
        """Alias for SaveFormsData"""
        return self.SaveFormsData

    @saveformsdata.setter
    def saveformsdata(self, value):
        """Alias for SaveFormsData.setter"""
        self.SaveFormsData = value

    @property
    def save_forms_data(self):
        """Alias for SaveFormsData"""
        return self.SaveFormsData

    @save_forms_data.setter
    def save_forms_data(self, value):
        """Alias for SaveFormsData.setter"""
        self.SaveFormsData = value

    @property
    def SaveSubsetFonts(self):
        return self.com_object.SaveSubsetFonts

    @SaveSubsetFonts.setter
    def SaveSubsetFonts(self, value):
        self.com_object.SaveSubsetFonts = value

    @property
    def savesubsetfonts(self):
        """Alias for SaveSubsetFonts"""
        return self.SaveSubsetFonts

    @savesubsetfonts.setter
    def savesubsetfonts(self, value):
        """Alias for SaveSubsetFonts.setter"""
        self.SaveSubsetFonts = value

    @property
    def save_subset_fonts(self):
        """Alias for SaveSubsetFonts"""
        return self.SaveSubsetFonts

    @save_subset_fonts.setter
    def save_subset_fonts(self, value):
        """Alias for SaveSubsetFonts.setter"""
        self.SaveSubsetFonts = value

    @property
    def Scripts(self):
        return self.com_object.Scripts

    @property
    def scripts(self):
        """Alias for Scripts"""
        return self.Scripts

    @property
    def Sections(self):
        return Section(self.com_object.Sections)

    @property
    def sections(self):
        """Alias for Sections"""
        return self.Sections

    @property
    def SensitivityLabel(self):
        return self.com_object.SensitivityLabel

    @property
    def sensitivitylabel(self):
        """Alias for SensitivityLabel"""
        return self.SensitivityLabel

    @property
    def sensitivity_label(self):
        """Alias for SensitivityLabel"""
        return self.SensitivityLabel

    @property
    def Sentences(self):
        return Sentences(self.com_object.Sentences)

    @property
    def sentences(self):
        """Alias for Sentences"""
        return self.Sentences

    @property
    def ServerPolicy(self):
        return self.com_object.ServerPolicy

    @property
    def serverpolicy(self):
        """Alias for ServerPolicy"""
        return self.ServerPolicy

    @property
    def server_policy(self):
        """Alias for ServerPolicy"""
        return self.ServerPolicy

    @property
    def Shapes(self):
        return Shapes(self.com_object.Shapes)

    @property
    def shapes(self):
        """Alias for Shapes"""
        return self.Shapes

    @property
    def ShowGrammaticalErrors(self):
        return self.com_object.ShowGrammaticalErrors

    @ShowGrammaticalErrors.setter
    def ShowGrammaticalErrors(self, value):
        self.com_object.ShowGrammaticalErrors = value

    @property
    def showgrammaticalerrors(self):
        """Alias for ShowGrammaticalErrors"""
        return self.ShowGrammaticalErrors

    @showgrammaticalerrors.setter
    def showgrammaticalerrors(self, value):
        """Alias for ShowGrammaticalErrors.setter"""
        self.ShowGrammaticalErrors = value

    @property
    def show_grammatical_errors(self):
        """Alias for ShowGrammaticalErrors"""
        return self.ShowGrammaticalErrors

    @show_grammatical_errors.setter
    def show_grammatical_errors(self, value):
        """Alias for ShowGrammaticalErrors.setter"""
        self.ShowGrammaticalErrors = value

    @property
    def ShowSpellingErrors(self):
        return self.com_object.ShowSpellingErrors

    @ShowSpellingErrors.setter
    def ShowSpellingErrors(self, value):
        self.com_object.ShowSpellingErrors = value

    @property
    def showspellingerrors(self):
        """Alias for ShowSpellingErrors"""
        return self.ShowSpellingErrors

    @showspellingerrors.setter
    def showspellingerrors(self, value):
        """Alias for ShowSpellingErrors.setter"""
        self.ShowSpellingErrors = value

    @property
    def show_spelling_errors(self):
        """Alias for ShowSpellingErrors"""
        return self.ShowSpellingErrors

    @show_spelling_errors.setter
    def show_spelling_errors(self, value):
        """Alias for ShowSpellingErrors.setter"""
        self.ShowSpellingErrors = value

    @property
    def Signatures(self):
        return self.com_object.Signatures

    @property
    def signatures(self):
        """Alias for Signatures"""
        return self.Signatures

    @property
    def SmartDocument(self):
        return self.com_object.SmartDocument

    @property
    def smartdocument(self):
        """Alias for SmartDocument"""
        return self.SmartDocument

    @property
    def smart_document(self):
        """Alias for SmartDocument"""
        return self.SmartDocument

    @property
    def SnapToGrid(self):
        return self.com_object.SnapToGrid

    @SnapToGrid.setter
    def SnapToGrid(self, value):
        self.com_object.SnapToGrid = value

    @property
    def snaptogrid(self):
        """Alias for SnapToGrid"""
        return self.SnapToGrid

    @snaptogrid.setter
    def snaptogrid(self, value):
        """Alias for SnapToGrid.setter"""
        self.SnapToGrid = value

    @property
    def snap_to_grid(self):
        """Alias for SnapToGrid"""
        return self.SnapToGrid

    @snap_to_grid.setter
    def snap_to_grid(self, value):
        """Alias for SnapToGrid.setter"""
        self.SnapToGrid = value

    @property
    def SnapToShapes(self):
        return self.com_object.SnapToShapes

    @SnapToShapes.setter
    def SnapToShapes(self, value):
        self.com_object.SnapToShapes = value

    @property
    def snaptoshapes(self):
        """Alias for SnapToShapes"""
        return self.SnapToShapes

    @snaptoshapes.setter
    def snaptoshapes(self, value):
        """Alias for SnapToShapes.setter"""
        self.SnapToShapes = value

    @property
    def snap_to_shapes(self):
        """Alias for SnapToShapes"""
        return self.SnapToShapes

    @snap_to_shapes.setter
    def snap_to_shapes(self, value):
        """Alias for SnapToShapes.setter"""
        self.SnapToShapes = value

    @property
    def SpellingChecked(self):
        return self.com_object.SpellingChecked

    @SpellingChecked.setter
    def SpellingChecked(self, value):
        self.com_object.SpellingChecked = value

    @property
    def spellingchecked(self):
        """Alias for SpellingChecked"""
        return self.SpellingChecked

    @spellingchecked.setter
    def spellingchecked(self, value):
        """Alias for SpellingChecked.setter"""
        self.SpellingChecked = value

    @property
    def spelling_checked(self):
        """Alias for SpellingChecked"""
        return self.SpellingChecked

    @spelling_checked.setter
    def spelling_checked(self, value):
        """Alias for SpellingChecked.setter"""
        self.SpellingChecked = value

    @property
    def SpellingErrors(self):
        return ProofreadingErrors(self.com_object.SpellingErrors)

    @property
    def spellingerrors(self):
        """Alias for SpellingErrors"""
        return self.SpellingErrors

    @property
    def spelling_errors(self):
        """Alias for SpellingErrors"""
        return self.SpellingErrors

    @property
    def StoryRanges(self):
        return StoryRanges(self.com_object.StoryRanges)

    @property
    def storyranges(self):
        """Alias for StoryRanges"""
        return self.StoryRanges

    @property
    def story_ranges(self):
        """Alias for StoryRanges"""
        return self.StoryRanges

    @property
    def Styles(self):
        return Styles(self.com_object.Styles)

    @property
    def styles(self):
        """Alias for Styles"""
        return self.Styles

    @property
    def StyleSheets(self):
        return StyleSheets(self.com_object.StyleSheets)

    @property
    def stylesheets(self):
        """Alias for StyleSheets"""
        return self.StyleSheets

    @property
    def style_sheets(self):
        """Alias for StyleSheets"""
        return self.StyleSheets

    @property
    def StyleSortMethod(self):
        return WdStyleSort(self.com_object.StyleSortMethod)

    @StyleSortMethod.setter
    def StyleSortMethod(self, value):
        self.com_object.StyleSortMethod = value

    @property
    def stylesortmethod(self):
        """Alias for StyleSortMethod"""
        return self.StyleSortMethod

    @stylesortmethod.setter
    def stylesortmethod(self, value):
        """Alias for StyleSortMethod.setter"""
        self.StyleSortMethod = value

    @property
    def style_sort_method(self):
        """Alias for StyleSortMethod"""
        return self.StyleSortMethod

    @style_sort_method.setter
    def style_sort_method(self, value):
        """Alias for StyleSortMethod.setter"""
        self.StyleSortMethod = value

    @property
    def Subdocuments(self):
        return Subdocuments(self.com_object.Subdocuments)

    @property
    def subdocuments(self):
        """Alias for Subdocuments"""
        return self.Subdocuments

    @property
    def Sync(self):
        return self.com_object.Sync

    @property
    def sync(self):
        """Alias for Sync"""
        return self.Sync

    @property
    def Tables(self):
        return Table(self.com_object.Tables)

    @property
    def tables(self):
        """Alias for Tables"""
        return self.Tables

    @property
    def TablesOfAuthorities(self):
        return TableOfAuthorities(self.com_object.TablesOfAuthorities)

    @property
    def tablesofauthorities(self):
        """Alias for TablesOfAuthorities"""
        return self.TablesOfAuthorities

    @property
    def tables_of_authorities(self):
        """Alias for TablesOfAuthorities"""
        return self.TablesOfAuthorities

    @property
    def TablesOfAuthoritiesCategories(self):
        return TablesOfAuthoritiesCategories(self.com_object.TablesOfAuthoritiesCategories)

    @property
    def tablesofauthoritiescategories(self):
        """Alias for TablesOfAuthoritiesCategories"""
        return self.TablesOfAuthoritiesCategories

    @property
    def tables_of_authorities_categories(self):
        """Alias for TablesOfAuthoritiesCategories"""
        return self.TablesOfAuthoritiesCategories

    @property
    def TablesOfContents(self):
        return TablesOfContents(self.com_object.TablesOfContents)

    @property
    def tablesofcontents(self):
        """Alias for TablesOfContents"""
        return self.TablesOfContents

    @property
    def tables_of_contents(self):
        """Alias for TablesOfContents"""
        return self.TablesOfContents

    @property
    def TablesOfFigures(self):
        return TablesOfFigures(self.com_object.TablesOfFigures)

    @property
    def tablesoffigures(self):
        """Alias for TablesOfFigures"""
        return self.TablesOfFigures

    @property
    def tables_of_figures(self):
        """Alias for TablesOfFigures"""
        return self.TablesOfFigures

    @property
    def TextEncoding(self):
        return self.com_object.TextEncoding

    @TextEncoding.setter
    def TextEncoding(self, value):
        self.com_object.TextEncoding = value

    @property
    def textencoding(self):
        """Alias for TextEncoding"""
        return self.TextEncoding

    @textencoding.setter
    def textencoding(self, value):
        """Alias for TextEncoding.setter"""
        self.TextEncoding = value

    @property
    def text_encoding(self):
        """Alias for TextEncoding"""
        return self.TextEncoding

    @text_encoding.setter
    def text_encoding(self, value):
        """Alias for TextEncoding.setter"""
        self.TextEncoding = value

    @property
    def TextLineEnding(self):
        return WdLineEndingType(self.com_object.TextLineEnding)

    @TextLineEnding.setter
    def TextLineEnding(self, value):
        self.com_object.TextLineEnding = value

    @property
    def textlineending(self):
        """Alias for TextLineEnding"""
        return self.TextLineEnding

    @textlineending.setter
    def textlineending(self, value):
        """Alias for TextLineEnding.setter"""
        self.TextLineEnding = value

    @property
    def text_line_ending(self):
        """Alias for TextLineEnding"""
        return self.TextLineEnding

    @text_line_ending.setter
    def text_line_ending(self, value):
        """Alias for TextLineEnding.setter"""
        self.TextLineEnding = value

    @property
    def TrackFormatting(self):
        return self.com_object.TrackFormatting

    @TrackFormatting.setter
    def TrackFormatting(self, value):
        self.com_object.TrackFormatting = value

    @property
    def trackformatting(self):
        """Alias for TrackFormatting"""
        return self.TrackFormatting

    @trackformatting.setter
    def trackformatting(self, value):
        """Alias for TrackFormatting.setter"""
        self.TrackFormatting = value

    @property
    def track_formatting(self):
        """Alias for TrackFormatting"""
        return self.TrackFormatting

    @track_formatting.setter
    def track_formatting(self, value):
        """Alias for TrackFormatting.setter"""
        self.TrackFormatting = value

    @property
    def TrackMoves(self):
        return self.com_object.TrackMoves

    @TrackMoves.setter
    def TrackMoves(self, value):
        self.com_object.TrackMoves = value

    @property
    def trackmoves(self):
        """Alias for TrackMoves"""
        return self.TrackMoves

    @trackmoves.setter
    def trackmoves(self, value):
        """Alias for TrackMoves.setter"""
        self.TrackMoves = value

    @property
    def track_moves(self):
        """Alias for TrackMoves"""
        return self.TrackMoves

    @track_moves.setter
    def track_moves(self, value):
        """Alias for TrackMoves.setter"""
        self.TrackMoves = value

    @property
    def TrackRevisions(self):
        return self.com_object.TrackRevisions

    @TrackRevisions.setter
    def TrackRevisions(self, value):
        self.com_object.TrackRevisions = value

    @property
    def trackrevisions(self):
        """Alias for TrackRevisions"""
        return self.TrackRevisions

    @trackrevisions.setter
    def trackrevisions(self, value):
        """Alias for TrackRevisions.setter"""
        self.TrackRevisions = value

    @property
    def track_revisions(self):
        """Alias for TrackRevisions"""
        return self.TrackRevisions

    @track_revisions.setter
    def track_revisions(self, value):
        """Alias for TrackRevisions.setter"""
        self.TrackRevisions = value

    @property
    def Type(self):
        return WdDocumentType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def UpdateStylesOnOpen(self):
        return self.com_object.UpdateStylesOnOpen

    @UpdateStylesOnOpen.setter
    def UpdateStylesOnOpen(self, value):
        self.com_object.UpdateStylesOnOpen = value

    @property
    def updatestylesonopen(self):
        """Alias for UpdateStylesOnOpen"""
        return self.UpdateStylesOnOpen

    @updatestylesonopen.setter
    def updatestylesonopen(self, value):
        """Alias for UpdateStylesOnOpen.setter"""
        self.UpdateStylesOnOpen = value

    @property
    def update_styles_on_open(self):
        """Alias for UpdateStylesOnOpen"""
        return self.UpdateStylesOnOpen

    @update_styles_on_open.setter
    def update_styles_on_open(self, value):
        """Alias for UpdateStylesOnOpen.setter"""
        self.UpdateStylesOnOpen = value

    @property
    def UseMathDefaults(self):
        return self.com_object.UseMathDefaults

    @UseMathDefaults.setter
    def UseMathDefaults(self, value):
        self.com_object.UseMathDefaults = value

    @property
    def usemathdefaults(self):
        """Alias for UseMathDefaults"""
        return self.UseMathDefaults

    @usemathdefaults.setter
    def usemathdefaults(self, value):
        """Alias for UseMathDefaults.setter"""
        self.UseMathDefaults = value

    @property
    def use_math_defaults(self):
        """Alias for UseMathDefaults"""
        return self.UseMathDefaults

    @use_math_defaults.setter
    def use_math_defaults(self, value):
        """Alias for UseMathDefaults.setter"""
        self.UseMathDefaults = value

    @property
    def UserControl(self):
        return self.com_object.UserControl

    @UserControl.setter
    def UserControl(self, value):
        self.com_object.UserControl = value

    @property
    def usercontrol(self):
        """Alias for UserControl"""
        return self.UserControl

    @usercontrol.setter
    def usercontrol(self, value):
        """Alias for UserControl.setter"""
        self.UserControl = value

    @property
    def user_control(self):
        """Alias for UserControl"""
        return self.UserControl

    @user_control.setter
    def user_control(self, value):
        """Alias for UserControl.setter"""
        self.UserControl = value

    @property
    def Variables(self):
        return Variables(self.com_object.Variables)

    @property
    def variables(self):
        """Alias for Variables"""
        return self.Variables

    @property
    def VBASigned(self):
        return self.com_object.VBASigned

    @property
    def vbasigned(self):
        """Alias for VBASigned"""
        return self.VBASigned

    @property
    def v_b_a_signed(self):
        """Alias for VBASigned"""
        return self.VBASigned

    @property
    def VBProject(self):
        return self.com_object.VBProject

    @property
    def vbproject(self):
        """Alias for VBProject"""
        return self.VBProject

    @property
    def v_b_project(self):
        """Alias for VBProject"""
        return self.VBProject

    @property
    def WebOptions(self):
        return WebOptions(self.com_object.WebOptions)

    @property
    def weboptions(self):
        """Alias for WebOptions"""
        return self.WebOptions

    @property
    def web_options(self):
        """Alias for WebOptions"""
        return self.WebOptions

    @property
    def Windows(self):
        return Windows(self.com_object.Windows)

    @property
    def windows(self):
        """Alias for Windows"""
        return self.Windows

    @property
    def WordOpenXML(self):
        return self.com_object.WordOpenXML

    @property
    def wordopenxml(self):
        """Alias for WordOpenXML"""
        return self.WordOpenXML

    @property
    def word_open_x_m_l(self):
        """Alias for WordOpenXML"""
        return self.WordOpenXML

    @property
    def Words(self):
        return Words(self.com_object.Words)

    @property
    def words(self):
        """Alias for Words"""
        return self.Words

    @property
    def WritePassword(self):
        return self.com_object.WritePassword

    @property
    def writepassword(self):
        """Alias for WritePassword"""
        return self.WritePassword

    @property
    def write_password(self):
        """Alias for WritePassword"""
        return self.WritePassword

    @property
    def WriteReserved(self):
        return self.com_object.WriteReserved

    @property
    def writereserved(self):
        """Alias for WriteReserved"""
        return self.WriteReserved

    @property
    def write_reserved(self):
        """Alias for WriteReserved"""
        return self.WriteReserved

    @property
    def XMLSaveThroughXSLT(self):
        return self.com_object.XMLSaveThroughXSLT

    @property
    def xmlsavethroughxslt(self):
        """Alias for XMLSaveThroughXSLT"""
        return self.XMLSaveThroughXSLT

    @property
    def x_m_l_save_through_x_s_l_t(self):
        """Alias for XMLSaveThroughXSLT"""
        return self.XMLSaveThroughXSLT

    @property
    def XMLSchemaReferences(self):
        return self.com_object.XMLSchemaReferences

    @property
    def xmlschemareferences(self):
        """Alias for XMLSchemaReferences"""
        return self.XMLSchemaReferences

    @property
    def x_m_l_schema_references(self):
        """Alias for XMLSchemaReferences"""
        return self.XMLSchemaReferences

    @property
    def XMLShowAdvancedErrors(self):
        return self.com_object.XMLShowAdvancedErrors

    @XMLShowAdvancedErrors.setter
    def XMLShowAdvancedErrors(self, value):
        self.com_object.XMLShowAdvancedErrors = value

    @property
    def xmlshowadvancederrors(self):
        """Alias for XMLShowAdvancedErrors"""
        return self.XMLShowAdvancedErrors

    @xmlshowadvancederrors.setter
    def xmlshowadvancederrors(self, value):
        """Alias for XMLShowAdvancedErrors.setter"""
        self.XMLShowAdvancedErrors = value

    @property
    def x_m_l_show_advanced_errors(self):
        """Alias for XMLShowAdvancedErrors"""
        return self.XMLShowAdvancedErrors

    @x_m_l_show_advanced_errors.setter
    def x_m_l_show_advanced_errors(self, value):
        """Alias for XMLShowAdvancedErrors.setter"""
        self.XMLShowAdvancedErrors = value

    @property
    def XMLUseXSLTWhenSaving(self):
        return self.com_object.XMLUseXSLTWhenSaving

    @property
    def xmlusexsltwhensaving(self):
        """Alias for XMLUseXSLTWhenSaving"""
        return self.XMLUseXSLTWhenSaving

    @property
    def x_m_l_use_x_s_l_t_when_saving(self):
        """Alias for XMLUseXSLTWhenSaving"""
        return self.XMLUseXSLTWhenSaving

    def AcceptAllRevisions(self):
        self.com_object.AcceptAllRevisions()

    def acceptallrevisions(self):
        """Alias for AcceptAllRevisions"""
        return self.AcceptAllRevisions()

    def accept_all_revisions(self):
        """Alias for AcceptAllRevisions"""
        return self.AcceptAllRevisions()

    def AcceptAllRevisionsShown(self):
        self.com_object.AcceptAllRevisionsShown()

    def acceptallrevisionsshown(self):
        """Alias for AcceptAllRevisionsShown"""
        return self.AcceptAllRevisionsShown()

    def accept_all_revisions_shown(self):
        """Alias for AcceptAllRevisionsShown"""
        return self.AcceptAllRevisionsShown()

    def Activate(self):
        self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()

    def AddToFavorites(self):
        self.com_object.AddToFavorites()

    def addtofavorites(self):
        """Alias for AddToFavorites"""
        return self.AddToFavorites()

    def add_to_favorites(self):
        """Alias for AddToFavorites"""
        return self.AddToFavorites()

    def ApplyQuickStyleSet2(self, Style=None):
        arguments = com_arguments([unwrap(a) for a in [Style]])
        self.com_object.ApplyQuickStyleSet2(*arguments)

    def applyquickstyleset2(self, Style=None):
        """Alias for ApplyQuickStyleSet2"""
        arguments = [Style]
        return self.ApplyQuickStyleSet2(*arguments)

    def apply_quick_style_set2(self, Style=None):
        """Alias for ApplyQuickStyleSet2"""
        arguments = [Style]
        return self.ApplyQuickStyleSet2(*arguments)

    def ApplyTheme(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        self.com_object.ApplyTheme(*arguments)

    def applytheme(self, Name=None):
        """Alias for ApplyTheme"""
        arguments = [Name]
        return self.ApplyTheme(*arguments)

    def apply_theme(self, Name=None):
        """Alias for ApplyTheme"""
        arguments = [Name]
        return self.ApplyTheme(*arguments)

    def AutoFormat(self):
        self.com_object.AutoFormat()

    def autoformat(self):
        """Alias for AutoFormat"""
        return self.AutoFormat()

    def auto_format(self):
        """Alias for AutoFormat"""
        return self.AutoFormat()

    def CanCheckin(self):
        return self.com_object.CanCheckin()

    def cancheckin(self):
        """Alias for CanCheckin"""
        return self.CanCheckin()

    def can_checkin(self):
        """Alias for CanCheckin"""
        return self.CanCheckin()

    def CheckConsistency(self):
        self.com_object.CheckConsistency()

    def checkconsistency(self):
        """Alias for CheckConsistency"""
        return self.CheckConsistency()

    def check_consistency(self):
        """Alias for CheckConsistency"""
        return self.CheckConsistency()

    def CheckGrammar(self):
        self.com_object.CheckGrammar()

    def checkgrammar(self):
        """Alias for CheckGrammar"""
        return self.CheckGrammar()

    def check_grammar(self):
        """Alias for CheckGrammar"""
        return self.CheckGrammar()

    def CheckIn(self, SaveChanges=None, Comments=None, MakePublic=None):
        arguments = com_arguments([unwrap(a) for a in [SaveChanges, Comments, MakePublic]])
        self.com_object.CheckIn(*arguments)

    def checkin(self, SaveChanges=None, Comments=None, MakePublic=None):
        """Alias for CheckIn"""
        arguments = [SaveChanges, Comments, MakePublic]
        return self.CheckIn(*arguments)

    def check_in(self, SaveChanges=None, Comments=None, MakePublic=None):
        """Alias for CheckIn"""
        arguments = [SaveChanges, Comments, MakePublic]
        return self.CheckIn(*arguments)

    def CheckInWithVersion(self, SaveChanges=None, Comments=None, MakePublic=None, VersionType=None):
        arguments = com_arguments([unwrap(a) for a in [SaveChanges, Comments, MakePublic, VersionType]])
        self.com_object.CheckInWithVersion(*arguments)

    def checkinwithversion(self, SaveChanges=None, Comments=None, MakePublic=None, VersionType=None):
        """Alias for CheckInWithVersion"""
        arguments = [SaveChanges, Comments, MakePublic, VersionType]
        return self.CheckInWithVersion(*arguments)

    def check_in_with_version(self, SaveChanges=None, Comments=None, MakePublic=None, VersionType=None):
        """Alias for CheckInWithVersion"""
        arguments = [SaveChanges, Comments, MakePublic, VersionType]
        return self.CheckInWithVersion(*arguments)

    def CheckSpelling(self, CustomDictionary=None, IgnoreUppercase=None, AlwaysSuggest=None, CustomDictionary2=None, CustomDictionary3=None, CustomDictionary4=None, CustomDictionary5=None, CustomDictionary6=None, CustomDictionary7=None, CustomDictionary8=None, CustomDictionary9=None, CustomDictionary10=None):
        arguments = com_arguments([unwrap(a) for a in [CustomDictionary, IgnoreUppercase, AlwaysSuggest, CustomDictionary2, CustomDictionary3, CustomDictionary4, CustomDictionary5, CustomDictionary6, CustomDictionary7, CustomDictionary8, CustomDictionary9, CustomDictionary10]])
        self.com_object.CheckSpelling(*arguments)

    def checkspelling(self, CustomDictionary=None, IgnoreUppercase=None, AlwaysSuggest=None, CustomDictionary2=None, CustomDictionary3=None, CustomDictionary4=None, CustomDictionary5=None, CustomDictionary6=None, CustomDictionary7=None, CustomDictionary8=None, CustomDictionary9=None, CustomDictionary10=None):
        """Alias for CheckSpelling"""
        arguments = [CustomDictionary, IgnoreUppercase, AlwaysSuggest, CustomDictionary2, CustomDictionary3, CustomDictionary4, CustomDictionary5, CustomDictionary6, CustomDictionary7, CustomDictionary8, CustomDictionary9, CustomDictionary10]
        return self.CheckSpelling(*arguments)

    def check_spelling(self, CustomDictionary=None, IgnoreUppercase=None, AlwaysSuggest=None, CustomDictionary2=None, CustomDictionary3=None, CustomDictionary4=None, CustomDictionary5=None, CustomDictionary6=None, CustomDictionary7=None, CustomDictionary8=None, CustomDictionary9=None, CustomDictionary10=None):
        """Alias for CheckSpelling"""
        arguments = [CustomDictionary, IgnoreUppercase, AlwaysSuggest, CustomDictionary2, CustomDictionary3, CustomDictionary4, CustomDictionary5, CustomDictionary6, CustomDictionary7, CustomDictionary8, CustomDictionary9, CustomDictionary10]
        return self.CheckSpelling(*arguments)

    def Close(self, SaveChanges=None, OriginalFormat=None, RouteDocument=None):
        arguments = com_arguments([unwrap(a) for a in [SaveChanges, OriginalFormat, RouteDocument]])
        self.com_object.Close(*arguments)

    def close(self, SaveChanges=None, OriginalFormat=None, RouteDocument=None):
        """Alias for Close"""
        arguments = [SaveChanges, OriginalFormat, RouteDocument]
        return self.Close(*arguments)

    def ClosePrintPreview(self):
        self.com_object.ClosePrintPreview()

    def closeprintpreview(self):
        """Alias for ClosePrintPreview"""
        return self.ClosePrintPreview()

    def close_print_preview(self):
        """Alias for ClosePrintPreview"""
        return self.ClosePrintPreview()

    def Compare(self, Name=None, AuthorName=None, CompareTarget=None, DetectFormatChanges=None, IgnoreAllComparisonWarnings=None, AddToRecentFiles=None, RemovePersonalInformation=None, RemoveDateAndTime=None):
        arguments = com_arguments([unwrap(a) for a in [Name, AuthorName, CompareTarget, DetectFormatChanges, IgnoreAllComparisonWarnings, AddToRecentFiles, RemovePersonalInformation, RemoveDateAndTime]])
        self.com_object.Compare(*arguments)

    def compare(self, Name=None, AuthorName=None, CompareTarget=None, DetectFormatChanges=None, IgnoreAllComparisonWarnings=None, AddToRecentFiles=None, RemovePersonalInformation=None, RemoveDateAndTime=None):
        """Alias for Compare"""
        arguments = [Name, AuthorName, CompareTarget, DetectFormatChanges, IgnoreAllComparisonWarnings, AddToRecentFiles, RemovePersonalInformation, RemoveDateAndTime]
        return self.Compare(*arguments)

    def ComputeStatistics(self, Statistic=None, IncludeFootnotesAndEndnotes=None):
        arguments = com_arguments([unwrap(a) for a in [Statistic, IncludeFootnotesAndEndnotes]])
        self.com_object.ComputeStatistics(*arguments)

    def computestatistics(self, Statistic=None, IncludeFootnotesAndEndnotes=None):
        """Alias for ComputeStatistics"""
        arguments = [Statistic, IncludeFootnotesAndEndnotes]
        return self.ComputeStatistics(*arguments)

    def compute_statistics(self, Statistic=None, IncludeFootnotesAndEndnotes=None):
        """Alias for ComputeStatistics"""
        arguments = [Statistic, IncludeFootnotesAndEndnotes]
        return self.ComputeStatistics(*arguments)

    def Convert(self):
        self.com_object.Convert()

    def convert(self):
        """Alias for Convert"""
        return self.Convert()

    def ConvertAutoHyphens(self):
        self.com_object.ConvertAutoHyphens()

    def convertautohyphens(self):
        """Alias for ConvertAutoHyphens"""
        return self.ConvertAutoHyphens()

    def convert_auto_hyphens(self):
        """Alias for ConvertAutoHyphens"""
        return self.ConvertAutoHyphens()

    def ConvertNumbersToText(self):
        self.com_object.ConvertNumbersToText()

    def convertnumberstotext(self):
        """Alias for ConvertNumbersToText"""
        return self.ConvertNumbersToText()

    def convert_numbers_to_text(self):
        """Alias for ConvertNumbersToText"""
        return self.ConvertNumbersToText()

    def ConvertVietDoc(self, CodePageOrigin=None):
        arguments = com_arguments([unwrap(a) for a in [CodePageOrigin]])
        self.com_object.ConvertVietDoc(*arguments)

    def convertvietdoc(self, CodePageOrigin=None):
        """Alias for ConvertVietDoc"""
        arguments = [CodePageOrigin]
        return self.ConvertVietDoc(*arguments)

    def convert_viet_doc(self, CodePageOrigin=None):
        """Alias for ConvertVietDoc"""
        arguments = [CodePageOrigin]
        return self.ConvertVietDoc(*arguments)

    def CopyStylesFromTemplate(self, Template=None):
        arguments = com_arguments([unwrap(a) for a in [Template]])
        self.com_object.CopyStylesFromTemplate(*arguments)

    def copystylesfromtemplate(self, Template=None):
        """Alias for CopyStylesFromTemplate"""
        arguments = [Template]
        return self.CopyStylesFromTemplate(*arguments)

    def copy_styles_from_template(self, Template=None):
        """Alias for CopyStylesFromTemplate"""
        arguments = [Template]
        return self.CopyStylesFromTemplate(*arguments)

    def CountNumberedItems(self, NumberType=None, Level=None):
        arguments = com_arguments([unwrap(a) for a in [NumberType, Level]])
        self.com_object.CountNumberedItems(*arguments)

    def countnumbereditems(self, NumberType=None, Level=None):
        """Alias for CountNumberedItems"""
        arguments = [NumberType, Level]
        return self.CountNumberedItems(*arguments)

    def count_numbered_items(self, NumberType=None, Level=None):
        """Alias for CountNumberedItems"""
        arguments = [NumberType, Level]
        return self.CountNumberedItems(*arguments)

    def CreateLetterContent(self, DateFormat=None, IncludeHeaderFooter=None, PageDesign=None, LetterStyle=None, Letterhead=None, LetterheadLocation=None, LetterheadSize=None, RecipientName=None, RecipientAddress=None, Salutation=None, SalutationType=None, RecipientReference=None, MailingInstructions=None, AttentionLine=None, Subject=None, CCList=None, ReturnAddress=None, SenderName=None, Closing=None, SenderCompany=None, SenderJobTitle=None, SenderInitials=None, EnclosureNumber=None, InfoBlock=None, RecipientCode=None, RecipientGender=None, ReturnAddressShortForm=None, SenderCity=None, SenderCode=None, SenderGender=None, SenderReference=None):
        arguments = com_arguments([unwrap(a) for a in [DateFormat, IncludeHeaderFooter, PageDesign, LetterStyle, Letterhead, LetterheadLocation, LetterheadSize, RecipientName, RecipientAddress, Salutation, SalutationType, RecipientReference, MailingInstructions, AttentionLine, Subject, CCList, ReturnAddress, SenderName, Closing, SenderCompany, SenderJobTitle, SenderInitials, EnclosureNumber, InfoBlock, RecipientCode, RecipientGender, ReturnAddressShortForm, SenderCity, SenderCode, SenderGender, SenderReference]])
        return LetterContent(self.com_object.CreateLetterContent(*arguments))

    def createlettercontent(self, DateFormat=None, IncludeHeaderFooter=None, PageDesign=None, LetterStyle=None, Letterhead=None, LetterheadLocation=None, LetterheadSize=None, RecipientName=None, RecipientAddress=None, Salutation=None, SalutationType=None, RecipientReference=None, MailingInstructions=None, AttentionLine=None, Subject=None, CCList=None, ReturnAddress=None, SenderName=None, Closing=None, SenderCompany=None, SenderJobTitle=None, SenderInitials=None, EnclosureNumber=None, InfoBlock=None, RecipientCode=None, RecipientGender=None, ReturnAddressShortForm=None, SenderCity=None, SenderCode=None, SenderGender=None, SenderReference=None):
        """Alias for CreateLetterContent"""
        arguments = [DateFormat, IncludeHeaderFooter, PageDesign, LetterStyle, Letterhead, LetterheadLocation, LetterheadSize, RecipientName, RecipientAddress, Salutation, SalutationType, RecipientReference, MailingInstructions, AttentionLine, Subject, CCList, ReturnAddress, SenderName, Closing, SenderCompany, SenderJobTitle, SenderInitials, EnclosureNumber, InfoBlock, RecipientCode, RecipientGender, ReturnAddressShortForm, SenderCity, SenderCode, SenderGender, SenderReference]
        return self.CreateLetterContent(*arguments)

    def create_letter_content(self, DateFormat=None, IncludeHeaderFooter=None, PageDesign=None, LetterStyle=None, Letterhead=None, LetterheadLocation=None, LetterheadSize=None, RecipientName=None, RecipientAddress=None, Salutation=None, SalutationType=None, RecipientReference=None, MailingInstructions=None, AttentionLine=None, Subject=None, CCList=None, ReturnAddress=None, SenderName=None, Closing=None, SenderCompany=None, SenderJobTitle=None, SenderInitials=None, EnclosureNumber=None, InfoBlock=None, RecipientCode=None, RecipientGender=None, ReturnAddressShortForm=None, SenderCity=None, SenderCode=None, SenderGender=None, SenderReference=None):
        """Alias for CreateLetterContent"""
        arguments = [DateFormat, IncludeHeaderFooter, PageDesign, LetterStyle, Letterhead, LetterheadLocation, LetterheadSize, RecipientName, RecipientAddress, Salutation, SalutationType, RecipientReference, MailingInstructions, AttentionLine, Subject, CCList, ReturnAddress, SenderName, Closing, SenderCompany, SenderJobTitle, SenderInitials, EnclosureNumber, InfoBlock, RecipientCode, RecipientGender, ReturnAddressShortForm, SenderCity, SenderCode, SenderGender, SenderReference]
        return self.CreateLetterContent(*arguments)

    def DataForm(self):
        self.com_object.DataForm()

    def dataform(self):
        """Alias for DataForm"""
        return self.DataForm()

    def data_form(self):
        """Alias for DataForm"""
        return self.DataForm()

    def DeleteAllComments(self):
        self.com_object.DeleteAllComments()

    def deleteallcomments(self):
        """Alias for DeleteAllComments"""
        return self.DeleteAllComments()

    def delete_all_comments(self):
        """Alias for DeleteAllComments"""
        return self.DeleteAllComments()

    def DeleteAllCommentsShown(self):
        self.com_object.DeleteAllCommentsShown()

    def deleteallcommentsshown(self):
        """Alias for DeleteAllCommentsShown"""
        return self.DeleteAllCommentsShown()

    def delete_all_comments_shown(self):
        """Alias for DeleteAllCommentsShown"""
        return self.DeleteAllCommentsShown()

    def DeleteAllEditableRanges(self, EditorID=None):
        arguments = com_arguments([unwrap(a) for a in [EditorID]])
        self.com_object.DeleteAllEditableRanges(*arguments)

    def deletealleditableranges(self, EditorID=None):
        """Alias for DeleteAllEditableRanges"""
        arguments = [EditorID]
        return self.DeleteAllEditableRanges(*arguments)

    def delete_all_editable_ranges(self, EditorID=None):
        """Alias for DeleteAllEditableRanges"""
        arguments = [EditorID]
        return self.DeleteAllEditableRanges(*arguments)

    def DeleteAllInkAnnotations(self):
        self.com_object.DeleteAllInkAnnotations()

    def deleteallinkannotations(self):
        """Alias for DeleteAllInkAnnotations"""
        return self.DeleteAllInkAnnotations()

    def delete_all_ink_annotations(self):
        """Alias for DeleteAllInkAnnotations"""
        return self.DeleteAllInkAnnotations()

    def DetectLanguage(self):
        self.com_object.DetectLanguage()

    def detectlanguage(self):
        """Alias for DetectLanguage"""
        return self.DetectLanguage()

    def detect_language(self):
        """Alias for DetectLanguage"""
        return self.DetectLanguage()

    def DowngradeDocument(self):
        self.com_object.DowngradeDocument()

    def downgradedocument(self):
        """Alias for DowngradeDocument"""
        return self.DowngradeDocument()

    def downgrade_document(self):
        """Alias for DowngradeDocument"""
        return self.DowngradeDocument()

    def EndReview(self):
        self.com_object.EndReview()

    def endreview(self):
        """Alias for EndReview"""
        return self.EndReview()

    def end_review(self):
        """Alias for EndReview"""
        return self.EndReview()

    def ExportAsFixedFormat(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, Range=None, From=None, To=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, FixedFormatExtClassPtr=None):
        arguments = com_arguments([unwrap(a) for a in [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, Range, From, To, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, FixedFormatExtClassPtr]])
        self.com_object.ExportAsFixedFormat(*arguments)

    def exportasfixedformat(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, Range=None, From=None, To=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat"""
        arguments = [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, Range, From, To, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat(*arguments)

    def export_as_fixed_format(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, Range=None, From=None, To=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat"""
        arguments = [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, Range, From, To, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat(*arguments)

    def ExportAsFixedFormat2(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, Range=None, From=None, To=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, OptimizeForImageQuality=None, FixedFormatExtClassPtr=None):
        arguments = com_arguments([unwrap(a) for a in [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, Range, From, To, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, OptimizeForImageQuality, FixedFormatExtClassPtr]])
        self.com_object.ExportAsFixedFormat2(*arguments)

    def exportasfixedformat2(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, Range=None, From=None, To=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, OptimizeForImageQuality=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat2"""
        arguments = [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, Range, From, To, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, OptimizeForImageQuality, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat2(*arguments)

    def export_as_fixed_format2(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, Range=None, From=None, To=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, OptimizeForImageQuality=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat2"""
        arguments = [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, Range, From, To, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, OptimizeForImageQuality, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat2(*arguments)

    def ExportAsFixedFormat3(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, Range=None, From=None, To=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, OptimizeForImageQuality=None, ImproveExportTagging=None, FixedFormatExtClassPtr=None):
        arguments = com_arguments([unwrap(a) for a in [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, Range, From, To, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, OptimizeForImageQuality, ImproveExportTagging, FixedFormatExtClassPtr]])
        self.com_object.ExportAsFixedFormat3(*arguments)

    def exportasfixedformat3(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, Range=None, From=None, To=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, OptimizeForImageQuality=None, ImproveExportTagging=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat3"""
        arguments = [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, Range, From, To, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, OptimizeForImageQuality, ImproveExportTagging, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat3(*arguments)

    def export_as_fixed_format3(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, Range=None, From=None, To=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, OptimizeForImageQuality=None, ImproveExportTagging=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat3"""
        arguments = [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, Range, From, To, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, OptimizeForImageQuality, ImproveExportTagging, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat3(*arguments)

    def FitToPages(self):
        self.com_object.FitToPages()

    def fittopages(self):
        """Alias for FitToPages"""
        return self.FitToPages()

    def fit_to_pages(self):
        """Alias for FitToPages"""
        return self.FitToPages()

    def FollowHyperlink(self, Address=None, SubAddress=None, NewWindow=None, AddHistory=None, ExtraInfo=None, Method=None, HeaderInfo=None):
        arguments = com_arguments([unwrap(a) for a in [Address, SubAddress, NewWindow, AddHistory, ExtraInfo, Method, HeaderInfo]])
        self.com_object.FollowHyperlink(*arguments)

    def followhyperlink(self, Address=None, SubAddress=None, NewWindow=None, AddHistory=None, ExtraInfo=None, Method=None, HeaderInfo=None):
        """Alias for FollowHyperlink"""
        arguments = [Address, SubAddress, NewWindow, AddHistory, ExtraInfo, Method, HeaderInfo]
        return self.FollowHyperlink(*arguments)

    def follow_hyperlink(self, Address=None, SubAddress=None, NewWindow=None, AddHistory=None, ExtraInfo=None, Method=None, HeaderInfo=None):
        """Alias for FollowHyperlink"""
        arguments = [Address, SubAddress, NewWindow, AddHistory, ExtraInfo, Method, HeaderInfo]
        return self.FollowHyperlink(*arguments)

    def FreezeLayout(self):
        self.com_object.FreezeLayout()

    def freezelayout(self):
        """Alias for FreezeLayout"""
        return self.FreezeLayout()

    def freeze_layout(self):
        """Alias for FreezeLayout"""
        return self.FreezeLayout()

    def GetCrossReferenceItems(self, ReferenceType=None):
        arguments = com_arguments([unwrap(a) for a in [ReferenceType]])
        self.com_object.GetCrossReferenceItems(*arguments)

    def getcrossreferenceitems(self, ReferenceType=None):
        """Alias for GetCrossReferenceItems"""
        arguments = [ReferenceType]
        return self.GetCrossReferenceItems(*arguments)

    def get_cross_reference_items(self, ReferenceType=None):
        """Alias for GetCrossReferenceItems"""
        arguments = [ReferenceType]
        return self.GetCrossReferenceItems(*arguments)

    def GetLetterContent(self):
        return LetterContent(self.com_object.GetLetterContent())

    def getlettercontent(self):
        """Alias for GetLetterContent"""
        return self.GetLetterContent()

    def get_letter_content(self):
        """Alias for GetLetterContent"""
        return self.GetLetterContent()

    def GetWorkflowTasks(self):
        return self.com_object.GetWorkflowTasks()

    def getworkflowtasks(self):
        """Alias for GetWorkflowTasks"""
        return self.GetWorkflowTasks()

    def get_workflow_tasks(self):
        """Alias for GetWorkflowTasks"""
        return self.GetWorkflowTasks()

    def GetWorkflowTemplates(self):
        return self.com_object.GetWorkflowTemplates()

    def getworkflowtemplates(self):
        """Alias for GetWorkflowTemplates"""
        return self.GetWorkflowTemplates()

    def get_workflow_templates(self):
        """Alias for GetWorkflowTemplates"""
        return self.GetWorkflowTemplates()

    def GoTo(self, What=None, Which=None, Count=None, Name=None):
        arguments = com_arguments([unwrap(a) for a in [What, Which, Count, Name]])
        self.com_object.GoTo(*arguments)

    def goto(self, What=None, Which=None, Count=None, Name=None):
        """Alias for GoTo"""
        arguments = [What, Which, Count, Name]
        return self.GoTo(*arguments)

    def go_to(self, What=None, Which=None, Count=None, Name=None):
        """Alias for GoTo"""
        arguments = [What, Which, Count, Name]
        return self.GoTo(*arguments)

    def LockServerFile(self):
        self.com_object.LockServerFile()

    def lockserverfile(self):
        """Alias for LockServerFile"""
        return self.LockServerFile()

    def lock_server_file(self):
        """Alias for LockServerFile"""
        return self.LockServerFile()

    def MakeCompatibilityDefault(self):
        self.com_object.MakeCompatibilityDefault()

    def makecompatibilitydefault(self):
        """Alias for MakeCompatibilityDefault"""
        return self.MakeCompatibilityDefault()

    def make_compatibility_default(self):
        """Alias for MakeCompatibilityDefault"""
        return self.MakeCompatibilityDefault()

    def ManualHyphenation(self):
        self.com_object.ManualHyphenation()

    def manualhyphenation(self):
        """Alias for ManualHyphenation"""
        return self.ManualHyphenation()

    def manual_hyphenation(self):
        """Alias for ManualHyphenation"""
        return self.ManualHyphenation()

    def Merge(self, Name=None, MergeTarget=None, DetectFormatChanges=None, UseFormattingFrom=None, AddToRecentFiles=None):
        arguments = com_arguments([unwrap(a) for a in [Name, MergeTarget, DetectFormatChanges, UseFormattingFrom, AddToRecentFiles]])
        self.com_object.Merge(*arguments)

    def merge(self, Name=None, MergeTarget=None, DetectFormatChanges=None, UseFormattingFrom=None, AddToRecentFiles=None):
        """Alias for Merge"""
        arguments = [Name, MergeTarget, DetectFormatChanges, UseFormattingFrom, AddToRecentFiles]
        return self.Merge(*arguments)

    def Post(self):
        self.com_object.Post()

    def post(self):
        """Alias for Post"""
        return self.Post()

    def PresentIt(self):
        self.com_object.PresentIt()

    def presentit(self):
        """Alias for PresentIt"""
        return self.PresentIt()

    def present_it(self):
        """Alias for PresentIt"""
        return self.PresentIt()

    def PrintOut(self, Background=None, Append=None, Range=None, OutputFileName=None, From=None, To=None, Item=None, Copies=None, Pages=None, PageType=None, PrintToFile=None, Collate=None, FileName=None, ActivePrinterMacGX=None, ManualDuplexPrint=None, PrintZoomColumn=None, PrintZoomRow=None, PrintZoomPaperWidth=None, PrintZoomPaperHeight=None):
        arguments = com_arguments([unwrap(a) for a in [Background, Append, Range, OutputFileName, From, To, Item, Copies, Pages, PageType, PrintToFile, Collate, FileName, ActivePrinterMacGX, ManualDuplexPrint, PrintZoomColumn, PrintZoomRow, PrintZoomPaperWidth, PrintZoomPaperHeight]])
        self.com_object.PrintOut(*arguments)

    def printout(self, Background=None, Append=None, Range=None, OutputFileName=None, From=None, To=None, Item=None, Copies=None, Pages=None, PageType=None, PrintToFile=None, Collate=None, FileName=None, ActivePrinterMacGX=None, ManualDuplexPrint=None, PrintZoomColumn=None, PrintZoomRow=None, PrintZoomPaperWidth=None, PrintZoomPaperHeight=None):
        """Alias for PrintOut"""
        arguments = [Background, Append, Range, OutputFileName, From, To, Item, Copies, Pages, PageType, PrintToFile, Collate, FileName, ActivePrinterMacGX, ManualDuplexPrint, PrintZoomColumn, PrintZoomRow, PrintZoomPaperWidth, PrintZoomPaperHeight]
        return self.PrintOut(*arguments)

    def print_out(self, Background=None, Append=None, Range=None, OutputFileName=None, From=None, To=None, Item=None, Copies=None, Pages=None, PageType=None, PrintToFile=None, Collate=None, FileName=None, ActivePrinterMacGX=None, ManualDuplexPrint=None, PrintZoomColumn=None, PrintZoomRow=None, PrintZoomPaperWidth=None, PrintZoomPaperHeight=None):
        """Alias for PrintOut"""
        arguments = [Background, Append, Range, OutputFileName, From, To, Item, Copies, Pages, PageType, PrintToFile, Collate, FileName, ActivePrinterMacGX, ManualDuplexPrint, PrintZoomColumn, PrintZoomRow, PrintZoomPaperWidth, PrintZoomPaperHeight]
        return self.PrintOut(*arguments)

    def PrintPreview(self):
        self.com_object.PrintPreview()

    def printpreview(self):
        """Alias for PrintPreview"""
        return self.PrintPreview()

    def print_preview(self):
        """Alias for PrintPreview"""
        return self.PrintPreview()

    def Protect(self, Type=None, NoReset=None, Password=None, UseIRM=None, EnforceStyleLock=None):
        arguments = com_arguments([unwrap(a) for a in [Type, NoReset, Password, UseIRM, EnforceStyleLock]])
        return self.com_object.Protect(*arguments)

    def protect(self, Type=None, NoReset=None, Password=None, UseIRM=None, EnforceStyleLock=None):
        """Alias for Protect"""
        arguments = [Type, NoReset, Password, UseIRM, EnforceStyleLock]
        return self.Protect(*arguments)

    def Range(self, Start=None, End=None):
        arguments = com_arguments([unwrap(a) for a in [Start, End]])
        return Range(self.com_object.Range(*arguments))

    def range(self, Start=None, End=None):
        """Alias for Range"""
        arguments = [Start, End]
        return self.Range(*arguments)

    def Redo(self, Times=None):
        arguments = com_arguments([unwrap(a) for a in [Times]])
        return self.com_object.Redo(*arguments)

    def redo(self, Times=None):
        """Alias for Redo"""
        arguments = [Times]
        return self.Redo(*arguments)

    def RejectAllRevisions(self):
        self.com_object.RejectAllRevisions()

    def rejectallrevisions(self):
        """Alias for RejectAllRevisions"""
        return self.RejectAllRevisions()

    def reject_all_revisions(self):
        """Alias for RejectAllRevisions"""
        return self.RejectAllRevisions()

    def RejectAllRevisionsShown(self):
        self.com_object.RejectAllRevisionsShown()

    def rejectallrevisionsshown(self):
        """Alias for RejectAllRevisionsShown"""
        return self.RejectAllRevisionsShown()

    def reject_all_revisions_shown(self):
        """Alias for RejectAllRevisionsShown"""
        return self.RejectAllRevisionsShown()

    def Reload(self):
        self.com_object.Reload()

    def reload(self):
        """Alias for Reload"""
        return self.Reload()

    def ReloadAs(self, Encoding=None):
        arguments = com_arguments([unwrap(a) for a in [Encoding]])
        self.com_object.ReloadAs(*arguments)

    def reloadas(self, Encoding=None):
        """Alias for ReloadAs"""
        arguments = [Encoding]
        return self.ReloadAs(*arguments)

    def reload_as(self, Encoding=None):
        """Alias for ReloadAs"""
        arguments = [Encoding]
        return self.ReloadAs(*arguments)

    def RemoveDocumentInformation(self, RemoveDocInfoType=None):
        arguments = com_arguments([unwrap(a) for a in [RemoveDocInfoType]])
        self.com_object.RemoveDocumentInformation(*arguments)

    def removedocumentinformation(self, RemoveDocInfoType=None):
        """Alias for RemoveDocumentInformation"""
        arguments = [RemoveDocInfoType]
        return self.RemoveDocumentInformation(*arguments)

    def remove_document_information(self, RemoveDocInfoType=None):
        """Alias for RemoveDocumentInformation"""
        arguments = [RemoveDocInfoType]
        return self.RemoveDocumentInformation(*arguments)

    def RemoveLockedStyles(self):
        self.com_object.RemoveLockedStyles()

    def removelockedstyles(self):
        """Alias for RemoveLockedStyles"""
        return self.RemoveLockedStyles()

    def remove_locked_styles(self):
        """Alias for RemoveLockedStyles"""
        return self.RemoveLockedStyles()

    def RemoveNumbers(self, NumberType=None):
        arguments = com_arguments([unwrap(a) for a in [NumberType]])
        self.com_object.RemoveNumbers(*arguments)

    def removenumbers(self, NumberType=None):
        """Alias for RemoveNumbers"""
        arguments = [NumberType]
        return self.RemoveNumbers(*arguments)

    def remove_numbers(self, NumberType=None):
        """Alias for RemoveNumbers"""
        arguments = [NumberType]
        return self.RemoveNumbers(*arguments)

    def RemoveTheme(self):
        self.com_object.RemoveTheme()

    def removetheme(self):
        """Alias for RemoveTheme"""
        return self.RemoveTheme()

    def remove_theme(self):
        """Alias for RemoveTheme"""
        return self.RemoveTheme()

    def Repaginate(self):
        self.com_object.Repaginate()

    def repaginate(self):
        """Alias for Repaginate"""
        return self.Repaginate()

    def ReplyWithChanges(self, ShowMessage=None):
        arguments = com_arguments([unwrap(a) for a in [ShowMessage]])
        self.com_object.ReplyWithChanges(*arguments)

    def replywithchanges(self, ShowMessage=None):
        """Alias for ReplyWithChanges"""
        arguments = [ShowMessage]
        return self.ReplyWithChanges(*arguments)

    def reply_with_changes(self, ShowMessage=None):
        """Alias for ReplyWithChanges"""
        arguments = [ShowMessage]
        return self.ReplyWithChanges(*arguments)

    def ResetFormFields(self):
        self.com_object.ResetFormFields()

    def resetformfields(self):
        """Alias for ResetFormFields"""
        return self.ResetFormFields()

    def reset_form_fields(self):
        """Alias for ResetFormFields"""
        return self.ResetFormFields()

    def ReturnToLastReadPosition(self):
        return self.com_object.ReturnToLastReadPosition()

    def returntolastreadposition(self):
        """Alias for ReturnToLastReadPosition"""
        return self.ReturnToLastReadPosition()

    def return_to_last_read_position(self):
        """Alias for ReturnToLastReadPosition"""
        return self.ReturnToLastReadPosition()

    def RunAutoMacro(self, Which=None):
        arguments = com_arguments([unwrap(a) for a in [Which]])
        self.com_object.RunAutoMacro(*arguments)

    def runautomacro(self, Which=None):
        """Alias for RunAutoMacro"""
        arguments = [Which]
        return self.RunAutoMacro(*arguments)

    def run_auto_macro(self, Which=None):
        """Alias for RunAutoMacro"""
        arguments = [Which]
        return self.RunAutoMacro(*arguments)

    def RunLetterWizard(self, LetterContent=None, WizardMode=None):
        arguments = com_arguments([unwrap(a) for a in [LetterContent, WizardMode]])
        self.com_object.RunLetterWizard(*arguments)

    def runletterwizard(self, LetterContent=None, WizardMode=None):
        """Alias for RunLetterWizard"""
        arguments = [LetterContent, WizardMode]
        return self.RunLetterWizard(*arguments)

    def run_letter_wizard(self, LetterContent=None, WizardMode=None):
        """Alias for RunLetterWizard"""
        arguments = [LetterContent, WizardMode]
        return self.RunLetterWizard(*arguments)

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()

    def SaveAsQuickStyleSet(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        self.com_object.SaveAsQuickStyleSet(*arguments)

    def saveasquickstyleset(self, FileName=None):
        """Alias for SaveAsQuickStyleSet"""
        arguments = [FileName]
        return self.SaveAsQuickStyleSet(*arguments)

    def save_as_quick_style_set(self, FileName=None):
        """Alias for SaveAsQuickStyleSet"""
        arguments = [FileName]
        return self.SaveAsQuickStyleSet(*arguments)

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()

    def SelectAllEditableRanges(self, EditorID=None):
        arguments = com_arguments([unwrap(a) for a in [EditorID]])
        self.com_object.SelectAllEditableRanges(*arguments)

    def selectalleditableranges(self, EditorID=None):
        """Alias for SelectAllEditableRanges"""
        arguments = [EditorID]
        return self.SelectAllEditableRanges(*arguments)

    def select_all_editable_ranges(self, EditorID=None):
        """Alias for SelectAllEditableRanges"""
        arguments = [EditorID]
        return self.SelectAllEditableRanges(*arguments)

    def SelectContentControlsByTag(self, Tag=None):
        arguments = com_arguments([unwrap(a) for a in [Tag]])
        return ContentControls(self.com_object.SelectContentControlsByTag(*arguments))

    def selectcontentcontrolsbytag(self, Tag=None):
        """Alias for SelectContentControlsByTag"""
        arguments = [Tag]
        return self.SelectContentControlsByTag(*arguments)

    def select_content_controls_by_tag(self, Tag=None):
        """Alias for SelectContentControlsByTag"""
        arguments = [Tag]
        return self.SelectContentControlsByTag(*arguments)

    def SelectContentControlsByTitle(self, Title=None):
        arguments = com_arguments([unwrap(a) for a in [Title]])
        return ContentControls(self.com_object.SelectContentControlsByTitle(*arguments))

    def selectcontentcontrolsbytitle(self, Title=None):
        """Alias for SelectContentControlsByTitle"""
        arguments = [Title]
        return self.SelectContentControlsByTitle(*arguments)

    def select_content_controls_by_title(self, Title=None):
        """Alias for SelectContentControlsByTitle"""
        arguments = [Title]
        return self.SelectContentControlsByTitle(*arguments)

    def SelectLinkedControls(self, Node=None):
        arguments = com_arguments([unwrap(a) for a in [Node]])
        return ContentControls(self.com_object.SelectLinkedControls(*arguments))

    def selectlinkedcontrols(self, Node=None):
        """Alias for SelectLinkedControls"""
        arguments = [Node]
        return self.SelectLinkedControls(*arguments)

    def select_linked_controls(self, Node=None):
        """Alias for SelectLinkedControls"""
        arguments = [Node]
        return self.SelectLinkedControls(*arguments)

    def SelectNodes(self, XPath=None, PrefixMapping=None, FastSearchSkippingTextNodes=None):
        arguments = com_arguments([unwrap(a) for a in [XPath, PrefixMapping, FastSearchSkippingTextNodes]])
        return XMLNodes(self.com_object.SelectNodes(*arguments))

    def selectnodes(self, XPath=None, PrefixMapping=None, FastSearchSkippingTextNodes=None):
        """Alias for SelectNodes"""
        arguments = [XPath, PrefixMapping, FastSearchSkippingTextNodes]
        return self.SelectNodes(*arguments)

    def select_nodes(self, XPath=None, PrefixMapping=None, FastSearchSkippingTextNodes=None):
        """Alias for SelectNodes"""
        arguments = [XPath, PrefixMapping, FastSearchSkippingTextNodes]
        return self.SelectNodes(*arguments)

    def SelectSingleNode(self, XPath=None, PrefixMapping=None, FastSearchSkippingTextNodes=None):
        arguments = com_arguments([unwrap(a) for a in [XPath, PrefixMapping, FastSearchSkippingTextNodes]])
        return XMLNode(self.com_object.SelectSingleNode(*arguments))

    def selectsinglenode(self, XPath=None, PrefixMapping=None, FastSearchSkippingTextNodes=None):
        """Alias for SelectSingleNode"""
        arguments = [XPath, PrefixMapping, FastSearchSkippingTextNodes]
        return self.SelectSingleNode(*arguments)

    def select_single_node(self, XPath=None, PrefixMapping=None, FastSearchSkippingTextNodes=None):
        """Alias for SelectSingleNode"""
        arguments = [XPath, PrefixMapping, FastSearchSkippingTextNodes]
        return self.SelectSingleNode(*arguments)

    def SelectUnlinkedControls(self, Stream=None):
        arguments = com_arguments([unwrap(a) for a in [Stream]])
        return ContentControls(self.com_object.SelectUnlinkedControls(*arguments))

    def selectunlinkedcontrols(self, Stream=None):
        """Alias for SelectUnlinkedControls"""
        arguments = [Stream]
        return self.SelectUnlinkedControls(*arguments)

    def select_unlinked_controls(self, Stream=None):
        """Alias for SelectUnlinkedControls"""
        arguments = [Stream]
        return self.SelectUnlinkedControls(*arguments)

    def SendFax(self, Address=None, Subject=None):
        arguments = com_arguments([unwrap(a) for a in [Address, Subject]])
        self.com_object.SendFax(*arguments)

    def sendfax(self, Address=None, Subject=None):
        """Alias for SendFax"""
        arguments = [Address, Subject]
        return self.SendFax(*arguments)

    def send_fax(self, Address=None, Subject=None):
        """Alias for SendFax"""
        arguments = [Address, Subject]
        return self.SendFax(*arguments)

    def SendFaxOverInternet(self, Recipients=None, Subject=None, ShowMessage=None):
        arguments = com_arguments([unwrap(a) for a in [Recipients, Subject, ShowMessage]])
        self.com_object.SendFaxOverInternet(*arguments)

    def sendfaxoverinternet(self, Recipients=None, Subject=None, ShowMessage=None):
        """Alias for SendFaxOverInternet"""
        arguments = [Recipients, Subject, ShowMessage]
        return self.SendFaxOverInternet(*arguments)

    def send_fax_over_internet(self, Recipients=None, Subject=None, ShowMessage=None):
        """Alias for SendFaxOverInternet"""
        arguments = [Recipients, Subject, ShowMessage]
        return self.SendFaxOverInternet(*arguments)

    def SendForReview(self, Recipients=None, Subject=None, ShowMessage=None, IncludeAttachment=None):
        arguments = com_arguments([unwrap(a) for a in [Recipients, Subject, ShowMessage, IncludeAttachment]])
        self.com_object.SendForReview(*arguments)

    def sendforreview(self, Recipients=None, Subject=None, ShowMessage=None, IncludeAttachment=None):
        """Alias for SendForReview"""
        arguments = [Recipients, Subject, ShowMessage, IncludeAttachment]
        return self.SendForReview(*arguments)

    def send_for_review(self, Recipients=None, Subject=None, ShowMessage=None, IncludeAttachment=None):
        """Alias for SendForReview"""
        arguments = [Recipients, Subject, ShowMessage, IncludeAttachment]
        return self.SendForReview(*arguments)

    def SendMail(self):
        self.com_object.SendMail()

    def sendmail(self):
        """Alias for SendMail"""
        return self.SendMail()

    def send_mail(self):
        """Alias for SendMail"""
        return self.SendMail()

    def SetDefaultTableStyle(self, Style=None, SetInTemplate=None):
        arguments = com_arguments([unwrap(a) for a in [Style, SetInTemplate]])
        self.com_object.SetDefaultTableStyle(*arguments)

    def setdefaulttablestyle(self, Style=None, SetInTemplate=None):
        """Alias for SetDefaultTableStyle"""
        arguments = [Style, SetInTemplate]
        return self.SetDefaultTableStyle(*arguments)

    def set_default_table_style(self, Style=None, SetInTemplate=None):
        """Alias for SetDefaultTableStyle"""
        arguments = [Style, SetInTemplate]
        return self.SetDefaultTableStyle(*arguments)

    def SetLetterContent(self, LetterContent=None):
        arguments = com_arguments([unwrap(a) for a in [LetterContent]])
        self.com_object.SetLetterContent(*arguments)

    def setlettercontent(self, LetterContent=None):
        """Alias for SetLetterContent"""
        arguments = [LetterContent]
        return self.SetLetterContent(*arguments)

    def set_letter_content(self, LetterContent=None):
        """Alias for SetLetterContent"""
        arguments = [LetterContent]
        return self.SetLetterContent(*arguments)

    def SetPasswordEncryptionOptions(self, PasswordEncryptionProvider=None, PasswordEncryptionAlgorithm=None, PasswordEncryptionKeyLength=None, PasswordEncryptionFileProperties=None):
        arguments = com_arguments([unwrap(a) for a in [PasswordEncryptionProvider, PasswordEncryptionAlgorithm, PasswordEncryptionKeyLength, PasswordEncryptionFileProperties]])
        self.com_object.SetPasswordEncryptionOptions(*arguments)

    def setpasswordencryptionoptions(self, PasswordEncryptionProvider=None, PasswordEncryptionAlgorithm=None, PasswordEncryptionKeyLength=None, PasswordEncryptionFileProperties=None):
        """Alias for SetPasswordEncryptionOptions"""
        arguments = [PasswordEncryptionProvider, PasswordEncryptionAlgorithm, PasswordEncryptionKeyLength, PasswordEncryptionFileProperties]
        return self.SetPasswordEncryptionOptions(*arguments)

    def set_password_encryption_options(self, PasswordEncryptionProvider=None, PasswordEncryptionAlgorithm=None, PasswordEncryptionKeyLength=None, PasswordEncryptionFileProperties=None):
        """Alias for SetPasswordEncryptionOptions"""
        arguments = [PasswordEncryptionProvider, PasswordEncryptionAlgorithm, PasswordEncryptionKeyLength, PasswordEncryptionFileProperties]
        return self.SetPasswordEncryptionOptions(*arguments)

    def ToggleFormsDesign(self):
        self.com_object.ToggleFormsDesign()

    def toggleformsdesign(self):
        """Alias for ToggleFormsDesign"""
        return self.ToggleFormsDesign()

    def toggle_forms_design(self):
        """Alias for ToggleFormsDesign"""
        return self.ToggleFormsDesign()

    def TransformDocument(self, Path=None, DataOnly=None):
        arguments = com_arguments([unwrap(a) for a in [Path, DataOnly]])
        self.com_object.TransformDocument(*arguments)

    def transformdocument(self, Path=None, DataOnly=None):
        """Alias for TransformDocument"""
        arguments = [Path, DataOnly]
        return self.TransformDocument(*arguments)

    def transform_document(self, Path=None, DataOnly=None):
        """Alias for TransformDocument"""
        arguments = [Path, DataOnly]
        return self.TransformDocument(*arguments)

    def Undo(self, Times=None):
        arguments = com_arguments([unwrap(a) for a in [Times]])
        return self.com_object.Undo(*arguments)

    def undo(self, Times=None):
        """Alias for Undo"""
        arguments = [Times]
        return self.Undo(*arguments)

    def UndoClear(self):
        self.com_object.UndoClear()

    def undoclear(self):
        """Alias for UndoClear"""
        return self.UndoClear()

    def undo_clear(self):
        """Alias for UndoClear"""
        return self.UndoClear()

    def Unprotect(self, Password=None):
        arguments = com_arguments([unwrap(a) for a in [Password]])
        self.com_object.Unprotect(*arguments)

    def unprotect(self, Password=None):
        """Alias for Unprotect"""
        arguments = [Password]
        return self.Unprotect(*arguments)

    def UpdateStyles(self):
        self.com_object.UpdateStyles()

    def updatestyles(self):
        """Alias for UpdateStyles"""
        return self.UpdateStyles()

    def update_styles(self):
        """Alias for UpdateStyles"""
        return self.UpdateStyles()

    def ViewCode(self):
        self.com_object.ViewCode()

    def viewcode(self):
        """Alias for ViewCode"""
        return self.ViewCode()

    def view_code(self):
        """Alias for ViewCode"""
        return self.ViewCode()

    def ViewPropertyBrowser(self):
        self.com_object.ViewPropertyBrowser()

    def viewpropertybrowser(self):
        """Alias for ViewPropertyBrowser"""
        return self.ViewPropertyBrowser()

    def view_property_browser(self):
        """Alias for ViewPropertyBrowser"""
        return self.ViewPropertyBrowser()

    def WebPagePreview(self):
        self.com_object.WebPagePreview()

    def webpagepreview(self):
        """Alias for WebPagePreview"""
        return self.WebPagePreview()

    def web_page_preview(self):
        """Alias for WebPagePreview"""
        return self.WebPagePreview()

    def SaveAs2(self, FileName=None, FileFormat=None, LockComments=None, Password=None, AddToRecentFiles=None, WritePassword=None, ReadOnlyRecommended=None, EmbedTrueTypeFonts=None, SaveNativePictureFormat=None, SaveFormsData=None, SaveAsAOCELetter=None, Encoding=None, InsertLineBreaks=None, AllowSubstitutions=None, LineEnding=None, AddBiDiMarks=None, CompatibilityMode=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, FileFormat, LockComments, Password, AddToRecentFiles, WritePassword, ReadOnlyRecommended, EmbedTrueTypeFonts, SaveNativePictureFormat, SaveFormsData, SaveAsAOCELetter, Encoding, InsertLineBreaks, AllowSubstitutions, LineEnding, AddBiDiMarks, CompatibilityMode]])
        return self.com_object.SaveAs2(*arguments)

    def saveas2(self, FileName=None, FileFormat=None, LockComments=None, Password=None, AddToRecentFiles=None, WritePassword=None, ReadOnlyRecommended=None, EmbedTrueTypeFonts=None, SaveNativePictureFormat=None, SaveFormsData=None, SaveAsAOCELetter=None, Encoding=None, InsertLineBreaks=None, AllowSubstitutions=None, LineEnding=None, AddBiDiMarks=None, CompatibilityMode=None):
        """Alias for SaveAs2"""
        arguments = [FileName, FileFormat, LockComments, Password, AddToRecentFiles, WritePassword, ReadOnlyRecommended, EmbedTrueTypeFonts, SaveNativePictureFormat, SaveFormsData, SaveAsAOCELetter, Encoding, InsertLineBreaks, AllowSubstitutions, LineEnding, AddBiDiMarks, CompatibilityMode]
        return self.SaveAs2(*arguments)

    def save_as2(self, FileName=None, FileFormat=None, LockComments=None, Password=None, AddToRecentFiles=None, WritePassword=None, ReadOnlyRecommended=None, EmbedTrueTypeFonts=None, SaveNativePictureFormat=None, SaveFormsData=None, SaveAsAOCELetter=None, Encoding=None, InsertLineBreaks=None, AllowSubstitutions=None, LineEnding=None, AddBiDiMarks=None, CompatibilityMode=None):
        """Alias for SaveAs2"""
        arguments = [FileName, FileFormat, LockComments, Password, AddToRecentFiles, WritePassword, ReadOnlyRecommended, EmbedTrueTypeFonts, SaveNativePictureFormat, SaveFormsData, SaveAsAOCELetter, Encoding, InsertLineBreaks, AllowSubstitutions, LineEnding, AddBiDiMarks, CompatibilityMode]
        return self.SaveAs2(*arguments)

    def SetCompatibilityMode(self, Mode=None):
        arguments = com_arguments([unwrap(a) for a in [Mode]])
        self.com_object.SetCompatibilityMode(*arguments)

    def setcompatibilitymode(self, Mode=None):
        """Alias for SetCompatibilityMode"""
        arguments = [Mode]
        return self.SetCompatibilityMode(*arguments)

    def set_compatibility_mode(self, Mode=None):
        """Alias for SetCompatibilityMode"""
        arguments = [Mode]
        return self.SetCompatibilityMode(*arguments)


class Documents:

    def __init__(self, documents=None):
        self.com_object= documents

    def __call__(self, item):
        return Document(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Template=None, NewTemplate=None, DocumentType=None, Visible=None):
        arguments = com_arguments([unwrap(a) for a in [Template, NewTemplate, DocumentType, Visible]])
        return Document(self.com_object.Add(*arguments))

    def add(self, Template=None, NewTemplate=None, DocumentType=None, Visible=None):
        """Alias for Add"""
        arguments = [Template, NewTemplate, DocumentType, Visible]
        return self.Add(*arguments)

    def AddBlogDocument(self, ProviderID=None, PostURL=None, BlogName=None, PostID=None):
        arguments = com_arguments([unwrap(a) for a in [ProviderID, PostURL, BlogName, PostID]])
        self.com_object.AddBlogDocument(*arguments)

    def addblogdocument(self, ProviderID=None, PostURL=None, BlogName=None, PostID=None):
        """Alias for AddBlogDocument"""
        arguments = [ProviderID, PostURL, BlogName, PostID]
        return self.AddBlogDocument(*arguments)

    def add_blog_document(self, ProviderID=None, PostURL=None, BlogName=None, PostID=None):
        """Alias for AddBlogDocument"""
        arguments = [ProviderID, PostURL, BlogName, PostID]
        return self.AddBlogDocument(*arguments)

    def CanCheckOut(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        return self.com_object.CanCheckOut(*arguments)

    def cancheckout(self, FileName=None):
        """Alias for CanCheckOut"""
        arguments = [FileName]
        return self.CanCheckOut(*arguments)

    def can_check_out(self, FileName=None):
        """Alias for CanCheckOut"""
        arguments = [FileName]
        return self.CanCheckOut(*arguments)

    def CheckOut(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        self.com_object.CheckOut(*arguments)

    def checkout(self, FileName=None):
        """Alias for CheckOut"""
        arguments = [FileName]
        return self.CheckOut(*arguments)

    def check_out(self, FileName=None):
        """Alias for CheckOut"""
        arguments = [FileName]
        return self.CheckOut(*arguments)

    def Close(self, SaveChanges=None, OriginalFormat=None, RouteDocument=None):
        arguments = com_arguments([unwrap(a) for a in [SaveChanges, OriginalFormat, RouteDocument]])
        self.com_object.Close(*arguments)

    def close(self, SaveChanges=None, OriginalFormat=None, RouteDocument=None):
        """Alias for Close"""
        arguments = [SaveChanges, OriginalFormat, RouteDocument]
        return self.Close(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Document(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Open(self, FileName=None, ConfirmConversions=None, ReadOnly=None, AddToRecentFiles=None, PasswordDocument=None, PasswordTemplate=None, Revert=None, WritePasswordDocument=None, WritePasswordTemplate=None, Format=None, Encoding=None, Visible=None, OpenConflictDocument=None, OpenAndRepair=None, DocumentDirection=None, NoEncodingDialog=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, ConfirmConversions, ReadOnly, AddToRecentFiles, PasswordDocument, PasswordTemplate, Revert, WritePasswordDocument, WritePasswordTemplate, Format, Encoding, Visible, OpenConflictDocument, OpenAndRepair, DocumentDirection, NoEncodingDialog]])
        return Document(self.com_object.Open(*arguments))

    def open(self, FileName=None, ConfirmConversions=None, ReadOnly=None, AddToRecentFiles=None, PasswordDocument=None, PasswordTemplate=None, Revert=None, WritePasswordDocument=None, WritePasswordTemplate=None, Format=None, Encoding=None, Visible=None, OpenConflictDocument=None, OpenAndRepair=None, DocumentDirection=None, NoEncodingDialog=None):
        """Alias for Open"""
        arguments = [FileName, ConfirmConversions, ReadOnly, AddToRecentFiles, PasswordDocument, PasswordTemplate, Revert, WritePasswordDocument, WritePasswordTemplate, Format, Encoding, Visible, OpenConflictDocument, OpenAndRepair, DocumentDirection, NoEncodingDialog]
        return self.Open(*arguments)

    def OpenNoRepairDialog(self, FileName=None, ConfirmConversions=None, ReadOnly=None, AddToRecentFiles=None, PasswordDocument=None, PasswordTemplate=None, Revert=None, WritePasswordDocument=None, WritePasswordTemplate=None, Format=None, Encoding=None, Visible=None, OpenAndRepair=None, DocumentDirection=None, NoEncodingDialog=None, XMLTransform=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, ConfirmConversions, ReadOnly, AddToRecentFiles, PasswordDocument, PasswordTemplate, Revert, WritePasswordDocument, WritePasswordTemplate, Format, Encoding, Visible, OpenAndRepair, DocumentDirection, NoEncodingDialog, XMLTransform]])
        return Document(self.com_object.OpenNoRepairDialog(*arguments))

    def opennorepairdialog(self, FileName=None, ConfirmConversions=None, ReadOnly=None, AddToRecentFiles=None, PasswordDocument=None, PasswordTemplate=None, Revert=None, WritePasswordDocument=None, WritePasswordTemplate=None, Format=None, Encoding=None, Visible=None, OpenAndRepair=None, DocumentDirection=None, NoEncodingDialog=None, XMLTransform=None):
        """Alias for OpenNoRepairDialog"""
        arguments = [FileName, ConfirmConversions, ReadOnly, AddToRecentFiles, PasswordDocument, PasswordTemplate, Revert, WritePasswordDocument, WritePasswordTemplate, Format, Encoding, Visible, OpenAndRepair, DocumentDirection, NoEncodingDialog, XMLTransform]
        return self.OpenNoRepairDialog(*arguments)

    def open_no_repair_dialog(self, FileName=None, ConfirmConversions=None, ReadOnly=None, AddToRecentFiles=None, PasswordDocument=None, PasswordTemplate=None, Revert=None, WritePasswordDocument=None, WritePasswordTemplate=None, Format=None, Encoding=None, Visible=None, OpenAndRepair=None, DocumentDirection=None, NoEncodingDialog=None, XMLTransform=None):
        """Alias for OpenNoRepairDialog"""
        arguments = [FileName, ConfirmConversions, ReadOnly, AddToRecentFiles, PasswordDocument, PasswordTemplate, Revert, WritePasswordDocument, WritePasswordTemplate, Format, Encoding, Visible, OpenAndRepair, DocumentDirection, NoEncodingDialog, XMLTransform]
        return self.OpenNoRepairDialog(*arguments)

    def Save(self, NoPrompt=None, OriginalFormat=None):
        arguments = com_arguments([unwrap(a) for a in [NoPrompt, OriginalFormat]])
        self.com_object.Save(*arguments)

    def save(self, NoPrompt=None, OriginalFormat=None):
        """Alias for Save"""
        arguments = [NoPrompt, OriginalFormat]
        return self.Save(*arguments)


class DownBars:

    def __init__(self, downbars=None):
        self.com_object= downbars

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class DropCap:

    def __init__(self, dropcap=None):
        self.com_object= dropcap

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DistanceFromText(self):
        return self.com_object.DistanceFromText

    @DistanceFromText.setter
    def DistanceFromText(self, value):
        self.com_object.DistanceFromText = value

    @property
    def distancefromtext(self):
        """Alias for DistanceFromText"""
        return self.DistanceFromText

    @distancefromtext.setter
    def distancefromtext(self, value):
        """Alias for DistanceFromText.setter"""
        self.DistanceFromText = value

    @property
    def distance_from_text(self):
        """Alias for DistanceFromText"""
        return self.DistanceFromText

    @distance_from_text.setter
    def distance_from_text(self, value):
        """Alias for DistanceFromText.setter"""
        self.DistanceFromText = value

    @property
    def FontName(self):
        return self.com_object.FontName

    @FontName.setter
    def FontName(self, value):
        self.com_object.FontName = value

    @property
    def fontname(self):
        """Alias for FontName"""
        return self.FontName

    @fontname.setter
    def fontname(self, value):
        """Alias for FontName.setter"""
        self.FontName = value

    @property
    def font_name(self):
        """Alias for FontName"""
        return self.FontName

    @font_name.setter
    def font_name(self, value):
        """Alias for FontName.setter"""
        self.FontName = value

    @property
    def LinesToDrop(self):
        return self.com_object.LinesToDrop

    @LinesToDrop.setter
    def LinesToDrop(self, value):
        self.com_object.LinesToDrop = value

    @property
    def linestodrop(self):
        """Alias for LinesToDrop"""
        return self.LinesToDrop

    @linestodrop.setter
    def linestodrop(self, value):
        """Alias for LinesToDrop.setter"""
        self.LinesToDrop = value

    @property
    def lines_to_drop(self):
        """Alias for LinesToDrop"""
        return self.LinesToDrop

    @lines_to_drop.setter
    def lines_to_drop(self, value):
        """Alias for LinesToDrop.setter"""
        self.LinesToDrop = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return WdDropPosition(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    def Clear(self):
        self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()

    def Enable(self):
        self.com_object.Enable()

    def enable(self):
        """Alias for Enable"""
        return self.Enable()


class DropDown:

    def __init__(self, dropdown=None):
        self.com_object= dropdown

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Default(self):
        return self.com_object.Default

    @Default.setter
    def Default(self, value):
        self.com_object.Default = value

    @property
    def default(self):
        """Alias for Default"""
        return self.Default

    @default.setter
    def default(self, value):
        """Alias for Default.setter"""
        self.Default = value

    @property
    def ListEntries(self):
        return ListEntries(self.com_object.ListEntries)

    @property
    def listentries(self):
        """Alias for ListEntries"""
        return self.ListEntries

    @property
    def list_entries(self):
        """Alias for ListEntries"""
        return self.ListEntries

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Valid(self):
        return self.com_object.Valid

    @property
    def valid(self):
        """Alias for Valid"""
        return self.Valid

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value


class DropLines:

    def __init__(self, droplines=None):
        self.com_object= droplines

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Border(self):
        return ChartBorder(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Editor:

    def __init__(self, editor=None):
        self.com_object= editor

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ID(self):
        return self.com_object.ID

    @ID.setter
    def ID(self, value):
        self.com_object.ID = value

    @property
    def id(self):
        """Alias for ID"""
        return self.ID

    @id.setter
    def id(self, value):
        """Alias for ID.setter"""
        self.ID = value

    @property
    def i_d(self):
        """Alias for ID"""
        return self.ID

    @i_d.setter
    def i_d(self, value):
        """Alias for ID.setter"""
        self.ID = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def NextRange(self):
        return Range(self.com_object.NextRange)

    @property
    def nextrange(self):
        """Alias for NextRange"""
        return self.NextRange

    @property
    def next_range(self):
        """Alias for NextRange"""
        return self.NextRange

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def DeleteAll(self):
        self.com_object.DeleteAll()

    def deleteall(self):
        """Alias for DeleteAll"""
        return self.DeleteAll()

    def delete_all(self):
        """Alias for DeleteAll"""
        return self.DeleteAll()

    def SelectAll(self):
        self.com_object.SelectAll()

    def selectall(self):
        """Alias for SelectAll"""
        return self.SelectAll()

    def select_all(self):
        """Alias for SelectAll"""
        return self.SelectAll()


class Editors:

    def __init__(self, editors=None):
        self.com_object= editors

    def __call__(self, item):
        return Editor(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, EditorID=None):
        arguments = com_arguments([unwrap(a) for a in [EditorID]])
        self.com_object.Add(*arguments)

    def add(self, EditorID=None):
        """Alias for Add"""
        arguments = [EditorID]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Editor(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Email:

    def __init__(self, email=None):
        self.com_object= email

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def CurrentEmailAuthor(self):
        return EmailAuthor(self.com_object.CurrentEmailAuthor)

    @property
    def currentemailauthor(self):
        """Alias for CurrentEmailAuthor"""
        return self.CurrentEmailAuthor

    @property
    def current_email_author(self):
        """Alias for CurrentEmailAuthor"""
        return self.CurrentEmailAuthor

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class EmailAuthor:

    def __init__(self, emailauthor=None):
        self.com_object= emailauthor

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Style(self):
        return Style(self.com_object.Style)

    @property
    def style(self):
        """Alias for Style"""
        return self.Style


class EmailOptions:

    def __init__(self, emailoptions=None):
        self.com_object= emailoptions

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoFormatAsYouTypeApplyBorders(self):
        return self.com_object.AutoFormatAsYouTypeApplyBorders

    @AutoFormatAsYouTypeApplyBorders.setter
    def AutoFormatAsYouTypeApplyBorders(self, value):
        self.com_object.AutoFormatAsYouTypeApplyBorders = value

    @property
    def autoformatasyoutypeapplyborders(self):
        """Alias for AutoFormatAsYouTypeApplyBorders"""
        return self.AutoFormatAsYouTypeApplyBorders

    @autoformatasyoutypeapplyborders.setter
    def autoformatasyoutypeapplyborders(self, value):
        """Alias for AutoFormatAsYouTypeApplyBorders.setter"""
        self.AutoFormatAsYouTypeApplyBorders = value

    @property
    def auto_format_as_you_type_apply_borders(self):
        """Alias for AutoFormatAsYouTypeApplyBorders"""
        return self.AutoFormatAsYouTypeApplyBorders

    @auto_format_as_you_type_apply_borders.setter
    def auto_format_as_you_type_apply_borders(self, value):
        """Alias for AutoFormatAsYouTypeApplyBorders.setter"""
        self.AutoFormatAsYouTypeApplyBorders = value

    @property
    def AutoFormatAsYouTypeApplyBulletedLists(self):
        return self.com_object.AutoFormatAsYouTypeApplyBulletedLists

    @AutoFormatAsYouTypeApplyBulletedLists.setter
    def AutoFormatAsYouTypeApplyBulletedLists(self, value):
        self.com_object.AutoFormatAsYouTypeApplyBulletedLists = value

    @property
    def autoformatasyoutypeapplybulletedlists(self):
        """Alias for AutoFormatAsYouTypeApplyBulletedLists"""
        return self.AutoFormatAsYouTypeApplyBulletedLists

    @autoformatasyoutypeapplybulletedlists.setter
    def autoformatasyoutypeapplybulletedlists(self, value):
        """Alias for AutoFormatAsYouTypeApplyBulletedLists.setter"""
        self.AutoFormatAsYouTypeApplyBulletedLists = value

    @property
    def auto_format_as_you_type_apply_bulleted_lists(self):
        """Alias for AutoFormatAsYouTypeApplyBulletedLists"""
        return self.AutoFormatAsYouTypeApplyBulletedLists

    @auto_format_as_you_type_apply_bulleted_lists.setter
    def auto_format_as_you_type_apply_bulleted_lists(self, value):
        """Alias for AutoFormatAsYouTypeApplyBulletedLists.setter"""
        self.AutoFormatAsYouTypeApplyBulletedLists = value

    @property
    def AutoFormatAsYouTypeApplyClosings(self):
        return self.com_object.AutoFormatAsYouTypeApplyClosings

    @AutoFormatAsYouTypeApplyClosings.setter
    def AutoFormatAsYouTypeApplyClosings(self, value):
        self.com_object.AutoFormatAsYouTypeApplyClosings = value

    @property
    def autoformatasyoutypeapplyclosings(self):
        """Alias for AutoFormatAsYouTypeApplyClosings"""
        return self.AutoFormatAsYouTypeApplyClosings

    @autoformatasyoutypeapplyclosings.setter
    def autoformatasyoutypeapplyclosings(self, value):
        """Alias for AutoFormatAsYouTypeApplyClosings.setter"""
        self.AutoFormatAsYouTypeApplyClosings = value

    @property
    def auto_format_as_you_type_apply_closings(self):
        """Alias for AutoFormatAsYouTypeApplyClosings"""
        return self.AutoFormatAsYouTypeApplyClosings

    @auto_format_as_you_type_apply_closings.setter
    def auto_format_as_you_type_apply_closings(self, value):
        """Alias for AutoFormatAsYouTypeApplyClosings.setter"""
        self.AutoFormatAsYouTypeApplyClosings = value

    @property
    def AutoFormatAsYouTypeApplyDates(self):
        return self.com_object.AutoFormatAsYouTypeApplyDates

    @AutoFormatAsYouTypeApplyDates.setter
    def AutoFormatAsYouTypeApplyDates(self, value):
        self.com_object.AutoFormatAsYouTypeApplyDates = value

    @property
    def autoformatasyoutypeapplydates(self):
        """Alias for AutoFormatAsYouTypeApplyDates"""
        return self.AutoFormatAsYouTypeApplyDates

    @autoformatasyoutypeapplydates.setter
    def autoformatasyoutypeapplydates(self, value):
        """Alias for AutoFormatAsYouTypeApplyDates.setter"""
        self.AutoFormatAsYouTypeApplyDates = value

    @property
    def auto_format_as_you_type_apply_dates(self):
        """Alias for AutoFormatAsYouTypeApplyDates"""
        return self.AutoFormatAsYouTypeApplyDates

    @auto_format_as_you_type_apply_dates.setter
    def auto_format_as_you_type_apply_dates(self, value):
        """Alias for AutoFormatAsYouTypeApplyDates.setter"""
        self.AutoFormatAsYouTypeApplyDates = value

    @property
    def AutoFormatAsYouTypeApplyFirstIndents(self):
        return self.com_object.AutoFormatAsYouTypeApplyFirstIndents

    @AutoFormatAsYouTypeApplyFirstIndents.setter
    def AutoFormatAsYouTypeApplyFirstIndents(self, value):
        self.com_object.AutoFormatAsYouTypeApplyFirstIndents = value

    @property
    def autoformatasyoutypeapplyfirstindents(self):
        """Alias for AutoFormatAsYouTypeApplyFirstIndents"""
        return self.AutoFormatAsYouTypeApplyFirstIndents

    @autoformatasyoutypeapplyfirstindents.setter
    def autoformatasyoutypeapplyfirstindents(self, value):
        """Alias for AutoFormatAsYouTypeApplyFirstIndents.setter"""
        self.AutoFormatAsYouTypeApplyFirstIndents = value

    @property
    def auto_format_as_you_type_apply_first_indents(self):
        """Alias for AutoFormatAsYouTypeApplyFirstIndents"""
        return self.AutoFormatAsYouTypeApplyFirstIndents

    @auto_format_as_you_type_apply_first_indents.setter
    def auto_format_as_you_type_apply_first_indents(self, value):
        """Alias for AutoFormatAsYouTypeApplyFirstIndents.setter"""
        self.AutoFormatAsYouTypeApplyFirstIndents = value

    @property
    def AutoFormatAsYouTypeApplyHeadings(self):
        return self.com_object.AutoFormatAsYouTypeApplyHeadings

    @AutoFormatAsYouTypeApplyHeadings.setter
    def AutoFormatAsYouTypeApplyHeadings(self, value):
        self.com_object.AutoFormatAsYouTypeApplyHeadings = value

    @property
    def autoformatasyoutypeapplyheadings(self):
        """Alias for AutoFormatAsYouTypeApplyHeadings"""
        return self.AutoFormatAsYouTypeApplyHeadings

    @autoformatasyoutypeapplyheadings.setter
    def autoformatasyoutypeapplyheadings(self, value):
        """Alias for AutoFormatAsYouTypeApplyHeadings.setter"""
        self.AutoFormatAsYouTypeApplyHeadings = value

    @property
    def auto_format_as_you_type_apply_headings(self):
        """Alias for AutoFormatAsYouTypeApplyHeadings"""
        return self.AutoFormatAsYouTypeApplyHeadings

    @auto_format_as_you_type_apply_headings.setter
    def auto_format_as_you_type_apply_headings(self, value):
        """Alias for AutoFormatAsYouTypeApplyHeadings.setter"""
        self.AutoFormatAsYouTypeApplyHeadings = value

    @property
    def AutoFormatAsYouTypeApplyNumberedLists(self):
        return self.com_object.AutoFormatAsYouTypeApplyNumberedLists

    @AutoFormatAsYouTypeApplyNumberedLists.setter
    def AutoFormatAsYouTypeApplyNumberedLists(self, value):
        self.com_object.AutoFormatAsYouTypeApplyNumberedLists = value

    @property
    def autoformatasyoutypeapplynumberedlists(self):
        """Alias for AutoFormatAsYouTypeApplyNumberedLists"""
        return self.AutoFormatAsYouTypeApplyNumberedLists

    @autoformatasyoutypeapplynumberedlists.setter
    def autoformatasyoutypeapplynumberedlists(self, value):
        """Alias for AutoFormatAsYouTypeApplyNumberedLists.setter"""
        self.AutoFormatAsYouTypeApplyNumberedLists = value

    @property
    def auto_format_as_you_type_apply_numbered_lists(self):
        """Alias for AutoFormatAsYouTypeApplyNumberedLists"""
        return self.AutoFormatAsYouTypeApplyNumberedLists

    @auto_format_as_you_type_apply_numbered_lists.setter
    def auto_format_as_you_type_apply_numbered_lists(self, value):
        """Alias for AutoFormatAsYouTypeApplyNumberedLists.setter"""
        self.AutoFormatAsYouTypeApplyNumberedLists = value

    @property
    def AutoFormatAsYouTypeApplyTables(self):
        return self.com_object.AutoFormatAsYouTypeApplyTables

    @AutoFormatAsYouTypeApplyTables.setter
    def AutoFormatAsYouTypeApplyTables(self, value):
        self.com_object.AutoFormatAsYouTypeApplyTables = value

    @property
    def autoformatasyoutypeapplytables(self):
        """Alias for AutoFormatAsYouTypeApplyTables"""
        return self.AutoFormatAsYouTypeApplyTables

    @autoformatasyoutypeapplytables.setter
    def autoformatasyoutypeapplytables(self, value):
        """Alias for AutoFormatAsYouTypeApplyTables.setter"""
        self.AutoFormatAsYouTypeApplyTables = value

    @property
    def auto_format_as_you_type_apply_tables(self):
        """Alias for AutoFormatAsYouTypeApplyTables"""
        return self.AutoFormatAsYouTypeApplyTables

    @auto_format_as_you_type_apply_tables.setter
    def auto_format_as_you_type_apply_tables(self, value):
        """Alias for AutoFormatAsYouTypeApplyTables.setter"""
        self.AutoFormatAsYouTypeApplyTables = value

    @property
    def AutoFormatAsYouTypeAutoLetterWizard(self):
        return self.com_object.AutoFormatAsYouTypeAutoLetterWizard

    @AutoFormatAsYouTypeAutoLetterWizard.setter
    def AutoFormatAsYouTypeAutoLetterWizard(self, value):
        self.com_object.AutoFormatAsYouTypeAutoLetterWizard = value

    @property
    def autoformatasyoutypeautoletterwizard(self):
        """Alias for AutoFormatAsYouTypeAutoLetterWizard"""
        return self.AutoFormatAsYouTypeAutoLetterWizard

    @autoformatasyoutypeautoletterwizard.setter
    def autoformatasyoutypeautoletterwizard(self, value):
        """Alias for AutoFormatAsYouTypeAutoLetterWizard.setter"""
        self.AutoFormatAsYouTypeAutoLetterWizard = value

    @property
    def auto_format_as_you_type_auto_letter_wizard(self):
        """Alias for AutoFormatAsYouTypeAutoLetterWizard"""
        return self.AutoFormatAsYouTypeAutoLetterWizard

    @auto_format_as_you_type_auto_letter_wizard.setter
    def auto_format_as_you_type_auto_letter_wizard(self, value):
        """Alias for AutoFormatAsYouTypeAutoLetterWizard.setter"""
        self.AutoFormatAsYouTypeAutoLetterWizard = value

    @property
    def AutoFormatAsYouTypeDefineStyles(self):
        return self.com_object.AutoFormatAsYouTypeDefineStyles

    @AutoFormatAsYouTypeDefineStyles.setter
    def AutoFormatAsYouTypeDefineStyles(self, value):
        self.com_object.AutoFormatAsYouTypeDefineStyles = value

    @property
    def autoformatasyoutypedefinestyles(self):
        """Alias for AutoFormatAsYouTypeDefineStyles"""
        return self.AutoFormatAsYouTypeDefineStyles

    @autoformatasyoutypedefinestyles.setter
    def autoformatasyoutypedefinestyles(self, value):
        """Alias for AutoFormatAsYouTypeDefineStyles.setter"""
        self.AutoFormatAsYouTypeDefineStyles = value

    @property
    def auto_format_as_you_type_define_styles(self):
        """Alias for AutoFormatAsYouTypeDefineStyles"""
        return self.AutoFormatAsYouTypeDefineStyles

    @auto_format_as_you_type_define_styles.setter
    def auto_format_as_you_type_define_styles(self, value):
        """Alias for AutoFormatAsYouTypeDefineStyles.setter"""
        self.AutoFormatAsYouTypeDefineStyles = value

    @property
    def AutoFormatAsYouTypeDeleteAutoSpaces(self):
        return self.com_object.AutoFormatAsYouTypeDeleteAutoSpaces

    @AutoFormatAsYouTypeDeleteAutoSpaces.setter
    def AutoFormatAsYouTypeDeleteAutoSpaces(self, value):
        self.com_object.AutoFormatAsYouTypeDeleteAutoSpaces = value

    @property
    def autoformatasyoutypedeleteautospaces(self):
        """Alias for AutoFormatAsYouTypeDeleteAutoSpaces"""
        return self.AutoFormatAsYouTypeDeleteAutoSpaces

    @autoformatasyoutypedeleteautospaces.setter
    def autoformatasyoutypedeleteautospaces(self, value):
        """Alias for AutoFormatAsYouTypeDeleteAutoSpaces.setter"""
        self.AutoFormatAsYouTypeDeleteAutoSpaces = value

    @property
    def auto_format_as_you_type_delete_auto_spaces(self):
        """Alias for AutoFormatAsYouTypeDeleteAutoSpaces"""
        return self.AutoFormatAsYouTypeDeleteAutoSpaces

    @auto_format_as_you_type_delete_auto_spaces.setter
    def auto_format_as_you_type_delete_auto_spaces(self, value):
        """Alias for AutoFormatAsYouTypeDeleteAutoSpaces.setter"""
        self.AutoFormatAsYouTypeDeleteAutoSpaces = value

    @property
    def AutoFormatAsYouTypeFormatListItemBeginning(self):
        return self.com_object.AutoFormatAsYouTypeFormatListItemBeginning

    @AutoFormatAsYouTypeFormatListItemBeginning.setter
    def AutoFormatAsYouTypeFormatListItemBeginning(self, value):
        self.com_object.AutoFormatAsYouTypeFormatListItemBeginning = value

    @property
    def autoformatasyoutypeformatlistitembeginning(self):
        """Alias for AutoFormatAsYouTypeFormatListItemBeginning"""
        return self.AutoFormatAsYouTypeFormatListItemBeginning

    @autoformatasyoutypeformatlistitembeginning.setter
    def autoformatasyoutypeformatlistitembeginning(self, value):
        """Alias for AutoFormatAsYouTypeFormatListItemBeginning.setter"""
        self.AutoFormatAsYouTypeFormatListItemBeginning = value

    @property
    def auto_format_as_you_type_format_list_item_beginning(self):
        """Alias for AutoFormatAsYouTypeFormatListItemBeginning"""
        return self.AutoFormatAsYouTypeFormatListItemBeginning

    @auto_format_as_you_type_format_list_item_beginning.setter
    def auto_format_as_you_type_format_list_item_beginning(self, value):
        """Alias for AutoFormatAsYouTypeFormatListItemBeginning.setter"""
        self.AutoFormatAsYouTypeFormatListItemBeginning = value

    @property
    def AutoFormatAsYouTypeInsertClosings(self):
        return self.com_object.AutoFormatAsYouTypeInsertClosings

    @AutoFormatAsYouTypeInsertClosings.setter
    def AutoFormatAsYouTypeInsertClosings(self, value):
        self.com_object.AutoFormatAsYouTypeInsertClosings = value

    @property
    def autoformatasyoutypeinsertclosings(self):
        """Alias for AutoFormatAsYouTypeInsertClosings"""
        return self.AutoFormatAsYouTypeInsertClosings

    @autoformatasyoutypeinsertclosings.setter
    def autoformatasyoutypeinsertclosings(self, value):
        """Alias for AutoFormatAsYouTypeInsertClosings.setter"""
        self.AutoFormatAsYouTypeInsertClosings = value

    @property
    def auto_format_as_you_type_insert_closings(self):
        """Alias for AutoFormatAsYouTypeInsertClosings"""
        return self.AutoFormatAsYouTypeInsertClosings

    @auto_format_as_you_type_insert_closings.setter
    def auto_format_as_you_type_insert_closings(self, value):
        """Alias for AutoFormatAsYouTypeInsertClosings.setter"""
        self.AutoFormatAsYouTypeInsertClosings = value

    @property
    def AutoFormatAsYouTypeInsertOvers(self):
        return self.com_object.AutoFormatAsYouTypeInsertOvers

    @AutoFormatAsYouTypeInsertOvers.setter
    def AutoFormatAsYouTypeInsertOvers(self, value):
        self.com_object.AutoFormatAsYouTypeInsertOvers = value

    @property
    def autoformatasyoutypeinsertovers(self):
        """Alias for AutoFormatAsYouTypeInsertOvers"""
        return self.AutoFormatAsYouTypeInsertOvers

    @autoformatasyoutypeinsertovers.setter
    def autoformatasyoutypeinsertovers(self, value):
        """Alias for AutoFormatAsYouTypeInsertOvers.setter"""
        self.AutoFormatAsYouTypeInsertOvers = value

    @property
    def auto_format_as_you_type_insert_overs(self):
        """Alias for AutoFormatAsYouTypeInsertOvers"""
        return self.AutoFormatAsYouTypeInsertOvers

    @auto_format_as_you_type_insert_overs.setter
    def auto_format_as_you_type_insert_overs(self, value):
        """Alias for AutoFormatAsYouTypeInsertOvers.setter"""
        self.AutoFormatAsYouTypeInsertOvers = value

    @property
    def AutoFormatAsYouTypeMatchParentheses(self):
        return self.com_object.AutoFormatAsYouTypeMatchParentheses

    @AutoFormatAsYouTypeMatchParentheses.setter
    def AutoFormatAsYouTypeMatchParentheses(self, value):
        self.com_object.AutoFormatAsYouTypeMatchParentheses = value

    @property
    def autoformatasyoutypematchparentheses(self):
        """Alias for AutoFormatAsYouTypeMatchParentheses"""
        return self.AutoFormatAsYouTypeMatchParentheses

    @autoformatasyoutypematchparentheses.setter
    def autoformatasyoutypematchparentheses(self, value):
        """Alias for AutoFormatAsYouTypeMatchParentheses.setter"""
        self.AutoFormatAsYouTypeMatchParentheses = value

    @property
    def auto_format_as_you_type_match_parentheses(self):
        """Alias for AutoFormatAsYouTypeMatchParentheses"""
        return self.AutoFormatAsYouTypeMatchParentheses

    @auto_format_as_you_type_match_parentheses.setter
    def auto_format_as_you_type_match_parentheses(self, value):
        """Alias for AutoFormatAsYouTypeMatchParentheses.setter"""
        self.AutoFormatAsYouTypeMatchParentheses = value

    @property
    def AutoFormatAsYouTypeReplaceFarEastDashes(self):
        return self.com_object.AutoFormatAsYouTypeReplaceFarEastDashes

    @AutoFormatAsYouTypeReplaceFarEastDashes.setter
    def AutoFormatAsYouTypeReplaceFarEastDashes(self, value):
        self.com_object.AutoFormatAsYouTypeReplaceFarEastDashes = value

    @property
    def autoformatasyoutypereplacefareastdashes(self):
        """Alias for AutoFormatAsYouTypeReplaceFarEastDashes"""
        return self.AutoFormatAsYouTypeReplaceFarEastDashes

    @autoformatasyoutypereplacefareastdashes.setter
    def autoformatasyoutypereplacefareastdashes(self, value):
        """Alias for AutoFormatAsYouTypeReplaceFarEastDashes.setter"""
        self.AutoFormatAsYouTypeReplaceFarEastDashes = value

    @property
    def auto_format_as_you_type_replace_far_east_dashes(self):
        """Alias for AutoFormatAsYouTypeReplaceFarEastDashes"""
        return self.AutoFormatAsYouTypeReplaceFarEastDashes

    @auto_format_as_you_type_replace_far_east_dashes.setter
    def auto_format_as_you_type_replace_far_east_dashes(self, value):
        """Alias for AutoFormatAsYouTypeReplaceFarEastDashes.setter"""
        self.AutoFormatAsYouTypeReplaceFarEastDashes = value

    @property
    def AutoFormatAsYouTypeReplaceFractions(self):
        return self.com_object.AutoFormatAsYouTypeReplaceFractions

    @AutoFormatAsYouTypeReplaceFractions.setter
    def AutoFormatAsYouTypeReplaceFractions(self, value):
        self.com_object.AutoFormatAsYouTypeReplaceFractions = value

    @property
    def autoformatasyoutypereplacefractions(self):
        """Alias for AutoFormatAsYouTypeReplaceFractions"""
        return self.AutoFormatAsYouTypeReplaceFractions

    @autoformatasyoutypereplacefractions.setter
    def autoformatasyoutypereplacefractions(self, value):
        """Alias for AutoFormatAsYouTypeReplaceFractions.setter"""
        self.AutoFormatAsYouTypeReplaceFractions = value

    @property
    def auto_format_as_you_type_replace_fractions(self):
        """Alias for AutoFormatAsYouTypeReplaceFractions"""
        return self.AutoFormatAsYouTypeReplaceFractions

    @auto_format_as_you_type_replace_fractions.setter
    def auto_format_as_you_type_replace_fractions(self, value):
        """Alias for AutoFormatAsYouTypeReplaceFractions.setter"""
        self.AutoFormatAsYouTypeReplaceFractions = value

    @property
    def AutoFormatAsYouTypeReplaceHyperlinks(self):
        return self.com_object.AutoFormatAsYouTypeReplaceHyperlinks

    @AutoFormatAsYouTypeReplaceHyperlinks.setter
    def AutoFormatAsYouTypeReplaceHyperlinks(self, value):
        self.com_object.AutoFormatAsYouTypeReplaceHyperlinks = value

    @property
    def autoformatasyoutypereplacehyperlinks(self):
        """Alias for AutoFormatAsYouTypeReplaceHyperlinks"""
        return self.AutoFormatAsYouTypeReplaceHyperlinks

    @autoformatasyoutypereplacehyperlinks.setter
    def autoformatasyoutypereplacehyperlinks(self, value):
        """Alias for AutoFormatAsYouTypeReplaceHyperlinks.setter"""
        self.AutoFormatAsYouTypeReplaceHyperlinks = value

    @property
    def auto_format_as_you_type_replace_hyperlinks(self):
        """Alias for AutoFormatAsYouTypeReplaceHyperlinks"""
        return self.AutoFormatAsYouTypeReplaceHyperlinks

    @auto_format_as_you_type_replace_hyperlinks.setter
    def auto_format_as_you_type_replace_hyperlinks(self, value):
        """Alias for AutoFormatAsYouTypeReplaceHyperlinks.setter"""
        self.AutoFormatAsYouTypeReplaceHyperlinks = value

    @property
    def AutoFormatAsYouTypeReplaceOrdinals(self):
        return self.com_object.AutoFormatAsYouTypeReplaceOrdinals

    @AutoFormatAsYouTypeReplaceOrdinals.setter
    def AutoFormatAsYouTypeReplaceOrdinals(self, value):
        self.com_object.AutoFormatAsYouTypeReplaceOrdinals = value

    @property
    def autoformatasyoutypereplaceordinals(self):
        """Alias for AutoFormatAsYouTypeReplaceOrdinals"""
        return self.AutoFormatAsYouTypeReplaceOrdinals

    @autoformatasyoutypereplaceordinals.setter
    def autoformatasyoutypereplaceordinals(self, value):
        """Alias for AutoFormatAsYouTypeReplaceOrdinals.setter"""
        self.AutoFormatAsYouTypeReplaceOrdinals = value

    @property
    def auto_format_as_you_type_replace_ordinals(self):
        """Alias for AutoFormatAsYouTypeReplaceOrdinals"""
        return self.AutoFormatAsYouTypeReplaceOrdinals

    @auto_format_as_you_type_replace_ordinals.setter
    def auto_format_as_you_type_replace_ordinals(self, value):
        """Alias for AutoFormatAsYouTypeReplaceOrdinals.setter"""
        self.AutoFormatAsYouTypeReplaceOrdinals = value

    @property
    def AutoFormatAsYouTypeReplacePlainTextEmphasis(self):
        return self.com_object.AutoFormatAsYouTypeReplacePlainTextEmphasis

    @AutoFormatAsYouTypeReplacePlainTextEmphasis.setter
    def AutoFormatAsYouTypeReplacePlainTextEmphasis(self, value):
        self.com_object.AutoFormatAsYouTypeReplacePlainTextEmphasis = value

    @property
    def autoformatasyoutypereplaceplaintextemphasis(self):
        """Alias for AutoFormatAsYouTypeReplacePlainTextEmphasis"""
        return self.AutoFormatAsYouTypeReplacePlainTextEmphasis

    @autoformatasyoutypereplaceplaintextemphasis.setter
    def autoformatasyoutypereplaceplaintextemphasis(self, value):
        """Alias for AutoFormatAsYouTypeReplacePlainTextEmphasis.setter"""
        self.AutoFormatAsYouTypeReplacePlainTextEmphasis = value

    @property
    def auto_format_as_you_type_replace_plain_text_emphasis(self):
        """Alias for AutoFormatAsYouTypeReplacePlainTextEmphasis"""
        return self.AutoFormatAsYouTypeReplacePlainTextEmphasis

    @auto_format_as_you_type_replace_plain_text_emphasis.setter
    def auto_format_as_you_type_replace_plain_text_emphasis(self, value):
        """Alias for AutoFormatAsYouTypeReplacePlainTextEmphasis.setter"""
        self.AutoFormatAsYouTypeReplacePlainTextEmphasis = value

    @property
    def AutoFormatAsYouTypeReplaceQuotes(self):
        return self.com_object.AutoFormatAsYouTypeReplaceQuotes

    @AutoFormatAsYouTypeReplaceQuotes.setter
    def AutoFormatAsYouTypeReplaceQuotes(self, value):
        self.com_object.AutoFormatAsYouTypeReplaceQuotes = value

    @property
    def autoformatasyoutypereplacequotes(self):
        """Alias for AutoFormatAsYouTypeReplaceQuotes"""
        return self.AutoFormatAsYouTypeReplaceQuotes

    @autoformatasyoutypereplacequotes.setter
    def autoformatasyoutypereplacequotes(self, value):
        """Alias for AutoFormatAsYouTypeReplaceQuotes.setter"""
        self.AutoFormatAsYouTypeReplaceQuotes = value

    @property
    def auto_format_as_you_type_replace_quotes(self):
        """Alias for AutoFormatAsYouTypeReplaceQuotes"""
        return self.AutoFormatAsYouTypeReplaceQuotes

    @auto_format_as_you_type_replace_quotes.setter
    def auto_format_as_you_type_replace_quotes(self, value):
        """Alias for AutoFormatAsYouTypeReplaceQuotes.setter"""
        self.AutoFormatAsYouTypeReplaceQuotes = value

    @property
    def AutoFormatAsYouTypeReplaceSymbols(self):
        return self.com_object.AutoFormatAsYouTypeReplaceSymbols

    @AutoFormatAsYouTypeReplaceSymbols.setter
    def AutoFormatAsYouTypeReplaceSymbols(self, value):
        self.com_object.AutoFormatAsYouTypeReplaceSymbols = value

    @property
    def autoformatasyoutypereplacesymbols(self):
        """Alias for AutoFormatAsYouTypeReplaceSymbols"""
        return self.AutoFormatAsYouTypeReplaceSymbols

    @autoformatasyoutypereplacesymbols.setter
    def autoformatasyoutypereplacesymbols(self, value):
        """Alias for AutoFormatAsYouTypeReplaceSymbols.setter"""
        self.AutoFormatAsYouTypeReplaceSymbols = value

    @property
    def auto_format_as_you_type_replace_symbols(self):
        """Alias for AutoFormatAsYouTypeReplaceSymbols"""
        return self.AutoFormatAsYouTypeReplaceSymbols

    @auto_format_as_you_type_replace_symbols.setter
    def auto_format_as_you_type_replace_symbols(self, value):
        """Alias for AutoFormatAsYouTypeReplaceSymbols.setter"""
        self.AutoFormatAsYouTypeReplaceSymbols = value

    @property
    def ComposeStyle(self):
        return Style(self.com_object.ComposeStyle)

    @property
    def composestyle(self):
        """Alias for ComposeStyle"""
        return self.ComposeStyle

    @property
    def compose_style(self):
        """Alias for ComposeStyle"""
        return self.ComposeStyle

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def EmailSignature(self):
        return EmailSignature(self.com_object.EmailSignature)

    @property
    def emailsignature(self):
        """Alias for EmailSignature"""
        return self.EmailSignature

    @property
    def email_signature(self):
        """Alias for EmailSignature"""
        return self.EmailSignature

    @property
    def HTMLFidelity(self):
        return self.com_object.HTMLFidelity

    @HTMLFidelity.setter
    def HTMLFidelity(self, value):
        self.com_object.HTMLFidelity = value

    @property
    def htmlfidelity(self):
        """Alias for HTMLFidelity"""
        return self.HTMLFidelity

    @htmlfidelity.setter
    def htmlfidelity(self, value):
        """Alias for HTMLFidelity.setter"""
        self.HTMLFidelity = value

    @property
    def h_t_m_l_fidelity(self):
        """Alias for HTMLFidelity"""
        return self.HTMLFidelity

    @h_t_m_l_fidelity.setter
    def h_t_m_l_fidelity(self, value):
        """Alias for HTMLFidelity.setter"""
        self.HTMLFidelity = value

    @property
    def MarkComments(self):
        return self.com_object.MarkComments

    @MarkComments.setter
    def MarkComments(self, value):
        self.com_object.MarkComments = value

    @property
    def markcomments(self):
        """Alias for MarkComments"""
        return self.MarkComments

    @markcomments.setter
    def markcomments(self, value):
        """Alias for MarkComments.setter"""
        self.MarkComments = value

    @property
    def mark_comments(self):
        """Alias for MarkComments"""
        return self.MarkComments

    @mark_comments.setter
    def mark_comments(self, value):
        """Alias for MarkComments.setter"""
        self.MarkComments = value

    @property
    def MarkCommentsWith(self):
        return self.com_object.MarkCommentsWith

    @MarkCommentsWith.setter
    def MarkCommentsWith(self, value):
        self.com_object.MarkCommentsWith = value

    @property
    def markcommentswith(self):
        """Alias for MarkCommentsWith"""
        return self.MarkCommentsWith

    @markcommentswith.setter
    def markcommentswith(self, value):
        """Alias for MarkCommentsWith.setter"""
        self.MarkCommentsWith = value

    @property
    def mark_comments_with(self):
        """Alias for MarkCommentsWith"""
        return self.MarkCommentsWith

    @mark_comments_with.setter
    def mark_comments_with(self, value):
        """Alias for MarkCommentsWith.setter"""
        self.MarkCommentsWith = value

    @property
    def NewColorOnReply(self):
        return self.com_object.NewColorOnReply

    @NewColorOnReply.setter
    def NewColorOnReply(self, value):
        self.com_object.NewColorOnReply = value

    @property
    def newcoloronreply(self):
        """Alias for NewColorOnReply"""
        return self.NewColorOnReply

    @newcoloronreply.setter
    def newcoloronreply(self, value):
        """Alias for NewColorOnReply.setter"""
        self.NewColorOnReply = value

    @property
    def new_color_on_reply(self):
        """Alias for NewColorOnReply"""
        return self.NewColorOnReply

    @new_color_on_reply.setter
    def new_color_on_reply(self, value):
        """Alias for NewColorOnReply.setter"""
        self.NewColorOnReply = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PlainTextStyle(self):
        return Style(self.com_object.PlainTextStyle)

    @property
    def plaintextstyle(self):
        """Alias for PlainTextStyle"""
        return self.PlainTextStyle

    @property
    def plain_text_style(self):
        """Alias for PlainTextStyle"""
        return self.PlainTextStyle

    @property
    def RelyOnCSS(self):
        return self.com_object.RelyOnCSS

    @RelyOnCSS.setter
    def RelyOnCSS(self, value):
        self.com_object.RelyOnCSS = value

    @property
    def relyoncss(self):
        """Alias for RelyOnCSS"""
        return self.RelyOnCSS

    @relyoncss.setter
    def relyoncss(self, value):
        """Alias for RelyOnCSS.setter"""
        self.RelyOnCSS = value

    @property
    def rely_on_c_s_s(self):
        """Alias for RelyOnCSS"""
        return self.RelyOnCSS

    @rely_on_c_s_s.setter
    def rely_on_c_s_s(self, value):
        """Alias for RelyOnCSS.setter"""
        self.RelyOnCSS = value

    @property
    def ReplyStyle(self):
        return Style(self.com_object.ReplyStyle)

    @property
    def replystyle(self):
        """Alias for ReplyStyle"""
        return self.ReplyStyle

    @property
    def reply_style(self):
        """Alias for ReplyStyle"""
        return self.ReplyStyle

    @property
    def TabIndentKey(self):
        return self.com_object.TabIndentKey

    @TabIndentKey.setter
    def TabIndentKey(self, value):
        self.com_object.TabIndentKey = value

    @property
    def tabindentkey(self):
        """Alias for TabIndentKey"""
        return self.TabIndentKey

    @tabindentkey.setter
    def tabindentkey(self, value):
        """Alias for TabIndentKey.setter"""
        self.TabIndentKey = value

    @property
    def tab_indent_key(self):
        """Alias for TabIndentKey"""
        return self.TabIndentKey

    @tab_indent_key.setter
    def tab_indent_key(self, value):
        """Alias for TabIndentKey.setter"""
        self.TabIndentKey = value

    @property
    def ThemeName(self):
        return self.com_object.ThemeName

    @ThemeName.setter
    def ThemeName(self, value):
        self.com_object.ThemeName = value

    @property
    def themename(self):
        """Alias for ThemeName"""
        return self.ThemeName

    @themename.setter
    def themename(self, value):
        """Alias for ThemeName.setter"""
        self.ThemeName = value

    @property
    def theme_name(self):
        """Alias for ThemeName"""
        return self.ThemeName

    @theme_name.setter
    def theme_name(self, value):
        """Alias for ThemeName.setter"""
        self.ThemeName = value

    @property
    def UseThemeStyle(self):
        return self.com_object.UseThemeStyle

    @UseThemeStyle.setter
    def UseThemeStyle(self, value):
        self.com_object.UseThemeStyle = value

    @property
    def usethemestyle(self):
        """Alias for UseThemeStyle"""
        return self.UseThemeStyle

    @usethemestyle.setter
    def usethemestyle(self, value):
        """Alias for UseThemeStyle.setter"""
        self.UseThemeStyle = value

    @property
    def use_theme_style(self):
        """Alias for UseThemeStyle"""
        return self.UseThemeStyle

    @use_theme_style.setter
    def use_theme_style(self, value):
        """Alias for UseThemeStyle.setter"""
        self.UseThemeStyle = value

    @property
    def UseThemeStyleOnReply(self):
        return self.com_object.UseThemeStyleOnReply

    @UseThemeStyleOnReply.setter
    def UseThemeStyleOnReply(self, value):
        self.com_object.UseThemeStyleOnReply = value

    @property
    def usethemestyleonreply(self):
        """Alias for UseThemeStyleOnReply"""
        return self.UseThemeStyleOnReply

    @usethemestyleonreply.setter
    def usethemestyleonreply(self, value):
        """Alias for UseThemeStyleOnReply.setter"""
        self.UseThemeStyleOnReply = value

    @property
    def use_theme_style_on_reply(self):
        """Alias for UseThemeStyleOnReply"""
        return self.UseThemeStyleOnReply

    @use_theme_style_on_reply.setter
    def use_theme_style_on_reply(self, value):
        """Alias for UseThemeStyleOnReply.setter"""
        self.UseThemeStyleOnReply = value


class EmailSignature:

    def __init__(self, emailsignature=None):
        self.com_object= emailsignature

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def EmailSignatureEntries(self):
        return EmailSignatureEntries(self.com_object.EmailSignatureEntries)

    @property
    def emailsignatureentries(self):
        """Alias for EmailSignatureEntries"""
        return self.EmailSignatureEntries

    @property
    def email_signature_entries(self):
        """Alias for EmailSignatureEntries"""
        return self.EmailSignatureEntries

    @property
    def NewMessageSignature(self):
        return self.com_object.NewMessageSignature

    @NewMessageSignature.setter
    def NewMessageSignature(self, value):
        self.com_object.NewMessageSignature = value

    @property
    def newmessagesignature(self):
        """Alias for NewMessageSignature"""
        return self.NewMessageSignature

    @newmessagesignature.setter
    def newmessagesignature(self, value):
        """Alias for NewMessageSignature.setter"""
        self.NewMessageSignature = value

    @property
    def new_message_signature(self):
        """Alias for NewMessageSignature"""
        return self.NewMessageSignature

    @new_message_signature.setter
    def new_message_signature(self, value):
        """Alias for NewMessageSignature.setter"""
        self.NewMessageSignature = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ReplyMessageSignature(self):
        return self.com_object.ReplyMessageSignature

    @ReplyMessageSignature.setter
    def ReplyMessageSignature(self, value):
        self.com_object.ReplyMessageSignature = value

    @property
    def replymessagesignature(self):
        """Alias for ReplyMessageSignature"""
        return self.ReplyMessageSignature

    @replymessagesignature.setter
    def replymessagesignature(self, value):
        """Alias for ReplyMessageSignature.setter"""
        self.ReplyMessageSignature = value

    @property
    def reply_message_signature(self):
        """Alias for ReplyMessageSignature"""
        return self.ReplyMessageSignature

    @reply_message_signature.setter
    def reply_message_signature(self, value):
        """Alias for ReplyMessageSignature.setter"""
        self.ReplyMessageSignature = value


class EmailSignatureEntries:

    def __init__(self, emailsignatureentries=None):
        self.com_object= emailsignatureentries

    def __call__(self, item):
        return EmailSignatureEntrie(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Range]])
        return EmailSignatureEntry(self.com_object.Add(*arguments))

    def add(self, Name=None, Range=None):
        """Alias for Add"""
        arguments = [Name, Range]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return EmailSignatureEntry(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class EmailSignatureEntry:

    def __init__(self, emailsignatureentry=None):
        self.com_object= emailsignatureentry

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class Endnote:

    def __init__(self, endnote=None):
        self.com_object= endnote

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def Reference(self):
        return Range(self.com_object.Reference)

    @property
    def reference(self):
        """Alias for Reference"""
        return self.Reference

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class EndnoteOptions:

    def __init__(self, endnoteoptions=None):
        self.com_object= endnoteoptions

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Location(self):
        return WdEndnoteLocation(self.com_object.Location)

    @Location.setter
    def Location(self, value):
        self.com_object.Location = value

    @property
    def location(self):
        """Alias for Location"""
        return self.Location

    @location.setter
    def location(self, value):
        """Alias for Location.setter"""
        self.Location = value

    @property
    def NumberingRule(self):
        return WdNumberingRule(self.com_object.NumberingRule)

    @NumberingRule.setter
    def NumberingRule(self, value):
        self.com_object.NumberingRule = value

    @property
    def numberingrule(self):
        """Alias for NumberingRule"""
        return self.NumberingRule

    @numberingrule.setter
    def numberingrule(self, value):
        """Alias for NumberingRule.setter"""
        self.NumberingRule = value

    @property
    def numbering_rule(self):
        """Alias for NumberingRule"""
        return self.NumberingRule

    @numbering_rule.setter
    def numbering_rule(self, value):
        """Alias for NumberingRule.setter"""
        self.NumberingRule = value

    @property
    def NumberStyle(self):
        return WdNoteNumberStyle(self.com_object.NumberStyle)

    @NumberStyle.setter
    def NumberStyle(self, value):
        self.com_object.NumberStyle = value

    @property
    def numberstyle(self):
        """Alias for NumberStyle"""
        return self.NumberStyle

    @numberstyle.setter
    def numberstyle(self, value):
        """Alias for NumberStyle.setter"""
        self.NumberStyle = value

    @property
    def number_style(self):
        """Alias for NumberStyle"""
        return self.NumberStyle

    @number_style.setter
    def number_style(self, value):
        """Alias for NumberStyle.setter"""
        self.NumberStyle = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def StartingNumber(self):
        return self.com_object.StartingNumber

    @StartingNumber.setter
    def StartingNumber(self, value):
        self.com_object.StartingNumber = value

    @property
    def startingnumber(self):
        """Alias for StartingNumber"""
        return self.StartingNumber

    @startingnumber.setter
    def startingnumber(self, value):
        """Alias for StartingNumber.setter"""
        self.StartingNumber = value

    @property
    def starting_number(self):
        """Alias for StartingNumber"""
        return self.StartingNumber

    @starting_number.setter
    def starting_number(self, value):
        """Alias for StartingNumber.setter"""
        self.StartingNumber = value


class Endnotes:

    def __init__(self, endnotes=None):
        self.com_object= endnotes

    def __call__(self, item):
        return Endnote(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ContinuationNotice(self):
        return Range(self.com_object.ContinuationNotice)

    @property
    def continuationnotice(self):
        """Alias for ContinuationNotice"""
        return self.ContinuationNotice

    @property
    def continuation_notice(self):
        """Alias for ContinuationNotice"""
        return self.ContinuationNotice

    @property
    def ContinuationSeparator(self):
        return Range(self.com_object.ContinuationSeparator)

    @property
    def continuationseparator(self):
        """Alias for ContinuationSeparator"""
        return self.ContinuationSeparator

    @property
    def continuation_separator(self):
        """Alias for ContinuationSeparator"""
        return self.ContinuationSeparator

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Location(self):
        return WdEndnoteLocation(self.com_object.Location)

    @Location.setter
    def Location(self, value):
        self.com_object.Location = value

    @property
    def location(self):
        """Alias for Location"""
        return self.Location

    @location.setter
    def location(self, value):
        """Alias for Location.setter"""
        self.Location = value

    @property
    def NumberingRule(self):
        return WdNumberingRule(self.com_object.NumberingRule)

    @NumberingRule.setter
    def NumberingRule(self, value):
        self.com_object.NumberingRule = value

    @property
    def numberingrule(self):
        """Alias for NumberingRule"""
        return self.NumberingRule

    @numberingrule.setter
    def numberingrule(self, value):
        """Alias for NumberingRule.setter"""
        self.NumberingRule = value

    @property
    def numbering_rule(self):
        """Alias for NumberingRule"""
        return self.NumberingRule

    @numbering_rule.setter
    def numbering_rule(self, value):
        """Alias for NumberingRule.setter"""
        self.NumberingRule = value

    @property
    def NumberStyle(self):
        return WdNoteNumberStyle(self.com_object.NumberStyle)

    @NumberStyle.setter
    def NumberStyle(self, value):
        self.com_object.NumberStyle = value

    @property
    def numberstyle(self):
        """Alias for NumberStyle"""
        return self.NumberStyle

    @numberstyle.setter
    def numberstyle(self, value):
        """Alias for NumberStyle.setter"""
        self.NumberStyle = value

    @property
    def number_style(self):
        """Alias for NumberStyle"""
        return self.NumberStyle

    @number_style.setter
    def number_style(self, value):
        """Alias for NumberStyle.setter"""
        self.NumberStyle = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Separator(self):
        return Range(self.com_object.Separator)

    @property
    def separator(self):
        """Alias for Separator"""
        return self.Separator

    @property
    def StartingNumber(self):
        return self.com_object.StartingNumber

    @StartingNumber.setter
    def StartingNumber(self, value):
        self.com_object.StartingNumber = value

    @property
    def startingnumber(self):
        """Alias for StartingNumber"""
        return self.StartingNumber

    @startingnumber.setter
    def startingnumber(self, value):
        """Alias for StartingNumber.setter"""
        self.StartingNumber = value

    @property
    def starting_number(self):
        """Alias for StartingNumber"""
        return self.StartingNumber

    @starting_number.setter
    def starting_number(self, value):
        """Alias for StartingNumber.setter"""
        self.StartingNumber = value

    def Add(self, Range=None, Reference=None, Text=None):
        arguments = com_arguments([unwrap(a) for a in [Range, Reference, Text]])
        self.com_object.Add(*arguments)

    def add(self, Range=None, Reference=None, Text=None):
        """Alias for Add"""
        arguments = [Range, Reference, Text]
        return self.Add(*arguments)

    def Convert(self):
        self.com_object.Convert()

    def convert(self):
        """Alias for Convert"""
        return self.Convert()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Endnote(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def ResetContinuationNotice(self):
        self.com_object.ResetContinuationNotice()

    def resetcontinuationnotice(self):
        """Alias for ResetContinuationNotice"""
        return self.ResetContinuationNotice()

    def reset_continuation_notice(self):
        """Alias for ResetContinuationNotice"""
        return self.ResetContinuationNotice()

    def ResetContinuationSeparator(self):
        self.com_object.ResetContinuationSeparator()

    def resetcontinuationseparator(self):
        """Alias for ResetContinuationSeparator"""
        return self.ResetContinuationSeparator()

    def reset_continuation_separator(self):
        """Alias for ResetContinuationSeparator"""
        return self.ResetContinuationSeparator()

    def ResetSeparator(self):
        self.com_object.ResetSeparator()

    def resetseparator(self):
        """Alias for ResetSeparator"""
        return self.ResetSeparator()

    def reset_separator(self):
        """Alias for ResetSeparator"""
        return self.ResetSeparator()

    def SwapWithFootnotes(self):
        self.com_object.SwapWithFootnotes()

    def swapwithfootnotes(self):
        """Alias for SwapWithFootnotes"""
        return self.SwapWithFootnotes()

    def swap_with_footnotes(self):
        """Alias for SwapWithFootnotes"""
        return self.SwapWithFootnotes()


class Envelope:

    def __init__(self, envelope=None):
        self.com_object= envelope

    @property
    def Address(self):
        return Range(self.com_object.Address)

    @property
    def address(self):
        """Alias for Address"""
        return self.Address

    @property
    def AddressFromLeft(self):
        return self.com_object.AddressFromLeft

    @AddressFromLeft.setter
    def AddressFromLeft(self, value):
        self.com_object.AddressFromLeft = value

    @property
    def addressfromleft(self):
        """Alias for AddressFromLeft"""
        return self.AddressFromLeft

    @addressfromleft.setter
    def addressfromleft(self, value):
        """Alias for AddressFromLeft.setter"""
        self.AddressFromLeft = value

    @property
    def address_from_left(self):
        """Alias for AddressFromLeft"""
        return self.AddressFromLeft

    @address_from_left.setter
    def address_from_left(self, value):
        """Alias for AddressFromLeft.setter"""
        self.AddressFromLeft = value

    @property
    def AddressFromTop(self):
        return self.com_object.AddressFromTop

    @AddressFromTop.setter
    def AddressFromTop(self, value):
        self.com_object.AddressFromTop = value

    @property
    def addressfromtop(self):
        """Alias for AddressFromTop"""
        return self.AddressFromTop

    @addressfromtop.setter
    def addressfromtop(self, value):
        """Alias for AddressFromTop.setter"""
        self.AddressFromTop = value

    @property
    def address_from_top(self):
        """Alias for AddressFromTop"""
        return self.AddressFromTop

    @address_from_top.setter
    def address_from_top(self, value):
        """Alias for AddressFromTop.setter"""
        self.AddressFromTop = value

    @property
    def AddressStyle(self):
        return Style(self.com_object.AddressStyle)

    @property
    def addressstyle(self):
        """Alias for AddressStyle"""
        return self.AddressStyle

    @property
    def address_style(self):
        """Alias for AddressStyle"""
        return self.AddressStyle

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DefaultFaceUp(self):
        return self.com_object.DefaultFaceUp

    @DefaultFaceUp.setter
    def DefaultFaceUp(self, value):
        self.com_object.DefaultFaceUp = value

    @property
    def defaultfaceup(self):
        """Alias for DefaultFaceUp"""
        return self.DefaultFaceUp

    @defaultfaceup.setter
    def defaultfaceup(self, value):
        """Alias for DefaultFaceUp.setter"""
        self.DefaultFaceUp = value

    @property
    def default_face_up(self):
        """Alias for DefaultFaceUp"""
        return self.DefaultFaceUp

    @default_face_up.setter
    def default_face_up(self, value):
        """Alias for DefaultFaceUp.setter"""
        self.DefaultFaceUp = value

    @property
    def DefaultHeight(self):
        return self.com_object.DefaultHeight

    @DefaultHeight.setter
    def DefaultHeight(self, value):
        self.com_object.DefaultHeight = value

    @property
    def defaultheight(self):
        """Alias for DefaultHeight"""
        return self.DefaultHeight

    @defaultheight.setter
    def defaultheight(self, value):
        """Alias for DefaultHeight.setter"""
        self.DefaultHeight = value

    @property
    def default_height(self):
        """Alias for DefaultHeight"""
        return self.DefaultHeight

    @default_height.setter
    def default_height(self, value):
        """Alias for DefaultHeight.setter"""
        self.DefaultHeight = value

    @property
    def DefaultOmitReturnAddress(self):
        return self.com_object.DefaultOmitReturnAddress

    @DefaultOmitReturnAddress.setter
    def DefaultOmitReturnAddress(self, value):
        self.com_object.DefaultOmitReturnAddress = value

    @property
    def defaultomitreturnaddress(self):
        """Alias for DefaultOmitReturnAddress"""
        return self.DefaultOmitReturnAddress

    @defaultomitreturnaddress.setter
    def defaultomitreturnaddress(self, value):
        """Alias for DefaultOmitReturnAddress.setter"""
        self.DefaultOmitReturnAddress = value

    @property
    def default_omit_return_address(self):
        """Alias for DefaultOmitReturnAddress"""
        return self.DefaultOmitReturnAddress

    @default_omit_return_address.setter
    def default_omit_return_address(self, value):
        """Alias for DefaultOmitReturnAddress.setter"""
        self.DefaultOmitReturnAddress = value

    @property
    def DefaultOrientation(self):
        return WdEnvelopeOrientation(self.com_object.DefaultOrientation)

    @DefaultOrientation.setter
    def DefaultOrientation(self, value):
        self.com_object.DefaultOrientation = value

    @property
    def defaultorientation(self):
        """Alias for DefaultOrientation"""
        return self.DefaultOrientation

    @defaultorientation.setter
    def defaultorientation(self, value):
        """Alias for DefaultOrientation.setter"""
        self.DefaultOrientation = value

    @property
    def default_orientation(self):
        """Alias for DefaultOrientation"""
        return self.DefaultOrientation

    @default_orientation.setter
    def default_orientation(self, value):
        """Alias for DefaultOrientation.setter"""
        self.DefaultOrientation = value

    @property
    def DefaultPrintFIMA(self):
        return self.com_object.DefaultPrintFIMA

    @DefaultPrintFIMA.setter
    def DefaultPrintFIMA(self, value):
        self.com_object.DefaultPrintFIMA = value

    @property
    def defaultprintfima(self):
        """Alias for DefaultPrintFIMA"""
        return self.DefaultPrintFIMA

    @defaultprintfima.setter
    def defaultprintfima(self, value):
        """Alias for DefaultPrintFIMA.setter"""
        self.DefaultPrintFIMA = value

    @property
    def default_print_f_i_m_a(self):
        """Alias for DefaultPrintFIMA"""
        return self.DefaultPrintFIMA

    @default_print_f_i_m_a.setter
    def default_print_f_i_m_a(self, value):
        """Alias for DefaultPrintFIMA.setter"""
        self.DefaultPrintFIMA = value

    @property
    def DefaultSize(self):
        return self.com_object.DefaultSize

    @DefaultSize.setter
    def DefaultSize(self, value):
        self.com_object.DefaultSize = value

    @property
    def defaultsize(self):
        """Alias for DefaultSize"""
        return self.DefaultSize

    @defaultsize.setter
    def defaultsize(self, value):
        """Alias for DefaultSize.setter"""
        self.DefaultSize = value

    @property
    def default_size(self):
        """Alias for DefaultSize"""
        return self.DefaultSize

    @default_size.setter
    def default_size(self, value):
        """Alias for DefaultSize.setter"""
        self.DefaultSize = value

    @property
    def DefaultWidth(self):
        return self.com_object.DefaultWidth

    @DefaultWidth.setter
    def DefaultWidth(self, value):
        self.com_object.DefaultWidth = value

    @property
    def defaultwidth(self):
        """Alias for DefaultWidth"""
        return self.DefaultWidth

    @defaultwidth.setter
    def defaultwidth(self, value):
        """Alias for DefaultWidth.setter"""
        self.DefaultWidth = value

    @property
    def default_width(self):
        """Alias for DefaultWidth"""
        return self.DefaultWidth

    @default_width.setter
    def default_width(self, value):
        """Alias for DefaultWidth.setter"""
        self.DefaultWidth = value

    @property
    def FeedSource(self):
        return WdPaperTray(self.com_object.FeedSource)

    @FeedSource.setter
    def FeedSource(self, value):
        self.com_object.FeedSource = value

    @property
    def feedsource(self):
        """Alias for FeedSource"""
        return self.FeedSource

    @feedsource.setter
    def feedsource(self, value):
        """Alias for FeedSource.setter"""
        self.FeedSource = value

    @property
    def feed_source(self):
        """Alias for FeedSource"""
        return self.FeedSource

    @feed_source.setter
    def feed_source(self, value):
        """Alias for FeedSource.setter"""
        self.FeedSource = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RecipientNamefromLeft(self):
        return self.com_object.RecipientNamefromLeft

    @RecipientNamefromLeft.setter
    def RecipientNamefromLeft(self, value):
        self.com_object.RecipientNamefromLeft = value

    @property
    def recipientnamefromleft(self):
        """Alias for RecipientNamefromLeft"""
        return self.RecipientNamefromLeft

    @recipientnamefromleft.setter
    def recipientnamefromleft(self, value):
        """Alias for RecipientNamefromLeft.setter"""
        self.RecipientNamefromLeft = value

    @property
    def recipient_namefrom_left(self):
        """Alias for RecipientNamefromLeft"""
        return self.RecipientNamefromLeft

    @recipient_namefrom_left.setter
    def recipient_namefrom_left(self, value):
        """Alias for RecipientNamefromLeft.setter"""
        self.RecipientNamefromLeft = value

    @property
    def RecipientNamefromTop(self):
        return self.com_object.RecipientNamefromTop

    @RecipientNamefromTop.setter
    def RecipientNamefromTop(self, value):
        self.com_object.RecipientNamefromTop = value

    @property
    def recipientnamefromtop(self):
        """Alias for RecipientNamefromTop"""
        return self.RecipientNamefromTop

    @recipientnamefromtop.setter
    def recipientnamefromtop(self, value):
        """Alias for RecipientNamefromTop.setter"""
        self.RecipientNamefromTop = value

    @property
    def recipient_namefrom_top(self):
        """Alias for RecipientNamefromTop"""
        return self.RecipientNamefromTop

    @recipient_namefrom_top.setter
    def recipient_namefrom_top(self, value):
        """Alias for RecipientNamefromTop.setter"""
        self.RecipientNamefromTop = value

    @property
    def RecipientPostalfromLeft(self):
        return self.com_object.RecipientPostalfromLeft

    @RecipientPostalfromLeft.setter
    def RecipientPostalfromLeft(self, value):
        self.com_object.RecipientPostalfromLeft = value

    @property
    def recipientpostalfromleft(self):
        """Alias for RecipientPostalfromLeft"""
        return self.RecipientPostalfromLeft

    @recipientpostalfromleft.setter
    def recipientpostalfromleft(self, value):
        """Alias for RecipientPostalfromLeft.setter"""
        self.RecipientPostalfromLeft = value

    @property
    def recipient_postalfrom_left(self):
        """Alias for RecipientPostalfromLeft"""
        return self.RecipientPostalfromLeft

    @recipient_postalfrom_left.setter
    def recipient_postalfrom_left(self, value):
        """Alias for RecipientPostalfromLeft.setter"""
        self.RecipientPostalfromLeft = value

    @property
    def RecipientPostalfromTop(self):
        return self.com_object.RecipientPostalfromTop

    @RecipientPostalfromTop.setter
    def RecipientPostalfromTop(self, value):
        self.com_object.RecipientPostalfromTop = value

    @property
    def recipientpostalfromtop(self):
        """Alias for RecipientPostalfromTop"""
        return self.RecipientPostalfromTop

    @recipientpostalfromtop.setter
    def recipientpostalfromtop(self, value):
        """Alias for RecipientPostalfromTop.setter"""
        self.RecipientPostalfromTop = value

    @property
    def recipient_postalfrom_top(self):
        """Alias for RecipientPostalfromTop"""
        return self.RecipientPostalfromTop

    @recipient_postalfrom_top.setter
    def recipient_postalfrom_top(self, value):
        """Alias for RecipientPostalfromTop.setter"""
        self.RecipientPostalfromTop = value

    @property
    def ReturnAddress(self):
        return Range(self.com_object.ReturnAddress)

    @property
    def returnaddress(self):
        """Alias for ReturnAddress"""
        return self.ReturnAddress

    @property
    def return_address(self):
        """Alias for ReturnAddress"""
        return self.ReturnAddress

    @property
    def ReturnAddressFromLeft(self):
        return self.com_object.ReturnAddressFromLeft

    @ReturnAddressFromLeft.setter
    def ReturnAddressFromLeft(self, value):
        self.com_object.ReturnAddressFromLeft = value

    @property
    def returnaddressfromleft(self):
        """Alias for ReturnAddressFromLeft"""
        return self.ReturnAddressFromLeft

    @returnaddressfromleft.setter
    def returnaddressfromleft(self, value):
        """Alias for ReturnAddressFromLeft.setter"""
        self.ReturnAddressFromLeft = value

    @property
    def return_address_from_left(self):
        """Alias for ReturnAddressFromLeft"""
        return self.ReturnAddressFromLeft

    @return_address_from_left.setter
    def return_address_from_left(self, value):
        """Alias for ReturnAddressFromLeft.setter"""
        self.ReturnAddressFromLeft = value

    @property
    def ReturnAddressFromTop(self):
        return self.com_object.ReturnAddressFromTop

    @ReturnAddressFromTop.setter
    def ReturnAddressFromTop(self, value):
        self.com_object.ReturnAddressFromTop = value

    @property
    def returnaddressfromtop(self):
        """Alias for ReturnAddressFromTop"""
        return self.ReturnAddressFromTop

    @returnaddressfromtop.setter
    def returnaddressfromtop(self, value):
        """Alias for ReturnAddressFromTop.setter"""
        self.ReturnAddressFromTop = value

    @property
    def return_address_from_top(self):
        """Alias for ReturnAddressFromTop"""
        return self.ReturnAddressFromTop

    @return_address_from_top.setter
    def return_address_from_top(self, value):
        """Alias for ReturnAddressFromTop.setter"""
        self.ReturnAddressFromTop = value

    @property
    def ReturnAddressStyle(self):
        return Style(self.com_object.ReturnAddressStyle)

    @property
    def returnaddressstyle(self):
        """Alias for ReturnAddressStyle"""
        return self.ReturnAddressStyle

    @property
    def return_address_style(self):
        """Alias for ReturnAddressStyle"""
        return self.ReturnAddressStyle

    @property
    def SenderNamefromLeft(self):
        return self.com_object.SenderNamefromLeft

    @SenderNamefromLeft.setter
    def SenderNamefromLeft(self, value):
        self.com_object.SenderNamefromLeft = value

    @property
    def sendernamefromleft(self):
        """Alias for SenderNamefromLeft"""
        return self.SenderNamefromLeft

    @sendernamefromleft.setter
    def sendernamefromleft(self, value):
        """Alias for SenderNamefromLeft.setter"""
        self.SenderNamefromLeft = value

    @property
    def sender_namefrom_left(self):
        """Alias for SenderNamefromLeft"""
        return self.SenderNamefromLeft

    @sender_namefrom_left.setter
    def sender_namefrom_left(self, value):
        """Alias for SenderNamefromLeft.setter"""
        self.SenderNamefromLeft = value

    @property
    def SenderNamefromTop(self):
        return self.com_object.SenderNamefromTop

    @SenderNamefromTop.setter
    def SenderNamefromTop(self, value):
        self.com_object.SenderNamefromTop = value

    @property
    def sendernamefromtop(self):
        """Alias for SenderNamefromTop"""
        return self.SenderNamefromTop

    @sendernamefromtop.setter
    def sendernamefromtop(self, value):
        """Alias for SenderNamefromTop.setter"""
        self.SenderNamefromTop = value

    @property
    def sender_namefrom_top(self):
        """Alias for SenderNamefromTop"""
        return self.SenderNamefromTop

    @sender_namefrom_top.setter
    def sender_namefrom_top(self, value):
        """Alias for SenderNamefromTop.setter"""
        self.SenderNamefromTop = value

    @property
    def SenderPostalfromLeft(self):
        return self.com_object.SenderPostalfromLeft

    @SenderPostalfromLeft.setter
    def SenderPostalfromLeft(self, value):
        self.com_object.SenderPostalfromLeft = value

    @property
    def senderpostalfromleft(self):
        """Alias for SenderPostalfromLeft"""
        return self.SenderPostalfromLeft

    @senderpostalfromleft.setter
    def senderpostalfromleft(self, value):
        """Alias for SenderPostalfromLeft.setter"""
        self.SenderPostalfromLeft = value

    @property
    def sender_postalfrom_left(self):
        """Alias for SenderPostalfromLeft"""
        return self.SenderPostalfromLeft

    @sender_postalfrom_left.setter
    def sender_postalfrom_left(self, value):
        """Alias for SenderPostalfromLeft.setter"""
        self.SenderPostalfromLeft = value

    @property
    def SenderPostalfromTop(self):
        return self.com_object.SenderPostalfromTop

    @SenderPostalfromTop.setter
    def SenderPostalfromTop(self, value):
        self.com_object.SenderPostalfromTop = value

    @property
    def senderpostalfromtop(self):
        """Alias for SenderPostalfromTop"""
        return self.SenderPostalfromTop

    @senderpostalfromtop.setter
    def senderpostalfromtop(self, value):
        """Alias for SenderPostalfromTop.setter"""
        self.SenderPostalfromTop = value

    @property
    def sender_postalfrom_top(self):
        """Alias for SenderPostalfromTop"""
        return self.SenderPostalfromTop

    @sender_postalfrom_top.setter
    def sender_postalfrom_top(self, value):
        """Alias for SenderPostalfromTop.setter"""
        self.SenderPostalfromTop = value

    @property
    def Vertical(self):
        return self.com_object.Vertical

    @Vertical.setter
    def Vertical(self, value):
        self.com_object.Vertical = value

    @property
    def vertical(self):
        """Alias for Vertical"""
        return self.Vertical

    @vertical.setter
    def vertical(self, value):
        """Alias for Vertical.setter"""
        self.Vertical = value

    def Insert(self, ExtractAddress=None, Address=None, AutoText=None, OmitReturnAddress=None, ReturnAddress=None, ReturnAutoText=None, PrintBarCode=None, PrintFIMA=None, Size=None, Height=None, Width=None, FeedSource=None, AddressFromLeft=None, AddressFromTop=None, ReturnAddressFromLeft=None, ReturnAddressFromTop=None, DefaultFaceUp=None, DefaultOrientation=None, PrintEPostage=None, Vertical=None, RecipientNamefromLeft=None, RecipientNamefromTop=None, RecipientPostalfromLeft=None, RecipientPostalfromTop=None, SenderNamefromLeft=None, SenderNamefromTop=None, SenderPostalfromLeft=None, SenderPostalfromTop=None):
        arguments = com_arguments([unwrap(a) for a in [ExtractAddress, Address, AutoText, OmitReturnAddress, ReturnAddress, ReturnAutoText, PrintBarCode, PrintFIMA, Size, Height, Width, FeedSource, AddressFromLeft, AddressFromTop, ReturnAddressFromLeft, ReturnAddressFromTop, DefaultFaceUp, DefaultOrientation, PrintEPostage, Vertical, RecipientNamefromLeft, RecipientNamefromTop, RecipientPostalfromLeft, RecipientPostalfromTop, SenderNamefromLeft, SenderNamefromTop, SenderPostalfromLeft, SenderPostalfromTop]])
        self.com_object.Insert(*arguments)

    def insert(self, ExtractAddress=None, Address=None, AutoText=None, OmitReturnAddress=None, ReturnAddress=None, ReturnAutoText=None, PrintBarCode=None, PrintFIMA=None, Size=None, Height=None, Width=None, FeedSource=None, AddressFromLeft=None, AddressFromTop=None, ReturnAddressFromLeft=None, ReturnAddressFromTop=None, DefaultFaceUp=None, DefaultOrientation=None, PrintEPostage=None, Vertical=None, RecipientNamefromLeft=None, RecipientNamefromTop=None, RecipientPostalfromLeft=None, RecipientPostalfromTop=None, SenderNamefromLeft=None, SenderNamefromTop=None, SenderPostalfromLeft=None, SenderPostalfromTop=None):
        """Alias for Insert"""
        arguments = [ExtractAddress, Address, AutoText, OmitReturnAddress, ReturnAddress, ReturnAutoText, PrintBarCode, PrintFIMA, Size, Height, Width, FeedSource, AddressFromLeft, AddressFromTop, ReturnAddressFromLeft, ReturnAddressFromTop, DefaultFaceUp, DefaultOrientation, PrintEPostage, Vertical, RecipientNamefromLeft, RecipientNamefromTop, RecipientPostalfromLeft, RecipientPostalfromTop, SenderNamefromLeft, SenderNamefromTop, SenderPostalfromLeft, SenderPostalfromTop]
        return self.Insert(*arguments)

    def Options(self):
        self.com_object.Options()

    def options(self):
        """Alias for Options"""
        return self.Options()

    def PrintOut(self, ExtractAddress=None, Address=None, AutoText=None, OmitReturnAddress=None, ReturnAddress=None, ReturnAutoText=None, PrintBarCode=None, PrintFIMA=None, Size=None, Height=None, Width=None, FeedSource=None, AddressFromLeft=None, AddressFromTop=None, ReturnAddressFromLeft=None, ReturnAddressFromTop=None, DefaultFaceUp=None, DefaultOrientation=None, PrintEPostage=None, Vertical=None, RecipientNamefromLeft=None, RecipientNamefromTop=None, RecipientPostalfromLeft=None, RecipientPostalfromTop=None, SenderNamefromLeft=None, SenderNamefromTop=None, SenderPostalfromLeft=None, SenderPostalfromTop=None):
        arguments = com_arguments([unwrap(a) for a in [ExtractAddress, Address, AutoText, OmitReturnAddress, ReturnAddress, ReturnAutoText, PrintBarCode, PrintFIMA, Size, Height, Width, FeedSource, AddressFromLeft, AddressFromTop, ReturnAddressFromLeft, ReturnAddressFromTop, DefaultFaceUp, DefaultOrientation, PrintEPostage, Vertical, RecipientNamefromLeft, RecipientNamefromTop, RecipientPostalfromLeft, RecipientPostalfromTop, SenderNamefromLeft, SenderNamefromTop, SenderPostalfromLeft, SenderPostalfromTop]])
        self.com_object.PrintOut(*arguments)

    def printout(self, ExtractAddress=None, Address=None, AutoText=None, OmitReturnAddress=None, ReturnAddress=None, ReturnAutoText=None, PrintBarCode=None, PrintFIMA=None, Size=None, Height=None, Width=None, FeedSource=None, AddressFromLeft=None, AddressFromTop=None, ReturnAddressFromLeft=None, ReturnAddressFromTop=None, DefaultFaceUp=None, DefaultOrientation=None, PrintEPostage=None, Vertical=None, RecipientNamefromLeft=None, RecipientNamefromTop=None, RecipientPostalfromLeft=None, RecipientPostalfromTop=None, SenderNamefromLeft=None, SenderNamefromTop=None, SenderPostalfromLeft=None, SenderPostalfromTop=None):
        """Alias for PrintOut"""
        arguments = [ExtractAddress, Address, AutoText, OmitReturnAddress, ReturnAddress, ReturnAutoText, PrintBarCode, PrintFIMA, Size, Height, Width, FeedSource, AddressFromLeft, AddressFromTop, ReturnAddressFromLeft, ReturnAddressFromTop, DefaultFaceUp, DefaultOrientation, PrintEPostage, Vertical, RecipientNamefromLeft, RecipientNamefromTop, RecipientPostalfromLeft, RecipientPostalfromTop, SenderNamefromLeft, SenderNamefromTop, SenderPostalfromLeft, SenderPostalfromTop]
        return self.PrintOut(*arguments)

    def print_out(self, ExtractAddress=None, Address=None, AutoText=None, OmitReturnAddress=None, ReturnAddress=None, ReturnAutoText=None, PrintBarCode=None, PrintFIMA=None, Size=None, Height=None, Width=None, FeedSource=None, AddressFromLeft=None, AddressFromTop=None, ReturnAddressFromLeft=None, ReturnAddressFromTop=None, DefaultFaceUp=None, DefaultOrientation=None, PrintEPostage=None, Vertical=None, RecipientNamefromLeft=None, RecipientNamefromTop=None, RecipientPostalfromLeft=None, RecipientPostalfromTop=None, SenderNamefromLeft=None, SenderNamefromTop=None, SenderPostalfromLeft=None, SenderPostalfromTop=None):
        """Alias for PrintOut"""
        arguments = [ExtractAddress, Address, AutoText, OmitReturnAddress, ReturnAddress, ReturnAutoText, PrintBarCode, PrintFIMA, Size, Height, Width, FeedSource, AddressFromLeft, AddressFromTop, ReturnAddressFromLeft, ReturnAddressFromTop, DefaultFaceUp, DefaultOrientation, PrintEPostage, Vertical, RecipientNamefromLeft, RecipientNamefromTop, RecipientPostalfromLeft, RecipientPostalfromTop, SenderNamefromLeft, SenderNamefromTop, SenderPostalfromLeft, SenderPostalfromTop]
        return self.PrintOut(*arguments)

    def UpdateDocument(self):
        self.com_object.UpdateDocument()

    def updatedocument(self):
        """Alias for UpdateDocument"""
        return self.UpdateDocument()

    def update_document(self):
        """Alias for UpdateDocument"""
        return self.UpdateDocument()


class ErrorBars:

    def __init__(self, errorbars=None):
        self.com_object= errorbars

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Border(self):
        return ChartBorder(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def EndStyle(self):
        return self.com_object.EndStyle

    @EndStyle.setter
    def EndStyle(self, value):
        self.com_object.EndStyle = value

    @property
    def endstyle(self):
        """Alias for EndStyle"""
        return self.EndStyle

    @endstyle.setter
    def endstyle(self, value):
        """Alias for EndStyle.setter"""
        self.EndStyle = value

    @property
    def end_style(self):
        """Alias for EndStyle"""
        return self.EndStyle

    @end_style.setter
    def end_style(self, value):
        """Alias for EndStyle.setter"""
        self.EndStyle = value

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def ClearFormats(self):
        self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Field:

    def __init__(self, field=None):
        self.com_object= field

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Code(self):
        return Range(self.com_object.Code)

    @Code.setter
    def Code(self, value):
        self.com_object.Code = value

    @property
    def code(self):
        """Alias for Code"""
        return self.Code

    @code.setter
    def code(self, value):
        """Alias for Code.setter"""
        self.Code = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Data(self):
        return self.com_object.Data

    @Data.setter
    def Data(self, value):
        self.com_object.Data = value

    @property
    def data(self):
        """Alias for Data"""
        return self.Data

    @data.setter
    def data(self, value):
        """Alias for Data.setter"""
        self.Data = value

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def InlineShape(self):
        return InlineShape(self.com_object.InlineShape)

    @property
    def inlineshape(self):
        """Alias for InlineShape"""
        return self.InlineShape

    @property
    def inline_shape(self):
        """Alias for InlineShape"""
        return self.InlineShape

    @property
    def Kind(self):
        return WdFieldKind(self.com_object.Kind)

    @property
    def kind(self):
        """Alias for Kind"""
        return self.Kind

    @property
    def LinkFormat(self):
        return LinkFormat(self.com_object.LinkFormat)

    @property
    def linkformat(self):
        """Alias for LinkFormat"""
        return self.LinkFormat

    @property
    def link_format(self):
        """Alias for LinkFormat"""
        return self.LinkFormat

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def Next(self):
        return self.com_object.Next

    @property
    def next(self):
        """Alias for Next"""
        return self.Next

    @property
    def OLEFormat(self):
        return OLEFormat(self.com_object.OLEFormat)

    @property
    def oleformat(self):
        """Alias for OLEFormat"""
        return self.OLEFormat

    @property
    def o_l_e_format(self):
        """Alias for OLEFormat"""
        return self.OLEFormat

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Previous(self):
        return self.com_object.Previous

    @property
    def previous(self):
        """Alias for Previous"""
        return self.Previous

    @property
    def Result(self):
        return Range(self.com_object.Result)

    @Result.setter
    def Result(self, value):
        self.com_object.Result = value

    @property
    def result(self):
        """Alias for Result"""
        return self.Result

    @result.setter
    def result(self, value):
        """Alias for Result.setter"""
        self.Result = value

    @property
    def ShowCodes(self):
        return self.com_object.ShowCodes

    @ShowCodes.setter
    def ShowCodes(self, value):
        self.com_object.ShowCodes = value

    @property
    def showcodes(self):
        """Alias for ShowCodes"""
        return self.ShowCodes

    @showcodes.setter
    def showcodes(self, value):
        """Alias for ShowCodes.setter"""
        self.ShowCodes = value

    @property
    def show_codes(self):
        """Alias for ShowCodes"""
        return self.ShowCodes

    @show_codes.setter
    def show_codes(self, value):
        """Alias for ShowCodes.setter"""
        self.ShowCodes = value

    @property
    def Type(self):
        return WdFieldType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Cut(self):
        self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def DoClick(self):
        self.com_object.DoClick()

    def doclick(self):
        """Alias for DoClick"""
        return self.DoClick()

    def do_click(self):
        """Alias for DoClick"""
        return self.DoClick()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()

    def Unlink(self):
        self.com_object.Unlink()

    def unlink(self):
        """Alias for Unlink"""
        return self.Unlink()

    def Update(self):
        return self.com_object.Update()

    def update(self):
        """Alias for Update"""
        return self.Update()

    def UpdateSource(self):
        self.com_object.UpdateSource()

    def updatesource(self):
        """Alias for UpdateSource"""
        return self.UpdateSource()

    def update_source(self):
        """Alias for UpdateSource"""
        return self.UpdateSource()


class Fields:

    def __init__(self, fields=None):
        self.com_object= fields

    def __call__(self, item):
        return Field(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Range=None, Type=None, Text=None, PreserveFormatting=None):
        arguments = com_arguments([unwrap(a) for a in [Range, Type, Text, PreserveFormatting]])
        return Field(self.com_object.Add(*arguments))

    def add(self, Range=None, Type=None, Text=None, PreserveFormatting=None):
        """Alias for Add"""
        arguments = [Range, Type, Text, PreserveFormatting]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Field(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def ToggleShowCodes(self):
        self.com_object.ToggleShowCodes()

    def toggleshowcodes(self):
        """Alias for ToggleShowCodes"""
        return self.ToggleShowCodes()

    def toggle_show_codes(self):
        """Alias for ToggleShowCodes"""
        return self.ToggleShowCodes()

    def Unlink(self):
        self.com_object.Unlink()

    def unlink(self):
        """Alias for Unlink"""
        return self.Unlink()

    def Update(self):
        return self.com_object.Update()

    def update(self):
        """Alias for Update"""
        return self.Update()

    def UpdateSource(self):
        self.com_object.UpdateSource()

    def updatesource(self):
        """Alias for UpdateSource"""
        return self.UpdateSource()

    def update_source(self):
        """Alias for UpdateSource"""
        return self.UpdateSource()


class FileConverter:

    def __init__(self, fileconverter=None):
        self.com_object= fileconverter

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def CanOpen(self):
        return self.com_object.CanOpen

    @property
    def canopen(self):
        """Alias for CanOpen"""
        return self.CanOpen

    @property
    def can_open(self):
        """Alias for CanOpen"""
        return self.CanOpen

    @property
    def CanSave(self):
        return self.com_object.CanSave

    @property
    def cansave(self):
        """Alias for CanSave"""
        return self.CanSave

    @property
    def can_save(self):
        """Alias for CanSave"""
        return self.CanSave

    @property
    def ClassName(self):
        return self.com_object.ClassName

    @property
    def classname(self):
        """Alias for ClassName"""
        return self.ClassName

    @property
    def class_name(self):
        """Alias for ClassName"""
        return self.ClassName

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Extensions(self):
        return FileConverter(self.com_object.Extensions)

    @property
    def extensions(self):
        """Alias for Extensions"""
        return self.Extensions

    @property
    def FormatName(self):
        return self.com_object.FormatName

    @property
    def formatname(self):
        """Alias for FormatName"""
        return self.FormatName

    @property
    def format_name(self):
        """Alias for FormatName"""
        return self.FormatName

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def OpenFormat(self):
        return self.com_object.OpenFormat

    @property
    def openformat(self):
        """Alias for OpenFormat"""
        return self.OpenFormat

    @property
    def open_format(self):
        """Alias for OpenFormat"""
        return self.OpenFormat

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Path(self):
        return self.com_object.Path

    @property
    def path(self):
        """Alias for Path"""
        return self.Path

    @property
    def SaveFormat(self):
        return self.com_object.SaveFormat

    @property
    def saveformat(self):
        """Alias for SaveFormat"""
        return self.SaveFormat

    @property
    def save_format(self):
        """Alias for SaveFormat"""
        return self.SaveFormat


class FileConverters:

    def __init__(self, fileconverters=None):
        self.com_object= fileconverters

    def __call__(self, item):
        return FileConverter(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ConvertMacWordChevrons(self):
        return self.com_object.ConvertMacWordChevrons

    @ConvertMacWordChevrons.setter
    def ConvertMacWordChevrons(self, value):
        self.com_object.ConvertMacWordChevrons = value

    @property
    def convertmacwordchevrons(self):
        """Alias for ConvertMacWordChevrons"""
        return self.ConvertMacWordChevrons

    @convertmacwordchevrons.setter
    def convertmacwordchevrons(self, value):
        """Alias for ConvertMacWordChevrons.setter"""
        self.ConvertMacWordChevrons = value

    @property
    def convert_mac_word_chevrons(self):
        """Alias for ConvertMacWordChevrons"""
        return self.ConvertMacWordChevrons

    @convert_mac_word_chevrons.setter
    def convert_mac_word_chevrons(self, value):
        """Alias for ConvertMacWordChevrons.setter"""
        self.ConvertMacWordChevrons = value

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return FileConverter(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class FillFormat:

    def __init__(self, fillformat=None):
        self.com_object= fillformat

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BackColor(self):
        return ColorFormat(self.com_object.BackColor)

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ForeColor(self):
        return ColorFormat(self.com_object.ForeColor)

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def GradientAngle(self):
        return self.com_object.GradientAngle

    @GradientAngle.setter
    def GradientAngle(self, value):
        self.com_object.GradientAngle = value

    @property
    def gradientangle(self):
        """Alias for GradientAngle"""
        return self.GradientAngle

    @gradientangle.setter
    def gradientangle(self, value):
        """Alias for GradientAngle.setter"""
        self.GradientAngle = value

    @property
    def gradient_angle(self):
        """Alias for GradientAngle"""
        return self.GradientAngle

    @gradient_angle.setter
    def gradient_angle(self, value):
        """Alias for GradientAngle.setter"""
        self.GradientAngle = value

    @property
    def GradientColorType(self):
        return self.com_object.GradientColorType

    @property
    def gradientcolortype(self):
        """Alias for GradientColorType"""
        return self.GradientColorType

    @property
    def gradient_color_type(self):
        """Alias for GradientColorType"""
        return self.GradientColorType

    @property
    def GradientDegree(self):
        return self.com_object.GradientDegree

    @property
    def gradientdegree(self):
        """Alias for GradientDegree"""
        return self.GradientDegree

    @property
    def gradient_degree(self):
        """Alias for GradientDegree"""
        return self.GradientDegree

    @property
    def GradientStops(self):
        return self.com_object.GradientStops

    @property
    def gradientstops(self):
        """Alias for GradientStops"""
        return self.GradientStops

    @property
    def gradient_stops(self):
        """Alias for GradientStops"""
        return self.GradientStops

    @property
    def GradientStyle(self):
        return self.com_object.GradientStyle

    @property
    def gradientstyle(self):
        """Alias for GradientStyle"""
        return self.GradientStyle

    @property
    def gradient_style(self):
        """Alias for GradientStyle"""
        return self.GradientStyle

    @property
    def GradientVariant(self):
        return self.com_object.GradientVariant

    @property
    def gradientvariant(self):
        """Alias for GradientVariant"""
        return self.GradientVariant

    @property
    def gradient_variant(self):
        """Alias for GradientVariant"""
        return self.GradientVariant

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Pattern(self):
        return self.com_object.Pattern

    @Pattern.setter
    def Pattern(self, value):
        self.com_object.Pattern = value

    @property
    def pattern(self):
        """Alias for Pattern"""
        return self.Pattern

    @pattern.setter
    def pattern(self, value):
        """Alias for Pattern.setter"""
        self.Pattern = value

    @property
    def PictureEffects(self):
        return self.com_object.PictureEffects

    @property
    def pictureeffects(self):
        """Alias for PictureEffects"""
        return self.PictureEffects

    @property
    def picture_effects(self):
        """Alias for PictureEffects"""
        return self.PictureEffects

    @property
    def PresetGradientType(self):
        return self.com_object.PresetGradientType

    @property
    def presetgradienttype(self):
        """Alias for PresetGradientType"""
        return self.PresetGradientType

    @property
    def preset_gradient_type(self):
        """Alias for PresetGradientType"""
        return self.PresetGradientType

    @property
    def PresetTexture(self):
        return self.com_object.PresetTexture

    @property
    def presettexture(self):
        """Alias for PresetTexture"""
        return self.PresetTexture

    @property
    def preset_texture(self):
        """Alias for PresetTexture"""
        return self.PresetTexture

    @property
    def RotateWithObject(self):
        return self.com_object.RotateWithObject

    @RotateWithObject.setter
    def RotateWithObject(self, value):
        self.com_object.RotateWithObject = value

    @property
    def rotatewithobject(self):
        """Alias for RotateWithObject"""
        return self.RotateWithObject

    @rotatewithobject.setter
    def rotatewithobject(self, value):
        """Alias for RotateWithObject.setter"""
        self.RotateWithObject = value

    @property
    def rotate_with_object(self):
        """Alias for RotateWithObject"""
        return self.RotateWithObject

    @rotate_with_object.setter
    def rotate_with_object(self, value):
        """Alias for RotateWithObject.setter"""
        self.RotateWithObject = value

    @property
    def TextureAlignment(self):
        return self.com_object.TextureAlignment

    @TextureAlignment.setter
    def TextureAlignment(self, value):
        self.com_object.TextureAlignment = value

    @property
    def texturealignment(self):
        """Alias for TextureAlignment"""
        return self.TextureAlignment

    @texturealignment.setter
    def texturealignment(self, value):
        """Alias for TextureAlignment.setter"""
        self.TextureAlignment = value

    @property
    def texture_alignment(self):
        """Alias for TextureAlignment"""
        return self.TextureAlignment

    @texture_alignment.setter
    def texture_alignment(self, value):
        """Alias for TextureAlignment.setter"""
        self.TextureAlignment = value

    @property
    def TextureHorizontalScale(self):
        return self.com_object.TextureHorizontalScale

    @TextureHorizontalScale.setter
    def TextureHorizontalScale(self, value):
        self.com_object.TextureHorizontalScale = value

    @property
    def texturehorizontalscale(self):
        """Alias for TextureHorizontalScale"""
        return self.TextureHorizontalScale

    @texturehorizontalscale.setter
    def texturehorizontalscale(self, value):
        """Alias for TextureHorizontalScale.setter"""
        self.TextureHorizontalScale = value

    @property
    def texture_horizontal_scale(self):
        """Alias for TextureHorizontalScale"""
        return self.TextureHorizontalScale

    @texture_horizontal_scale.setter
    def texture_horizontal_scale(self, value):
        """Alias for TextureHorizontalScale.setter"""
        self.TextureHorizontalScale = value

    @property
    def TextureName(self):
        return self.com_object.TextureName

    @property
    def texturename(self):
        """Alias for TextureName"""
        return self.TextureName

    @property
    def texture_name(self):
        """Alias for TextureName"""
        return self.TextureName

    @property
    def TextureOffsetX(self):
        return self.com_object.TextureOffsetX

    @TextureOffsetX.setter
    def TextureOffsetX(self, value):
        self.com_object.TextureOffsetX = value

    @property
    def textureoffsetx(self):
        """Alias for TextureOffsetX"""
        return self.TextureOffsetX

    @textureoffsetx.setter
    def textureoffsetx(self, value):
        """Alias for TextureOffsetX.setter"""
        self.TextureOffsetX = value

    @property
    def texture_offset_x(self):
        """Alias for TextureOffsetX"""
        return self.TextureOffsetX

    @texture_offset_x.setter
    def texture_offset_x(self, value):
        """Alias for TextureOffsetX.setter"""
        self.TextureOffsetX = value

    @property
    def TextureOffsetY(self):
        return self.com_object.TextureOffsetY

    @TextureOffsetY.setter
    def TextureOffsetY(self, value):
        self.com_object.TextureOffsetY = value

    @property
    def textureoffsety(self):
        """Alias for TextureOffsetY"""
        return self.TextureOffsetY

    @textureoffsety.setter
    def textureoffsety(self, value):
        """Alias for TextureOffsetY.setter"""
        self.TextureOffsetY = value

    @property
    def texture_offset_y(self):
        """Alias for TextureOffsetY"""
        return self.TextureOffsetY

    @texture_offset_y.setter
    def texture_offset_y(self, value):
        """Alias for TextureOffsetY.setter"""
        self.TextureOffsetY = value

    @property
    def TextureTile(self):
        return self.com_object.TextureTile

    @TextureTile.setter
    def TextureTile(self, value):
        self.com_object.TextureTile = value

    @property
    def texturetile(self):
        """Alias for TextureTile"""
        return self.TextureTile

    @texturetile.setter
    def texturetile(self, value):
        """Alias for TextureTile.setter"""
        self.TextureTile = value

    @property
    def texture_tile(self):
        """Alias for TextureTile"""
        return self.TextureTile

    @texture_tile.setter
    def texture_tile(self, value):
        """Alias for TextureTile.setter"""
        self.TextureTile = value

    @property
    def TextureType(self):
        return self.com_object.TextureType

    @property
    def texturetype(self):
        """Alias for TextureType"""
        return self.TextureType

    @property
    def texture_type(self):
        """Alias for TextureType"""
        return self.TextureType

    @property
    def TextureVerticalScale(self):
        return self.com_object.TextureVerticalScale

    @TextureVerticalScale.setter
    def TextureVerticalScale(self, value):
        self.com_object.TextureVerticalScale = value

    @property
    def textureverticalscale(self):
        """Alias for TextureVerticalScale"""
        return self.TextureVerticalScale

    @textureverticalscale.setter
    def textureverticalscale(self, value):
        """Alias for TextureVerticalScale.setter"""
        self.TextureVerticalScale = value

    @property
    def texture_vertical_scale(self):
        """Alias for TextureVerticalScale"""
        return self.TextureVerticalScale

    @texture_vertical_scale.setter
    def texture_vertical_scale(self, value):
        """Alias for TextureVerticalScale.setter"""
        self.TextureVerticalScale = value

    @property
    def Transparency(self):
        return self.com_object.Transparency

    @Transparency.setter
    def Transparency(self, value):
        self.com_object.Transparency = value

    @property
    def transparency(self):
        """Alias for Transparency"""
        return self.Transparency

    @transparency.setter
    def transparency(self, value):
        """Alias for Transparency.setter"""
        self.Transparency = value

    @property
    def Type(self):
        return self.com_object.Type

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    def OneColorGradient(self, Style=None, Variant=None, Degree=None):
        arguments = com_arguments([unwrap(a) for a in [Style, Variant, Degree]])
        self.com_object.OneColorGradient(*arguments)

    def onecolorgradient(self, Style=None, Variant=None, Degree=None):
        """Alias for OneColorGradient"""
        arguments = [Style, Variant, Degree]
        return self.OneColorGradient(*arguments)

    def one_color_gradient(self, Style=None, Variant=None, Degree=None):
        """Alias for OneColorGradient"""
        arguments = [Style, Variant, Degree]
        return self.OneColorGradient(*arguments)

    def Patterned(self, Pattern=None):
        arguments = com_arguments([unwrap(a) for a in [Pattern]])
        self.com_object.Patterned(*arguments)

    def patterned(self, Pattern=None):
        """Alias for Patterned"""
        arguments = [Pattern]
        return self.Patterned(*arguments)

    def PresetGradient(self, Style=None, Variant=None, PresetGradientType=None):
        arguments = com_arguments([unwrap(a) for a in [Style, Variant, PresetGradientType]])
        self.com_object.PresetGradient(*arguments)

    def presetgradient(self, Style=None, Variant=None, PresetGradientType=None):
        """Alias for PresetGradient"""
        arguments = [Style, Variant, PresetGradientType]
        return self.PresetGradient(*arguments)

    def preset_gradient(self, Style=None, Variant=None, PresetGradientType=None):
        """Alias for PresetGradient"""
        arguments = [Style, Variant, PresetGradientType]
        return self.PresetGradient(*arguments)

    def PresetTextured(self, PresetTexture=None):
        arguments = com_arguments([unwrap(a) for a in [PresetTexture]])
        self.com_object.PresetTextured(*arguments)

    def presettextured(self, PresetTexture=None):
        """Alias for PresetTextured"""
        arguments = [PresetTexture]
        return self.PresetTextured(*arguments)

    def preset_textured(self, PresetTexture=None):
        """Alias for PresetTextured"""
        arguments = [PresetTexture]
        return self.PresetTextured(*arguments)

    def Solid(self):
        self.com_object.Solid()

    def solid(self):
        """Alias for Solid"""
        return self.Solid()

    def TwoColorGradient(self, Style=None, Variant=None):
        arguments = com_arguments([unwrap(a) for a in [Style, Variant]])
        self.com_object.TwoColorGradient(*arguments)

    def twocolorgradient(self, Style=None, Variant=None):
        """Alias for TwoColorGradient"""
        arguments = [Style, Variant]
        return self.TwoColorGradient(*arguments)

    def two_color_gradient(self, Style=None, Variant=None):
        """Alias for TwoColorGradient"""
        arguments = [Style, Variant]
        return self.TwoColorGradient(*arguments)

    def UserPicture(self, PictureFile=None):
        arguments = com_arguments([unwrap(a) for a in [PictureFile]])
        self.com_object.UserPicture(*arguments)

    def userpicture(self, PictureFile=None):
        """Alias for UserPicture"""
        arguments = [PictureFile]
        return self.UserPicture(*arguments)

    def user_picture(self, PictureFile=None):
        """Alias for UserPicture"""
        arguments = [PictureFile]
        return self.UserPicture(*arguments)

    def UserTextured(self, TextureFile=None):
        arguments = com_arguments([unwrap(a) for a in [TextureFile]])
        self.com_object.UserTextured(*arguments)

    def usertextured(self, TextureFile=None):
        """Alias for UserTextured"""
        arguments = [TextureFile]
        return self.UserTextured(*arguments)

    def user_textured(self, TextureFile=None):
        """Alias for UserTextured"""
        arguments = [TextureFile]
        return self.UserTextured(*arguments)


class Find:

    def __init__(self, find=None):
        self.com_object= find

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def CorrectHangulEndings(self):
        return self.com_object.CorrectHangulEndings

    @CorrectHangulEndings.setter
    def CorrectHangulEndings(self, value):
        self.com_object.CorrectHangulEndings = value

    @property
    def correcthangulendings(self):
        """Alias for CorrectHangulEndings"""
        return self.CorrectHangulEndings

    @correcthangulendings.setter
    def correcthangulendings(self, value):
        """Alias for CorrectHangulEndings.setter"""
        self.CorrectHangulEndings = value

    @property
    def correct_hangul_endings(self):
        """Alias for CorrectHangulEndings"""
        return self.CorrectHangulEndings

    @correct_hangul_endings.setter
    def correct_hangul_endings(self, value):
        """Alias for CorrectHangulEndings.setter"""
        self.CorrectHangulEndings = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @Font.setter
    def Font(self, value):
        self.com_object.Font = value

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @font.setter
    def font(self, value):
        """Alias for Font.setter"""
        self.Font = value

    @property
    def Format(self):
        return self.com_object.Format

    @Format.setter
    def Format(self, value):
        self.com_object.Format = value

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @format.setter
    def format(self, value):
        """Alias for Format.setter"""
        self.Format = value

    @property
    def Forward(self):
        return self.com_object.Forward

    @Forward.setter
    def Forward(self, value):
        self.com_object.Forward = value

    @property
    def forward(self):
        """Alias for Forward"""
        return self.Forward

    @forward.setter
    def forward(self, value):
        """Alias for Forward.setter"""
        self.Forward = value

    @property
    def Found(self):
        return self.com_object.Found

    @property
    def found(self):
        """Alias for Found"""
        return self.Found

    @property
    def Frame(self):
        return Frame(self.com_object.Frame)

    @property
    def frame(self):
        """Alias for Frame"""
        return self.Frame

    @property
    def HanjaPhoneticHangul(self):
        return self.com_object.HanjaPhoneticHangul

    @HanjaPhoneticHangul.setter
    def HanjaPhoneticHangul(self, value):
        self.com_object.HanjaPhoneticHangul = value

    @property
    def hanjaphonetichangul(self):
        """Alias for HanjaPhoneticHangul"""
        return self.HanjaPhoneticHangul

    @hanjaphonetichangul.setter
    def hanjaphonetichangul(self, value):
        """Alias for HanjaPhoneticHangul.setter"""
        self.HanjaPhoneticHangul = value

    @property
    def hanja_phonetic_hangul(self):
        """Alias for HanjaPhoneticHangul"""
        return self.HanjaPhoneticHangul

    @hanja_phonetic_hangul.setter
    def hanja_phonetic_hangul(self, value):
        """Alias for HanjaPhoneticHangul.setter"""
        self.HanjaPhoneticHangul = value

    @property
    def Highlight(self):
        return self.com_object.Highlight

    @Highlight.setter
    def Highlight(self, value):
        self.com_object.Highlight = value

    @property
    def highlight(self):
        """Alias for Highlight"""
        return self.Highlight

    @highlight.setter
    def highlight(self, value):
        """Alias for Highlight.setter"""
        self.Highlight = value

    @property
    def IgnorePunct(self):
        return self.com_object.IgnorePunct

    @IgnorePunct.setter
    def IgnorePunct(self, value):
        self.com_object.IgnorePunct = value

    @property
    def ignorepunct(self):
        """Alias for IgnorePunct"""
        return self.IgnorePunct

    @ignorepunct.setter
    def ignorepunct(self, value):
        """Alias for IgnorePunct.setter"""
        self.IgnorePunct = value

    @property
    def ignore_punct(self):
        """Alias for IgnorePunct"""
        return self.IgnorePunct

    @ignore_punct.setter
    def ignore_punct(self, value):
        """Alias for IgnorePunct.setter"""
        self.IgnorePunct = value

    @property
    def IgnoreSpace(self):
        return self.com_object.IgnoreSpace

    @IgnoreSpace.setter
    def IgnoreSpace(self, value):
        self.com_object.IgnoreSpace = value

    @property
    def ignorespace(self):
        """Alias for IgnoreSpace"""
        return self.IgnoreSpace

    @ignorespace.setter
    def ignorespace(self, value):
        """Alias for IgnoreSpace.setter"""
        self.IgnoreSpace = value

    @property
    def ignore_space(self):
        """Alias for IgnoreSpace"""
        return self.IgnoreSpace

    @ignore_space.setter
    def ignore_space(self, value):
        """Alias for IgnoreSpace.setter"""
        self.IgnoreSpace = value

    @property
    def LanguageID(self):
        return WdLanguageID(self.com_object.LanguageID)

    @LanguageID.setter
    def LanguageID(self, value):
        self.com_object.LanguageID = value

    @property
    def languageid(self):
        """Alias for LanguageID"""
        return self.LanguageID

    @languageid.setter
    def languageid(self, value):
        """Alias for LanguageID.setter"""
        self.LanguageID = value

    @property
    def language_i_d(self):
        """Alias for LanguageID"""
        return self.LanguageID

    @language_i_d.setter
    def language_i_d(self, value):
        """Alias for LanguageID.setter"""
        self.LanguageID = value

    @property
    def LanguageIDFarEast(self):
        return WdLanguageID(self.com_object.LanguageIDFarEast)

    @LanguageIDFarEast.setter
    def LanguageIDFarEast(self, value):
        self.com_object.LanguageIDFarEast = value

    @property
    def languageidfareast(self):
        """Alias for LanguageIDFarEast"""
        return self.LanguageIDFarEast

    @languageidfareast.setter
    def languageidfareast(self, value):
        """Alias for LanguageIDFarEast.setter"""
        self.LanguageIDFarEast = value

    @property
    def language_i_d_far_east(self):
        """Alias for LanguageIDFarEast"""
        return self.LanguageIDFarEast

    @language_i_d_far_east.setter
    def language_i_d_far_east(self, value):
        """Alias for LanguageIDFarEast.setter"""
        self.LanguageIDFarEast = value

    @property
    def LanguageIDOther(self):
        return WdLanguageID(self.com_object.LanguageIDOther)

    @LanguageIDOther.setter
    def LanguageIDOther(self, value):
        self.com_object.LanguageIDOther = value

    @property
    def languageidother(self):
        """Alias for LanguageIDOther"""
        return self.LanguageIDOther

    @languageidother.setter
    def languageidother(self, value):
        """Alias for LanguageIDOther.setter"""
        self.LanguageIDOther = value

    @property
    def language_i_d_other(self):
        """Alias for LanguageIDOther"""
        return self.LanguageIDOther

    @language_i_d_other.setter
    def language_i_d_other(self, value):
        """Alias for LanguageIDOther.setter"""
        self.LanguageIDOther = value

    @property
    def MatchAlefHamza(self):
        return self.com_object.MatchAlefHamza

    @MatchAlefHamza.setter
    def MatchAlefHamza(self, value):
        self.com_object.MatchAlefHamza = value

    @property
    def matchalefhamza(self):
        """Alias for MatchAlefHamza"""
        return self.MatchAlefHamza

    @matchalefhamza.setter
    def matchalefhamza(self, value):
        """Alias for MatchAlefHamza.setter"""
        self.MatchAlefHamza = value

    @property
    def match_alef_hamza(self):
        """Alias for MatchAlefHamza"""
        return self.MatchAlefHamza

    @match_alef_hamza.setter
    def match_alef_hamza(self, value):
        """Alias for MatchAlefHamza.setter"""
        self.MatchAlefHamza = value

    @property
    def MatchAllWordForms(self):
        return self.com_object.MatchAllWordForms

    @MatchAllWordForms.setter
    def MatchAllWordForms(self, value):
        self.com_object.MatchAllWordForms = value

    @property
    def matchallwordforms(self):
        """Alias for MatchAllWordForms"""
        return self.MatchAllWordForms

    @matchallwordforms.setter
    def matchallwordforms(self, value):
        """Alias for MatchAllWordForms.setter"""
        self.MatchAllWordForms = value

    @property
    def match_all_word_forms(self):
        """Alias for MatchAllWordForms"""
        return self.MatchAllWordForms

    @match_all_word_forms.setter
    def match_all_word_forms(self, value):
        """Alias for MatchAllWordForms.setter"""
        self.MatchAllWordForms = value

    @property
    def MatchByte(self):
        return self.com_object.MatchByte

    @MatchByte.setter
    def MatchByte(self, value):
        self.com_object.MatchByte = value

    @property
    def matchbyte(self):
        """Alias for MatchByte"""
        return self.MatchByte

    @matchbyte.setter
    def matchbyte(self, value):
        """Alias for MatchByte.setter"""
        self.MatchByte = value

    @property
    def match_byte(self):
        """Alias for MatchByte"""
        return self.MatchByte

    @match_byte.setter
    def match_byte(self, value):
        """Alias for MatchByte.setter"""
        self.MatchByte = value

    @property
    def MatchCase(self):
        return self.com_object.MatchCase

    @MatchCase.setter
    def MatchCase(self, value):
        self.com_object.MatchCase = value

    @property
    def matchcase(self):
        """Alias for MatchCase"""
        return self.MatchCase

    @matchcase.setter
    def matchcase(self, value):
        """Alias for MatchCase.setter"""
        self.MatchCase = value

    @property
    def match_case(self):
        """Alias for MatchCase"""
        return self.MatchCase

    @match_case.setter
    def match_case(self, value):
        """Alias for MatchCase.setter"""
        self.MatchCase = value

    @property
    def MatchControl(self):
        return self.com_object.MatchControl

    @MatchControl.setter
    def MatchControl(self, value):
        self.com_object.MatchControl = value

    @property
    def matchcontrol(self):
        """Alias for MatchControl"""
        return self.MatchControl

    @matchcontrol.setter
    def matchcontrol(self, value):
        """Alias for MatchControl.setter"""
        self.MatchControl = value

    @property
    def match_control(self):
        """Alias for MatchControl"""
        return self.MatchControl

    @match_control.setter
    def match_control(self, value):
        """Alias for MatchControl.setter"""
        self.MatchControl = value

    @property
    def MatchDiacritics(self):
        return self.com_object.MatchDiacritics

    @MatchDiacritics.setter
    def MatchDiacritics(self, value):
        self.com_object.MatchDiacritics = value

    @property
    def matchdiacritics(self):
        """Alias for MatchDiacritics"""
        return self.MatchDiacritics

    @matchdiacritics.setter
    def matchdiacritics(self, value):
        """Alias for MatchDiacritics.setter"""
        self.MatchDiacritics = value

    @property
    def match_diacritics(self):
        """Alias for MatchDiacritics"""
        return self.MatchDiacritics

    @match_diacritics.setter
    def match_diacritics(self, value):
        """Alias for MatchDiacritics.setter"""
        self.MatchDiacritics = value

    @property
    def MatchFuzzy(self):
        return self.com_object.MatchFuzzy

    @MatchFuzzy.setter
    def MatchFuzzy(self, value):
        self.com_object.MatchFuzzy = value

    @property
    def matchfuzzy(self):
        """Alias for MatchFuzzy"""
        return self.MatchFuzzy

    @matchfuzzy.setter
    def matchfuzzy(self, value):
        """Alias for MatchFuzzy.setter"""
        self.MatchFuzzy = value

    @property
    def match_fuzzy(self):
        """Alias for MatchFuzzy"""
        return self.MatchFuzzy

    @match_fuzzy.setter
    def match_fuzzy(self, value):
        """Alias for MatchFuzzy.setter"""
        self.MatchFuzzy = value

    @property
    def MatchKashida(self):
        return self.com_object.MatchKashida

    @MatchKashida.setter
    def MatchKashida(self, value):
        self.com_object.MatchKashida = value

    @property
    def matchkashida(self):
        """Alias for MatchKashida"""
        return self.MatchKashida

    @matchkashida.setter
    def matchkashida(self, value):
        """Alias for MatchKashida.setter"""
        self.MatchKashida = value

    @property
    def match_kashida(self):
        """Alias for MatchKashida"""
        return self.MatchKashida

    @match_kashida.setter
    def match_kashida(self, value):
        """Alias for MatchKashida.setter"""
        self.MatchKashida = value

    @property
    def MatchPhrase(self):
        return self.com_object.MatchPhrase

    @MatchPhrase.setter
    def MatchPhrase(self, value):
        self.com_object.MatchPhrase = value

    @property
    def matchphrase(self):
        """Alias for MatchPhrase"""
        return self.MatchPhrase

    @matchphrase.setter
    def matchphrase(self, value):
        """Alias for MatchPhrase.setter"""
        self.MatchPhrase = value

    @property
    def match_phrase(self):
        """Alias for MatchPhrase"""
        return self.MatchPhrase

    @match_phrase.setter
    def match_phrase(self, value):
        """Alias for MatchPhrase.setter"""
        self.MatchPhrase = value

    @property
    def MatchPrefix(self):
        return self.com_object.MatchPrefix

    @MatchPrefix.setter
    def MatchPrefix(self, value):
        self.com_object.MatchPrefix = value

    @property
    def matchprefix(self):
        """Alias for MatchPrefix"""
        return self.MatchPrefix

    @matchprefix.setter
    def matchprefix(self, value):
        """Alias for MatchPrefix.setter"""
        self.MatchPrefix = value

    @property
    def match_prefix(self):
        """Alias for MatchPrefix"""
        return self.MatchPrefix

    @match_prefix.setter
    def match_prefix(self, value):
        """Alias for MatchPrefix.setter"""
        self.MatchPrefix = value

    @property
    def MatchSoundsLike(self):
        return self.com_object.MatchSoundsLike

    @MatchSoundsLike.setter
    def MatchSoundsLike(self, value):
        self.com_object.MatchSoundsLike = value

    @property
    def matchsoundslike(self):
        """Alias for MatchSoundsLike"""
        return self.MatchSoundsLike

    @matchsoundslike.setter
    def matchsoundslike(self, value):
        """Alias for MatchSoundsLike.setter"""
        self.MatchSoundsLike = value

    @property
    def match_sounds_like(self):
        """Alias for MatchSoundsLike"""
        return self.MatchSoundsLike

    @match_sounds_like.setter
    def match_sounds_like(self, value):
        """Alias for MatchSoundsLike.setter"""
        self.MatchSoundsLike = value

    @property
    def MatchSuffix(self):
        return self.com_object.MatchSuffix

    @MatchSuffix.setter
    def MatchSuffix(self, value):
        self.com_object.MatchSuffix = value

    @property
    def matchsuffix(self):
        """Alias for MatchSuffix"""
        return self.MatchSuffix

    @matchsuffix.setter
    def matchsuffix(self, value):
        """Alias for MatchSuffix.setter"""
        self.MatchSuffix = value

    @property
    def match_suffix(self):
        """Alias for MatchSuffix"""
        return self.MatchSuffix

    @match_suffix.setter
    def match_suffix(self, value):
        """Alias for MatchSuffix.setter"""
        self.MatchSuffix = value

    @property
    def MatchWholeWord(self):
        return self.com_object.MatchWholeWord

    @MatchWholeWord.setter
    def MatchWholeWord(self, value):
        self.com_object.MatchWholeWord = value

    @property
    def matchwholeword(self):
        """Alias for MatchWholeWord"""
        return self.MatchWholeWord

    @matchwholeword.setter
    def matchwholeword(self, value):
        """Alias for MatchWholeWord.setter"""
        self.MatchWholeWord = value

    @property
    def match_whole_word(self):
        """Alias for MatchWholeWord"""
        return self.MatchWholeWord

    @match_whole_word.setter
    def match_whole_word(self, value):
        """Alias for MatchWholeWord.setter"""
        self.MatchWholeWord = value

    @property
    def MatchWildcards(self):
        return self.com_object.MatchWildcards

    @MatchWildcards.setter
    def MatchWildcards(self, value):
        self.com_object.MatchWildcards = value

    @property
    def matchwildcards(self):
        """Alias for MatchWildcards"""
        return self.MatchWildcards

    @matchwildcards.setter
    def matchwildcards(self, value):
        """Alias for MatchWildcards.setter"""
        self.MatchWildcards = value

    @property
    def match_wildcards(self):
        """Alias for MatchWildcards"""
        return self.MatchWildcards

    @match_wildcards.setter
    def match_wildcards(self, value):
        """Alias for MatchWildcards.setter"""
        self.MatchWildcards = value

    @property
    def NoProofing(self):
        return self.com_object.NoProofing

    @NoProofing.setter
    def NoProofing(self, value):
        self.com_object.NoProofing = value

    @property
    def noproofing(self):
        """Alias for NoProofing"""
        return self.NoProofing

    @noproofing.setter
    def noproofing(self, value):
        """Alias for NoProofing.setter"""
        self.NoProofing = value

    @property
    def no_proofing(self):
        """Alias for NoProofing"""
        return self.NoProofing

    @no_proofing.setter
    def no_proofing(self, value):
        """Alias for NoProofing.setter"""
        self.NoProofing = value

    @property
    def ParagraphFormat(self):
        return ParagraphFormat(self.com_object.ParagraphFormat)

    @ParagraphFormat.setter
    def ParagraphFormat(self, value):
        self.com_object.ParagraphFormat = value

    @property
    def paragraphformat(self):
        """Alias for ParagraphFormat"""
        return self.ParagraphFormat

    @paragraphformat.setter
    def paragraphformat(self, value):
        """Alias for ParagraphFormat.setter"""
        self.ParagraphFormat = value

    @property
    def paragraph_format(self):
        """Alias for ParagraphFormat"""
        return self.ParagraphFormat

    @paragraph_format.setter
    def paragraph_format(self, value):
        """Alias for ParagraphFormat.setter"""
        self.ParagraphFormat = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Replacement(self):
        return Replacement(self.com_object.Replacement)

    @property
    def replacement(self):
        """Alias for Replacement"""
        return self.Replacement

    @property
    def Style(self):
        return self.com_object.Style

    @Style.setter
    def Style(self, value):
        self.com_object.Style = value

    @property
    def style(self):
        """Alias for Style"""
        return self.Style

    @style.setter
    def style(self, value):
        """Alias for Style.setter"""
        self.Style = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def Wrap(self):
        return self.com_object.Wrap

    @Wrap.setter
    def Wrap(self, value):
        self.com_object.Wrap = value

    @property
    def wrap(self):
        """Alias for Wrap"""
        return self.Wrap

    @wrap.setter
    def wrap(self, value):
        """Alias for Wrap.setter"""
        self.Wrap = value

    def ClearAllFuzzyOptions(self):
        self.com_object.ClearAllFuzzyOptions()

    def clearallfuzzyoptions(self):
        """Alias for ClearAllFuzzyOptions"""
        return self.ClearAllFuzzyOptions()

    def clear_all_fuzzy_options(self):
        """Alias for ClearAllFuzzyOptions"""
        return self.ClearAllFuzzyOptions()

    def ClearFormatting(self):
        self.com_object.ClearFormatting()

    def clearformatting(self):
        """Alias for ClearFormatting"""
        return self.ClearFormatting()

    def clear_formatting(self):
        """Alias for ClearFormatting"""
        return self.ClearFormatting()

    def ClearHitHighlight(self):
        return self.com_object.ClearHitHighlight()

    def clearhithighlight(self):
        """Alias for ClearHitHighlight"""
        return self.ClearHitHighlight()

    def clear_hit_highlight(self):
        """Alias for ClearHitHighlight"""
        return self.ClearHitHighlight()

    def Execute(self, FindText=None, MatchCase=None, MatchWholeWord=None, MatchWildcards=None, MatchSoundsLike=None, MatchAllWordForms=None, Forward=None, Wrap=None, Format=None, ReplaceWith=None, Replace=None, MatchKashida=None, MatchDiacritics=None, MatchAlefHamza=None, MatchControl=None):
        arguments = com_arguments([unwrap(a) for a in [FindText, MatchCase, MatchWholeWord, MatchWildcards, MatchSoundsLike, MatchAllWordForms, Forward, Wrap, Format, ReplaceWith, Replace, MatchKashida, MatchDiacritics, MatchAlefHamza, MatchControl]])
        return self.com_object.Execute(*arguments)

    def execute(self, FindText=None, MatchCase=None, MatchWholeWord=None, MatchWildcards=None, MatchSoundsLike=None, MatchAllWordForms=None, Forward=None, Wrap=None, Format=None, ReplaceWith=None, Replace=None, MatchKashida=None, MatchDiacritics=None, MatchAlefHamza=None, MatchControl=None):
        """Alias for Execute"""
        arguments = [FindText, MatchCase, MatchWholeWord, MatchWildcards, MatchSoundsLike, MatchAllWordForms, Forward, Wrap, Format, ReplaceWith, Replace, MatchKashida, MatchDiacritics, MatchAlefHamza, MatchControl]
        return self.Execute(*arguments)

    def Execute2007(self, FindText=None, MatchCase=None, MatchWholeWord=None, MatchWildcards=None, MatchSoundsLike=None, MatchAllWordForms=None, Forward=None, Wrap=None, Format=None, ReplaceWith=None, Replace=None, MatchKashida=None, MatchDiacritics=None, MatchAlefHamza=None, MatchControl=None, MatchPrefix=None, MatchSuffix=None, MatchPhrase=None, IgnoreSpace=None, IgnorePunct=None):
        arguments = com_arguments([unwrap(a) for a in [FindText, MatchCase, MatchWholeWord, MatchWildcards, MatchSoundsLike, MatchAllWordForms, Forward, Wrap, Format, ReplaceWith, Replace, MatchKashida, MatchDiacritics, MatchAlefHamza, MatchControl, MatchPrefix, MatchSuffix, MatchPhrase, IgnoreSpace, IgnorePunct]])
        return self.com_object.Execute2007(*arguments)

    def execute2007(self, FindText=None, MatchCase=None, MatchWholeWord=None, MatchWildcards=None, MatchSoundsLike=None, MatchAllWordForms=None, Forward=None, Wrap=None, Format=None, ReplaceWith=None, Replace=None, MatchKashida=None, MatchDiacritics=None, MatchAlefHamza=None, MatchControl=None, MatchPrefix=None, MatchSuffix=None, MatchPhrase=None, IgnoreSpace=None, IgnorePunct=None):
        """Alias for Execute2007"""
        arguments = [FindText, MatchCase, MatchWholeWord, MatchWildcards, MatchSoundsLike, MatchAllWordForms, Forward, Wrap, Format, ReplaceWith, Replace, MatchKashida, MatchDiacritics, MatchAlefHamza, MatchControl, MatchPrefix, MatchSuffix, MatchPhrase, IgnoreSpace, IgnorePunct]
        return self.Execute2007(*arguments)

    def HitHighlight(self, FindText=None, HighlightColor=None, TextColor=None, MatchCase=None, MatchWholeWord=None, MatchPrefix=None, MatchSuffix=None, MatchPhrase=None, MatchWildcards=None, MatchSoundsLike=None, MatchAllWordForms=None, MatchByte=None, MatchFuzzy=None, MatchKashida=None, MatchDiacritics=None, MatchAlefHamza=None, MatchControl=None, IgnoreSpace=None, IgnorePunct=None, HanjaPhoneticHangul=None):
        arguments = com_arguments([unwrap(a) for a in [FindText, HighlightColor, TextColor, MatchCase, MatchWholeWord, MatchPrefix, MatchSuffix, MatchPhrase, MatchWildcards, MatchSoundsLike, MatchAllWordForms, MatchByte, MatchFuzzy, MatchKashida, MatchDiacritics, MatchAlefHamza, MatchControl, IgnoreSpace, IgnorePunct, HanjaPhoneticHangul]])
        return self.com_object.HitHighlight(*arguments)

    def hithighlight(self, FindText=None, HighlightColor=None, TextColor=None, MatchCase=None, MatchWholeWord=None, MatchPrefix=None, MatchSuffix=None, MatchPhrase=None, MatchWildcards=None, MatchSoundsLike=None, MatchAllWordForms=None, MatchByte=None, MatchFuzzy=None, MatchKashida=None, MatchDiacritics=None, MatchAlefHamza=None, MatchControl=None, IgnoreSpace=None, IgnorePunct=None, HanjaPhoneticHangul=None):
        """Alias for HitHighlight"""
        arguments = [FindText, HighlightColor, TextColor, MatchCase, MatchWholeWord, MatchPrefix, MatchSuffix, MatchPhrase, MatchWildcards, MatchSoundsLike, MatchAllWordForms, MatchByte, MatchFuzzy, MatchKashida, MatchDiacritics, MatchAlefHamza, MatchControl, IgnoreSpace, IgnorePunct, HanjaPhoneticHangul]
        return self.HitHighlight(*arguments)

    def hit_highlight(self, FindText=None, HighlightColor=None, TextColor=None, MatchCase=None, MatchWholeWord=None, MatchPrefix=None, MatchSuffix=None, MatchPhrase=None, MatchWildcards=None, MatchSoundsLike=None, MatchAllWordForms=None, MatchByte=None, MatchFuzzy=None, MatchKashida=None, MatchDiacritics=None, MatchAlefHamza=None, MatchControl=None, IgnoreSpace=None, IgnorePunct=None, HanjaPhoneticHangul=None):
        """Alias for HitHighlight"""
        arguments = [FindText, HighlightColor, TextColor, MatchCase, MatchWholeWord, MatchPrefix, MatchSuffix, MatchPhrase, MatchWildcards, MatchSoundsLike, MatchAllWordForms, MatchByte, MatchFuzzy, MatchKashida, MatchDiacritics, MatchAlefHamza, MatchControl, IgnoreSpace, IgnorePunct, HanjaPhoneticHangul]
        return self.HitHighlight(*arguments)

    def SetAllFuzzyOptions(self):
        self.com_object.SetAllFuzzyOptions()

    def setallfuzzyoptions(self):
        """Alias for SetAllFuzzyOptions"""
        return self.SetAllFuzzyOptions()

    def set_all_fuzzy_options(self):
        """Alias for SetAllFuzzyOptions"""
        return self.SetAllFuzzyOptions()


class FirstLetterException:

    def __init__(self, firstletterexception=None):
        self.com_object= firstletterexception

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class FirstLetterExceptions:

    def __init__(self, firstletterexceptions=None):
        self.com_object= firstletterexceptions

    def __call__(self, item):
        return FirstLetterException(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        return FirstLetterException(self.com_object.Add(*arguments))

    def add(self, Name=None):
        """Alias for Add"""
        arguments = [Name]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return FirstLetterException(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Floor:

    def __init__(self, floor=None):
        self.com_object= floor

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PictureType(self):
        return self.com_object.PictureType

    @PictureType.setter
    def PictureType(self, value):
        self.com_object.PictureType = value

    @property
    def picturetype(self):
        """Alias for PictureType"""
        return self.PictureType

    @picturetype.setter
    def picturetype(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def picture_type(self):
        """Alias for PictureType"""
        return self.PictureType

    @picture_type.setter
    def picture_type(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def Thickness(self):
        return self.com_object.Thickness

    @Thickness.setter
    def Thickness(self, value):
        self.com_object.Thickness = value

    @property
    def thickness(self):
        """Alias for Thickness"""
        return self.Thickness

    @thickness.setter
    def thickness(self, value):
        """Alias for Thickness.setter"""
        self.Thickness = value

    def ClearFormats(self):
        self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Paste(self):
        self.com_object.Paste()

    def paste(self):
        """Alias for Paste"""
        return self.Paste()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Font:

    def __init__(self, font=None):
        self.com_object= font

    @property
    def AllCaps(self):
        return self.com_object.AllCaps

    @AllCaps.setter
    def AllCaps(self, value):
        self.com_object.AllCaps = value

    @property
    def allcaps(self):
        """Alias for AllCaps"""
        return self.AllCaps

    @allcaps.setter
    def allcaps(self, value):
        """Alias for AllCaps.setter"""
        self.AllCaps = value

    @property
    def all_caps(self):
        """Alias for AllCaps"""
        return self.AllCaps

    @all_caps.setter
    def all_caps(self, value):
        """Alias for AllCaps.setter"""
        self.AllCaps = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Bold(self):
        return self.com_object.Bold

    @Bold.setter
    def Bold(self, value):
        self.com_object.Bold = value

    @property
    def bold(self):
        """Alias for Bold"""
        return self.Bold

    @bold.setter
    def bold(self, value):
        """Alias for Bold.setter"""
        self.Bold = value

    @property
    def BoldBi(self):
        return self.com_object.BoldBi

    @BoldBi.setter
    def BoldBi(self, value):
        self.com_object.BoldBi = value

    @property
    def boldbi(self):
        """Alias for BoldBi"""
        return self.BoldBi

    @boldbi.setter
    def boldbi(self, value):
        """Alias for BoldBi.setter"""
        self.BoldBi = value

    @property
    def bold_bi(self):
        """Alias for BoldBi"""
        return self.BoldBi

    @bold_bi.setter
    def bold_bi(self, value):
        """Alias for BoldBi.setter"""
        self.BoldBi = value

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def ColorIndex(self):
        return WdColorIndex(self.com_object.ColorIndex)

    @ColorIndex.setter
    def ColorIndex(self, value):
        self.com_object.ColorIndex = value

    @property
    def colorindex(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @colorindex.setter
    def colorindex(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def color_index(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @color_index.setter
    def color_index(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def ColorIndexBi(self):
        return Font(self.com_object.ColorIndexBi)

    @ColorIndexBi.setter
    def ColorIndexBi(self, value):
        self.com_object.ColorIndexBi = value

    @property
    def colorindexbi(self):
        """Alias for ColorIndexBi"""
        return self.ColorIndexBi

    @colorindexbi.setter
    def colorindexbi(self, value):
        """Alias for ColorIndexBi.setter"""
        self.ColorIndexBi = value

    @property
    def color_index_bi(self):
        """Alias for ColorIndexBi"""
        return self.ColorIndexBi

    @color_index_bi.setter
    def color_index_bi(self, value):
        """Alias for ColorIndexBi.setter"""
        self.ColorIndexBi = value

    @property
    def ContextualAlternates(self):
        return self.com_object.ContextualAlternates

    @ContextualAlternates.setter
    def ContextualAlternates(self, value):
        self.com_object.ContextualAlternates = value

    @property
    def contextualalternates(self):
        """Alias for ContextualAlternates"""
        return self.ContextualAlternates

    @contextualalternates.setter
    def contextualalternates(self, value):
        """Alias for ContextualAlternates.setter"""
        self.ContextualAlternates = value

    @property
    def contextual_alternates(self):
        """Alias for ContextualAlternates"""
        return self.ContextualAlternates

    @contextual_alternates.setter
    def contextual_alternates(self, value):
        """Alias for ContextualAlternates.setter"""
        self.ContextualAlternates = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DiacriticColor(self):
        return Font(self.com_object.DiacriticColor)

    @DiacriticColor.setter
    def DiacriticColor(self, value):
        self.com_object.DiacriticColor = value

    @property
    def diacriticcolor(self):
        """Alias for DiacriticColor"""
        return self.DiacriticColor

    @diacriticcolor.setter
    def diacriticcolor(self, value):
        """Alias for DiacriticColor.setter"""
        self.DiacriticColor = value

    @property
    def diacritic_color(self):
        """Alias for DiacriticColor"""
        return self.DiacriticColor

    @diacritic_color.setter
    def diacritic_color(self, value):
        """Alias for DiacriticColor.setter"""
        self.DiacriticColor = value

    @property
    def DisableCharacterSpaceGrid(self):
        return self.com_object.DisableCharacterSpaceGrid

    @DisableCharacterSpaceGrid.setter
    def DisableCharacterSpaceGrid(self, value):
        self.com_object.DisableCharacterSpaceGrid = value

    @property
    def disablecharacterspacegrid(self):
        """Alias for DisableCharacterSpaceGrid"""
        return self.DisableCharacterSpaceGrid

    @disablecharacterspacegrid.setter
    def disablecharacterspacegrid(self, value):
        """Alias for DisableCharacterSpaceGrid.setter"""
        self.DisableCharacterSpaceGrid = value

    @property
    def disable_character_space_grid(self):
        """Alias for DisableCharacterSpaceGrid"""
        return self.DisableCharacterSpaceGrid

    @disable_character_space_grid.setter
    def disable_character_space_grid(self, value):
        """Alias for DisableCharacterSpaceGrid.setter"""
        self.DisableCharacterSpaceGrid = value

    @property
    def DoubleStrikeThrough(self):
        return self.com_object.DoubleStrikeThrough

    @property
    def doublestrikethrough(self):
        """Alias for DoubleStrikeThrough"""
        return self.DoubleStrikeThrough

    @property
    def double_strike_through(self):
        """Alias for DoubleStrikeThrough"""
        return self.DoubleStrikeThrough

    @property
    def Duplicate(self):
        return Font(self.com_object.Duplicate)

    @property
    def duplicate(self):
        """Alias for Duplicate"""
        return self.Duplicate

    @property
    def Emboss(self):
        return self.com_object.Emboss

    @Emboss.setter
    def Emboss(self, value):
        self.com_object.Emboss = value

    @property
    def emboss(self):
        """Alias for Emboss"""
        return self.Emboss

    @emboss.setter
    def emboss(self, value):
        """Alias for Emboss.setter"""
        self.Emboss = value

    @property
    def EmphasisMark(self):
        return WdEmphasisMark(self.com_object.EmphasisMark)

    @EmphasisMark.setter
    def EmphasisMark(self, value):
        self.com_object.EmphasisMark = value

    @property
    def emphasismark(self):
        """Alias for EmphasisMark"""
        return self.EmphasisMark

    @emphasismark.setter
    def emphasismark(self, value):
        """Alias for EmphasisMark.setter"""
        self.EmphasisMark = value

    @property
    def emphasis_mark(self):
        """Alias for EmphasisMark"""
        return self.EmphasisMark

    @emphasis_mark.setter
    def emphasis_mark(self, value):
        """Alias for EmphasisMark.setter"""
        self.EmphasisMark = value

    @property
    def Engrave(self):
        return self.com_object.Engrave

    @Engrave.setter
    def Engrave(self, value):
        self.com_object.Engrave = value

    @property
    def engrave(self):
        """Alias for Engrave"""
        return self.Engrave

    @engrave.setter
    def engrave(self, value):
        """Alias for Engrave.setter"""
        self.Engrave = value

    @property
    def Fill(self):
        return self.com_object.Fill

    @property
    def fill(self):
        """Alias for Fill"""
        return self.Fill

    @property
    def Glow(self):
        return GlowFormat(self.com_object.Glow)

    @property
    def glow(self):
        """Alias for Glow"""
        return self.Glow

    @property
    def Hidden(self):
        return self.com_object.Hidden

    @Hidden.setter
    def Hidden(self, value):
        self.com_object.Hidden = value

    @property
    def hidden(self):
        """Alias for Hidden"""
        return self.Hidden

    @hidden.setter
    def hidden(self, value):
        """Alias for Hidden.setter"""
        self.Hidden = value

    @property
    def Italic(self):
        return self.com_object.Italic

    @Italic.setter
    def Italic(self, value):
        self.com_object.Italic = value

    @property
    def italic(self):
        """Alias for Italic"""
        return self.Italic

    @italic.setter
    def italic(self, value):
        """Alias for Italic.setter"""
        self.Italic = value

    @property
    def ItalicBi(self):
        return self.com_object.ItalicBi

    @ItalicBi.setter
    def ItalicBi(self, value):
        self.com_object.ItalicBi = value

    @property
    def italicbi(self):
        """Alias for ItalicBi"""
        return self.ItalicBi

    @italicbi.setter
    def italicbi(self, value):
        """Alias for ItalicBi.setter"""
        self.ItalicBi = value

    @property
    def italic_bi(self):
        """Alias for ItalicBi"""
        return self.ItalicBi

    @italic_bi.setter
    def italic_bi(self, value):
        """Alias for ItalicBi.setter"""
        self.ItalicBi = value

    @property
    def Kerning(self):
        return self.com_object.Kerning

    @Kerning.setter
    def Kerning(self, value):
        self.com_object.Kerning = value

    @property
    def kerning(self):
        """Alias for Kerning"""
        return self.Kerning

    @kerning.setter
    def kerning(self, value):
        """Alias for Kerning.setter"""
        self.Kerning = value

    @property
    def Ligatures(self):
        return Font(self.com_object.Ligatures)

    @Ligatures.setter
    def Ligatures(self, value):
        self.com_object.Ligatures = value

    @property
    def ligatures(self):
        """Alias for Ligatures"""
        return self.Ligatures

    @ligatures.setter
    def ligatures(self, value):
        """Alias for Ligatures.setter"""
        self.Ligatures = value

    @property
    def Line(self):
        return self.com_object.Line

    @Line.setter
    def Line(self, value):
        self.com_object.Line = value

    @property
    def line(self):
        """Alias for Line"""
        return self.Line

    @line.setter
    def line(self, value):
        """Alias for Line.setter"""
        self.Line = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def NameAscii(self):
        return self.com_object.NameAscii

    @NameAscii.setter
    def NameAscii(self, value):
        self.com_object.NameAscii = value

    @property
    def nameascii(self):
        """Alias for NameAscii"""
        return self.NameAscii

    @nameascii.setter
    def nameascii(self, value):
        """Alias for NameAscii.setter"""
        self.NameAscii = value

    @property
    def name_ascii(self):
        """Alias for NameAscii"""
        return self.NameAscii

    @name_ascii.setter
    def name_ascii(self, value):
        """Alias for NameAscii.setter"""
        self.NameAscii = value

    @property
    def NameBi(self):
        return self.com_object.NameBi

    @NameBi.setter
    def NameBi(self, value):
        self.com_object.NameBi = value

    @property
    def namebi(self):
        """Alias for NameBi"""
        return self.NameBi

    @namebi.setter
    def namebi(self, value):
        """Alias for NameBi.setter"""
        self.NameBi = value

    @property
    def name_bi(self):
        """Alias for NameBi"""
        return self.NameBi

    @name_bi.setter
    def name_bi(self, value):
        """Alias for NameBi.setter"""
        self.NameBi = value

    @property
    def NameFarEast(self):
        return self.com_object.NameFarEast

    @NameFarEast.setter
    def NameFarEast(self, value):
        self.com_object.NameFarEast = value

    @property
    def namefareast(self):
        """Alias for NameFarEast"""
        return self.NameFarEast

    @namefareast.setter
    def namefareast(self, value):
        """Alias for NameFarEast.setter"""
        self.NameFarEast = value

    @property
    def name_far_east(self):
        """Alias for NameFarEast"""
        return self.NameFarEast

    @name_far_east.setter
    def name_far_east(self, value):
        """Alias for NameFarEast.setter"""
        self.NameFarEast = value

    @property
    def NameOther(self):
        return self.com_object.NameOther

    @NameOther.setter
    def NameOther(self, value):
        self.com_object.NameOther = value

    @property
    def nameother(self):
        """Alias for NameOther"""
        return self.NameOther

    @nameother.setter
    def nameother(self, value):
        """Alias for NameOther.setter"""
        self.NameOther = value

    @property
    def name_other(self):
        """Alias for NameOther"""
        return self.NameOther

    @name_other.setter
    def name_other(self, value):
        """Alias for NameOther.setter"""
        self.NameOther = value

    @property
    def NumberForm(self):
        return self.com_object.NumberForm

    @NumberForm.setter
    def NumberForm(self, value):
        self.com_object.NumberForm = value

    @property
    def numberform(self):
        """Alias for NumberForm"""
        return self.NumberForm

    @numberform.setter
    def numberform(self, value):
        """Alias for NumberForm.setter"""
        self.NumberForm = value

    @property
    def number_form(self):
        """Alias for NumberForm"""
        return self.NumberForm

    @number_form.setter
    def number_form(self, value):
        """Alias for NumberForm.setter"""
        self.NumberForm = value

    @property
    def NumberSpacing(self):
        return self.com_object.NumberSpacing

    @NumberSpacing.setter
    def NumberSpacing(self, value):
        self.com_object.NumberSpacing = value

    @property
    def numberspacing(self):
        """Alias for NumberSpacing"""
        return self.NumberSpacing

    @numberspacing.setter
    def numberspacing(self, value):
        """Alias for NumberSpacing.setter"""
        self.NumberSpacing = value

    @property
    def number_spacing(self):
        """Alias for NumberSpacing"""
        return self.NumberSpacing

    @number_spacing.setter
    def number_spacing(self, value):
        """Alias for NumberSpacing.setter"""
        self.NumberSpacing = value

    @property
    def Outline(self):
        return self.com_object.Outline

    @Outline.setter
    def Outline(self, value):
        self.com_object.Outline = value

    @property
    def outline(self):
        """Alias for Outline"""
        return self.Outline

    @outline.setter
    def outline(self, value):
        """Alias for Outline.setter"""
        self.Outline = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return self.com_object.Position

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def Reflection(self):
        return self.com_object.Reflection

    @property
    def reflection(self):
        """Alias for Reflection"""
        return self.Reflection

    @property
    def Scaling(self):
        return self.com_object.Scaling

    @Scaling.setter
    def Scaling(self, value):
        self.com_object.Scaling = value

    @property
    def scaling(self):
        """Alias for Scaling"""
        return self.Scaling

    @scaling.setter
    def scaling(self, value):
        """Alias for Scaling.setter"""
        self.Scaling = value

    @property
    def Shading(self):
        return Shading(self.com_object.Shading)

    @property
    def shading(self):
        """Alias for Shading"""
        return self.Shading

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Size(self):
        return self.com_object.Size

    @Size.setter
    def Size(self, value):
        self.com_object.Size = value

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @size.setter
    def size(self, value):
        """Alias for Size.setter"""
        self.Size = value

    @property
    def SizeBi(self):
        return self.com_object.SizeBi

    @SizeBi.setter
    def SizeBi(self, value):
        self.com_object.SizeBi = value

    @property
    def sizebi(self):
        """Alias for SizeBi"""
        return self.SizeBi

    @sizebi.setter
    def sizebi(self, value):
        """Alias for SizeBi.setter"""
        self.SizeBi = value

    @property
    def size_bi(self):
        """Alias for SizeBi"""
        return self.SizeBi

    @size_bi.setter
    def size_bi(self, value):
        """Alias for SizeBi.setter"""
        self.SizeBi = value

    @property
    def SmallCaps(self):
        return self.com_object.SmallCaps

    @SmallCaps.setter
    def SmallCaps(self, value):
        self.com_object.SmallCaps = value

    @property
    def smallcaps(self):
        """Alias for SmallCaps"""
        return self.SmallCaps

    @smallcaps.setter
    def smallcaps(self, value):
        """Alias for SmallCaps.setter"""
        self.SmallCaps = value

    @property
    def small_caps(self):
        """Alias for SmallCaps"""
        return self.SmallCaps

    @small_caps.setter
    def small_caps(self, value):
        """Alias for SmallCaps.setter"""
        self.SmallCaps = value

    @property
    def Spacing(self):
        return self.com_object.Spacing

    @Spacing.setter
    def Spacing(self, value):
        self.com_object.Spacing = value

    @property
    def spacing(self):
        """Alias for Spacing"""
        return self.Spacing

    @spacing.setter
    def spacing(self, value):
        """Alias for Spacing.setter"""
        self.Spacing = value

    @property
    def StrikeThrough(self):
        return self.com_object.StrikeThrough

    @StrikeThrough.setter
    def StrikeThrough(self, value):
        self.com_object.StrikeThrough = value

    @property
    def strikethrough(self):
        """Alias for StrikeThrough"""
        return self.StrikeThrough

    @strikethrough.setter
    def strikethrough(self, value):
        """Alias for StrikeThrough.setter"""
        self.StrikeThrough = value

    @property
    def strike_through(self):
        """Alias for StrikeThrough"""
        return self.StrikeThrough

    @strike_through.setter
    def strike_through(self, value):
        """Alias for StrikeThrough.setter"""
        self.StrikeThrough = value

    @property
    def StylisticSet(self):
        return self.com_object.StylisticSet

    @StylisticSet.setter
    def StylisticSet(self, value):
        self.com_object.StylisticSet = value

    @property
    def stylisticset(self):
        """Alias for StylisticSet"""
        return self.StylisticSet

    @stylisticset.setter
    def stylisticset(self, value):
        """Alias for StylisticSet.setter"""
        self.StylisticSet = value

    @property
    def stylistic_set(self):
        """Alias for StylisticSet"""
        return self.StylisticSet

    @stylistic_set.setter
    def stylistic_set(self, value):
        """Alias for StylisticSet.setter"""
        self.StylisticSet = value

    @property
    def Subscript(self):
        return self.com_object.Subscript

    @Subscript.setter
    def Subscript(self, value):
        self.com_object.Subscript = value

    @property
    def subscript(self):
        """Alias for Subscript"""
        return self.Subscript

    @subscript.setter
    def subscript(self, value):
        """Alias for Subscript.setter"""
        self.Subscript = value

    @property
    def Superscript(self):
        return self.com_object.Superscript

    @Superscript.setter
    def Superscript(self, value):
        self.com_object.Superscript = value

    @property
    def superscript(self):
        """Alias for Superscript"""
        return self.Superscript

    @superscript.setter
    def superscript(self, value):
        """Alias for Superscript.setter"""
        self.Superscript = value

    @property
    def TextColor(self):
        return self.com_object.TextColor

    @property
    def textcolor(self):
        """Alias for TextColor"""
        return self.TextColor

    @property
    def text_color(self):
        """Alias for TextColor"""
        return self.TextColor

    @property
    def TextShadow(self):
        return self.com_object.TextShadow

    @property
    def textshadow(self):
        """Alias for TextShadow"""
        return self.TextShadow

    @property
    def text_shadow(self):
        """Alias for TextShadow"""
        return self.TextShadow

    @property
    def ThreeD(self):
        return self.com_object.ThreeD

    @property
    def threed(self):
        """Alias for ThreeD"""
        return self.ThreeD

    @property
    def three_d(self):
        """Alias for ThreeD"""
        return self.ThreeD

    @property
    def Underline(self):
        return WdUnderline(self.com_object.Underline)

    @Underline.setter
    def Underline(self, value):
        self.com_object.Underline = value

    @property
    def underline(self):
        """Alias for Underline"""
        return self.Underline

    @underline.setter
    def underline(self, value):
        """Alias for Underline.setter"""
        self.Underline = value

    @property
    def UnderlineColor(self):
        return Font(self.com_object.UnderlineColor)

    @UnderlineColor.setter
    def UnderlineColor(self, value):
        self.com_object.UnderlineColor = value

    @property
    def underlinecolor(self):
        """Alias for UnderlineColor"""
        return self.UnderlineColor

    @underlinecolor.setter
    def underlinecolor(self, value):
        """Alias for UnderlineColor.setter"""
        self.UnderlineColor = value

    @property
    def underline_color(self):
        """Alias for UnderlineColor"""
        return self.UnderlineColor

    @underline_color.setter
    def underline_color(self, value):
        """Alias for UnderlineColor.setter"""
        self.UnderlineColor = value

    def Grow(self):
        self.com_object.Grow()

    def grow(self):
        """Alias for Grow"""
        return self.Grow()

    def Reset(self):
        self.com_object.Reset()

    def reset(self):
        """Alias for Reset"""
        return self.Reset()

    def SetAsTemplateDefault(self):
        self.com_object.SetAsTemplateDefault()

    def setastemplatedefault(self):
        """Alias for SetAsTemplateDefault"""
        return self.SetAsTemplateDefault()

    def set_as_template_default(self):
        """Alias for SetAsTemplateDefault"""
        return self.SetAsTemplateDefault()

    def Shrink(self):
        self.com_object.Shrink()

    def shrink(self):
        """Alias for Shrink"""
        return self.Shrink()


class FontNames:

    def __init__(self, fontnames=None):
        self.com_object= fontnames

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Footnote:

    def __init__(self, footnote=None):
        self.com_object= footnote

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def Reference(self):
        return Range(self.com_object.Reference)

    @property
    def reference(self):
        """Alias for Reference"""
        return self.Reference

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class FootnoteOptions:

    def __init__(self, footnoteoptions=None):
        self.com_object= footnoteoptions

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def LayoutColumns(self):
        return self.com_object.LayoutColumns

    @LayoutColumns.setter
    def LayoutColumns(self, value):
        self.com_object.LayoutColumns = value

    @property
    def layoutcolumns(self):
        """Alias for LayoutColumns"""
        return self.LayoutColumns

    @layoutcolumns.setter
    def layoutcolumns(self, value):
        """Alias for LayoutColumns.setter"""
        self.LayoutColumns = value

    @property
    def layout_columns(self):
        """Alias for LayoutColumns"""
        return self.LayoutColumns

    @layout_columns.setter
    def layout_columns(self, value):
        """Alias for LayoutColumns.setter"""
        self.LayoutColumns = value

    @property
    def Location(self):
        return WdFootnoteLocation(self.com_object.Location)

    @Location.setter
    def Location(self, value):
        self.com_object.Location = value

    @property
    def location(self):
        """Alias for Location"""
        return self.Location

    @location.setter
    def location(self, value):
        """Alias for Location.setter"""
        self.Location = value

    @property
    def NumberingRule(self):
        return WdNumberingRule(self.com_object.NumberingRule)

    @NumberingRule.setter
    def NumberingRule(self, value):
        self.com_object.NumberingRule = value

    @property
    def numberingrule(self):
        """Alias for NumberingRule"""
        return self.NumberingRule

    @numberingrule.setter
    def numberingrule(self, value):
        """Alias for NumberingRule.setter"""
        self.NumberingRule = value

    @property
    def numbering_rule(self):
        """Alias for NumberingRule"""
        return self.NumberingRule

    @numbering_rule.setter
    def numbering_rule(self, value):
        """Alias for NumberingRule.setter"""
        self.NumberingRule = value

    @property
    def NumberStyle(self):
        return WdNoteNumberStyle(self.com_object.NumberStyle)

    @NumberStyle.setter
    def NumberStyle(self, value):
        self.com_object.NumberStyle = value

    @property
    def numberstyle(self):
        """Alias for NumberStyle"""
        return self.NumberStyle

    @numberstyle.setter
    def numberstyle(self, value):
        """Alias for NumberStyle.setter"""
        self.NumberStyle = value

    @property
    def number_style(self):
        """Alias for NumberStyle"""
        return self.NumberStyle

    @number_style.setter
    def number_style(self, value):
        """Alias for NumberStyle.setter"""
        self.NumberStyle = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def StartingNumber(self):
        return self.com_object.StartingNumber

    @StartingNumber.setter
    def StartingNumber(self, value):
        self.com_object.StartingNumber = value

    @property
    def startingnumber(self):
        """Alias for StartingNumber"""
        return self.StartingNumber

    @startingnumber.setter
    def startingnumber(self, value):
        """Alias for StartingNumber.setter"""
        self.StartingNumber = value

    @property
    def starting_number(self):
        """Alias for StartingNumber"""
        return self.StartingNumber

    @starting_number.setter
    def starting_number(self, value):
        """Alias for StartingNumber.setter"""
        self.StartingNumber = value


class Footnotes:

    def __init__(self, footnotes=None):
        self.com_object= footnotes

    def __call__(self, item):
        return Footnote(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ContinuationNotice(self):
        return Range(self.com_object.ContinuationNotice)

    @property
    def continuationnotice(self):
        """Alias for ContinuationNotice"""
        return self.ContinuationNotice

    @property
    def continuation_notice(self):
        """Alias for ContinuationNotice"""
        return self.ContinuationNotice

    @property
    def ContinuationSeparator(self):
        return Range(self.com_object.ContinuationSeparator)

    @property
    def continuationseparator(self):
        """Alias for ContinuationSeparator"""
        return self.ContinuationSeparator

    @property
    def continuation_separator(self):
        """Alias for ContinuationSeparator"""
        return self.ContinuationSeparator

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Location(self):
        return WdFootnoteLocation(self.com_object.Location)

    @Location.setter
    def Location(self, value):
        self.com_object.Location = value

    @property
    def location(self):
        """Alias for Location"""
        return self.Location

    @location.setter
    def location(self, value):
        """Alias for Location.setter"""
        self.Location = value

    @property
    def NumberingRule(self):
        return WdNumberingRule(self.com_object.NumberingRule)

    @NumberingRule.setter
    def NumberingRule(self, value):
        self.com_object.NumberingRule = value

    @property
    def numberingrule(self):
        """Alias for NumberingRule"""
        return self.NumberingRule

    @numberingrule.setter
    def numberingrule(self, value):
        """Alias for NumberingRule.setter"""
        self.NumberingRule = value

    @property
    def numbering_rule(self):
        """Alias for NumberingRule"""
        return self.NumberingRule

    @numbering_rule.setter
    def numbering_rule(self, value):
        """Alias for NumberingRule.setter"""
        self.NumberingRule = value

    @property
    def NumberStyle(self):
        return WdNoteNumberStyle(self.com_object.NumberStyle)

    @NumberStyle.setter
    def NumberStyle(self, value):
        self.com_object.NumberStyle = value

    @property
    def numberstyle(self):
        """Alias for NumberStyle"""
        return self.NumberStyle

    @numberstyle.setter
    def numberstyle(self, value):
        """Alias for NumberStyle.setter"""
        self.NumberStyle = value

    @property
    def number_style(self):
        """Alias for NumberStyle"""
        return self.NumberStyle

    @number_style.setter
    def number_style(self, value):
        """Alias for NumberStyle.setter"""
        self.NumberStyle = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Separator(self):
        return Range(self.com_object.Separator)

    @property
    def separator(self):
        """Alias for Separator"""
        return self.Separator

    @property
    def StartingNumber(self):
        return self.com_object.StartingNumber

    @StartingNumber.setter
    def StartingNumber(self, value):
        self.com_object.StartingNumber = value

    @property
    def startingnumber(self):
        """Alias for StartingNumber"""
        return self.StartingNumber

    @startingnumber.setter
    def startingnumber(self, value):
        """Alias for StartingNumber.setter"""
        self.StartingNumber = value

    @property
    def starting_number(self):
        """Alias for StartingNumber"""
        return self.StartingNumber

    @starting_number.setter
    def starting_number(self, value):
        """Alias for StartingNumber.setter"""
        self.StartingNumber = value

    def Add(self, Range=None, Reference=None, Text=None):
        arguments = com_arguments([unwrap(a) for a in [Range, Reference, Text]])
        return Footnote(self.com_object.Add(*arguments))

    def add(self, Range=None, Reference=None, Text=None):
        """Alias for Add"""
        arguments = [Range, Reference, Text]
        return self.Add(*arguments)

    def Convert(self):
        self.com_object.Convert()

    def convert(self):
        """Alias for Convert"""
        return self.Convert()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Footnote(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def ResetContinuationNotice(self):
        self.com_object.ResetContinuationNotice()

    def resetcontinuationnotice(self):
        """Alias for ResetContinuationNotice"""
        return self.ResetContinuationNotice()

    def reset_continuation_notice(self):
        """Alias for ResetContinuationNotice"""
        return self.ResetContinuationNotice()

    def ResetContinuationSeparator(self):
        self.com_object.ResetContinuationSeparator()

    def resetcontinuationseparator(self):
        """Alias for ResetContinuationSeparator"""
        return self.ResetContinuationSeparator()

    def reset_continuation_separator(self):
        """Alias for ResetContinuationSeparator"""
        return self.ResetContinuationSeparator()

    def ResetSeparator(self):
        self.com_object.ResetSeparator()

    def resetseparator(self):
        """Alias for ResetSeparator"""
        return self.ResetSeparator()

    def reset_separator(self):
        """Alias for ResetSeparator"""
        return self.ResetSeparator()

    def SwapWithEndnotes(self):
        self.com_object.SwapWithEndnotes()

    def swapwithendnotes(self):
        """Alias for SwapWithEndnotes"""
        return self.SwapWithEndnotes()

    def swap_with_endnotes(self):
        """Alias for SwapWithEndnotes"""
        return self.SwapWithEndnotes()


class FormField:

    def __init__(self, formfield=None):
        self.com_object= formfield

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def CalculateOnExit(self):
        return self.com_object.CalculateOnExit

    @CalculateOnExit.setter
    def CalculateOnExit(self, value):
        self.com_object.CalculateOnExit = value

    @property
    def calculateonexit(self):
        """Alias for CalculateOnExit"""
        return self.CalculateOnExit

    @calculateonexit.setter
    def calculateonexit(self, value):
        """Alias for CalculateOnExit.setter"""
        self.CalculateOnExit = value

    @property
    def calculate_on_exit(self):
        """Alias for CalculateOnExit"""
        return self.CalculateOnExit

    @calculate_on_exit.setter
    def calculate_on_exit(self, value):
        """Alias for CalculateOnExit.setter"""
        self.CalculateOnExit = value

    @property
    def CheckBox(self):
        return CheckBox(self.com_object.CheckBox)

    @property
    def checkbox(self):
        """Alias for CheckBox"""
        return self.CheckBox

    @property
    def check_box(self):
        """Alias for CheckBox"""
        return self.CheckBox

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DropDown(self):
        return DropDown(self.com_object.DropDown)

    @property
    def dropdown(self):
        """Alias for DropDown"""
        return self.DropDown

    @property
    def drop_down(self):
        """Alias for DropDown"""
        return self.DropDown

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def EntryMacro(self):
        return self.com_object.EntryMacro

    @EntryMacro.setter
    def EntryMacro(self, value):
        self.com_object.EntryMacro = value

    @property
    def entrymacro(self):
        """Alias for EntryMacro"""
        return self.EntryMacro

    @entrymacro.setter
    def entrymacro(self, value):
        """Alias for EntryMacro.setter"""
        self.EntryMacro = value

    @property
    def entry_macro(self):
        """Alias for EntryMacro"""
        return self.EntryMacro

    @entry_macro.setter
    def entry_macro(self, value):
        """Alias for EntryMacro.setter"""
        self.EntryMacro = value

    @property
    def ExitMacro(self):
        return self.com_object.ExitMacro

    @ExitMacro.setter
    def ExitMacro(self, value):
        self.com_object.ExitMacro = value

    @property
    def exitmacro(self):
        """Alias for ExitMacro"""
        return self.ExitMacro

    @exitmacro.setter
    def exitmacro(self, value):
        """Alias for ExitMacro.setter"""
        self.ExitMacro = value

    @property
    def exit_macro(self):
        """Alias for ExitMacro"""
        return self.ExitMacro

    @exit_macro.setter
    def exit_macro(self, value):
        """Alias for ExitMacro.setter"""
        self.ExitMacro = value

    @property
    def HelpText(self):
        return self.com_object.HelpText

    @HelpText.setter
    def HelpText(self, value):
        self.com_object.HelpText = value

    @property
    def helptext(self):
        """Alias for HelpText"""
        return self.HelpText

    @helptext.setter
    def helptext(self, value):
        """Alias for HelpText.setter"""
        self.HelpText = value

    @property
    def help_text(self):
        """Alias for HelpText"""
        return self.HelpText

    @help_text.setter
    def help_text(self, value):
        """Alias for HelpText.setter"""
        self.HelpText = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Next(self):
        return self.com_object.Next

    @property
    def next(self):
        """Alias for Next"""
        return self.Next

    @property
    def OwnHelp(self):
        return self.com_object.OwnHelp

    @OwnHelp.setter
    def OwnHelp(self, value):
        self.com_object.OwnHelp = value

    @property
    def ownhelp(self):
        """Alias for OwnHelp"""
        return self.OwnHelp

    @ownhelp.setter
    def ownhelp(self, value):
        """Alias for OwnHelp.setter"""
        self.OwnHelp = value

    @property
    def own_help(self):
        """Alias for OwnHelp"""
        return self.OwnHelp

    @own_help.setter
    def own_help(self, value):
        """Alias for OwnHelp.setter"""
        self.OwnHelp = value

    @property
    def OwnStatus(self):
        return self.com_object.OwnStatus

    @OwnStatus.setter
    def OwnStatus(self, value):
        self.com_object.OwnStatus = value

    @property
    def ownstatus(self):
        """Alias for OwnStatus"""
        return self.OwnStatus

    @ownstatus.setter
    def ownstatus(self, value):
        """Alias for OwnStatus.setter"""
        self.OwnStatus = value

    @property
    def own_status(self):
        """Alias for OwnStatus"""
        return self.OwnStatus

    @own_status.setter
    def own_status(self, value):
        """Alias for OwnStatus.setter"""
        self.OwnStatus = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Previous(self):
        return self.com_object.Previous

    @property
    def previous(self):
        """Alias for Previous"""
        return self.Previous

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def Result(self):
        return self.com_object.Result

    @Result.setter
    def Result(self, value):
        self.com_object.Result = value

    @property
    def result(self):
        """Alias for Result"""
        return self.Result

    @result.setter
    def result(self, value):
        """Alias for Result.setter"""
        self.Result = value

    @property
    def StatusText(self):
        return self.com_object.StatusText

    @StatusText.setter
    def StatusText(self, value):
        self.com_object.StatusText = value

    @property
    def statustext(self):
        """Alias for StatusText"""
        return self.StatusText

    @statustext.setter
    def statustext(self, value):
        """Alias for StatusText.setter"""
        self.StatusText = value

    @property
    def status_text(self):
        """Alias for StatusText"""
        return self.StatusText

    @status_text.setter
    def status_text(self, value):
        """Alias for StatusText.setter"""
        self.StatusText = value

    @property
    def TextInput(self):
        return TextInput(self.com_object.TextInput)

    @property
    def textinput(self):
        """Alias for TextInput"""
        return self.TextInput

    @property
    def text_input(self):
        """Alias for TextInput"""
        return self.TextInput

    @property
    def Type(self):
        return WdFieldType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Cut(self):
        self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class FormFields:

    def __init__(self, formfields=None):
        self.com_object= formfields

    def __call__(self, item):
        return FormField(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Shaded(self):
        return self.com_object.Shaded

    @Shaded.setter
    def Shaded(self, value):
        self.com_object.Shaded = value

    @property
    def shaded(self):
        """Alias for Shaded"""
        return self.Shaded

    @shaded.setter
    def shaded(self, value):
        """Alias for Shaded.setter"""
        self.Shaded = value

    def Add(self, Range=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Range, Type]])
        return FormField(self.com_object.Add(*arguments))

    def add(self, Range=None, Type=None):
        """Alias for Add"""
        arguments = [Range, Type]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return FormField(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Frame:

    def __init__(self, frame=None):
        self.com_object= frame

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HeightRule(self):
        return WdFrameSizeRule(self.com_object.HeightRule)

    @HeightRule.setter
    def HeightRule(self, value):
        self.com_object.HeightRule = value

    @property
    def heightrule(self):
        """Alias for HeightRule"""
        return self.HeightRule

    @heightrule.setter
    def heightrule(self, value):
        """Alias for HeightRule.setter"""
        self.HeightRule = value

    @property
    def height_rule(self):
        """Alias for HeightRule"""
        return self.HeightRule

    @height_rule.setter
    def height_rule(self, value):
        """Alias for HeightRule.setter"""
        self.HeightRule = value

    @property
    def HorizontalDistanceFromText(self):
        return self.com_object.HorizontalDistanceFromText

    @HorizontalDistanceFromText.setter
    def HorizontalDistanceFromText(self, value):
        self.com_object.HorizontalDistanceFromText = value

    @property
    def horizontaldistancefromtext(self):
        """Alias for HorizontalDistanceFromText"""
        return self.HorizontalDistanceFromText

    @horizontaldistancefromtext.setter
    def horizontaldistancefromtext(self, value):
        """Alias for HorizontalDistanceFromText.setter"""
        self.HorizontalDistanceFromText = value

    @property
    def horizontal_distance_from_text(self):
        """Alias for HorizontalDistanceFromText"""
        return self.HorizontalDistanceFromText

    @horizontal_distance_from_text.setter
    def horizontal_distance_from_text(self, value):
        """Alias for HorizontalDistanceFromText.setter"""
        self.HorizontalDistanceFromText = value

    @property
    def HorizontalPosition(self):
        return self.com_object.HorizontalPosition

    @HorizontalPosition.setter
    def HorizontalPosition(self, value):
        self.com_object.HorizontalPosition = value

    @property
    def horizontalposition(self):
        """Alias for HorizontalPosition"""
        return self.HorizontalPosition

    @horizontalposition.setter
    def horizontalposition(self, value):
        """Alias for HorizontalPosition.setter"""
        self.HorizontalPosition = value

    @property
    def horizontal_position(self):
        """Alias for HorizontalPosition"""
        return self.HorizontalPosition

    @horizontal_position.setter
    def horizontal_position(self, value):
        """Alias for HorizontalPosition.setter"""
        self.HorizontalPosition = value

    @property
    def LockAnchor(self):
        return self.com_object.LockAnchor

    @LockAnchor.setter
    def LockAnchor(self, value):
        self.com_object.LockAnchor = value

    @property
    def lockanchor(self):
        """Alias for LockAnchor"""
        return self.LockAnchor

    @lockanchor.setter
    def lockanchor(self, value):
        """Alias for LockAnchor.setter"""
        self.LockAnchor = value

    @property
    def lock_anchor(self):
        """Alias for LockAnchor"""
        return self.LockAnchor

    @lock_anchor.setter
    def lock_anchor(self, value):
        """Alias for LockAnchor.setter"""
        self.LockAnchor = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def RelativeHorizontalPosition(self):
        return self.com_object.RelativeHorizontalPosition

    @RelativeHorizontalPosition.setter
    def RelativeHorizontalPosition(self, value):
        self.com_object.RelativeHorizontalPosition = value

    @property
    def relativehorizontalposition(self):
        """Alias for RelativeHorizontalPosition"""
        return self.RelativeHorizontalPosition

    @relativehorizontalposition.setter
    def relativehorizontalposition(self, value):
        """Alias for RelativeHorizontalPosition.setter"""
        self.RelativeHorizontalPosition = value

    @property
    def relative_horizontal_position(self):
        """Alias for RelativeHorizontalPosition"""
        return self.RelativeHorizontalPosition

    @relative_horizontal_position.setter
    def relative_horizontal_position(self, value):
        """Alias for RelativeHorizontalPosition.setter"""
        self.RelativeHorizontalPosition = value

    @property
    def RelativeVerticalPosition(self):
        return self.com_object.RelativeVerticalPosition

    @RelativeVerticalPosition.setter
    def RelativeVerticalPosition(self, value):
        self.com_object.RelativeVerticalPosition = value

    @property
    def relativeverticalposition(self):
        """Alias for RelativeVerticalPosition"""
        return self.RelativeVerticalPosition

    @relativeverticalposition.setter
    def relativeverticalposition(self, value):
        """Alias for RelativeVerticalPosition.setter"""
        self.RelativeVerticalPosition = value

    @property
    def relative_vertical_position(self):
        """Alias for RelativeVerticalPosition"""
        return self.RelativeVerticalPosition

    @relative_vertical_position.setter
    def relative_vertical_position(self, value):
        """Alias for RelativeVerticalPosition.setter"""
        self.RelativeVerticalPosition = value

    @property
    def Shading(self):
        return Shading(self.com_object.Shading)

    @property
    def shading(self):
        """Alias for Shading"""
        return self.Shading

    @property
    def TextWrap(self):
        return self.com_object.TextWrap

    @TextWrap.setter
    def TextWrap(self, value):
        self.com_object.TextWrap = value

    @property
    def textwrap(self):
        """Alias for TextWrap"""
        return self.TextWrap

    @textwrap.setter
    def textwrap(self, value):
        """Alias for TextWrap.setter"""
        self.TextWrap = value

    @property
    def text_wrap(self):
        """Alias for TextWrap"""
        return self.TextWrap

    @text_wrap.setter
    def text_wrap(self, value):
        """Alias for TextWrap.setter"""
        self.TextWrap = value

    @property
    def VerticalDistanceFromText(self):
        return self.com_object.VerticalDistanceFromText

    @VerticalDistanceFromText.setter
    def VerticalDistanceFromText(self, value):
        self.com_object.VerticalDistanceFromText = value

    @property
    def verticaldistancefromtext(self):
        """Alias for VerticalDistanceFromText"""
        return self.VerticalDistanceFromText

    @verticaldistancefromtext.setter
    def verticaldistancefromtext(self, value):
        """Alias for VerticalDistanceFromText.setter"""
        self.VerticalDistanceFromText = value

    @property
    def vertical_distance_from_text(self):
        """Alias for VerticalDistanceFromText"""
        return self.VerticalDistanceFromText

    @vertical_distance_from_text.setter
    def vertical_distance_from_text(self, value):
        """Alias for VerticalDistanceFromText.setter"""
        self.VerticalDistanceFromText = value

    @property
    def VerticalPosition(self):
        return self.com_object.VerticalPosition

    @VerticalPosition.setter
    def VerticalPosition(self, value):
        self.com_object.VerticalPosition = value

    @property
    def verticalposition(self):
        """Alias for VerticalPosition"""
        return self.VerticalPosition

    @verticalposition.setter
    def verticalposition(self, value):
        """Alias for VerticalPosition.setter"""
        self.VerticalPosition = value

    @property
    def vertical_position(self):
        """Alias for VerticalPosition"""
        return self.VerticalPosition

    @vertical_position.setter
    def vertical_position(self, value):
        """Alias for VerticalPosition.setter"""
        self.VerticalPosition = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def WidthRule(self):
        return WdFrameSizeRule(self.com_object.WidthRule)

    @WidthRule.setter
    def WidthRule(self, value):
        self.com_object.WidthRule = value

    @property
    def widthrule(self):
        """Alias for WidthRule"""
        return self.WidthRule

    @widthrule.setter
    def widthrule(self, value):
        """Alias for WidthRule.setter"""
        self.WidthRule = value

    @property
    def width_rule(self):
        """Alias for WidthRule"""
        return self.WidthRule

    @width_rule.setter
    def width_rule(self, value):
        """Alias for WidthRule.setter"""
        self.WidthRule = value

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Cut(self):
        self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Frameset:

    def __init__(self, frameset=None):
        self.com_object= frameset

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ChildFramesetCount(self):
        return Frameset(self.com_object.ChildFramesetCount)

    @property
    def childframesetcount(self):
        """Alias for ChildFramesetCount"""
        return self.ChildFramesetCount

    @property
    def child_frameset_count(self):
        """Alias for ChildFramesetCount"""
        return self.ChildFramesetCount

    def ChildFramesetItem(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetChildFramesetItem"):
            return Frameset(self.com_object.GetChildFramesetItem(*arguments))
        else:
            return Frameset(self.com_object.ChildFramesetItem(*arguments))

    def childframesetitem(self, Index=None):
        """Alias for ChildFramesetItem"""
        arguments = [Index]
        return self.ChildFramesetItem(*arguments)

    def child_frameset_item(self, Index=None):
        """Alias for ChildFramesetItem"""
        arguments = [Index]
        return self.ChildFramesetItem(*arguments)

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def FrameDefaultURL(self):
        return self.com_object.FrameDefaultURL

    @FrameDefaultURL.setter
    def FrameDefaultURL(self, value):
        self.com_object.FrameDefaultURL = value

    @property
    def framedefaulturl(self):
        """Alias for FrameDefaultURL"""
        return self.FrameDefaultURL

    @framedefaulturl.setter
    def framedefaulturl(self, value):
        """Alias for FrameDefaultURL.setter"""
        self.FrameDefaultURL = value

    @property
    def frame_default_u_r_l(self):
        """Alias for FrameDefaultURL"""
        return self.FrameDefaultURL

    @frame_default_u_r_l.setter
    def frame_default_u_r_l(self, value):
        """Alias for FrameDefaultURL.setter"""
        self.FrameDefaultURL = value

    @property
    def FrameDisplayBorders(self):
        return self.com_object.FrameDisplayBorders

    @FrameDisplayBorders.setter
    def FrameDisplayBorders(self, value):
        self.com_object.FrameDisplayBorders = value

    @property
    def framedisplayborders(self):
        """Alias for FrameDisplayBorders"""
        return self.FrameDisplayBorders

    @framedisplayborders.setter
    def framedisplayborders(self, value):
        """Alias for FrameDisplayBorders.setter"""
        self.FrameDisplayBorders = value

    @property
    def frame_display_borders(self):
        """Alias for FrameDisplayBorders"""
        return self.FrameDisplayBorders

    @frame_display_borders.setter
    def frame_display_borders(self, value):
        """Alias for FrameDisplayBorders.setter"""
        self.FrameDisplayBorders = value

    @property
    def FrameLinkToFile(self):
        return self.com_object.FrameLinkToFile

    @FrameLinkToFile.setter
    def FrameLinkToFile(self, value):
        self.com_object.FrameLinkToFile = value

    @property
    def framelinktofile(self):
        """Alias for FrameLinkToFile"""
        return self.FrameLinkToFile

    @framelinktofile.setter
    def framelinktofile(self, value):
        """Alias for FrameLinkToFile.setter"""
        self.FrameLinkToFile = value

    @property
    def frame_link_to_file(self):
        """Alias for FrameLinkToFile"""
        return self.FrameLinkToFile

    @frame_link_to_file.setter
    def frame_link_to_file(self, value):
        """Alias for FrameLinkToFile.setter"""
        self.FrameLinkToFile = value

    @property
    def FrameName(self):
        return self.com_object.FrameName

    @FrameName.setter
    def FrameName(self, value):
        self.com_object.FrameName = value

    @property
    def framename(self):
        """Alias for FrameName"""
        return self.FrameName

    @framename.setter
    def framename(self, value):
        """Alias for FrameName.setter"""
        self.FrameName = value

    @property
    def frame_name(self):
        """Alias for FrameName"""
        return self.FrameName

    @frame_name.setter
    def frame_name(self, value):
        """Alias for FrameName.setter"""
        self.FrameName = value

    @property
    def FrameResizable(self):
        return self.com_object.FrameResizable

    @FrameResizable.setter
    def FrameResizable(self, value):
        self.com_object.FrameResizable = value

    @property
    def frameresizable(self):
        """Alias for FrameResizable"""
        return self.FrameResizable

    @frameresizable.setter
    def frameresizable(self, value):
        """Alias for FrameResizable.setter"""
        self.FrameResizable = value

    @property
    def frame_resizable(self):
        """Alias for FrameResizable"""
        return self.FrameResizable

    @frame_resizable.setter
    def frame_resizable(self, value):
        """Alias for FrameResizable.setter"""
        self.FrameResizable = value

    @property
    def FrameScrollbarType(self):
        return WdScrollbarType(self.com_object.FrameScrollbarType)

    @FrameScrollbarType.setter
    def FrameScrollbarType(self, value):
        self.com_object.FrameScrollbarType = value

    @property
    def framescrollbartype(self):
        """Alias for FrameScrollbarType"""
        return self.FrameScrollbarType

    @framescrollbartype.setter
    def framescrollbartype(self, value):
        """Alias for FrameScrollbarType.setter"""
        self.FrameScrollbarType = value

    @property
    def frame_scrollbar_type(self):
        """Alias for FrameScrollbarType"""
        return self.FrameScrollbarType

    @frame_scrollbar_type.setter
    def frame_scrollbar_type(self, value):
        """Alias for FrameScrollbarType.setter"""
        self.FrameScrollbarType = value

    @property
    def FramesetBorderColor(self):
        return self.com_object.FramesetBorderColor

    @FramesetBorderColor.setter
    def FramesetBorderColor(self, value):
        self.com_object.FramesetBorderColor = value

    @property
    def framesetbordercolor(self):
        """Alias for FramesetBorderColor"""
        return self.FramesetBorderColor

    @framesetbordercolor.setter
    def framesetbordercolor(self, value):
        """Alias for FramesetBorderColor.setter"""
        self.FramesetBorderColor = value

    @property
    def frameset_border_color(self):
        """Alias for FramesetBorderColor"""
        return self.FramesetBorderColor

    @frameset_border_color.setter
    def frameset_border_color(self, value):
        """Alias for FramesetBorderColor.setter"""
        self.FramesetBorderColor = value

    @property
    def FramesetBorderWidth(self):
        return self.com_object.FramesetBorderWidth

    @FramesetBorderWidth.setter
    def FramesetBorderWidth(self, value):
        self.com_object.FramesetBorderWidth = value

    @property
    def framesetborderwidth(self):
        """Alias for FramesetBorderWidth"""
        return self.FramesetBorderWidth

    @framesetborderwidth.setter
    def framesetborderwidth(self, value):
        """Alias for FramesetBorderWidth.setter"""
        self.FramesetBorderWidth = value

    @property
    def frameset_border_width(self):
        """Alias for FramesetBorderWidth"""
        return self.FramesetBorderWidth

    @frameset_border_width.setter
    def frameset_border_width(self, value):
        """Alias for FramesetBorderWidth.setter"""
        self.FramesetBorderWidth = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HeightType(self):
        return WdFramesetSizeType(self.com_object.HeightType)

    @HeightType.setter
    def HeightType(self, value):
        self.com_object.HeightType = value

    @property
    def heighttype(self):
        """Alias for HeightType"""
        return self.HeightType

    @heighttype.setter
    def heighttype(self, value):
        """Alias for HeightType.setter"""
        self.HeightType = value

    @property
    def height_type(self):
        """Alias for HeightType"""
        return self.HeightType

    @height_type.setter
    def height_type(self, value):
        """Alias for HeightType.setter"""
        self.HeightType = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ParentFrameset(self):
        return Frameset(self.com_object.ParentFrameset)

    @property
    def parentframeset(self):
        """Alias for ParentFrameset"""
        return self.ParentFrameset

    @property
    def parent_frameset(self):
        """Alias for ParentFrameset"""
        return self.ParentFrameset

    @property
    def Type(self):
        return WdFramesetType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def Width(self):
        return Frameset(self.com_object.Width)

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def WidthType(self):
        return Frameset(self.com_object.WidthType)

    @WidthType.setter
    def WidthType(self, value):
        self.com_object.WidthType = value

    @property
    def widthtype(self):
        """Alias for WidthType"""
        return self.WidthType

    @widthtype.setter
    def widthtype(self, value):
        """Alias for WidthType.setter"""
        self.WidthType = value

    @property
    def width_type(self):
        """Alias for WidthType"""
        return self.WidthType

    @width_type.setter
    def width_type(self, value):
        """Alias for WidthType.setter"""
        self.WidthType = value

    def AddNewFrame(self, Where=None):
        arguments = com_arguments([unwrap(a) for a in [Where]])
        self.com_object.AddNewFrame(*arguments)

    def addnewframe(self, Where=None):
        """Alias for AddNewFrame"""
        arguments = [Where]
        return self.AddNewFrame(*arguments)

    def add_new_frame(self, Where=None):
        """Alias for AddNewFrame"""
        arguments = [Where]
        return self.AddNewFrame(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class FreeformBuilder:

    def __init__(self, freeformbuilder=None):
        self.com_object= freeformbuilder

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def AddNodes(self, SegmentType=None, EditingType=None, X1=None, Y1=None, X2=None, Y2=None, X3=None, Y3=None):
        arguments = com_arguments([unwrap(a) for a in [SegmentType, EditingType, X1, Y1, X2, Y2, X3, Y3]])
        self.com_object.AddNodes(*arguments)

    def addnodes(self, SegmentType=None, EditingType=None, X1=None, Y1=None, X2=None, Y2=None, X3=None, Y3=None):
        """Alias for AddNodes"""
        arguments = [SegmentType, EditingType, X1, Y1, X2, Y2, X3, Y3]
        return self.AddNodes(*arguments)

    def add_nodes(self, SegmentType=None, EditingType=None, X1=None, Y1=None, X2=None, Y2=None, X3=None, Y3=None):
        """Alias for AddNodes"""
        arguments = [SegmentType, EditingType, X1, Y1, X2, Y2, X3, Y3]
        return self.AddNodes(*arguments)

    def ConvertToShape(self, Anchor=None):
        arguments = com_arguments([unwrap(a) for a in [Anchor]])
        self.com_object.ConvertToShape(*arguments)

    def converttoshape(self, Anchor=None):
        """Alias for ConvertToShape"""
        arguments = [Anchor]
        return self.ConvertToShape(*arguments)

    def convert_to_shape(self, Anchor=None):
        """Alias for ConvertToShape"""
        arguments = [Anchor]
        return self.ConvertToShape(*arguments)


class FullSeriesCollection:

    def __init__(self, fullseriescollection=None):
        self.com_object= fullseriescollection

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return SERIES(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class GlowFormat:

    def __init__(self, glowformat=None):
        self.com_object= glowformat

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Color(self):
        return ColorFormat(self.com_object.Color)

    @property
    def color(self):
        """Alias for Color"""
        return self.Color

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Radius(self):
        return self.com_object.Radius

    @Radius.setter
    def Radius(self, value):
        self.com_object.Radius = value

    @property
    def radius(self):
        """Alias for Radius"""
        return self.Radius

    @radius.setter
    def radius(self, value):
        """Alias for Radius.setter"""
        self.Radius = value

    @property
    def Transparency(self):
        return self.com_object.Transparency

    @Transparency.setter
    def Transparency(self, value):
        self.com_object.Transparency = value

    @property
    def transparency(self):
        """Alias for Transparency"""
        return self.Transparency

    @transparency.setter
    def transparency(self, value):
        """Alias for Transparency.setter"""
        self.Transparency = value


class Gridlines:

    def __init__(self, gridlines=None):
        self.com_object= gridlines

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Border(self):
        return ChartBorder(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class GroupShapes:

    def __init__(self, groupshapes=None):
        self.com_object= groupshapes

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Shape(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Range(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ShapeRange(self.com_object.Range(*arguments))

    def range(self, Index=None):
        """Alias for Range"""
        arguments = [Index]
        return self.Range(*arguments)


class HangulAndAlphabetException:

    def __init__(self, hangulandalphabetexception=None):
        self.com_object= hangulandalphabetexception

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class HangulAndAlphabetExceptions:

    def __init__(self, hangulandalphabetexceptions=None):
        self.com_object= hangulandalphabetexceptions

    def __call__(self, item):
        return HangulAndAlphabetException(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        return HangulAndAlphabetException(self.com_object.Add(*arguments))

    def add(self, Name=None):
        """Alias for Add"""
        arguments = [Name]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return HangulAndAlphabetException(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class HangulHanjaConversionDictionaries:

    def __init__(self, hangulhanjaconversiondictionaries=None):
        self.com_object= hangulhanjaconversiondictionaries

    def __call__(self, item):
        return HangulHanjaConversionDictionarie(self.com_object(item))

    @property
    def ActiveCustomDictionary(self):
        return Dictionary(self.com_object.ActiveCustomDictionary)

    @ActiveCustomDictionary.setter
    def ActiveCustomDictionary(self, value):
        self.com_object.ActiveCustomDictionary = value

    @property
    def activecustomdictionary(self):
        """Alias for ActiveCustomDictionary"""
        return self.ActiveCustomDictionary

    @activecustomdictionary.setter
    def activecustomdictionary(self, value):
        """Alias for ActiveCustomDictionary.setter"""
        self.ActiveCustomDictionary = value

    @property
    def active_custom_dictionary(self):
        """Alias for ActiveCustomDictionary"""
        return self.ActiveCustomDictionary

    @active_custom_dictionary.setter
    def active_custom_dictionary(self, value):
        """Alias for ActiveCustomDictionary.setter"""
        self.ActiveCustomDictionary = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Maximum(self):
        return self.com_object.Maximum

    @property
    def maximum(self):
        """Alias for Maximum"""
        return self.Maximum

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        return Dictionary(self.com_object.Add(*arguments))

    def add(self, FileName=None):
        """Alias for Add"""
        arguments = [FileName]
        return self.Add(*arguments)

    def ClearAll(self):
        self.com_object.ClearAll()

    def clearall(self):
        """Alias for ClearAll"""
        return self.ClearAll()

    def clear_all(self):
        """Alias for ClearAll"""
        return self.ClearAll()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Dictionary(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class HeaderFooter:

    def __init__(self, headerfooter=None):
        self.com_object= headerfooter

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Exists(self):
        return self.com_object.Exists

    @Exists.setter
    def Exists(self, value):
        self.com_object.Exists = value

    @property
    def exists(self):
        """Alias for Exists"""
        return self.Exists

    @exists.setter
    def exists(self, value):
        """Alias for Exists.setter"""
        self.Exists = value

    @property
    def Index(self):
        return WdHeaderFooterIndex(self.com_object.Index)

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def IsHeader(self):
        return self.com_object.IsHeader

    @property
    def isheader(self):
        """Alias for IsHeader"""
        return self.IsHeader

    @property
    def is_header(self):
        """Alias for IsHeader"""
        return self.IsHeader

    @property
    def LinkToPrevious(self):
        return self.com_object.LinkToPrevious

    @LinkToPrevious.setter
    def LinkToPrevious(self, value):
        self.com_object.LinkToPrevious = value

    @property
    def linktoprevious(self):
        """Alias for LinkToPrevious"""
        return self.LinkToPrevious

    @linktoprevious.setter
    def linktoprevious(self, value):
        """Alias for LinkToPrevious.setter"""
        self.LinkToPrevious = value

    @property
    def link_to_previous(self):
        """Alias for LinkToPrevious"""
        return self.LinkToPrevious

    @link_to_previous.setter
    def link_to_previous(self, value):
        """Alias for LinkToPrevious.setter"""
        self.LinkToPrevious = value

    @property
    def PageNumbers(self):
        return PageNumbers(self.com_object.PageNumbers)

    @property
    def pagenumbers(self):
        """Alias for PageNumbers"""
        return self.PageNumbers

    @property
    def page_numbers(self):
        """Alias for PageNumbers"""
        return self.PageNumbers

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def Shapes(self):
        return Shapes(self.com_object.Shapes)

    @property
    def shapes(self):
        """Alias for Shapes"""
        return self.Shapes


class HeadersFooters:

    def __init__(self, headersfooters=None):
        self.com_object= headersfooters

    def __call__(self, item):
        return HeadersFooter(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return HeaderFooter(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class HeadingStyle:

    def __init__(self, headingstyle=None):
        self.com_object= headingstyle

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Level(self):
        return self.com_object.Level

    @Level.setter
    def Level(self, value):
        self.com_object.Level = value

    @property
    def level(self):
        """Alias for Level"""
        return self.Level

    @level.setter
    def level(self, value):
        """Alias for Level.setter"""
        self.Level = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Style(self):
        return self.com_object.Style

    @Style.setter
    def Style(self, value):
        self.com_object.Style = value

    @property
    def style(self):
        """Alias for Style"""
        return self.Style

    @style.setter
    def style(self, value):
        """Alias for Style.setter"""
        self.Style = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class HeadingStyles:

    def __init__(self, headingstyles=None):
        self.com_object= headingstyles

    def __call__(self, item):
        return HeadingStyle(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Style=None, Level=None):
        arguments = com_arguments([unwrap(a) for a in [Style, Level]])
        return HeadingStyle(self.com_object.Add(*arguments))

    def add(self, Style=None, Level=None):
        """Alias for Add"""
        arguments = [Style, Level]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return HeadingStyle(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class HiLoLines:

    def __init__(self, hilolines=None):
        self.com_object= hilolines

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Border(self):
        return ChartBorder(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class HorizontalLineFormat:

    def __init__(self, horizontallineformat=None):
        self.com_object= horizontallineformat

    @property
    def Alignment(self):
        return WdHorizontalLineAlignment(self.com_object.Alignment)

    @Alignment.setter
    def Alignment(self, value):
        self.com_object.Alignment = value

    @property
    def alignment(self):
        """Alias for Alignment"""
        return self.Alignment

    @alignment.setter
    def alignment(self, value):
        """Alias for Alignment.setter"""
        self.Alignment = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def NoShade(self):
        return self.com_object.NoShade

    @NoShade.setter
    def NoShade(self, value):
        self.com_object.NoShade = value

    @property
    def noshade(self):
        """Alias for NoShade"""
        return self.NoShade

    @noshade.setter
    def noshade(self, value):
        """Alias for NoShade.setter"""
        self.NoShade = value

    @property
    def no_shade(self):
        """Alias for NoShade"""
        return self.NoShade

    @no_shade.setter
    def no_shade(self, value):
        """Alias for NoShade.setter"""
        self.NoShade = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PercentWidth(self):
        return self.com_object.PercentWidth

    @PercentWidth.setter
    def PercentWidth(self, value):
        self.com_object.PercentWidth = value

    @property
    def percentwidth(self):
        """Alias for PercentWidth"""
        return self.PercentWidth

    @percentwidth.setter
    def percentwidth(self, value):
        """Alias for PercentWidth.setter"""
        self.PercentWidth = value

    @property
    def percent_width(self):
        """Alias for PercentWidth"""
        return self.PercentWidth

    @percent_width.setter
    def percent_width(self, value):
        """Alias for PercentWidth.setter"""
        self.PercentWidth = value

    @property
    def WidthType(self):
        return HorizontalLineFormat(self.com_object.WidthType)

    @WidthType.setter
    def WidthType(self, value):
        self.com_object.WidthType = value

    @property
    def widthtype(self):
        """Alias for WidthType"""
        return self.WidthType

    @widthtype.setter
    def widthtype(self, value):
        """Alias for WidthType.setter"""
        self.WidthType = value

    @property
    def width_type(self):
        """Alias for WidthType"""
        return self.WidthType

    @width_type.setter
    def width_type(self, value):
        """Alias for WidthType.setter"""
        self.WidthType = value


class HTMLDivision:

    def __init__(self, htmldivision=None):
        self.com_object= htmldivision

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def HTMLDivisions(self):
        return HTMLDivisions(self.com_object.HTMLDivisions)

    @property
    def htmldivisions(self):
        """Alias for HTMLDivisions"""
        return self.HTMLDivisions

    @property
    def h_t_m_l_divisions(self):
        """Alias for HTMLDivisions"""
        return self.HTMLDivisions

    @property
    def LeftIndent(self):
        return self.com_object.LeftIndent

    @LeftIndent.setter
    def LeftIndent(self, value):
        self.com_object.LeftIndent = value

    @property
    def leftindent(self):
        """Alias for LeftIndent"""
        return self.LeftIndent

    @leftindent.setter
    def leftindent(self, value):
        """Alias for LeftIndent.setter"""
        self.LeftIndent = value

    @property
    def left_indent(self):
        """Alias for LeftIndent"""
        return self.LeftIndent

    @left_indent.setter
    def left_indent(self, value):
        """Alias for LeftIndent.setter"""
        self.LeftIndent = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def RightIndent(self):
        return self.com_object.RightIndent

    @RightIndent.setter
    def RightIndent(self, value):
        self.com_object.RightIndent = value

    @property
    def rightindent(self):
        """Alias for RightIndent"""
        return self.RightIndent

    @rightindent.setter
    def rightindent(self, value):
        """Alias for RightIndent.setter"""
        self.RightIndent = value

    @property
    def right_indent(self):
        """Alias for RightIndent"""
        return self.RightIndent

    @right_indent.setter
    def right_indent(self, value):
        """Alias for RightIndent.setter"""
        self.RightIndent = value

    @property
    def SpaceAfter(self):
        return self.com_object.SpaceAfter

    @SpaceAfter.setter
    def SpaceAfter(self, value):
        self.com_object.SpaceAfter = value

    @property
    def spaceafter(self):
        """Alias for SpaceAfter"""
        return self.SpaceAfter

    @spaceafter.setter
    def spaceafter(self, value):
        """Alias for SpaceAfter.setter"""
        self.SpaceAfter = value

    @property
    def space_after(self):
        """Alias for SpaceAfter"""
        return self.SpaceAfter

    @space_after.setter
    def space_after(self, value):
        """Alias for SpaceAfter.setter"""
        self.SpaceAfter = value

    @property
    def SpaceBefore(self):
        return self.com_object.SpaceBefore

    @SpaceBefore.setter
    def SpaceBefore(self, value):
        self.com_object.SpaceBefore = value

    @property
    def spacebefore(self):
        """Alias for SpaceBefore"""
        return self.SpaceBefore

    @spacebefore.setter
    def spacebefore(self, value):
        """Alias for SpaceBefore.setter"""
        self.SpaceBefore = value

    @property
    def space_before(self):
        """Alias for SpaceBefore"""
        return self.SpaceBefore

    @space_before.setter
    def space_before(self, value):
        """Alias for SpaceBefore.setter"""
        self.SpaceBefore = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def HTMLDivisionParent(self, LevelsUp=None):
        arguments = com_arguments([unwrap(a) for a in [LevelsUp]])
        return HTMLDivision(self.com_object.HTMLDivisionParent(*arguments))

    def htmldivisionparent(self, LevelsUp=None):
        """Alias for HTMLDivisionParent"""
        arguments = [LevelsUp]
        return self.HTMLDivisionParent(*arguments)

    def h_t_m_l_division_parent(self, LevelsUp=None):
        """Alias for HTMLDivisionParent"""
        arguments = [LevelsUp]
        return self.HTMLDivisionParent(*arguments)


class HTMLDivisions:

    def __init__(self, htmldivisions=None):
        self.com_object= htmldivisions

    def __call__(self, item):
        return HTMLDivision(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def NestingLevel(self):
        return self.com_object.NestingLevel

    @property
    def nestinglevel(self):
        """Alias for NestingLevel"""
        return self.NestingLevel

    @property
    def nesting_level(self):
        """Alias for NestingLevel"""
        return self.NestingLevel

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        return HTMLDivision(self.com_object.Add(*arguments))

    def add(self, Range=None):
        """Alias for Add"""
        arguments = [Range]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return HTMLDivision(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Hyperlink:

    def __init__(self, hyperlink=None):
        self.com_object= hyperlink

    @property
    def Address(self):
        return self.com_object.Address

    @Address.setter
    def Address(self, value):
        self.com_object.Address = value

    @property
    def address(self):
        """Alias for Address"""
        return self.Address

    @address.setter
    def address(self, value):
        """Alias for Address.setter"""
        self.Address = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def EmailSubject(self):
        return self.com_object.EmailSubject

    @EmailSubject.setter
    def EmailSubject(self, value):
        self.com_object.EmailSubject = value

    @property
    def emailsubject(self):
        """Alias for EmailSubject"""
        return self.EmailSubject

    @emailsubject.setter
    def emailsubject(self, value):
        """Alias for EmailSubject.setter"""
        self.EmailSubject = value

    @property
    def email_subject(self):
        """Alias for EmailSubject"""
        return self.EmailSubject

    @email_subject.setter
    def email_subject(self, value):
        """Alias for EmailSubject.setter"""
        self.EmailSubject = value

    @property
    def ExtraInfoRequired(self):
        return self.com_object.ExtraInfoRequired

    @property
    def extrainforequired(self):
        """Alias for ExtraInfoRequired"""
        return self.ExtraInfoRequired

    @property
    def extra_info_required(self):
        """Alias for ExtraInfoRequired"""
        return self.ExtraInfoRequired

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def ScreenTip(self):
        return self.com_object.ScreenTip

    @ScreenTip.setter
    def ScreenTip(self, value):
        self.com_object.ScreenTip = value

    @property
    def screentip(self):
        """Alias for ScreenTip"""
        return self.ScreenTip

    @screentip.setter
    def screentip(self, value):
        """Alias for ScreenTip.setter"""
        self.ScreenTip = value

    @property
    def screen_tip(self):
        """Alias for ScreenTip"""
        return self.ScreenTip

    @screen_tip.setter
    def screen_tip(self, value):
        """Alias for ScreenTip.setter"""
        self.ScreenTip = value

    @property
    def Shape(self):
        return Shape(self.com_object.Shape)

    @property
    def shape(self):
        """Alias for Shape"""
        return self.Shape

    @property
    def SubAddress(self):
        return self.com_object.SubAddress

    @SubAddress.setter
    def SubAddress(self, value):
        self.com_object.SubAddress = value

    @property
    def subaddress(self):
        """Alias for SubAddress"""
        return self.SubAddress

    @subaddress.setter
    def subaddress(self, value):
        """Alias for SubAddress.setter"""
        self.SubAddress = value

    @property
    def sub_address(self):
        """Alias for SubAddress"""
        return self.SubAddress

    @sub_address.setter
    def sub_address(self, value):
        """Alias for SubAddress.setter"""
        self.SubAddress = value

    @property
    def Target(self):
        return self.com_object.Target

    @Target.setter
    def Target(self, value):
        self.com_object.Target = value

    @property
    def target(self):
        """Alias for Target"""
        return self.Target

    @target.setter
    def target(self, value):
        """Alias for Target.setter"""
        self.Target = value

    @property
    def TextToDisplay(self):
        return self.com_object.TextToDisplay

    @TextToDisplay.setter
    def TextToDisplay(self, value):
        self.com_object.TextToDisplay = value

    @property
    def texttodisplay(self):
        """Alias for TextToDisplay"""
        return self.TextToDisplay

    @texttodisplay.setter
    def texttodisplay(self, value):
        """Alias for TextToDisplay.setter"""
        self.TextToDisplay = value

    @property
    def text_to_display(self):
        """Alias for TextToDisplay"""
        return self.TextToDisplay

    @text_to_display.setter
    def text_to_display(self, value):
        """Alias for TextToDisplay.setter"""
        self.TextToDisplay = value

    @property
    def Type(self):
        return self.com_object.Type

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def AddToFavorites(self):
        self.com_object.AddToFavorites()

    def addtofavorites(self):
        """Alias for AddToFavorites"""
        return self.AddToFavorites()

    def add_to_favorites(self):
        """Alias for AddToFavorites"""
        return self.AddToFavorites()

    def CreateNewDocument(self, FileName=None, EditNow=None, Overwrite=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, EditNow, Overwrite]])
        self.com_object.CreateNewDocument(*arguments)

    def createnewdocument(self, FileName=None, EditNow=None, Overwrite=None):
        """Alias for CreateNewDocument"""
        arguments = [FileName, EditNow, Overwrite]
        return self.CreateNewDocument(*arguments)

    def create_new_document(self, FileName=None, EditNow=None, Overwrite=None):
        """Alias for CreateNewDocument"""
        arguments = [FileName, EditNow, Overwrite]
        return self.CreateNewDocument(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Follow(self, NewWindow=None, AddHistory=None, ExtraInfo=None, Method=None, HeaderInfo=None):
        arguments = com_arguments([unwrap(a) for a in [NewWindow, AddHistory, ExtraInfo, Method, HeaderInfo]])
        self.com_object.Follow(*arguments)

    def follow(self, NewWindow=None, AddHistory=None, ExtraInfo=None, Method=None, HeaderInfo=None):
        """Alias for Follow"""
        arguments = [NewWindow, AddHistory, ExtraInfo, Method, HeaderInfo]
        return self.Follow(*arguments)


class Hyperlinks:

    def __init__(self, hyperlinks=None):
        self.com_object= hyperlinks

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Anchor=None, Address=None, SubAddress=None, ScreenTip=None, TextToDisplay=None, Target=None):
        arguments = com_arguments([unwrap(a) for a in [Anchor, Address, SubAddress, ScreenTip, TextToDisplay, Target]])
        return Hyperlink(self.com_object.Add(*arguments))

    def add(self, Anchor=None, Address=None, SubAddress=None, ScreenTip=None, TextToDisplay=None, Target=None):
        """Alias for Add"""
        arguments = [Anchor, Address, SubAddress, ScreenTip, TextToDisplay, Target]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Hyperlink(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Index:

    def __init__(self, index=None):
        self.com_object= index

    @property
    def AccentedLetters(self):
        return self.com_object.AccentedLetters

    @AccentedLetters.setter
    def AccentedLetters(self, value):
        self.com_object.AccentedLetters = value

    @property
    def accentedletters(self):
        """Alias for AccentedLetters"""
        return self.AccentedLetters

    @accentedletters.setter
    def accentedletters(self, value):
        """Alias for AccentedLetters.setter"""
        self.AccentedLetters = value

    @property
    def accented_letters(self):
        """Alias for AccentedLetters"""
        return self.AccentedLetters

    @accented_letters.setter
    def accented_letters(self, value):
        """Alias for AccentedLetters.setter"""
        self.AccentedLetters = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Filter(self):
        return self.com_object.Filter

    @Filter.setter
    def Filter(self, value):
        self.com_object.Filter = value

    @property
    def filter(self):
        """Alias for Filter"""
        return self.Filter

    @filter.setter
    def filter(self, value):
        """Alias for Filter.setter"""
        self.Filter = value

    @property
    def HeadingSeparator(self):
        return WdHeadingSeparator(self.com_object.HeadingSeparator)

    @HeadingSeparator.setter
    def HeadingSeparator(self, value):
        self.com_object.HeadingSeparator = value

    @property
    def headingseparator(self):
        """Alias for HeadingSeparator"""
        return self.HeadingSeparator

    @headingseparator.setter
    def headingseparator(self, value):
        """Alias for HeadingSeparator.setter"""
        self.HeadingSeparator = value

    @property
    def heading_separator(self):
        """Alias for HeadingSeparator"""
        return self.HeadingSeparator

    @heading_separator.setter
    def heading_separator(self, value):
        """Alias for HeadingSeparator.setter"""
        self.HeadingSeparator = value

    @property
    def IndexLanguage(self):
        return WdLanguageID(self.com_object.IndexLanguage)

    @IndexLanguage.setter
    def IndexLanguage(self, value):
        self.com_object.IndexLanguage = value

    @property
    def indexlanguage(self):
        """Alias for IndexLanguage"""
        return self.IndexLanguage

    @indexlanguage.setter
    def indexlanguage(self, value):
        """Alias for IndexLanguage.setter"""
        self.IndexLanguage = value

    @property
    def index_language(self):
        """Alias for IndexLanguage"""
        return self.IndexLanguage

    @index_language.setter
    def index_language(self, value):
        """Alias for IndexLanguage.setter"""
        self.IndexLanguage = value

    @property
    def NumberOfColumns(self):
        return self.com_object.NumberOfColumns

    @NumberOfColumns.setter
    def NumberOfColumns(self, value):
        self.com_object.NumberOfColumns = value

    @property
    def numberofcolumns(self):
        """Alias for NumberOfColumns"""
        return self.NumberOfColumns

    @numberofcolumns.setter
    def numberofcolumns(self, value):
        """Alias for NumberOfColumns.setter"""
        self.NumberOfColumns = value

    @property
    def number_of_columns(self):
        """Alias for NumberOfColumns"""
        return self.NumberOfColumns

    @number_of_columns.setter
    def number_of_columns(self, value):
        """Alias for NumberOfColumns.setter"""
        self.NumberOfColumns = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def RightAlignPageNumbers(self):
        return self.com_object.RightAlignPageNumbers

    @RightAlignPageNumbers.setter
    def RightAlignPageNumbers(self, value):
        self.com_object.RightAlignPageNumbers = value

    @property
    def rightalignpagenumbers(self):
        """Alias for RightAlignPageNumbers"""
        return self.RightAlignPageNumbers

    @rightalignpagenumbers.setter
    def rightalignpagenumbers(self, value):
        """Alias for RightAlignPageNumbers.setter"""
        self.RightAlignPageNumbers = value

    @property
    def right_align_page_numbers(self):
        """Alias for RightAlignPageNumbers"""
        return self.RightAlignPageNumbers

    @right_align_page_numbers.setter
    def right_align_page_numbers(self, value):
        """Alias for RightAlignPageNumbers.setter"""
        self.RightAlignPageNumbers = value

    @property
    def SortBy(self):
        return WdIndexSortBy(self.com_object.SortBy)

    @SortBy.setter
    def SortBy(self, value):
        self.com_object.SortBy = value

    @property
    def sortby(self):
        """Alias for SortBy"""
        return self.SortBy

    @sortby.setter
    def sortby(self, value):
        """Alias for SortBy.setter"""
        self.SortBy = value

    @property
    def sort_by(self):
        """Alias for SortBy"""
        return self.SortBy

    @sort_by.setter
    def sort_by(self, value):
        """Alias for SortBy.setter"""
        self.SortBy = value

    @property
    def TabLeader(self):
        return WdTabLeader(self.com_object.TabLeader)

    @TabLeader.setter
    def TabLeader(self, value):
        self.com_object.TabLeader = value

    @property
    def tableader(self):
        """Alias for TabLeader"""
        return self.TabLeader

    @tableader.setter
    def tableader(self, value):
        """Alias for TabLeader.setter"""
        self.TabLeader = value

    @property
    def tab_leader(self):
        """Alias for TabLeader"""
        return self.TabLeader

    @tab_leader.setter
    def tab_leader(self, value):
        """Alias for TabLeader.setter"""
        self.TabLeader = value

    @property
    def Type(self):
        return WdIndexType(self.com_object.Type)

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Update(self):
        self.com_object.Update()

    def update(self):
        """Alias for Update"""
        return self.Update()


class Indexes:

    def __init__(self, indexes=None):
        self.com_object= indexes

    def __call__(self, item):
        return Indexe(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return WdIndexFormat(self.com_object.Format)

    @Format.setter
    def Format(self, value):
        self.com_object.Format = value

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @format.setter
    def format(self, value):
        """Alias for Format.setter"""
        self.Format = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Range=None, HeadingSeparator=None, RightAlignPageNumbers=None, Type=None, NumberOfColumns=None, AccentedLetters=None, SortBy=None, IndexLanguage=None):
        arguments = com_arguments([unwrap(a) for a in [Range, HeadingSeparator, RightAlignPageNumbers, Type, NumberOfColumns, AccentedLetters, SortBy, IndexLanguage]])
        return Index(self.com_object.Add(*arguments))

    def add(self, Range=None, HeadingSeparator=None, RightAlignPageNumbers=None, Type=None, NumberOfColumns=None, AccentedLetters=None, SortBy=None, IndexLanguage=None):
        """Alias for Add"""
        arguments = [Range, HeadingSeparator, RightAlignPageNumbers, Type, NumberOfColumns, AccentedLetters, SortBy, IndexLanguage]
        return self.Add(*arguments)

    def AutoMarkEntries(self, ConcordanceFileName=None):
        arguments = com_arguments([unwrap(a) for a in [ConcordanceFileName]])
        self.com_object.AutoMarkEntries(*arguments)

    def automarkentries(self, ConcordanceFileName=None):
        """Alias for AutoMarkEntries"""
        arguments = [ConcordanceFileName]
        return self.AutoMarkEntries(*arguments)

    def auto_mark_entries(self, ConcordanceFileName=None):
        """Alias for AutoMarkEntries"""
        arguments = [ConcordanceFileName]
        return self.AutoMarkEntries(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Index(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def MarkAllEntries(self, Range=None, Entry=None, EntryAutoText=None, CrossReference=None, CrossReferenceAutoText=None, BookmarkName=None, Bold=None, Italic=None):
        arguments = com_arguments([unwrap(a) for a in [Range, Entry, EntryAutoText, CrossReference, CrossReferenceAutoText, BookmarkName, Bold, Italic]])
        self.com_object.MarkAllEntries(*arguments)

    def markallentries(self, Range=None, Entry=None, EntryAutoText=None, CrossReference=None, CrossReferenceAutoText=None, BookmarkName=None, Bold=None, Italic=None):
        """Alias for MarkAllEntries"""
        arguments = [Range, Entry, EntryAutoText, CrossReference, CrossReferenceAutoText, BookmarkName, Bold, Italic]
        return self.MarkAllEntries(*arguments)

    def mark_all_entries(self, Range=None, Entry=None, EntryAutoText=None, CrossReference=None, CrossReferenceAutoText=None, BookmarkName=None, Bold=None, Italic=None):
        """Alias for MarkAllEntries"""
        arguments = [Range, Entry, EntryAutoText, CrossReference, CrossReferenceAutoText, BookmarkName, Bold, Italic]
        return self.MarkAllEntries(*arguments)

    def MarkEntry(self, Range=None, Entry=None, EntryAutoText=None, CrossReference=None, CrossReferenceAutoText=None, BookmarkName=None, Bold=None, Italic=None, Reading=None):
        arguments = com_arguments([unwrap(a) for a in [Range, Entry, EntryAutoText, CrossReference, CrossReferenceAutoText, BookmarkName, Bold, Italic, Reading]])
        return Field(self.com_object.MarkEntry(*arguments))

    def markentry(self, Range=None, Entry=None, EntryAutoText=None, CrossReference=None, CrossReferenceAutoText=None, BookmarkName=None, Bold=None, Italic=None, Reading=None):
        """Alias for MarkEntry"""
        arguments = [Range, Entry, EntryAutoText, CrossReference, CrossReferenceAutoText, BookmarkName, Bold, Italic, Reading]
        return self.MarkEntry(*arguments)

    def mark_entry(self, Range=None, Entry=None, EntryAutoText=None, CrossReference=None, CrossReferenceAutoText=None, BookmarkName=None, Bold=None, Italic=None, Reading=None):
        """Alias for MarkEntry"""
        arguments = [Range, Entry, EntryAutoText, CrossReference, CrossReferenceAutoText, BookmarkName, Bold, Italic, Reading]
        return self.MarkEntry(*arguments)


class InlineShape:

    def __init__(self, inlineshape=None):
        self.com_object= inlineshape

    @property
    def AlternativeText(self):
        return self.com_object.AlternativeText

    @AlternativeText.setter
    def AlternativeText(self, value):
        self.com_object.AlternativeText = value

    @property
    def alternativetext(self):
        """Alias for AlternativeText"""
        return self.AlternativeText

    @alternativetext.setter
    def alternativetext(self, value):
        """Alias for AlternativeText.setter"""
        self.AlternativeText = value

    @property
    def alternative_text(self):
        """Alias for AlternativeText"""
        return self.AlternativeText

    @alternative_text.setter
    def alternative_text(self, value):
        """Alias for AlternativeText.setter"""
        self.AlternativeText = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def Chart(self):
        return Chart(self.com_object.Chart)

    @property
    def chart(self):
        """Alias for Chart"""
        return self.Chart

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Field(self):
        return Field(self.com_object.Field)

    @property
    def field(self):
        """Alias for Field"""
        return self.Field

    @property
    def Fill(self):
        return FillFormat(self.com_object.Fill)

    @property
    def fill(self):
        """Alias for Fill"""
        return self.Fill

    @property
    def Glow(self):
        return GlowFormat(self.com_object.Glow)

    @property
    def glow(self):
        """Alias for Glow"""
        return self.Glow

    @property
    def GroupItems(self):
        return GroupShapes(self.com_object.GroupItems)

    @property
    def groupitems(self):
        """Alias for GroupItems"""
        return self.GroupItems

    @property
    def group_items(self):
        """Alias for GroupItems"""
        return self.GroupItems

    @property
    def HasChart(self):
        return self.com_object.HasChart

    @property
    def haschart(self):
        """Alias for HasChart"""
        return self.HasChart

    @property
    def has_chart(self):
        """Alias for HasChart"""
        return self.HasChart

    @property
    def HasSmartArt(self):
        return self.com_object.HasSmartArt

    @property
    def hassmartart(self):
        """Alias for HasSmartArt"""
        return self.HasSmartArt

    @property
    def has_smart_art(self):
        """Alias for HasSmartArt"""
        return self.HasSmartArt

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HorizontalLineFormat(self):
        return HorizontalLineFormat(self.com_object.HorizontalLineFormat)

    @property
    def horizontallineformat(self):
        """Alias for HorizontalLineFormat"""
        return self.HorizontalLineFormat

    @property
    def horizontal_line_format(self):
        """Alias for HorizontalLineFormat"""
        return self.HorizontalLineFormat

    @property
    def Hyperlink(self):
        return Hyperlink(self.com_object.Hyperlink)

    @property
    def hyperlink(self):
        """Alias for Hyperlink"""
        return self.Hyperlink

    @property
    def IsPictureBullet(self):
        return self.com_object.IsPictureBullet

    @property
    def ispicturebullet(self):
        """Alias for IsPictureBullet"""
        return self.IsPictureBullet

    @property
    def is_picture_bullet(self):
        """Alias for IsPictureBullet"""
        return self.IsPictureBullet

    @property
    def Line(self):
        return LineFormat(self.com_object.Line)

    @property
    def line(self):
        """Alias for Line"""
        return self.Line

    @property
    def LinkFormat(self):
        return LinkFormat(self.com_object.LinkFormat)

    @property
    def linkformat(self):
        """Alias for LinkFormat"""
        return self.LinkFormat

    @property
    def link_format(self):
        """Alias for LinkFormat"""
        return self.LinkFormat

    @property
    def LockAspectRatio(self):
        return self.com_object.LockAspectRatio

    @LockAspectRatio.setter
    def LockAspectRatio(self, value):
        self.com_object.LockAspectRatio = value

    @property
    def lockaspectratio(self):
        """Alias for LockAspectRatio"""
        return self.LockAspectRatio

    @lockaspectratio.setter
    def lockaspectratio(self, value):
        """Alias for LockAspectRatio.setter"""
        self.LockAspectRatio = value

    @property
    def lock_aspect_ratio(self):
        """Alias for LockAspectRatio"""
        return self.LockAspectRatio

    @lock_aspect_ratio.setter
    def lock_aspect_ratio(self, value):
        """Alias for LockAspectRatio.setter"""
        self.LockAspectRatio = value

    @property
    def OLEFormat(self):
        return OLEFormat(self.com_object.OLEFormat)

    @property
    def oleformat(self):
        """Alias for OLEFormat"""
        return self.OLEFormat

    @property
    def o_l_e_format(self):
        """Alias for OLEFormat"""
        return self.OLEFormat

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PictureFormat(self):
        return PictureFormat(self.com_object.PictureFormat)

    @property
    def pictureformat(self):
        """Alias for PictureFormat"""
        return self.PictureFormat

    @property
    def picture_format(self):
        """Alias for PictureFormat"""
        return self.PictureFormat

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def Reflection(self):
        return ReflectionFormat(self.com_object.Reflection)

    @property
    def reflection(self):
        """Alias for Reflection"""
        return self.Reflection

    @property
    def ScaleHeight(self):
        return self.com_object.ScaleHeight

    @ScaleHeight.setter
    def ScaleHeight(self, value):
        self.com_object.ScaleHeight = value

    @property
    def scaleheight(self):
        """Alias for ScaleHeight"""
        return self.ScaleHeight

    @scaleheight.setter
    def scaleheight(self, value):
        """Alias for ScaleHeight.setter"""
        self.ScaleHeight = value

    @property
    def scale_height(self):
        """Alias for ScaleHeight"""
        return self.ScaleHeight

    @scale_height.setter
    def scale_height(self, value):
        """Alias for ScaleHeight.setter"""
        self.ScaleHeight = value

    @property
    def ScaleWidth(self):
        return self.com_object.ScaleWidth

    @ScaleWidth.setter
    def ScaleWidth(self, value):
        self.com_object.ScaleWidth = value

    @property
    def scalewidth(self):
        """Alias for ScaleWidth"""
        return self.ScaleWidth

    @scalewidth.setter
    def scalewidth(self, value):
        """Alias for ScaleWidth.setter"""
        self.ScaleWidth = value

    @property
    def scale_width(self):
        """Alias for ScaleWidth"""
        return self.ScaleWidth

    @scale_width.setter
    def scale_width(self, value):
        """Alias for ScaleWidth.setter"""
        self.ScaleWidth = value

    @property
    def Script(self):
        return self.com_object.Script

    @property
    def script(self):
        """Alias for Script"""
        return self.Script

    @property
    def Shadow(self):
        return ShadowFormat(self.com_object.Shadow)

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @property
    def SmartArt(self):
        return self.com_object.SmartArt

    @property
    def smartart(self):
        """Alias for SmartArt"""
        return self.SmartArt

    @property
    def smart_art(self):
        """Alias for SmartArt"""
        return self.SmartArt

    @property
    def SoftEdge(self):
        return SoftEdgeFormat(self.com_object.SoftEdge)

    @property
    def softedge(self):
        """Alias for SoftEdge"""
        return self.SoftEdge

    @property
    def soft_edge(self):
        """Alias for SoftEdge"""
        return self.SoftEdge

    @property
    def TextEffect(self):
        return TextEffectFormat(self.com_object.TextEffect)

    @property
    def texteffect(self):
        """Alias for TextEffect"""
        return self.TextEffect

    @property
    def text_effect(self):
        """Alias for TextEffect"""
        return self.TextEffect

    @property
    def Title(self):
        return self.com_object.Title

    @Title.setter
    def Title(self, value):
        self.com_object.Title = value

    @property
    def title(self):
        """Alias for Title"""
        return self.Title

    @title.setter
    def title(self, value):
        """Alias for Title.setter"""
        self.Title = value

    @property
    def Type(self):
        return WdInlineShapeType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def ConvertToShape(self):
        self.com_object.ConvertToShape()

    def converttoshape(self):
        """Alias for ConvertToShape"""
        return self.ConvertToShape()

    def convert_to_shape(self):
        """Alias for ConvertToShape"""
        return self.ConvertToShape()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Reset(self):
        self.com_object.Reset()

    def reset(self):
        """Alias for Reset"""
        return self.Reset()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class InlineShapes:

    def __init__(self, inlineshapes=None):
        self.com_object= inlineshapes

    def __call__(self, item):
        return InlineShape(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def AddChart2(self, Style=None, Type=None, Range=None, NewLayout=None):
        arguments = com_arguments([unwrap(a) for a in [Style, Type, Range, NewLayout]])
        return INLINESHAPE(self.com_object.AddChart2(*arguments))

    def addchart2(self, Style=None, Type=None, Range=None, NewLayout=None):
        """Alias for AddChart2"""
        arguments = [Style, Type, Range, NewLayout]
        return self.AddChart2(*arguments)

    def add_chart2(self, Style=None, Type=None, Range=None, NewLayout=None):
        """Alias for AddChart2"""
        arguments = [Style, Type, Range, NewLayout]
        return self.AddChart2(*arguments)

    def AddHorizontalLine(self, FileName=None, Range=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, Range]])
        self.com_object.AddHorizontalLine(*arguments)

    def addhorizontalline(self, FileName=None, Range=None):
        """Alias for AddHorizontalLine"""
        arguments = [FileName, Range]
        return self.AddHorizontalLine(*arguments)

    def add_horizontal_line(self, FileName=None, Range=None):
        """Alias for AddHorizontalLine"""
        arguments = [FileName, Range]
        return self.AddHorizontalLine(*arguments)

    def AddHorizontalLineStandard(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        self.com_object.AddHorizontalLineStandard(*arguments)

    def addhorizontallinestandard(self, Range=None):
        """Alias for AddHorizontalLineStandard"""
        arguments = [Range]
        return self.AddHorizontalLineStandard(*arguments)

    def add_horizontal_line_standard(self, Range=None):
        """Alias for AddHorizontalLineStandard"""
        arguments = [Range]
        return self.AddHorizontalLineStandard(*arguments)

    def AddOLEControl(self, ClassType=None, Range=None):
        arguments = com_arguments([unwrap(a) for a in [ClassType, Range]])
        self.com_object.AddOLEControl(*arguments)

    def addolecontrol(self, ClassType=None, Range=None):
        """Alias for AddOLEControl"""
        arguments = [ClassType, Range]
        return self.AddOLEControl(*arguments)

    def add_o_l_e_control(self, ClassType=None, Range=None):
        """Alias for AddOLEControl"""
        arguments = [ClassType, Range]
        return self.AddOLEControl(*arguments)

    def AddOLEObject(self, ClassType=None, FileName=None, LinkToFile=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, Range=None):
        arguments = com_arguments([unwrap(a) for a in [ClassType, FileName, LinkToFile, DisplayAsIcon, IconFileName, IconIndex, IconLabel, Range]])
        self.com_object.AddOLEObject(*arguments)

    def addoleobject(self, ClassType=None, FileName=None, LinkToFile=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, Range=None):
        """Alias for AddOLEObject"""
        arguments = [ClassType, FileName, LinkToFile, DisplayAsIcon, IconFileName, IconIndex, IconLabel, Range]
        return self.AddOLEObject(*arguments)

    def add_o_l_e_object(self, ClassType=None, FileName=None, LinkToFile=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, Range=None):
        """Alias for AddOLEObject"""
        arguments = [ClassType, FileName, LinkToFile, DisplayAsIcon, IconFileName, IconIndex, IconLabel, Range]
        return self.AddOLEObject(*arguments)

    def AddPicture(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Range=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, LinkToFile, SaveWithDocument, Range]])
        self.com_object.AddPicture(*arguments)

    def addpicture(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Range=None):
        """Alias for AddPicture"""
        arguments = [FileName, LinkToFile, SaveWithDocument, Range]
        return self.AddPicture(*arguments)

    def add_picture(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Range=None):
        """Alias for AddPicture"""
        arguments = [FileName, LinkToFile, SaveWithDocument, Range]
        return self.AddPicture(*arguments)

    def AddPictureBullet(self, FileName=None, Range=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, Range]])
        return InlineShape(self.com_object.AddPictureBullet(*arguments))

    def addpicturebullet(self, FileName=None, Range=None):
        """Alias for AddPictureBullet"""
        arguments = [FileName, Range]
        return self.AddPictureBullet(*arguments)

    def add_picture_bullet(self, FileName=None, Range=None):
        """Alias for AddPictureBullet"""
        arguments = [FileName, Range]
        return self.AddPictureBullet(*arguments)

    def AddSmartArt(self, Layout=None, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Layout, Range]])
        return InlineShape(self.com_object.AddSmartArt(*arguments))

    def addsmartart(self, Layout=None, Range=None):
        """Alias for AddSmartArt"""
        arguments = [Layout, Range]
        return self.AddSmartArt(*arguments)

    def add_smart_art(self, Layout=None, Range=None):
        """Alias for AddSmartArt"""
        arguments = [Layout, Range]
        return self.AddSmartArt(*arguments)

    def AddWebVideo(self, EmbedCode=None, VideoWidth=None, VideoHeight=None, PosterFrameImage=None, Url=None, Range=None):
        arguments = com_arguments([unwrap(a) for a in [EmbedCode, VideoWidth, VideoHeight, PosterFrameImage, Url, Range]])
        return INLINESHAPE(self.com_object.AddWebVideo(*arguments))

    def addwebvideo(self, EmbedCode=None, VideoWidth=None, VideoHeight=None, PosterFrameImage=None, Url=None, Range=None):
        """Alias for AddWebVideo"""
        arguments = [EmbedCode, VideoWidth, VideoHeight, PosterFrameImage, Url, Range]
        return self.AddWebVideo(*arguments)

    def add_web_video(self, EmbedCode=None, VideoWidth=None, VideoHeight=None, PosterFrameImage=None, Url=None, Range=None):
        """Alias for AddWebVideo"""
        arguments = [EmbedCode, VideoWidth, VideoHeight, PosterFrameImage, Url, Range]
        return self.AddWebVideo(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return InlineShape(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def New(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        return InlineShape(self.com_object.New(*arguments))

    def new(self, Range=None):
        """Alias for New"""
        arguments = [Range]
        return self.New(*arguments)


class Interior:

    def __init__(self, interior=None):
        self.com_object= interior

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Color(self):
        return self.com_object.Color

    @Color.setter
    def Color(self, value):
        self.com_object.Color = value

    @property
    def color(self):
        """Alias for Color"""
        return self.Color

    @color.setter
    def color(self, value):
        """Alias for Color.setter"""
        self.Color = value

    @property
    def ColorIndex(self):
        return self.com_object.ColorIndex

    @ColorIndex.setter
    def ColorIndex(self, value):
        self.com_object.ColorIndex = value

    @property
    def colorindex(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @colorindex.setter
    def colorindex(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def color_index(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @color_index.setter
    def color_index(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def InvertIfNegative(self):
        return self.com_object.InvertIfNegative

    @InvertIfNegative.setter
    def InvertIfNegative(self, value):
        self.com_object.InvertIfNegative = value

    @property
    def invertifnegative(self):
        """Alias for InvertIfNegative"""
        return self.InvertIfNegative

    @invertifnegative.setter
    def invertifnegative(self, value):
        """Alias for InvertIfNegative.setter"""
        self.InvertIfNegative = value

    @property
    def invert_if_negative(self):
        """Alias for InvertIfNegative"""
        return self.InvertIfNegative

    @invert_if_negative.setter
    def invert_if_negative(self, value):
        """Alias for InvertIfNegative.setter"""
        self.InvertIfNegative = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Pattern(self):
        return XlPattern(self.com_object.Pattern)

    @Pattern.setter
    def Pattern(self, value):
        self.com_object.Pattern = value

    @property
    def pattern(self):
        """Alias for Pattern"""
        return self.Pattern

    @pattern.setter
    def pattern(self, value):
        """Alias for Pattern.setter"""
        self.Pattern = value

    @property
    def PatternColor(self):
        return self.com_object.PatternColor

    @PatternColor.setter
    def PatternColor(self, value):
        self.com_object.PatternColor = value

    @property
    def patterncolor(self):
        """Alias for PatternColor"""
        return self.PatternColor

    @patterncolor.setter
    def patterncolor(self, value):
        """Alias for PatternColor.setter"""
        self.PatternColor = value

    @property
    def pattern_color(self):
        """Alias for PatternColor"""
        return self.PatternColor

    @pattern_color.setter
    def pattern_color(self, value):
        """Alias for PatternColor.setter"""
        self.PatternColor = value

    @property
    def PatternColorIndex(self):
        return XlColorIndex(self.com_object.PatternColorIndex)

    @PatternColorIndex.setter
    def PatternColorIndex(self, value):
        self.com_object.PatternColorIndex = value

    @property
    def patterncolorindex(self):
        """Alias for PatternColorIndex"""
        return self.PatternColorIndex

    @patterncolorindex.setter
    def patterncolorindex(self, value):
        """Alias for PatternColorIndex.setter"""
        self.PatternColorIndex = value

    @property
    def pattern_color_index(self):
        """Alias for PatternColorIndex"""
        return self.PatternColorIndex

    @pattern_color_index.setter
    def pattern_color_index(self, value):
        """Alias for PatternColorIndex.setter"""
        self.PatternColorIndex = value


class KeyBinding:

    def __init__(self, keybinding=None):
        self.com_object= keybinding

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Command(self):
        return self.com_object.Command

    @property
    def command(self):
        """Alias for Command"""
        return self.Command

    @property
    def CommandParameter(self):
        return self.com_object.CommandParameter

    @property
    def commandparameter(self):
        """Alias for CommandParameter"""
        return self.CommandParameter

    @property
    def command_parameter(self):
        """Alias for CommandParameter"""
        return self.CommandParameter

    @property
    def Context(self):
        return self.com_object.Context

    @property
    def context(self):
        """Alias for Context"""
        return self.Context

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def KeyCategory(self):
        return WdKeyCategory(self.com_object.KeyCategory)

    @property
    def keycategory(self):
        """Alias for KeyCategory"""
        return self.KeyCategory

    @property
    def key_category(self):
        """Alias for KeyCategory"""
        return self.KeyCategory

    @property
    def KeyCode(self):
        return self.com_object.KeyCode

    @property
    def keycode(self):
        """Alias for KeyCode"""
        return self.KeyCode

    @property
    def key_code(self):
        """Alias for KeyCode"""
        return self.KeyCode

    @property
    def KeyCode2(self):
        return self.com_object.KeyCode2

    @property
    def keycode2(self):
        """Alias for KeyCode2"""
        return self.KeyCode2

    @property
    def key_code2(self):
        """Alias for KeyCode2"""
        return self.KeyCode2

    @property
    def KeyString(self):
        return self.com_object.KeyString

    @property
    def keystring(self):
        """Alias for KeyString"""
        return self.KeyString

    @property
    def key_string(self):
        """Alias for KeyString"""
        return self.KeyString

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Protected(self):
        return self.com_object.Protected

    @property
    def protected(self):
        """Alias for Protected"""
        return self.Protected

    def Clear(self):
        self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()

    def Disable(self):
        self.com_object.Disable()

    def disable(self):
        """Alias for Disable"""
        return self.Disable()

    def Execute(self):
        self.com_object.Execute()

    def execute(self):
        """Alias for Execute"""
        return self.Execute()

    def Rebind(self, KeyCategory=None, Command=None, CommandParameter=None):
        arguments = com_arguments([unwrap(a) for a in [KeyCategory, Command, CommandParameter]])
        self.com_object.Rebind(*arguments)

    def rebind(self, KeyCategory=None, Command=None, CommandParameter=None):
        """Alias for Rebind"""
        arguments = [KeyCategory, Command, CommandParameter]
        return self.Rebind(*arguments)


class KeyBindings:

    def __init__(self, keybindings=None):
        self.com_object= keybindings

    def __call__(self, item):
        return KeyBinding(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Context(self):
        return self.com_object.Context

    @property
    def context(self):
        """Alias for Context"""
        return self.Context

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, KeyCategory=None, Command=None, KeyCode=None, KeyCode2=None, CommandParameter=None):
        arguments = com_arguments([unwrap(a) for a in [KeyCategory, Command, KeyCode, KeyCode2, CommandParameter]])
        return KeyBinding(self.com_object.Add(*arguments))

    def add(self, KeyCategory=None, Command=None, KeyCode=None, KeyCode2=None, CommandParameter=None):
        """Alias for Add"""
        arguments = [KeyCategory, Command, KeyCode, KeyCode2, CommandParameter]
        return self.Add(*arguments)

    def ClearAll(self):
        self.com_object.ClearAll()

    def clearall(self):
        """Alias for ClearAll"""
        return self.ClearAll()

    def clear_all(self):
        """Alias for ClearAll"""
        return self.ClearAll()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return KeyBinding(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Key(self, KeyCode=None, KeyCode2=None):
        arguments = com_arguments([unwrap(a) for a in [KeyCode, KeyCode2]])
        return KeyBinding(self.com_object.Key(*arguments))

    def key(self, KeyCode=None, KeyCode2=None):
        """Alias for Key"""
        arguments = [KeyCode, KeyCode2]
        return self.Key(*arguments)


class KeysBoundTo:

    def __init__(self, keysboundto=None):
        self.com_object= keysboundto

    def __call__(self, item):
        return KeysBoundTo(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Command(self):
        return self.com_object.Command

    @property
    def command(self):
        """Alias for Command"""
        return self.Command

    @property
    def CommandParameter(self):
        return self.com_object.CommandParameter

    @property
    def commandparameter(self):
        """Alias for CommandParameter"""
        return self.CommandParameter

    @property
    def command_parameter(self):
        """Alias for CommandParameter"""
        return self.CommandParameter

    @property
    def Context(self):
        return self.com_object.Context

    @property
    def context(self):
        """Alias for Context"""
        return self.Context

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def KeyCategory(self):
        return WdKeyCategory(self.com_object.KeyCategory)

    @property
    def keycategory(self):
        """Alias for KeyCategory"""
        return self.KeyCategory

    @property
    def key_category(self):
        """Alias for KeyCategory"""
        return self.KeyCategory

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return KeyBinding(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Key(self, KeyCode=None, KeyCode2=None):
        arguments = com_arguments([unwrap(a) for a in [KeyCode, KeyCode2]])
        return KeyBinding(self.com_object.Key(*arguments))

    def key(self, KeyCode=None, KeyCode2=None):
        """Alias for Key"""
        arguments = [KeyCode, KeyCode2]
        return self.Key(*arguments)


class Language:

    def __init__(self, language=None):
        self.com_object= language

    @property
    def ActiveGrammarDictionary(self):
        return Dictionary(self.com_object.ActiveGrammarDictionary)

    @property
    def activegrammardictionary(self):
        """Alias for ActiveGrammarDictionary"""
        return self.ActiveGrammarDictionary

    @property
    def active_grammar_dictionary(self):
        """Alias for ActiveGrammarDictionary"""
        return self.ActiveGrammarDictionary

    @property
    def ActiveHyphenationDictionary(self):
        return Dictionary(self.com_object.ActiveHyphenationDictionary)

    @property
    def activehyphenationdictionary(self):
        """Alias for ActiveHyphenationDictionary"""
        return self.ActiveHyphenationDictionary

    @property
    def active_hyphenation_dictionary(self):
        """Alias for ActiveHyphenationDictionary"""
        return self.ActiveHyphenationDictionary

    @property
    def ActiveSpellingDictionary(self):
        return Dictionary(self.com_object.ActiveSpellingDictionary)

    @property
    def activespellingdictionary(self):
        """Alias for ActiveSpellingDictionary"""
        return self.ActiveSpellingDictionary

    @property
    def active_spelling_dictionary(self):
        """Alias for ActiveSpellingDictionary"""
        return self.ActiveSpellingDictionary

    @property
    def ActiveThesaurusDictionary(self):
        return Dictionary(self.com_object.ActiveThesaurusDictionary)

    @property
    def activethesaurusdictionary(self):
        """Alias for ActiveThesaurusDictionary"""
        return self.ActiveThesaurusDictionary

    @property
    def active_thesaurus_dictionary(self):
        """Alias for ActiveThesaurusDictionary"""
        return self.ActiveThesaurusDictionary

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DefaultWritingStyle(self):
        return self.com_object.DefaultWritingStyle

    @DefaultWritingStyle.setter
    def DefaultWritingStyle(self, value):
        self.com_object.DefaultWritingStyle = value

    @property
    def defaultwritingstyle(self):
        """Alias for DefaultWritingStyle"""
        return self.DefaultWritingStyle

    @defaultwritingstyle.setter
    def defaultwritingstyle(self, value):
        """Alias for DefaultWritingStyle.setter"""
        self.DefaultWritingStyle = value

    @property
    def default_writing_style(self):
        """Alias for DefaultWritingStyle"""
        return self.DefaultWritingStyle

    @default_writing_style.setter
    def default_writing_style(self, value):
        """Alias for DefaultWritingStyle.setter"""
        self.DefaultWritingStyle = value

    @property
    def ID(self):
        return WdLanguageID(self.com_object.ID)

    @property
    def id(self):
        """Alias for ID"""
        return self.ID

    @property
    def i_d(self):
        """Alias for ID"""
        return self.ID

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NameLocal(self):
        return self.com_object.NameLocal

    @property
    def namelocal(self):
        """Alias for NameLocal"""
        return self.NameLocal

    @property
    def name_local(self):
        """Alias for NameLocal"""
        return self.NameLocal

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SpellingDictionaryType(self):
        return WdDictionaryType(self.com_object.SpellingDictionaryType)

    @SpellingDictionaryType.setter
    def SpellingDictionaryType(self, value):
        self.com_object.SpellingDictionaryType = value

    @property
    def spellingdictionarytype(self):
        """Alias for SpellingDictionaryType"""
        return self.SpellingDictionaryType

    @spellingdictionarytype.setter
    def spellingdictionarytype(self, value):
        """Alias for SpellingDictionaryType.setter"""
        self.SpellingDictionaryType = value

    @property
    def spelling_dictionary_type(self):
        """Alias for SpellingDictionaryType"""
        return self.SpellingDictionaryType

    @spelling_dictionary_type.setter
    def spelling_dictionary_type(self, value):
        """Alias for SpellingDictionaryType.setter"""
        self.SpellingDictionaryType = value

    @property
    def WritingStyleList(self):
        return self.com_object.WritingStyleList

    @property
    def writingstylelist(self):
        """Alias for WritingStyleList"""
        return self.WritingStyleList

    @property
    def writing_style_list(self):
        """Alias for WritingStyleList"""
        return self.WritingStyleList


class Languages:

    def __init__(self, languages=None):
        self.com_object= languages

    def __call__(self, item):
        return Language(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Language(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class LeaderLines:

    def __init__(self, leaderlines=None):
        self.com_object= leaderlines

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Border(self):
        return ChartBorder(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Legend:

    def __init__(self, legend=None):
        self.com_object= legend

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def IncludeInLayout(self):
        return self.com_object.IncludeInLayout

    @IncludeInLayout.setter
    def IncludeInLayout(self, value):
        self.com_object.IncludeInLayout = value

    @property
    def includeinlayout(self):
        """Alias for IncludeInLayout"""
        return self.IncludeInLayout

    @includeinlayout.setter
    def includeinlayout(self, value):
        """Alias for IncludeInLayout.setter"""
        self.IncludeInLayout = value

    @property
    def include_in_layout(self):
        """Alias for IncludeInLayout"""
        return self.IncludeInLayout

    @include_in_layout.setter
    def include_in_layout(self, value):
        """Alias for IncludeInLayout.setter"""
        self.IncludeInLayout = value

    @property
    def Left(self):
        return self.com_object.Left

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return XlLegendPosition(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Clear(self):
        self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def LegendEntries(self):
        return LegendEntries(self.com_object.LegendEntries())

    def legendentries(self):
        """Alias for LegendEntries"""
        return self.LegendEntries()

    def legend_entries(self):
        """Alias for LegendEntries"""
        return self.LegendEntries()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class LegendEntries:

    def __init__(self, legendentries=None):
        self.com_object= legendentries

    def __call__(self, item):
        return LegendEntrie(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return LegendEntry(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class LegendEntry:

    def __init__(self, legendentry=None):
        self.com_object= legendentry

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Font(self):
        return ChartFont(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Left(self):
        return self.com_object.Left

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @property
    def LegendKey(self):
        return LegendKey(self.com_object.LegendKey)

    @property
    def legendkey(self):
        """Alias for LegendKey"""
        return self.LegendKey

    @property
    def legend_key(self):
        """Alias for LegendKey"""
        return self.LegendKey

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Top(self):
        return self.com_object.Top

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class LegendKey:

    def __init__(self, legendkey=None):
        self.com_object= legendkey

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def InvertIfNegative(self):
        return self.com_object.InvertIfNegative

    @InvertIfNegative.setter
    def InvertIfNegative(self, value):
        self.com_object.InvertIfNegative = value

    @property
    def invertifnegative(self):
        """Alias for InvertIfNegative"""
        return self.InvertIfNegative

    @invertifnegative.setter
    def invertifnegative(self, value):
        """Alias for InvertIfNegative.setter"""
        self.InvertIfNegative = value

    @property
    def invert_if_negative(self):
        """Alias for InvertIfNegative"""
        return self.InvertIfNegative

    @invert_if_negative.setter
    def invert_if_negative(self, value):
        """Alias for InvertIfNegative.setter"""
        self.InvertIfNegative = value

    @property
    def Left(self):
        return self.com_object.Left

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @property
    def MarkerBackgroundColor(self):
        return self.com_object.MarkerBackgroundColor

    @MarkerBackgroundColor.setter
    def MarkerBackgroundColor(self, value):
        self.com_object.MarkerBackgroundColor = value

    @property
    def markerbackgroundcolor(self):
        """Alias for MarkerBackgroundColor"""
        return self.MarkerBackgroundColor

    @markerbackgroundcolor.setter
    def markerbackgroundcolor(self, value):
        """Alias for MarkerBackgroundColor.setter"""
        self.MarkerBackgroundColor = value

    @property
    def marker_background_color(self):
        """Alias for MarkerBackgroundColor"""
        return self.MarkerBackgroundColor

    @marker_background_color.setter
    def marker_background_color(self, value):
        """Alias for MarkerBackgroundColor.setter"""
        self.MarkerBackgroundColor = value

    @property
    def MarkerBackgroundColorIndex(self):
        return XlColorIndex(self.com_object.MarkerBackgroundColorIndex)

    @MarkerBackgroundColorIndex.setter
    def MarkerBackgroundColorIndex(self, value):
        self.com_object.MarkerBackgroundColorIndex = value

    @property
    def markerbackgroundcolorindex(self):
        """Alias for MarkerBackgroundColorIndex"""
        return self.MarkerBackgroundColorIndex

    @markerbackgroundcolorindex.setter
    def markerbackgroundcolorindex(self, value):
        """Alias for MarkerBackgroundColorIndex.setter"""
        self.MarkerBackgroundColorIndex = value

    @property
    def marker_background_color_index(self):
        """Alias for MarkerBackgroundColorIndex"""
        return self.MarkerBackgroundColorIndex

    @marker_background_color_index.setter
    def marker_background_color_index(self, value):
        """Alias for MarkerBackgroundColorIndex.setter"""
        self.MarkerBackgroundColorIndex = value

    @property
    def MarkerForegroundColor(self):
        return self.com_object.MarkerForegroundColor

    @MarkerForegroundColor.setter
    def MarkerForegroundColor(self, value):
        self.com_object.MarkerForegroundColor = value

    @property
    def markerforegroundcolor(self):
        """Alias for MarkerForegroundColor"""
        return self.MarkerForegroundColor

    @markerforegroundcolor.setter
    def markerforegroundcolor(self, value):
        """Alias for MarkerForegroundColor.setter"""
        self.MarkerForegroundColor = value

    @property
    def marker_foreground_color(self):
        """Alias for MarkerForegroundColor"""
        return self.MarkerForegroundColor

    @marker_foreground_color.setter
    def marker_foreground_color(self, value):
        """Alias for MarkerForegroundColor.setter"""
        self.MarkerForegroundColor = value

    @property
    def MarkerForegroundColorIndex(self):
        return XlColorIndex(self.com_object.MarkerForegroundColorIndex)

    @MarkerForegroundColorIndex.setter
    def MarkerForegroundColorIndex(self, value):
        self.com_object.MarkerForegroundColorIndex = value

    @property
    def markerforegroundcolorindex(self):
        """Alias for MarkerForegroundColorIndex"""
        return self.MarkerForegroundColorIndex

    @markerforegroundcolorindex.setter
    def markerforegroundcolorindex(self, value):
        """Alias for MarkerForegroundColorIndex.setter"""
        self.MarkerForegroundColorIndex = value

    @property
    def marker_foreground_color_index(self):
        """Alias for MarkerForegroundColorIndex"""
        return self.MarkerForegroundColorIndex

    @marker_foreground_color_index.setter
    def marker_foreground_color_index(self, value):
        """Alias for MarkerForegroundColorIndex.setter"""
        self.MarkerForegroundColorIndex = value

    @property
    def MarkerSize(self):
        return self.com_object.MarkerSize

    @MarkerSize.setter
    def MarkerSize(self, value):
        self.com_object.MarkerSize = value

    @property
    def markersize(self):
        """Alias for MarkerSize"""
        return self.MarkerSize

    @markersize.setter
    def markersize(self, value):
        """Alias for MarkerSize.setter"""
        self.MarkerSize = value

    @property
    def marker_size(self):
        """Alias for MarkerSize"""
        return self.MarkerSize

    @marker_size.setter
    def marker_size(self, value):
        """Alias for MarkerSize.setter"""
        self.MarkerSize = value

    @property
    def MarkerStyle(self):
        return XlMarkerStyle(self.com_object.MarkerStyle)

    @MarkerStyle.setter
    def MarkerStyle(self, value):
        self.com_object.MarkerStyle = value

    @property
    def markerstyle(self):
        """Alias for MarkerStyle"""
        return self.MarkerStyle

    @markerstyle.setter
    def markerstyle(self, value):
        """Alias for MarkerStyle.setter"""
        self.MarkerStyle = value

    @property
    def marker_style(self):
        """Alias for MarkerStyle"""
        return self.MarkerStyle

    @marker_style.setter
    def marker_style(self, value):
        """Alias for MarkerStyle.setter"""
        self.MarkerStyle = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PictureType(self):
        return XlChartPictureType(self.com_object.PictureType)

    @PictureType.setter
    def PictureType(self, value):
        self.com_object.PictureType = value

    @property
    def picturetype(self):
        """Alias for PictureType"""
        return self.PictureType

    @picturetype.setter
    def picturetype(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def picture_type(self):
        """Alias for PictureType"""
        return self.PictureType

    @picture_type.setter
    def picture_type(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def PictureUnit2(self):
        return self.com_object.PictureUnit2

    @PictureUnit2.setter
    def PictureUnit2(self, value):
        self.com_object.PictureUnit2 = value

    @property
    def pictureunit2(self):
        """Alias for PictureUnit2"""
        return self.PictureUnit2

    @pictureunit2.setter
    def pictureunit2(self, value):
        """Alias for PictureUnit2.setter"""
        self.PictureUnit2 = value

    @property
    def picture_unit2(self):
        """Alias for PictureUnit2"""
        return self.PictureUnit2

    @picture_unit2.setter
    def picture_unit2(self, value):
        """Alias for PictureUnit2.setter"""
        self.PictureUnit2 = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Smooth(self):
        return self.com_object.Smooth

    @Smooth.setter
    def Smooth(self, value):
        self.com_object.Smooth = value

    @property
    def smooth(self):
        """Alias for Smooth"""
        return self.Smooth

    @smooth.setter
    def smooth(self, value):
        """Alias for Smooth.setter"""
        self.Smooth = value

    @property
    def Top(self):
        return self.com_object.Top

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    def ClearFormats(self):
        self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class LetterContent:

    def __init__(self, lettercontent=None):
        self.com_object= lettercontent

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AttentionLine(self):
        return self.com_object.AttentionLine

    @AttentionLine.setter
    def AttentionLine(self, value):
        self.com_object.AttentionLine = value

    @property
    def attentionline(self):
        """Alias for AttentionLine"""
        return self.AttentionLine

    @attentionline.setter
    def attentionline(self, value):
        """Alias for AttentionLine.setter"""
        self.AttentionLine = value

    @property
    def attention_line(self):
        """Alias for AttentionLine"""
        return self.AttentionLine

    @attention_line.setter
    def attention_line(self, value):
        """Alias for AttentionLine.setter"""
        self.AttentionLine = value

    @property
    def CCList(self):
        return self.com_object.CCList

    @CCList.setter
    def CCList(self, value):
        self.com_object.CCList = value

    @property
    def cclist(self):
        """Alias for CCList"""
        return self.CCList

    @cclist.setter
    def cclist(self, value):
        """Alias for CCList.setter"""
        self.CCList = value

    @property
    def c_c_list(self):
        """Alias for CCList"""
        return self.CCList

    @c_c_list.setter
    def c_c_list(self, value):
        """Alias for CCList.setter"""
        self.CCList = value

    @property
    def Closing(self):
        return self.com_object.Closing

    @Closing.setter
    def Closing(self, value):
        self.com_object.Closing = value

    @property
    def closing(self):
        """Alias for Closing"""
        return self.Closing

    @closing.setter
    def closing(self, value):
        """Alias for Closing.setter"""
        self.Closing = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DateFormat(self):
        return self.com_object.DateFormat

    @DateFormat.setter
    def DateFormat(self, value):
        self.com_object.DateFormat = value

    @property
    def dateformat(self):
        """Alias for DateFormat"""
        return self.DateFormat

    @dateformat.setter
    def dateformat(self, value):
        """Alias for DateFormat.setter"""
        self.DateFormat = value

    @property
    def date_format(self):
        """Alias for DateFormat"""
        return self.DateFormat

    @date_format.setter
    def date_format(self, value):
        """Alias for DateFormat.setter"""
        self.DateFormat = value

    @property
    def Duplicate(self):
        return LetterContent(self.com_object.Duplicate)

    @property
    def duplicate(self):
        """Alias for Duplicate"""
        return self.Duplicate

    @property
    def EnclosureNumber(self):
        return self.com_object.EnclosureNumber

    @EnclosureNumber.setter
    def EnclosureNumber(self, value):
        self.com_object.EnclosureNumber = value

    @property
    def enclosurenumber(self):
        """Alias for EnclosureNumber"""
        return self.EnclosureNumber

    @enclosurenumber.setter
    def enclosurenumber(self, value):
        """Alias for EnclosureNumber.setter"""
        self.EnclosureNumber = value

    @property
    def enclosure_number(self):
        """Alias for EnclosureNumber"""
        return self.EnclosureNumber

    @enclosure_number.setter
    def enclosure_number(self, value):
        """Alias for EnclosureNumber.setter"""
        self.EnclosureNumber = value

    @property
    def IncludeHeaderFooter(self):
        return self.com_object.IncludeHeaderFooter

    @IncludeHeaderFooter.setter
    def IncludeHeaderFooter(self, value):
        self.com_object.IncludeHeaderFooter = value

    @property
    def includeheaderfooter(self):
        """Alias for IncludeHeaderFooter"""
        return self.IncludeHeaderFooter

    @includeheaderfooter.setter
    def includeheaderfooter(self, value):
        """Alias for IncludeHeaderFooter.setter"""
        self.IncludeHeaderFooter = value

    @property
    def include_header_footer(self):
        """Alias for IncludeHeaderFooter"""
        return self.IncludeHeaderFooter

    @include_header_footer.setter
    def include_header_footer(self, value):
        """Alias for IncludeHeaderFooter.setter"""
        self.IncludeHeaderFooter = value

    @property
    def InfoBlock(self):
        return self.com_object.InfoBlock

    @property
    def infoblock(self):
        """Alias for InfoBlock"""
        return self.InfoBlock

    @property
    def info_block(self):
        """Alias for InfoBlock"""
        return self.InfoBlock

    @property
    def Letterhead(self):
        return self.com_object.Letterhead

    @Letterhead.setter
    def Letterhead(self, value):
        self.com_object.Letterhead = value

    @property
    def letterhead(self):
        """Alias for Letterhead"""
        return self.Letterhead

    @letterhead.setter
    def letterhead(self, value):
        """Alias for Letterhead.setter"""
        self.Letterhead = value

    @property
    def LetterheadLocation(self):
        return WdLetterheadLocation(self.com_object.LetterheadLocation)

    @LetterheadLocation.setter
    def LetterheadLocation(self, value):
        self.com_object.LetterheadLocation = value

    @property
    def letterheadlocation(self):
        """Alias for LetterheadLocation"""
        return self.LetterheadLocation

    @letterheadlocation.setter
    def letterheadlocation(self, value):
        """Alias for LetterheadLocation.setter"""
        self.LetterheadLocation = value

    @property
    def letterhead_location(self):
        """Alias for LetterheadLocation"""
        return self.LetterheadLocation

    @letterhead_location.setter
    def letterhead_location(self, value):
        """Alias for LetterheadLocation.setter"""
        self.LetterheadLocation = value

    @property
    def LetterheadSize(self):
        return self.com_object.LetterheadSize

    @LetterheadSize.setter
    def LetterheadSize(self, value):
        self.com_object.LetterheadSize = value

    @property
    def letterheadsize(self):
        """Alias for LetterheadSize"""
        return self.LetterheadSize

    @letterheadsize.setter
    def letterheadsize(self, value):
        """Alias for LetterheadSize.setter"""
        self.LetterheadSize = value

    @property
    def letterhead_size(self):
        """Alias for LetterheadSize"""
        return self.LetterheadSize

    @letterhead_size.setter
    def letterhead_size(self, value):
        """Alias for LetterheadSize.setter"""
        self.LetterheadSize = value

    @property
    def LetterStyle(self):
        return WdLetterStyle(self.com_object.LetterStyle)

    @LetterStyle.setter
    def LetterStyle(self, value):
        self.com_object.LetterStyle = value

    @property
    def letterstyle(self):
        """Alias for LetterStyle"""
        return self.LetterStyle

    @letterstyle.setter
    def letterstyle(self, value):
        """Alias for LetterStyle.setter"""
        self.LetterStyle = value

    @property
    def letter_style(self):
        """Alias for LetterStyle"""
        return self.LetterStyle

    @letter_style.setter
    def letter_style(self, value):
        """Alias for LetterStyle.setter"""
        self.LetterStyle = value

    @property
    def MailingInstructions(self):
        return self.com_object.MailingInstructions

    @MailingInstructions.setter
    def MailingInstructions(self, value):
        self.com_object.MailingInstructions = value

    @property
    def mailinginstructions(self):
        """Alias for MailingInstructions"""
        return self.MailingInstructions

    @mailinginstructions.setter
    def mailinginstructions(self, value):
        """Alias for MailingInstructions.setter"""
        self.MailingInstructions = value

    @property
    def mailing_instructions(self):
        """Alias for MailingInstructions"""
        return self.MailingInstructions

    @mailing_instructions.setter
    def mailing_instructions(self, value):
        """Alias for MailingInstructions.setter"""
        self.MailingInstructions = value

    @property
    def PageDesign(self):
        return self.com_object.PageDesign

    @PageDesign.setter
    def PageDesign(self, value):
        self.com_object.PageDesign = value

    @property
    def pagedesign(self):
        """Alias for PageDesign"""
        return self.PageDesign

    @pagedesign.setter
    def pagedesign(self, value):
        """Alias for PageDesign.setter"""
        self.PageDesign = value

    @property
    def page_design(self):
        """Alias for PageDesign"""
        return self.PageDesign

    @page_design.setter
    def page_design(self, value):
        """Alias for PageDesign.setter"""
        self.PageDesign = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RecipientAddress(self):
        return self.com_object.RecipientAddress

    @RecipientAddress.setter
    def RecipientAddress(self, value):
        self.com_object.RecipientAddress = value

    @property
    def recipientaddress(self):
        """Alias for RecipientAddress"""
        return self.RecipientAddress

    @recipientaddress.setter
    def recipientaddress(self, value):
        """Alias for RecipientAddress.setter"""
        self.RecipientAddress = value

    @property
    def recipient_address(self):
        """Alias for RecipientAddress"""
        return self.RecipientAddress

    @recipient_address.setter
    def recipient_address(self, value):
        """Alias for RecipientAddress.setter"""
        self.RecipientAddress = value

    @property
    def RecipientCode(self):
        return self.com_object.RecipientCode

    @RecipientCode.setter
    def RecipientCode(self, value):
        self.com_object.RecipientCode = value

    @property
    def recipientcode(self):
        """Alias for RecipientCode"""
        return self.RecipientCode

    @recipientcode.setter
    def recipientcode(self, value):
        """Alias for RecipientCode.setter"""
        self.RecipientCode = value

    @property
    def recipient_code(self):
        """Alias for RecipientCode"""
        return self.RecipientCode

    @recipient_code.setter
    def recipient_code(self, value):
        """Alias for RecipientCode.setter"""
        self.RecipientCode = value

    @property
    def RecipientGender(self):
        return WdSalutationGender(self.com_object.RecipientGender)

    @RecipientGender.setter
    def RecipientGender(self, value):
        self.com_object.RecipientGender = value

    @property
    def recipientgender(self):
        """Alias for RecipientGender"""
        return self.RecipientGender

    @recipientgender.setter
    def recipientgender(self, value):
        """Alias for RecipientGender.setter"""
        self.RecipientGender = value

    @property
    def recipient_gender(self):
        """Alias for RecipientGender"""
        return self.RecipientGender

    @recipient_gender.setter
    def recipient_gender(self, value):
        """Alias for RecipientGender.setter"""
        self.RecipientGender = value

    @property
    def RecipientName(self):
        return self.com_object.RecipientName

    @RecipientName.setter
    def RecipientName(self, value):
        self.com_object.RecipientName = value

    @property
    def recipientname(self):
        """Alias for RecipientName"""
        return self.RecipientName

    @recipientname.setter
    def recipientname(self, value):
        """Alias for RecipientName.setter"""
        self.RecipientName = value

    @property
    def recipient_name(self):
        """Alias for RecipientName"""
        return self.RecipientName

    @recipient_name.setter
    def recipient_name(self, value):
        """Alias for RecipientName.setter"""
        self.RecipientName = value

    @property
    def RecipientReference(self):
        return self.com_object.RecipientReference

    @RecipientReference.setter
    def RecipientReference(self, value):
        self.com_object.RecipientReference = value

    @property
    def recipientreference(self):
        """Alias for RecipientReference"""
        return self.RecipientReference

    @recipientreference.setter
    def recipientreference(self, value):
        """Alias for RecipientReference.setter"""
        self.RecipientReference = value

    @property
    def recipient_reference(self):
        """Alias for RecipientReference"""
        return self.RecipientReference

    @recipient_reference.setter
    def recipient_reference(self, value):
        """Alias for RecipientReference.setter"""
        self.RecipientReference = value

    @property
    def ReturnAddress(self):
        return self.com_object.ReturnAddress

    @ReturnAddress.setter
    def ReturnAddress(self, value):
        self.com_object.ReturnAddress = value

    @property
    def returnaddress(self):
        """Alias for ReturnAddress"""
        return self.ReturnAddress

    @returnaddress.setter
    def returnaddress(self, value):
        """Alias for ReturnAddress.setter"""
        self.ReturnAddress = value

    @property
    def return_address(self):
        """Alias for ReturnAddress"""
        return self.ReturnAddress

    @return_address.setter
    def return_address(self, value):
        """Alias for ReturnAddress.setter"""
        self.ReturnAddress = value

    @property
    def ReturnAddressShortForm(self):
        return self.com_object.ReturnAddressShortForm

    @ReturnAddressShortForm.setter
    def ReturnAddressShortForm(self, value):
        self.com_object.ReturnAddressShortForm = value

    @property
    def returnaddressshortform(self):
        """Alias for ReturnAddressShortForm"""
        return self.ReturnAddressShortForm

    @returnaddressshortform.setter
    def returnaddressshortform(self, value):
        """Alias for ReturnAddressShortForm.setter"""
        self.ReturnAddressShortForm = value

    @property
    def return_address_short_form(self):
        """Alias for ReturnAddressShortForm"""
        return self.ReturnAddressShortForm

    @return_address_short_form.setter
    def return_address_short_form(self, value):
        """Alias for ReturnAddressShortForm.setter"""
        self.ReturnAddressShortForm = value

    @property
    def Salutation(self):
        return self.com_object.Salutation

    @Salutation.setter
    def Salutation(self, value):
        self.com_object.Salutation = value

    @property
    def salutation(self):
        """Alias for Salutation"""
        return self.Salutation

    @salutation.setter
    def salutation(self, value):
        """Alias for Salutation.setter"""
        self.Salutation = value

    @property
    def SalutationType(self):
        return WdSalutationType(self.com_object.SalutationType)

    @SalutationType.setter
    def SalutationType(self, value):
        self.com_object.SalutationType = value

    @property
    def salutationtype(self):
        """Alias for SalutationType"""
        return self.SalutationType

    @salutationtype.setter
    def salutationtype(self, value):
        """Alias for SalutationType.setter"""
        self.SalutationType = value

    @property
    def salutation_type(self):
        """Alias for SalutationType"""
        return self.SalutationType

    @salutation_type.setter
    def salutation_type(self, value):
        """Alias for SalutationType.setter"""
        self.SalutationType = value

    @property
    def SenderCity(self):
        return self.com_object.SenderCity

    @SenderCity.setter
    def SenderCity(self, value):
        self.com_object.SenderCity = value

    @property
    def sendercity(self):
        """Alias for SenderCity"""
        return self.SenderCity

    @sendercity.setter
    def sendercity(self, value):
        """Alias for SenderCity.setter"""
        self.SenderCity = value

    @property
    def sender_city(self):
        """Alias for SenderCity"""
        return self.SenderCity

    @sender_city.setter
    def sender_city(self, value):
        """Alias for SenderCity.setter"""
        self.SenderCity = value

    @property
    def SenderCode(self):
        return self.com_object.SenderCode

    @SenderCode.setter
    def SenderCode(self, value):
        self.com_object.SenderCode = value

    @property
    def sendercode(self):
        """Alias for SenderCode"""
        return self.SenderCode

    @sendercode.setter
    def sendercode(self, value):
        """Alias for SenderCode.setter"""
        self.SenderCode = value

    @property
    def sender_code(self):
        """Alias for SenderCode"""
        return self.SenderCode

    @sender_code.setter
    def sender_code(self, value):
        """Alias for SenderCode.setter"""
        self.SenderCode = value

    @property
    def SenderCompany(self):
        return self.com_object.SenderCompany

    @SenderCompany.setter
    def SenderCompany(self, value):
        self.com_object.SenderCompany = value

    @property
    def sendercompany(self):
        """Alias for SenderCompany"""
        return self.SenderCompany

    @sendercompany.setter
    def sendercompany(self, value):
        """Alias for SenderCompany.setter"""
        self.SenderCompany = value

    @property
    def sender_company(self):
        """Alias for SenderCompany"""
        return self.SenderCompany

    @sender_company.setter
    def sender_company(self, value):
        """Alias for SenderCompany.setter"""
        self.SenderCompany = value

    @property
    def SenderGender(self):
        return WdSalutationGender(self.com_object.SenderGender)

    @SenderGender.setter
    def SenderGender(self, value):
        self.com_object.SenderGender = value

    @property
    def sendergender(self):
        """Alias for SenderGender"""
        return self.SenderGender

    @sendergender.setter
    def sendergender(self, value):
        """Alias for SenderGender.setter"""
        self.SenderGender = value

    @property
    def sender_gender(self):
        """Alias for SenderGender"""
        return self.SenderGender

    @sender_gender.setter
    def sender_gender(self, value):
        """Alias for SenderGender.setter"""
        self.SenderGender = value

    @property
    def SenderInitials(self):
        return self.com_object.SenderInitials

    @SenderInitials.setter
    def SenderInitials(self, value):
        self.com_object.SenderInitials = value

    @property
    def senderinitials(self):
        """Alias for SenderInitials"""
        return self.SenderInitials

    @senderinitials.setter
    def senderinitials(self, value):
        """Alias for SenderInitials.setter"""
        self.SenderInitials = value

    @property
    def sender_initials(self):
        """Alias for SenderInitials"""
        return self.SenderInitials

    @sender_initials.setter
    def sender_initials(self, value):
        """Alias for SenderInitials.setter"""
        self.SenderInitials = value

    @property
    def SenderJobTitle(self):
        return self.com_object.SenderJobTitle

    @SenderJobTitle.setter
    def SenderJobTitle(self, value):
        self.com_object.SenderJobTitle = value

    @property
    def senderjobtitle(self):
        """Alias for SenderJobTitle"""
        return self.SenderJobTitle

    @senderjobtitle.setter
    def senderjobtitle(self, value):
        """Alias for SenderJobTitle.setter"""
        self.SenderJobTitle = value

    @property
    def sender_job_title(self):
        """Alias for SenderJobTitle"""
        return self.SenderJobTitle

    @sender_job_title.setter
    def sender_job_title(self, value):
        """Alias for SenderJobTitle.setter"""
        self.SenderJobTitle = value

    @property
    def SenderName(self):
        return self.com_object.SenderName

    @SenderName.setter
    def SenderName(self, value):
        self.com_object.SenderName = value

    @property
    def sendername(self):
        """Alias for SenderName"""
        return self.SenderName

    @sendername.setter
    def sendername(self, value):
        """Alias for SenderName.setter"""
        self.SenderName = value

    @property
    def sender_name(self):
        """Alias for SenderName"""
        return self.SenderName

    @sender_name.setter
    def sender_name(self, value):
        """Alias for SenderName.setter"""
        self.SenderName = value

    @property
    def SenderReference(self):
        return self.com_object.SenderReference

    @SenderReference.setter
    def SenderReference(self, value):
        self.com_object.SenderReference = value

    @property
    def senderreference(self):
        """Alias for SenderReference"""
        return self.SenderReference

    @senderreference.setter
    def senderreference(self, value):
        """Alias for SenderReference.setter"""
        self.SenderReference = value

    @property
    def sender_reference(self):
        """Alias for SenderReference"""
        return self.SenderReference

    @sender_reference.setter
    def sender_reference(self, value):
        """Alias for SenderReference.setter"""
        self.SenderReference = value

    @property
    def Subject(self):
        return self.com_object.Subject

    @Subject.setter
    def Subject(self, value):
        self.com_object.Subject = value

    @property
    def subject(self):
        """Alias for Subject"""
        return self.Subject

    @subject.setter
    def subject(self, value):
        """Alias for Subject.setter"""
        self.Subject = value


class Line:

    def __init__(self, line=None):
        self.com_object= line

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def Left(self):
        return self.com_object.Left

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @property
    def LineType(self):
        return wdLineType(self.com_object.LineType)

    @property
    def linetype(self):
        """Alias for LineType"""
        return self.LineType

    @property
    def line_type(self):
        """Alias for LineType"""
        return self.LineType

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def Rectangles(self):
        return Rectangles(self.com_object.Rectangles)

    @property
    def rectangles(self):
        """Alias for Rectangles"""
        return self.Rectangles

    @property
    def Top(self):
        return self.com_object.Top

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width


class LineFormat:

    def __init__(self, lineformat=None):
        self.com_object= lineformat

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BackColor(self):
        return ColorFormat(self.com_object.BackColor)

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BeginArrowheadLength(self):
        return self.com_object.BeginArrowheadLength

    @BeginArrowheadLength.setter
    def BeginArrowheadLength(self, value):
        self.com_object.BeginArrowheadLength = value

    @property
    def beginarrowheadlength(self):
        """Alias for BeginArrowheadLength"""
        return self.BeginArrowheadLength

    @beginarrowheadlength.setter
    def beginarrowheadlength(self, value):
        """Alias for BeginArrowheadLength.setter"""
        self.BeginArrowheadLength = value

    @property
    def begin_arrowhead_length(self):
        """Alias for BeginArrowheadLength"""
        return self.BeginArrowheadLength

    @begin_arrowhead_length.setter
    def begin_arrowhead_length(self, value):
        """Alias for BeginArrowheadLength.setter"""
        self.BeginArrowheadLength = value

    @property
    def BeginArrowheadStyle(self):
        return self.com_object.BeginArrowheadStyle

    @BeginArrowheadStyle.setter
    def BeginArrowheadStyle(self, value):
        self.com_object.BeginArrowheadStyle = value

    @property
    def beginarrowheadstyle(self):
        """Alias for BeginArrowheadStyle"""
        return self.BeginArrowheadStyle

    @beginarrowheadstyle.setter
    def beginarrowheadstyle(self, value):
        """Alias for BeginArrowheadStyle.setter"""
        self.BeginArrowheadStyle = value

    @property
    def begin_arrowhead_style(self):
        """Alias for BeginArrowheadStyle"""
        return self.BeginArrowheadStyle

    @begin_arrowhead_style.setter
    def begin_arrowhead_style(self, value):
        """Alias for BeginArrowheadStyle.setter"""
        self.BeginArrowheadStyle = value

    @property
    def BeginArrowheadWidth(self):
        return self.com_object.BeginArrowheadWidth

    @BeginArrowheadWidth.setter
    def BeginArrowheadWidth(self, value):
        self.com_object.BeginArrowheadWidth = value

    @property
    def beginarrowheadwidth(self):
        """Alias for BeginArrowheadWidth"""
        return self.BeginArrowheadWidth

    @beginarrowheadwidth.setter
    def beginarrowheadwidth(self, value):
        """Alias for BeginArrowheadWidth.setter"""
        self.BeginArrowheadWidth = value

    @property
    def begin_arrowhead_width(self):
        """Alias for BeginArrowheadWidth"""
        return self.BeginArrowheadWidth

    @begin_arrowhead_width.setter
    def begin_arrowhead_width(self, value):
        """Alias for BeginArrowheadWidth.setter"""
        self.BeginArrowheadWidth = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DashStyle(self):
        return self.com_object.DashStyle

    @DashStyle.setter
    def DashStyle(self, value):
        self.com_object.DashStyle = value

    @property
    def dashstyle(self):
        """Alias for DashStyle"""
        return self.DashStyle

    @dashstyle.setter
    def dashstyle(self, value):
        """Alias for DashStyle.setter"""
        self.DashStyle = value

    @property
    def dash_style(self):
        """Alias for DashStyle"""
        return self.DashStyle

    @dash_style.setter
    def dash_style(self, value):
        """Alias for DashStyle.setter"""
        self.DashStyle = value

    @property
    def EndArrowheadLength(self):
        return self.com_object.EndArrowheadLength

    @EndArrowheadLength.setter
    def EndArrowheadLength(self, value):
        self.com_object.EndArrowheadLength = value

    @property
    def endarrowheadlength(self):
        """Alias for EndArrowheadLength"""
        return self.EndArrowheadLength

    @endarrowheadlength.setter
    def endarrowheadlength(self, value):
        """Alias for EndArrowheadLength.setter"""
        self.EndArrowheadLength = value

    @property
    def end_arrowhead_length(self):
        """Alias for EndArrowheadLength"""
        return self.EndArrowheadLength

    @end_arrowhead_length.setter
    def end_arrowhead_length(self, value):
        """Alias for EndArrowheadLength.setter"""
        self.EndArrowheadLength = value

    @property
    def EndArrowheadStyle(self):
        return self.com_object.EndArrowheadStyle

    @EndArrowheadStyle.setter
    def EndArrowheadStyle(self, value):
        self.com_object.EndArrowheadStyle = value

    @property
    def endarrowheadstyle(self):
        """Alias for EndArrowheadStyle"""
        return self.EndArrowheadStyle

    @endarrowheadstyle.setter
    def endarrowheadstyle(self, value):
        """Alias for EndArrowheadStyle.setter"""
        self.EndArrowheadStyle = value

    @property
    def end_arrowhead_style(self):
        """Alias for EndArrowheadStyle"""
        return self.EndArrowheadStyle

    @end_arrowhead_style.setter
    def end_arrowhead_style(self, value):
        """Alias for EndArrowheadStyle.setter"""
        self.EndArrowheadStyle = value

    @property
    def EndArrowheadWidth(self):
        return self.com_object.EndArrowheadWidth

    @EndArrowheadWidth.setter
    def EndArrowheadWidth(self, value):
        self.com_object.EndArrowheadWidth = value

    @property
    def endarrowheadwidth(self):
        """Alias for EndArrowheadWidth"""
        return self.EndArrowheadWidth

    @endarrowheadwidth.setter
    def endarrowheadwidth(self, value):
        """Alias for EndArrowheadWidth.setter"""
        self.EndArrowheadWidth = value

    @property
    def end_arrowhead_width(self):
        """Alias for EndArrowheadWidth"""
        return self.EndArrowheadWidth

    @end_arrowhead_width.setter
    def end_arrowhead_width(self, value):
        """Alias for EndArrowheadWidth.setter"""
        self.EndArrowheadWidth = value

    @property
    def ForeColor(self):
        return ColorFormat(self.com_object.ForeColor)

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def InsetPen(self):
        return self.com_object.InsetPen

    @InsetPen.setter
    def InsetPen(self, value):
        self.com_object.InsetPen = value

    @property
    def insetpen(self):
        """Alias for InsetPen"""
        return self.InsetPen

    @insetpen.setter
    def insetpen(self, value):
        """Alias for InsetPen.setter"""
        self.InsetPen = value

    @property
    def inset_pen(self):
        """Alias for InsetPen"""
        return self.InsetPen

    @inset_pen.setter
    def inset_pen(self, value):
        """Alias for InsetPen.setter"""
        self.InsetPen = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Pattern(self):
        return self.com_object.Pattern

    @Pattern.setter
    def Pattern(self, value):
        self.com_object.Pattern = value

    @property
    def pattern(self):
        """Alias for Pattern"""
        return self.Pattern

    @pattern.setter
    def pattern(self, value):
        """Alias for Pattern.setter"""
        self.Pattern = value

    @property
    def Style(self):
        return self.com_object.Style

    @Style.setter
    def Style(self, value):
        self.com_object.Style = value

    @property
    def style(self):
        """Alias for Style"""
        return self.Style

    @style.setter
    def style(self, value):
        """Alias for Style.setter"""
        self.Style = value

    @property
    def Transparency(self):
        return self.com_object.Transparency

    @Transparency.setter
    def Transparency(self, value):
        self.com_object.Transparency = value

    @property
    def transparency(self):
        """Alias for Transparency"""
        return self.Transparency

    @transparency.setter
    def transparency(self, value):
        """Alias for Transparency.setter"""
        self.Transparency = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Weight(self):
        return self.com_object.Weight

    @Weight.setter
    def Weight(self, value):
        self.com_object.Weight = value

    @property
    def weight(self):
        """Alias for Weight"""
        return self.Weight

    @weight.setter
    def weight(self, value):
        """Alias for Weight.setter"""
        self.Weight = value


class LineNumbering:

    def __init__(self, linenumbering=None):
        self.com_object= linenumbering

    @property
    def Active(self):
        return self.com_object.Active

    @Active.setter
    def Active(self, value):
        self.com_object.Active = value

    @property
    def active(self):
        """Alias for Active"""
        return self.Active

    @active.setter
    def active(self, value):
        """Alias for Active.setter"""
        self.Active = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def CountBy(self):
        return self.com_object.CountBy

    @CountBy.setter
    def CountBy(self, value):
        self.com_object.CountBy = value

    @property
    def countby(self):
        """Alias for CountBy"""
        return self.CountBy

    @countby.setter
    def countby(self, value):
        """Alias for CountBy.setter"""
        self.CountBy = value

    @property
    def count_by(self):
        """Alias for CountBy"""
        return self.CountBy

    @count_by.setter
    def count_by(self, value):
        """Alias for CountBy.setter"""
        self.CountBy = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DistanceFromText(self):
        return self.com_object.DistanceFromText

    @DistanceFromText.setter
    def DistanceFromText(self, value):
        self.com_object.DistanceFromText = value

    @property
    def distancefromtext(self):
        """Alias for DistanceFromText"""
        return self.DistanceFromText

    @distancefromtext.setter
    def distancefromtext(self, value):
        """Alias for DistanceFromText.setter"""
        self.DistanceFromText = value

    @property
    def distance_from_text(self):
        """Alias for DistanceFromText"""
        return self.DistanceFromText

    @distance_from_text.setter
    def distance_from_text(self, value):
        """Alias for DistanceFromText.setter"""
        self.DistanceFromText = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RestartMode(self):
        return WdNumberingRule(self.com_object.RestartMode)

    @RestartMode.setter
    def RestartMode(self, value):
        self.com_object.RestartMode = value

    @property
    def restartmode(self):
        """Alias for RestartMode"""
        return self.RestartMode

    @restartmode.setter
    def restartmode(self, value):
        """Alias for RestartMode.setter"""
        self.RestartMode = value

    @property
    def restart_mode(self):
        """Alias for RestartMode"""
        return self.RestartMode

    @restart_mode.setter
    def restart_mode(self, value):
        """Alias for RestartMode.setter"""
        self.RestartMode = value

    @property
    def StartingNumber(self):
        return self.com_object.StartingNumber

    @StartingNumber.setter
    def StartingNumber(self, value):
        self.com_object.StartingNumber = value

    @property
    def startingnumber(self):
        """Alias for StartingNumber"""
        return self.StartingNumber

    @startingnumber.setter
    def startingnumber(self, value):
        """Alias for StartingNumber.setter"""
        self.StartingNumber = value

    @property
    def starting_number(self):
        """Alias for StartingNumber"""
        return self.StartingNumber

    @starting_number.setter
    def starting_number(self, value):
        """Alias for StartingNumber.setter"""
        self.StartingNumber = value


class Lines:

    def __init__(self, lines=None):
        self.com_object= lines

    def __call__(self, item):
        return Line(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Line(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class LinkFormat:

    def __init__(self, linkformat=None):
        self.com_object= linkformat

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoUpdate(self):
        return self.com_object.AutoUpdate

    @AutoUpdate.setter
    def AutoUpdate(self, value):
        self.com_object.AutoUpdate = value

    @property
    def autoupdate(self):
        """Alias for AutoUpdate"""
        return self.AutoUpdate

    @autoupdate.setter
    def autoupdate(self, value):
        """Alias for AutoUpdate.setter"""
        self.AutoUpdate = value

    @property
    def auto_update(self):
        """Alias for AutoUpdate"""
        return self.AutoUpdate

    @auto_update.setter
    def auto_update(self, value):
        """Alias for AutoUpdate.setter"""
        self.AutoUpdate = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SavePictureWithDocument(self):
        return self.com_object.SavePictureWithDocument

    @SavePictureWithDocument.setter
    def SavePictureWithDocument(self, value):
        self.com_object.SavePictureWithDocument = value

    @property
    def savepicturewithdocument(self):
        """Alias for SavePictureWithDocument"""
        return self.SavePictureWithDocument

    @savepicturewithdocument.setter
    def savepicturewithdocument(self, value):
        """Alias for SavePictureWithDocument.setter"""
        self.SavePictureWithDocument = value

    @property
    def save_picture_with_document(self):
        """Alias for SavePictureWithDocument"""
        return self.SavePictureWithDocument

    @save_picture_with_document.setter
    def save_picture_with_document(self, value):
        """Alias for SavePictureWithDocument.setter"""
        self.SavePictureWithDocument = value

    @property
    def SourceFullName(self):
        return self.com_object.SourceFullName

    @SourceFullName.setter
    def SourceFullName(self, value):
        self.com_object.SourceFullName = value

    @property
    def sourcefullname(self):
        """Alias for SourceFullName"""
        return self.SourceFullName

    @sourcefullname.setter
    def sourcefullname(self, value):
        """Alias for SourceFullName.setter"""
        self.SourceFullName = value

    @property
    def source_full_name(self):
        """Alias for SourceFullName"""
        return self.SourceFullName

    @source_full_name.setter
    def source_full_name(self, value):
        """Alias for SourceFullName.setter"""
        self.SourceFullName = value

    @property
    def SourceName(self):
        return self.com_object.SourceName

    @property
    def sourcename(self):
        """Alias for SourceName"""
        return self.SourceName

    @property
    def source_name(self):
        """Alias for SourceName"""
        return self.SourceName

    @property
    def SourcePath(self):
        return self.com_object.SourcePath

    @property
    def sourcepath(self):
        """Alias for SourcePath"""
        return self.SourcePath

    @property
    def source_path(self):
        """Alias for SourcePath"""
        return self.SourcePath

    @property
    def Type(self):
        return WdLinkType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def BreakLink(self):
        self.com_object.BreakLink()

    def breaklink(self):
        """Alias for BreakLink"""
        return self.BreakLink()

    def break_link(self):
        """Alias for BreakLink"""
        return self.BreakLink()

    def Update(self):
        self.com_object.Update()

    def update(self):
        """Alias for Update"""
        return self.Update()


class List:

    def __init__(self, list=None):
        self.com_object= list

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ListParagraphs(self):
        return ListParagraphs(self.com_object.ListParagraphs)

    @property
    def listparagraphs(self):
        """Alias for ListParagraphs"""
        return self.ListParagraphs

    @property
    def list_paragraphs(self):
        """Alias for ListParagraphs"""
        return self.ListParagraphs

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def SingleListTemplate(self):
        return self.com_object.SingleListTemplate

    @property
    def singlelisttemplate(self):
        """Alias for SingleListTemplate"""
        return self.SingleListTemplate

    @property
    def single_list_template(self):
        """Alias for SingleListTemplate"""
        return self.SingleListTemplate

    @property
    def StyleName(self):
        return self.com_object.StyleName

    @property
    def stylename(self):
        """Alias for StyleName"""
        return self.StyleName

    @property
    def style_name(self):
        """Alias for StyleName"""
        return self.StyleName

    def ApplyListTemplate(self, ListTemplate=None, ContinuePreviousList=None, ApplyTo=None, DefaultListBehavior=None):
        arguments = com_arguments([unwrap(a) for a in [ListTemplate, ContinuePreviousList, ApplyTo, DefaultListBehavior]])
        self.com_object.ApplyListTemplate(*arguments)

    def applylisttemplate(self, ListTemplate=None, ContinuePreviousList=None, ApplyTo=None, DefaultListBehavior=None):
        """Alias for ApplyListTemplate"""
        arguments = [ListTemplate, ContinuePreviousList, ApplyTo, DefaultListBehavior]
        return self.ApplyListTemplate(*arguments)

    def apply_list_template(self, ListTemplate=None, ContinuePreviousList=None, ApplyTo=None, DefaultListBehavior=None):
        """Alias for ApplyListTemplate"""
        arguments = [ListTemplate, ContinuePreviousList, ApplyTo, DefaultListBehavior]
        return self.ApplyListTemplate(*arguments)

    def ApplyListTemplateWithLevel(self, ListTemplate=None, ContinuePreviousList=None, DefaultListBehavior=None, ApplyLevel=None):
        arguments = com_arguments([unwrap(a) for a in [ListTemplate, ContinuePreviousList, DefaultListBehavior, ApplyLevel]])
        self.com_object.ApplyListTemplateWithLevel(*arguments)

    def applylisttemplatewithlevel(self, ListTemplate=None, ContinuePreviousList=None, DefaultListBehavior=None, ApplyLevel=None):
        """Alias for ApplyListTemplateWithLevel"""
        arguments = [ListTemplate, ContinuePreviousList, DefaultListBehavior, ApplyLevel]
        return self.ApplyListTemplateWithLevel(*arguments)

    def apply_list_template_with_level(self, ListTemplate=None, ContinuePreviousList=None, DefaultListBehavior=None, ApplyLevel=None):
        """Alias for ApplyListTemplateWithLevel"""
        arguments = [ListTemplate, ContinuePreviousList, DefaultListBehavior, ApplyLevel]
        return self.ApplyListTemplateWithLevel(*arguments)

    def CanContinuePreviousList(self, ListTemplate=None):
        arguments = com_arguments([unwrap(a) for a in [ListTemplate]])
        self.com_object.CanContinuePreviousList(*arguments)

    def cancontinuepreviouslist(self, ListTemplate=None):
        """Alias for CanContinuePreviousList"""
        arguments = [ListTemplate]
        return self.CanContinuePreviousList(*arguments)

    def can_continue_previous_list(self, ListTemplate=None):
        """Alias for CanContinuePreviousList"""
        arguments = [ListTemplate]
        return self.CanContinuePreviousList(*arguments)

    def ConvertNumbersToText(self):
        self.com_object.ConvertNumbersToText()

    def convertnumberstotext(self):
        """Alias for ConvertNumbersToText"""
        return self.ConvertNumbersToText()

    def convert_numbers_to_text(self):
        """Alias for ConvertNumbersToText"""
        return self.ConvertNumbersToText()

    def CountNumberedItems(self):
        self.com_object.CountNumberedItems()

    def countnumbereditems(self):
        """Alias for CountNumberedItems"""
        return self.CountNumberedItems()

    def count_numbered_items(self):
        """Alias for CountNumberedItems"""
        return self.CountNumberedItems()

    def RemoveNumbers(self, NumberType=None):
        arguments = com_arguments([unwrap(a) for a in [NumberType]])
        self.com_object.RemoveNumbers(*arguments)

    def removenumbers(self, NumberType=None):
        """Alias for RemoveNumbers"""
        arguments = [NumberType]
        return self.RemoveNumbers(*arguments)

    def remove_numbers(self, NumberType=None):
        """Alias for RemoveNumbers"""
        arguments = [NumberType]
        return self.RemoveNumbers(*arguments)


class ListEntries:

    def __init__(self, listentries=None):
        self.com_object= listentries

    def __call__(self, item):
        return ListEntrie(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Index]])
        return ListEntry(self.com_object.Add(*arguments))

    def add(self, Name=None, Index=None):
        """Alias for Add"""
        arguments = [Name, Index]
        return self.Add(*arguments)

    def Clear(self):
        self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ListEntry(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ListEntry:

    def __init__(self, listentry=None):
        self.com_object= listentry

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class ListFormat:

    def __init__(self, listformat=None):
        self.com_object= listformat

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def List(self):
        return List(self.com_object.List)

    @property
    def list(self):
        """Alias for List"""
        return self.List

    @property
    def ListLevelNumber(self):
        return ListFormat(self.com_object.ListLevelNumber)

    @ListLevelNumber.setter
    def ListLevelNumber(self, value):
        self.com_object.ListLevelNumber = value

    @property
    def listlevelnumber(self):
        """Alias for ListLevelNumber"""
        return self.ListLevelNumber

    @listlevelnumber.setter
    def listlevelnumber(self, value):
        """Alias for ListLevelNumber.setter"""
        self.ListLevelNumber = value

    @property
    def list_level_number(self):
        """Alias for ListLevelNumber"""
        return self.ListLevelNumber

    @list_level_number.setter
    def list_level_number(self, value):
        """Alias for ListLevelNumber.setter"""
        self.ListLevelNumber = value

    @property
    def ListPictureBullet(self):
        return InlineShape(self.com_object.ListPictureBullet)

    @property
    def listpicturebullet(self):
        """Alias for ListPictureBullet"""
        return self.ListPictureBullet

    @property
    def list_picture_bullet(self):
        """Alias for ListPictureBullet"""
        return self.ListPictureBullet

    @property
    def ListString(self):
        return self.com_object.ListString

    @property
    def liststring(self):
        """Alias for ListString"""
        return self.ListString

    @property
    def list_string(self):
        """Alias for ListString"""
        return self.ListString

    @property
    def ListTemplate(self):
        return ListTemplate(self.com_object.ListTemplate)

    @property
    def listtemplate(self):
        """Alias for ListTemplate"""
        return self.ListTemplate

    @property
    def list_template(self):
        """Alias for ListTemplate"""
        return self.ListTemplate

    @property
    def ListType(self):
        return ListFormat(self.com_object.ListType)

    @property
    def listtype(self):
        """Alias for ListType"""
        return self.ListType

    @property
    def list_type(self):
        """Alias for ListType"""
        return self.ListType

    @property
    def ListValue(self):
        return ListFormat(self.com_object.ListValue)

    @property
    def listvalue(self):
        """Alias for ListValue"""
        return self.ListValue

    @property
    def list_value(self):
        """Alias for ListValue"""
        return self.ListValue

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SingleList(self):
        return self.com_object.SingleList

    @property
    def singlelist(self):
        """Alias for SingleList"""
        return self.SingleList

    @property
    def single_list(self):
        """Alias for SingleList"""
        return self.SingleList

    @property
    def SingleListTemplate(self):
        return self.com_object.SingleListTemplate

    @property
    def singlelisttemplate(self):
        """Alias for SingleListTemplate"""
        return self.SingleListTemplate

    @property
    def single_list_template(self):
        """Alias for SingleListTemplate"""
        return self.SingleListTemplate

    def ApplyBulletDefault(self, DefaultListBehavior=None):
        arguments = com_arguments([unwrap(a) for a in [DefaultListBehavior]])
        self.com_object.ApplyBulletDefault(*arguments)

    def applybulletdefault(self, DefaultListBehavior=None):
        """Alias for ApplyBulletDefault"""
        arguments = [DefaultListBehavior]
        return self.ApplyBulletDefault(*arguments)

    def apply_bullet_default(self, DefaultListBehavior=None):
        """Alias for ApplyBulletDefault"""
        arguments = [DefaultListBehavior]
        return self.ApplyBulletDefault(*arguments)

    def ApplyListTemplate(self, ListTemplate=None, ContinuePreviousList=None, ApplyTo=None, DefaultListBehavior=None):
        arguments = com_arguments([unwrap(a) for a in [ListTemplate, ContinuePreviousList, ApplyTo, DefaultListBehavior]])
        self.com_object.ApplyListTemplate(*arguments)

    def applylisttemplate(self, ListTemplate=None, ContinuePreviousList=None, ApplyTo=None, DefaultListBehavior=None):
        """Alias for ApplyListTemplate"""
        arguments = [ListTemplate, ContinuePreviousList, ApplyTo, DefaultListBehavior]
        return self.ApplyListTemplate(*arguments)

    def apply_list_template(self, ListTemplate=None, ContinuePreviousList=None, ApplyTo=None, DefaultListBehavior=None):
        """Alias for ApplyListTemplate"""
        arguments = [ListTemplate, ContinuePreviousList, ApplyTo, DefaultListBehavior]
        return self.ApplyListTemplate(*arguments)

    def ApplyListTemplateWithLevel(self, ListTemplate=None, ContinuePreviousList=None, ApplyTo=None, DefaultListBehavior=None, ApplyLevel=None):
        arguments = com_arguments([unwrap(a) for a in [ListTemplate, ContinuePreviousList, ApplyTo, DefaultListBehavior, ApplyLevel]])
        self.com_object.ApplyListTemplateWithLevel(*arguments)

    def applylisttemplatewithlevel(self, ListTemplate=None, ContinuePreviousList=None, ApplyTo=None, DefaultListBehavior=None, ApplyLevel=None):
        """Alias for ApplyListTemplateWithLevel"""
        arguments = [ListTemplate, ContinuePreviousList, ApplyTo, DefaultListBehavior, ApplyLevel]
        return self.ApplyListTemplateWithLevel(*arguments)

    def apply_list_template_with_level(self, ListTemplate=None, ContinuePreviousList=None, ApplyTo=None, DefaultListBehavior=None, ApplyLevel=None):
        """Alias for ApplyListTemplateWithLevel"""
        arguments = [ListTemplate, ContinuePreviousList, ApplyTo, DefaultListBehavior, ApplyLevel]
        return self.ApplyListTemplateWithLevel(*arguments)

    def ApplyNumberDefault(self, DefaultListBehavior=None):
        arguments = com_arguments([unwrap(a) for a in [DefaultListBehavior]])
        self.com_object.ApplyNumberDefault(*arguments)

    def applynumberdefault(self, DefaultListBehavior=None):
        """Alias for ApplyNumberDefault"""
        arguments = [DefaultListBehavior]
        return self.ApplyNumberDefault(*arguments)

    def apply_number_default(self, DefaultListBehavior=None):
        """Alias for ApplyNumberDefault"""
        arguments = [DefaultListBehavior]
        return self.ApplyNumberDefault(*arguments)

    def ApplyOutlineNumberDefault(self, DefaultListBehavior=None):
        arguments = com_arguments([unwrap(a) for a in [DefaultListBehavior]])
        self.com_object.ApplyOutlineNumberDefault(*arguments)

    def applyoutlinenumberdefault(self, DefaultListBehavior=None):
        """Alias for ApplyOutlineNumberDefault"""
        arguments = [DefaultListBehavior]
        return self.ApplyOutlineNumberDefault(*arguments)

    def apply_outline_number_default(self, DefaultListBehavior=None):
        """Alias for ApplyOutlineNumberDefault"""
        arguments = [DefaultListBehavior]
        return self.ApplyOutlineNumberDefault(*arguments)

    def CanContinuePreviousList(self, ListTemplate=None):
        arguments = com_arguments([unwrap(a) for a in [ListTemplate]])
        self.com_object.CanContinuePreviousList(*arguments)

    def cancontinuepreviouslist(self, ListTemplate=None):
        """Alias for CanContinuePreviousList"""
        arguments = [ListTemplate]
        return self.CanContinuePreviousList(*arguments)

    def can_continue_previous_list(self, ListTemplate=None):
        """Alias for CanContinuePreviousList"""
        arguments = [ListTemplate]
        return self.CanContinuePreviousList(*arguments)

    def ConvertNumbersToText(self):
        self.com_object.ConvertNumbersToText()

    def convertnumberstotext(self):
        """Alias for ConvertNumbersToText"""
        return self.ConvertNumbersToText()

    def convert_numbers_to_text(self):
        """Alias for ConvertNumbersToText"""
        return self.ConvertNumbersToText()

    def CountNumberedItems(self):
        self.com_object.CountNumberedItems()

    def countnumbereditems(self):
        """Alias for CountNumberedItems"""
        return self.CountNumberedItems()

    def count_numbered_items(self):
        """Alias for CountNumberedItems"""
        return self.CountNumberedItems()

    def ListIndent(self):
        self.com_object.ListIndent()

    def listindent(self):
        """Alias for ListIndent"""
        return self.ListIndent()

    def list_indent(self):
        """Alias for ListIndent"""
        return self.ListIndent()

    def ListOutdent(self):
        self.com_object.ListOutdent()

    def listoutdent(self):
        """Alias for ListOutdent"""
        return self.ListOutdent()

    def list_outdent(self):
        """Alias for ListOutdent"""
        return self.ListOutdent()

    def RemoveNumbers(self, NumberType=None):
        arguments = com_arguments([unwrap(a) for a in [NumberType]])
        self.com_object.RemoveNumbers(*arguments)

    def removenumbers(self, NumberType=None):
        """Alias for RemoveNumbers"""
        arguments = [NumberType]
        return self.RemoveNumbers(*arguments)

    def remove_numbers(self, NumberType=None):
        """Alias for RemoveNumbers"""
        arguments = [NumberType]
        return self.RemoveNumbers(*arguments)


class ListGalleries:

    def __init__(self, listgalleries=None):
        self.com_object= listgalleries

    def __call__(self, item):
        return ListGallerie(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ListGallery(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ListGallery:

    def __init__(self, listgallery=None):
        self.com_object= listgallery

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ListTemplates(self):
        return ListTemplates(self.com_object.ListTemplates)

    @property
    def listtemplates(self):
        """Alias for ListTemplates"""
        return self.ListTemplates

    @property
    def list_templates(self):
        """Alias for ListTemplates"""
        return self.ListTemplates

    def Modified(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetModified"):
            return self.com_object.GetModified(*arguments)
        else:
            return self.com_object.Modified(*arguments)

    def modified(self, Index=None):
        """Alias for Modified"""
        arguments = [Index]
        return self.Modified(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Reset(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Reset(*arguments)

    def reset(self, Index=None):
        """Alias for Reset"""
        arguments = [Index]
        return self.Reset(*arguments)


class ListLevel:

    def __init__(self, listlevel=None):
        self.com_object= listlevel

    @property
    def Alignment(self):
        return WdListLevelAlignment(self.com_object.Alignment)

    @Alignment.setter
    def Alignment(self, value):
        self.com_object.Alignment = value

    @property
    def alignment(self):
        """Alias for Alignment"""
        return self.Alignment

    @alignment.setter
    def alignment(self, value):
        """Alias for Alignment.setter"""
        self.Alignment = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @Font.setter
    def Font(self, value):
        self.com_object.Font = value

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @font.setter
    def font(self, value):
        """Alias for Font.setter"""
        self.Font = value

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def LinkedStyle(self):
        return ListLevel(self.com_object.LinkedStyle)

    @LinkedStyle.setter
    def LinkedStyle(self, value):
        self.com_object.LinkedStyle = value

    @property
    def linkedstyle(self):
        """Alias for LinkedStyle"""
        return self.LinkedStyle

    @linkedstyle.setter
    def linkedstyle(self, value):
        """Alias for LinkedStyle.setter"""
        self.LinkedStyle = value

    @property
    def linked_style(self):
        """Alias for LinkedStyle"""
        return self.LinkedStyle

    @linked_style.setter
    def linked_style(self, value):
        """Alias for LinkedStyle.setter"""
        self.LinkedStyle = value

    @property
    def NumberFormat(self):
        return self.com_object.NumberFormat

    @NumberFormat.setter
    def NumberFormat(self, value):
        self.com_object.NumberFormat = value

    @property
    def numberformat(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @numberformat.setter
    def numberformat(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def number_format(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @number_format.setter
    def number_format(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def NumberPosition(self):
        return ListLevel(self.com_object.NumberPosition)

    @NumberPosition.setter
    def NumberPosition(self, value):
        self.com_object.NumberPosition = value

    @property
    def numberposition(self):
        """Alias for NumberPosition"""
        return self.NumberPosition

    @numberposition.setter
    def numberposition(self, value):
        """Alias for NumberPosition.setter"""
        self.NumberPosition = value

    @property
    def number_position(self):
        """Alias for NumberPosition"""
        return self.NumberPosition

    @number_position.setter
    def number_position(self, value):
        """Alias for NumberPosition.setter"""
        self.NumberPosition = value

    @property
    def NumberStyle(self):
        return ListLevel(self.com_object.NumberStyle)

    @NumberStyle.setter
    def NumberStyle(self, value):
        self.com_object.NumberStyle = value

    @property
    def numberstyle(self):
        """Alias for NumberStyle"""
        return self.NumberStyle

    @numberstyle.setter
    def numberstyle(self, value):
        """Alias for NumberStyle.setter"""
        self.NumberStyle = value

    @property
    def number_style(self):
        """Alias for NumberStyle"""
        return self.NumberStyle

    @number_style.setter
    def number_style(self, value):
        """Alias for NumberStyle.setter"""
        self.NumberStyle = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PictureBullet(self):
        return InlineShape(self.com_object.PictureBullet)

    @property
    def picturebullet(self):
        """Alias for PictureBullet"""
        return self.PictureBullet

    @property
    def picture_bullet(self):
        """Alias for PictureBullet"""
        return self.PictureBullet

    @property
    def ResetOnHigher(self):
        return self.com_object.ResetOnHigher

    @ResetOnHigher.setter
    def ResetOnHigher(self, value):
        self.com_object.ResetOnHigher = value

    @property
    def resetonhigher(self):
        """Alias for ResetOnHigher"""
        return self.ResetOnHigher

    @resetonhigher.setter
    def resetonhigher(self, value):
        """Alias for ResetOnHigher.setter"""
        self.ResetOnHigher = value

    @property
    def reset_on_higher(self):
        """Alias for ResetOnHigher"""
        return self.ResetOnHigher

    @reset_on_higher.setter
    def reset_on_higher(self, value):
        """Alias for ResetOnHigher.setter"""
        self.ResetOnHigher = value

    @property
    def StartAt(self):
        return ListLevel(self.com_object.StartAt)

    @StartAt.setter
    def StartAt(self, value):
        self.com_object.StartAt = value

    @property
    def startat(self):
        """Alias for StartAt"""
        return self.StartAt

    @startat.setter
    def startat(self, value):
        """Alias for StartAt.setter"""
        self.StartAt = value

    @property
    def start_at(self):
        """Alias for StartAt"""
        return self.StartAt

    @start_at.setter
    def start_at(self, value):
        """Alias for StartAt.setter"""
        self.StartAt = value

    @property
    def TabPosition(self):
        return ListLevel(self.com_object.TabPosition)

    @TabPosition.setter
    def TabPosition(self, value):
        self.com_object.TabPosition = value

    @property
    def tabposition(self):
        """Alias for TabPosition"""
        return self.TabPosition

    @tabposition.setter
    def tabposition(self, value):
        """Alias for TabPosition.setter"""
        self.TabPosition = value

    @property
    def tab_position(self):
        """Alias for TabPosition"""
        return self.TabPosition

    @tab_position.setter
    def tab_position(self, value):
        """Alias for TabPosition.setter"""
        self.TabPosition = value

    @property
    def TextPosition(self):
        return ListLevel(self.com_object.TextPosition)

    @TextPosition.setter
    def TextPosition(self, value):
        self.com_object.TextPosition = value

    @property
    def textposition(self):
        """Alias for TextPosition"""
        return self.TextPosition

    @textposition.setter
    def textposition(self, value):
        """Alias for TextPosition.setter"""
        self.TextPosition = value

    @property
    def text_position(self):
        """Alias for TextPosition"""
        return self.TextPosition

    @text_position.setter
    def text_position(self, value):
        """Alias for TextPosition.setter"""
        self.TextPosition = value

    @property
    def TrailingCharacter(self):
        return WdTrailingCharacter(self.com_object.TrailingCharacter)

    @TrailingCharacter.setter
    def TrailingCharacter(self, value):
        self.com_object.TrailingCharacter = value

    @property
    def trailingcharacter(self):
        """Alias for TrailingCharacter"""
        return self.TrailingCharacter

    @trailingcharacter.setter
    def trailingcharacter(self, value):
        """Alias for TrailingCharacter.setter"""
        self.TrailingCharacter = value

    @property
    def trailing_character(self):
        """Alias for TrailingCharacter"""
        return self.TrailingCharacter

    @trailing_character.setter
    def trailing_character(self, value):
        """Alias for TrailingCharacter.setter"""
        self.TrailingCharacter = value

    def ApplyPictureBullet(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        self.com_object.ApplyPictureBullet(*arguments)

    def applypicturebullet(self, FileName=None):
        """Alias for ApplyPictureBullet"""
        arguments = [FileName]
        return self.ApplyPictureBullet(*arguments)

    def apply_picture_bullet(self, FileName=None):
        """Alias for ApplyPictureBullet"""
        arguments = [FileName]
        return self.ApplyPictureBullet(*arguments)


class ListLevels:

    def __init__(self, listlevels=None):
        self.com_object= listlevels

    def __call__(self, item):
        return ListLevel(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ListLevel(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ListParagraphs:

    def __init__(self, listparagraphs=None):
        self.com_object= listparagraphs

    def __call__(self, item):
        return ListParagraph(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Paragraph(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Lists:

    def __init__(self, lists=None):
        self.com_object= lists

    def __call__(self, item):
        return List(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return List(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ListTemplate:

    def __init__(self, listtemplate=None):
        self.com_object= listtemplate

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ListLevels(self):
        return ListLevels(self.com_object.ListLevels)

    @property
    def listlevels(self):
        """Alias for ListLevels"""
        return self.ListLevels

    @property
    def list_levels(self):
        """Alias for ListLevels"""
        return self.ListLevels

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def OutlineNumbered(self):
        return self.com_object.OutlineNumbered

    @OutlineNumbered.setter
    def OutlineNumbered(self, value):
        self.com_object.OutlineNumbered = value

    @property
    def outlinenumbered(self):
        """Alias for OutlineNumbered"""
        return self.OutlineNumbered

    @outlinenumbered.setter
    def outlinenumbered(self, value):
        """Alias for OutlineNumbered.setter"""
        self.OutlineNumbered = value

    @property
    def outline_numbered(self):
        """Alias for OutlineNumbered"""
        return self.OutlineNumbered

    @outline_numbered.setter
    def outline_numbered(self, value):
        """Alias for OutlineNumbered.setter"""
        self.OutlineNumbered = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Convert(self, Level=None):
        arguments = com_arguments([unwrap(a) for a in [Level]])
        self.com_object.Convert(*arguments)

    def convert(self, Level=None):
        """Alias for Convert"""
        arguments = [Level]
        return self.Convert(*arguments)


class ListTemplates:

    def __init__(self, listtemplates=None):
        self.com_object= listtemplates

    def __call__(self, item):
        return ListTemplate(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, OutlineNumbered=None, Name=None):
        arguments = com_arguments([unwrap(a) for a in [OutlineNumbered, Name]])
        return ListTemplate(self.com_object.Add(*arguments))

    def add(self, OutlineNumbered=None, Name=None):
        """Alias for Add"""
        arguments = [OutlineNumbered, Name]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ListTemplate(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class MailingLabel:

    def __init__(self, mailinglabel=None):
        self.com_object= mailinglabel

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def CustomLabels(self):
        return CustomLabels(self.com_object.CustomLabels)

    @property
    def customlabels(self):
        """Alias for CustomLabels"""
        return self.CustomLabels

    @property
    def custom_labels(self):
        """Alias for CustomLabels"""
        return self.CustomLabels

    @property
    def DefaultLabelName(self):
        return self.com_object.DefaultLabelName

    @DefaultLabelName.setter
    def DefaultLabelName(self, value):
        self.com_object.DefaultLabelName = value

    @property
    def defaultlabelname(self):
        """Alias for DefaultLabelName"""
        return self.DefaultLabelName

    @defaultlabelname.setter
    def defaultlabelname(self, value):
        """Alias for DefaultLabelName.setter"""
        self.DefaultLabelName = value

    @property
    def default_label_name(self):
        """Alias for DefaultLabelName"""
        return self.DefaultLabelName

    @default_label_name.setter
    def default_label_name(self, value):
        """Alias for DefaultLabelName.setter"""
        self.DefaultLabelName = value

    @property
    def DefaultLaserTray(self):
        return WdPaperTray(self.com_object.DefaultLaserTray)

    @DefaultLaserTray.setter
    def DefaultLaserTray(self, value):
        self.com_object.DefaultLaserTray = value

    @property
    def defaultlasertray(self):
        """Alias for DefaultLaserTray"""
        return self.DefaultLaserTray

    @defaultlasertray.setter
    def defaultlasertray(self, value):
        """Alias for DefaultLaserTray.setter"""
        self.DefaultLaserTray = value

    @property
    def default_laser_tray(self):
        """Alias for DefaultLaserTray"""
        return self.DefaultLaserTray

    @default_laser_tray.setter
    def default_laser_tray(self, value):
        """Alias for DefaultLaserTray.setter"""
        self.DefaultLaserTray = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Vertical(self):
        return self.com_object.Vertical

    @Vertical.setter
    def Vertical(self, value):
        self.com_object.Vertical = value

    @property
    def vertical(self):
        """Alias for Vertical"""
        return self.Vertical

    @vertical.setter
    def vertical(self, value):
        """Alias for Vertical.setter"""
        self.Vertical = value

    def CreateNewDocument(self, Name=None, Address=None, AutoText=None, ExtractAddress=None, LaserTray=None, PrintEPostageLabel=None, Vertical=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Address, AutoText, ExtractAddress, LaserTray, PrintEPostageLabel, Vertical]])
        return Document(self.com_object.CreateNewDocument(*arguments))

    def createnewdocument(self, Name=None, Address=None, AutoText=None, ExtractAddress=None, LaserTray=None, PrintEPostageLabel=None, Vertical=None):
        """Alias for CreateNewDocument"""
        arguments = [Name, Address, AutoText, ExtractAddress, LaserTray, PrintEPostageLabel, Vertical]
        return self.CreateNewDocument(*arguments)

    def create_new_document(self, Name=None, Address=None, AutoText=None, ExtractAddress=None, LaserTray=None, PrintEPostageLabel=None, Vertical=None):
        """Alias for CreateNewDocument"""
        arguments = [Name, Address, AutoText, ExtractAddress, LaserTray, PrintEPostageLabel, Vertical]
        return self.CreateNewDocument(*arguments)

    def CreateNewDocumentByID(self, LabelID=None, Address=None, AutoText=None, ExtractAddress=None, LaserTray=None, PrintEPostageLabel=None, Vertical=None):
        arguments = com_arguments([unwrap(a) for a in [LabelID, Address, AutoText, ExtractAddress, LaserTray, PrintEPostageLabel, Vertical]])
        return Document(self.com_object.CreateNewDocumentByID(*arguments))

    def createnewdocumentbyid(self, LabelID=None, Address=None, AutoText=None, ExtractAddress=None, LaserTray=None, PrintEPostageLabel=None, Vertical=None):
        """Alias for CreateNewDocumentByID"""
        arguments = [LabelID, Address, AutoText, ExtractAddress, LaserTray, PrintEPostageLabel, Vertical]
        return self.CreateNewDocumentByID(*arguments)

    def create_new_document_by_i_d(self, LabelID=None, Address=None, AutoText=None, ExtractAddress=None, LaserTray=None, PrintEPostageLabel=None, Vertical=None):
        """Alias for CreateNewDocumentByID"""
        arguments = [LabelID, Address, AutoText, ExtractAddress, LaserTray, PrintEPostageLabel, Vertical]
        return self.CreateNewDocumentByID(*arguments)

    def LabelOptions(self):
        self.com_object.LabelOptions()

    def labeloptions(self):
        """Alias for LabelOptions"""
        return self.LabelOptions()

    def label_options(self):
        """Alias for LabelOptions"""
        return self.LabelOptions()

    def PrintOut(self, Name=None, Address=None, ExtractAddress=None, LaserTray=None, SingleLabel=None, Row=None, Column=None, PrintEPostageLabel=None, Vertical=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Address, ExtractAddress, LaserTray, SingleLabel, Row, Column, PrintEPostageLabel, Vertical]])
        self.com_object.PrintOut(*arguments)

    def printout(self, Name=None, Address=None, ExtractAddress=None, LaserTray=None, SingleLabel=None, Row=None, Column=None, PrintEPostageLabel=None, Vertical=None):
        """Alias for PrintOut"""
        arguments = [Name, Address, ExtractAddress, LaserTray, SingleLabel, Row, Column, PrintEPostageLabel, Vertical]
        return self.PrintOut(*arguments)

    def print_out(self, Name=None, Address=None, ExtractAddress=None, LaserTray=None, SingleLabel=None, Row=None, Column=None, PrintEPostageLabel=None, Vertical=None):
        """Alias for PrintOut"""
        arguments = [Name, Address, ExtractAddress, LaserTray, SingleLabel, Row, Column, PrintEPostageLabel, Vertical]
        return self.PrintOut(*arguments)

    def PrintOutByID(self, LabelID=None, Address=None, ExtractAddress=None, LaserTray=None, SingleLabel=None, Row=None, Column=None, PrintEPostageLabel=None, Vertical=None):
        arguments = com_arguments([unwrap(a) for a in [LabelID, Address, ExtractAddress, LaserTray, SingleLabel, Row, Column, PrintEPostageLabel, Vertical]])
        self.com_object.PrintOutByID(*arguments)

    def printoutbyid(self, LabelID=None, Address=None, ExtractAddress=None, LaserTray=None, SingleLabel=None, Row=None, Column=None, PrintEPostageLabel=None, Vertical=None):
        """Alias for PrintOutByID"""
        arguments = [LabelID, Address, ExtractAddress, LaserTray, SingleLabel, Row, Column, PrintEPostageLabel, Vertical]
        return self.PrintOutByID(*arguments)

    def print_out_by_i_d(self, LabelID=None, Address=None, ExtractAddress=None, LaserTray=None, SingleLabel=None, Row=None, Column=None, PrintEPostageLabel=None, Vertical=None):
        """Alias for PrintOutByID"""
        arguments = [LabelID, Address, ExtractAddress, LaserTray, SingleLabel, Row, Column, PrintEPostageLabel, Vertical]
        return self.PrintOutByID(*arguments)


class MailMerge:

    def __init__(self, mailmerge=None):
        self.com_object= mailmerge

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DataSource(self):
        return MailMergeDataSource(self.com_object.DataSource)

    @property
    def datasource(self):
        """Alias for DataSource"""
        return self.DataSource

    @property
    def data_source(self):
        """Alias for DataSource"""
        return self.DataSource

    @property
    def Destination(self):
        return WdMailMergeDestination(self.com_object.Destination)

    @Destination.setter
    def Destination(self, value):
        self.com_object.Destination = value

    @property
    def destination(self):
        """Alias for Destination"""
        return self.Destination

    @destination.setter
    def destination(self, value):
        """Alias for Destination.setter"""
        self.Destination = value

    @property
    def Fields(self):
        return MailMergeFields(self.com_object.Fields)

    @property
    def fields(self):
        """Alias for Fields"""
        return self.Fields

    @property
    def HighlightMergeFields(self):
        return self.com_object.HighlightMergeFields

    @HighlightMergeFields.setter
    def HighlightMergeFields(self, value):
        self.com_object.HighlightMergeFields = value

    @property
    def highlightmergefields(self):
        """Alias for HighlightMergeFields"""
        return self.HighlightMergeFields

    @highlightmergefields.setter
    def highlightmergefields(self, value):
        """Alias for HighlightMergeFields.setter"""
        self.HighlightMergeFields = value

    @property
    def highlight_merge_fields(self):
        """Alias for HighlightMergeFields"""
        return self.HighlightMergeFields

    @highlight_merge_fields.setter
    def highlight_merge_fields(self, value):
        """Alias for HighlightMergeFields.setter"""
        self.HighlightMergeFields = value

    @property
    def MailAddressFieldName(self):
        return self.com_object.MailAddressFieldName

    @MailAddressFieldName.setter
    def MailAddressFieldName(self, value):
        self.com_object.MailAddressFieldName = value

    @property
    def mailaddressfieldname(self):
        """Alias for MailAddressFieldName"""
        return self.MailAddressFieldName

    @mailaddressfieldname.setter
    def mailaddressfieldname(self, value):
        """Alias for MailAddressFieldName.setter"""
        self.MailAddressFieldName = value

    @property
    def mail_address_field_name(self):
        """Alias for MailAddressFieldName"""
        return self.MailAddressFieldName

    @mail_address_field_name.setter
    def mail_address_field_name(self, value):
        """Alias for MailAddressFieldName.setter"""
        self.MailAddressFieldName = value

    @property
    def MailAsAttachment(self):
        return self.com_object.MailAsAttachment

    @MailAsAttachment.setter
    def MailAsAttachment(self, value):
        self.com_object.MailAsAttachment = value

    @property
    def mailasattachment(self):
        """Alias for MailAsAttachment"""
        return self.MailAsAttachment

    @mailasattachment.setter
    def mailasattachment(self, value):
        """Alias for MailAsAttachment.setter"""
        self.MailAsAttachment = value

    @property
    def mail_as_attachment(self):
        """Alias for MailAsAttachment"""
        return self.MailAsAttachment

    @mail_as_attachment.setter
    def mail_as_attachment(self, value):
        """Alias for MailAsAttachment.setter"""
        self.MailAsAttachment = value

    @property
    def MailFormat(self):
        return WdMailMergeMailFormat(self.com_object.MailFormat)

    @MailFormat.setter
    def MailFormat(self, value):
        self.com_object.MailFormat = value

    @property
    def mailformat(self):
        """Alias for MailFormat"""
        return self.MailFormat

    @mailformat.setter
    def mailformat(self, value):
        """Alias for MailFormat.setter"""
        self.MailFormat = value

    @property
    def mail_format(self):
        """Alias for MailFormat"""
        return self.MailFormat

    @mail_format.setter
    def mail_format(self, value):
        """Alias for MailFormat.setter"""
        self.MailFormat = value

    @property
    def MailSubject(self):
        return self.com_object.MailSubject

    @MailSubject.setter
    def MailSubject(self, value):
        self.com_object.MailSubject = value

    @property
    def mailsubject(self):
        """Alias for MailSubject"""
        return self.MailSubject

    @mailsubject.setter
    def mailsubject(self, value):
        """Alias for MailSubject.setter"""
        self.MailSubject = value

    @property
    def mail_subject(self):
        """Alias for MailSubject"""
        return self.MailSubject

    @mail_subject.setter
    def mail_subject(self, value):
        """Alias for MailSubject.setter"""
        self.MailSubject = value

    @property
    def MainDocumentType(self):
        return WdMailMergeMainDocType(self.com_object.MainDocumentType)

    @MainDocumentType.setter
    def MainDocumentType(self, value):
        self.com_object.MainDocumentType = value

    @property
    def maindocumenttype(self):
        """Alias for MainDocumentType"""
        return self.MainDocumentType

    @maindocumenttype.setter
    def maindocumenttype(self, value):
        """Alias for MainDocumentType.setter"""
        self.MainDocumentType = value

    @property
    def main_document_type(self):
        """Alias for MainDocumentType"""
        return self.MainDocumentType

    @main_document_type.setter
    def main_document_type(self, value):
        """Alias for MainDocumentType.setter"""
        self.MainDocumentType = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ShowSendToCustom(self):
        return self.com_object.ShowSendToCustom

    @ShowSendToCustom.setter
    def ShowSendToCustom(self, value):
        self.com_object.ShowSendToCustom = value

    @property
    def showsendtocustom(self):
        """Alias for ShowSendToCustom"""
        return self.ShowSendToCustom

    @showsendtocustom.setter
    def showsendtocustom(self, value):
        """Alias for ShowSendToCustom.setter"""
        self.ShowSendToCustom = value

    @property
    def show_send_to_custom(self):
        """Alias for ShowSendToCustom"""
        return self.ShowSendToCustom

    @show_send_to_custom.setter
    def show_send_to_custom(self, value):
        """Alias for ShowSendToCustom.setter"""
        self.ShowSendToCustom = value

    @property
    def State(self):
        return WdMailMergeState(self.com_object.State)

    @property
    def state(self):
        """Alias for State"""
        return self.State

    @property
    def SuppressBlankLines(self):
        return self.com_object.SuppressBlankLines

    @SuppressBlankLines.setter
    def SuppressBlankLines(self, value):
        self.com_object.SuppressBlankLines = value

    @property
    def suppressblanklines(self):
        """Alias for SuppressBlankLines"""
        return self.SuppressBlankLines

    @suppressblanklines.setter
    def suppressblanklines(self, value):
        """Alias for SuppressBlankLines.setter"""
        self.SuppressBlankLines = value

    @property
    def suppress_blank_lines(self):
        """Alias for SuppressBlankLines"""
        return self.SuppressBlankLines

    @suppress_blank_lines.setter
    def suppress_blank_lines(self, value):
        """Alias for SuppressBlankLines.setter"""
        self.SuppressBlankLines = value

    @property
    def ViewMailMergeFieldCodes(self):
        return self.com_object.ViewMailMergeFieldCodes

    @ViewMailMergeFieldCodes.setter
    def ViewMailMergeFieldCodes(self, value):
        self.com_object.ViewMailMergeFieldCodes = value

    @property
    def viewmailmergefieldcodes(self):
        """Alias for ViewMailMergeFieldCodes"""
        return self.ViewMailMergeFieldCodes

    @viewmailmergefieldcodes.setter
    def viewmailmergefieldcodes(self, value):
        """Alias for ViewMailMergeFieldCodes.setter"""
        self.ViewMailMergeFieldCodes = value

    @property
    def view_mail_merge_field_codes(self):
        """Alias for ViewMailMergeFieldCodes"""
        return self.ViewMailMergeFieldCodes

    @view_mail_merge_field_codes.setter
    def view_mail_merge_field_codes(self, value):
        """Alias for ViewMailMergeFieldCodes.setter"""
        self.ViewMailMergeFieldCodes = value

    @property
    def WizardState(self):
        return self.com_object.WizardState

    @WizardState.setter
    def WizardState(self, value):
        self.com_object.WizardState = value

    @property
    def wizardstate(self):
        """Alias for WizardState"""
        return self.WizardState

    @wizardstate.setter
    def wizardstate(self, value):
        """Alias for WizardState.setter"""
        self.WizardState = value

    @property
    def wizard_state(self):
        """Alias for WizardState"""
        return self.WizardState

    @wizard_state.setter
    def wizard_state(self, value):
        """Alias for WizardState.setter"""
        self.WizardState = value

    def Check(self):
        self.com_object.Check()

    def check(self):
        """Alias for Check"""
        return self.Check()

    def CreateDataSource(self, Name=None, PasswordDocument=None, WritePasswordDocument=None, HeaderRecord=None, MSQuery=None, SQLStatement=None, SQLStatement1=None, Connection=None, LinkToSource=None):
        arguments = com_arguments([unwrap(a) for a in [Name, PasswordDocument, WritePasswordDocument, HeaderRecord, MSQuery, SQLStatement, SQLStatement1, Connection, LinkToSource]])
        self.com_object.CreateDataSource(*arguments)

    def createdatasource(self, Name=None, PasswordDocument=None, WritePasswordDocument=None, HeaderRecord=None, MSQuery=None, SQLStatement=None, SQLStatement1=None, Connection=None, LinkToSource=None):
        """Alias for CreateDataSource"""
        arguments = [Name, PasswordDocument, WritePasswordDocument, HeaderRecord, MSQuery, SQLStatement, SQLStatement1, Connection, LinkToSource]
        return self.CreateDataSource(*arguments)

    def create_data_source(self, Name=None, PasswordDocument=None, WritePasswordDocument=None, HeaderRecord=None, MSQuery=None, SQLStatement=None, SQLStatement1=None, Connection=None, LinkToSource=None):
        """Alias for CreateDataSource"""
        arguments = [Name, PasswordDocument, WritePasswordDocument, HeaderRecord, MSQuery, SQLStatement, SQLStatement1, Connection, LinkToSource]
        return self.CreateDataSource(*arguments)

    def CreateHeaderSource(self, Name=None, PasswordDocument=None, WritePasswordDocument=None, HeaderRecord=None):
        arguments = com_arguments([unwrap(a) for a in [Name, PasswordDocument, WritePasswordDocument, HeaderRecord]])
        self.com_object.CreateHeaderSource(*arguments)

    def createheadersource(self, Name=None, PasswordDocument=None, WritePasswordDocument=None, HeaderRecord=None):
        """Alias for CreateHeaderSource"""
        arguments = [Name, PasswordDocument, WritePasswordDocument, HeaderRecord]
        return self.CreateHeaderSource(*arguments)

    def create_header_source(self, Name=None, PasswordDocument=None, WritePasswordDocument=None, HeaderRecord=None):
        """Alias for CreateHeaderSource"""
        arguments = [Name, PasswordDocument, WritePasswordDocument, HeaderRecord]
        return self.CreateHeaderSource(*arguments)

    def EditDataSource(self):
        self.com_object.EditDataSource()

    def editdatasource(self):
        """Alias for EditDataSource"""
        return self.EditDataSource()

    def edit_data_source(self):
        """Alias for EditDataSource"""
        return self.EditDataSource()

    def EditHeaderSource(self):
        self.com_object.EditHeaderSource()

    def editheadersource(self):
        """Alias for EditHeaderSource"""
        return self.EditHeaderSource()

    def edit_header_source(self):
        """Alias for EditHeaderSource"""
        return self.EditHeaderSource()

    def EditMainDocument(self):
        self.com_object.EditMainDocument()

    def editmaindocument(self):
        """Alias for EditMainDocument"""
        return self.EditMainDocument()

    def edit_main_document(self):
        """Alias for EditMainDocument"""
        return self.EditMainDocument()

    def Execute(self, Pause=None):
        arguments = com_arguments([unwrap(a) for a in [Pause]])
        self.com_object.Execute(*arguments)

    def execute(self, Pause=None):
        """Alias for Execute"""
        arguments = [Pause]
        return self.Execute(*arguments)

    def OpenDataSource(self, Name=None, Format=None, ConfirmConversions=None, ReadOnly=None, LinkToSource=None, AddToRecentFiles=None, PasswordDocument=None, PasswordTemplate=None, Revert=None, WritePasswordDocument=None, WritePasswordTemplate=None, Connection=None, SQLStatement=None, SQLStatement1=None, OpenExclusive=None, SubType=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Format, ConfirmConversions, ReadOnly, LinkToSource, AddToRecentFiles, PasswordDocument, PasswordTemplate, Revert, WritePasswordDocument, WritePasswordTemplate, Connection, SQLStatement, SQLStatement1, OpenExclusive, SubType]])
        self.com_object.OpenDataSource(*arguments)

    def opendatasource(self, Name=None, Format=None, ConfirmConversions=None, ReadOnly=None, LinkToSource=None, AddToRecentFiles=None, PasswordDocument=None, PasswordTemplate=None, Revert=None, WritePasswordDocument=None, WritePasswordTemplate=None, Connection=None, SQLStatement=None, SQLStatement1=None, OpenExclusive=None, SubType=None):
        """Alias for OpenDataSource"""
        arguments = [Name, Format, ConfirmConversions, ReadOnly, LinkToSource, AddToRecentFiles, PasswordDocument, PasswordTemplate, Revert, WritePasswordDocument, WritePasswordTemplate, Connection, SQLStatement, SQLStatement1, OpenExclusive, SubType]
        return self.OpenDataSource(*arguments)

    def open_data_source(self, Name=None, Format=None, ConfirmConversions=None, ReadOnly=None, LinkToSource=None, AddToRecentFiles=None, PasswordDocument=None, PasswordTemplate=None, Revert=None, WritePasswordDocument=None, WritePasswordTemplate=None, Connection=None, SQLStatement=None, SQLStatement1=None, OpenExclusive=None, SubType=None):
        """Alias for OpenDataSource"""
        arguments = [Name, Format, ConfirmConversions, ReadOnly, LinkToSource, AddToRecentFiles, PasswordDocument, PasswordTemplate, Revert, WritePasswordDocument, WritePasswordTemplate, Connection, SQLStatement, SQLStatement1, OpenExclusive, SubType]
        return self.OpenDataSource(*arguments)

    def OpenHeaderSource(self, Name=None, Format=None, ConfirmConversions=None, ReadOnly=None, AddToRecentFiles=None, PasswordDocument=None, PasswordTemplate=None, Revert=None, WritePasswordDocument=None, WritePasswordTemplate=None, OpenExclusive=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Format, ConfirmConversions, ReadOnly, AddToRecentFiles, PasswordDocument, PasswordTemplate, Revert, WritePasswordDocument, WritePasswordTemplate, OpenExclusive]])
        self.com_object.OpenHeaderSource(*arguments)

    def openheadersource(self, Name=None, Format=None, ConfirmConversions=None, ReadOnly=None, AddToRecentFiles=None, PasswordDocument=None, PasswordTemplate=None, Revert=None, WritePasswordDocument=None, WritePasswordTemplate=None, OpenExclusive=None):
        """Alias for OpenHeaderSource"""
        arguments = [Name, Format, ConfirmConversions, ReadOnly, AddToRecentFiles, PasswordDocument, PasswordTemplate, Revert, WritePasswordDocument, WritePasswordTemplate, OpenExclusive]
        return self.OpenHeaderSource(*arguments)

    def open_header_source(self, Name=None, Format=None, ConfirmConversions=None, ReadOnly=None, AddToRecentFiles=None, PasswordDocument=None, PasswordTemplate=None, Revert=None, WritePasswordDocument=None, WritePasswordTemplate=None, OpenExclusive=None):
        """Alias for OpenHeaderSource"""
        arguments = [Name, Format, ConfirmConversions, ReadOnly, AddToRecentFiles, PasswordDocument, PasswordTemplate, Revert, WritePasswordDocument, WritePasswordTemplate, OpenExclusive]
        return self.OpenHeaderSource(*arguments)

    def ShowWizard(self, InitialState=None, ShowDocumentStep=None, ShowTemplateStep=None, ShowDataStep=None, ShowWriteStep=None, ShowPreviewStep=None, ShowMergeStep=None):
        arguments = com_arguments([unwrap(a) for a in [InitialState, ShowDocumentStep, ShowTemplateStep, ShowDataStep, ShowWriteStep, ShowPreviewStep, ShowMergeStep]])
        self.com_object.ShowWizard(*arguments)

    def showwizard(self, InitialState=None, ShowDocumentStep=None, ShowTemplateStep=None, ShowDataStep=None, ShowWriteStep=None, ShowPreviewStep=None, ShowMergeStep=None):
        """Alias for ShowWizard"""
        arguments = [InitialState, ShowDocumentStep, ShowTemplateStep, ShowDataStep, ShowWriteStep, ShowPreviewStep, ShowMergeStep]
        return self.ShowWizard(*arguments)

    def show_wizard(self, InitialState=None, ShowDocumentStep=None, ShowTemplateStep=None, ShowDataStep=None, ShowWriteStep=None, ShowPreviewStep=None, ShowMergeStep=None):
        """Alias for ShowWizard"""
        arguments = [InitialState, ShowDocumentStep, ShowTemplateStep, ShowDataStep, ShowWriteStep, ShowPreviewStep, ShowMergeStep]
        return self.ShowWizard(*arguments)


class MailMergeDataField:

    def __init__(self, mailmergedatafield=None):
        self.com_object= mailmergedatafield

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Value(self):
        return self.com_object.Value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value


class MailMergeDataFields:

    def __init__(self, mailmergedatafields=None):
        self.com_object= mailmergedatafields

    def __call__(self, item):
        return MailMergeDataField(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return MailMergeDataField(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class MailMergeDataSource:

    def __init__(self, mailmergedatasource=None):
        self.com_object= mailmergedatasource

    @property
    def ActiveRecord(self):
        return WdMailMergeActiveRecord(self.com_object.ActiveRecord)

    @ActiveRecord.setter
    def ActiveRecord(self, value):
        self.com_object.ActiveRecord = value

    @property
    def activerecord(self):
        """Alias for ActiveRecord"""
        return self.ActiveRecord

    @activerecord.setter
    def activerecord(self, value):
        """Alias for ActiveRecord.setter"""
        self.ActiveRecord = value

    @property
    def active_record(self):
        """Alias for ActiveRecord"""
        return self.ActiveRecord

    @active_record.setter
    def active_record(self, value):
        """Alias for ActiveRecord.setter"""
        self.ActiveRecord = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ConnectString(self):
        return self.com_object.ConnectString

    @property
    def connectstring(self):
        """Alias for ConnectString"""
        return self.ConnectString

    @property
    def connect_string(self):
        """Alias for ConnectString"""
        return self.ConnectString

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DataFields(self):
        return MailMergeDataFields(self.com_object.DataFields)

    @property
    def datafields(self):
        """Alias for DataFields"""
        return self.DataFields

    @property
    def data_fields(self):
        """Alias for DataFields"""
        return self.DataFields

    @property
    def FieldNames(self):
        return MailMergeFieldNames(self.com_object.FieldNames)

    @property
    def fieldnames(self):
        """Alias for FieldNames"""
        return self.FieldNames

    @property
    def field_names(self):
        """Alias for FieldNames"""
        return self.FieldNames

    @property
    def FirstRecord(self):
        return self.com_object.FirstRecord

    @FirstRecord.setter
    def FirstRecord(self, value):
        self.com_object.FirstRecord = value

    @property
    def firstrecord(self):
        """Alias for FirstRecord"""
        return self.FirstRecord

    @firstrecord.setter
    def firstrecord(self, value):
        """Alias for FirstRecord.setter"""
        self.FirstRecord = value

    @property
    def first_record(self):
        """Alias for FirstRecord"""
        return self.FirstRecord

    @first_record.setter
    def first_record(self, value):
        """Alias for FirstRecord.setter"""
        self.FirstRecord = value

    @property
    def HeaderSourceName(self):
        return self.com_object.HeaderSourceName

    @property
    def headersourcename(self):
        """Alias for HeaderSourceName"""
        return self.HeaderSourceName

    @property
    def header_source_name(self):
        """Alias for HeaderSourceName"""
        return self.HeaderSourceName

    @property
    def HeaderSourceType(self):
        return WdMailMergeDataSource(self.com_object.HeaderSourceType)

    @property
    def headersourcetype(self):
        """Alias for HeaderSourceType"""
        return self.HeaderSourceType

    @property
    def header_source_type(self):
        """Alias for HeaderSourceType"""
        return self.HeaderSourceType

    @property
    def Included(self):
        return self.com_object.Included

    @Included.setter
    def Included(self, value):
        self.com_object.Included = value

    @property
    def included(self):
        """Alias for Included"""
        return self.Included

    @included.setter
    def included(self, value):
        """Alias for Included.setter"""
        self.Included = value

    @property
    def InvalidAddress(self):
        return self.com_object.InvalidAddress

    @InvalidAddress.setter
    def InvalidAddress(self, value):
        self.com_object.InvalidAddress = value

    @property
    def invalidaddress(self):
        """Alias for InvalidAddress"""
        return self.InvalidAddress

    @invalidaddress.setter
    def invalidaddress(self, value):
        """Alias for InvalidAddress.setter"""
        self.InvalidAddress = value

    @property
    def invalid_address(self):
        """Alias for InvalidAddress"""
        return self.InvalidAddress

    @invalid_address.setter
    def invalid_address(self, value):
        """Alias for InvalidAddress.setter"""
        self.InvalidAddress = value

    @property
    def InvalidComments(self):
        return self.com_object.InvalidComments

    @InvalidComments.setter
    def InvalidComments(self, value):
        self.com_object.InvalidComments = value

    @property
    def invalidcomments(self):
        """Alias for InvalidComments"""
        return self.InvalidComments

    @invalidcomments.setter
    def invalidcomments(self, value):
        """Alias for InvalidComments.setter"""
        self.InvalidComments = value

    @property
    def invalid_comments(self):
        """Alias for InvalidComments"""
        return self.InvalidComments

    @invalid_comments.setter
    def invalid_comments(self, value):
        """Alias for InvalidComments.setter"""
        self.InvalidComments = value

    @property
    def LastRecord(self):
        return self.com_object.LastRecord

    @LastRecord.setter
    def LastRecord(self, value):
        self.com_object.LastRecord = value

    @property
    def lastrecord(self):
        """Alias for LastRecord"""
        return self.LastRecord

    @lastrecord.setter
    def lastrecord(self, value):
        """Alias for LastRecord.setter"""
        self.LastRecord = value

    @property
    def last_record(self):
        """Alias for LastRecord"""
        return self.LastRecord

    @last_record.setter
    def last_record(self, value):
        """Alias for LastRecord.setter"""
        self.LastRecord = value

    @property
    def MappedDataFields(self):
        return MappedDataFields(self.com_object.MappedDataFields)

    @property
    def mappeddatafields(self):
        """Alias for MappedDataFields"""
        return self.MappedDataFields

    @property
    def mapped_data_fields(self):
        """Alias for MappedDataFields"""
        return self.MappedDataFields

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def QueryString(self):
        return self.com_object.QueryString

    @QueryString.setter
    def QueryString(self, value):
        self.com_object.QueryString = value

    @property
    def querystring(self):
        """Alias for QueryString"""
        return self.QueryString

    @querystring.setter
    def querystring(self, value):
        """Alias for QueryString.setter"""
        self.QueryString = value

    @property
    def query_string(self):
        """Alias for QueryString"""
        return self.QueryString

    @query_string.setter
    def query_string(self, value):
        """Alias for QueryString.setter"""
        self.QueryString = value

    @property
    def RecordCount(self):
        return self.com_object.RecordCount

    @property
    def recordcount(self):
        """Alias for RecordCount"""
        return self.RecordCount

    @property
    def record_count(self):
        """Alias for RecordCount"""
        return self.RecordCount

    @property
    def TableName(self):
        return self.com_object.TableName

    @property
    def tablename(self):
        """Alias for TableName"""
        return self.TableName

    @property
    def table_name(self):
        """Alias for TableName"""
        return self.TableName

    @property
    def Type(self):
        return WdMailMergeDataSource(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def Close(self):
        self.com_object.Close()

    def close(self):
        """Alias for Close"""
        return self.Close()

    def FindRecord(self, FindText=None, Field=None):
        arguments = com_arguments([unwrap(a) for a in [FindText, Field]])
        return self.com_object.FindRecord(*arguments)

    def findrecord(self, FindText=None, Field=None):
        """Alias for FindRecord"""
        arguments = [FindText, Field]
        return self.FindRecord(*arguments)

    def find_record(self, FindText=None, Field=None):
        """Alias for FindRecord"""
        arguments = [FindText, Field]
        return self.FindRecord(*arguments)

    def SetAllErrorFlags(self, Invalid=None, InvalidComment=None):
        arguments = com_arguments([unwrap(a) for a in [Invalid, InvalidComment]])
        self.com_object.SetAllErrorFlags(*arguments)

    def setallerrorflags(self, Invalid=None, InvalidComment=None):
        """Alias for SetAllErrorFlags"""
        arguments = [Invalid, InvalidComment]
        return self.SetAllErrorFlags(*arguments)

    def set_all_error_flags(self, Invalid=None, InvalidComment=None):
        """Alias for SetAllErrorFlags"""
        arguments = [Invalid, InvalidComment]
        return self.SetAllErrorFlags(*arguments)

    def SetAllIncludedFlags(self, Included=None):
        arguments = com_arguments([unwrap(a) for a in [Included]])
        self.com_object.SetAllIncludedFlags(*arguments)

    def setallincludedflags(self, Included=None):
        """Alias for SetAllIncludedFlags"""
        arguments = [Included]
        return self.SetAllIncludedFlags(*arguments)

    def set_all_included_flags(self, Included=None):
        """Alias for SetAllIncludedFlags"""
        arguments = [Included]
        return self.SetAllIncludedFlags(*arguments)


class MailMergeField:

    def __init__(self, mailmergefield=None):
        self.com_object= mailmergefield

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Code(self):
        return Range(self.com_object.Code)

    @Code.setter
    def Code(self, value):
        self.com_object.Code = value

    @property
    def code(self):
        """Alias for Code"""
        return self.Code

    @code.setter
    def code(self, value):
        """Alias for Code.setter"""
        self.Code = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def Next(self):
        return self.com_object.Next

    @property
    def next(self):
        """Alias for Next"""
        return self.Next

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Previous(self):
        return self.com_object.Previous

    @property
    def previous(self):
        """Alias for Previous"""
        return self.Previous

    @property
    def Type(self):
        return WdFieldType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Cut(self):
        self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class MailMergeFieldName:

    def __init__(self, mailmergefieldname=None):
        self.com_object= mailmergefieldname

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class MailMergeFields:

    def __init__(self, mailmergefields=None):
        self.com_object= mailmergefields

    def __call__(self, item):
        return MailMergeField(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Range=None, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Range, Name]])
        return MailMergeField(self.com_object.Add(*arguments))

    def add(self, Range=None, Name=None):
        """Alias for Add"""
        arguments = [Range, Name]
        return self.Add(*arguments)

    def AddAsk(self, Range=None, Name=None, Prompt=None, DefaultAskText=None, AskOnce=None):
        arguments = com_arguments([unwrap(a) for a in [Range, Name, Prompt, DefaultAskText, AskOnce]])
        return MailMergeField(self.com_object.AddAsk(*arguments))

    def addask(self, Range=None, Name=None, Prompt=None, DefaultAskText=None, AskOnce=None):
        """Alias for AddAsk"""
        arguments = [Range, Name, Prompt, DefaultAskText, AskOnce]
        return self.AddAsk(*arguments)

    def add_ask(self, Range=None, Name=None, Prompt=None, DefaultAskText=None, AskOnce=None):
        """Alias for AddAsk"""
        arguments = [Range, Name, Prompt, DefaultAskText, AskOnce]
        return self.AddAsk(*arguments)

    def AddFillIn(self, Range=None, Prompt=None, DefaultFillInText=None, AskOnce=None):
        arguments = com_arguments([unwrap(a) for a in [Range, Prompt, DefaultFillInText, AskOnce]])
        return MailMergeField(self.com_object.AddFillIn(*arguments))

    def addfillin(self, Range=None, Prompt=None, DefaultFillInText=None, AskOnce=None):
        """Alias for AddFillIn"""
        arguments = [Range, Prompt, DefaultFillInText, AskOnce]
        return self.AddFillIn(*arguments)

    def add_fill_in(self, Range=None, Prompt=None, DefaultFillInText=None, AskOnce=None):
        """Alias for AddFillIn"""
        arguments = [Range, Prompt, DefaultFillInText, AskOnce]
        return self.AddFillIn(*arguments)

    def AddIf(self, Range=None, MergeField=None, Comparison=None, CompareTo=None, TrueAutoText=None, TrueText=None, FalseAutoText=None, FalseText=None):
        arguments = com_arguments([unwrap(a) for a in [Range, MergeField, Comparison, CompareTo, TrueAutoText, TrueText, FalseAutoText, FalseText]])
        return MailMergeField(self.com_object.AddIf(*arguments))

    def addif(self, Range=None, MergeField=None, Comparison=None, CompareTo=None, TrueAutoText=None, TrueText=None, FalseAutoText=None, FalseText=None):
        """Alias for AddIf"""
        arguments = [Range, MergeField, Comparison, CompareTo, TrueAutoText, TrueText, FalseAutoText, FalseText]
        return self.AddIf(*arguments)

    def add_if(self, Range=None, MergeField=None, Comparison=None, CompareTo=None, TrueAutoText=None, TrueText=None, FalseAutoText=None, FalseText=None):
        """Alias for AddIf"""
        arguments = [Range, MergeField, Comparison, CompareTo, TrueAutoText, TrueText, FalseAutoText, FalseText]
        return self.AddIf(*arguments)

    def AddMergeRec(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        return MailMergeField(self.com_object.AddMergeRec(*arguments))

    def addmergerec(self, Range=None):
        """Alias for AddMergeRec"""
        arguments = [Range]
        return self.AddMergeRec(*arguments)

    def add_merge_rec(self, Range=None):
        """Alias for AddMergeRec"""
        arguments = [Range]
        return self.AddMergeRec(*arguments)

    def AddMergeSeq(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        return MailMergeField(self.com_object.AddMergeSeq(*arguments))

    def addmergeseq(self, Range=None):
        """Alias for AddMergeSeq"""
        arguments = [Range]
        return self.AddMergeSeq(*arguments)

    def add_merge_seq(self, Range=None):
        """Alias for AddMergeSeq"""
        arguments = [Range]
        return self.AddMergeSeq(*arguments)

    def AddNext(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        return MailMergeField(self.com_object.AddNext(*arguments))

    def addnext(self, Range=None):
        """Alias for AddNext"""
        arguments = [Range]
        return self.AddNext(*arguments)

    def add_next(self, Range=None):
        """Alias for AddNext"""
        arguments = [Range]
        return self.AddNext(*arguments)

    def AddNextIf(self, Range=None, MergeField=None, Comparison=None, CompareTo=None):
        arguments = com_arguments([unwrap(a) for a in [Range, MergeField, Comparison, CompareTo]])
        return MailMergeField(self.com_object.AddNextIf(*arguments))

    def addnextif(self, Range=None, MergeField=None, Comparison=None, CompareTo=None):
        """Alias for AddNextIf"""
        arguments = [Range, MergeField, Comparison, CompareTo]
        return self.AddNextIf(*arguments)

    def add_next_if(self, Range=None, MergeField=None, Comparison=None, CompareTo=None):
        """Alias for AddNextIf"""
        arguments = [Range, MergeField, Comparison, CompareTo]
        return self.AddNextIf(*arguments)

    def AddSet(self, Range=None, Name=None, ValueText=None, ValueAutoText=None):
        arguments = com_arguments([unwrap(a) for a in [Range, Name, ValueText, ValueAutoText]])
        return MailMergeField(self.com_object.AddSet(*arguments))

    def addset(self, Range=None, Name=None, ValueText=None, ValueAutoText=None):
        """Alias for AddSet"""
        arguments = [Range, Name, ValueText, ValueAutoText]
        return self.AddSet(*arguments)

    def add_set(self, Range=None, Name=None, ValueText=None, ValueAutoText=None):
        """Alias for AddSet"""
        arguments = [Range, Name, ValueText, ValueAutoText]
        return self.AddSet(*arguments)

    def AddSkipIf(self, Range=None, MergeField=None, Comparison=None, CompareTo=None):
        arguments = com_arguments([unwrap(a) for a in [Range, MergeField, Comparison, CompareTo]])
        return MailMergeField(self.com_object.AddSkipIf(*arguments))

    def addskipif(self, Range=None, MergeField=None, Comparison=None, CompareTo=None):
        """Alias for AddSkipIf"""
        arguments = [Range, MergeField, Comparison, CompareTo]
        return self.AddSkipIf(*arguments)

    def add_skip_if(self, Range=None, MergeField=None, Comparison=None, CompareTo=None):
        """Alias for AddSkipIf"""
        arguments = [Range, MergeField, Comparison, CompareTo]
        return self.AddSkipIf(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return MailMergeField(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class MailMessage:

    def __init__(self, mailmessage=None):
        self.com_object= mailmessage

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def CheckName(self):
        self.com_object.CheckName()

    def checkname(self):
        """Alias for CheckName"""
        return self.CheckName()

    def check_name(self):
        """Alias for CheckName"""
        return self.CheckName()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def DisplayMoveDialog(self):
        self.com_object.DisplayMoveDialog()

    def displaymovedialog(self):
        """Alias for DisplayMoveDialog"""
        return self.DisplayMoveDialog()

    def display_move_dialog(self):
        """Alias for DisplayMoveDialog"""
        return self.DisplayMoveDialog()

    def DisplayProperties(self):
        self.com_object.DisplayProperties()

    def displayproperties(self):
        """Alias for DisplayProperties"""
        return self.DisplayProperties()

    def display_properties(self):
        """Alias for DisplayProperties"""
        return self.DisplayProperties()

    def DisplaySelectNamesDialog(self):
        self.com_object.DisplaySelectNamesDialog()

    def displayselectnamesdialog(self):
        """Alias for DisplaySelectNamesDialog"""
        return self.DisplaySelectNamesDialog()

    def display_select_names_dialog(self):
        """Alias for DisplaySelectNamesDialog"""
        return self.DisplaySelectNamesDialog()

    def Forward(self):
        self.com_object.Forward()

    def forward(self):
        """Alias for Forward"""
        return self.Forward()

    def GoToNext(self):
        self.com_object.GoToNext()

    def gotonext(self):
        """Alias for GoToNext"""
        return self.GoToNext()

    def go_to_next(self):
        """Alias for GoToNext"""
        return self.GoToNext()

    def GoToPrevious(self):
        self.com_object.GoToPrevious()

    def gotoprevious(self):
        """Alias for GoToPrevious"""
        return self.GoToPrevious()

    def go_to_previous(self):
        """Alias for GoToPrevious"""
        return self.GoToPrevious()

    def Reply(self):
        self.com_object.Reply()

    def reply(self):
        """Alias for Reply"""
        return self.Reply()

    def ReplyAll(self):
        self.com_object.ReplyAll()

    def replyall(self):
        """Alias for ReplyAll"""
        return self.ReplyAll()

    def reply_all(self):
        """Alias for ReplyAll"""
        return self.ReplyAll()

    def ToggleHeader(self):
        self.com_object.ToggleHeader()

    def toggleheader(self):
        """Alias for ToggleHeader"""
        return self.ToggleHeader()

    def toggle_header(self):
        """Alias for ToggleHeader"""
        return self.ToggleHeader()


class MappedDataField:

    def __init__(self, mappeddatafield=None):
        self.com_object= mappeddatafield

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DataFieldIndex(self):
        return self.com_object.DataFieldIndex

    @DataFieldIndex.setter
    def DataFieldIndex(self, value):
        self.com_object.DataFieldIndex = value

    @property
    def datafieldindex(self):
        """Alias for DataFieldIndex"""
        return self.DataFieldIndex

    @datafieldindex.setter
    def datafieldindex(self, value):
        """Alias for DataFieldIndex.setter"""
        self.DataFieldIndex = value

    @property
    def data_field_index(self):
        """Alias for DataFieldIndex"""
        return self.DataFieldIndex

    @data_field_index.setter
    def data_field_index(self, value):
        """Alias for DataFieldIndex.setter"""
        self.DataFieldIndex = value

    @property
    def DataFieldName(self):
        return self.com_object.DataFieldName

    @DataFieldName.setter
    def DataFieldName(self, value):
        self.com_object.DataFieldName = value

    @property
    def datafieldname(self):
        """Alias for DataFieldName"""
        return self.DataFieldName

    @datafieldname.setter
    def datafieldname(self, value):
        """Alias for DataFieldName.setter"""
        self.DataFieldName = value

    @property
    def data_field_name(self):
        """Alias for DataFieldName"""
        return self.DataFieldName

    @data_field_name.setter
    def data_field_name(self, value):
        """Alias for DataFieldName.setter"""
        self.DataFieldName = value

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Value(self):
        return self.com_object.Value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value


class MappedDataFields:

    def __init__(self, mappeddatafields=None):
        self.com_object= mappeddatafields

    def __call__(self, item):
        return MappedDataField(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return MappedDataField(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Model3DFormat:

    def __init__(self, model3dformat=None):
        self.com_object= model3dformat

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoFit(self):
        return self.com_object.AutoFit

    @AutoFit.setter
    def AutoFit(self, value):
        self.com_object.AutoFit = value

    @property
    def autofit(self):
        """Alias for AutoFit"""
        return self.AutoFit

    @autofit.setter
    def autofit(self, value):
        """Alias for AutoFit.setter"""
        self.AutoFit = value

    @property
    def auto_fit(self):
        """Alias for AutoFit"""
        return self.AutoFit

    @auto_fit.setter
    def auto_fit(self, value):
        """Alias for AutoFit.setter"""
        self.AutoFit = value

    @property
    def CameraPositionX(self):
        return self.com_object.CameraPositionX

    @CameraPositionX.setter
    def CameraPositionX(self, value):
        self.com_object.CameraPositionX = value

    @property
    def camerapositionx(self):
        """Alias for CameraPositionX"""
        return self.CameraPositionX

    @camerapositionx.setter
    def camerapositionx(self, value):
        """Alias for CameraPositionX.setter"""
        self.CameraPositionX = value

    @property
    def camera_position_x(self):
        """Alias for CameraPositionX"""
        return self.CameraPositionX

    @camera_position_x.setter
    def camera_position_x(self, value):
        """Alias for CameraPositionX.setter"""
        self.CameraPositionX = value

    @property
    def CameraPositionY(self):
        return self.com_object.CameraPositionY

    @CameraPositionY.setter
    def CameraPositionY(self, value):
        self.com_object.CameraPositionY = value

    @property
    def camerapositiony(self):
        """Alias for CameraPositionY"""
        return self.CameraPositionY

    @camerapositiony.setter
    def camerapositiony(self, value):
        """Alias for CameraPositionY.setter"""
        self.CameraPositionY = value

    @property
    def camera_position_y(self):
        """Alias for CameraPositionY"""
        return self.CameraPositionY

    @camera_position_y.setter
    def camera_position_y(self, value):
        """Alias for CameraPositionY.setter"""
        self.CameraPositionY = value

    @property
    def CameraPositionZ(self):
        return self.com_object.CameraPositionZ

    @CameraPositionZ.setter
    def CameraPositionZ(self, value):
        self.com_object.CameraPositionZ = value

    @property
    def camerapositionz(self):
        """Alias for CameraPositionZ"""
        return self.CameraPositionZ

    @camerapositionz.setter
    def camerapositionz(self, value):
        """Alias for CameraPositionZ.setter"""
        self.CameraPositionZ = value

    @property
    def camera_position_z(self):
        """Alias for CameraPositionZ"""
        return self.CameraPositionZ

    @camera_position_z.setter
    def camera_position_z(self, value):
        """Alias for CameraPositionZ.setter"""
        self.CameraPositionZ = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def FieldOfView(self):
        return self.com_object.FieldOfView

    @FieldOfView.setter
    def FieldOfView(self, value):
        self.com_object.FieldOfView = value

    @property
    def fieldofview(self):
        """Alias for FieldOfView"""
        return self.FieldOfView

    @fieldofview.setter
    def fieldofview(self, value):
        """Alias for FieldOfView.setter"""
        self.FieldOfView = value

    @property
    def field_of_view(self):
        """Alias for FieldOfView"""
        return self.FieldOfView

    @field_of_view.setter
    def field_of_view(self, value):
        """Alias for FieldOfView.setter"""
        self.FieldOfView = value

    @property
    def LookAtPointX(self):
        return self.com_object.LookAtPointX

    @LookAtPointX.setter
    def LookAtPointX(self, value):
        self.com_object.LookAtPointX = value

    @property
    def lookatpointx(self):
        """Alias for LookAtPointX"""
        return self.LookAtPointX

    @lookatpointx.setter
    def lookatpointx(self, value):
        """Alias for LookAtPointX.setter"""
        self.LookAtPointX = value

    @property
    def look_at_point_x(self):
        """Alias for LookAtPointX"""
        return self.LookAtPointX

    @look_at_point_x.setter
    def look_at_point_x(self, value):
        """Alias for LookAtPointX.setter"""
        self.LookAtPointX = value

    @property
    def LookAtPointY(self):
        return self.com_object.LookAtPointY

    @LookAtPointY.setter
    def LookAtPointY(self, value):
        self.com_object.LookAtPointY = value

    @property
    def lookatpointy(self):
        """Alias for LookAtPointY"""
        return self.LookAtPointY

    @lookatpointy.setter
    def lookatpointy(self, value):
        """Alias for LookAtPointY.setter"""
        self.LookAtPointY = value

    @property
    def look_at_point_y(self):
        """Alias for LookAtPointY"""
        return self.LookAtPointY

    @look_at_point_y.setter
    def look_at_point_y(self, value):
        """Alias for LookAtPointY.setter"""
        self.LookAtPointY = value

    @property
    def LookAtPointZ(self):
        return self.com_object.LookAtPointZ

    @LookAtPointZ.setter
    def LookAtPointZ(self, value):
        self.com_object.LookAtPointZ = value

    @property
    def lookatpointz(self):
        """Alias for LookAtPointZ"""
        return self.LookAtPointZ

    @lookatpointz.setter
    def lookatpointz(self, value):
        """Alias for LookAtPointZ.setter"""
        self.LookAtPointZ = value

    @property
    def look_at_point_z(self):
        """Alias for LookAtPointZ"""
        return self.LookAtPointZ

    @look_at_point_z.setter
    def look_at_point_z(self, value):
        """Alias for LookAtPointZ.setter"""
        self.LookAtPointZ = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RotationX(self):
        return self.com_object.RotationX

    @RotationX.setter
    def RotationX(self, value):
        self.com_object.RotationX = value

    @property
    def rotationx(self):
        """Alias for RotationX"""
        return self.RotationX

    @rotationx.setter
    def rotationx(self, value):
        """Alias for RotationX.setter"""
        self.RotationX = value

    @property
    def rotation_x(self):
        """Alias for RotationX"""
        return self.RotationX

    @rotation_x.setter
    def rotation_x(self, value):
        """Alias for RotationX.setter"""
        self.RotationX = value

    @property
    def RotationY(self):
        return self.com_object.RotationY

    @RotationY.setter
    def RotationY(self, value):
        self.com_object.RotationY = value

    @property
    def rotationy(self):
        """Alias for RotationY"""
        return self.RotationY

    @rotationy.setter
    def rotationy(self, value):
        """Alias for RotationY.setter"""
        self.RotationY = value

    @property
    def rotation_y(self):
        """Alias for RotationY"""
        return self.RotationY

    @rotation_y.setter
    def rotation_y(self, value):
        """Alias for RotationY.setter"""
        self.RotationY = value

    @property
    def RotationZ(self):
        return self.com_object.RotationZ

    @RotationZ.setter
    def RotationZ(self, value):
        self.com_object.RotationZ = value

    @property
    def rotationz(self):
        """Alias for RotationZ"""
        return self.RotationZ

    @rotationz.setter
    def rotationz(self, value):
        """Alias for RotationZ.setter"""
        self.RotationZ = value

    @property
    def rotation_z(self):
        """Alias for RotationZ"""
        return self.RotationZ

    @rotation_z.setter
    def rotation_z(self, value):
        """Alias for RotationZ.setter"""
        self.RotationZ = value

    def IncrementRotationX(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotationX(*arguments)

    def incrementrotationx(self, Increment=None):
        """Alias for IncrementRotationX"""
        arguments = [Increment]
        return self.IncrementRotationX(*arguments)

    def increment_rotation_x(self, Increment=None):
        """Alias for IncrementRotationX"""
        arguments = [Increment]
        return self.IncrementRotationX(*arguments)

    def IncrementRotationY(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotationY(*arguments)

    def incrementrotationy(self, Increment=None):
        """Alias for IncrementRotationY"""
        arguments = [Increment]
        return self.IncrementRotationY(*arguments)

    def increment_rotation_y(self, Increment=None):
        """Alias for IncrementRotationY"""
        arguments = [Increment]
        return self.IncrementRotationY(*arguments)

    def IncrementRotationZ(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotationZ(*arguments)

    def incrementrotationz(self, Increment=None):
        """Alias for IncrementRotationZ"""
        arguments = [Increment]
        return self.IncrementRotationZ(*arguments)

    def increment_rotation_z(self, Increment=None):
        """Alias for IncrementRotationZ"""
        arguments = [Increment]
        return self.IncrementRotationZ(*arguments)

    def ResetModel(self, ResetSize=None):
        arguments = com_arguments([unwrap(a) for a in [ResetSize]])
        self.com_object.ResetModel(*arguments)

    def resetmodel(self, ResetSize=None):
        """Alias for ResetModel"""
        arguments = [ResetSize]
        return self.ResetModel(*arguments)

    def reset_model(self, ResetSize=None):
        """Alias for ResetModel"""
        arguments = [ResetSize]
        return self.ResetModel(*arguments)


class OLEFormat:

    def __init__(self, oleformat=None):
        self.com_object= oleformat

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ClassType(self):
        return self.com_object.ClassType

    @ClassType.setter
    def ClassType(self, value):
        self.com_object.ClassType = value

    @property
    def classtype(self):
        """Alias for ClassType"""
        return self.ClassType

    @classtype.setter
    def classtype(self, value):
        """Alias for ClassType.setter"""
        self.ClassType = value

    @property
    def class_type(self):
        """Alias for ClassType"""
        return self.ClassType

    @class_type.setter
    def class_type(self, value):
        """Alias for ClassType.setter"""
        self.ClassType = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DisplayAsIcon(self):
        return self.com_object.DisplayAsIcon

    @DisplayAsIcon.setter
    def DisplayAsIcon(self, value):
        self.com_object.DisplayAsIcon = value

    @property
    def displayasicon(self):
        """Alias for DisplayAsIcon"""
        return self.DisplayAsIcon

    @displayasicon.setter
    def displayasicon(self, value):
        """Alias for DisplayAsIcon.setter"""
        self.DisplayAsIcon = value

    @property
    def display_as_icon(self):
        """Alias for DisplayAsIcon"""
        return self.DisplayAsIcon

    @display_as_icon.setter
    def display_as_icon(self, value):
        """Alias for DisplayAsIcon.setter"""
        self.DisplayAsIcon = value

    @property
    def IconIndex(self):
        return self.com_object.IconIndex

    @IconIndex.setter
    def IconIndex(self, value):
        self.com_object.IconIndex = value

    @property
    def iconindex(self):
        """Alias for IconIndex"""
        return self.IconIndex

    @iconindex.setter
    def iconindex(self, value):
        """Alias for IconIndex.setter"""
        self.IconIndex = value

    @property
    def icon_index(self):
        """Alias for IconIndex"""
        return self.IconIndex

    @icon_index.setter
    def icon_index(self, value):
        """Alias for IconIndex.setter"""
        self.IconIndex = value

    @property
    def IconLabel(self):
        return self.com_object.IconLabel

    @IconLabel.setter
    def IconLabel(self, value):
        self.com_object.IconLabel = value

    @property
    def iconlabel(self):
        """Alias for IconLabel"""
        return self.IconLabel

    @iconlabel.setter
    def iconlabel(self, value):
        """Alias for IconLabel.setter"""
        self.IconLabel = value

    @property
    def icon_label(self):
        """Alias for IconLabel"""
        return self.IconLabel

    @icon_label.setter
    def icon_label(self, value):
        """Alias for IconLabel.setter"""
        self.IconLabel = value

    @property
    def IconName(self):
        return self.com_object.IconName

    @IconName.setter
    def IconName(self, value):
        self.com_object.IconName = value

    @property
    def iconname(self):
        """Alias for IconName"""
        return self.IconName

    @iconname.setter
    def iconname(self, value):
        """Alias for IconName.setter"""
        self.IconName = value

    @property
    def icon_name(self):
        """Alias for IconName"""
        return self.IconName

    @icon_name.setter
    def icon_name(self, value):
        """Alias for IconName.setter"""
        self.IconName = value

    @property
    def IconPath(self):
        return self.com_object.IconPath

    @property
    def iconpath(self):
        """Alias for IconPath"""
        return self.IconPath

    @property
    def icon_path(self):
        """Alias for IconPath"""
        return self.IconPath

    @property
    def Label(self):
        return self.com_object.Label

    @property
    def label(self):
        """Alias for Label"""
        return self.Label

    @property
    def Object(self):
        return self.com_object.Object

    @property
    def object(self):
        """Alias for Object"""
        return self.Object

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PreserveFormattingOnUpdate(self):
        return self.com_object.PreserveFormattingOnUpdate

    @PreserveFormattingOnUpdate.setter
    def PreserveFormattingOnUpdate(self, value):
        self.com_object.PreserveFormattingOnUpdate = value

    @property
    def preserveformattingonupdate(self):
        """Alias for PreserveFormattingOnUpdate"""
        return self.PreserveFormattingOnUpdate

    @preserveformattingonupdate.setter
    def preserveformattingonupdate(self, value):
        """Alias for PreserveFormattingOnUpdate.setter"""
        self.PreserveFormattingOnUpdate = value

    @property
    def preserve_formatting_on_update(self):
        """Alias for PreserveFormattingOnUpdate"""
        return self.PreserveFormattingOnUpdate

    @preserve_formatting_on_update.setter
    def preserve_formatting_on_update(self, value):
        """Alias for PreserveFormattingOnUpdate.setter"""
        self.PreserveFormattingOnUpdate = value

    @property
    def ProgID(self):
        return self.com_object.ProgID

    @property
    def progid(self):
        """Alias for ProgID"""
        return self.ProgID

    @property
    def prog_i_d(self):
        """Alias for ProgID"""
        return self.ProgID

    def Activate(self):
        self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()

    def ActivateAs(self, ClassType=None):
        arguments = com_arguments([unwrap(a) for a in [ClassType]])
        self.com_object.ActivateAs(*arguments)

    def activateas(self, ClassType=None):
        """Alias for ActivateAs"""
        arguments = [ClassType]
        return self.ActivateAs(*arguments)

    def activate_as(self, ClassType=None):
        """Alias for ActivateAs"""
        arguments = [ClassType]
        return self.ActivateAs(*arguments)

    def ConvertTo(self, ClassType=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None):
        arguments = com_arguments([unwrap(a) for a in [ClassType, DisplayAsIcon, IconFileName, IconIndex, IconLabel]])
        self.com_object.ConvertTo(*arguments)

    def convertto(self, ClassType=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None):
        """Alias for ConvertTo"""
        arguments = [ClassType, DisplayAsIcon, IconFileName, IconIndex, IconLabel]
        return self.ConvertTo(*arguments)

    def convert_to(self, ClassType=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None):
        """Alias for ConvertTo"""
        arguments = [ClassType, DisplayAsIcon, IconFileName, IconIndex, IconLabel]
        return self.ConvertTo(*arguments)

    def DoVerb(self, VerbIndex=None):
        arguments = com_arguments([unwrap(a) for a in [VerbIndex]])
        self.com_object.DoVerb(*arguments)

    def doverb(self, VerbIndex=None):
        """Alias for DoVerb"""
        arguments = [VerbIndex]
        return self.DoVerb(*arguments)

    def do_verb(self, VerbIndex=None):
        """Alias for DoVerb"""
        arguments = [VerbIndex]
        return self.DoVerb(*arguments)

    def Edit(self):
        self.com_object.Edit()

    def edit(self):
        """Alias for Edit"""
        return self.Edit()

    def Open(self):
        self.com_object.Open()

    def open(self):
        """Alias for Open"""
        return self.Open()


class OMath:

    def __init__(self, omath=None):
        self.com_object= omath

    @property
    def AlignPoint(self):
        return self.com_object.AlignPoint

    @AlignPoint.setter
    def AlignPoint(self, value):
        self.com_object.AlignPoint = value

    @property
    def alignpoint(self):
        """Alias for AlignPoint"""
        return self.AlignPoint

    @alignpoint.setter
    def alignpoint(self, value):
        """Alias for AlignPoint.setter"""
        self.AlignPoint = value

    @property
    def align_point(self):
        """Alias for AlignPoint"""
        return self.AlignPoint

    @align_point.setter
    def align_point(self, value):
        """Alias for AlignPoint.setter"""
        self.AlignPoint = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ArgIndex(self):
        return self.com_object.ArgIndex

    @property
    def argindex(self):
        """Alias for ArgIndex"""
        return self.ArgIndex

    @property
    def arg_index(self):
        """Alias for ArgIndex"""
        return self.ArgIndex

    @property
    def ArgSize(self):
        return self.com_object.ArgSize

    @ArgSize.setter
    def ArgSize(self, value):
        self.com_object.ArgSize = value

    @property
    def argsize(self):
        """Alias for ArgSize"""
        return self.ArgSize

    @argsize.setter
    def argsize(self, value):
        """Alias for ArgSize.setter"""
        self.ArgSize = value

    @property
    def arg_size(self):
        """Alias for ArgSize"""
        return self.ArgSize

    @arg_size.setter
    def arg_size(self, value):
        """Alias for ArgSize.setter"""
        self.ArgSize = value

    @property
    def Breaks(self):
        return OMathBreaks(self.com_object.Breaks)

    @property
    def breaks(self):
        """Alias for Breaks"""
        return self.Breaks

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Functions(self):
        return OMathFunctions(self.com_object.Functions)

    @property
    def functions(self):
        """Alias for Functions"""
        return self.Functions

    @property
    def Justification(self):
        return WdOMathJc(self.com_object.Justification)

    @Justification.setter
    def Justification(self, value):
        self.com_object.Justification = value

    @property
    def justification(self):
        """Alias for Justification"""
        return self.Justification

    @justification.setter
    def justification(self, value):
        """Alias for Justification.setter"""
        self.Justification = value

    @property
    def NestingLevel(self):
        return self.com_object.NestingLevel

    @property
    def nestinglevel(self):
        """Alias for NestingLevel"""
        return self.NestingLevel

    @property
    def nesting_level(self):
        """Alias for NestingLevel"""
        return self.NestingLevel

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ParentArg(self):
        return OMath(self.com_object.ParentArg)

    @property
    def parentarg(self):
        """Alias for ParentArg"""
        return self.ParentArg

    @property
    def parent_arg(self):
        """Alias for ParentArg"""
        return self.ParentArg

    @property
    def ParentCol(self):
        return OMathMatCol(self.com_object.ParentCol)

    @property
    def parentcol(self):
        """Alias for ParentCol"""
        return self.ParentCol

    @property
    def parent_col(self):
        """Alias for ParentCol"""
        return self.ParentCol

    @property
    def ParentFunction(self):
        return OMathFunction(self.com_object.ParentFunction)

    @property
    def parentfunction(self):
        """Alias for ParentFunction"""
        return self.ParentFunction

    @property
    def parent_function(self):
        """Alias for ParentFunction"""
        return self.ParentFunction

    @property
    def ParentOMath(self):
        return OMath(self.com_object.ParentOMath)

    @property
    def parentomath(self):
        """Alias for ParentOMath"""
        return self.ParentOMath

    @property
    def parent_o_math(self):
        """Alias for ParentOMath"""
        return self.ParentOMath

    @property
    def ParentRow(self):
        return OMathMatRow(self.com_object.ParentRow)

    @property
    def parentrow(self):
        """Alias for ParentRow"""
        return self.ParentRow

    @property
    def parent_row(self):
        """Alias for ParentRow"""
        return self.ParentRow

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def Type(self):
        return WdOMathType(self.com_object.Type)

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    def BuildUp(self):
        return self.com_object.BuildUp()

    def buildup(self):
        """Alias for BuildUp"""
        return self.BuildUp()

    def build_up(self):
        """Alias for BuildUp"""
        return self.BuildUp()

    def ConvertToLiteralText(self):
        self.com_object.ConvertToLiteralText()

    def converttoliteraltext(self):
        """Alias for ConvertToLiteralText"""
        return self.ConvertToLiteralText()

    def convert_to_literal_text(self):
        """Alias for ConvertToLiteralText"""
        return self.ConvertToLiteralText()

    def ConvertToMathText(self):
        self.com_object.ConvertToMathText()

    def converttomathtext(self):
        """Alias for ConvertToMathText"""
        return self.ConvertToMathText()

    def convert_to_math_text(self):
        """Alias for ConvertToMathText"""
        return self.ConvertToMathText()

    def ConvertToNormalText(self):
        self.com_object.ConvertToNormalText()

    def converttonormaltext(self):
        """Alias for ConvertToNormalText"""
        return self.ConvertToNormalText()

    def convert_to_normal_text(self):
        """Alias for ConvertToNormalText"""
        return self.ConvertToNormalText()

    def Linearize(self):
        return self.com_object.Linearize()

    def linearize(self):
        """Alias for Linearize"""
        return self.Linearize()

    def Remove(self):
        self.com_object.Remove()

    def remove(self):
        """Alias for Remove"""
        return self.Remove()


class OMathAcc:

    def __init__(self, omathacc=None):
        self.com_object= omathacc

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Char(self):
        return self.com_object.Char

    @Char.setter
    def Char(self, value):
        self.com_object.Char = value

    @property
    def char(self):
        """Alias for Char"""
        return self.Char

    @char.setter
    def char(self, value):
        """Alias for Char.setter"""
        self.Char = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def E(self):
        return OMath(self.com_object.E)

    @property
    def e(self):
        """Alias for E"""
        return self.E

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class OMathArgs:

    def __init__(self, omathargs=None):
        self.com_object= omathargs

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return OMathArgs(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, BeforeArg=None):
        arguments = com_arguments([unwrap(a) for a in [BeforeArg]])
        return OMath(self.com_object.Add(*arguments))

    def add(self, BeforeArg=None):
        """Alias for Add"""
        arguments = [BeforeArg]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return OMath(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class OMathAutoCorrect:

    def __init__(self, omathautocorrect=None):
        self.com_object= omathautocorrect

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Entries(self):
        return OMathAutoCorrectEntries(self.com_object.Entries)

    @property
    def entries(self):
        """Alias for Entries"""
        return self.Entries

    @property
    def Functions(self):
        return OMathRecognizedFunctions(self.com_object.Functions)

    @property
    def functions(self):
        """Alias for Functions"""
        return self.Functions

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ReplaceText(self):
        return self.com_object.ReplaceText

    @ReplaceText.setter
    def ReplaceText(self, value):
        self.com_object.ReplaceText = value

    @property
    def replacetext(self):
        """Alias for ReplaceText"""
        return self.ReplaceText

    @replacetext.setter
    def replacetext(self, value):
        """Alias for ReplaceText.setter"""
        self.ReplaceText = value

    @property
    def replace_text(self):
        """Alias for ReplaceText"""
        return self.ReplaceText

    @replace_text.setter
    def replace_text(self, value):
        """Alias for ReplaceText.setter"""
        self.ReplaceText = value

    @property
    def UseOutsideOMath(self):
        return self.com_object.UseOutsideOMath

    @UseOutsideOMath.setter
    def UseOutsideOMath(self, value):
        self.com_object.UseOutsideOMath = value

    @property
    def useoutsideomath(self):
        """Alias for UseOutsideOMath"""
        return self.UseOutsideOMath

    @useoutsideomath.setter
    def useoutsideomath(self, value):
        """Alias for UseOutsideOMath.setter"""
        self.UseOutsideOMath = value

    @property
    def use_outside_o_math(self):
        """Alias for UseOutsideOMath"""
        return self.UseOutsideOMath

    @use_outside_o_math.setter
    def use_outside_o_math(self, value):
        """Alias for UseOutsideOMath.setter"""
        self.UseOutsideOMath = value


class OMathAutoCorrectEntries:

    def __init__(self, omathautocorrectentries=None):
        self.com_object= omathautocorrectentries

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return OMathAutoCorrectEntries(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, Value=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Value]])
        return OMathAutoCorrectEntry(self.com_object.Add(*arguments))

    def add(self, Name=None, Value=None):
        """Alias for Add"""
        arguments = [Name, Value]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return OMathAutoCorrectEntry(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class OMathAutoCorrectEntry:

    def __init__(self, omathautocorrectentry=None):
        self.com_object= omathautocorrectentry

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class OMathBar:

    def __init__(self, omathbar=None):
        self.com_object= omathbar

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BarTop(self):
        return self.com_object.BarTop

    @BarTop.setter
    def BarTop(self, value):
        self.com_object.BarTop = value

    @property
    def bartop(self):
        """Alias for BarTop"""
        return self.BarTop

    @bartop.setter
    def bartop(self, value):
        """Alias for BarTop.setter"""
        self.BarTop = value

    @property
    def bar_top(self):
        """Alias for BarTop"""
        return self.BarTop

    @bar_top.setter
    def bar_top(self, value):
        """Alias for BarTop.setter"""
        self.BarTop = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def E(self):
        return OMath(self.com_object.E)

    @property
    def e(self):
        """Alias for E"""
        return self.E

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class OMathBorderBox:

    def __init__(self, omathborderbox=None):
        self.com_object= omathborderbox

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def E(self):
        return OMath(self.com_object.E)

    @property
    def e(self):
        """Alias for E"""
        return self.E

    @property
    def HideBot(self):
        return self.com_object.HideBot

    @HideBot.setter
    def HideBot(self, value):
        self.com_object.HideBot = value

    @property
    def hidebot(self):
        """Alias for HideBot"""
        return self.HideBot

    @hidebot.setter
    def hidebot(self, value):
        """Alias for HideBot.setter"""
        self.HideBot = value

    @property
    def hide_bot(self):
        """Alias for HideBot"""
        return self.HideBot

    @hide_bot.setter
    def hide_bot(self, value):
        """Alias for HideBot.setter"""
        self.HideBot = value

    @property
    def HideLeft(self):
        return self.com_object.HideLeft

    @HideLeft.setter
    def HideLeft(self, value):
        self.com_object.HideLeft = value

    @property
    def hideleft(self):
        """Alias for HideLeft"""
        return self.HideLeft

    @hideleft.setter
    def hideleft(self, value):
        """Alias for HideLeft.setter"""
        self.HideLeft = value

    @property
    def hide_left(self):
        """Alias for HideLeft"""
        return self.HideLeft

    @hide_left.setter
    def hide_left(self, value):
        """Alias for HideLeft.setter"""
        self.HideLeft = value

    @property
    def HideRight(self):
        return self.com_object.HideRight

    @HideRight.setter
    def HideRight(self, value):
        self.com_object.HideRight = value

    @property
    def hideright(self):
        """Alias for HideRight"""
        return self.HideRight

    @hideright.setter
    def hideright(self, value):
        """Alias for HideRight.setter"""
        self.HideRight = value

    @property
    def hide_right(self):
        """Alias for HideRight"""
        return self.HideRight

    @hide_right.setter
    def hide_right(self, value):
        """Alias for HideRight.setter"""
        self.HideRight = value

    @property
    def HideTop(self):
        return self.com_object.HideTop

    @HideTop.setter
    def HideTop(self, value):
        self.com_object.HideTop = value

    @property
    def hidetop(self):
        """Alias for HideTop"""
        return self.HideTop

    @hidetop.setter
    def hidetop(self, value):
        """Alias for HideTop.setter"""
        self.HideTop = value

    @property
    def hide_top(self):
        """Alias for HideTop"""
        return self.HideTop

    @hide_top.setter
    def hide_top(self, value):
        """Alias for HideTop.setter"""
        self.HideTop = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def StrikeBLTR(self):
        return self.com_object.StrikeBLTR

    @StrikeBLTR.setter
    def StrikeBLTR(self, value):
        self.com_object.StrikeBLTR = value

    @property
    def strikebltr(self):
        """Alias for StrikeBLTR"""
        return self.StrikeBLTR

    @strikebltr.setter
    def strikebltr(self, value):
        """Alias for StrikeBLTR.setter"""
        self.StrikeBLTR = value

    @property
    def strike_b_l_t_r(self):
        """Alias for StrikeBLTR"""
        return self.StrikeBLTR

    @strike_b_l_t_r.setter
    def strike_b_l_t_r(self, value):
        """Alias for StrikeBLTR.setter"""
        self.StrikeBLTR = value

    @property
    def StrikeH(self):
        return self.com_object.StrikeH

    @StrikeH.setter
    def StrikeH(self, value):
        self.com_object.StrikeH = value

    @property
    def strikeh(self):
        """Alias for StrikeH"""
        return self.StrikeH

    @strikeh.setter
    def strikeh(self, value):
        """Alias for StrikeH.setter"""
        self.StrikeH = value

    @property
    def strike_h(self):
        """Alias for StrikeH"""
        return self.StrikeH

    @strike_h.setter
    def strike_h(self, value):
        """Alias for StrikeH.setter"""
        self.StrikeH = value

    @property
    def StrikeTLBR(self):
        return self.com_object.StrikeTLBR

    @StrikeTLBR.setter
    def StrikeTLBR(self, value):
        self.com_object.StrikeTLBR = value

    @property
    def striketlbr(self):
        """Alias for StrikeTLBR"""
        return self.StrikeTLBR

    @striketlbr.setter
    def striketlbr(self, value):
        """Alias for StrikeTLBR.setter"""
        self.StrikeTLBR = value

    @property
    def strike_t_l_b_r(self):
        """Alias for StrikeTLBR"""
        return self.StrikeTLBR

    @strike_t_l_b_r.setter
    def strike_t_l_b_r(self, value):
        """Alias for StrikeTLBR.setter"""
        self.StrikeTLBR = value

    @property
    def StrikeV(self):
        return self.com_object.StrikeV

    @StrikeV.setter
    def StrikeV(self, value):
        self.com_object.StrikeV = value

    @property
    def strikev(self):
        """Alias for StrikeV"""
        return self.StrikeV

    @strikev.setter
    def strikev(self, value):
        """Alias for StrikeV.setter"""
        self.StrikeV = value

    @property
    def strike_v(self):
        """Alias for StrikeV"""
        return self.StrikeV

    @strike_v.setter
    def strike_v(self, value):
        """Alias for StrikeV.setter"""
        self.StrikeV = value


class OMathBox:

    def __init__(self, omathbox=None):
        self.com_object= omathbox

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Diff(self):
        return self.com_object.Diff

    @Diff.setter
    def Diff(self, value):
        self.com_object.Diff = value

    @property
    def diff(self):
        """Alias for Diff"""
        return self.Diff

    @diff.setter
    def diff(self, value):
        """Alias for Diff.setter"""
        self.Diff = value

    @property
    def E(self):
        return OMath(self.com_object.E)

    @property
    def e(self):
        """Alias for E"""
        return self.E

    @property
    def NoBreak(self):
        return self.com_object.NoBreak

    @NoBreak.setter
    def NoBreak(self, value):
        self.com_object.NoBreak = value

    @property
    def nobreak(self):
        """Alias for NoBreak"""
        return self.NoBreak

    @nobreak.setter
    def nobreak(self, value):
        """Alias for NoBreak.setter"""
        self.NoBreak = value

    @property
    def no_break(self):
        """Alias for NoBreak"""
        return self.NoBreak

    @no_break.setter
    def no_break(self, value):
        """Alias for NoBreak.setter"""
        self.NoBreak = value

    @property
    def OpEmu(self):
        return self.com_object.OpEmu

    @OpEmu.setter
    def OpEmu(self, value):
        self.com_object.OpEmu = value

    @property
    def opemu(self):
        """Alias for OpEmu"""
        return self.OpEmu

    @opemu.setter
    def opemu(self, value):
        """Alias for OpEmu.setter"""
        self.OpEmu = value

    @property
    def op_emu(self):
        """Alias for OpEmu"""
        return self.OpEmu

    @op_emu.setter
    def op_emu(self, value):
        """Alias for OpEmu.setter"""
        self.OpEmu = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class OMathBreak:

    def __init__(self, omathbreak=None):
        self.com_object= omathbreak

    @property
    def AlignAt(self):
        return self.com_object.AlignAt

    @AlignAt.setter
    def AlignAt(self, value):
        self.com_object.AlignAt = value

    @property
    def alignat(self):
        """Alias for AlignAt"""
        return self.AlignAt

    @alignat.setter
    def alignat(self, value):
        """Alias for AlignAt.setter"""
        self.AlignAt = value

    @property
    def align_at(self):
        """Alias for AlignAt"""
        return self.AlignAt

    @align_at.setter
    def align_at(self, value):
        """Alias for AlignAt.setter"""
        self.AlignAt = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class OMathBreaks:

    def __init__(self, omathbreaks=None):
        self.com_object= omathbreaks

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return OMathBreaks(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        return OMathBreak(self.com_object.Add(*arguments))

    def add(self, Range=None):
        """Alias for Add"""
        arguments = [Range]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return OMathBreak(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class OMathDelim:

    def __init__(self, omathdelim=None):
        self.com_object= omathdelim

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BegChar(self):
        return self.com_object.BegChar

    @BegChar.setter
    def BegChar(self, value):
        self.com_object.BegChar = value

    @property
    def begchar(self):
        """Alias for BegChar"""
        return self.BegChar

    @begchar.setter
    def begchar(self, value):
        """Alias for BegChar.setter"""
        self.BegChar = value

    @property
    def beg_char(self):
        """Alias for BegChar"""
        return self.BegChar

    @beg_char.setter
    def beg_char(self, value):
        """Alias for BegChar.setter"""
        self.BegChar = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def E(self):
        return OMathArgs(self.com_object.E)

    @property
    def e(self):
        """Alias for E"""
        return self.E

    @property
    def EndChar(self):
        return self.com_object.EndChar

    @EndChar.setter
    def EndChar(self, value):
        self.com_object.EndChar = value

    @property
    def endchar(self):
        """Alias for EndChar"""
        return self.EndChar

    @endchar.setter
    def endchar(self, value):
        """Alias for EndChar.setter"""
        self.EndChar = value

    @property
    def end_char(self):
        """Alias for EndChar"""
        return self.EndChar

    @end_char.setter
    def end_char(self, value):
        """Alias for EndChar.setter"""
        self.EndChar = value

    @property
    def Grow(self):
        return self.com_object.Grow

    @Grow.setter
    def Grow(self, value):
        self.com_object.Grow = value

    @property
    def grow(self):
        """Alias for Grow"""
        return self.Grow

    @grow.setter
    def grow(self, value):
        """Alias for Grow.setter"""
        self.Grow = value

    @property
    def NoLeftChar(self):
        return self.com_object.NoLeftChar

    @NoLeftChar.setter
    def NoLeftChar(self, value):
        self.com_object.NoLeftChar = value

    @property
    def noleftchar(self):
        """Alias for NoLeftChar"""
        return self.NoLeftChar

    @noleftchar.setter
    def noleftchar(self, value):
        """Alias for NoLeftChar.setter"""
        self.NoLeftChar = value

    @property
    def no_left_char(self):
        """Alias for NoLeftChar"""
        return self.NoLeftChar

    @no_left_char.setter
    def no_left_char(self, value):
        """Alias for NoLeftChar.setter"""
        self.NoLeftChar = value

    @property
    def NoRightChar(self):
        return self.com_object.NoRightChar

    @NoRightChar.setter
    def NoRightChar(self, value):
        self.com_object.NoRightChar = value

    @property
    def norightchar(self):
        """Alias for NoRightChar"""
        return self.NoRightChar

    @norightchar.setter
    def norightchar(self, value):
        """Alias for NoRightChar.setter"""
        self.NoRightChar = value

    @property
    def no_right_char(self):
        """Alias for NoRightChar"""
        return self.NoRightChar

    @no_right_char.setter
    def no_right_char(self, value):
        """Alias for NoRightChar.setter"""
        self.NoRightChar = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SepChar(self):
        return self.com_object.SepChar

    @SepChar.setter
    def SepChar(self, value):
        self.com_object.SepChar = value

    @property
    def sepchar(self):
        """Alias for SepChar"""
        return self.SepChar

    @sepchar.setter
    def sepchar(self, value):
        """Alias for SepChar.setter"""
        self.SepChar = value

    @property
    def sep_char(self):
        """Alias for SepChar"""
        return self.SepChar

    @sep_char.setter
    def sep_char(self, value):
        """Alias for SepChar.setter"""
        self.SepChar = value

    @property
    def Shape(self):
        return WdOMathShapeType(self.com_object.Shape)

    @Shape.setter
    def Shape(self, value):
        self.com_object.Shape = value

    @property
    def shape(self):
        """Alias for Shape"""
        return self.Shape

    @shape.setter
    def shape(self, value):
        """Alias for Shape.setter"""
        self.Shape = value


class OMathEqArray:

    def __init__(self, omatheqarray=None):
        self.com_object= omatheqarray

    @property
    def Align(self):
        return WdOMathVertAlignType(self.com_object.Align)

    @Align.setter
    def Align(self, value):
        self.com_object.Align = value

    @property
    def align(self):
        """Alias for Align"""
        return self.Align

    @align.setter
    def align(self, value):
        """Alias for Align.setter"""
        self.Align = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def E(self):
        return OMathArgs(self.com_object.E)

    @property
    def e(self):
        """Alias for E"""
        return self.E

    @property
    def MaxDist(self):
        return self.com_object.MaxDist

    @MaxDist.setter
    def MaxDist(self, value):
        self.com_object.MaxDist = value

    @property
    def maxdist(self):
        """Alias for MaxDist"""
        return self.MaxDist

    @maxdist.setter
    def maxdist(self, value):
        """Alias for MaxDist.setter"""
        self.MaxDist = value

    @property
    def max_dist(self):
        """Alias for MaxDist"""
        return self.MaxDist

    @max_dist.setter
    def max_dist(self, value):
        """Alias for MaxDist.setter"""
        self.MaxDist = value

    @property
    def ObjDist(self):
        return self.com_object.ObjDist

    @ObjDist.setter
    def ObjDist(self, value):
        self.com_object.ObjDist = value

    @property
    def objdist(self):
        """Alias for ObjDist"""
        return self.ObjDist

    @objdist.setter
    def objdist(self, value):
        """Alias for ObjDist.setter"""
        self.ObjDist = value

    @property
    def obj_dist(self):
        """Alias for ObjDist"""
        return self.ObjDist

    @obj_dist.setter
    def obj_dist(self, value):
        """Alias for ObjDist.setter"""
        self.ObjDist = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RowSpacing(self):
        return self.com_object.RowSpacing

    @RowSpacing.setter
    def RowSpacing(self, value):
        self.com_object.RowSpacing = value

    @property
    def rowspacing(self):
        """Alias for RowSpacing"""
        return self.RowSpacing

    @rowspacing.setter
    def rowspacing(self, value):
        """Alias for RowSpacing.setter"""
        self.RowSpacing = value

    @property
    def row_spacing(self):
        """Alias for RowSpacing"""
        return self.RowSpacing

    @row_spacing.setter
    def row_spacing(self, value):
        """Alias for RowSpacing.setter"""
        self.RowSpacing = value

    @property
    def RowSpacingRule(self):
        return WdOMathSpacingRule(self.com_object.RowSpacingRule)

    @RowSpacingRule.setter
    def RowSpacingRule(self, value):
        self.com_object.RowSpacingRule = value

    @property
    def rowspacingrule(self):
        """Alias for RowSpacingRule"""
        return self.RowSpacingRule

    @rowspacingrule.setter
    def rowspacingrule(self, value):
        """Alias for RowSpacingRule.setter"""
        self.RowSpacingRule = value

    @property
    def row_spacing_rule(self):
        """Alias for RowSpacingRule"""
        return self.RowSpacingRule

    @row_spacing_rule.setter
    def row_spacing_rule(self, value):
        """Alias for RowSpacingRule.setter"""
        self.RowSpacingRule = value


class OMathFrac:

    def __init__(self, omathfrac=None):
        self.com_object= omathfrac

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Den(self):
        return OMath(self.com_object.Den)

    @property
    def den(self):
        """Alias for Den"""
        return self.Den

    @property
    def Num(self):
        return OMath(self.com_object.Num)

    @property
    def num(self):
        """Alias for Num"""
        return self.Num

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Type(self):
        return WdOMathFracType(self.com_object.Type)

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value


class OMathFunc:

    def __init__(self, omathfunc=None):
        self.com_object= omathfunc

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def E(self):
        return OMath(self.com_object.E)

    @property
    def e(self):
        """Alias for E"""
        return self.E

    @property
    def FName(self):
        return OMath(self.com_object.FName)

    @property
    def fname(self):
        """Alias for FName"""
        return self.FName

    @property
    def f_name(self):
        """Alias for FName"""
        return self.FName

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class OMathFunction:

    def __init__(self, omathfunction=None):
        self.com_object= omathfunction

    @property
    def Acc(self):
        return OMathAcc(self.com_object.Acc)

    @property
    def acc(self):
        """Alias for Acc"""
        return self.Acc

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Args(self):
        return OMathArgs(self.com_object.Args)

    @property
    def args(self):
        """Alias for Args"""
        return self.Args

    @property
    def Bar(self):
        return OMathBar(self.com_object.Bar)

    @property
    def bar(self):
        """Alias for Bar"""
        return self.Bar

    @property
    def BorderBox(self):
        return OMathBorderBox(self.com_object.BorderBox)

    @property
    def borderbox(self):
        """Alias for BorderBox"""
        return self.BorderBox

    @property
    def border_box(self):
        """Alias for BorderBox"""
        return self.BorderBox

    @property
    def Box(self):
        return OMathBox(self.com_object.Box)

    @property
    def box(self):
        """Alias for Box"""
        return self.Box

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Delim(self):
        return OMathDelim(self.com_object.Delim)

    @property
    def delim(self):
        """Alias for Delim"""
        return self.Delim

    @property
    def EqArray(self):
        return OMathEqArray(self.com_object.EqArray)

    @property
    def eqarray(self):
        """Alias for EqArray"""
        return self.EqArray

    @property
    def eq_array(self):
        """Alias for EqArray"""
        return self.EqArray

    @property
    def Frac(self):
        return OMathFrac(self.com_object.Frac)

    @property
    def frac(self):
        """Alias for Frac"""
        return self.Frac

    @property
    def Func(self):
        return OMathFunc(self.com_object.Func)

    @property
    def func(self):
        """Alias for Func"""
        return self.Func

    @property
    def GroupChar(self):
        return OMathGroupChar(self.com_object.GroupChar)

    @property
    def groupchar(self):
        """Alias for GroupChar"""
        return self.GroupChar

    @property
    def group_char(self):
        """Alias for GroupChar"""
        return self.GroupChar

    @property
    def LimLow(self):
        return OMathLimLow(self.com_object.LimLow)

    @property
    def limlow(self):
        """Alias for LimLow"""
        return self.LimLow

    @property
    def lim_low(self):
        """Alias for LimLow"""
        return self.LimLow

    @property
    def LimUpp(self):
        return OMathLimUpp(self.com_object.LimUpp)

    @property
    def limupp(self):
        """Alias for LimUpp"""
        return self.LimUpp

    @property
    def lim_upp(self):
        """Alias for LimUpp"""
        return self.LimUpp

    @property
    def Mat(self):
        return OMathMat(self.com_object.Mat)

    @property
    def mat(self):
        """Alias for Mat"""
        return self.Mat

    @property
    def Nary(self):
        return OMathNary(self.com_object.Nary)

    @property
    def nary(self):
        """Alias for Nary"""
        return self.Nary

    @property
    def OMath(self):
        return OMath(self.com_object.OMath)

    @property
    def omath(self):
        """Alias for OMath"""
        return self.OMath

    @property
    def o_math(self):
        """Alias for OMath"""
        return self.OMath

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Phantom(self):
        return OMathPhantom(self.com_object.Phantom)

    @property
    def phantom(self):
        """Alias for Phantom"""
        return self.Phantom

    @property
    def Rad(self):
        return OMathRad(self.com_object.Rad)

    @property
    def rad(self):
        """Alias for Rad"""
        return self.Rad

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def ScrPre(self):
        return OMathScrPre(self.com_object.ScrPre)

    @property
    def scrpre(self):
        """Alias for ScrPre"""
        return self.ScrPre

    @property
    def scr_pre(self):
        """Alias for ScrPre"""
        return self.ScrPre

    @property
    def ScrSub(self):
        return self.com_object.ScrSub

    @property
    def scrsub(self):
        """Alias for ScrSub"""
        return self.ScrSub

    @property
    def scr_sub(self):
        """Alias for ScrSub"""
        return self.ScrSub

    @property
    def ScrSubSup(self):
        return OMathScrSubSup(self.com_object.ScrSubSup)

    @property
    def scrsubsup(self):
        """Alias for ScrSubSup"""
        return self.ScrSubSup

    @property
    def scr_sub_sup(self):
        """Alias for ScrSubSup"""
        return self.ScrSubSup

    @property
    def ScrSup(self):
        return OMathScrSup(self.com_object.ScrSup)

    @property
    def scrsup(self):
        """Alias for ScrSup"""
        return self.ScrSup

    @property
    def scr_sup(self):
        """Alias for ScrSup"""
        return self.ScrSup

    @property
    def Type(self):
        return WdOMathFunctionType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def Remove(self):
        return OMathFunction(self.com_object.Remove())

    def remove(self):
        """Alias for Remove"""
        return self.Remove()


class OMathFunctions:

    def __init__(self, omathfunctions=None):
        self.com_object= omathfunctions

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return OMathFunctions(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Range=None, Type=None, NumArgs=None, NumCols=None):
        arguments = com_arguments([unwrap(a) for a in [Range, Type, NumArgs, NumCols]])
        return OMathFunction(self.com_object.Add(*arguments))

    def add(self, Range=None, Type=None, NumArgs=None, NumCols=None):
        """Alias for Add"""
        arguments = [Range, Type, NumArgs, NumCols]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return OMathFunction(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class OMathGroupChar:

    def __init__(self, omathgroupchar=None):
        self.com_object= omathgroupchar

    @property
    def AlignTop(self):
        return self.com_object.AlignTop

    @AlignTop.setter
    def AlignTop(self, value):
        self.com_object.AlignTop = value

    @property
    def aligntop(self):
        """Alias for AlignTop"""
        return self.AlignTop

    @aligntop.setter
    def aligntop(self, value):
        """Alias for AlignTop.setter"""
        self.AlignTop = value

    @property
    def align_top(self):
        """Alias for AlignTop"""
        return self.AlignTop

    @align_top.setter
    def align_top(self, value):
        """Alias for AlignTop.setter"""
        self.AlignTop = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Char(self):
        return self.com_object.Char

    @Char.setter
    def Char(self, value):
        self.com_object.Char = value

    @property
    def char(self):
        """Alias for Char"""
        return self.Char

    @char.setter
    def char(self, value):
        """Alias for Char.setter"""
        self.Char = value

    @property
    def CharTop(self):
        return self.com_object.CharTop

    @CharTop.setter
    def CharTop(self, value):
        self.com_object.CharTop = value

    @property
    def chartop(self):
        """Alias for CharTop"""
        return self.CharTop

    @chartop.setter
    def chartop(self, value):
        """Alias for CharTop.setter"""
        self.CharTop = value

    @property
    def char_top(self):
        """Alias for CharTop"""
        return self.CharTop

    @char_top.setter
    def char_top(self, value):
        """Alias for CharTop.setter"""
        self.CharTop = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def E(self):
        return OMath(self.com_object.E)

    @property
    def e(self):
        """Alias for E"""
        return self.E

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class OMathLimLow:

    def __init__(self, omathlimlow=None):
        self.com_object= omathlimlow

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def E(self):
        return OMath(self.com_object.E)

    @property
    def e(self):
        """Alias for E"""
        return self.E

    @property
    def Lim(self):
        return OMath(self.com_object.Lim)

    @property
    def lim(self):
        """Alias for Lim"""
        return self.Lim

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def ToLimUpp(self):
        return OMathFunction(self.com_object.ToLimUpp())

    def tolimupp(self):
        """Alias for ToLimUpp"""
        return self.ToLimUpp()

    def to_lim_upp(self):
        """Alias for ToLimUpp"""
        return self.ToLimUpp()


class OMathLimUpp:

    def __init__(self, omathlimupp=None):
        self.com_object= omathlimupp

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def E(self):
        return OMath(self.com_object.E)

    @property
    def e(self):
        """Alias for E"""
        return self.E

    @property
    def Lim(self):
        return OMath(self.com_object.Lim)

    @property
    def lim(self):
        """Alias for Lim"""
        return self.Lim

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def ToLimLow(self):
        return OMathFunction(self.com_object.ToLimLow())

    def tolimlow(self):
        """Alias for ToLimLow"""
        return self.ToLimLow()

    def to_lim_low(self):
        """Alias for ToLimLow"""
        return self.ToLimLow()


class OMathMat:

    def __init__(self, omathmat=None):
        self.com_object= omathmat

    @property
    def Align(self):
        return WdOMathVertAlignType(self.com_object.Align)

    @Align.setter
    def Align(self, value):
        self.com_object.Align = value

    @property
    def align(self):
        """Alias for Align"""
        return self.Align

    @align.setter
    def align(self, value):
        """Alias for Align.setter"""
        self.Align = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    def Cell(self, Row=None, Col=None):
        arguments = com_arguments([unwrap(a) for a in [Row, Col]])
        if hasattr(self.com_object, "GetCell"):
            return OMath(self.com_object.GetCell(*arguments))
        else:
            return OMath(self.com_object.Cell(*arguments))

    def cell(self, Row=None, Col=None):
        """Alias for Cell"""
        arguments = [Row, Col]
        return self.Cell(*arguments)

    @property
    def ColGap(self):
        return self.com_object.ColGap

    @ColGap.setter
    def ColGap(self, value):
        self.com_object.ColGap = value

    @property
    def colgap(self):
        """Alias for ColGap"""
        return self.ColGap

    @colgap.setter
    def colgap(self, value):
        """Alias for ColGap.setter"""
        self.ColGap = value

    @property
    def col_gap(self):
        """Alias for ColGap"""
        return self.ColGap

    @col_gap.setter
    def col_gap(self, value):
        """Alias for ColGap.setter"""
        self.ColGap = value

    @property
    def ColGapRule(self):
        return WdOMathSpacingRule(self.com_object.ColGapRule)

    @ColGapRule.setter
    def ColGapRule(self, value):
        self.com_object.ColGapRule = value

    @property
    def colgaprule(self):
        """Alias for ColGapRule"""
        return self.ColGapRule

    @colgaprule.setter
    def colgaprule(self, value):
        """Alias for ColGapRule.setter"""
        self.ColGapRule = value

    @property
    def col_gap_rule(self):
        """Alias for ColGapRule"""
        return self.ColGapRule

    @col_gap_rule.setter
    def col_gap_rule(self, value):
        """Alias for ColGapRule.setter"""
        self.ColGapRule = value

    @property
    def Cols(self):
        return OMathMatCols(self.com_object.Cols)

    @property
    def cols(self):
        """Alias for Cols"""
        return self.Cols

    @property
    def ColSpacing(self):
        return self.com_object.ColSpacing

    @ColSpacing.setter
    def ColSpacing(self, value):
        self.com_object.ColSpacing = value

    @property
    def colspacing(self):
        """Alias for ColSpacing"""
        return self.ColSpacing

    @colspacing.setter
    def colspacing(self, value):
        """Alias for ColSpacing.setter"""
        self.ColSpacing = value

    @property
    def col_spacing(self):
        """Alias for ColSpacing"""
        return self.ColSpacing

    @col_spacing.setter
    def col_spacing(self, value):
        """Alias for ColSpacing.setter"""
        self.ColSpacing = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PlcHoldHidden(self):
        return self.com_object.PlcHoldHidden

    @PlcHoldHidden.setter
    def PlcHoldHidden(self, value):
        self.com_object.PlcHoldHidden = value

    @property
    def plcholdhidden(self):
        """Alias for PlcHoldHidden"""
        return self.PlcHoldHidden

    @plcholdhidden.setter
    def plcholdhidden(self, value):
        """Alias for PlcHoldHidden.setter"""
        self.PlcHoldHidden = value

    @property
    def plc_hold_hidden(self):
        """Alias for PlcHoldHidden"""
        return self.PlcHoldHidden

    @plc_hold_hidden.setter
    def plc_hold_hidden(self, value):
        """Alias for PlcHoldHidden.setter"""
        self.PlcHoldHidden = value

    @property
    def Rows(self):
        return OMathMatRows(self.com_object.Rows)

    @property
    def rows(self):
        """Alias for Rows"""
        return self.Rows

    @property
    def RowSpacing(self):
        return self.com_object.RowSpacing

    @RowSpacing.setter
    def RowSpacing(self, value):
        self.com_object.RowSpacing = value

    @property
    def rowspacing(self):
        """Alias for RowSpacing"""
        return self.RowSpacing

    @rowspacing.setter
    def rowspacing(self, value):
        """Alias for RowSpacing.setter"""
        self.RowSpacing = value

    @property
    def row_spacing(self):
        """Alias for RowSpacing"""
        return self.RowSpacing

    @row_spacing.setter
    def row_spacing(self, value):
        """Alias for RowSpacing.setter"""
        self.RowSpacing = value

    @property
    def RowSpacingRule(self):
        return WdOMathSpacingRule(self.com_object.RowSpacingRule)

    @RowSpacingRule.setter
    def RowSpacingRule(self, value):
        self.com_object.RowSpacingRule = value

    @property
    def rowspacingrule(self):
        """Alias for RowSpacingRule"""
        return self.RowSpacingRule

    @rowspacingrule.setter
    def rowspacingrule(self, value):
        """Alias for RowSpacingRule.setter"""
        self.RowSpacingRule = value

    @property
    def row_spacing_rule(self):
        """Alias for RowSpacingRule"""
        return self.RowSpacingRule

    @row_spacing_rule.setter
    def row_spacing_rule(self, value):
        """Alias for RowSpacingRule.setter"""
        self.RowSpacingRule = value


class OMathMatCol:

    def __init__(self, omathmatcol=None):
        self.com_object= omathmatcol

    @property
    def Align(self):
        return WdOMathHorizAlignType(self.com_object.Align)

    @Align.setter
    def Align(self, value):
        self.com_object.Align = value

    @property
    def align(self):
        """Alias for Align"""
        return self.Align

    @align.setter
    def align(self, value):
        """Alias for Align.setter"""
        self.Align = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Args(self):
        return OMathArgs(self.com_object.Args)

    @property
    def args(self):
        """Alias for Args"""
        return self.Args

    @property
    def ColIndex(self):
        return self.com_object.ColIndex

    @property
    def colindex(self):
        """Alias for ColIndex"""
        return self.ColIndex

    @property
    def col_index(self):
        """Alias for ColIndex"""
        return self.ColIndex

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class OMathMatCols:

    def __init__(self, omathmatcols=None):
        self.com_object= omathmatcols

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return OMathMatCols(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, BeforeCol=None):
        arguments = com_arguments([unwrap(a) for a in [BeforeCol]])
        return OMathMatCol(self.com_object.Add(*arguments))

    def add(self, BeforeCol=None):
        """Alias for Add"""
        arguments = [BeforeCol]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return OMathMatCol(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class OMathMatRow:

    def __init__(self, omathmatrow=None):
        self.com_object= omathmatrow

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Args(self):
        return OMathArgs(self.com_object.Args)

    @property
    def args(self):
        """Alias for Args"""
        return self.Args

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RowIndex(self):
        return self.com_object.RowIndex

    @RowIndex.setter
    def RowIndex(self, value):
        self.com_object.RowIndex = value

    @property
    def rowindex(self):
        """Alias for RowIndex"""
        return self.RowIndex

    @rowindex.setter
    def rowindex(self, value):
        """Alias for RowIndex.setter"""
        self.RowIndex = value

    @property
    def row_index(self):
        """Alias for RowIndex"""
        return self.RowIndex

    @row_index.setter
    def row_index(self, value):
        """Alias for RowIndex.setter"""
        self.RowIndex = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class OMathMatRows:

    def __init__(self, omathmatrows=None):
        self.com_object= omathmatrows

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return OMathMatRows(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, BeforeRow=None):
        arguments = com_arguments([unwrap(a) for a in [BeforeRow]])
        return OMathMatRow(self.com_object.Add(*arguments))

    def add(self, BeforeRow=None):
        """Alias for Add"""
        arguments = [BeforeRow]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return OMathMatRow(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class OMathNary:

    def __init__(self, omathnary=None):
        self.com_object= omathnary

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Char(self):
        return self.com_object.Char

    @Char.setter
    def Char(self, value):
        self.com_object.Char = value

    @property
    def char(self):
        """Alias for Char"""
        return self.Char

    @char.setter
    def char(self, value):
        """Alias for Char.setter"""
        self.Char = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def E(self):
        return OMath(self.com_object.E)

    @property
    def e(self):
        """Alias for E"""
        return self.E

    @property
    def Grow(self):
        return self.com_object.Grow

    @Grow.setter
    def Grow(self, value):
        self.com_object.Grow = value

    @property
    def grow(self):
        """Alias for Grow"""
        return self.Grow

    @grow.setter
    def grow(self, value):
        """Alias for Grow.setter"""
        self.Grow = value

    @property
    def HideSub(self):
        return self.com_object.HideSub

    @HideSub.setter
    def HideSub(self, value):
        self.com_object.HideSub = value

    @property
    def hidesub(self):
        """Alias for HideSub"""
        return self.HideSub

    @hidesub.setter
    def hidesub(self, value):
        """Alias for HideSub.setter"""
        self.HideSub = value

    @property
    def hide_sub(self):
        """Alias for HideSub"""
        return self.HideSub

    @hide_sub.setter
    def hide_sub(self, value):
        """Alias for HideSub.setter"""
        self.HideSub = value

    @property
    def HideSup(self):
        return self.com_object.HideSup

    @HideSup.setter
    def HideSup(self, value):
        self.com_object.HideSup = value

    @property
    def hidesup(self):
        """Alias for HideSup"""
        return self.HideSup

    @hidesup.setter
    def hidesup(self, value):
        """Alias for HideSup.setter"""
        self.HideSup = value

    @property
    def hide_sup(self):
        """Alias for HideSup"""
        return self.HideSup

    @hide_sup.setter
    def hide_sup(self, value):
        """Alias for HideSup.setter"""
        self.HideSup = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Sub(self):
        return OMath(self.com_object.Sub)

    @property
    def sub(self):
        """Alias for Sub"""
        return self.Sub

    @property
    def SubSupLim(self):
        return self.com_object.SubSupLim

    @SubSupLim.setter
    def SubSupLim(self, value):
        self.com_object.SubSupLim = value

    @property
    def subsuplim(self):
        """Alias for SubSupLim"""
        return self.SubSupLim

    @subsuplim.setter
    def subsuplim(self, value):
        """Alias for SubSupLim.setter"""
        self.SubSupLim = value

    @property
    def sub_sup_lim(self):
        """Alias for SubSupLim"""
        return self.SubSupLim

    @sub_sup_lim.setter
    def sub_sup_lim(self, value):
        """Alias for SubSupLim.setter"""
        self.SubSupLim = value

    @property
    def Sup(self):
        return OMath(self.com_object.Sup)

    @property
    def sup(self):
        """Alias for Sup"""
        return self.Sup


class OMathPhantom:

    def __init__(self, omathphantom=None):
        self.com_object= omathphantom

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def E(self):
        return OMath(self.com_object.E)

    @property
    def e(self):
        """Alias for E"""
        return self.E

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Show(self):
        return self.com_object.Show

    @Show.setter
    def Show(self, value):
        self.com_object.Show = value

    @property
    def show(self):
        """Alias for Show"""
        return self.Show

    @show.setter
    def show(self, value):
        """Alias for Show.setter"""
        self.Show = value

    @property
    def Smash(self):
        return self.com_object.Smash

    @Smash.setter
    def Smash(self, value):
        self.com_object.Smash = value

    @property
    def smash(self):
        """Alias for Smash"""
        return self.Smash

    @smash.setter
    def smash(self, value):
        """Alias for Smash.setter"""
        self.Smash = value

    @property
    def Transp(self):
        return self.com_object.Transp

    @Transp.setter
    def Transp(self, value):
        self.com_object.Transp = value

    @property
    def transp(self):
        """Alias for Transp"""
        return self.Transp

    @transp.setter
    def transp(self, value):
        """Alias for Transp.setter"""
        self.Transp = value

    @property
    def ZeroAsc(self):
        return self.com_object.ZeroAsc

    @ZeroAsc.setter
    def ZeroAsc(self, value):
        self.com_object.ZeroAsc = value

    @property
    def zeroasc(self):
        """Alias for ZeroAsc"""
        return self.ZeroAsc

    @zeroasc.setter
    def zeroasc(self, value):
        """Alias for ZeroAsc.setter"""
        self.ZeroAsc = value

    @property
    def zero_asc(self):
        """Alias for ZeroAsc"""
        return self.ZeroAsc

    @zero_asc.setter
    def zero_asc(self, value):
        """Alias for ZeroAsc.setter"""
        self.ZeroAsc = value

    @property
    def ZeroDesc(self):
        return self.com_object.ZeroDesc

    @ZeroDesc.setter
    def ZeroDesc(self, value):
        self.com_object.ZeroDesc = value

    @property
    def zerodesc(self):
        """Alias for ZeroDesc"""
        return self.ZeroDesc

    @zerodesc.setter
    def zerodesc(self, value):
        """Alias for ZeroDesc.setter"""
        self.ZeroDesc = value

    @property
    def zero_desc(self):
        """Alias for ZeroDesc"""
        return self.ZeroDesc

    @zero_desc.setter
    def zero_desc(self, value):
        """Alias for ZeroDesc.setter"""
        self.ZeroDesc = value

    @property
    def ZeroWid(self):
        return self.com_object.ZeroWid

    @ZeroWid.setter
    def ZeroWid(self, value):
        self.com_object.ZeroWid = value

    @property
    def zerowid(self):
        """Alias for ZeroWid"""
        return self.ZeroWid

    @zerowid.setter
    def zerowid(self, value):
        """Alias for ZeroWid.setter"""
        self.ZeroWid = value

    @property
    def zero_wid(self):
        """Alias for ZeroWid"""
        return self.ZeroWid

    @zero_wid.setter
    def zero_wid(self, value):
        """Alias for ZeroWid.setter"""
        self.ZeroWid = value


class OMathRad:

    def __init__(self, omathrad=None):
        self.com_object= omathrad

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Deg(self):
        return OMath(self.com_object.Deg)

    @property
    def deg(self):
        """Alias for Deg"""
        return self.Deg

    @property
    def E(self):
        return OMath(self.com_object.E)

    @property
    def e(self):
        """Alias for E"""
        return self.E

    @property
    def HideDeg(self):
        return self.com_object.HideDeg

    @HideDeg.setter
    def HideDeg(self, value):
        self.com_object.HideDeg = value

    @property
    def hidedeg(self):
        """Alias for HideDeg"""
        return self.HideDeg

    @hidedeg.setter
    def hidedeg(self, value):
        """Alias for HideDeg.setter"""
        self.HideDeg = value

    @property
    def hide_deg(self):
        """Alias for HideDeg"""
        return self.HideDeg

    @hide_deg.setter
    def hide_deg(self, value):
        """Alias for HideDeg.setter"""
        self.HideDeg = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class OMathRecognizedFunction:

    def __init__(self, omathrecognizedfunction=None):
        self.com_object= omathrecognizedfunction

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class OMathRecognizedFunctions:

    def __init__(self, omathrecognizedfunctions=None):
        self.com_object= omathrecognizedfunctions

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return OMathRecognizedFunctions(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        return OMathRecognizedFunction(self.com_object.Add(*arguments))

    def add(self, Name=None):
        """Alias for Add"""
        arguments = [Name]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return OMathRecognizedFunction(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class OMaths:

    def __init__(self, omaths=None):
        self.com_object= omaths

    def __call__(self, item):
        return OMath(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return OMaths(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        return Range(self.com_object.Add(*arguments))

    def add(self, Range=None):
        """Alias for Add"""
        arguments = [Range]
        return self.Add(*arguments)

    def BuildUp(self):
        return self.com_object.BuildUp()

    def buildup(self):
        """Alias for BuildUp"""
        return self.BuildUp()

    def build_up(self):
        """Alias for BuildUp"""
        return self.BuildUp()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return OMath(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Linearize(self):
        return self.com_object.Linearize()

    def linearize(self):
        """Alias for Linearize"""
        return self.Linearize()


class OMathScrPre:

    def __init__(self, omathscrpre=None):
        self.com_object= omathscrpre

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def E(self):
        return OMath(self.com_object.E)

    @property
    def e(self):
        """Alias for E"""
        return self.E

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Sub(self):
        return OMath(self.com_object.Sub)

    @property
    def sub(self):
        """Alias for Sub"""
        return self.Sub

    @property
    def Sup(self):
        return OMath(self.com_object.Sup)

    @property
    def sup(self):
        """Alias for Sup"""
        return self.Sup

    def ToScrSubSup(self):
        return OMathFunction(self.com_object.ToScrSubSup())

    def toscrsubsup(self):
        """Alias for ToScrSubSup"""
        return self.ToScrSubSup()

    def to_scr_sub_sup(self):
        """Alias for ToScrSubSup"""
        return self.ToScrSubSup()


class OMathScrSub:

    def __init__(self, omathscrsub=None):
        self.com_object= omathscrsub

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def E(self):
        return OMath(self.com_object.E)

    @property
    def e(self):
        """Alias for E"""
        return self.E

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Sub(self):
        return OMath(self.com_object.Sub)

    @property
    def sub(self):
        """Alias for Sub"""
        return self.Sub


class OMathScrSubSup:

    def __init__(self, omathscrsubsup=None):
        self.com_object= omathscrsubsup

    @property
    def AlignScripts(self):
        return self.com_object.AlignScripts

    @AlignScripts.setter
    def AlignScripts(self, value):
        self.com_object.AlignScripts = value

    @property
    def alignscripts(self):
        """Alias for AlignScripts"""
        return self.AlignScripts

    @alignscripts.setter
    def alignscripts(self, value):
        """Alias for AlignScripts.setter"""
        self.AlignScripts = value

    @property
    def align_scripts(self):
        """Alias for AlignScripts"""
        return self.AlignScripts

    @align_scripts.setter
    def align_scripts(self, value):
        """Alias for AlignScripts.setter"""
        self.AlignScripts = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def E(self):
        return OMath(self.com_object.E)

    @property
    def e(self):
        """Alias for E"""
        return self.E

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Sub(self):
        return OMath(self.com_object.Sub)

    @property
    def sub(self):
        """Alias for Sub"""
        return self.Sub

    @property
    def Sup(self):
        return OMath(self.com_object.Sup)

    @property
    def sup(self):
        """Alias for Sup"""
        return self.Sup

    def RemoveSub(self):
        return OMathFunction(self.com_object.RemoveSub())

    def removesub(self):
        """Alias for RemoveSub"""
        return self.RemoveSub()

    def remove_sub(self):
        """Alias for RemoveSub"""
        return self.RemoveSub()

    def RemoveSup(self):
        return OMathFunction(self.com_object.RemoveSup())

    def removesup(self):
        """Alias for RemoveSup"""
        return self.RemoveSup()

    def remove_sup(self):
        """Alias for RemoveSup"""
        return self.RemoveSup()

    def ToScrPre(self):
        return OMathFunction(self.com_object.ToScrPre())

    def toscrpre(self):
        """Alias for ToScrPre"""
        return self.ToScrPre()

    def to_scr_pre(self):
        """Alias for ToScrPre"""
        return self.ToScrPre()


class OMathScrSup:

    def __init__(self, omathscrsup=None):
        self.com_object= omathscrsup

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def E(self):
        return OMath(self.com_object.E)

    @property
    def e(self):
        """Alias for E"""
        return self.E

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Sup(self):
        return OMath(self.com_object.Sup)

    @property
    def sup(self):
        """Alias for Sup"""
        return self.Sup


class Options:

    def __init__(self, options=None):
        self.com_object= options

    @property
    def AddBiDirectionalMarksWhenSavingTextFile(self):
        return self.com_object.AddBiDirectionalMarksWhenSavingTextFile

    @AddBiDirectionalMarksWhenSavingTextFile.setter
    def AddBiDirectionalMarksWhenSavingTextFile(self, value):
        self.com_object.AddBiDirectionalMarksWhenSavingTextFile = value

    @property
    def addbidirectionalmarkswhensavingtextfile(self):
        """Alias for AddBiDirectionalMarksWhenSavingTextFile"""
        return self.AddBiDirectionalMarksWhenSavingTextFile

    @addbidirectionalmarkswhensavingtextfile.setter
    def addbidirectionalmarkswhensavingtextfile(self, value):
        """Alias for AddBiDirectionalMarksWhenSavingTextFile.setter"""
        self.AddBiDirectionalMarksWhenSavingTextFile = value

    @property
    def add_bi_directional_marks_when_saving_text_file(self):
        """Alias for AddBiDirectionalMarksWhenSavingTextFile"""
        return self.AddBiDirectionalMarksWhenSavingTextFile

    @add_bi_directional_marks_when_saving_text_file.setter
    def add_bi_directional_marks_when_saving_text_file(self, value):
        """Alias for AddBiDirectionalMarksWhenSavingTextFile.setter"""
        self.AddBiDirectionalMarksWhenSavingTextFile = value

    @property
    def AddControlCharacters(self):
        return self.com_object.AddControlCharacters

    @AddControlCharacters.setter
    def AddControlCharacters(self, value):
        self.com_object.AddControlCharacters = value

    @property
    def addcontrolcharacters(self):
        """Alias for AddControlCharacters"""
        return self.AddControlCharacters

    @addcontrolcharacters.setter
    def addcontrolcharacters(self, value):
        """Alias for AddControlCharacters.setter"""
        self.AddControlCharacters = value

    @property
    def add_control_characters(self):
        """Alias for AddControlCharacters"""
        return self.AddControlCharacters

    @add_control_characters.setter
    def add_control_characters(self, value):
        """Alias for AddControlCharacters.setter"""
        self.AddControlCharacters = value

    @property
    def AddHebDoubleQuote(self):
        return self.com_object.AddHebDoubleQuote

    @AddHebDoubleQuote.setter
    def AddHebDoubleQuote(self, value):
        self.com_object.AddHebDoubleQuote = value

    @property
    def addhebdoublequote(self):
        """Alias for AddHebDoubleQuote"""
        return self.AddHebDoubleQuote

    @addhebdoublequote.setter
    def addhebdoublequote(self, value):
        """Alias for AddHebDoubleQuote.setter"""
        self.AddHebDoubleQuote = value

    @property
    def add_heb_double_quote(self):
        """Alias for AddHebDoubleQuote"""
        return self.AddHebDoubleQuote

    @add_heb_double_quote.setter
    def add_heb_double_quote(self, value):
        """Alias for AddHebDoubleQuote.setter"""
        self.AddHebDoubleQuote = value

    @property
    def AlertIfNotDefault(self):
        return self.com_object.AlertIfNotDefault

    @AlertIfNotDefault.setter
    def AlertIfNotDefault(self, value):
        self.com_object.AlertIfNotDefault = value

    @property
    def alertifnotdefault(self):
        """Alias for AlertIfNotDefault"""
        return self.AlertIfNotDefault

    @alertifnotdefault.setter
    def alertifnotdefault(self, value):
        """Alias for AlertIfNotDefault.setter"""
        self.AlertIfNotDefault = value

    @property
    def alert_if_not_default(self):
        """Alias for AlertIfNotDefault"""
        return self.AlertIfNotDefault

    @alert_if_not_default.setter
    def alert_if_not_default(self, value):
        """Alias for AlertIfNotDefault.setter"""
        self.AlertIfNotDefault = value

    @property
    def AllowAccentedUppercase(self):
        return self.com_object.AllowAccentedUppercase

    @AllowAccentedUppercase.setter
    def AllowAccentedUppercase(self, value):
        self.com_object.AllowAccentedUppercase = value

    @property
    def allowaccenteduppercase(self):
        """Alias for AllowAccentedUppercase"""
        return self.AllowAccentedUppercase

    @allowaccenteduppercase.setter
    def allowaccenteduppercase(self, value):
        """Alias for AllowAccentedUppercase.setter"""
        self.AllowAccentedUppercase = value

    @property
    def allow_accented_uppercase(self):
        """Alias for AllowAccentedUppercase"""
        return self.AllowAccentedUppercase

    @allow_accented_uppercase.setter
    def allow_accented_uppercase(self, value):
        """Alias for AllowAccentedUppercase.setter"""
        self.AllowAccentedUppercase = value

    @property
    def AllowClickAndTypeMouse(self):
        return self.com_object.AllowClickAndTypeMouse

    @AllowClickAndTypeMouse.setter
    def AllowClickAndTypeMouse(self, value):
        self.com_object.AllowClickAndTypeMouse = value

    @property
    def allowclickandtypemouse(self):
        """Alias for AllowClickAndTypeMouse"""
        return self.AllowClickAndTypeMouse

    @allowclickandtypemouse.setter
    def allowclickandtypemouse(self, value):
        """Alias for AllowClickAndTypeMouse.setter"""
        self.AllowClickAndTypeMouse = value

    @property
    def allow_click_and_type_mouse(self):
        """Alias for AllowClickAndTypeMouse"""
        return self.AllowClickAndTypeMouse

    @allow_click_and_type_mouse.setter
    def allow_click_and_type_mouse(self, value):
        """Alias for AllowClickAndTypeMouse.setter"""
        self.AllowClickAndTypeMouse = value

    @property
    def AllowCombinedAuxiliaryForms(self):
        return self.com_object.AllowCombinedAuxiliaryForms

    @AllowCombinedAuxiliaryForms.setter
    def AllowCombinedAuxiliaryForms(self, value):
        self.com_object.AllowCombinedAuxiliaryForms = value

    @property
    def allowcombinedauxiliaryforms(self):
        """Alias for AllowCombinedAuxiliaryForms"""
        return self.AllowCombinedAuxiliaryForms

    @allowcombinedauxiliaryforms.setter
    def allowcombinedauxiliaryforms(self, value):
        """Alias for AllowCombinedAuxiliaryForms.setter"""
        self.AllowCombinedAuxiliaryForms = value

    @property
    def allow_combined_auxiliary_forms(self):
        """Alias for AllowCombinedAuxiliaryForms"""
        return self.AllowCombinedAuxiliaryForms

    @allow_combined_auxiliary_forms.setter
    def allow_combined_auxiliary_forms(self, value):
        """Alias for AllowCombinedAuxiliaryForms.setter"""
        self.AllowCombinedAuxiliaryForms = value

    @property
    def AllowCompoundNounProcessing(self):
        return self.com_object.AllowCompoundNounProcessing

    @AllowCompoundNounProcessing.setter
    def AllowCompoundNounProcessing(self, value):
        self.com_object.AllowCompoundNounProcessing = value

    @property
    def allowcompoundnounprocessing(self):
        """Alias for AllowCompoundNounProcessing"""
        return self.AllowCompoundNounProcessing

    @allowcompoundnounprocessing.setter
    def allowcompoundnounprocessing(self, value):
        """Alias for AllowCompoundNounProcessing.setter"""
        self.AllowCompoundNounProcessing = value

    @property
    def allow_compound_noun_processing(self):
        """Alias for AllowCompoundNounProcessing"""
        return self.AllowCompoundNounProcessing

    @allow_compound_noun_processing.setter
    def allow_compound_noun_processing(self, value):
        """Alias for AllowCompoundNounProcessing.setter"""
        self.AllowCompoundNounProcessing = value

    @property
    def AllowDragAndDrop(self):
        return self.com_object.AllowDragAndDrop

    @AllowDragAndDrop.setter
    def AllowDragAndDrop(self, value):
        self.com_object.AllowDragAndDrop = value

    @property
    def allowdraganddrop(self):
        """Alias for AllowDragAndDrop"""
        return self.AllowDragAndDrop

    @allowdraganddrop.setter
    def allowdraganddrop(self, value):
        """Alias for AllowDragAndDrop.setter"""
        self.AllowDragAndDrop = value

    @property
    def allow_drag_and_drop(self):
        """Alias for AllowDragAndDrop"""
        return self.AllowDragAndDrop

    @allow_drag_and_drop.setter
    def allow_drag_and_drop(self, value):
        """Alias for AllowDragAndDrop.setter"""
        self.AllowDragAndDrop = value

    @property
    def AllowOpenInDraftView(self):
        return self.com_object.AllowOpenInDraftView

    @AllowOpenInDraftView.setter
    def AllowOpenInDraftView(self, value):
        self.com_object.AllowOpenInDraftView = value

    @property
    def allowopenindraftview(self):
        """Alias for AllowOpenInDraftView"""
        return self.AllowOpenInDraftView

    @allowopenindraftview.setter
    def allowopenindraftview(self, value):
        """Alias for AllowOpenInDraftView.setter"""
        self.AllowOpenInDraftView = value

    @property
    def allow_open_in_draft_view(self):
        """Alias for AllowOpenInDraftView"""
        return self.AllowOpenInDraftView

    @allow_open_in_draft_view.setter
    def allow_open_in_draft_view(self, value):
        """Alias for AllowOpenInDraftView.setter"""
        self.AllowOpenInDraftView = value

    @property
    def AllowPixelUnits(self):
        return self.com_object.AllowPixelUnits

    @AllowPixelUnits.setter
    def AllowPixelUnits(self, value):
        self.com_object.AllowPixelUnits = value

    @property
    def allowpixelunits(self):
        """Alias for AllowPixelUnits"""
        return self.AllowPixelUnits

    @allowpixelunits.setter
    def allowpixelunits(self, value):
        """Alias for AllowPixelUnits.setter"""
        self.AllowPixelUnits = value

    @property
    def allow_pixel_units(self):
        """Alias for AllowPixelUnits"""
        return self.AllowPixelUnits

    @allow_pixel_units.setter
    def allow_pixel_units(self, value):
        """Alias for AllowPixelUnits.setter"""
        self.AllowPixelUnits = value

    @property
    def AllowReadingMode(self):
        return self.com_object.AllowReadingMode

    @AllowReadingMode.setter
    def AllowReadingMode(self, value):
        self.com_object.AllowReadingMode = value

    @property
    def allowreadingmode(self):
        """Alias for AllowReadingMode"""
        return self.AllowReadingMode

    @allowreadingmode.setter
    def allowreadingmode(self, value):
        """Alias for AllowReadingMode.setter"""
        self.AllowReadingMode = value

    @property
    def allow_reading_mode(self):
        """Alias for AllowReadingMode"""
        return self.AllowReadingMode

    @allow_reading_mode.setter
    def allow_reading_mode(self, value):
        """Alias for AllowReadingMode.setter"""
        self.AllowReadingMode = value

    @property
    def AnimateScreenMovements(self):
        return self.com_object.AnimateScreenMovements

    @AnimateScreenMovements.setter
    def AnimateScreenMovements(self, value):
        self.com_object.AnimateScreenMovements = value

    @property
    def animatescreenmovements(self):
        """Alias for AnimateScreenMovements"""
        return self.AnimateScreenMovements

    @animatescreenmovements.setter
    def animatescreenmovements(self, value):
        """Alias for AnimateScreenMovements.setter"""
        self.AnimateScreenMovements = value

    @property
    def animate_screen_movements(self):
        """Alias for AnimateScreenMovements"""
        return self.AnimateScreenMovements

    @animate_screen_movements.setter
    def animate_screen_movements(self, value):
        """Alias for AnimateScreenMovements.setter"""
        self.AnimateScreenMovements = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ApplyFarEastFontsToAscii(self):
        return self.com_object.ApplyFarEastFontsToAscii

    @ApplyFarEastFontsToAscii.setter
    def ApplyFarEastFontsToAscii(self, value):
        self.com_object.ApplyFarEastFontsToAscii = value

    @property
    def applyfareastfontstoascii(self):
        """Alias for ApplyFarEastFontsToAscii"""
        return self.ApplyFarEastFontsToAscii

    @applyfareastfontstoascii.setter
    def applyfareastfontstoascii(self, value):
        """Alias for ApplyFarEastFontsToAscii.setter"""
        self.ApplyFarEastFontsToAscii = value

    @property
    def apply_far_east_fonts_to_ascii(self):
        """Alias for ApplyFarEastFontsToAscii"""
        return self.ApplyFarEastFontsToAscii

    @apply_far_east_fonts_to_ascii.setter
    def apply_far_east_fonts_to_ascii(self, value):
        """Alias for ApplyFarEastFontsToAscii.setter"""
        self.ApplyFarEastFontsToAscii = value

    @property
    def ArabicMode(self):
        return WdAraSpeller(self.com_object.ArabicMode)

    @ArabicMode.setter
    def ArabicMode(self, value):
        self.com_object.ArabicMode = value

    @property
    def arabicmode(self):
        """Alias for ArabicMode"""
        return self.ArabicMode

    @arabicmode.setter
    def arabicmode(self, value):
        """Alias for ArabicMode.setter"""
        self.ArabicMode = value

    @property
    def arabic_mode(self):
        """Alias for ArabicMode"""
        return self.ArabicMode

    @arabic_mode.setter
    def arabic_mode(self, value):
        """Alias for ArabicMode.setter"""
        self.ArabicMode = value

    @property
    def ArabicNumeral(self):
        return WdArabicNumeral(self.com_object.ArabicNumeral)

    @ArabicNumeral.setter
    def ArabicNumeral(self, value):
        self.com_object.ArabicNumeral = value

    @property
    def arabicnumeral(self):
        """Alias for ArabicNumeral"""
        return self.ArabicNumeral

    @arabicnumeral.setter
    def arabicnumeral(self, value):
        """Alias for ArabicNumeral.setter"""
        self.ArabicNumeral = value

    @property
    def arabic_numeral(self):
        """Alias for ArabicNumeral"""
        return self.ArabicNumeral

    @arabic_numeral.setter
    def arabic_numeral(self, value):
        """Alias for ArabicNumeral.setter"""
        self.ArabicNumeral = value

    @property
    def AutoCreateNewDrawings(self):
        return self.com_object.AutoCreateNewDrawings

    @AutoCreateNewDrawings.setter
    def AutoCreateNewDrawings(self, value):
        self.com_object.AutoCreateNewDrawings = value

    @property
    def autocreatenewdrawings(self):
        """Alias for AutoCreateNewDrawings"""
        return self.AutoCreateNewDrawings

    @autocreatenewdrawings.setter
    def autocreatenewdrawings(self, value):
        """Alias for AutoCreateNewDrawings.setter"""
        self.AutoCreateNewDrawings = value

    @property
    def auto_create_new_drawings(self):
        """Alias for AutoCreateNewDrawings"""
        return self.AutoCreateNewDrawings

    @auto_create_new_drawings.setter
    def auto_create_new_drawings(self, value):
        """Alias for AutoCreateNewDrawings.setter"""
        self.AutoCreateNewDrawings = value

    @property
    def AutoFormatApplyBulletedLists(self):
        return self.com_object.AutoFormatApplyBulletedLists

    @AutoFormatApplyBulletedLists.setter
    def AutoFormatApplyBulletedLists(self, value):
        self.com_object.AutoFormatApplyBulletedLists = value

    @property
    def autoformatapplybulletedlists(self):
        """Alias for AutoFormatApplyBulletedLists"""
        return self.AutoFormatApplyBulletedLists

    @autoformatapplybulletedlists.setter
    def autoformatapplybulletedlists(self, value):
        """Alias for AutoFormatApplyBulletedLists.setter"""
        self.AutoFormatApplyBulletedLists = value

    @property
    def auto_format_apply_bulleted_lists(self):
        """Alias for AutoFormatApplyBulletedLists"""
        return self.AutoFormatApplyBulletedLists

    @auto_format_apply_bulleted_lists.setter
    def auto_format_apply_bulleted_lists(self, value):
        """Alias for AutoFormatApplyBulletedLists.setter"""
        self.AutoFormatApplyBulletedLists = value

    @property
    def AutoFormatApplyFirstIndents(self):
        return self.com_object.AutoFormatApplyFirstIndents

    @AutoFormatApplyFirstIndents.setter
    def AutoFormatApplyFirstIndents(self, value):
        self.com_object.AutoFormatApplyFirstIndents = value

    @property
    def autoformatapplyfirstindents(self):
        """Alias for AutoFormatApplyFirstIndents"""
        return self.AutoFormatApplyFirstIndents

    @autoformatapplyfirstindents.setter
    def autoformatapplyfirstindents(self, value):
        """Alias for AutoFormatApplyFirstIndents.setter"""
        self.AutoFormatApplyFirstIndents = value

    @property
    def auto_format_apply_first_indents(self):
        """Alias for AutoFormatApplyFirstIndents"""
        return self.AutoFormatApplyFirstIndents

    @auto_format_apply_first_indents.setter
    def auto_format_apply_first_indents(self, value):
        """Alias for AutoFormatApplyFirstIndents.setter"""
        self.AutoFormatApplyFirstIndents = value

    @property
    def AutoFormatApplyHeadings(self):
        return self.com_object.AutoFormatApplyHeadings

    @AutoFormatApplyHeadings.setter
    def AutoFormatApplyHeadings(self, value):
        self.com_object.AutoFormatApplyHeadings = value

    @property
    def autoformatapplyheadings(self):
        """Alias for AutoFormatApplyHeadings"""
        return self.AutoFormatApplyHeadings

    @autoformatapplyheadings.setter
    def autoformatapplyheadings(self, value):
        """Alias for AutoFormatApplyHeadings.setter"""
        self.AutoFormatApplyHeadings = value

    @property
    def auto_format_apply_headings(self):
        """Alias for AutoFormatApplyHeadings"""
        return self.AutoFormatApplyHeadings

    @auto_format_apply_headings.setter
    def auto_format_apply_headings(self, value):
        """Alias for AutoFormatApplyHeadings.setter"""
        self.AutoFormatApplyHeadings = value

    @property
    def AutoFormatApplyLists(self):
        return self.com_object.AutoFormatApplyLists

    @AutoFormatApplyLists.setter
    def AutoFormatApplyLists(self, value):
        self.com_object.AutoFormatApplyLists = value

    @property
    def autoformatapplylists(self):
        """Alias for AutoFormatApplyLists"""
        return self.AutoFormatApplyLists

    @autoformatapplylists.setter
    def autoformatapplylists(self, value):
        """Alias for AutoFormatApplyLists.setter"""
        self.AutoFormatApplyLists = value

    @property
    def auto_format_apply_lists(self):
        """Alias for AutoFormatApplyLists"""
        return self.AutoFormatApplyLists

    @auto_format_apply_lists.setter
    def auto_format_apply_lists(self, value):
        """Alias for AutoFormatApplyLists.setter"""
        self.AutoFormatApplyLists = value

    @property
    def AutoFormatApplyOtherParas(self):
        return self.com_object.AutoFormatApplyOtherParas

    @AutoFormatApplyOtherParas.setter
    def AutoFormatApplyOtherParas(self, value):
        self.com_object.AutoFormatApplyOtherParas = value

    @property
    def autoformatapplyotherparas(self):
        """Alias for AutoFormatApplyOtherParas"""
        return self.AutoFormatApplyOtherParas

    @autoformatapplyotherparas.setter
    def autoformatapplyotherparas(self, value):
        """Alias for AutoFormatApplyOtherParas.setter"""
        self.AutoFormatApplyOtherParas = value

    @property
    def auto_format_apply_other_paras(self):
        """Alias for AutoFormatApplyOtherParas"""
        return self.AutoFormatApplyOtherParas

    @auto_format_apply_other_paras.setter
    def auto_format_apply_other_paras(self, value):
        """Alias for AutoFormatApplyOtherParas.setter"""
        self.AutoFormatApplyOtherParas = value

    @property
    def AutoFormatAsYouTypeApplyBorders(self):
        return self.com_object.AutoFormatAsYouTypeApplyBorders

    @AutoFormatAsYouTypeApplyBorders.setter
    def AutoFormatAsYouTypeApplyBorders(self, value):
        self.com_object.AutoFormatAsYouTypeApplyBorders = value

    @property
    def autoformatasyoutypeapplyborders(self):
        """Alias for AutoFormatAsYouTypeApplyBorders"""
        return self.AutoFormatAsYouTypeApplyBorders

    @autoformatasyoutypeapplyborders.setter
    def autoformatasyoutypeapplyborders(self, value):
        """Alias for AutoFormatAsYouTypeApplyBorders.setter"""
        self.AutoFormatAsYouTypeApplyBorders = value

    @property
    def auto_format_as_you_type_apply_borders(self):
        """Alias for AutoFormatAsYouTypeApplyBorders"""
        return self.AutoFormatAsYouTypeApplyBorders

    @auto_format_as_you_type_apply_borders.setter
    def auto_format_as_you_type_apply_borders(self, value):
        """Alias for AutoFormatAsYouTypeApplyBorders.setter"""
        self.AutoFormatAsYouTypeApplyBorders = value

    @property
    def AutoFormatAsYouTypeApplyBulletedLists(self):
        return self.com_object.AutoFormatAsYouTypeApplyBulletedLists

    @AutoFormatAsYouTypeApplyBulletedLists.setter
    def AutoFormatAsYouTypeApplyBulletedLists(self, value):
        self.com_object.AutoFormatAsYouTypeApplyBulletedLists = value

    @property
    def autoformatasyoutypeapplybulletedlists(self):
        """Alias for AutoFormatAsYouTypeApplyBulletedLists"""
        return self.AutoFormatAsYouTypeApplyBulletedLists

    @autoformatasyoutypeapplybulletedlists.setter
    def autoformatasyoutypeapplybulletedlists(self, value):
        """Alias for AutoFormatAsYouTypeApplyBulletedLists.setter"""
        self.AutoFormatAsYouTypeApplyBulletedLists = value

    @property
    def auto_format_as_you_type_apply_bulleted_lists(self):
        """Alias for AutoFormatAsYouTypeApplyBulletedLists"""
        return self.AutoFormatAsYouTypeApplyBulletedLists

    @auto_format_as_you_type_apply_bulleted_lists.setter
    def auto_format_as_you_type_apply_bulleted_lists(self, value):
        """Alias for AutoFormatAsYouTypeApplyBulletedLists.setter"""
        self.AutoFormatAsYouTypeApplyBulletedLists = value

    @property
    def AutoFormatAsYouTypeApplyClosings(self):
        return self.com_object.AutoFormatAsYouTypeApplyClosings

    @AutoFormatAsYouTypeApplyClosings.setter
    def AutoFormatAsYouTypeApplyClosings(self, value):
        self.com_object.AutoFormatAsYouTypeApplyClosings = value

    @property
    def autoformatasyoutypeapplyclosings(self):
        """Alias for AutoFormatAsYouTypeApplyClosings"""
        return self.AutoFormatAsYouTypeApplyClosings

    @autoformatasyoutypeapplyclosings.setter
    def autoformatasyoutypeapplyclosings(self, value):
        """Alias for AutoFormatAsYouTypeApplyClosings.setter"""
        self.AutoFormatAsYouTypeApplyClosings = value

    @property
    def auto_format_as_you_type_apply_closings(self):
        """Alias for AutoFormatAsYouTypeApplyClosings"""
        return self.AutoFormatAsYouTypeApplyClosings

    @auto_format_as_you_type_apply_closings.setter
    def auto_format_as_you_type_apply_closings(self, value):
        """Alias for AutoFormatAsYouTypeApplyClosings.setter"""
        self.AutoFormatAsYouTypeApplyClosings = value

    @property
    def AutoFormatAsYouTypeApplyDates(self):
        return self.com_object.AutoFormatAsYouTypeApplyDates

    @AutoFormatAsYouTypeApplyDates.setter
    def AutoFormatAsYouTypeApplyDates(self, value):
        self.com_object.AutoFormatAsYouTypeApplyDates = value

    @property
    def autoformatasyoutypeapplydates(self):
        """Alias for AutoFormatAsYouTypeApplyDates"""
        return self.AutoFormatAsYouTypeApplyDates

    @autoformatasyoutypeapplydates.setter
    def autoformatasyoutypeapplydates(self, value):
        """Alias for AutoFormatAsYouTypeApplyDates.setter"""
        self.AutoFormatAsYouTypeApplyDates = value

    @property
    def auto_format_as_you_type_apply_dates(self):
        """Alias for AutoFormatAsYouTypeApplyDates"""
        return self.AutoFormatAsYouTypeApplyDates

    @auto_format_as_you_type_apply_dates.setter
    def auto_format_as_you_type_apply_dates(self, value):
        """Alias for AutoFormatAsYouTypeApplyDates.setter"""
        self.AutoFormatAsYouTypeApplyDates = value

    @property
    def AutoFormatAsYouTypeApplyFirstIndents(self):
        return self.com_object.AutoFormatAsYouTypeApplyFirstIndents

    @AutoFormatAsYouTypeApplyFirstIndents.setter
    def AutoFormatAsYouTypeApplyFirstIndents(self, value):
        self.com_object.AutoFormatAsYouTypeApplyFirstIndents = value

    @property
    def autoformatasyoutypeapplyfirstindents(self):
        """Alias for AutoFormatAsYouTypeApplyFirstIndents"""
        return self.AutoFormatAsYouTypeApplyFirstIndents

    @autoformatasyoutypeapplyfirstindents.setter
    def autoformatasyoutypeapplyfirstindents(self, value):
        """Alias for AutoFormatAsYouTypeApplyFirstIndents.setter"""
        self.AutoFormatAsYouTypeApplyFirstIndents = value

    @property
    def auto_format_as_you_type_apply_first_indents(self):
        """Alias for AutoFormatAsYouTypeApplyFirstIndents"""
        return self.AutoFormatAsYouTypeApplyFirstIndents

    @auto_format_as_you_type_apply_first_indents.setter
    def auto_format_as_you_type_apply_first_indents(self, value):
        """Alias for AutoFormatAsYouTypeApplyFirstIndents.setter"""
        self.AutoFormatAsYouTypeApplyFirstIndents = value

    @property
    def AutoFormatAsYouTypeApplyHeadings(self):
        return self.com_object.AutoFormatAsYouTypeApplyHeadings

    @AutoFormatAsYouTypeApplyHeadings.setter
    def AutoFormatAsYouTypeApplyHeadings(self, value):
        self.com_object.AutoFormatAsYouTypeApplyHeadings = value

    @property
    def autoformatasyoutypeapplyheadings(self):
        """Alias for AutoFormatAsYouTypeApplyHeadings"""
        return self.AutoFormatAsYouTypeApplyHeadings

    @autoformatasyoutypeapplyheadings.setter
    def autoformatasyoutypeapplyheadings(self, value):
        """Alias for AutoFormatAsYouTypeApplyHeadings.setter"""
        self.AutoFormatAsYouTypeApplyHeadings = value

    @property
    def auto_format_as_you_type_apply_headings(self):
        """Alias for AutoFormatAsYouTypeApplyHeadings"""
        return self.AutoFormatAsYouTypeApplyHeadings

    @auto_format_as_you_type_apply_headings.setter
    def auto_format_as_you_type_apply_headings(self, value):
        """Alias for AutoFormatAsYouTypeApplyHeadings.setter"""
        self.AutoFormatAsYouTypeApplyHeadings = value

    @property
    def AutoFormatAsYouTypeApplyNumberedLists(self):
        return self.com_object.AutoFormatAsYouTypeApplyNumberedLists

    @AutoFormatAsYouTypeApplyNumberedLists.setter
    def AutoFormatAsYouTypeApplyNumberedLists(self, value):
        self.com_object.AutoFormatAsYouTypeApplyNumberedLists = value

    @property
    def autoformatasyoutypeapplynumberedlists(self):
        """Alias for AutoFormatAsYouTypeApplyNumberedLists"""
        return self.AutoFormatAsYouTypeApplyNumberedLists

    @autoformatasyoutypeapplynumberedlists.setter
    def autoformatasyoutypeapplynumberedlists(self, value):
        """Alias for AutoFormatAsYouTypeApplyNumberedLists.setter"""
        self.AutoFormatAsYouTypeApplyNumberedLists = value

    @property
    def auto_format_as_you_type_apply_numbered_lists(self):
        """Alias for AutoFormatAsYouTypeApplyNumberedLists"""
        return self.AutoFormatAsYouTypeApplyNumberedLists

    @auto_format_as_you_type_apply_numbered_lists.setter
    def auto_format_as_you_type_apply_numbered_lists(self, value):
        """Alias for AutoFormatAsYouTypeApplyNumberedLists.setter"""
        self.AutoFormatAsYouTypeApplyNumberedLists = value

    @property
    def AutoFormatAsYouTypeApplyTables(self):
        return self.com_object.AutoFormatAsYouTypeApplyTables

    @AutoFormatAsYouTypeApplyTables.setter
    def AutoFormatAsYouTypeApplyTables(self, value):
        self.com_object.AutoFormatAsYouTypeApplyTables = value

    @property
    def autoformatasyoutypeapplytables(self):
        """Alias for AutoFormatAsYouTypeApplyTables"""
        return self.AutoFormatAsYouTypeApplyTables

    @autoformatasyoutypeapplytables.setter
    def autoformatasyoutypeapplytables(self, value):
        """Alias for AutoFormatAsYouTypeApplyTables.setter"""
        self.AutoFormatAsYouTypeApplyTables = value

    @property
    def auto_format_as_you_type_apply_tables(self):
        """Alias for AutoFormatAsYouTypeApplyTables"""
        return self.AutoFormatAsYouTypeApplyTables

    @auto_format_as_you_type_apply_tables.setter
    def auto_format_as_you_type_apply_tables(self, value):
        """Alias for AutoFormatAsYouTypeApplyTables.setter"""
        self.AutoFormatAsYouTypeApplyTables = value

    @property
    def AutoFormatAsYouTypeAutoLetterWizard(self):
        return self.com_object.AutoFormatAsYouTypeAutoLetterWizard

    @AutoFormatAsYouTypeAutoLetterWizard.setter
    def AutoFormatAsYouTypeAutoLetterWizard(self, value):
        self.com_object.AutoFormatAsYouTypeAutoLetterWizard = value

    @property
    def autoformatasyoutypeautoletterwizard(self):
        """Alias for AutoFormatAsYouTypeAutoLetterWizard"""
        return self.AutoFormatAsYouTypeAutoLetterWizard

    @autoformatasyoutypeautoletterwizard.setter
    def autoformatasyoutypeautoletterwizard(self, value):
        """Alias for AutoFormatAsYouTypeAutoLetterWizard.setter"""
        self.AutoFormatAsYouTypeAutoLetterWizard = value

    @property
    def auto_format_as_you_type_auto_letter_wizard(self):
        """Alias for AutoFormatAsYouTypeAutoLetterWizard"""
        return self.AutoFormatAsYouTypeAutoLetterWizard

    @auto_format_as_you_type_auto_letter_wizard.setter
    def auto_format_as_you_type_auto_letter_wizard(self, value):
        """Alias for AutoFormatAsYouTypeAutoLetterWizard.setter"""
        self.AutoFormatAsYouTypeAutoLetterWizard = value

    @property
    def AutoFormatAsYouTypeDefineStyles(self):
        return self.com_object.AutoFormatAsYouTypeDefineStyles

    @AutoFormatAsYouTypeDefineStyles.setter
    def AutoFormatAsYouTypeDefineStyles(self, value):
        self.com_object.AutoFormatAsYouTypeDefineStyles = value

    @property
    def autoformatasyoutypedefinestyles(self):
        """Alias for AutoFormatAsYouTypeDefineStyles"""
        return self.AutoFormatAsYouTypeDefineStyles

    @autoformatasyoutypedefinestyles.setter
    def autoformatasyoutypedefinestyles(self, value):
        """Alias for AutoFormatAsYouTypeDefineStyles.setter"""
        self.AutoFormatAsYouTypeDefineStyles = value

    @property
    def auto_format_as_you_type_define_styles(self):
        """Alias for AutoFormatAsYouTypeDefineStyles"""
        return self.AutoFormatAsYouTypeDefineStyles

    @auto_format_as_you_type_define_styles.setter
    def auto_format_as_you_type_define_styles(self, value):
        """Alias for AutoFormatAsYouTypeDefineStyles.setter"""
        self.AutoFormatAsYouTypeDefineStyles = value

    @property
    def AutoFormatAsYouTypeDeleteAutoSpaces(self):
        return self.com_object.AutoFormatAsYouTypeDeleteAutoSpaces

    @AutoFormatAsYouTypeDeleteAutoSpaces.setter
    def AutoFormatAsYouTypeDeleteAutoSpaces(self, value):
        self.com_object.AutoFormatAsYouTypeDeleteAutoSpaces = value

    @property
    def autoformatasyoutypedeleteautospaces(self):
        """Alias for AutoFormatAsYouTypeDeleteAutoSpaces"""
        return self.AutoFormatAsYouTypeDeleteAutoSpaces

    @autoformatasyoutypedeleteautospaces.setter
    def autoformatasyoutypedeleteautospaces(self, value):
        """Alias for AutoFormatAsYouTypeDeleteAutoSpaces.setter"""
        self.AutoFormatAsYouTypeDeleteAutoSpaces = value

    @property
    def auto_format_as_you_type_delete_auto_spaces(self):
        """Alias for AutoFormatAsYouTypeDeleteAutoSpaces"""
        return self.AutoFormatAsYouTypeDeleteAutoSpaces

    @auto_format_as_you_type_delete_auto_spaces.setter
    def auto_format_as_you_type_delete_auto_spaces(self, value):
        """Alias for AutoFormatAsYouTypeDeleteAutoSpaces.setter"""
        self.AutoFormatAsYouTypeDeleteAutoSpaces = value

    @property
    def AutoFormatAsYouTypeFormatListItemBeginning(self):
        return self.com_object.AutoFormatAsYouTypeFormatListItemBeginning

    @AutoFormatAsYouTypeFormatListItemBeginning.setter
    def AutoFormatAsYouTypeFormatListItemBeginning(self, value):
        self.com_object.AutoFormatAsYouTypeFormatListItemBeginning = value

    @property
    def autoformatasyoutypeformatlistitembeginning(self):
        """Alias for AutoFormatAsYouTypeFormatListItemBeginning"""
        return self.AutoFormatAsYouTypeFormatListItemBeginning

    @autoformatasyoutypeformatlistitembeginning.setter
    def autoformatasyoutypeformatlistitembeginning(self, value):
        """Alias for AutoFormatAsYouTypeFormatListItemBeginning.setter"""
        self.AutoFormatAsYouTypeFormatListItemBeginning = value

    @property
    def auto_format_as_you_type_format_list_item_beginning(self):
        """Alias for AutoFormatAsYouTypeFormatListItemBeginning"""
        return self.AutoFormatAsYouTypeFormatListItemBeginning

    @auto_format_as_you_type_format_list_item_beginning.setter
    def auto_format_as_you_type_format_list_item_beginning(self, value):
        """Alias for AutoFormatAsYouTypeFormatListItemBeginning.setter"""
        self.AutoFormatAsYouTypeFormatListItemBeginning = value

    @property
    def AutoFormatAsYouTypeInsertClosings(self):
        return self.com_object.AutoFormatAsYouTypeInsertClosings

    @AutoFormatAsYouTypeInsertClosings.setter
    def AutoFormatAsYouTypeInsertClosings(self, value):
        self.com_object.AutoFormatAsYouTypeInsertClosings = value

    @property
    def autoformatasyoutypeinsertclosings(self):
        """Alias for AutoFormatAsYouTypeInsertClosings"""
        return self.AutoFormatAsYouTypeInsertClosings

    @autoformatasyoutypeinsertclosings.setter
    def autoformatasyoutypeinsertclosings(self, value):
        """Alias for AutoFormatAsYouTypeInsertClosings.setter"""
        self.AutoFormatAsYouTypeInsertClosings = value

    @property
    def auto_format_as_you_type_insert_closings(self):
        """Alias for AutoFormatAsYouTypeInsertClosings"""
        return self.AutoFormatAsYouTypeInsertClosings

    @auto_format_as_you_type_insert_closings.setter
    def auto_format_as_you_type_insert_closings(self, value):
        """Alias for AutoFormatAsYouTypeInsertClosings.setter"""
        self.AutoFormatAsYouTypeInsertClosings = value

    @property
    def AutoFormatAsYouTypeInsertOvers(self):
        return self.com_object.AutoFormatAsYouTypeInsertOvers

    @AutoFormatAsYouTypeInsertOvers.setter
    def AutoFormatAsYouTypeInsertOvers(self, value):
        self.com_object.AutoFormatAsYouTypeInsertOvers = value

    @property
    def autoformatasyoutypeinsertovers(self):
        """Alias for AutoFormatAsYouTypeInsertOvers"""
        return self.AutoFormatAsYouTypeInsertOvers

    @autoformatasyoutypeinsertovers.setter
    def autoformatasyoutypeinsertovers(self, value):
        """Alias for AutoFormatAsYouTypeInsertOvers.setter"""
        self.AutoFormatAsYouTypeInsertOvers = value

    @property
    def auto_format_as_you_type_insert_overs(self):
        """Alias for AutoFormatAsYouTypeInsertOvers"""
        return self.AutoFormatAsYouTypeInsertOvers

    @auto_format_as_you_type_insert_overs.setter
    def auto_format_as_you_type_insert_overs(self, value):
        """Alias for AutoFormatAsYouTypeInsertOvers.setter"""
        self.AutoFormatAsYouTypeInsertOvers = value

    @property
    def AutoFormatAsYouTypeMatchParentheses(self):
        return self.com_object.AutoFormatAsYouTypeMatchParentheses

    @AutoFormatAsYouTypeMatchParentheses.setter
    def AutoFormatAsYouTypeMatchParentheses(self, value):
        self.com_object.AutoFormatAsYouTypeMatchParentheses = value

    @property
    def autoformatasyoutypematchparentheses(self):
        """Alias for AutoFormatAsYouTypeMatchParentheses"""
        return self.AutoFormatAsYouTypeMatchParentheses

    @autoformatasyoutypematchparentheses.setter
    def autoformatasyoutypematchparentheses(self, value):
        """Alias for AutoFormatAsYouTypeMatchParentheses.setter"""
        self.AutoFormatAsYouTypeMatchParentheses = value

    @property
    def auto_format_as_you_type_match_parentheses(self):
        """Alias for AutoFormatAsYouTypeMatchParentheses"""
        return self.AutoFormatAsYouTypeMatchParentheses

    @auto_format_as_you_type_match_parentheses.setter
    def auto_format_as_you_type_match_parentheses(self, value):
        """Alias for AutoFormatAsYouTypeMatchParentheses.setter"""
        self.AutoFormatAsYouTypeMatchParentheses = value

    @property
    def AutoFormatAsYouTypeReplaceFarEastDashes(self):
        return self.com_object.AutoFormatAsYouTypeReplaceFarEastDashes

    @AutoFormatAsYouTypeReplaceFarEastDashes.setter
    def AutoFormatAsYouTypeReplaceFarEastDashes(self, value):
        self.com_object.AutoFormatAsYouTypeReplaceFarEastDashes = value

    @property
    def autoformatasyoutypereplacefareastdashes(self):
        """Alias for AutoFormatAsYouTypeReplaceFarEastDashes"""
        return self.AutoFormatAsYouTypeReplaceFarEastDashes

    @autoformatasyoutypereplacefareastdashes.setter
    def autoformatasyoutypereplacefareastdashes(self, value):
        """Alias for AutoFormatAsYouTypeReplaceFarEastDashes.setter"""
        self.AutoFormatAsYouTypeReplaceFarEastDashes = value

    @property
    def auto_format_as_you_type_replace_far_east_dashes(self):
        """Alias for AutoFormatAsYouTypeReplaceFarEastDashes"""
        return self.AutoFormatAsYouTypeReplaceFarEastDashes

    @auto_format_as_you_type_replace_far_east_dashes.setter
    def auto_format_as_you_type_replace_far_east_dashes(self, value):
        """Alias for AutoFormatAsYouTypeReplaceFarEastDashes.setter"""
        self.AutoFormatAsYouTypeReplaceFarEastDashes = value

    @property
    def AutoFormatAsYouTypeReplaceFractions(self):
        return self.com_object.AutoFormatAsYouTypeReplaceFractions

    @AutoFormatAsYouTypeReplaceFractions.setter
    def AutoFormatAsYouTypeReplaceFractions(self, value):
        self.com_object.AutoFormatAsYouTypeReplaceFractions = value

    @property
    def autoformatasyoutypereplacefractions(self):
        """Alias for AutoFormatAsYouTypeReplaceFractions"""
        return self.AutoFormatAsYouTypeReplaceFractions

    @autoformatasyoutypereplacefractions.setter
    def autoformatasyoutypereplacefractions(self, value):
        """Alias for AutoFormatAsYouTypeReplaceFractions.setter"""
        self.AutoFormatAsYouTypeReplaceFractions = value

    @property
    def auto_format_as_you_type_replace_fractions(self):
        """Alias for AutoFormatAsYouTypeReplaceFractions"""
        return self.AutoFormatAsYouTypeReplaceFractions

    @auto_format_as_you_type_replace_fractions.setter
    def auto_format_as_you_type_replace_fractions(self, value):
        """Alias for AutoFormatAsYouTypeReplaceFractions.setter"""
        self.AutoFormatAsYouTypeReplaceFractions = value

    @property
    def AutoFormatAsYouTypeReplaceHyperlinks(self):
        return self.com_object.AutoFormatAsYouTypeReplaceHyperlinks

    @AutoFormatAsYouTypeReplaceHyperlinks.setter
    def AutoFormatAsYouTypeReplaceHyperlinks(self, value):
        self.com_object.AutoFormatAsYouTypeReplaceHyperlinks = value

    @property
    def autoformatasyoutypereplacehyperlinks(self):
        """Alias for AutoFormatAsYouTypeReplaceHyperlinks"""
        return self.AutoFormatAsYouTypeReplaceHyperlinks

    @autoformatasyoutypereplacehyperlinks.setter
    def autoformatasyoutypereplacehyperlinks(self, value):
        """Alias for AutoFormatAsYouTypeReplaceHyperlinks.setter"""
        self.AutoFormatAsYouTypeReplaceHyperlinks = value

    @property
    def auto_format_as_you_type_replace_hyperlinks(self):
        """Alias for AutoFormatAsYouTypeReplaceHyperlinks"""
        return self.AutoFormatAsYouTypeReplaceHyperlinks

    @auto_format_as_you_type_replace_hyperlinks.setter
    def auto_format_as_you_type_replace_hyperlinks(self, value):
        """Alias for AutoFormatAsYouTypeReplaceHyperlinks.setter"""
        self.AutoFormatAsYouTypeReplaceHyperlinks = value

    @property
    def AutoFormatAsYouTypeReplaceOrdinals(self):
        return self.com_object.AutoFormatAsYouTypeReplaceOrdinals

    @AutoFormatAsYouTypeReplaceOrdinals.setter
    def AutoFormatAsYouTypeReplaceOrdinals(self, value):
        self.com_object.AutoFormatAsYouTypeReplaceOrdinals = value

    @property
    def autoformatasyoutypereplaceordinals(self):
        """Alias for AutoFormatAsYouTypeReplaceOrdinals"""
        return self.AutoFormatAsYouTypeReplaceOrdinals

    @autoformatasyoutypereplaceordinals.setter
    def autoformatasyoutypereplaceordinals(self, value):
        """Alias for AutoFormatAsYouTypeReplaceOrdinals.setter"""
        self.AutoFormatAsYouTypeReplaceOrdinals = value

    @property
    def auto_format_as_you_type_replace_ordinals(self):
        """Alias for AutoFormatAsYouTypeReplaceOrdinals"""
        return self.AutoFormatAsYouTypeReplaceOrdinals

    @auto_format_as_you_type_replace_ordinals.setter
    def auto_format_as_you_type_replace_ordinals(self, value):
        """Alias for AutoFormatAsYouTypeReplaceOrdinals.setter"""
        self.AutoFormatAsYouTypeReplaceOrdinals = value

    @property
    def AutoFormatAsYouTypeReplacePlainTextEmphasis(self):
        return self.com_object.AutoFormatAsYouTypeReplacePlainTextEmphasis

    @AutoFormatAsYouTypeReplacePlainTextEmphasis.setter
    def AutoFormatAsYouTypeReplacePlainTextEmphasis(self, value):
        self.com_object.AutoFormatAsYouTypeReplacePlainTextEmphasis = value

    @property
    def autoformatasyoutypereplaceplaintextemphasis(self):
        """Alias for AutoFormatAsYouTypeReplacePlainTextEmphasis"""
        return self.AutoFormatAsYouTypeReplacePlainTextEmphasis

    @autoformatasyoutypereplaceplaintextemphasis.setter
    def autoformatasyoutypereplaceplaintextemphasis(self, value):
        """Alias for AutoFormatAsYouTypeReplacePlainTextEmphasis.setter"""
        self.AutoFormatAsYouTypeReplacePlainTextEmphasis = value

    @property
    def auto_format_as_you_type_replace_plain_text_emphasis(self):
        """Alias for AutoFormatAsYouTypeReplacePlainTextEmphasis"""
        return self.AutoFormatAsYouTypeReplacePlainTextEmphasis

    @auto_format_as_you_type_replace_plain_text_emphasis.setter
    def auto_format_as_you_type_replace_plain_text_emphasis(self, value):
        """Alias for AutoFormatAsYouTypeReplacePlainTextEmphasis.setter"""
        self.AutoFormatAsYouTypeReplacePlainTextEmphasis = value

    @property
    def AutoFormatAsYouTypeReplaceQuotes(self):
        return self.com_object.AutoFormatAsYouTypeReplaceQuotes

    @AutoFormatAsYouTypeReplaceQuotes.setter
    def AutoFormatAsYouTypeReplaceQuotes(self, value):
        self.com_object.AutoFormatAsYouTypeReplaceQuotes = value

    @property
    def autoformatasyoutypereplacequotes(self):
        """Alias for AutoFormatAsYouTypeReplaceQuotes"""
        return self.AutoFormatAsYouTypeReplaceQuotes

    @autoformatasyoutypereplacequotes.setter
    def autoformatasyoutypereplacequotes(self, value):
        """Alias for AutoFormatAsYouTypeReplaceQuotes.setter"""
        self.AutoFormatAsYouTypeReplaceQuotes = value

    @property
    def auto_format_as_you_type_replace_quotes(self):
        """Alias for AutoFormatAsYouTypeReplaceQuotes"""
        return self.AutoFormatAsYouTypeReplaceQuotes

    @auto_format_as_you_type_replace_quotes.setter
    def auto_format_as_you_type_replace_quotes(self, value):
        """Alias for AutoFormatAsYouTypeReplaceQuotes.setter"""
        self.AutoFormatAsYouTypeReplaceQuotes = value

    @property
    def AutoFormatAsYouTypeReplaceSymbols(self):
        return self.com_object.AutoFormatAsYouTypeReplaceSymbols

    @AutoFormatAsYouTypeReplaceSymbols.setter
    def AutoFormatAsYouTypeReplaceSymbols(self, value):
        self.com_object.AutoFormatAsYouTypeReplaceSymbols = value

    @property
    def autoformatasyoutypereplacesymbols(self):
        """Alias for AutoFormatAsYouTypeReplaceSymbols"""
        return self.AutoFormatAsYouTypeReplaceSymbols

    @autoformatasyoutypereplacesymbols.setter
    def autoformatasyoutypereplacesymbols(self, value):
        """Alias for AutoFormatAsYouTypeReplaceSymbols.setter"""
        self.AutoFormatAsYouTypeReplaceSymbols = value

    @property
    def auto_format_as_you_type_replace_symbols(self):
        """Alias for AutoFormatAsYouTypeReplaceSymbols"""
        return self.AutoFormatAsYouTypeReplaceSymbols

    @auto_format_as_you_type_replace_symbols.setter
    def auto_format_as_you_type_replace_symbols(self, value):
        """Alias for AutoFormatAsYouTypeReplaceSymbols.setter"""
        self.AutoFormatAsYouTypeReplaceSymbols = value

    @property
    def AutoFormatDeleteAutoSpaces(self):
        return self.com_object.AutoFormatDeleteAutoSpaces

    @AutoFormatDeleteAutoSpaces.setter
    def AutoFormatDeleteAutoSpaces(self, value):
        self.com_object.AutoFormatDeleteAutoSpaces = value

    @property
    def autoformatdeleteautospaces(self):
        """Alias for AutoFormatDeleteAutoSpaces"""
        return self.AutoFormatDeleteAutoSpaces

    @autoformatdeleteautospaces.setter
    def autoformatdeleteautospaces(self, value):
        """Alias for AutoFormatDeleteAutoSpaces.setter"""
        self.AutoFormatDeleteAutoSpaces = value

    @property
    def auto_format_delete_auto_spaces(self):
        """Alias for AutoFormatDeleteAutoSpaces"""
        return self.AutoFormatDeleteAutoSpaces

    @auto_format_delete_auto_spaces.setter
    def auto_format_delete_auto_spaces(self, value):
        """Alias for AutoFormatDeleteAutoSpaces.setter"""
        self.AutoFormatDeleteAutoSpaces = value

    @property
    def AutoFormatMatchParentheses(self):
        return self.com_object.AutoFormatMatchParentheses

    @AutoFormatMatchParentheses.setter
    def AutoFormatMatchParentheses(self, value):
        self.com_object.AutoFormatMatchParentheses = value

    @property
    def autoformatmatchparentheses(self):
        """Alias for AutoFormatMatchParentheses"""
        return self.AutoFormatMatchParentheses

    @autoformatmatchparentheses.setter
    def autoformatmatchparentheses(self, value):
        """Alias for AutoFormatMatchParentheses.setter"""
        self.AutoFormatMatchParentheses = value

    @property
    def auto_format_match_parentheses(self):
        """Alias for AutoFormatMatchParentheses"""
        return self.AutoFormatMatchParentheses

    @auto_format_match_parentheses.setter
    def auto_format_match_parentheses(self, value):
        """Alias for AutoFormatMatchParentheses.setter"""
        self.AutoFormatMatchParentheses = value

    @property
    def AutoFormatPlainTextWordMail(self):
        return self.com_object.AutoFormatPlainTextWordMail

    @AutoFormatPlainTextWordMail.setter
    def AutoFormatPlainTextWordMail(self, value):
        self.com_object.AutoFormatPlainTextWordMail = value

    @property
    def autoformatplaintextwordmail(self):
        """Alias for AutoFormatPlainTextWordMail"""
        return self.AutoFormatPlainTextWordMail

    @autoformatplaintextwordmail.setter
    def autoformatplaintextwordmail(self, value):
        """Alias for AutoFormatPlainTextWordMail.setter"""
        self.AutoFormatPlainTextWordMail = value

    @property
    def auto_format_plain_text_word_mail(self):
        """Alias for AutoFormatPlainTextWordMail"""
        return self.AutoFormatPlainTextWordMail

    @auto_format_plain_text_word_mail.setter
    def auto_format_plain_text_word_mail(self, value):
        """Alias for AutoFormatPlainTextWordMail.setter"""
        self.AutoFormatPlainTextWordMail = value

    @property
    def AutoFormatPreserveStyles(self):
        return self.com_object.AutoFormatPreserveStyles

    @AutoFormatPreserveStyles.setter
    def AutoFormatPreserveStyles(self, value):
        self.com_object.AutoFormatPreserveStyles = value

    @property
    def autoformatpreservestyles(self):
        """Alias for AutoFormatPreserveStyles"""
        return self.AutoFormatPreserveStyles

    @autoformatpreservestyles.setter
    def autoformatpreservestyles(self, value):
        """Alias for AutoFormatPreserveStyles.setter"""
        self.AutoFormatPreserveStyles = value

    @property
    def auto_format_preserve_styles(self):
        """Alias for AutoFormatPreserveStyles"""
        return self.AutoFormatPreserveStyles

    @auto_format_preserve_styles.setter
    def auto_format_preserve_styles(self, value):
        """Alias for AutoFormatPreserveStyles.setter"""
        self.AutoFormatPreserveStyles = value

    @property
    def AutoFormatReplaceFarEastDashes(self):
        return self.com_object.AutoFormatReplaceFarEastDashes

    @AutoFormatReplaceFarEastDashes.setter
    def AutoFormatReplaceFarEastDashes(self, value):
        self.com_object.AutoFormatReplaceFarEastDashes = value

    @property
    def autoformatreplacefareastdashes(self):
        """Alias for AutoFormatReplaceFarEastDashes"""
        return self.AutoFormatReplaceFarEastDashes

    @autoformatreplacefareastdashes.setter
    def autoformatreplacefareastdashes(self, value):
        """Alias for AutoFormatReplaceFarEastDashes.setter"""
        self.AutoFormatReplaceFarEastDashes = value

    @property
    def auto_format_replace_far_east_dashes(self):
        """Alias for AutoFormatReplaceFarEastDashes"""
        return self.AutoFormatReplaceFarEastDashes

    @auto_format_replace_far_east_dashes.setter
    def auto_format_replace_far_east_dashes(self, value):
        """Alias for AutoFormatReplaceFarEastDashes.setter"""
        self.AutoFormatReplaceFarEastDashes = value

    @property
    def AutoFormatReplaceFractions(self):
        return self.com_object.AutoFormatReplaceFractions

    @AutoFormatReplaceFractions.setter
    def AutoFormatReplaceFractions(self, value):
        self.com_object.AutoFormatReplaceFractions = value

    @property
    def autoformatreplacefractions(self):
        """Alias for AutoFormatReplaceFractions"""
        return self.AutoFormatReplaceFractions

    @autoformatreplacefractions.setter
    def autoformatreplacefractions(self, value):
        """Alias for AutoFormatReplaceFractions.setter"""
        self.AutoFormatReplaceFractions = value

    @property
    def auto_format_replace_fractions(self):
        """Alias for AutoFormatReplaceFractions"""
        return self.AutoFormatReplaceFractions

    @auto_format_replace_fractions.setter
    def auto_format_replace_fractions(self, value):
        """Alias for AutoFormatReplaceFractions.setter"""
        self.AutoFormatReplaceFractions = value

    @property
    def AutoFormatReplaceHyperlinks(self):
        return self.com_object.AutoFormatReplaceHyperlinks

    @AutoFormatReplaceHyperlinks.setter
    def AutoFormatReplaceHyperlinks(self, value):
        self.com_object.AutoFormatReplaceHyperlinks = value

    @property
    def autoformatreplacehyperlinks(self):
        """Alias for AutoFormatReplaceHyperlinks"""
        return self.AutoFormatReplaceHyperlinks

    @autoformatreplacehyperlinks.setter
    def autoformatreplacehyperlinks(self, value):
        """Alias for AutoFormatReplaceHyperlinks.setter"""
        self.AutoFormatReplaceHyperlinks = value

    @property
    def auto_format_replace_hyperlinks(self):
        """Alias for AutoFormatReplaceHyperlinks"""
        return self.AutoFormatReplaceHyperlinks

    @auto_format_replace_hyperlinks.setter
    def auto_format_replace_hyperlinks(self, value):
        """Alias for AutoFormatReplaceHyperlinks.setter"""
        self.AutoFormatReplaceHyperlinks = value

    @property
    def AutoFormatReplaceOrdinals(self):
        return self.com_object.AutoFormatReplaceOrdinals

    @AutoFormatReplaceOrdinals.setter
    def AutoFormatReplaceOrdinals(self, value):
        self.com_object.AutoFormatReplaceOrdinals = value

    @property
    def autoformatreplaceordinals(self):
        """Alias for AutoFormatReplaceOrdinals"""
        return self.AutoFormatReplaceOrdinals

    @autoformatreplaceordinals.setter
    def autoformatreplaceordinals(self, value):
        """Alias for AutoFormatReplaceOrdinals.setter"""
        self.AutoFormatReplaceOrdinals = value

    @property
    def auto_format_replace_ordinals(self):
        """Alias for AutoFormatReplaceOrdinals"""
        return self.AutoFormatReplaceOrdinals

    @auto_format_replace_ordinals.setter
    def auto_format_replace_ordinals(self, value):
        """Alias for AutoFormatReplaceOrdinals.setter"""
        self.AutoFormatReplaceOrdinals = value

    @property
    def AutoFormatReplacePlainTextEmphasis(self):
        return self.com_object.AutoFormatReplacePlainTextEmphasis

    @AutoFormatReplacePlainTextEmphasis.setter
    def AutoFormatReplacePlainTextEmphasis(self, value):
        self.com_object.AutoFormatReplacePlainTextEmphasis = value

    @property
    def autoformatreplaceplaintextemphasis(self):
        """Alias for AutoFormatReplacePlainTextEmphasis"""
        return self.AutoFormatReplacePlainTextEmphasis

    @autoformatreplaceplaintextemphasis.setter
    def autoformatreplaceplaintextemphasis(self, value):
        """Alias for AutoFormatReplacePlainTextEmphasis.setter"""
        self.AutoFormatReplacePlainTextEmphasis = value

    @property
    def auto_format_replace_plain_text_emphasis(self):
        """Alias for AutoFormatReplacePlainTextEmphasis"""
        return self.AutoFormatReplacePlainTextEmphasis

    @auto_format_replace_plain_text_emphasis.setter
    def auto_format_replace_plain_text_emphasis(self, value):
        """Alias for AutoFormatReplacePlainTextEmphasis.setter"""
        self.AutoFormatReplacePlainTextEmphasis = value

    @property
    def AutoFormatReplaceQuotes(self):
        return self.com_object.AutoFormatReplaceQuotes

    @AutoFormatReplaceQuotes.setter
    def AutoFormatReplaceQuotes(self, value):
        self.com_object.AutoFormatReplaceQuotes = value

    @property
    def autoformatreplacequotes(self):
        """Alias for AutoFormatReplaceQuotes"""
        return self.AutoFormatReplaceQuotes

    @autoformatreplacequotes.setter
    def autoformatreplacequotes(self, value):
        """Alias for AutoFormatReplaceQuotes.setter"""
        self.AutoFormatReplaceQuotes = value

    @property
    def auto_format_replace_quotes(self):
        """Alias for AutoFormatReplaceQuotes"""
        return self.AutoFormatReplaceQuotes

    @auto_format_replace_quotes.setter
    def auto_format_replace_quotes(self, value):
        """Alias for AutoFormatReplaceQuotes.setter"""
        self.AutoFormatReplaceQuotes = value

    @property
    def AutoFormatReplaceSymbols(self):
        return self.com_object.AutoFormatReplaceSymbols

    @AutoFormatReplaceSymbols.setter
    def AutoFormatReplaceSymbols(self, value):
        self.com_object.AutoFormatReplaceSymbols = value

    @property
    def autoformatreplacesymbols(self):
        """Alias for AutoFormatReplaceSymbols"""
        return self.AutoFormatReplaceSymbols

    @autoformatreplacesymbols.setter
    def autoformatreplacesymbols(self, value):
        """Alias for AutoFormatReplaceSymbols.setter"""
        self.AutoFormatReplaceSymbols = value

    @property
    def auto_format_replace_symbols(self):
        """Alias for AutoFormatReplaceSymbols"""
        return self.AutoFormatReplaceSymbols

    @auto_format_replace_symbols.setter
    def auto_format_replace_symbols(self, value):
        """Alias for AutoFormatReplaceSymbols.setter"""
        self.AutoFormatReplaceSymbols = value

    @property
    def AutoKeyboardSwitching(self):
        return self.com_object.AutoKeyboardSwitching

    @AutoKeyboardSwitching.setter
    def AutoKeyboardSwitching(self, value):
        self.com_object.AutoKeyboardSwitching = value

    @property
    def autokeyboardswitching(self):
        """Alias for AutoKeyboardSwitching"""
        return self.AutoKeyboardSwitching

    @autokeyboardswitching.setter
    def autokeyboardswitching(self, value):
        """Alias for AutoKeyboardSwitching.setter"""
        self.AutoKeyboardSwitching = value

    @property
    def auto_keyboard_switching(self):
        """Alias for AutoKeyboardSwitching"""
        return self.AutoKeyboardSwitching

    @auto_keyboard_switching.setter
    def auto_keyboard_switching(self, value):
        """Alias for AutoKeyboardSwitching.setter"""
        self.AutoKeyboardSwitching = value

    @property
    def AutoWordSelection(self):
        return self.com_object.AutoWordSelection

    @AutoWordSelection.setter
    def AutoWordSelection(self, value):
        self.com_object.AutoWordSelection = value

    @property
    def autowordselection(self):
        """Alias for AutoWordSelection"""
        return self.AutoWordSelection

    @autowordselection.setter
    def autowordselection(self, value):
        """Alias for AutoWordSelection.setter"""
        self.AutoWordSelection = value

    @property
    def auto_word_selection(self):
        """Alias for AutoWordSelection"""
        return self.AutoWordSelection

    @auto_word_selection.setter
    def auto_word_selection(self, value):
        """Alias for AutoWordSelection.setter"""
        self.AutoWordSelection = value

    @property
    def BackgroundSave(self):
        return self.com_object.BackgroundSave

    @BackgroundSave.setter
    def BackgroundSave(self, value):
        self.com_object.BackgroundSave = value

    @property
    def backgroundsave(self):
        """Alias for BackgroundSave"""
        return self.BackgroundSave

    @backgroundsave.setter
    def backgroundsave(self, value):
        """Alias for BackgroundSave.setter"""
        self.BackgroundSave = value

    @property
    def background_save(self):
        """Alias for BackgroundSave"""
        return self.BackgroundSave

    @background_save.setter
    def background_save(self, value):
        """Alias for BackgroundSave.setter"""
        self.BackgroundSave = value

    @property
    def BibliographySort(self):
        return self.com_object.BibliographySort

    @BibliographySort.setter
    def BibliographySort(self, value):
        self.com_object.BibliographySort = value

    @property
    def bibliographysort(self):
        """Alias for BibliographySort"""
        return self.BibliographySort

    @bibliographysort.setter
    def bibliographysort(self, value):
        """Alias for BibliographySort.setter"""
        self.BibliographySort = value

    @property
    def bibliography_sort(self):
        """Alias for BibliographySort"""
        return self.BibliographySort

    @bibliography_sort.setter
    def bibliography_sort(self, value):
        """Alias for BibliographySort.setter"""
        self.BibliographySort = value

    @property
    def BibliographyStyle(self):
        return self.com_object.BibliographyStyle

    @BibliographyStyle.setter
    def BibliographyStyle(self, value):
        self.com_object.BibliographyStyle = value

    @property
    def bibliographystyle(self):
        """Alias for BibliographyStyle"""
        return self.BibliographyStyle

    @bibliographystyle.setter
    def bibliographystyle(self, value):
        """Alias for BibliographyStyle.setter"""
        self.BibliographyStyle = value

    @property
    def bibliography_style(self):
        """Alias for BibliographyStyle"""
        return self.BibliographyStyle

    @bibliography_style.setter
    def bibliography_style(self, value):
        """Alias for BibliographyStyle.setter"""
        self.BibliographyStyle = value

    @property
    def BrazilReform(self):
        return self.com_object.BrazilReform

    @BrazilReform.setter
    def BrazilReform(self, value):
        self.com_object.BrazilReform = value

    @property
    def brazilreform(self):
        """Alias for BrazilReform"""
        return self.BrazilReform

    @brazilreform.setter
    def brazilreform(self, value):
        """Alias for BrazilReform.setter"""
        self.BrazilReform = value

    @property
    def brazil_reform(self):
        """Alias for BrazilReform"""
        return self.BrazilReform

    @brazil_reform.setter
    def brazil_reform(self, value):
        """Alias for BrazilReform.setter"""
        self.BrazilReform = value

    @property
    def ButtonFieldClicks(self):
        return self.com_object.ButtonFieldClicks

    @ButtonFieldClicks.setter
    def ButtonFieldClicks(self, value):
        self.com_object.ButtonFieldClicks = value

    @property
    def buttonfieldclicks(self):
        """Alias for ButtonFieldClicks"""
        return self.ButtonFieldClicks

    @buttonfieldclicks.setter
    def buttonfieldclicks(self, value):
        """Alias for ButtonFieldClicks.setter"""
        self.ButtonFieldClicks = value

    @property
    def button_field_clicks(self):
        """Alias for ButtonFieldClicks"""
        return self.ButtonFieldClicks

    @button_field_clicks.setter
    def button_field_clicks(self, value):
        """Alias for ButtonFieldClicks.setter"""
        self.ButtonFieldClicks = value

    @property
    def CheckGrammarAsYouType(self):
        return self.com_object.CheckGrammarAsYouType

    @CheckGrammarAsYouType.setter
    def CheckGrammarAsYouType(self, value):
        self.com_object.CheckGrammarAsYouType = value

    @property
    def checkgrammarasyoutype(self):
        """Alias for CheckGrammarAsYouType"""
        return self.CheckGrammarAsYouType

    @checkgrammarasyoutype.setter
    def checkgrammarasyoutype(self, value):
        """Alias for CheckGrammarAsYouType.setter"""
        self.CheckGrammarAsYouType = value

    @property
    def check_grammar_as_you_type(self):
        """Alias for CheckGrammarAsYouType"""
        return self.CheckGrammarAsYouType

    @check_grammar_as_you_type.setter
    def check_grammar_as_you_type(self, value):
        """Alias for CheckGrammarAsYouType.setter"""
        self.CheckGrammarAsYouType = value

    @property
    def CheckGrammarWithSpelling(self):
        return self.com_object.CheckGrammarWithSpelling

    @CheckGrammarWithSpelling.setter
    def CheckGrammarWithSpelling(self, value):
        self.com_object.CheckGrammarWithSpelling = value

    @property
    def checkgrammarwithspelling(self):
        """Alias for CheckGrammarWithSpelling"""
        return self.CheckGrammarWithSpelling

    @checkgrammarwithspelling.setter
    def checkgrammarwithspelling(self, value):
        """Alias for CheckGrammarWithSpelling.setter"""
        self.CheckGrammarWithSpelling = value

    @property
    def check_grammar_with_spelling(self):
        """Alias for CheckGrammarWithSpelling"""
        return self.CheckGrammarWithSpelling

    @check_grammar_with_spelling.setter
    def check_grammar_with_spelling(self, value):
        """Alias for CheckGrammarWithSpelling.setter"""
        self.CheckGrammarWithSpelling = value

    @property
    def CheckHangulEndings(self):
        return self.com_object.CheckHangulEndings

    @CheckHangulEndings.setter
    def CheckHangulEndings(self, value):
        self.com_object.CheckHangulEndings = value

    @property
    def checkhangulendings(self):
        """Alias for CheckHangulEndings"""
        return self.CheckHangulEndings

    @checkhangulendings.setter
    def checkhangulendings(self, value):
        """Alias for CheckHangulEndings.setter"""
        self.CheckHangulEndings = value

    @property
    def check_hangul_endings(self):
        """Alias for CheckHangulEndings"""
        return self.CheckHangulEndings

    @check_hangul_endings.setter
    def check_hangul_endings(self, value):
        """Alias for CheckHangulEndings.setter"""
        self.CheckHangulEndings = value

    @property
    def CheckSpellingAsYouType(self):
        return self.com_object.CheckSpellingAsYouType

    @CheckSpellingAsYouType.setter
    def CheckSpellingAsYouType(self, value):
        self.com_object.CheckSpellingAsYouType = value

    @property
    def checkspellingasyoutype(self):
        """Alias for CheckSpellingAsYouType"""
        return self.CheckSpellingAsYouType

    @checkspellingasyoutype.setter
    def checkspellingasyoutype(self, value):
        """Alias for CheckSpellingAsYouType.setter"""
        self.CheckSpellingAsYouType = value

    @property
    def check_spelling_as_you_type(self):
        """Alias for CheckSpellingAsYouType"""
        return self.CheckSpellingAsYouType

    @check_spelling_as_you_type.setter
    def check_spelling_as_you_type(self, value):
        """Alias for CheckSpellingAsYouType.setter"""
        self.CheckSpellingAsYouType = value

    @property
    def CloudSignInOption(self):
        return self.com_object.CloudSignInOption

    @CloudSignInOption.setter
    def CloudSignInOption(self, value):
        self.com_object.CloudSignInOption = value

    @property
    def cloudsigninoption(self):
        """Alias for CloudSignInOption"""
        return self.CloudSignInOption

    @cloudsigninoption.setter
    def cloudsigninoption(self, value):
        """Alias for CloudSignInOption.setter"""
        self.CloudSignInOption = value

    @property
    def cloud_sign_in_option(self):
        """Alias for CloudSignInOption"""
        return self.CloudSignInOption

    @cloud_sign_in_option.setter
    def cloud_sign_in_option(self, value):
        """Alias for CloudSignInOption.setter"""
        self.CloudSignInOption = value

    @property
    def CommentsColor(self):
        return WdColorIndex(self.com_object.CommentsColor)

    @CommentsColor.setter
    def CommentsColor(self, value):
        self.com_object.CommentsColor = value

    @property
    def commentscolor(self):
        """Alias for CommentsColor"""
        return self.CommentsColor

    @commentscolor.setter
    def commentscolor(self, value):
        """Alias for CommentsColor.setter"""
        self.CommentsColor = value

    @property
    def comments_color(self):
        """Alias for CommentsColor"""
        return self.CommentsColor

    @comments_color.setter
    def comments_color(self, value):
        """Alias for CommentsColor.setter"""
        self.CommentsColor = value

    @property
    def ConfirmConversions(self):
        return self.com_object.ConfirmConversions

    @ConfirmConversions.setter
    def ConfirmConversions(self, value):
        self.com_object.ConfirmConversions = value

    @property
    def confirmconversions(self):
        """Alias for ConfirmConversions"""
        return self.ConfirmConversions

    @confirmconversions.setter
    def confirmconversions(self, value):
        """Alias for ConfirmConversions.setter"""
        self.ConfirmConversions = value

    @property
    def confirm_conversions(self):
        """Alias for ConfirmConversions"""
        return self.ConfirmConversions

    @confirm_conversions.setter
    def confirm_conversions(self, value):
        """Alias for ConfirmConversions.setter"""
        self.ConfirmConversions = value

    @property
    def ContextualSpeller(self):
        return self.com_object.ContextualSpeller

    @ContextualSpeller.setter
    def ContextualSpeller(self, value):
        self.com_object.ContextualSpeller = value

    @property
    def contextualspeller(self):
        """Alias for ContextualSpeller"""
        return self.ContextualSpeller

    @contextualspeller.setter
    def contextualspeller(self, value):
        """Alias for ContextualSpeller.setter"""
        self.ContextualSpeller = value

    @property
    def contextual_speller(self):
        """Alias for ContextualSpeller"""
        return self.ContextualSpeller

    @contextual_speller.setter
    def contextual_speller(self, value):
        """Alias for ContextualSpeller.setter"""
        self.ContextualSpeller = value

    @property
    def ConvertHighAnsiToFarEast(self):
        return self.com_object.ConvertHighAnsiToFarEast

    @ConvertHighAnsiToFarEast.setter
    def ConvertHighAnsiToFarEast(self, value):
        self.com_object.ConvertHighAnsiToFarEast = value

    @property
    def converthighansitofareast(self):
        """Alias for ConvertHighAnsiToFarEast"""
        return self.ConvertHighAnsiToFarEast

    @converthighansitofareast.setter
    def converthighansitofareast(self, value):
        """Alias for ConvertHighAnsiToFarEast.setter"""
        self.ConvertHighAnsiToFarEast = value

    @property
    def convert_high_ansi_to_far_east(self):
        """Alias for ConvertHighAnsiToFarEast"""
        return self.ConvertHighAnsiToFarEast

    @convert_high_ansi_to_far_east.setter
    def convert_high_ansi_to_far_east(self, value):
        """Alias for ConvertHighAnsiToFarEast.setter"""
        self.ConvertHighAnsiToFarEast = value

    @property
    def CreateBackup(self):
        return self.com_object.CreateBackup

    @CreateBackup.setter
    def CreateBackup(self, value):
        self.com_object.CreateBackup = value

    @property
    def createbackup(self):
        """Alias for CreateBackup"""
        return self.CreateBackup

    @createbackup.setter
    def createbackup(self, value):
        """Alias for CreateBackup.setter"""
        self.CreateBackup = value

    @property
    def create_backup(self):
        """Alias for CreateBackup"""
        return self.CreateBackup

    @create_backup.setter
    def create_backup(self, value):
        """Alias for CreateBackup.setter"""
        self.CreateBackup = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def CtrlClickHyperlinkToOpen(self):
        return self.com_object.CtrlClickHyperlinkToOpen

    @CtrlClickHyperlinkToOpen.setter
    def CtrlClickHyperlinkToOpen(self, value):
        self.com_object.CtrlClickHyperlinkToOpen = value

    @property
    def ctrlclickhyperlinktoopen(self):
        """Alias for CtrlClickHyperlinkToOpen"""
        return self.CtrlClickHyperlinkToOpen

    @ctrlclickhyperlinktoopen.setter
    def ctrlclickhyperlinktoopen(self, value):
        """Alias for CtrlClickHyperlinkToOpen.setter"""
        self.CtrlClickHyperlinkToOpen = value

    @property
    def ctrl_click_hyperlink_to_open(self):
        """Alias for CtrlClickHyperlinkToOpen"""
        return self.CtrlClickHyperlinkToOpen

    @ctrl_click_hyperlink_to_open.setter
    def ctrl_click_hyperlink_to_open(self, value):
        """Alias for CtrlClickHyperlinkToOpen.setter"""
        self.CtrlClickHyperlinkToOpen = value

    @property
    def CursorMovement(self):
        return WdCursorMovement(self.com_object.CursorMovement)

    @CursorMovement.setter
    def CursorMovement(self, value):
        self.com_object.CursorMovement = value

    @property
    def cursormovement(self):
        """Alias for CursorMovement"""
        return self.CursorMovement

    @cursormovement.setter
    def cursormovement(self, value):
        """Alias for CursorMovement.setter"""
        self.CursorMovement = value

    @property
    def cursor_movement(self):
        """Alias for CursorMovement"""
        return self.CursorMovement

    @cursor_movement.setter
    def cursor_movement(self, value):
        """Alias for CursorMovement.setter"""
        self.CursorMovement = value

    @property
    def DefaultBorderColor(self):
        return Border(self.com_object.DefaultBorderColor)

    @DefaultBorderColor.setter
    def DefaultBorderColor(self, value):
        self.com_object.DefaultBorderColor = value

    @property
    def defaultbordercolor(self):
        """Alias for DefaultBorderColor"""
        return self.DefaultBorderColor

    @defaultbordercolor.setter
    def defaultbordercolor(self, value):
        """Alias for DefaultBorderColor.setter"""
        self.DefaultBorderColor = value

    @property
    def default_border_color(self):
        """Alias for DefaultBorderColor"""
        return self.DefaultBorderColor

    @default_border_color.setter
    def default_border_color(self, value):
        """Alias for DefaultBorderColor.setter"""
        self.DefaultBorderColor = value

    @property
    def DefaultBorderColorIndex(self):
        return WdColorIndex(self.com_object.DefaultBorderColorIndex)

    @DefaultBorderColorIndex.setter
    def DefaultBorderColorIndex(self, value):
        self.com_object.DefaultBorderColorIndex = value

    @property
    def defaultbordercolorindex(self):
        """Alias for DefaultBorderColorIndex"""
        return self.DefaultBorderColorIndex

    @defaultbordercolorindex.setter
    def defaultbordercolorindex(self, value):
        """Alias for DefaultBorderColorIndex.setter"""
        self.DefaultBorderColorIndex = value

    @property
    def default_border_color_index(self):
        """Alias for DefaultBorderColorIndex"""
        return self.DefaultBorderColorIndex

    @default_border_color_index.setter
    def default_border_color_index(self, value):
        """Alias for DefaultBorderColorIndex.setter"""
        self.DefaultBorderColorIndex = value

    @property
    def DefaultBorderLineStyle(self):
        return WdLineStyle(self.com_object.DefaultBorderLineStyle)

    @DefaultBorderLineStyle.setter
    def DefaultBorderLineStyle(self, value):
        self.com_object.DefaultBorderLineStyle = value

    @property
    def defaultborderlinestyle(self):
        """Alias for DefaultBorderLineStyle"""
        return self.DefaultBorderLineStyle

    @defaultborderlinestyle.setter
    def defaultborderlinestyle(self, value):
        """Alias for DefaultBorderLineStyle.setter"""
        self.DefaultBorderLineStyle = value

    @property
    def default_border_line_style(self):
        """Alias for DefaultBorderLineStyle"""
        return self.DefaultBorderLineStyle

    @default_border_line_style.setter
    def default_border_line_style(self, value):
        """Alias for DefaultBorderLineStyle.setter"""
        self.DefaultBorderLineStyle = value

    @property
    def DefaultBorderLineWidth(self):
        return WdLineWidth(self.com_object.DefaultBorderLineWidth)

    @DefaultBorderLineWidth.setter
    def DefaultBorderLineWidth(self, value):
        self.com_object.DefaultBorderLineWidth = value

    @property
    def defaultborderlinewidth(self):
        """Alias for DefaultBorderLineWidth"""
        return self.DefaultBorderLineWidth

    @defaultborderlinewidth.setter
    def defaultborderlinewidth(self, value):
        """Alias for DefaultBorderLineWidth.setter"""
        self.DefaultBorderLineWidth = value

    @property
    def default_border_line_width(self):
        """Alias for DefaultBorderLineWidth"""
        return self.DefaultBorderLineWidth

    @default_border_line_width.setter
    def default_border_line_width(self, value):
        """Alias for DefaultBorderLineWidth.setter"""
        self.DefaultBorderLineWidth = value

    @property
    def DefaultEPostageApp(self):
        return self.com_object.DefaultEPostageApp

    @DefaultEPostageApp.setter
    def DefaultEPostageApp(self, value):
        self.com_object.DefaultEPostageApp = value

    @property
    def defaultepostageapp(self):
        """Alias for DefaultEPostageApp"""
        return self.DefaultEPostageApp

    @defaultepostageapp.setter
    def defaultepostageapp(self, value):
        """Alias for DefaultEPostageApp.setter"""
        self.DefaultEPostageApp = value

    @property
    def default_e_postage_app(self):
        """Alias for DefaultEPostageApp"""
        return self.DefaultEPostageApp

    @default_e_postage_app.setter
    def default_e_postage_app(self, value):
        """Alias for DefaultEPostageApp.setter"""
        self.DefaultEPostageApp = value

    @property
    def DefaultFilePath(self):
        return self.com_object.DefaultFilePath

    @DefaultFilePath.setter
    def DefaultFilePath(self, value):
        self.com_object.DefaultFilePath = value

    @property
    def defaultfilepath(self):
        """Alias for DefaultFilePath"""
        return self.DefaultFilePath

    @defaultfilepath.setter
    def defaultfilepath(self, value):
        """Alias for DefaultFilePath.setter"""
        self.DefaultFilePath = value

    @property
    def default_file_path(self):
        """Alias for DefaultFilePath"""
        return self.DefaultFilePath

    @default_file_path.setter
    def default_file_path(self, value):
        """Alias for DefaultFilePath.setter"""
        self.DefaultFilePath = value

    @property
    def DefaultHighlightColorIndex(self):
        return self.com_object.DefaultHighlightColorIndex

    @DefaultHighlightColorIndex.setter
    def DefaultHighlightColorIndex(self, value):
        self.com_object.DefaultHighlightColorIndex = value

    @property
    def defaulthighlightcolorindex(self):
        """Alias for DefaultHighlightColorIndex"""
        return self.DefaultHighlightColorIndex

    @defaulthighlightcolorindex.setter
    def defaulthighlightcolorindex(self, value):
        """Alias for DefaultHighlightColorIndex.setter"""
        self.DefaultHighlightColorIndex = value

    @property
    def default_highlight_color_index(self):
        """Alias for DefaultHighlightColorIndex"""
        return self.DefaultHighlightColorIndex

    @default_highlight_color_index.setter
    def default_highlight_color_index(self, value):
        """Alias for DefaultHighlightColorIndex.setter"""
        self.DefaultHighlightColorIndex = value

    @property
    def DefaultOpenFormat(self):
        return self.com_object.DefaultOpenFormat

    @DefaultOpenFormat.setter
    def DefaultOpenFormat(self, value):
        self.com_object.DefaultOpenFormat = value

    @property
    def defaultopenformat(self):
        """Alias for DefaultOpenFormat"""
        return self.DefaultOpenFormat

    @defaultopenformat.setter
    def defaultopenformat(self, value):
        """Alias for DefaultOpenFormat.setter"""
        self.DefaultOpenFormat = value

    @property
    def default_open_format(self):
        """Alias for DefaultOpenFormat"""
        return self.DefaultOpenFormat

    @default_open_format.setter
    def default_open_format(self, value):
        """Alias for DefaultOpenFormat.setter"""
        self.DefaultOpenFormat = value

    @property
    def DefaultTextEncoding(self):
        return self.com_object.DefaultTextEncoding

    @DefaultTextEncoding.setter
    def DefaultTextEncoding(self, value):
        self.com_object.DefaultTextEncoding = value

    @property
    def defaulttextencoding(self):
        """Alias for DefaultTextEncoding"""
        return self.DefaultTextEncoding

    @defaulttextencoding.setter
    def defaulttextencoding(self, value):
        """Alias for DefaultTextEncoding.setter"""
        self.DefaultTextEncoding = value

    @property
    def default_text_encoding(self):
        """Alias for DefaultTextEncoding"""
        return self.DefaultTextEncoding

    @default_text_encoding.setter
    def default_text_encoding(self, value):
        """Alias for DefaultTextEncoding.setter"""
        self.DefaultTextEncoding = value

    @property
    def DefaultTray(self):
        return self.com_object.DefaultTray

    @DefaultTray.setter
    def DefaultTray(self, value):
        self.com_object.DefaultTray = value

    @property
    def defaulttray(self):
        """Alias for DefaultTray"""
        return self.DefaultTray

    @defaulttray.setter
    def defaulttray(self, value):
        """Alias for DefaultTray.setter"""
        self.DefaultTray = value

    @property
    def default_tray(self):
        """Alias for DefaultTray"""
        return self.DefaultTray

    @default_tray.setter
    def default_tray(self, value):
        """Alias for DefaultTray.setter"""
        self.DefaultTray = value

    @property
    def DefaultTrayID(self):
        return WdPaperTray(self.com_object.DefaultTrayID)

    @DefaultTrayID.setter
    def DefaultTrayID(self, value):
        self.com_object.DefaultTrayID = value

    @property
    def defaulttrayid(self):
        """Alias for DefaultTrayID"""
        return self.DefaultTrayID

    @defaulttrayid.setter
    def defaulttrayid(self, value):
        """Alias for DefaultTrayID.setter"""
        self.DefaultTrayID = value

    @property
    def default_tray_i_d(self):
        """Alias for DefaultTrayID"""
        return self.DefaultTrayID

    @default_tray_i_d.setter
    def default_tray_i_d(self, value):
        """Alias for DefaultTrayID.setter"""
        self.DefaultTrayID = value

    @property
    def DeletedCellColor(self):
        return WdCellColor(self.com_object.DeletedCellColor)

    @DeletedCellColor.setter
    def DeletedCellColor(self, value):
        self.com_object.DeletedCellColor = value

    @property
    def deletedcellcolor(self):
        """Alias for DeletedCellColor"""
        return self.DeletedCellColor

    @deletedcellcolor.setter
    def deletedcellcolor(self, value):
        """Alias for DeletedCellColor.setter"""
        self.DeletedCellColor = value

    @property
    def deleted_cell_color(self):
        """Alias for DeletedCellColor"""
        return self.DeletedCellColor

    @deleted_cell_color.setter
    def deleted_cell_color(self, value):
        """Alias for DeletedCellColor.setter"""
        self.DeletedCellColor = value

    @property
    def DeletedTextColor(self):
        return WdColorIndex(self.com_object.DeletedTextColor)

    @DeletedTextColor.setter
    def DeletedTextColor(self, value):
        self.com_object.DeletedTextColor = value

    @property
    def deletedtextcolor(self):
        """Alias for DeletedTextColor"""
        return self.DeletedTextColor

    @deletedtextcolor.setter
    def deletedtextcolor(self, value):
        """Alias for DeletedTextColor.setter"""
        self.DeletedTextColor = value

    @property
    def deleted_text_color(self):
        """Alias for DeletedTextColor"""
        return self.DeletedTextColor

    @deleted_text_color.setter
    def deleted_text_color(self, value):
        """Alias for DeletedTextColor.setter"""
        self.DeletedTextColor = value

    @property
    def DeletedTextMark(self):
        return WdDeletedTextMark(self.com_object.DeletedTextMark)

    @DeletedTextMark.setter
    def DeletedTextMark(self, value):
        self.com_object.DeletedTextMark = value

    @property
    def deletedtextmark(self):
        """Alias for DeletedTextMark"""
        return self.DeletedTextMark

    @deletedtextmark.setter
    def deletedtextmark(self, value):
        """Alias for DeletedTextMark.setter"""
        self.DeletedTextMark = value

    @property
    def deleted_text_mark(self):
        """Alias for DeletedTextMark"""
        return self.DeletedTextMark

    @deleted_text_mark.setter
    def deleted_text_mark(self, value):
        """Alias for DeletedTextMark.setter"""
        self.DeletedTextMark = value

    @property
    def DiacriticColorVal(self):
        return self.com_object.DiacriticColorVal

    @DiacriticColorVal.setter
    def DiacriticColorVal(self, value):
        self.com_object.DiacriticColorVal = value

    @property
    def diacriticcolorval(self):
        """Alias for DiacriticColorVal"""
        return self.DiacriticColorVal

    @diacriticcolorval.setter
    def diacriticcolorval(self, value):
        """Alias for DiacriticColorVal.setter"""
        self.DiacriticColorVal = value

    @property
    def diacritic_color_val(self):
        """Alias for DiacriticColorVal"""
        return self.DiacriticColorVal

    @diacritic_color_val.setter
    def diacritic_color_val(self, value):
        """Alias for DiacriticColorVal.setter"""
        self.DiacriticColorVal = value

    @property
    def DisableFeaturesbyDefault(self):
        return self.com_object.DisableFeaturesbyDefault

    @DisableFeaturesbyDefault.setter
    def DisableFeaturesbyDefault(self, value):
        self.com_object.DisableFeaturesbyDefault = value

    @property
    def disablefeaturesbydefault(self):
        """Alias for DisableFeaturesbyDefault"""
        return self.DisableFeaturesbyDefault

    @disablefeaturesbydefault.setter
    def disablefeaturesbydefault(self, value):
        """Alias for DisableFeaturesbyDefault.setter"""
        self.DisableFeaturesbyDefault = value

    @property
    def disable_featuresby_default(self):
        """Alias for DisableFeaturesbyDefault"""
        return self.DisableFeaturesbyDefault

    @disable_featuresby_default.setter
    def disable_featuresby_default(self, value):
        """Alias for DisableFeaturesbyDefault.setter"""
        self.DisableFeaturesbyDefault = value

    @property
    def DisableFeaturesIntroducedAfterbyDefault(self):
        return self.com_object.DisableFeaturesIntroducedAfterbyDefault

    @DisableFeaturesIntroducedAfterbyDefault.setter
    def DisableFeaturesIntroducedAfterbyDefault(self, value):
        self.com_object.DisableFeaturesIntroducedAfterbyDefault = value

    @property
    def disablefeaturesintroducedafterbydefault(self):
        """Alias for DisableFeaturesIntroducedAfterbyDefault"""
        return self.DisableFeaturesIntroducedAfterbyDefault

    @disablefeaturesintroducedafterbydefault.setter
    def disablefeaturesintroducedafterbydefault(self, value):
        """Alias for DisableFeaturesIntroducedAfterbyDefault.setter"""
        self.DisableFeaturesIntroducedAfterbyDefault = value

    @property
    def disable_features_introduced_afterby_default(self):
        """Alias for DisableFeaturesIntroducedAfterbyDefault"""
        return self.DisableFeaturesIntroducedAfterbyDefault

    @disable_features_introduced_afterby_default.setter
    def disable_features_introduced_afterby_default(self, value):
        """Alias for DisableFeaturesIntroducedAfterbyDefault.setter"""
        self.DisableFeaturesIntroducedAfterbyDefault = value

    @property
    def DisplayAlignmentGuides(self):
        return self.com_object.DisplayAlignmentGuides

    @DisplayAlignmentGuides.setter
    def DisplayAlignmentGuides(self, value):
        self.com_object.DisplayAlignmentGuides = value

    @property
    def displayalignmentguides(self):
        """Alias for DisplayAlignmentGuides"""
        return self.DisplayAlignmentGuides

    @displayalignmentguides.setter
    def displayalignmentguides(self, value):
        """Alias for DisplayAlignmentGuides.setter"""
        self.DisplayAlignmentGuides = value

    @property
    def display_alignment_guides(self):
        """Alias for DisplayAlignmentGuides"""
        return self.DisplayAlignmentGuides

    @display_alignment_guides.setter
    def display_alignment_guides(self, value):
        """Alias for DisplayAlignmentGuides.setter"""
        self.DisplayAlignmentGuides = value

    @property
    def DisplayGridLines(self):
        return self.com_object.DisplayGridLines

    @DisplayGridLines.setter
    def DisplayGridLines(self, value):
        self.com_object.DisplayGridLines = value

    @property
    def displaygridlines(self):
        """Alias for DisplayGridLines"""
        return self.DisplayGridLines

    @displaygridlines.setter
    def displaygridlines(self, value):
        """Alias for DisplayGridLines.setter"""
        self.DisplayGridLines = value

    @property
    def display_grid_lines(self):
        """Alias for DisplayGridLines"""
        return self.DisplayGridLines

    @display_grid_lines.setter
    def display_grid_lines(self, value):
        """Alias for DisplayGridLines.setter"""
        self.DisplayGridLines = value

    @property
    def DisplayPasteOptions(self):
        return self.com_object.DisplayPasteOptions

    @DisplayPasteOptions.setter
    def DisplayPasteOptions(self, value):
        self.com_object.DisplayPasteOptions = value

    @property
    def displaypasteoptions(self):
        """Alias for DisplayPasteOptions"""
        return self.DisplayPasteOptions

    @displaypasteoptions.setter
    def displaypasteoptions(self, value):
        """Alias for DisplayPasteOptions.setter"""
        self.DisplayPasteOptions = value

    @property
    def display_paste_options(self):
        """Alias for DisplayPasteOptions"""
        return self.DisplayPasteOptions

    @display_paste_options.setter
    def display_paste_options(self, value):
        """Alias for DisplayPasteOptions.setter"""
        self.DisplayPasteOptions = value

    @property
    def DocumentViewDirection(self):
        return WdDocumentViewDirection(self.com_object.DocumentViewDirection)

    @DocumentViewDirection.setter
    def DocumentViewDirection(self, value):
        self.com_object.DocumentViewDirection = value

    @property
    def documentviewdirection(self):
        """Alias for DocumentViewDirection"""
        return self.DocumentViewDirection

    @documentviewdirection.setter
    def documentviewdirection(self, value):
        """Alias for DocumentViewDirection.setter"""
        self.DocumentViewDirection = value

    @property
    def document_view_direction(self):
        """Alias for DocumentViewDirection"""
        return self.DocumentViewDirection

    @document_view_direction.setter
    def document_view_direction(self, value):
        """Alias for DocumentViewDirection.setter"""
        self.DocumentViewDirection = value

    @property
    def DoNotPromptForConvert(self):
        return self.com_object.DoNotPromptForConvert

    @DoNotPromptForConvert.setter
    def DoNotPromptForConvert(self, value):
        self.com_object.DoNotPromptForConvert = value

    @property
    def donotpromptforconvert(self):
        """Alias for DoNotPromptForConvert"""
        return self.DoNotPromptForConvert

    @donotpromptforconvert.setter
    def donotpromptforconvert(self, value):
        """Alias for DoNotPromptForConvert.setter"""
        self.DoNotPromptForConvert = value

    @property
    def do_not_prompt_for_convert(self):
        """Alias for DoNotPromptForConvert"""
        return self.DoNotPromptForConvert

    @do_not_prompt_for_convert.setter
    def do_not_prompt_for_convert(self, value):
        """Alias for DoNotPromptForConvert.setter"""
        self.DoNotPromptForConvert = value

    @property
    def EnableHangulHanjaRecentOrdering(self):
        return self.com_object.EnableHangulHanjaRecentOrdering

    @EnableHangulHanjaRecentOrdering.setter
    def EnableHangulHanjaRecentOrdering(self, value):
        self.com_object.EnableHangulHanjaRecentOrdering = value

    @property
    def enablehangulhanjarecentordering(self):
        """Alias for EnableHangulHanjaRecentOrdering"""
        return self.EnableHangulHanjaRecentOrdering

    @enablehangulhanjarecentordering.setter
    def enablehangulhanjarecentordering(self, value):
        """Alias for EnableHangulHanjaRecentOrdering.setter"""
        self.EnableHangulHanjaRecentOrdering = value

    @property
    def enable_hangul_hanja_recent_ordering(self):
        """Alias for EnableHangulHanjaRecentOrdering"""
        return self.EnableHangulHanjaRecentOrdering

    @enable_hangul_hanja_recent_ordering.setter
    def enable_hangul_hanja_recent_ordering(self, value):
        """Alias for EnableHangulHanjaRecentOrdering.setter"""
        self.EnableHangulHanjaRecentOrdering = value

    @property
    def EnableLegacyIMEMode(self):
        return self.com_object.EnableLegacyIMEMode

    @EnableLegacyIMEMode.setter
    def EnableLegacyIMEMode(self, value):
        self.com_object.EnableLegacyIMEMode = value

    @property
    def enablelegacyimemode(self):
        """Alias for EnableLegacyIMEMode"""
        return self.EnableLegacyIMEMode

    @enablelegacyimemode.setter
    def enablelegacyimemode(self, value):
        """Alias for EnableLegacyIMEMode.setter"""
        self.EnableLegacyIMEMode = value

    @property
    def enable_legacy_i_m_e_mode(self):
        """Alias for EnableLegacyIMEMode"""
        return self.EnableLegacyIMEMode

    @enable_legacy_i_m_e_mode.setter
    def enable_legacy_i_m_e_mode(self, value):
        """Alias for EnableLegacyIMEMode.setter"""
        self.EnableLegacyIMEMode = value

    @property
    def EnableLiveDrag(self):
        return self.com_object.EnableLiveDrag

    @EnableLiveDrag.setter
    def EnableLiveDrag(self, value):
        self.com_object.EnableLiveDrag = value

    @property
    def enablelivedrag(self):
        """Alias for EnableLiveDrag"""
        return self.EnableLiveDrag

    @enablelivedrag.setter
    def enablelivedrag(self, value):
        """Alias for EnableLiveDrag.setter"""
        self.EnableLiveDrag = value

    @property
    def enable_live_drag(self):
        """Alias for EnableLiveDrag"""
        return self.EnableLiveDrag

    @enable_live_drag.setter
    def enable_live_drag(self, value):
        """Alias for EnableLiveDrag.setter"""
        self.EnableLiveDrag = value

    @property
    def EnableLivePreview(self):
        return self.com_object.EnableLivePreview

    @EnableLivePreview.setter
    def EnableLivePreview(self, value):
        self.com_object.EnableLivePreview = value

    @property
    def enablelivepreview(self):
        """Alias for EnableLivePreview"""
        return self.EnableLivePreview

    @enablelivepreview.setter
    def enablelivepreview(self, value):
        """Alias for EnableLivePreview.setter"""
        self.EnableLivePreview = value

    @property
    def enable_live_preview(self):
        """Alias for EnableLivePreview"""
        return self.EnableLivePreview

    @enable_live_preview.setter
    def enable_live_preview(self, value):
        """Alias for EnableLivePreview.setter"""
        self.EnableLivePreview = value

    @property
    def EnableMisusedWordsDictionary(self):
        return self.com_object.EnableMisusedWordsDictionary

    @EnableMisusedWordsDictionary.setter
    def EnableMisusedWordsDictionary(self, value):
        self.com_object.EnableMisusedWordsDictionary = value

    @property
    def enablemisusedwordsdictionary(self):
        """Alias for EnableMisusedWordsDictionary"""
        return self.EnableMisusedWordsDictionary

    @enablemisusedwordsdictionary.setter
    def enablemisusedwordsdictionary(self, value):
        """Alias for EnableMisusedWordsDictionary.setter"""
        self.EnableMisusedWordsDictionary = value

    @property
    def enable_misused_words_dictionary(self):
        """Alias for EnableMisusedWordsDictionary"""
        return self.EnableMisusedWordsDictionary

    @enable_misused_words_dictionary.setter
    def enable_misused_words_dictionary(self, value):
        """Alias for EnableMisusedWordsDictionary.setter"""
        self.EnableMisusedWordsDictionary = value

    @property
    def EnableProofingToolsAdvertisement(self):
        return self.com_object.EnableProofingToolsAdvertisement

    @EnableProofingToolsAdvertisement.setter
    def EnableProofingToolsAdvertisement(self, value):
        self.com_object.EnableProofingToolsAdvertisement = value

    @property
    def enableproofingtoolsadvertisement(self):
        """Alias for EnableProofingToolsAdvertisement"""
        return self.EnableProofingToolsAdvertisement

    @enableproofingtoolsadvertisement.setter
    def enableproofingtoolsadvertisement(self, value):
        """Alias for EnableProofingToolsAdvertisement.setter"""
        self.EnableProofingToolsAdvertisement = value

    @property
    def enable_proofing_tools_advertisement(self):
        """Alias for EnableProofingToolsAdvertisement"""
        return self.EnableProofingToolsAdvertisement

    @enable_proofing_tools_advertisement.setter
    def enable_proofing_tools_advertisement(self, value):
        """Alias for EnableProofingToolsAdvertisement.setter"""
        self.EnableProofingToolsAdvertisement = value

    @property
    def EnableSound(self):
        return self.com_object.EnableSound

    @EnableSound.setter
    def EnableSound(self, value):
        self.com_object.EnableSound = value

    @property
    def enablesound(self):
        """Alias for EnableSound"""
        return self.EnableSound

    @enablesound.setter
    def enablesound(self, value):
        """Alias for EnableSound.setter"""
        self.EnableSound = value

    @property
    def enable_sound(self):
        """Alias for EnableSound"""
        return self.EnableSound

    @enable_sound.setter
    def enable_sound(self, value):
        """Alias for EnableSound.setter"""
        self.EnableSound = value

    @property
    def EnvelopeFeederInstalled(self):
        return self.com_object.EnvelopeFeederInstalled

    @property
    def envelopefeederinstalled(self):
        """Alias for EnvelopeFeederInstalled"""
        return self.EnvelopeFeederInstalled

    @property
    def envelope_feeder_installed(self):
        """Alias for EnvelopeFeederInstalled"""
        return self.EnvelopeFeederInstalled

    @property
    def ExpandHeadingsOnOpen(self):
        return self.com_object.ExpandHeadingsOnOpen

    @ExpandHeadingsOnOpen.setter
    def ExpandHeadingsOnOpen(self, value):
        self.com_object.ExpandHeadingsOnOpen = value

    @property
    def expandheadingsonopen(self):
        """Alias for ExpandHeadingsOnOpen"""
        return self.ExpandHeadingsOnOpen

    @expandheadingsonopen.setter
    def expandheadingsonopen(self, value):
        """Alias for ExpandHeadingsOnOpen.setter"""
        self.ExpandHeadingsOnOpen = value

    @property
    def expand_headings_on_open(self):
        """Alias for ExpandHeadingsOnOpen"""
        return self.ExpandHeadingsOnOpen

    @expand_headings_on_open.setter
    def expand_headings_on_open(self, value):
        """Alias for ExpandHeadingsOnOpen.setter"""
        self.ExpandHeadingsOnOpen = value

    @property
    def FormatScanning(self):
        return self.com_object.FormatScanning

    @FormatScanning.setter
    def FormatScanning(self, value):
        self.com_object.FormatScanning = value

    @property
    def formatscanning(self):
        """Alias for FormatScanning"""
        return self.FormatScanning

    @formatscanning.setter
    def formatscanning(self, value):
        """Alias for FormatScanning.setter"""
        self.FormatScanning = value

    @property
    def format_scanning(self):
        """Alias for FormatScanning"""
        return self.FormatScanning

    @format_scanning.setter
    def format_scanning(self, value):
        """Alias for FormatScanning.setter"""
        self.FormatScanning = value

    @property
    def FrenchReform(self):
        return WdFrenchSpeller(self.com_object.FrenchReform)

    @FrenchReform.setter
    def FrenchReform(self, value):
        self.com_object.FrenchReform = value

    @property
    def frenchreform(self):
        """Alias for FrenchReform"""
        return self.FrenchReform

    @frenchreform.setter
    def frenchreform(self, value):
        """Alias for FrenchReform.setter"""
        self.FrenchReform = value

    @property
    def french_reform(self):
        """Alias for FrenchReform"""
        return self.FrenchReform

    @french_reform.setter
    def french_reform(self, value):
        """Alias for FrenchReform.setter"""
        self.FrenchReform = value

    @property
    def GridDistanceHorizontal(self):
        return self.com_object.GridDistanceHorizontal

    @GridDistanceHorizontal.setter
    def GridDistanceHorizontal(self, value):
        self.com_object.GridDistanceHorizontal = value

    @property
    def griddistancehorizontal(self):
        """Alias for GridDistanceHorizontal"""
        return self.GridDistanceHorizontal

    @griddistancehorizontal.setter
    def griddistancehorizontal(self, value):
        """Alias for GridDistanceHorizontal.setter"""
        self.GridDistanceHorizontal = value

    @property
    def grid_distance_horizontal(self):
        """Alias for GridDistanceHorizontal"""
        return self.GridDistanceHorizontal

    @grid_distance_horizontal.setter
    def grid_distance_horizontal(self, value):
        """Alias for GridDistanceHorizontal.setter"""
        self.GridDistanceHorizontal = value

    @property
    def GridDistanceVertical(self):
        return self.com_object.GridDistanceVertical

    @GridDistanceVertical.setter
    def GridDistanceVertical(self, value):
        self.com_object.GridDistanceVertical = value

    @property
    def griddistancevertical(self):
        """Alias for GridDistanceVertical"""
        return self.GridDistanceVertical

    @griddistancevertical.setter
    def griddistancevertical(self, value):
        """Alias for GridDistanceVertical.setter"""
        self.GridDistanceVertical = value

    @property
    def grid_distance_vertical(self):
        """Alias for GridDistanceVertical"""
        return self.GridDistanceVertical

    @grid_distance_vertical.setter
    def grid_distance_vertical(self, value):
        """Alias for GridDistanceVertical.setter"""
        self.GridDistanceVertical = value

    @property
    def GridOriginHorizontal(self):
        return self.com_object.GridOriginHorizontal

    @GridOriginHorizontal.setter
    def GridOriginHorizontal(self, value):
        self.com_object.GridOriginHorizontal = value

    @property
    def gridoriginhorizontal(self):
        """Alias for GridOriginHorizontal"""
        return self.GridOriginHorizontal

    @gridoriginhorizontal.setter
    def gridoriginhorizontal(self, value):
        """Alias for GridOriginHorizontal.setter"""
        self.GridOriginHorizontal = value

    @property
    def grid_origin_horizontal(self):
        """Alias for GridOriginHorizontal"""
        return self.GridOriginHorizontal

    @grid_origin_horizontal.setter
    def grid_origin_horizontal(self, value):
        """Alias for GridOriginHorizontal.setter"""
        self.GridOriginHorizontal = value

    @property
    def GridOriginVertical(self):
        return self.com_object.GridOriginVertical

    @GridOriginVertical.setter
    def GridOriginVertical(self, value):
        self.com_object.GridOriginVertical = value

    @property
    def gridoriginvertical(self):
        """Alias for GridOriginVertical"""
        return self.GridOriginVertical

    @gridoriginvertical.setter
    def gridoriginvertical(self, value):
        """Alias for GridOriginVertical.setter"""
        self.GridOriginVertical = value

    @property
    def grid_origin_vertical(self):
        """Alias for GridOriginVertical"""
        return self.GridOriginVertical

    @grid_origin_vertical.setter
    def grid_origin_vertical(self, value):
        """Alias for GridOriginVertical.setter"""
        self.GridOriginVertical = value

    @property
    def HangulHanjaFastConversion(self):
        return self.com_object.HangulHanjaFastConversion

    @HangulHanjaFastConversion.setter
    def HangulHanjaFastConversion(self, value):
        self.com_object.HangulHanjaFastConversion = value

    @property
    def hangulhanjafastconversion(self):
        """Alias for HangulHanjaFastConversion"""
        return self.HangulHanjaFastConversion

    @hangulhanjafastconversion.setter
    def hangulhanjafastconversion(self, value):
        """Alias for HangulHanjaFastConversion.setter"""
        self.HangulHanjaFastConversion = value

    @property
    def hangul_hanja_fast_conversion(self):
        """Alias for HangulHanjaFastConversion"""
        return self.HangulHanjaFastConversion

    @hangul_hanja_fast_conversion.setter
    def hangul_hanja_fast_conversion(self, value):
        """Alias for HangulHanjaFastConversion.setter"""
        self.HangulHanjaFastConversion = value

    @property
    def HebrewMode(self):
        return WdHebSpellStart(self.com_object.HebrewMode)

    @HebrewMode.setter
    def HebrewMode(self, value):
        self.com_object.HebrewMode = value

    @property
    def hebrewmode(self):
        """Alias for HebrewMode"""
        return self.HebrewMode

    @hebrewmode.setter
    def hebrewmode(self, value):
        """Alias for HebrewMode.setter"""
        self.HebrewMode = value

    @property
    def hebrew_mode(self):
        """Alias for HebrewMode"""
        return self.HebrewMode

    @hebrew_mode.setter
    def hebrew_mode(self, value):
        """Alias for HebrewMode.setter"""
        self.HebrewMode = value

    @property
    def IgnoreInternetAndFileAddresses(self):
        return self.com_object.IgnoreInternetAndFileAddresses

    @IgnoreInternetAndFileAddresses.setter
    def IgnoreInternetAndFileAddresses(self, value):
        self.com_object.IgnoreInternetAndFileAddresses = value

    @property
    def ignoreinternetandfileaddresses(self):
        """Alias for IgnoreInternetAndFileAddresses"""
        return self.IgnoreInternetAndFileAddresses

    @ignoreinternetandfileaddresses.setter
    def ignoreinternetandfileaddresses(self, value):
        """Alias for IgnoreInternetAndFileAddresses.setter"""
        self.IgnoreInternetAndFileAddresses = value

    @property
    def ignore_internet_and_file_addresses(self):
        """Alias for IgnoreInternetAndFileAddresses"""
        return self.IgnoreInternetAndFileAddresses

    @ignore_internet_and_file_addresses.setter
    def ignore_internet_and_file_addresses(self, value):
        """Alias for IgnoreInternetAndFileAddresses.setter"""
        self.IgnoreInternetAndFileAddresses = value

    @property
    def IgnoreMixedDigits(self):
        return self.com_object.IgnoreMixedDigits

    @IgnoreMixedDigits.setter
    def IgnoreMixedDigits(self, value):
        self.com_object.IgnoreMixedDigits = value

    @property
    def ignoremixeddigits(self):
        """Alias for IgnoreMixedDigits"""
        return self.IgnoreMixedDigits

    @ignoremixeddigits.setter
    def ignoremixeddigits(self, value):
        """Alias for IgnoreMixedDigits.setter"""
        self.IgnoreMixedDigits = value

    @property
    def ignore_mixed_digits(self):
        """Alias for IgnoreMixedDigits"""
        return self.IgnoreMixedDigits

    @ignore_mixed_digits.setter
    def ignore_mixed_digits(self, value):
        """Alias for IgnoreMixedDigits.setter"""
        self.IgnoreMixedDigits = value

    @property
    def IgnoreUppercase(self):
        return self.com_object.IgnoreUppercase

    @IgnoreUppercase.setter
    def IgnoreUppercase(self, value):
        self.com_object.IgnoreUppercase = value

    @property
    def ignoreuppercase(self):
        """Alias for IgnoreUppercase"""
        return self.IgnoreUppercase

    @ignoreuppercase.setter
    def ignoreuppercase(self, value):
        """Alias for IgnoreUppercase.setter"""
        self.IgnoreUppercase = value

    @property
    def ignore_uppercase(self):
        """Alias for IgnoreUppercase"""
        return self.IgnoreUppercase

    @ignore_uppercase.setter
    def ignore_uppercase(self, value):
        """Alias for IgnoreUppercase.setter"""
        self.IgnoreUppercase = value

    @property
    def IMEAutomaticControl(self):
        return self.com_object.IMEAutomaticControl

    @IMEAutomaticControl.setter
    def IMEAutomaticControl(self, value):
        self.com_object.IMEAutomaticControl = value

    @property
    def imeautomaticcontrol(self):
        """Alias for IMEAutomaticControl"""
        return self.IMEAutomaticControl

    @imeautomaticcontrol.setter
    def imeautomaticcontrol(self, value):
        """Alias for IMEAutomaticControl.setter"""
        self.IMEAutomaticControl = value

    @property
    def i_m_e_automatic_control(self):
        """Alias for IMEAutomaticControl"""
        return self.IMEAutomaticControl

    @i_m_e_automatic_control.setter
    def i_m_e_automatic_control(self, value):
        """Alias for IMEAutomaticControl.setter"""
        self.IMEAutomaticControl = value

    @property
    def InlineConversion(self):
        return self.com_object.InlineConversion

    @InlineConversion.setter
    def InlineConversion(self, value):
        self.com_object.InlineConversion = value

    @property
    def inlineconversion(self):
        """Alias for InlineConversion"""
        return self.InlineConversion

    @inlineconversion.setter
    def inlineconversion(self, value):
        """Alias for InlineConversion.setter"""
        self.InlineConversion = value

    @property
    def inline_conversion(self):
        """Alias for InlineConversion"""
        return self.InlineConversion

    @inline_conversion.setter
    def inline_conversion(self, value):
        """Alias for InlineConversion.setter"""
        self.InlineConversion = value

    @property
    def InsertedCellColor(self):
        return WdCellColor(self.com_object.InsertedCellColor)

    @InsertedCellColor.setter
    def InsertedCellColor(self, value):
        self.com_object.InsertedCellColor = value

    @property
    def insertedcellcolor(self):
        """Alias for InsertedCellColor"""
        return self.InsertedCellColor

    @insertedcellcolor.setter
    def insertedcellcolor(self, value):
        """Alias for InsertedCellColor.setter"""
        self.InsertedCellColor = value

    @property
    def inserted_cell_color(self):
        """Alias for InsertedCellColor"""
        return self.InsertedCellColor

    @inserted_cell_color.setter
    def inserted_cell_color(self, value):
        """Alias for InsertedCellColor.setter"""
        self.InsertedCellColor = value

    @property
    def InsertedTextColor(self):
        return WdColorIndex(self.com_object.InsertedTextColor)

    @InsertedTextColor.setter
    def InsertedTextColor(self, value):
        self.com_object.InsertedTextColor = value

    @property
    def insertedtextcolor(self):
        """Alias for InsertedTextColor"""
        return self.InsertedTextColor

    @insertedtextcolor.setter
    def insertedtextcolor(self, value):
        """Alias for InsertedTextColor.setter"""
        self.InsertedTextColor = value

    @property
    def inserted_text_color(self):
        """Alias for InsertedTextColor"""
        return self.InsertedTextColor

    @inserted_text_color.setter
    def inserted_text_color(self, value):
        """Alias for InsertedTextColor.setter"""
        self.InsertedTextColor = value

    @property
    def InsertedTextMark(self):
        return self.com_object.InsertedTextMark

    @InsertedTextMark.setter
    def InsertedTextMark(self, value):
        self.com_object.InsertedTextMark = value

    @property
    def insertedtextmark(self):
        """Alias for InsertedTextMark"""
        return self.InsertedTextMark

    @insertedtextmark.setter
    def insertedtextmark(self, value):
        """Alias for InsertedTextMark.setter"""
        self.InsertedTextMark = value

    @property
    def inserted_text_mark(self):
        """Alias for InsertedTextMark"""
        return self.InsertedTextMark

    @inserted_text_mark.setter
    def inserted_text_mark(self, value):
        """Alias for InsertedTextMark.setter"""
        self.InsertedTextMark = value

    @property
    def INSKeyForOvertype(self):
        return self.com_object.INSKeyForOvertype

    @INSKeyForOvertype.setter
    def INSKeyForOvertype(self, value):
        self.com_object.INSKeyForOvertype = value

    @property
    def inskeyforovertype(self):
        """Alias for INSKeyForOvertype"""
        return self.INSKeyForOvertype

    @inskeyforovertype.setter
    def inskeyforovertype(self, value):
        """Alias for INSKeyForOvertype.setter"""
        self.INSKeyForOvertype = value

    @property
    def i_n_s_key_for_overtype(self):
        """Alias for INSKeyForOvertype"""
        return self.INSKeyForOvertype

    @i_n_s_key_for_overtype.setter
    def i_n_s_key_for_overtype(self, value):
        """Alias for INSKeyForOvertype.setter"""
        self.INSKeyForOvertype = value

    @property
    def INSKeyForPaste(self):
        return self.com_object.INSKeyForPaste

    @INSKeyForPaste.setter
    def INSKeyForPaste(self, value):
        self.com_object.INSKeyForPaste = value

    @property
    def inskeyforpaste(self):
        """Alias for INSKeyForPaste"""
        return self.INSKeyForPaste

    @inskeyforpaste.setter
    def inskeyforpaste(self, value):
        """Alias for INSKeyForPaste.setter"""
        self.INSKeyForPaste = value

    @property
    def i_n_s_key_for_paste(self):
        """Alias for INSKeyForPaste"""
        return self.INSKeyForPaste

    @i_n_s_key_for_paste.setter
    def i_n_s_key_for_paste(self, value):
        """Alias for INSKeyForPaste.setter"""
        self.INSKeyForPaste = value

    @property
    def InterpretHighAnsi(self):
        return WdHighAnsiText(self.com_object.InterpretHighAnsi)

    @InterpretHighAnsi.setter
    def InterpretHighAnsi(self, value):
        self.com_object.InterpretHighAnsi = value

    @property
    def interprethighansi(self):
        """Alias for InterpretHighAnsi"""
        return self.InterpretHighAnsi

    @interprethighansi.setter
    def interprethighansi(self, value):
        """Alias for InterpretHighAnsi.setter"""
        self.InterpretHighAnsi = value

    @property
    def interpret_high_ansi(self):
        """Alias for InterpretHighAnsi"""
        return self.InterpretHighAnsi

    @interpret_high_ansi.setter
    def interpret_high_ansi(self, value):
        """Alias for InterpretHighAnsi.setter"""
        self.InterpretHighAnsi = value

    @property
    def LocalNetworkFile(self):
        return self.com_object.LocalNetworkFile

    @LocalNetworkFile.setter
    def LocalNetworkFile(self, value):
        self.com_object.LocalNetworkFile = value

    @property
    def localnetworkfile(self):
        """Alias for LocalNetworkFile"""
        return self.LocalNetworkFile

    @localnetworkfile.setter
    def localnetworkfile(self, value):
        """Alias for LocalNetworkFile.setter"""
        self.LocalNetworkFile = value

    @property
    def local_network_file(self):
        """Alias for LocalNetworkFile"""
        return self.LocalNetworkFile

    @local_network_file.setter
    def local_network_file(self, value):
        """Alias for LocalNetworkFile.setter"""
        self.LocalNetworkFile = value

    @property
    def MapPaperSize(self):
        return self.com_object.MapPaperSize

    @MapPaperSize.setter
    def MapPaperSize(self, value):
        self.com_object.MapPaperSize = value

    @property
    def mappapersize(self):
        """Alias for MapPaperSize"""
        return self.MapPaperSize

    @mappapersize.setter
    def mappapersize(self, value):
        """Alias for MapPaperSize.setter"""
        self.MapPaperSize = value

    @property
    def map_paper_size(self):
        """Alias for MapPaperSize"""
        return self.MapPaperSize

    @map_paper_size.setter
    def map_paper_size(self, value):
        """Alias for MapPaperSize.setter"""
        self.MapPaperSize = value

    @property
    def MarginAlignmentGuides(self):
        return self.com_object.MarginAlignmentGuides

    @MarginAlignmentGuides.setter
    def MarginAlignmentGuides(self, value):
        self.com_object.MarginAlignmentGuides = value

    @property
    def marginalignmentguides(self):
        """Alias for MarginAlignmentGuides"""
        return self.MarginAlignmentGuides

    @marginalignmentguides.setter
    def marginalignmentguides(self, value):
        """Alias for MarginAlignmentGuides.setter"""
        self.MarginAlignmentGuides = value

    @property
    def margin_alignment_guides(self):
        """Alias for MarginAlignmentGuides"""
        return self.MarginAlignmentGuides

    @margin_alignment_guides.setter
    def margin_alignment_guides(self, value):
        """Alias for MarginAlignmentGuides.setter"""
        self.MarginAlignmentGuides = value

    @property
    def MatchFuzzyAY(self):
        return self.com_object.MatchFuzzyAY

    @MatchFuzzyAY.setter
    def MatchFuzzyAY(self, value):
        self.com_object.MatchFuzzyAY = value

    @property
    def matchfuzzyay(self):
        """Alias for MatchFuzzyAY"""
        return self.MatchFuzzyAY

    @matchfuzzyay.setter
    def matchfuzzyay(self, value):
        """Alias for MatchFuzzyAY.setter"""
        self.MatchFuzzyAY = value

    @property
    def match_fuzzy_a_y(self):
        """Alias for MatchFuzzyAY"""
        return self.MatchFuzzyAY

    @match_fuzzy_a_y.setter
    def match_fuzzy_a_y(self, value):
        """Alias for MatchFuzzyAY.setter"""
        self.MatchFuzzyAY = value

    @property
    def MatchFuzzyBV(self):
        return self.com_object.MatchFuzzyBV

    @MatchFuzzyBV.setter
    def MatchFuzzyBV(self, value):
        self.com_object.MatchFuzzyBV = value

    @property
    def matchfuzzybv(self):
        """Alias for MatchFuzzyBV"""
        return self.MatchFuzzyBV

    @matchfuzzybv.setter
    def matchfuzzybv(self, value):
        """Alias for MatchFuzzyBV.setter"""
        self.MatchFuzzyBV = value

    @property
    def match_fuzzy_b_v(self):
        """Alias for MatchFuzzyBV"""
        return self.MatchFuzzyBV

    @match_fuzzy_b_v.setter
    def match_fuzzy_b_v(self, value):
        """Alias for MatchFuzzyBV.setter"""
        self.MatchFuzzyBV = value

    @property
    def MatchFuzzyByte(self):
        return self.com_object.MatchFuzzyByte

    @MatchFuzzyByte.setter
    def MatchFuzzyByte(self, value):
        self.com_object.MatchFuzzyByte = value

    @property
    def matchfuzzybyte(self):
        """Alias for MatchFuzzyByte"""
        return self.MatchFuzzyByte

    @matchfuzzybyte.setter
    def matchfuzzybyte(self, value):
        """Alias for MatchFuzzyByte.setter"""
        self.MatchFuzzyByte = value

    @property
    def match_fuzzy_byte(self):
        """Alias for MatchFuzzyByte"""
        return self.MatchFuzzyByte

    @match_fuzzy_byte.setter
    def match_fuzzy_byte(self, value):
        """Alias for MatchFuzzyByte.setter"""
        self.MatchFuzzyByte = value

    @property
    def MatchFuzzyCase(self):
        return self.com_object.MatchFuzzyCase

    @MatchFuzzyCase.setter
    def MatchFuzzyCase(self, value):
        self.com_object.MatchFuzzyCase = value

    @property
    def matchfuzzycase(self):
        """Alias for MatchFuzzyCase"""
        return self.MatchFuzzyCase

    @matchfuzzycase.setter
    def matchfuzzycase(self, value):
        """Alias for MatchFuzzyCase.setter"""
        self.MatchFuzzyCase = value

    @property
    def match_fuzzy_case(self):
        """Alias for MatchFuzzyCase"""
        return self.MatchFuzzyCase

    @match_fuzzy_case.setter
    def match_fuzzy_case(self, value):
        """Alias for MatchFuzzyCase.setter"""
        self.MatchFuzzyCase = value

    @property
    def MatchFuzzyDash(self):
        return self.com_object.MatchFuzzyDash

    @MatchFuzzyDash.setter
    def MatchFuzzyDash(self, value):
        self.com_object.MatchFuzzyDash = value

    @property
    def matchfuzzydash(self):
        """Alias for MatchFuzzyDash"""
        return self.MatchFuzzyDash

    @matchfuzzydash.setter
    def matchfuzzydash(self, value):
        """Alias for MatchFuzzyDash.setter"""
        self.MatchFuzzyDash = value

    @property
    def match_fuzzy_dash(self):
        """Alias for MatchFuzzyDash"""
        return self.MatchFuzzyDash

    @match_fuzzy_dash.setter
    def match_fuzzy_dash(self, value):
        """Alias for MatchFuzzyDash.setter"""
        self.MatchFuzzyDash = value

    @property
    def MatchFuzzyDZ(self):
        return self.com_object.MatchFuzzyDZ

    @MatchFuzzyDZ.setter
    def MatchFuzzyDZ(self, value):
        self.com_object.MatchFuzzyDZ = value

    @property
    def matchfuzzydz(self):
        """Alias for MatchFuzzyDZ"""
        return self.MatchFuzzyDZ

    @matchfuzzydz.setter
    def matchfuzzydz(self, value):
        """Alias for MatchFuzzyDZ.setter"""
        self.MatchFuzzyDZ = value

    @property
    def match_fuzzy_d_z(self):
        """Alias for MatchFuzzyDZ"""
        return self.MatchFuzzyDZ

    @match_fuzzy_d_z.setter
    def match_fuzzy_d_z(self, value):
        """Alias for MatchFuzzyDZ.setter"""
        self.MatchFuzzyDZ = value

    @property
    def MatchFuzzyHF(self):
        return self.com_object.MatchFuzzyHF

    @MatchFuzzyHF.setter
    def MatchFuzzyHF(self, value):
        self.com_object.MatchFuzzyHF = value

    @property
    def matchfuzzyhf(self):
        """Alias for MatchFuzzyHF"""
        return self.MatchFuzzyHF

    @matchfuzzyhf.setter
    def matchfuzzyhf(self, value):
        """Alias for MatchFuzzyHF.setter"""
        self.MatchFuzzyHF = value

    @property
    def match_fuzzy_h_f(self):
        """Alias for MatchFuzzyHF"""
        return self.MatchFuzzyHF

    @match_fuzzy_h_f.setter
    def match_fuzzy_h_f(self, value):
        """Alias for MatchFuzzyHF.setter"""
        self.MatchFuzzyHF = value

    @property
    def MatchFuzzyHiragana(self):
        return self.com_object.MatchFuzzyHiragana

    @MatchFuzzyHiragana.setter
    def MatchFuzzyHiragana(self, value):
        self.com_object.MatchFuzzyHiragana = value

    @property
    def matchfuzzyhiragana(self):
        """Alias for MatchFuzzyHiragana"""
        return self.MatchFuzzyHiragana

    @matchfuzzyhiragana.setter
    def matchfuzzyhiragana(self, value):
        """Alias for MatchFuzzyHiragana.setter"""
        self.MatchFuzzyHiragana = value

    @property
    def match_fuzzy_hiragana(self):
        """Alias for MatchFuzzyHiragana"""
        return self.MatchFuzzyHiragana

    @match_fuzzy_hiragana.setter
    def match_fuzzy_hiragana(self, value):
        """Alias for MatchFuzzyHiragana.setter"""
        self.MatchFuzzyHiragana = value

    @property
    def MatchFuzzyIterationMark(self):
        return self.com_object.MatchFuzzyIterationMark

    @MatchFuzzyIterationMark.setter
    def MatchFuzzyIterationMark(self, value):
        self.com_object.MatchFuzzyIterationMark = value

    @property
    def matchfuzzyiterationmark(self):
        """Alias for MatchFuzzyIterationMark"""
        return self.MatchFuzzyIterationMark

    @matchfuzzyiterationmark.setter
    def matchfuzzyiterationmark(self, value):
        """Alias for MatchFuzzyIterationMark.setter"""
        self.MatchFuzzyIterationMark = value

    @property
    def match_fuzzy_iteration_mark(self):
        """Alias for MatchFuzzyIterationMark"""
        return self.MatchFuzzyIterationMark

    @match_fuzzy_iteration_mark.setter
    def match_fuzzy_iteration_mark(self, value):
        """Alias for MatchFuzzyIterationMark.setter"""
        self.MatchFuzzyIterationMark = value

    @property
    def MatchFuzzyKanji(self):
        return self.com_object.MatchFuzzyKanji

    @MatchFuzzyKanji.setter
    def MatchFuzzyKanji(self, value):
        self.com_object.MatchFuzzyKanji = value

    @property
    def matchfuzzykanji(self):
        """Alias for MatchFuzzyKanji"""
        return self.MatchFuzzyKanji

    @matchfuzzykanji.setter
    def matchfuzzykanji(self, value):
        """Alias for MatchFuzzyKanji.setter"""
        self.MatchFuzzyKanji = value

    @property
    def match_fuzzy_kanji(self):
        """Alias for MatchFuzzyKanji"""
        return self.MatchFuzzyKanji

    @match_fuzzy_kanji.setter
    def match_fuzzy_kanji(self, value):
        """Alias for MatchFuzzyKanji.setter"""
        self.MatchFuzzyKanji = value

    @property
    def MatchFuzzyKiKu(self):
        return self.com_object.MatchFuzzyKiKu

    @MatchFuzzyKiKu.setter
    def MatchFuzzyKiKu(self, value):
        self.com_object.MatchFuzzyKiKu = value

    @property
    def matchfuzzykiku(self):
        """Alias for MatchFuzzyKiKu"""
        return self.MatchFuzzyKiKu

    @matchfuzzykiku.setter
    def matchfuzzykiku(self, value):
        """Alias for MatchFuzzyKiKu.setter"""
        self.MatchFuzzyKiKu = value

    @property
    def match_fuzzy_ki_ku(self):
        """Alias for MatchFuzzyKiKu"""
        return self.MatchFuzzyKiKu

    @match_fuzzy_ki_ku.setter
    def match_fuzzy_ki_ku(self, value):
        """Alias for MatchFuzzyKiKu.setter"""
        self.MatchFuzzyKiKu = value

    @property
    def MatchFuzzyOldKana(self):
        return self.com_object.MatchFuzzyOldKana

    @MatchFuzzyOldKana.setter
    def MatchFuzzyOldKana(self, value):
        self.com_object.MatchFuzzyOldKana = value

    @property
    def matchfuzzyoldkana(self):
        """Alias for MatchFuzzyOldKana"""
        return self.MatchFuzzyOldKana

    @matchfuzzyoldkana.setter
    def matchfuzzyoldkana(self, value):
        """Alias for MatchFuzzyOldKana.setter"""
        self.MatchFuzzyOldKana = value

    @property
    def match_fuzzy_old_kana(self):
        """Alias for MatchFuzzyOldKana"""
        return self.MatchFuzzyOldKana

    @match_fuzzy_old_kana.setter
    def match_fuzzy_old_kana(self, value):
        """Alias for MatchFuzzyOldKana.setter"""
        self.MatchFuzzyOldKana = value

    @property
    def MatchFuzzyProlongedSoundMark(self):
        return self.com_object.MatchFuzzyProlongedSoundMark

    @MatchFuzzyProlongedSoundMark.setter
    def MatchFuzzyProlongedSoundMark(self, value):
        self.com_object.MatchFuzzyProlongedSoundMark = value

    @property
    def matchfuzzyprolongedsoundmark(self):
        """Alias for MatchFuzzyProlongedSoundMark"""
        return self.MatchFuzzyProlongedSoundMark

    @matchfuzzyprolongedsoundmark.setter
    def matchfuzzyprolongedsoundmark(self, value):
        """Alias for MatchFuzzyProlongedSoundMark.setter"""
        self.MatchFuzzyProlongedSoundMark = value

    @property
    def match_fuzzy_prolonged_sound_mark(self):
        """Alias for MatchFuzzyProlongedSoundMark"""
        return self.MatchFuzzyProlongedSoundMark

    @match_fuzzy_prolonged_sound_mark.setter
    def match_fuzzy_prolonged_sound_mark(self, value):
        """Alias for MatchFuzzyProlongedSoundMark.setter"""
        self.MatchFuzzyProlongedSoundMark = value

    @property
    def MatchFuzzyPunctuation(self):
        return self.com_object.MatchFuzzyPunctuation

    @MatchFuzzyPunctuation.setter
    def MatchFuzzyPunctuation(self, value):
        self.com_object.MatchFuzzyPunctuation = value

    @property
    def matchfuzzypunctuation(self):
        """Alias for MatchFuzzyPunctuation"""
        return self.MatchFuzzyPunctuation

    @matchfuzzypunctuation.setter
    def matchfuzzypunctuation(self, value):
        """Alias for MatchFuzzyPunctuation.setter"""
        self.MatchFuzzyPunctuation = value

    @property
    def match_fuzzy_punctuation(self):
        """Alias for MatchFuzzyPunctuation"""
        return self.MatchFuzzyPunctuation

    @match_fuzzy_punctuation.setter
    def match_fuzzy_punctuation(self, value):
        """Alias for MatchFuzzyPunctuation.setter"""
        self.MatchFuzzyPunctuation = value

    @property
    def MatchFuzzySmallKana(self):
        return self.com_object.MatchFuzzySmallKana

    @MatchFuzzySmallKana.setter
    def MatchFuzzySmallKana(self, value):
        self.com_object.MatchFuzzySmallKana = value

    @property
    def matchfuzzysmallkana(self):
        """Alias for MatchFuzzySmallKana"""
        return self.MatchFuzzySmallKana

    @matchfuzzysmallkana.setter
    def matchfuzzysmallkana(self, value):
        """Alias for MatchFuzzySmallKana.setter"""
        self.MatchFuzzySmallKana = value

    @property
    def match_fuzzy_small_kana(self):
        """Alias for MatchFuzzySmallKana"""
        return self.MatchFuzzySmallKana

    @match_fuzzy_small_kana.setter
    def match_fuzzy_small_kana(self, value):
        """Alias for MatchFuzzySmallKana.setter"""
        self.MatchFuzzySmallKana = value

    @property
    def MatchFuzzySpace(self):
        return self.com_object.MatchFuzzySpace

    @MatchFuzzySpace.setter
    def MatchFuzzySpace(self, value):
        self.com_object.MatchFuzzySpace = value

    @property
    def matchfuzzyspace(self):
        """Alias for MatchFuzzySpace"""
        return self.MatchFuzzySpace

    @matchfuzzyspace.setter
    def matchfuzzyspace(self, value):
        """Alias for MatchFuzzySpace.setter"""
        self.MatchFuzzySpace = value

    @property
    def match_fuzzy_space(self):
        """Alias for MatchFuzzySpace"""
        return self.MatchFuzzySpace

    @match_fuzzy_space.setter
    def match_fuzzy_space(self, value):
        """Alias for MatchFuzzySpace.setter"""
        self.MatchFuzzySpace = value

    @property
    def MatchFuzzyTC(self):
        return self.com_object.MatchFuzzyTC

    @MatchFuzzyTC.setter
    def MatchFuzzyTC(self, value):
        self.com_object.MatchFuzzyTC = value

    @property
    def matchfuzzytc(self):
        """Alias for MatchFuzzyTC"""
        return self.MatchFuzzyTC

    @matchfuzzytc.setter
    def matchfuzzytc(self, value):
        """Alias for MatchFuzzyTC.setter"""
        self.MatchFuzzyTC = value

    @property
    def match_fuzzy_t_c(self):
        """Alias for MatchFuzzyTC"""
        return self.MatchFuzzyTC

    @match_fuzzy_t_c.setter
    def match_fuzzy_t_c(self, value):
        """Alias for MatchFuzzyTC.setter"""
        self.MatchFuzzyTC = value

    @property
    def MatchFuzzyZJ(self):
        return self.com_object.MatchFuzzyZJ

    @MatchFuzzyZJ.setter
    def MatchFuzzyZJ(self, value):
        self.com_object.MatchFuzzyZJ = value

    @property
    def matchfuzzyzj(self):
        """Alias for MatchFuzzyZJ"""
        return self.MatchFuzzyZJ

    @matchfuzzyzj.setter
    def matchfuzzyzj(self, value):
        """Alias for MatchFuzzyZJ.setter"""
        self.MatchFuzzyZJ = value

    @property
    def match_fuzzy_z_j(self):
        """Alias for MatchFuzzyZJ"""
        return self.MatchFuzzyZJ

    @match_fuzzy_z_j.setter
    def match_fuzzy_z_j(self, value):
        """Alias for MatchFuzzyZJ.setter"""
        self.MatchFuzzyZJ = value

    @property
    def MeasurementUnit(self):
        return WdMeasurementUnits(self.com_object.MeasurementUnit)

    @MeasurementUnit.setter
    def MeasurementUnit(self, value):
        self.com_object.MeasurementUnit = value

    @property
    def measurementunit(self):
        """Alias for MeasurementUnit"""
        return self.MeasurementUnit

    @measurementunit.setter
    def measurementunit(self, value):
        """Alias for MeasurementUnit.setter"""
        self.MeasurementUnit = value

    @property
    def measurement_unit(self):
        """Alias for MeasurementUnit"""
        return self.MeasurementUnit

    @measurement_unit.setter
    def measurement_unit(self, value):
        """Alias for MeasurementUnit.setter"""
        self.MeasurementUnit = value

    @property
    def MergedCellColor(self):
        return WdCellColor(self.com_object.MergedCellColor)

    @MergedCellColor.setter
    def MergedCellColor(self, value):
        self.com_object.MergedCellColor = value

    @property
    def mergedcellcolor(self):
        """Alias for MergedCellColor"""
        return self.MergedCellColor

    @mergedcellcolor.setter
    def mergedcellcolor(self, value):
        """Alias for MergedCellColor.setter"""
        self.MergedCellColor = value

    @property
    def merged_cell_color(self):
        """Alias for MergedCellColor"""
        return self.MergedCellColor

    @merged_cell_color.setter
    def merged_cell_color(self, value):
        """Alias for MergedCellColor.setter"""
        self.MergedCellColor = value

    @property
    def MonthNames(self):
        return WdMonthNames(self.com_object.MonthNames)

    @MonthNames.setter
    def MonthNames(self, value):
        self.com_object.MonthNames = value

    @property
    def monthnames(self):
        """Alias for MonthNames"""
        return self.MonthNames

    @monthnames.setter
    def monthnames(self, value):
        """Alias for MonthNames.setter"""
        self.MonthNames = value

    @property
    def month_names(self):
        """Alias for MonthNames"""
        return self.MonthNames

    @month_names.setter
    def month_names(self, value):
        """Alias for MonthNames.setter"""
        self.MonthNames = value

    @property
    def MoveFromTextColor(self):
        return WdColorIndex(self.com_object.MoveFromTextColor)

    @MoveFromTextColor.setter
    def MoveFromTextColor(self, value):
        self.com_object.MoveFromTextColor = value

    @property
    def movefromtextcolor(self):
        """Alias for MoveFromTextColor"""
        return self.MoveFromTextColor

    @movefromtextcolor.setter
    def movefromtextcolor(self, value):
        """Alias for MoveFromTextColor.setter"""
        self.MoveFromTextColor = value

    @property
    def move_from_text_color(self):
        """Alias for MoveFromTextColor"""
        return self.MoveFromTextColor

    @move_from_text_color.setter
    def move_from_text_color(self, value):
        """Alias for MoveFromTextColor.setter"""
        self.MoveFromTextColor = value

    @property
    def MoveFromTextMark(self):
        return WdMoveFromTextMark(self.com_object.MoveFromTextMark)

    @MoveFromTextMark.setter
    def MoveFromTextMark(self, value):
        self.com_object.MoveFromTextMark = value

    @property
    def movefromtextmark(self):
        """Alias for MoveFromTextMark"""
        return self.MoveFromTextMark

    @movefromtextmark.setter
    def movefromtextmark(self, value):
        """Alias for MoveFromTextMark.setter"""
        self.MoveFromTextMark = value

    @property
    def move_from_text_mark(self):
        """Alias for MoveFromTextMark"""
        return self.MoveFromTextMark

    @move_from_text_mark.setter
    def move_from_text_mark(self, value):
        """Alias for MoveFromTextMark.setter"""
        self.MoveFromTextMark = value

    @property
    def MoveToTextColor(self):
        return WdColorIndex(self.com_object.MoveToTextColor)

    @MoveToTextColor.setter
    def MoveToTextColor(self, value):
        self.com_object.MoveToTextColor = value

    @property
    def movetotextcolor(self):
        """Alias for MoveToTextColor"""
        return self.MoveToTextColor

    @movetotextcolor.setter
    def movetotextcolor(self, value):
        """Alias for MoveToTextColor.setter"""
        self.MoveToTextColor = value

    @property
    def move_to_text_color(self):
        """Alias for MoveToTextColor"""
        return self.MoveToTextColor

    @move_to_text_color.setter
    def move_to_text_color(self, value):
        """Alias for MoveToTextColor.setter"""
        self.MoveToTextColor = value

    @property
    def MoveToTextMark(self):
        return WdMoveToTextMark(self.com_object.MoveToTextMark)

    @MoveToTextMark.setter
    def MoveToTextMark(self, value):
        self.com_object.MoveToTextMark = value

    @property
    def movetotextmark(self):
        """Alias for MoveToTextMark"""
        return self.MoveToTextMark

    @movetotextmark.setter
    def movetotextmark(self, value):
        """Alias for MoveToTextMark.setter"""
        self.MoveToTextMark = value

    @property
    def move_to_text_mark(self):
        """Alias for MoveToTextMark"""
        return self.MoveToTextMark

    @move_to_text_mark.setter
    def move_to_text_mark(self, value):
        """Alias for MoveToTextMark.setter"""
        self.MoveToTextMark = value

    @property
    def MultipleWordConversionsMode(self):
        return WdMultipleWordConversionsMode(self.com_object.MultipleWordConversionsMode)

    @MultipleWordConversionsMode.setter
    def MultipleWordConversionsMode(self, value):
        self.com_object.MultipleWordConversionsMode = value

    @property
    def multiplewordconversionsmode(self):
        """Alias for MultipleWordConversionsMode"""
        return self.MultipleWordConversionsMode

    @multiplewordconversionsmode.setter
    def multiplewordconversionsmode(self, value):
        """Alias for MultipleWordConversionsMode.setter"""
        self.MultipleWordConversionsMode = value

    @property
    def multiple_word_conversions_mode(self):
        """Alias for MultipleWordConversionsMode"""
        return self.MultipleWordConversionsMode

    @multiple_word_conversions_mode.setter
    def multiple_word_conversions_mode(self, value):
        """Alias for MultipleWordConversionsMode.setter"""
        self.MultipleWordConversionsMode = value

    @property
    def OMathAutoBuildUp(self):
        return self.com_object.OMathAutoBuildUp

    @OMathAutoBuildUp.setter
    def OMathAutoBuildUp(self, value):
        self.com_object.OMathAutoBuildUp = value

    @property
    def omathautobuildup(self):
        """Alias for OMathAutoBuildUp"""
        return self.OMathAutoBuildUp

    @omathautobuildup.setter
    def omathautobuildup(self, value):
        """Alias for OMathAutoBuildUp.setter"""
        self.OMathAutoBuildUp = value

    @property
    def o_math_auto_build_up(self):
        """Alias for OMathAutoBuildUp"""
        return self.OMathAutoBuildUp

    @o_math_auto_build_up.setter
    def o_math_auto_build_up(self, value):
        """Alias for OMathAutoBuildUp.setter"""
        self.OMathAutoBuildUp = value

    @property
    def OMathCopyLF(self):
        return self.com_object.OMathCopyLF

    @OMathCopyLF.setter
    def OMathCopyLF(self, value):
        self.com_object.OMathCopyLF = value

    @property
    def omathcopylf(self):
        """Alias for OMathCopyLF"""
        return self.OMathCopyLF

    @omathcopylf.setter
    def omathcopylf(self, value):
        """Alias for OMathCopyLF.setter"""
        self.OMathCopyLF = value

    @property
    def o_math_copy_l_f(self):
        """Alias for OMathCopyLF"""
        return self.OMathCopyLF

    @o_math_copy_l_f.setter
    def o_math_copy_l_f(self, value):
        """Alias for OMathCopyLF.setter"""
        self.OMathCopyLF = value

    @property
    def OptimizeForWord97byDefault(self):
        return self.com_object.OptimizeForWord97byDefault

    @OptimizeForWord97byDefault.setter
    def OptimizeForWord97byDefault(self, value):
        self.com_object.OptimizeForWord97byDefault = value

    @property
    def optimizeforword97bydefault(self):
        """Alias for OptimizeForWord97byDefault"""
        return self.OptimizeForWord97byDefault

    @optimizeforword97bydefault.setter
    def optimizeforword97bydefault(self, value):
        """Alias for OptimizeForWord97byDefault.setter"""
        self.OptimizeForWord97byDefault = value

    @property
    def optimize_for_word97by_default(self):
        """Alias for OptimizeForWord97byDefault"""
        return self.OptimizeForWord97byDefault

    @optimize_for_word97by_default.setter
    def optimize_for_word97by_default(self, value):
        """Alias for OptimizeForWord97byDefault.setter"""
        self.OptimizeForWord97byDefault = value

    @property
    def ShortMenuNames(self):
        return self.com_object.ShortMenuNames

    @property
    def shortmenunames(self):
        """Alias for ShortMenuNames"""
        return self.ShortMenuNames

    @property
    def short_menu_names(self):
        """Alias for ShortMenuNames"""
        return self.ShortMenuNames

    @property
    def Overtype(self):
        return self.com_object.Overtype

    @Overtype.setter
    def Overtype(self, value):
        self.com_object.Overtype = value

    @property
    def overtype(self):
        """Alias for Overtype"""
        return self.Overtype

    @overtype.setter
    def overtype(self, value):
        """Alias for Overtype.setter"""
        self.Overtype = value

    @property
    def PageAlignmentGuides(self):
        return self.com_object.PageAlignmentGuides

    @PageAlignmentGuides.setter
    def PageAlignmentGuides(self, value):
        self.com_object.PageAlignmentGuides = value

    @property
    def pagealignmentguides(self):
        """Alias for PageAlignmentGuides"""
        return self.PageAlignmentGuides

    @pagealignmentguides.setter
    def pagealignmentguides(self, value):
        """Alias for PageAlignmentGuides.setter"""
        self.PageAlignmentGuides = value

    @property
    def page_alignment_guides(self):
        """Alias for PageAlignmentGuides"""
        return self.PageAlignmentGuides

    @page_alignment_guides.setter
    def page_alignment_guides(self, value):
        """Alias for PageAlignmentGuides.setter"""
        self.PageAlignmentGuides = value

    @property
    def Pagination(self):
        return self.com_object.Pagination

    @Pagination.setter
    def Pagination(self, value):
        self.com_object.Pagination = value

    @property
    def pagination(self):
        """Alias for Pagination"""
        return self.Pagination

    @pagination.setter
    def pagination(self, value):
        """Alias for Pagination.setter"""
        self.Pagination = value

    @property
    def ParagraphAlignmentGuides(self):
        return self.com_object.ParagraphAlignmentGuides

    @ParagraphAlignmentGuides.setter
    def ParagraphAlignmentGuides(self, value):
        self.com_object.ParagraphAlignmentGuides = value

    @property
    def paragraphalignmentguides(self):
        """Alias for ParagraphAlignmentGuides"""
        return self.ParagraphAlignmentGuides

    @paragraphalignmentguides.setter
    def paragraphalignmentguides(self, value):
        """Alias for ParagraphAlignmentGuides.setter"""
        self.ParagraphAlignmentGuides = value

    @property
    def paragraph_alignment_guides(self):
        """Alias for ParagraphAlignmentGuides"""
        return self.ParagraphAlignmentGuides

    @paragraph_alignment_guides.setter
    def paragraph_alignment_guides(self, value):
        """Alias for ParagraphAlignmentGuides.setter"""
        self.ParagraphAlignmentGuides = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PasteAdjustParagraphSpacing(self):
        return self.com_object.PasteAdjustParagraphSpacing

    @PasteAdjustParagraphSpacing.setter
    def PasteAdjustParagraphSpacing(self, value):
        self.com_object.PasteAdjustParagraphSpacing = value

    @property
    def pasteadjustparagraphspacing(self):
        """Alias for PasteAdjustParagraphSpacing"""
        return self.PasteAdjustParagraphSpacing

    @pasteadjustparagraphspacing.setter
    def pasteadjustparagraphspacing(self, value):
        """Alias for PasteAdjustParagraphSpacing.setter"""
        self.PasteAdjustParagraphSpacing = value

    @property
    def paste_adjust_paragraph_spacing(self):
        """Alias for PasteAdjustParagraphSpacing"""
        return self.PasteAdjustParagraphSpacing

    @paste_adjust_paragraph_spacing.setter
    def paste_adjust_paragraph_spacing(self, value):
        """Alias for PasteAdjustParagraphSpacing.setter"""
        self.PasteAdjustParagraphSpacing = value

    @property
    def PasteAdjustTableFormatting(self):
        return self.com_object.PasteAdjustTableFormatting

    @PasteAdjustTableFormatting.setter
    def PasteAdjustTableFormatting(self, value):
        self.com_object.PasteAdjustTableFormatting = value

    @property
    def pasteadjusttableformatting(self):
        """Alias for PasteAdjustTableFormatting"""
        return self.PasteAdjustTableFormatting

    @pasteadjusttableformatting.setter
    def pasteadjusttableformatting(self, value):
        """Alias for PasteAdjustTableFormatting.setter"""
        self.PasteAdjustTableFormatting = value

    @property
    def paste_adjust_table_formatting(self):
        """Alias for PasteAdjustTableFormatting"""
        return self.PasteAdjustTableFormatting

    @paste_adjust_table_formatting.setter
    def paste_adjust_table_formatting(self, value):
        """Alias for PasteAdjustTableFormatting.setter"""
        self.PasteAdjustTableFormatting = value

    @property
    def PasteAdjustWordSpacing(self):
        return self.com_object.PasteAdjustWordSpacing

    @PasteAdjustWordSpacing.setter
    def PasteAdjustWordSpacing(self, value):
        self.com_object.PasteAdjustWordSpacing = value

    @property
    def pasteadjustwordspacing(self):
        """Alias for PasteAdjustWordSpacing"""
        return self.PasteAdjustWordSpacing

    @pasteadjustwordspacing.setter
    def pasteadjustwordspacing(self, value):
        """Alias for PasteAdjustWordSpacing.setter"""
        self.PasteAdjustWordSpacing = value

    @property
    def paste_adjust_word_spacing(self):
        """Alias for PasteAdjustWordSpacing"""
        return self.PasteAdjustWordSpacing

    @paste_adjust_word_spacing.setter
    def paste_adjust_word_spacing(self, value):
        """Alias for PasteAdjustWordSpacing.setter"""
        self.PasteAdjustWordSpacing = value

    @property
    def PasteFormatBetweenDocuments(self):
        return WdPasteOptions(self.com_object.PasteFormatBetweenDocuments)

    @PasteFormatBetweenDocuments.setter
    def PasteFormatBetweenDocuments(self, value):
        self.com_object.PasteFormatBetweenDocuments = value

    @property
    def pasteformatbetweendocuments(self):
        """Alias for PasteFormatBetweenDocuments"""
        return self.PasteFormatBetweenDocuments

    @pasteformatbetweendocuments.setter
    def pasteformatbetweendocuments(self, value):
        """Alias for PasteFormatBetweenDocuments.setter"""
        self.PasteFormatBetweenDocuments = value

    @property
    def paste_format_between_documents(self):
        """Alias for PasteFormatBetweenDocuments"""
        return self.PasteFormatBetweenDocuments

    @paste_format_between_documents.setter
    def paste_format_between_documents(self, value):
        """Alias for PasteFormatBetweenDocuments.setter"""
        self.PasteFormatBetweenDocuments = value

    @property
    def PasteFormatBetweenStyledDocuments(self):
        return WdPasteOptions(self.com_object.PasteFormatBetweenStyledDocuments)

    @PasteFormatBetweenStyledDocuments.setter
    def PasteFormatBetweenStyledDocuments(self, value):
        self.com_object.PasteFormatBetweenStyledDocuments = value

    @property
    def pasteformatbetweenstyleddocuments(self):
        """Alias for PasteFormatBetweenStyledDocuments"""
        return self.PasteFormatBetweenStyledDocuments

    @pasteformatbetweenstyleddocuments.setter
    def pasteformatbetweenstyleddocuments(self, value):
        """Alias for PasteFormatBetweenStyledDocuments.setter"""
        self.PasteFormatBetweenStyledDocuments = value

    @property
    def paste_format_between_styled_documents(self):
        """Alias for PasteFormatBetweenStyledDocuments"""
        return self.PasteFormatBetweenStyledDocuments

    @paste_format_between_styled_documents.setter
    def paste_format_between_styled_documents(self, value):
        """Alias for PasteFormatBetweenStyledDocuments.setter"""
        self.PasteFormatBetweenStyledDocuments = value

    @property
    def PasteFormatFromExternalSource(self):
        return WdPasteOptions(self.com_object.PasteFormatFromExternalSource)

    @PasteFormatFromExternalSource.setter
    def PasteFormatFromExternalSource(self, value):
        self.com_object.PasteFormatFromExternalSource = value

    @property
    def pasteformatfromexternalsource(self):
        """Alias for PasteFormatFromExternalSource"""
        return self.PasteFormatFromExternalSource

    @pasteformatfromexternalsource.setter
    def pasteformatfromexternalsource(self, value):
        """Alias for PasteFormatFromExternalSource.setter"""
        self.PasteFormatFromExternalSource = value

    @property
    def paste_format_from_external_source(self):
        """Alias for PasteFormatFromExternalSource"""
        return self.PasteFormatFromExternalSource

    @paste_format_from_external_source.setter
    def paste_format_from_external_source(self, value):
        """Alias for PasteFormatFromExternalSource.setter"""
        self.PasteFormatFromExternalSource = value

    @property
    def PasteFormatWithinDocument(self):
        return WdPasteOptions(self.com_object.PasteFormatWithinDocument)

    @PasteFormatWithinDocument.setter
    def PasteFormatWithinDocument(self, value):
        self.com_object.PasteFormatWithinDocument = value

    @property
    def pasteformatwithindocument(self):
        """Alias for PasteFormatWithinDocument"""
        return self.PasteFormatWithinDocument

    @pasteformatwithindocument.setter
    def pasteformatwithindocument(self, value):
        """Alias for PasteFormatWithinDocument.setter"""
        self.PasteFormatWithinDocument = value

    @property
    def paste_format_within_document(self):
        """Alias for PasteFormatWithinDocument"""
        return self.PasteFormatWithinDocument

    @paste_format_within_document.setter
    def paste_format_within_document(self, value):
        """Alias for PasteFormatWithinDocument.setter"""
        self.PasteFormatWithinDocument = value

    @property
    def PasteMergeFromPPT(self):
        return self.com_object.PasteMergeFromPPT

    @PasteMergeFromPPT.setter
    def PasteMergeFromPPT(self, value):
        self.com_object.PasteMergeFromPPT = value

    @property
    def pastemergefromppt(self):
        """Alias for PasteMergeFromPPT"""
        return self.PasteMergeFromPPT

    @pastemergefromppt.setter
    def pastemergefromppt(self, value):
        """Alias for PasteMergeFromPPT.setter"""
        self.PasteMergeFromPPT = value

    @property
    def paste_merge_from_p_p_t(self):
        """Alias for PasteMergeFromPPT"""
        return self.PasteMergeFromPPT

    @paste_merge_from_p_p_t.setter
    def paste_merge_from_p_p_t(self, value):
        """Alias for PasteMergeFromPPT.setter"""
        self.PasteMergeFromPPT = value

    @property
    def PasteMergeFromXL(self):
        return self.com_object.PasteMergeFromXL

    @PasteMergeFromXL.setter
    def PasteMergeFromXL(self, value):
        self.com_object.PasteMergeFromXL = value

    @property
    def pastemergefromxl(self):
        """Alias for PasteMergeFromXL"""
        return self.PasteMergeFromXL

    @pastemergefromxl.setter
    def pastemergefromxl(self, value):
        """Alias for PasteMergeFromXL.setter"""
        self.PasteMergeFromXL = value

    @property
    def paste_merge_from_x_l(self):
        """Alias for PasteMergeFromXL"""
        return self.PasteMergeFromXL

    @paste_merge_from_x_l.setter
    def paste_merge_from_x_l(self, value):
        """Alias for PasteMergeFromXL.setter"""
        self.PasteMergeFromXL = value

    @property
    def PasteMergeLists(self):
        return self.com_object.PasteMergeLists

    @PasteMergeLists.setter
    def PasteMergeLists(self, value):
        self.com_object.PasteMergeLists = value

    @property
    def pastemergelists(self):
        """Alias for PasteMergeLists"""
        return self.PasteMergeLists

    @pastemergelists.setter
    def pastemergelists(self, value):
        """Alias for PasteMergeLists.setter"""
        self.PasteMergeLists = value

    @property
    def paste_merge_lists(self):
        """Alias for PasteMergeLists"""
        return self.PasteMergeLists

    @paste_merge_lists.setter
    def paste_merge_lists(self, value):
        """Alias for PasteMergeLists.setter"""
        self.PasteMergeLists = value

    @property
    def PasteOptionKeepBulletsAndNumbers(self):
        return self.com_object.PasteOptionKeepBulletsAndNumbers

    @PasteOptionKeepBulletsAndNumbers.setter
    def PasteOptionKeepBulletsAndNumbers(self, value):
        self.com_object.PasteOptionKeepBulletsAndNumbers = value

    @property
    def pasteoptionkeepbulletsandnumbers(self):
        """Alias for PasteOptionKeepBulletsAndNumbers"""
        return self.PasteOptionKeepBulletsAndNumbers

    @pasteoptionkeepbulletsandnumbers.setter
    def pasteoptionkeepbulletsandnumbers(self, value):
        """Alias for PasteOptionKeepBulletsAndNumbers.setter"""
        self.PasteOptionKeepBulletsAndNumbers = value

    @property
    def paste_option_keep_bullets_and_numbers(self):
        """Alias for PasteOptionKeepBulletsAndNumbers"""
        return self.PasteOptionKeepBulletsAndNumbers

    @paste_option_keep_bullets_and_numbers.setter
    def paste_option_keep_bullets_and_numbers(self, value):
        """Alias for PasteOptionKeepBulletsAndNumbers.setter"""
        self.PasteOptionKeepBulletsAndNumbers = value

    @property
    def PasteSmartCutPaste(self):
        return self.com_object.PasteSmartCutPaste

    @PasteSmartCutPaste.setter
    def PasteSmartCutPaste(self, value):
        self.com_object.PasteSmartCutPaste = value

    @property
    def pastesmartcutpaste(self):
        """Alias for PasteSmartCutPaste"""
        return self.PasteSmartCutPaste

    @pastesmartcutpaste.setter
    def pastesmartcutpaste(self, value):
        """Alias for PasteSmartCutPaste.setter"""
        self.PasteSmartCutPaste = value

    @property
    def paste_smart_cut_paste(self):
        """Alias for PasteSmartCutPaste"""
        return self.PasteSmartCutPaste

    @paste_smart_cut_paste.setter
    def paste_smart_cut_paste(self, value):
        """Alias for PasteSmartCutPaste.setter"""
        self.PasteSmartCutPaste = value

    @property
    def PasteSmartStyleBehavior(self):
        return self.com_object.PasteSmartStyleBehavior

    @PasteSmartStyleBehavior.setter
    def PasteSmartStyleBehavior(self, value):
        self.com_object.PasteSmartStyleBehavior = value

    @property
    def pastesmartstylebehavior(self):
        """Alias for PasteSmartStyleBehavior"""
        return self.PasteSmartStyleBehavior

    @pastesmartstylebehavior.setter
    def pastesmartstylebehavior(self, value):
        """Alias for PasteSmartStyleBehavior.setter"""
        self.PasteSmartStyleBehavior = value

    @property
    def paste_smart_style_behavior(self):
        """Alias for PasteSmartStyleBehavior"""
        return self.PasteSmartStyleBehavior

    @paste_smart_style_behavior.setter
    def paste_smart_style_behavior(self, value):
        """Alias for PasteSmartStyleBehavior.setter"""
        self.PasteSmartStyleBehavior = value

    @property
    def PictureEditor(self):
        return self.com_object.PictureEditor

    @PictureEditor.setter
    def PictureEditor(self, value):
        self.com_object.PictureEditor = value

    @property
    def pictureeditor(self):
        """Alias for PictureEditor"""
        return self.PictureEditor

    @pictureeditor.setter
    def pictureeditor(self, value):
        """Alias for PictureEditor.setter"""
        self.PictureEditor = value

    @property
    def picture_editor(self):
        """Alias for PictureEditor"""
        return self.PictureEditor

    @picture_editor.setter
    def picture_editor(self, value):
        """Alias for PictureEditor.setter"""
        self.PictureEditor = value

    @property
    def PictureWrapType(self):
        return self.com_object.PictureWrapType

    @PictureWrapType.setter
    def PictureWrapType(self, value):
        self.com_object.PictureWrapType = value

    @property
    def picturewraptype(self):
        """Alias for PictureWrapType"""
        return self.PictureWrapType

    @picturewraptype.setter
    def picturewraptype(self, value):
        """Alias for PictureWrapType.setter"""
        self.PictureWrapType = value

    @property
    def picture_wrap_type(self):
        """Alias for PictureWrapType"""
        return self.PictureWrapType

    @picture_wrap_type.setter
    def picture_wrap_type(self, value):
        """Alias for PictureWrapType.setter"""
        self.PictureWrapType = value

    @property
    def PortugalReform(self):
        return self.com_object.PortugalReform

    @PortugalReform.setter
    def PortugalReform(self, value):
        self.com_object.PortugalReform = value

    @property
    def portugalreform(self):
        """Alias for PortugalReform"""
        return self.PortugalReform

    @portugalreform.setter
    def portugalreform(self, value):
        """Alias for PortugalReform.setter"""
        self.PortugalReform = value

    @property
    def portugal_reform(self):
        """Alias for PortugalReform"""
        return self.PortugalReform

    @portugal_reform.setter
    def portugal_reform(self, value):
        """Alias for PortugalReform.setter"""
        self.PortugalReform = value

    @property
    def PrecisePositioning(self):
        return self.com_object.PrecisePositioning

    @PrecisePositioning.setter
    def PrecisePositioning(self, value):
        self.com_object.PrecisePositioning = value

    @property
    def precisepositioning(self):
        """Alias for PrecisePositioning"""
        return self.PrecisePositioning

    @precisepositioning.setter
    def precisepositioning(self, value):
        """Alias for PrecisePositioning.setter"""
        self.PrecisePositioning = value

    @property
    def precise_positioning(self):
        """Alias for PrecisePositioning"""
        return self.PrecisePositioning

    @precise_positioning.setter
    def precise_positioning(self, value):
        """Alias for PrecisePositioning.setter"""
        self.PrecisePositioning = value

    @property
    def PreferCloudSaveLocations(self):
        return self.com_object.PreferCloudSaveLocations

    @PreferCloudSaveLocations.setter
    def PreferCloudSaveLocations(self, value):
        self.com_object.PreferCloudSaveLocations = value

    @property
    def prefercloudsavelocations(self):
        """Alias for PreferCloudSaveLocations"""
        return self.PreferCloudSaveLocations

    @prefercloudsavelocations.setter
    def prefercloudsavelocations(self, value):
        """Alias for PreferCloudSaveLocations.setter"""
        self.PreferCloudSaveLocations = value

    @property
    def prefer_cloud_save_locations(self):
        """Alias for PreferCloudSaveLocations"""
        return self.PreferCloudSaveLocations

    @prefer_cloud_save_locations.setter
    def prefer_cloud_save_locations(self, value):
        """Alias for PreferCloudSaveLocations.setter"""
        self.PreferCloudSaveLocations = value

    @property
    def PrintBackground(self):
        return self.com_object.PrintBackground

    @PrintBackground.setter
    def PrintBackground(self, value):
        self.com_object.PrintBackground = value

    @property
    def printbackground(self):
        """Alias for PrintBackground"""
        return self.PrintBackground

    @printbackground.setter
    def printbackground(self, value):
        """Alias for PrintBackground.setter"""
        self.PrintBackground = value

    @property
    def print_background(self):
        """Alias for PrintBackground"""
        return self.PrintBackground

    @print_background.setter
    def print_background(self, value):
        """Alias for PrintBackground.setter"""
        self.PrintBackground = value

    @property
    def PrintBackgrounds(self):
        return self.com_object.PrintBackgrounds

    @property
    def printbackgrounds(self):
        """Alias for PrintBackgrounds"""
        return self.PrintBackgrounds

    @property
    def print_backgrounds(self):
        """Alias for PrintBackgrounds"""
        return self.PrintBackgrounds

    @property
    def PrintComments(self):
        return self.com_object.PrintComments

    @PrintComments.setter
    def PrintComments(self, value):
        self.com_object.PrintComments = value

    @property
    def printcomments(self):
        """Alias for PrintComments"""
        return self.PrintComments

    @printcomments.setter
    def printcomments(self, value):
        """Alias for PrintComments.setter"""
        self.PrintComments = value

    @property
    def print_comments(self):
        """Alias for PrintComments"""
        return self.PrintComments

    @print_comments.setter
    def print_comments(self, value):
        """Alias for PrintComments.setter"""
        self.PrintComments = value

    @property
    def PrintDraft(self):
        return self.com_object.PrintDraft

    @PrintDraft.setter
    def PrintDraft(self, value):
        self.com_object.PrintDraft = value

    @property
    def printdraft(self):
        """Alias for PrintDraft"""
        return self.PrintDraft

    @printdraft.setter
    def printdraft(self, value):
        """Alias for PrintDraft.setter"""
        self.PrintDraft = value

    @property
    def print_draft(self):
        """Alias for PrintDraft"""
        return self.PrintDraft

    @print_draft.setter
    def print_draft(self, value):
        """Alias for PrintDraft.setter"""
        self.PrintDraft = value

    @property
    def PrintDrawingObjects(self):
        return self.com_object.PrintDrawingObjects

    @PrintDrawingObjects.setter
    def PrintDrawingObjects(self, value):
        self.com_object.PrintDrawingObjects = value

    @property
    def printdrawingobjects(self):
        """Alias for PrintDrawingObjects"""
        return self.PrintDrawingObjects

    @printdrawingobjects.setter
    def printdrawingobjects(self, value):
        """Alias for PrintDrawingObjects.setter"""
        self.PrintDrawingObjects = value

    @property
    def print_drawing_objects(self):
        """Alias for PrintDrawingObjects"""
        return self.PrintDrawingObjects

    @print_drawing_objects.setter
    def print_drawing_objects(self, value):
        """Alias for PrintDrawingObjects.setter"""
        self.PrintDrawingObjects = value

    @property
    def PrintEvenPagesInAscendingOrder(self):
        return self.com_object.PrintEvenPagesInAscendingOrder

    @PrintEvenPagesInAscendingOrder.setter
    def PrintEvenPagesInAscendingOrder(self, value):
        self.com_object.PrintEvenPagesInAscendingOrder = value

    @property
    def printevenpagesinascendingorder(self):
        """Alias for PrintEvenPagesInAscendingOrder"""
        return self.PrintEvenPagesInAscendingOrder

    @printevenpagesinascendingorder.setter
    def printevenpagesinascendingorder(self, value):
        """Alias for PrintEvenPagesInAscendingOrder.setter"""
        self.PrintEvenPagesInAscendingOrder = value

    @property
    def print_even_pages_in_ascending_order(self):
        """Alias for PrintEvenPagesInAscendingOrder"""
        return self.PrintEvenPagesInAscendingOrder

    @print_even_pages_in_ascending_order.setter
    def print_even_pages_in_ascending_order(self, value):
        """Alias for PrintEvenPagesInAscendingOrder.setter"""
        self.PrintEvenPagesInAscendingOrder = value

    @property
    def PrintFieldCodes(self):
        return self.com_object.PrintFieldCodes

    @PrintFieldCodes.setter
    def PrintFieldCodes(self, value):
        self.com_object.PrintFieldCodes = value

    @property
    def printfieldcodes(self):
        """Alias for PrintFieldCodes"""
        return self.PrintFieldCodes

    @printfieldcodes.setter
    def printfieldcodes(self, value):
        """Alias for PrintFieldCodes.setter"""
        self.PrintFieldCodes = value

    @property
    def print_field_codes(self):
        """Alias for PrintFieldCodes"""
        return self.PrintFieldCodes

    @print_field_codes.setter
    def print_field_codes(self, value):
        """Alias for PrintFieldCodes.setter"""
        self.PrintFieldCodes = value

    @property
    def PrintHiddenText(self):
        return self.com_object.PrintHiddenText

    @PrintHiddenText.setter
    def PrintHiddenText(self, value):
        self.com_object.PrintHiddenText = value

    @property
    def printhiddentext(self):
        """Alias for PrintHiddenText"""
        return self.PrintHiddenText

    @printhiddentext.setter
    def printhiddentext(self, value):
        """Alias for PrintHiddenText.setter"""
        self.PrintHiddenText = value

    @property
    def print_hidden_text(self):
        """Alias for PrintHiddenText"""
        return self.PrintHiddenText

    @print_hidden_text.setter
    def print_hidden_text(self, value):
        """Alias for PrintHiddenText.setter"""
        self.PrintHiddenText = value

    @property
    def PrintOddPagesInAscendingOrder(self):
        return self.com_object.PrintOddPagesInAscendingOrder

    @PrintOddPagesInAscendingOrder.setter
    def PrintOddPagesInAscendingOrder(self, value):
        self.com_object.PrintOddPagesInAscendingOrder = value

    @property
    def printoddpagesinascendingorder(self):
        """Alias for PrintOddPagesInAscendingOrder"""
        return self.PrintOddPagesInAscendingOrder

    @printoddpagesinascendingorder.setter
    def printoddpagesinascendingorder(self, value):
        """Alias for PrintOddPagesInAscendingOrder.setter"""
        self.PrintOddPagesInAscendingOrder = value

    @property
    def print_odd_pages_in_ascending_order(self):
        """Alias for PrintOddPagesInAscendingOrder"""
        return self.PrintOddPagesInAscendingOrder

    @print_odd_pages_in_ascending_order.setter
    def print_odd_pages_in_ascending_order(self, value):
        """Alias for PrintOddPagesInAscendingOrder.setter"""
        self.PrintOddPagesInAscendingOrder = value

    @property
    def PrintProperties(self):
        return self.com_object.PrintProperties

    @PrintProperties.setter
    def PrintProperties(self, value):
        self.com_object.PrintProperties = value

    @property
    def printproperties(self):
        """Alias for PrintProperties"""
        return self.PrintProperties

    @printproperties.setter
    def printproperties(self, value):
        """Alias for PrintProperties.setter"""
        self.PrintProperties = value

    @property
    def print_properties(self):
        """Alias for PrintProperties"""
        return self.PrintProperties

    @print_properties.setter
    def print_properties(self, value):
        """Alias for PrintProperties.setter"""
        self.PrintProperties = value

    @property
    def PrintReverse(self):
        return self.com_object.PrintReverse

    @PrintReverse.setter
    def PrintReverse(self, value):
        self.com_object.PrintReverse = value

    @property
    def printreverse(self):
        """Alias for PrintReverse"""
        return self.PrintReverse

    @printreverse.setter
    def printreverse(self, value):
        """Alias for PrintReverse.setter"""
        self.PrintReverse = value

    @property
    def print_reverse(self):
        """Alias for PrintReverse"""
        return self.PrintReverse

    @print_reverse.setter
    def print_reverse(self, value):
        """Alias for PrintReverse.setter"""
        self.PrintReverse = value

    @property
    def PrintXMLTag(self):
        return self.com_object.PrintXMLTag

    @property
    def printxmltag(self):
        """Alias for PrintXMLTag"""
        return self.PrintXMLTag

    @property
    def print_x_m_l_tag(self):
        """Alias for PrintXMLTag"""
        return self.PrintXMLTag

    @property
    def PromptUpdateStyle(self):
        return self.com_object.PromptUpdateStyle

    @PromptUpdateStyle.setter
    def PromptUpdateStyle(self, value):
        self.com_object.PromptUpdateStyle = value

    @property
    def promptupdatestyle(self):
        """Alias for PromptUpdateStyle"""
        return self.PromptUpdateStyle

    @promptupdatestyle.setter
    def promptupdatestyle(self, value):
        """Alias for PromptUpdateStyle.setter"""
        self.PromptUpdateStyle = value

    @property
    def prompt_update_style(self):
        """Alias for PromptUpdateStyle"""
        return self.PromptUpdateStyle

    @prompt_update_style.setter
    def prompt_update_style(self, value):
        """Alias for PromptUpdateStyle.setter"""
        self.PromptUpdateStyle = value

    @property
    def RepeatWord(self):
        return self.com_object.RepeatWord

    @RepeatWord.setter
    def RepeatWord(self, value):
        self.com_object.RepeatWord = value

    @property
    def repeatword(self):
        """Alias for RepeatWord"""
        return self.RepeatWord

    @repeatword.setter
    def repeatword(self, value):
        """Alias for RepeatWord.setter"""
        self.RepeatWord = value

    @property
    def repeat_word(self):
        """Alias for RepeatWord"""
        return self.RepeatWord

    @repeat_word.setter
    def repeat_word(self, value):
        """Alias for RepeatWord.setter"""
        self.RepeatWord = value

    @property
    def ReplaceSelection(self):
        return self.com_object.ReplaceSelection

    @ReplaceSelection.setter
    def ReplaceSelection(self, value):
        self.com_object.ReplaceSelection = value

    @property
    def replaceselection(self):
        """Alias for ReplaceSelection"""
        return self.ReplaceSelection

    @replaceselection.setter
    def replaceselection(self, value):
        """Alias for ReplaceSelection.setter"""
        self.ReplaceSelection = value

    @property
    def replace_selection(self):
        """Alias for ReplaceSelection"""
        return self.ReplaceSelection

    @replace_selection.setter
    def replace_selection(self, value):
        """Alias for ReplaceSelection.setter"""
        self.ReplaceSelection = value

    @property
    def RevisedLinesColor(self):
        return WdColorIndex(self.com_object.RevisedLinesColor)

    @RevisedLinesColor.setter
    def RevisedLinesColor(self, value):
        self.com_object.RevisedLinesColor = value

    @property
    def revisedlinescolor(self):
        """Alias for RevisedLinesColor"""
        return self.RevisedLinesColor

    @revisedlinescolor.setter
    def revisedlinescolor(self, value):
        """Alias for RevisedLinesColor.setter"""
        self.RevisedLinesColor = value

    @property
    def revised_lines_color(self):
        """Alias for RevisedLinesColor"""
        return self.RevisedLinesColor

    @revised_lines_color.setter
    def revised_lines_color(self, value):
        """Alias for RevisedLinesColor.setter"""
        self.RevisedLinesColor = value

    @property
    def RevisedLinesMark(self):
        return WdRevisedLinesMark(self.com_object.RevisedLinesMark)

    @RevisedLinesMark.setter
    def RevisedLinesMark(self, value):
        self.com_object.RevisedLinesMark = value

    @property
    def revisedlinesmark(self):
        """Alias for RevisedLinesMark"""
        return self.RevisedLinesMark

    @revisedlinesmark.setter
    def revisedlinesmark(self, value):
        """Alias for RevisedLinesMark.setter"""
        self.RevisedLinesMark = value

    @property
    def revised_lines_mark(self):
        """Alias for RevisedLinesMark"""
        return self.RevisedLinesMark

    @revised_lines_mark.setter
    def revised_lines_mark(self, value):
        """Alias for RevisedLinesMark.setter"""
        self.RevisedLinesMark = value

    @property
    def RevisedPropertiesColor(self):
        return WdColorIndex(self.com_object.RevisedPropertiesColor)

    @RevisedPropertiesColor.setter
    def RevisedPropertiesColor(self, value):
        self.com_object.RevisedPropertiesColor = value

    @property
    def revisedpropertiescolor(self):
        """Alias for RevisedPropertiesColor"""
        return self.RevisedPropertiesColor

    @revisedpropertiescolor.setter
    def revisedpropertiescolor(self, value):
        """Alias for RevisedPropertiesColor.setter"""
        self.RevisedPropertiesColor = value

    @property
    def revised_properties_color(self):
        """Alias for RevisedPropertiesColor"""
        return self.RevisedPropertiesColor

    @revised_properties_color.setter
    def revised_properties_color(self, value):
        """Alias for RevisedPropertiesColor.setter"""
        self.RevisedPropertiesColor = value

    @property
    def RevisedPropertiesMark(self):
        return WdRevisedPropertiesMark(self.com_object.RevisedPropertiesMark)

    @RevisedPropertiesMark.setter
    def RevisedPropertiesMark(self, value):
        self.com_object.RevisedPropertiesMark = value

    @property
    def revisedpropertiesmark(self):
        """Alias for RevisedPropertiesMark"""
        return self.RevisedPropertiesMark

    @revisedpropertiesmark.setter
    def revisedpropertiesmark(self, value):
        """Alias for RevisedPropertiesMark.setter"""
        self.RevisedPropertiesMark = value

    @property
    def revised_properties_mark(self):
        """Alias for RevisedPropertiesMark"""
        return self.RevisedPropertiesMark

    @revised_properties_mark.setter
    def revised_properties_mark(self, value):
        """Alias for RevisedPropertiesMark.setter"""
        self.RevisedPropertiesMark = value

    @property
    def RevisionsBalloonPrintOrientation(self):
        return WdRevisionsBalloonPrintOrientation(self.com_object.RevisionsBalloonPrintOrientation)

    @RevisionsBalloonPrintOrientation.setter
    def RevisionsBalloonPrintOrientation(self, value):
        self.com_object.RevisionsBalloonPrintOrientation = value

    @property
    def revisionsballoonprintorientation(self):
        """Alias for RevisionsBalloonPrintOrientation"""
        return self.RevisionsBalloonPrintOrientation

    @revisionsballoonprintorientation.setter
    def revisionsballoonprintorientation(self, value):
        """Alias for RevisionsBalloonPrintOrientation.setter"""
        self.RevisionsBalloonPrintOrientation = value

    @property
    def revisions_balloon_print_orientation(self):
        """Alias for RevisionsBalloonPrintOrientation"""
        return self.RevisionsBalloonPrintOrientation

    @revisions_balloon_print_orientation.setter
    def revisions_balloon_print_orientation(self, value):
        """Alias for RevisionsBalloonPrintOrientation.setter"""
        self.RevisionsBalloonPrintOrientation = value

    @property
    def RTFInClipboard(self):
        return self.com_object.RTFInClipboard

    @property
    def rtfinclipboard(self):
        """Alias for RTFInClipboard"""
        return self.RTFInClipboard

    @property
    def r_t_f_in_clipboard(self):
        """Alias for RTFInClipboard"""
        return self.RTFInClipboard

    @property
    def SaveInterval(self):
        return self.com_object.SaveInterval

    @SaveInterval.setter
    def SaveInterval(self, value):
        self.com_object.SaveInterval = value

    @property
    def saveinterval(self):
        """Alias for SaveInterval"""
        return self.SaveInterval

    @saveinterval.setter
    def saveinterval(self, value):
        """Alias for SaveInterval.setter"""
        self.SaveInterval = value

    @property
    def save_interval(self):
        """Alias for SaveInterval"""
        return self.SaveInterval

    @save_interval.setter
    def save_interval(self, value):
        """Alias for SaveInterval.setter"""
        self.SaveInterval = value

    @property
    def SaveNormalPrompt(self):
        return self.com_object.SaveNormalPrompt

    @SaveNormalPrompt.setter
    def SaveNormalPrompt(self, value):
        self.com_object.SaveNormalPrompt = value

    @property
    def savenormalprompt(self):
        """Alias for SaveNormalPrompt"""
        return self.SaveNormalPrompt

    @savenormalprompt.setter
    def savenormalprompt(self, value):
        """Alias for SaveNormalPrompt.setter"""
        self.SaveNormalPrompt = value

    @property
    def save_normal_prompt(self):
        """Alias for SaveNormalPrompt"""
        return self.SaveNormalPrompt

    @save_normal_prompt.setter
    def save_normal_prompt(self, value):
        """Alias for SaveNormalPrompt.setter"""
        self.SaveNormalPrompt = value

    @property
    def SavePropertiesPrompt(self):
        return self.com_object.SavePropertiesPrompt

    @SavePropertiesPrompt.setter
    def SavePropertiesPrompt(self, value):
        self.com_object.SavePropertiesPrompt = value

    @property
    def savepropertiesprompt(self):
        """Alias for SavePropertiesPrompt"""
        return self.SavePropertiesPrompt

    @savepropertiesprompt.setter
    def savepropertiesprompt(self, value):
        """Alias for SavePropertiesPrompt.setter"""
        self.SavePropertiesPrompt = value

    @property
    def save_properties_prompt(self):
        """Alias for SavePropertiesPrompt"""
        return self.SavePropertiesPrompt

    @save_properties_prompt.setter
    def save_properties_prompt(self, value):
        """Alias for SavePropertiesPrompt.setter"""
        self.SavePropertiesPrompt = value

    @property
    def SendMailAttach(self):
        return self.com_object.SendMailAttach

    @SendMailAttach.setter
    def SendMailAttach(self, value):
        self.com_object.SendMailAttach = value

    @property
    def sendmailattach(self):
        """Alias for SendMailAttach"""
        return self.SendMailAttach

    @sendmailattach.setter
    def sendmailattach(self, value):
        """Alias for SendMailAttach.setter"""
        self.SendMailAttach = value

    @property
    def send_mail_attach(self):
        """Alias for SendMailAttach"""
        return self.SendMailAttach

    @send_mail_attach.setter
    def send_mail_attach(self, value):
        """Alias for SendMailAttach.setter"""
        self.SendMailAttach = value

    @property
    def SequenceCheck(self):
        return self.com_object.SequenceCheck

    @SequenceCheck.setter
    def SequenceCheck(self, value):
        self.com_object.SequenceCheck = value

    @property
    def sequencecheck(self):
        """Alias for SequenceCheck"""
        return self.SequenceCheck

    @sequencecheck.setter
    def sequencecheck(self, value):
        """Alias for SequenceCheck.setter"""
        self.SequenceCheck = value

    @property
    def sequence_check(self):
        """Alias for SequenceCheck"""
        return self.SequenceCheck

    @sequence_check.setter
    def sequence_check(self, value):
        """Alias for SequenceCheck.setter"""
        self.SequenceCheck = value

    @property
    def ShowControlCharacters(self):
        return self.com_object.ShowControlCharacters

    @ShowControlCharacters.setter
    def ShowControlCharacters(self, value):
        self.com_object.ShowControlCharacters = value

    @property
    def showcontrolcharacters(self):
        """Alias for ShowControlCharacters"""
        return self.ShowControlCharacters

    @showcontrolcharacters.setter
    def showcontrolcharacters(self, value):
        """Alias for ShowControlCharacters.setter"""
        self.ShowControlCharacters = value

    @property
    def show_control_characters(self):
        """Alias for ShowControlCharacters"""
        return self.ShowControlCharacters

    @show_control_characters.setter
    def show_control_characters(self, value):
        """Alias for ShowControlCharacters.setter"""
        self.ShowControlCharacters = value

    @property
    def ShowDevTools(self):
        return self.com_object.ShowDevTools

    @ShowDevTools.setter
    def ShowDevTools(self, value):
        self.com_object.ShowDevTools = value

    @property
    def showdevtools(self):
        """Alias for ShowDevTools"""
        return self.ShowDevTools

    @showdevtools.setter
    def showdevtools(self, value):
        """Alias for ShowDevTools.setter"""
        self.ShowDevTools = value

    @property
    def show_dev_tools(self):
        """Alias for ShowDevTools"""
        return self.ShowDevTools

    @show_dev_tools.setter
    def show_dev_tools(self, value):
        """Alias for ShowDevTools.setter"""
        self.ShowDevTools = value

    @property
    def ShowDiacritics(self):
        return self.com_object.ShowDiacritics

    @ShowDiacritics.setter
    def ShowDiacritics(self, value):
        self.com_object.ShowDiacritics = value

    @property
    def showdiacritics(self):
        """Alias for ShowDiacritics"""
        return self.ShowDiacritics

    @showdiacritics.setter
    def showdiacritics(self, value):
        """Alias for ShowDiacritics.setter"""
        self.ShowDiacritics = value

    @property
    def show_diacritics(self):
        """Alias for ShowDiacritics"""
        return self.ShowDiacritics

    @show_diacritics.setter
    def show_diacritics(self, value):
        """Alias for ShowDiacritics.setter"""
        self.ShowDiacritics = value

    @property
    def ShowFormatError(self):
        return self.com_object.ShowFormatError

    @ShowFormatError.setter
    def ShowFormatError(self, value):
        self.com_object.ShowFormatError = value

    @property
    def showformaterror(self):
        """Alias for ShowFormatError"""
        return self.ShowFormatError

    @showformaterror.setter
    def showformaterror(self, value):
        """Alias for ShowFormatError.setter"""
        self.ShowFormatError = value

    @property
    def show_format_error(self):
        """Alias for ShowFormatError"""
        return self.ShowFormatError

    @show_format_error.setter
    def show_format_error(self, value):
        """Alias for ShowFormatError.setter"""
        self.ShowFormatError = value

    @property
    def ShowMarkupOpenSave(self):
        return self.com_object.ShowMarkupOpenSave

    @ShowMarkupOpenSave.setter
    def ShowMarkupOpenSave(self, value):
        self.com_object.ShowMarkupOpenSave = value

    @property
    def showmarkupopensave(self):
        """Alias for ShowMarkupOpenSave"""
        return self.ShowMarkupOpenSave

    @showmarkupopensave.setter
    def showmarkupopensave(self, value):
        """Alias for ShowMarkupOpenSave.setter"""
        self.ShowMarkupOpenSave = value

    @property
    def show_markup_open_save(self):
        """Alias for ShowMarkupOpenSave"""
        return self.ShowMarkupOpenSave

    @show_markup_open_save.setter
    def show_markup_open_save(self, value):
        """Alias for ShowMarkupOpenSave.setter"""
        self.ShowMarkupOpenSave = value

    @property
    def ShowMenuFloaties(self):
        return self.com_object.ShowMenuFloaties

    @ShowMenuFloaties.setter
    def ShowMenuFloaties(self, value):
        self.com_object.ShowMenuFloaties = value

    @property
    def showmenufloaties(self):
        """Alias for ShowMenuFloaties"""
        return self.ShowMenuFloaties

    @showmenufloaties.setter
    def showmenufloaties(self, value):
        """Alias for ShowMenuFloaties.setter"""
        self.ShowMenuFloaties = value

    @property
    def show_menu_floaties(self):
        """Alias for ShowMenuFloaties"""
        return self.ShowMenuFloaties

    @show_menu_floaties.setter
    def show_menu_floaties(self, value):
        """Alias for ShowMenuFloaties.setter"""
        self.ShowMenuFloaties = value

    @property
    def ShowReadabilityStatistics(self):
        return self.com_object.ShowReadabilityStatistics

    @ShowReadabilityStatistics.setter
    def ShowReadabilityStatistics(self, value):
        self.com_object.ShowReadabilityStatistics = value

    @property
    def showreadabilitystatistics(self):
        """Alias for ShowReadabilityStatistics"""
        return self.ShowReadabilityStatistics

    @showreadabilitystatistics.setter
    def showreadabilitystatistics(self, value):
        """Alias for ShowReadabilityStatistics.setter"""
        self.ShowReadabilityStatistics = value

    @property
    def show_readability_statistics(self):
        """Alias for ShowReadabilityStatistics"""
        return self.ShowReadabilityStatistics

    @show_readability_statistics.setter
    def show_readability_statistics(self, value):
        """Alias for ShowReadabilityStatistics.setter"""
        self.ShowReadabilityStatistics = value

    @property
    def ShowSelectionFloaties(self):
        return self.com_object.ShowSelectionFloaties

    @ShowSelectionFloaties.setter
    def ShowSelectionFloaties(self, value):
        self.com_object.ShowSelectionFloaties = value

    @property
    def showselectionfloaties(self):
        """Alias for ShowSelectionFloaties"""
        return self.ShowSelectionFloaties

    @showselectionfloaties.setter
    def showselectionfloaties(self, value):
        """Alias for ShowSelectionFloaties.setter"""
        self.ShowSelectionFloaties = value

    @property
    def show_selection_floaties(self):
        """Alias for ShowSelectionFloaties"""
        return self.ShowSelectionFloaties

    @show_selection_floaties.setter
    def show_selection_floaties(self, value):
        """Alias for ShowSelectionFloaties.setter"""
        self.ShowSelectionFloaties = value

    @property
    def SkyDriveSignInOption(self):
        return self.com_object.SkyDriveSignInOption

    @SkyDriveSignInOption.setter
    def SkyDriveSignInOption(self, value):
        self.com_object.SkyDriveSignInOption = value

    @property
    def skydrivesigninoption(self):
        """Alias for SkyDriveSignInOption"""
        return self.SkyDriveSignInOption

    @skydrivesigninoption.setter
    def skydrivesigninoption(self, value):
        """Alias for SkyDriveSignInOption.setter"""
        self.SkyDriveSignInOption = value

    @property
    def sky_drive_sign_in_option(self):
        """Alias for SkyDriveSignInOption"""
        return self.SkyDriveSignInOption

    @sky_drive_sign_in_option.setter
    def sky_drive_sign_in_option(self, value):
        """Alias for SkyDriveSignInOption.setter"""
        self.SkyDriveSignInOption = value

    @property
    def SmartCursoring(self):
        return self.com_object.SmartCursoring

    @SmartCursoring.setter
    def SmartCursoring(self, value):
        self.com_object.SmartCursoring = value

    @property
    def smartcursoring(self):
        """Alias for SmartCursoring"""
        return self.SmartCursoring

    @smartcursoring.setter
    def smartcursoring(self, value):
        """Alias for SmartCursoring.setter"""
        self.SmartCursoring = value

    @property
    def smart_cursoring(self):
        """Alias for SmartCursoring"""
        return self.SmartCursoring

    @smart_cursoring.setter
    def smart_cursoring(self, value):
        """Alias for SmartCursoring.setter"""
        self.SmartCursoring = value

    @property
    def SmartCutPaste(self):
        return self.com_object.SmartCutPaste

    @SmartCutPaste.setter
    def SmartCutPaste(self, value):
        self.com_object.SmartCutPaste = value

    @property
    def smartcutpaste(self):
        """Alias for SmartCutPaste"""
        return self.SmartCutPaste

    @smartcutpaste.setter
    def smartcutpaste(self, value):
        """Alias for SmartCutPaste.setter"""
        self.SmartCutPaste = value

    @property
    def smart_cut_paste(self):
        """Alias for SmartCutPaste"""
        return self.SmartCutPaste

    @smart_cut_paste.setter
    def smart_cut_paste(self, value):
        """Alias for SmartCutPaste.setter"""
        self.SmartCutPaste = value

    @property
    def SmartParaSelection(self):
        return self.com_object.SmartParaSelection

    @SmartParaSelection.setter
    def SmartParaSelection(self, value):
        self.com_object.SmartParaSelection = value

    @property
    def smartparaselection(self):
        """Alias for SmartParaSelection"""
        return self.SmartParaSelection

    @smartparaselection.setter
    def smartparaselection(self, value):
        """Alias for SmartParaSelection.setter"""
        self.SmartParaSelection = value

    @property
    def smart_para_selection(self):
        """Alias for SmartParaSelection"""
        return self.SmartParaSelection

    @smart_para_selection.setter
    def smart_para_selection(self, value):
        """Alias for SmartParaSelection.setter"""
        self.SmartParaSelection = value

    @property
    def SnapToGrid(self):
        return self.com_object.SnapToGrid

    @SnapToGrid.setter
    def SnapToGrid(self, value):
        self.com_object.SnapToGrid = value

    @property
    def snaptogrid(self):
        """Alias for SnapToGrid"""
        return self.SnapToGrid

    @snaptogrid.setter
    def snaptogrid(self, value):
        """Alias for SnapToGrid.setter"""
        self.SnapToGrid = value

    @property
    def snap_to_grid(self):
        """Alias for SnapToGrid"""
        return self.SnapToGrid

    @snap_to_grid.setter
    def snap_to_grid(self, value):
        """Alias for SnapToGrid.setter"""
        self.SnapToGrid = value

    @property
    def SnapToShapes(self):
        return self.com_object.SnapToShapes

    @SnapToShapes.setter
    def SnapToShapes(self, value):
        self.com_object.SnapToShapes = value

    @property
    def snaptoshapes(self):
        """Alias for SnapToShapes"""
        return self.SnapToShapes

    @snaptoshapes.setter
    def snaptoshapes(self, value):
        """Alias for SnapToShapes.setter"""
        self.SnapToShapes = value

    @property
    def snap_to_shapes(self):
        """Alias for SnapToShapes"""
        return self.SnapToShapes

    @snap_to_shapes.setter
    def snap_to_shapes(self, value):
        """Alias for SnapToShapes.setter"""
        self.SnapToShapes = value

    @property
    def SpanishMode(self):
        return self.com_object.SpanishMode

    @SpanishMode.setter
    def SpanishMode(self, value):
        self.com_object.SpanishMode = value

    @property
    def spanishmode(self):
        """Alias for SpanishMode"""
        return self.SpanishMode

    @spanishmode.setter
    def spanishmode(self, value):
        """Alias for SpanishMode.setter"""
        self.SpanishMode = value

    @property
    def spanish_mode(self):
        """Alias for SpanishMode"""
        return self.SpanishMode

    @spanish_mode.setter
    def spanish_mode(self, value):
        """Alias for SpanishMode.setter"""
        self.SpanishMode = value

    @property
    def SplitCellColor(self):
        return WdCellColor(self.com_object.SplitCellColor)

    @SplitCellColor.setter
    def SplitCellColor(self, value):
        self.com_object.SplitCellColor = value

    @property
    def splitcellcolor(self):
        """Alias for SplitCellColor"""
        return self.SplitCellColor

    @splitcellcolor.setter
    def splitcellcolor(self, value):
        """Alias for SplitCellColor.setter"""
        self.SplitCellColor = value

    @property
    def split_cell_color(self):
        """Alias for SplitCellColor"""
        return self.SplitCellColor

    @split_cell_color.setter
    def split_cell_color(self, value):
        """Alias for SplitCellColor.setter"""
        self.SplitCellColor = value

    @property
    def StoreRSIDOnSave(self):
        return self.com_object.StoreRSIDOnSave

    @StoreRSIDOnSave.setter
    def StoreRSIDOnSave(self, value):
        self.com_object.StoreRSIDOnSave = value

    @property
    def storersidonsave(self):
        """Alias for StoreRSIDOnSave"""
        return self.StoreRSIDOnSave

    @storersidonsave.setter
    def storersidonsave(self, value):
        """Alias for StoreRSIDOnSave.setter"""
        self.StoreRSIDOnSave = value

    @property
    def store_r_s_i_d_on_save(self):
        """Alias for StoreRSIDOnSave"""
        return self.StoreRSIDOnSave

    @store_r_s_i_d_on_save.setter
    def store_r_s_i_d_on_save(self, value):
        """Alias for StoreRSIDOnSave.setter"""
        self.StoreRSIDOnSave = value

    @property
    def StrictFinalYaa(self):
        return self.com_object.StrictFinalYaa

    @StrictFinalYaa.setter
    def StrictFinalYaa(self, value):
        self.com_object.StrictFinalYaa = value

    @property
    def strictfinalyaa(self):
        """Alias for StrictFinalYaa"""
        return self.StrictFinalYaa

    @strictfinalyaa.setter
    def strictfinalyaa(self, value):
        """Alias for StrictFinalYaa.setter"""
        self.StrictFinalYaa = value

    @property
    def strict_final_yaa(self):
        """Alias for StrictFinalYaa"""
        return self.StrictFinalYaa

    @strict_final_yaa.setter
    def strict_final_yaa(self, value):
        """Alias for StrictFinalYaa.setter"""
        self.StrictFinalYaa = value

    @property
    def StrictInitialAlefHamza(self):
        return self.com_object.StrictInitialAlefHamza

    @StrictInitialAlefHamza.setter
    def StrictInitialAlefHamza(self, value):
        self.com_object.StrictInitialAlefHamza = value

    @property
    def strictinitialalefhamza(self):
        """Alias for StrictInitialAlefHamza"""
        return self.StrictInitialAlefHamza

    @strictinitialalefhamza.setter
    def strictinitialalefhamza(self, value):
        """Alias for StrictInitialAlefHamza.setter"""
        self.StrictInitialAlefHamza = value

    @property
    def strict_initial_alef_hamza(self):
        """Alias for StrictInitialAlefHamza"""
        return self.StrictInitialAlefHamza

    @strict_initial_alef_hamza.setter
    def strict_initial_alef_hamza(self, value):
        """Alias for StrictInitialAlefHamza.setter"""
        self.StrictInitialAlefHamza = value

    @property
    def StrictRussianE(self):
        return self.com_object.StrictRussianE

    @StrictRussianE.setter
    def StrictRussianE(self, value):
        self.com_object.StrictRussianE = value

    @property
    def strictrussiane(self):
        """Alias for StrictRussianE"""
        return self.StrictRussianE

    @strictrussiane.setter
    def strictrussiane(self, value):
        """Alias for StrictRussianE.setter"""
        self.StrictRussianE = value

    @property
    def strict_russian_e(self):
        """Alias for StrictRussianE"""
        return self.StrictRussianE

    @strict_russian_e.setter
    def strict_russian_e(self, value):
        """Alias for StrictRussianE.setter"""
        self.StrictRussianE = value

    @property
    def StrictTaaMarboota(self):
        return self.com_object.StrictTaaMarboota

    @StrictTaaMarboota.setter
    def StrictTaaMarboota(self, value):
        self.com_object.StrictTaaMarboota = value

    @property
    def stricttaamarboota(self):
        """Alias for StrictTaaMarboota"""
        return self.StrictTaaMarboota

    @stricttaamarboota.setter
    def stricttaamarboota(self, value):
        """Alias for StrictTaaMarboota.setter"""
        self.StrictTaaMarboota = value

    @property
    def strict_taa_marboota(self):
        """Alias for StrictTaaMarboota"""
        return self.StrictTaaMarboota

    @strict_taa_marboota.setter
    def strict_taa_marboota(self, value):
        """Alias for StrictTaaMarboota.setter"""
        self.StrictTaaMarboota = value

    @property
    def SuggestFromMainDictionaryOnly(self):
        return self.com_object.SuggestFromMainDictionaryOnly

    @SuggestFromMainDictionaryOnly.setter
    def SuggestFromMainDictionaryOnly(self, value):
        self.com_object.SuggestFromMainDictionaryOnly = value

    @property
    def suggestfrommaindictionaryonly(self):
        """Alias for SuggestFromMainDictionaryOnly"""
        return self.SuggestFromMainDictionaryOnly

    @suggestfrommaindictionaryonly.setter
    def suggestfrommaindictionaryonly(self, value):
        """Alias for SuggestFromMainDictionaryOnly.setter"""
        self.SuggestFromMainDictionaryOnly = value

    @property
    def suggest_from_main_dictionary_only(self):
        """Alias for SuggestFromMainDictionaryOnly"""
        return self.SuggestFromMainDictionaryOnly

    @suggest_from_main_dictionary_only.setter
    def suggest_from_main_dictionary_only(self, value):
        """Alias for SuggestFromMainDictionaryOnly.setter"""
        self.SuggestFromMainDictionaryOnly = value

    @property
    def SuggestSpellingCorrections(self):
        return self.com_object.SuggestSpellingCorrections

    @SuggestSpellingCorrections.setter
    def SuggestSpellingCorrections(self, value):
        self.com_object.SuggestSpellingCorrections = value

    @property
    def suggestspellingcorrections(self):
        """Alias for SuggestSpellingCorrections"""
        return self.SuggestSpellingCorrections

    @suggestspellingcorrections.setter
    def suggestspellingcorrections(self, value):
        """Alias for SuggestSpellingCorrections.setter"""
        self.SuggestSpellingCorrections = value

    @property
    def suggest_spelling_corrections(self):
        """Alias for SuggestSpellingCorrections"""
        return self.SuggestSpellingCorrections

    @suggest_spelling_corrections.setter
    def suggest_spelling_corrections(self, value):
        """Alias for SuggestSpellingCorrections.setter"""
        self.SuggestSpellingCorrections = value

    @property
    def TabIndentKey(self):
        return self.com_object.TabIndentKey

    @TabIndentKey.setter
    def TabIndentKey(self, value):
        self.com_object.TabIndentKey = value

    @property
    def tabindentkey(self):
        """Alias for TabIndentKey"""
        return self.TabIndentKey

    @tabindentkey.setter
    def tabindentkey(self, value):
        """Alias for TabIndentKey.setter"""
        self.TabIndentKey = value

    @property
    def tab_indent_key(self):
        """Alias for TabIndentKey"""
        return self.TabIndentKey

    @tab_indent_key.setter
    def tab_indent_key(self, value):
        """Alias for TabIndentKey.setter"""
        self.TabIndentKey = value

    @property
    def TypeNReplace(self):
        return self.com_object.TypeNReplace

    @TypeNReplace.setter
    def TypeNReplace(self, value):
        self.com_object.TypeNReplace = value

    @property
    def typenreplace(self):
        """Alias for TypeNReplace"""
        return self.TypeNReplace

    @typenreplace.setter
    def typenreplace(self, value):
        """Alias for TypeNReplace.setter"""
        self.TypeNReplace = value

    @property
    def type_n_replace(self):
        """Alias for TypeNReplace"""
        return self.TypeNReplace

    @type_n_replace.setter
    def type_n_replace(self, value):
        """Alias for TypeNReplace.setter"""
        self.TypeNReplace = value

    @property
    def UpdateFieldsAtPrint(self):
        return self.com_object.UpdateFieldsAtPrint

    @UpdateFieldsAtPrint.setter
    def UpdateFieldsAtPrint(self, value):
        self.com_object.UpdateFieldsAtPrint = value

    @property
    def updatefieldsatprint(self):
        """Alias for UpdateFieldsAtPrint"""
        return self.UpdateFieldsAtPrint

    @updatefieldsatprint.setter
    def updatefieldsatprint(self, value):
        """Alias for UpdateFieldsAtPrint.setter"""
        self.UpdateFieldsAtPrint = value

    @property
    def update_fields_at_print(self):
        """Alias for UpdateFieldsAtPrint"""
        return self.UpdateFieldsAtPrint

    @update_fields_at_print.setter
    def update_fields_at_print(self, value):
        """Alias for UpdateFieldsAtPrint.setter"""
        self.UpdateFieldsAtPrint = value

    @property
    def UpdateFieldsWithTrackedChangesAtPrint(self):
        return self.com_object.UpdateFieldsWithTrackedChangesAtPrint

    @UpdateFieldsWithTrackedChangesAtPrint.setter
    def UpdateFieldsWithTrackedChangesAtPrint(self, value):
        self.com_object.UpdateFieldsWithTrackedChangesAtPrint = value

    @property
    def updatefieldswithtrackedchangesatprint(self):
        """Alias for UpdateFieldsWithTrackedChangesAtPrint"""
        return self.UpdateFieldsWithTrackedChangesAtPrint

    @updatefieldswithtrackedchangesatprint.setter
    def updatefieldswithtrackedchangesatprint(self, value):
        """Alias for UpdateFieldsWithTrackedChangesAtPrint.setter"""
        self.UpdateFieldsWithTrackedChangesAtPrint = value

    @property
    def update_fields_with_tracked_changes_at_print(self):
        """Alias for UpdateFieldsWithTrackedChangesAtPrint"""
        return self.UpdateFieldsWithTrackedChangesAtPrint

    @update_fields_with_tracked_changes_at_print.setter
    def update_fields_with_tracked_changes_at_print(self, value):
        """Alias for UpdateFieldsWithTrackedChangesAtPrint.setter"""
        self.UpdateFieldsWithTrackedChangesAtPrint = value

    @property
    def UpdateLinksAtOpen(self):
        return self.com_object.UpdateLinksAtOpen

    @UpdateLinksAtOpen.setter
    def UpdateLinksAtOpen(self, value):
        self.com_object.UpdateLinksAtOpen = value

    @property
    def updatelinksatopen(self):
        """Alias for UpdateLinksAtOpen"""
        return self.UpdateLinksAtOpen

    @updatelinksatopen.setter
    def updatelinksatopen(self, value):
        """Alias for UpdateLinksAtOpen.setter"""
        self.UpdateLinksAtOpen = value

    @property
    def update_links_at_open(self):
        """Alias for UpdateLinksAtOpen"""
        return self.UpdateLinksAtOpen

    @update_links_at_open.setter
    def update_links_at_open(self, value):
        """Alias for UpdateLinksAtOpen.setter"""
        self.UpdateLinksAtOpen = value

    @property
    def UpdateLinksAtPrint(self):
        return self.com_object.UpdateLinksAtPrint

    @UpdateLinksAtPrint.setter
    def UpdateLinksAtPrint(self, value):
        self.com_object.UpdateLinksAtPrint = value

    @property
    def updatelinksatprint(self):
        """Alias for UpdateLinksAtPrint"""
        return self.UpdateLinksAtPrint

    @updatelinksatprint.setter
    def updatelinksatprint(self, value):
        """Alias for UpdateLinksAtPrint.setter"""
        self.UpdateLinksAtPrint = value

    @property
    def update_links_at_print(self):
        """Alias for UpdateLinksAtPrint"""
        return self.UpdateLinksAtPrint

    @update_links_at_print.setter
    def update_links_at_print(self, value):
        """Alias for UpdateLinksAtPrint.setter"""
        self.UpdateLinksAtPrint = value

    @property
    def UpdateStyleListBehavior(self):
        return self.com_object.UpdateStyleListBehavior

    @UpdateStyleListBehavior.setter
    def UpdateStyleListBehavior(self, value):
        self.com_object.UpdateStyleListBehavior = value

    @property
    def updatestylelistbehavior(self):
        """Alias for UpdateStyleListBehavior"""
        return self.UpdateStyleListBehavior

    @updatestylelistbehavior.setter
    def updatestylelistbehavior(self, value):
        """Alias for UpdateStyleListBehavior.setter"""
        self.UpdateStyleListBehavior = value

    @property
    def update_style_list_behavior(self):
        """Alias for UpdateStyleListBehavior"""
        return self.UpdateStyleListBehavior

    @update_style_list_behavior.setter
    def update_style_list_behavior(self, value):
        """Alias for UpdateStyleListBehavior.setter"""
        self.UpdateStyleListBehavior = value

    @property
    def UseCharacterUnit(self):
        return self.com_object.UseCharacterUnit

    @UseCharacterUnit.setter
    def UseCharacterUnit(self, value):
        self.com_object.UseCharacterUnit = value

    @property
    def usecharacterunit(self):
        """Alias for UseCharacterUnit"""
        return self.UseCharacterUnit

    @usecharacterunit.setter
    def usecharacterunit(self, value):
        """Alias for UseCharacterUnit.setter"""
        self.UseCharacterUnit = value

    @property
    def use_character_unit(self):
        """Alias for UseCharacterUnit"""
        return self.UseCharacterUnit

    @use_character_unit.setter
    def use_character_unit(self, value):
        """Alias for UseCharacterUnit.setter"""
        self.UseCharacterUnit = value

    @property
    def UseDiffDiacColor(self):
        return self.com_object.UseDiffDiacColor

    @UseDiffDiacColor.setter
    def UseDiffDiacColor(self, value):
        self.com_object.UseDiffDiacColor = value

    @property
    def usediffdiaccolor(self):
        """Alias for UseDiffDiacColor"""
        return self.UseDiffDiacColor

    @usediffdiaccolor.setter
    def usediffdiaccolor(self, value):
        """Alias for UseDiffDiacColor.setter"""
        self.UseDiffDiacColor = value

    @property
    def use_diff_diac_color(self):
        """Alias for UseDiffDiacColor"""
        return self.UseDiffDiacColor

    @use_diff_diac_color.setter
    def use_diff_diac_color(self, value):
        """Alias for UseDiffDiacColor.setter"""
        self.UseDiffDiacColor = value

    @property
    def UseGermanSpellingReform(self):
        return self.com_object.UseGermanSpellingReform

    @UseGermanSpellingReform.setter
    def UseGermanSpellingReform(self, value):
        self.com_object.UseGermanSpellingReform = value

    @property
    def usegermanspellingreform(self):
        """Alias for UseGermanSpellingReform"""
        return self.UseGermanSpellingReform

    @usegermanspellingreform.setter
    def usegermanspellingreform(self, value):
        """Alias for UseGermanSpellingReform.setter"""
        self.UseGermanSpellingReform = value

    @property
    def use_german_spelling_reform(self):
        """Alias for UseGermanSpellingReform"""
        return self.UseGermanSpellingReform

    @use_german_spelling_reform.setter
    def use_german_spelling_reform(self, value):
        """Alias for UseGermanSpellingReform.setter"""
        self.UseGermanSpellingReform = value

    @property
    def UseLocalUserInfo(self):
        return self.com_object.UseLocalUserInfo

    @UseLocalUserInfo.setter
    def UseLocalUserInfo(self, value):
        self.com_object.UseLocalUserInfo = value

    @property
    def uselocaluserinfo(self):
        """Alias for UseLocalUserInfo"""
        return self.UseLocalUserInfo

    @uselocaluserinfo.setter
    def uselocaluserinfo(self, value):
        """Alias for UseLocalUserInfo.setter"""
        self.UseLocalUserInfo = value

    @property
    def use_local_user_info(self):
        """Alias for UseLocalUserInfo"""
        return self.UseLocalUserInfo

    @use_local_user_info.setter
    def use_local_user_info(self, value):
        """Alias for UseLocalUserInfo.setter"""
        self.UseLocalUserInfo = value

    @property
    def UseNormalStyleForList(self):
        return self.com_object.UseNormalStyleForList

    @UseNormalStyleForList.setter
    def UseNormalStyleForList(self, value):
        self.com_object.UseNormalStyleForList = value

    @property
    def usenormalstyleforlist(self):
        """Alias for UseNormalStyleForList"""
        return self.UseNormalStyleForList

    @usenormalstyleforlist.setter
    def usenormalstyleforlist(self, value):
        """Alias for UseNormalStyleForList.setter"""
        self.UseNormalStyleForList = value

    @property
    def use_normal_style_for_list(self):
        """Alias for UseNormalStyleForList"""
        return self.UseNormalStyleForList

    @use_normal_style_for_list.setter
    def use_normal_style_for_list(self, value):
        """Alias for UseNormalStyleForList.setter"""
        self.UseNormalStyleForList = value

    @property
    def UseSubPixelPositioning(self):
        return self.com_object.UseSubPixelPositioning

    @UseSubPixelPositioning.setter
    def UseSubPixelPositioning(self, value):
        self.com_object.UseSubPixelPositioning = value

    @property
    def usesubpixelpositioning(self):
        """Alias for UseSubPixelPositioning"""
        return self.UseSubPixelPositioning

    @usesubpixelpositioning.setter
    def usesubpixelpositioning(self, value):
        """Alias for UseSubPixelPositioning.setter"""
        self.UseSubPixelPositioning = value

    @property
    def use_sub_pixel_positioning(self):
        """Alias for UseSubPixelPositioning"""
        return self.UseSubPixelPositioning

    @use_sub_pixel_positioning.setter
    def use_sub_pixel_positioning(self, value):
        """Alias for UseSubPixelPositioning.setter"""
        self.UseSubPixelPositioning = value

    @property
    def VisualSelection(self):
        return WdVisualSelection(self.com_object.VisualSelection)

    @VisualSelection.setter
    def VisualSelection(self, value):
        self.com_object.VisualSelection = value

    @property
    def visualselection(self):
        """Alias for VisualSelection"""
        return self.VisualSelection

    @visualselection.setter
    def visualselection(self, value):
        """Alias for VisualSelection.setter"""
        self.VisualSelection = value

    @property
    def visual_selection(self):
        """Alias for VisualSelection"""
        return self.VisualSelection

    @visual_selection.setter
    def visual_selection(self, value):
        """Alias for VisualSelection.setter"""
        self.VisualSelection = value

    @property
    def WarnBeforeSavingPrintingSendingMarkup(self):
        return self.com_object.WarnBeforeSavingPrintingSendingMarkup

    @WarnBeforeSavingPrintingSendingMarkup.setter
    def WarnBeforeSavingPrintingSendingMarkup(self, value):
        self.com_object.WarnBeforeSavingPrintingSendingMarkup = value

    @property
    def warnbeforesavingprintingsendingmarkup(self):
        """Alias for WarnBeforeSavingPrintingSendingMarkup"""
        return self.WarnBeforeSavingPrintingSendingMarkup

    @warnbeforesavingprintingsendingmarkup.setter
    def warnbeforesavingprintingsendingmarkup(self, value):
        """Alias for WarnBeforeSavingPrintingSendingMarkup.setter"""
        self.WarnBeforeSavingPrintingSendingMarkup = value

    @property
    def warn_before_saving_printing_sending_markup(self):
        """Alias for WarnBeforeSavingPrintingSendingMarkup"""
        return self.WarnBeforeSavingPrintingSendingMarkup

    @warn_before_saving_printing_sending_markup.setter
    def warn_before_saving_printing_sending_markup(self, value):
        """Alias for WarnBeforeSavingPrintingSendingMarkup.setter"""
        self.WarnBeforeSavingPrintingSendingMarkup = value


class OtherCorrectionsException:

    def __init__(self, othercorrectionsexception=None):
        self.com_object= othercorrectionsexception

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class OtherCorrectionsExceptions:

    def __init__(self, othercorrectionsexceptions=None):
        self.com_object= othercorrectionsexceptions

    def __call__(self, item):
        return OtherCorrectionsException(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        return OtherCorrectionsException(self.com_object.Add(*arguments))

    def add(self, Name=None):
        """Alias for Add"""
        arguments = [Name]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return OtherCorrectionsException(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Page:

    def __init__(self, page=None):
        self.com_object= page

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Breaks(self):
        return Breaks(self.com_object.Breaks)

    @property
    def breaks(self):
        """Alias for Breaks"""
        return self.Breaks

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def EnhMetaFileBits(self):
        return self.com_object.EnhMetaFileBits

    @property
    def enhmetafilebits(self):
        """Alias for EnhMetaFileBits"""
        return self.EnhMetaFileBits

    @property
    def enh_meta_file_bits(self):
        """Alias for EnhMetaFileBits"""
        return self.EnhMetaFileBits

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def Left(self):
        return self.com_object.Left

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Rectangles(self):
        return Rectangles(self.com_object.Rectangles)

    @property
    def rectangles(self):
        """Alias for Rectangles"""
        return self.Rectangles

    @property
    def Top(self):
        return self.com_object.Top

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width


class PageNumber:

    def __init__(self, pagenumber=None):
        self.com_object= pagenumber

    @property
    def Alignment(self):
        return WdPageNumberAlignment(self.com_object.Alignment)

    @Alignment.setter
    def Alignment(self, value):
        self.com_object.Alignment = value

    @property
    def alignment(self):
        """Alias for Alignment"""
        return self.Alignment

    @alignment.setter
    def alignment(self, value):
        """Alias for Alignment.setter"""
        self.Alignment = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Cut(self):
        self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class PageNumbers:

    def __init__(self, pagenumbers=None):
        self.com_object= pagenumbers

    def __call__(self, item):
        return PageNumber(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ChapterPageSeparator(self):
        return WdSeparatorType(self.com_object.ChapterPageSeparator)

    @ChapterPageSeparator.setter
    def ChapterPageSeparator(self, value):
        self.com_object.ChapterPageSeparator = value

    @property
    def chapterpageseparator(self):
        """Alias for ChapterPageSeparator"""
        return self.ChapterPageSeparator

    @chapterpageseparator.setter
    def chapterpageseparator(self, value):
        """Alias for ChapterPageSeparator.setter"""
        self.ChapterPageSeparator = value

    @property
    def chapter_page_separator(self):
        """Alias for ChapterPageSeparator"""
        return self.ChapterPageSeparator

    @chapter_page_separator.setter
    def chapter_page_separator(self, value):
        """Alias for ChapterPageSeparator.setter"""
        self.ChapterPageSeparator = value

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DoubleQuote(self):
        return self.com_object.DoubleQuote

    @DoubleQuote.setter
    def DoubleQuote(self, value):
        self.com_object.DoubleQuote = value

    @property
    def doublequote(self):
        """Alias for DoubleQuote"""
        return self.DoubleQuote

    @doublequote.setter
    def doublequote(self, value):
        """Alias for DoubleQuote.setter"""
        self.DoubleQuote = value

    @property
    def double_quote(self):
        """Alias for DoubleQuote"""
        return self.DoubleQuote

    @double_quote.setter
    def double_quote(self, value):
        """Alias for DoubleQuote.setter"""
        self.DoubleQuote = value

    @property
    def HeadingLevelForChapter(self):
        return self.com_object.HeadingLevelForChapter

    @HeadingLevelForChapter.setter
    def HeadingLevelForChapter(self, value):
        self.com_object.HeadingLevelForChapter = value

    @property
    def headinglevelforchapter(self):
        """Alias for HeadingLevelForChapter"""
        return self.HeadingLevelForChapter

    @headinglevelforchapter.setter
    def headinglevelforchapter(self, value):
        """Alias for HeadingLevelForChapter.setter"""
        self.HeadingLevelForChapter = value

    @property
    def heading_level_for_chapter(self):
        """Alias for HeadingLevelForChapter"""
        return self.HeadingLevelForChapter

    @heading_level_for_chapter.setter
    def heading_level_for_chapter(self, value):
        """Alias for HeadingLevelForChapter.setter"""
        self.HeadingLevelForChapter = value

    @property
    def IncludeChapterNumber(self):
        return self.com_object.IncludeChapterNumber

    @IncludeChapterNumber.setter
    def IncludeChapterNumber(self, value):
        self.com_object.IncludeChapterNumber = value

    @property
    def includechapternumber(self):
        """Alias for IncludeChapterNumber"""
        return self.IncludeChapterNumber

    @includechapternumber.setter
    def includechapternumber(self, value):
        """Alias for IncludeChapterNumber.setter"""
        self.IncludeChapterNumber = value

    @property
    def include_chapter_number(self):
        """Alias for IncludeChapterNumber"""
        return self.IncludeChapterNumber

    @include_chapter_number.setter
    def include_chapter_number(self, value):
        """Alias for IncludeChapterNumber.setter"""
        self.IncludeChapterNumber = value

    @property
    def NumberStyle(self):
        return WdPageNumberStyle(self.com_object.NumberStyle)

    @NumberStyle.setter
    def NumberStyle(self, value):
        self.com_object.NumberStyle = value

    @property
    def numberstyle(self):
        """Alias for NumberStyle"""
        return self.NumberStyle

    @numberstyle.setter
    def numberstyle(self, value):
        """Alias for NumberStyle.setter"""
        self.NumberStyle = value

    @property
    def number_style(self):
        """Alias for NumberStyle"""
        return self.NumberStyle

    @number_style.setter
    def number_style(self, value):
        """Alias for NumberStyle.setter"""
        self.NumberStyle = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RestartNumberingAtSection(self):
        return self.com_object.RestartNumberingAtSection

    @RestartNumberingAtSection.setter
    def RestartNumberingAtSection(self, value):
        self.com_object.RestartNumberingAtSection = value

    @property
    def restartnumberingatsection(self):
        """Alias for RestartNumberingAtSection"""
        return self.RestartNumberingAtSection

    @restartnumberingatsection.setter
    def restartnumberingatsection(self, value):
        """Alias for RestartNumberingAtSection.setter"""
        self.RestartNumberingAtSection = value

    @property
    def restart_numbering_at_section(self):
        """Alias for RestartNumberingAtSection"""
        return self.RestartNumberingAtSection

    @restart_numbering_at_section.setter
    def restart_numbering_at_section(self, value):
        """Alias for RestartNumberingAtSection.setter"""
        self.RestartNumberingAtSection = value

    @property
    def ShowFirstPageNumber(self):
        return self.com_object.ShowFirstPageNumber

    @ShowFirstPageNumber.setter
    def ShowFirstPageNumber(self, value):
        self.com_object.ShowFirstPageNumber = value

    @property
    def showfirstpagenumber(self):
        """Alias for ShowFirstPageNumber"""
        return self.ShowFirstPageNumber

    @showfirstpagenumber.setter
    def showfirstpagenumber(self, value):
        """Alias for ShowFirstPageNumber.setter"""
        self.ShowFirstPageNumber = value

    @property
    def show_first_page_number(self):
        """Alias for ShowFirstPageNumber"""
        return self.ShowFirstPageNumber

    @show_first_page_number.setter
    def show_first_page_number(self, value):
        """Alias for ShowFirstPageNumber.setter"""
        self.ShowFirstPageNumber = value

    @property
    def StartingNumber(self):
        return self.com_object.StartingNumber

    @StartingNumber.setter
    def StartingNumber(self, value):
        self.com_object.StartingNumber = value

    @property
    def startingnumber(self):
        """Alias for StartingNumber"""
        return self.StartingNumber

    @startingnumber.setter
    def startingnumber(self, value):
        """Alias for StartingNumber.setter"""
        self.StartingNumber = value

    @property
    def starting_number(self):
        """Alias for StartingNumber"""
        return self.StartingNumber

    @starting_number.setter
    def starting_number(self, value):
        """Alias for StartingNumber.setter"""
        self.StartingNumber = value

    def Add(self, PageNumberAlignment=None, FirstPage=None):
        arguments = com_arguments([unwrap(a) for a in [PageNumberAlignment, FirstPage]])
        self.com_object.Add(*arguments)

    def add(self, PageNumberAlignment=None, FirstPage=None):
        """Alias for Add"""
        arguments = [PageNumberAlignment, FirstPage]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return PageNumber(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Pages:

    def __init__(self, pages=None):
        self.com_object= pages

    def __call__(self, item):
        return Page(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Page(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class PageSetup:

    def __init__(self, pagesetup=None):
        self.com_object= pagesetup

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BookFoldPrinting(self):
        return self.com_object.BookFoldPrinting

    @BookFoldPrinting.setter
    def BookFoldPrinting(self, value):
        self.com_object.BookFoldPrinting = value

    @property
    def bookfoldprinting(self):
        """Alias for BookFoldPrinting"""
        return self.BookFoldPrinting

    @bookfoldprinting.setter
    def bookfoldprinting(self, value):
        """Alias for BookFoldPrinting.setter"""
        self.BookFoldPrinting = value

    @property
    def book_fold_printing(self):
        """Alias for BookFoldPrinting"""
        return self.BookFoldPrinting

    @book_fold_printing.setter
    def book_fold_printing(self, value):
        """Alias for BookFoldPrinting.setter"""
        self.BookFoldPrinting = value

    @property
    def BookFoldPrintingSheets(self):
        return self.com_object.BookFoldPrintingSheets

    @BookFoldPrintingSheets.setter
    def BookFoldPrintingSheets(self, value):
        self.com_object.BookFoldPrintingSheets = value

    @property
    def bookfoldprintingsheets(self):
        """Alias for BookFoldPrintingSheets"""
        return self.BookFoldPrintingSheets

    @bookfoldprintingsheets.setter
    def bookfoldprintingsheets(self, value):
        """Alias for BookFoldPrintingSheets.setter"""
        self.BookFoldPrintingSheets = value

    @property
    def book_fold_printing_sheets(self):
        """Alias for BookFoldPrintingSheets"""
        return self.BookFoldPrintingSheets

    @book_fold_printing_sheets.setter
    def book_fold_printing_sheets(self, value):
        """Alias for BookFoldPrintingSheets.setter"""
        self.BookFoldPrintingSheets = value

    @property
    def BookFoldRevPrinting(self):
        return self.com_object.BookFoldRevPrinting

    @BookFoldRevPrinting.setter
    def BookFoldRevPrinting(self, value):
        self.com_object.BookFoldRevPrinting = value

    @property
    def bookfoldrevprinting(self):
        """Alias for BookFoldRevPrinting"""
        return self.BookFoldRevPrinting

    @bookfoldrevprinting.setter
    def bookfoldrevprinting(self, value):
        """Alias for BookFoldRevPrinting.setter"""
        self.BookFoldRevPrinting = value

    @property
    def book_fold_rev_printing(self):
        """Alias for BookFoldRevPrinting"""
        return self.BookFoldRevPrinting

    @book_fold_rev_printing.setter
    def book_fold_rev_printing(self, value):
        """Alias for BookFoldRevPrinting.setter"""
        self.BookFoldRevPrinting = value

    @property
    def BottomMargin(self):
        return self.com_object.BottomMargin

    @BottomMargin.setter
    def BottomMargin(self, value):
        self.com_object.BottomMargin = value

    @property
    def bottommargin(self):
        """Alias for BottomMargin"""
        return self.BottomMargin

    @bottommargin.setter
    def bottommargin(self, value):
        """Alias for BottomMargin.setter"""
        self.BottomMargin = value

    @property
    def bottom_margin(self):
        """Alias for BottomMargin"""
        return self.BottomMargin

    @bottom_margin.setter
    def bottom_margin(self, value):
        """Alias for BottomMargin.setter"""
        self.BottomMargin = value

    @property
    def CharsLine(self):
        return self.com_object.CharsLine

    @CharsLine.setter
    def CharsLine(self, value):
        self.com_object.CharsLine = value

    @property
    def charsline(self):
        """Alias for CharsLine"""
        return self.CharsLine

    @charsline.setter
    def charsline(self, value):
        """Alias for CharsLine.setter"""
        self.CharsLine = value

    @property
    def chars_line(self):
        """Alias for CharsLine"""
        return self.CharsLine

    @chars_line.setter
    def chars_line(self, value):
        """Alias for CharsLine.setter"""
        self.CharsLine = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DifferentFirstPageHeaderFooter(self):
        return self.com_object.DifferentFirstPageHeaderFooter

    @DifferentFirstPageHeaderFooter.setter
    def DifferentFirstPageHeaderFooter(self, value):
        self.com_object.DifferentFirstPageHeaderFooter = value

    @property
    def differentfirstpageheaderfooter(self):
        """Alias for DifferentFirstPageHeaderFooter"""
        return self.DifferentFirstPageHeaderFooter

    @differentfirstpageheaderfooter.setter
    def differentfirstpageheaderfooter(self, value):
        """Alias for DifferentFirstPageHeaderFooter.setter"""
        self.DifferentFirstPageHeaderFooter = value

    @property
    def different_first_page_header_footer(self):
        """Alias for DifferentFirstPageHeaderFooter"""
        return self.DifferentFirstPageHeaderFooter

    @different_first_page_header_footer.setter
    def different_first_page_header_footer(self, value):
        """Alias for DifferentFirstPageHeaderFooter.setter"""
        self.DifferentFirstPageHeaderFooter = value

    @property
    def FirstPageTray(self):
        return WdPaperTray(self.com_object.FirstPageTray)

    @FirstPageTray.setter
    def FirstPageTray(self, value):
        self.com_object.FirstPageTray = value

    @property
    def firstpagetray(self):
        """Alias for FirstPageTray"""
        return self.FirstPageTray

    @firstpagetray.setter
    def firstpagetray(self, value):
        """Alias for FirstPageTray.setter"""
        self.FirstPageTray = value

    @property
    def first_page_tray(self):
        """Alias for FirstPageTray"""
        return self.FirstPageTray

    @first_page_tray.setter
    def first_page_tray(self, value):
        """Alias for FirstPageTray.setter"""
        self.FirstPageTray = value

    @property
    def FooterDistance(self):
        return self.com_object.FooterDistance

    @FooterDistance.setter
    def FooterDistance(self, value):
        self.com_object.FooterDistance = value

    @property
    def footerdistance(self):
        """Alias for FooterDistance"""
        return self.FooterDistance

    @footerdistance.setter
    def footerdistance(self, value):
        """Alias for FooterDistance.setter"""
        self.FooterDistance = value

    @property
    def footer_distance(self):
        """Alias for FooterDistance"""
        return self.FooterDistance

    @footer_distance.setter
    def footer_distance(self, value):
        """Alias for FooterDistance.setter"""
        self.FooterDistance = value

    @property
    def Gutter(self):
        return self.com_object.Gutter

    @Gutter.setter
    def Gutter(self, value):
        self.com_object.Gutter = value

    @property
    def gutter(self):
        """Alias for Gutter"""
        return self.Gutter

    @gutter.setter
    def gutter(self, value):
        """Alias for Gutter.setter"""
        self.Gutter = value

    @property
    def GutterPos(self):
        return WdGutterStyle(self.com_object.GutterPos)

    @GutterPos.setter
    def GutterPos(self, value):
        self.com_object.GutterPos = value

    @property
    def gutterpos(self):
        """Alias for GutterPos"""
        return self.GutterPos

    @gutterpos.setter
    def gutterpos(self, value):
        """Alias for GutterPos.setter"""
        self.GutterPos = value

    @property
    def gutter_pos(self):
        """Alias for GutterPos"""
        return self.GutterPos

    @gutter_pos.setter
    def gutter_pos(self, value):
        """Alias for GutterPos.setter"""
        self.GutterPos = value

    @property
    def GutterStyle(self):
        return WdGutterStyleOld(self.com_object.GutterStyle)

    @GutterStyle.setter
    def GutterStyle(self, value):
        self.com_object.GutterStyle = value

    @property
    def gutterstyle(self):
        """Alias for GutterStyle"""
        return self.GutterStyle

    @gutterstyle.setter
    def gutterstyle(self, value):
        """Alias for GutterStyle.setter"""
        self.GutterStyle = value

    @property
    def gutter_style(self):
        """Alias for GutterStyle"""
        return self.GutterStyle

    @gutter_style.setter
    def gutter_style(self, value):
        """Alias for GutterStyle.setter"""
        self.GutterStyle = value

    @property
    def HeaderDistance(self):
        return self.com_object.HeaderDistance

    @HeaderDistance.setter
    def HeaderDistance(self, value):
        self.com_object.HeaderDistance = value

    @property
    def headerdistance(self):
        """Alias for HeaderDistance"""
        return self.HeaderDistance

    @headerdistance.setter
    def headerdistance(self, value):
        """Alias for HeaderDistance.setter"""
        self.HeaderDistance = value

    @property
    def header_distance(self):
        """Alias for HeaderDistance"""
        return self.HeaderDistance

    @header_distance.setter
    def header_distance(self, value):
        """Alias for HeaderDistance.setter"""
        self.HeaderDistance = value

    @property
    def LayoutMode(self):
        return WdLayoutMode(self.com_object.LayoutMode)

    @LayoutMode.setter
    def LayoutMode(self, value):
        self.com_object.LayoutMode = value

    @property
    def layoutmode(self):
        """Alias for LayoutMode"""
        return self.LayoutMode

    @layoutmode.setter
    def layoutmode(self, value):
        """Alias for LayoutMode.setter"""
        self.LayoutMode = value

    @property
    def layout_mode(self):
        """Alias for LayoutMode"""
        return self.LayoutMode

    @layout_mode.setter
    def layout_mode(self, value):
        """Alias for LayoutMode.setter"""
        self.LayoutMode = value

    @property
    def LeftMargin(self):
        return self.com_object.LeftMargin

    @LeftMargin.setter
    def LeftMargin(self, value):
        self.com_object.LeftMargin = value

    @property
    def leftmargin(self):
        """Alias for LeftMargin"""
        return self.LeftMargin

    @leftmargin.setter
    def leftmargin(self, value):
        """Alias for LeftMargin.setter"""
        self.LeftMargin = value

    @property
    def left_margin(self):
        """Alias for LeftMargin"""
        return self.LeftMargin

    @left_margin.setter
    def left_margin(self, value):
        """Alias for LeftMargin.setter"""
        self.LeftMargin = value

    @property
    def LineNumbering(self):
        return LineNumbering(self.com_object.LineNumbering)

    @LineNumbering.setter
    def LineNumbering(self, value):
        self.com_object.LineNumbering = value

    @property
    def linenumbering(self):
        """Alias for LineNumbering"""
        return self.LineNumbering

    @linenumbering.setter
    def linenumbering(self, value):
        """Alias for LineNumbering.setter"""
        self.LineNumbering = value

    @property
    def line_numbering(self):
        """Alias for LineNumbering"""
        return self.LineNumbering

    @line_numbering.setter
    def line_numbering(self, value):
        """Alias for LineNumbering.setter"""
        self.LineNumbering = value

    @property
    def LinesPage(self):
        return self.com_object.LinesPage

    @LinesPage.setter
    def LinesPage(self, value):
        self.com_object.LinesPage = value

    @property
    def linespage(self):
        """Alias for LinesPage"""
        return self.LinesPage

    @linespage.setter
    def linespage(self, value):
        """Alias for LinesPage.setter"""
        self.LinesPage = value

    @property
    def lines_page(self):
        """Alias for LinesPage"""
        return self.LinesPage

    @lines_page.setter
    def lines_page(self, value):
        """Alias for LinesPage.setter"""
        self.LinesPage = value

    @property
    def MirrorMargins(self):
        return self.com_object.MirrorMargins

    @MirrorMargins.setter
    def MirrorMargins(self, value):
        self.com_object.MirrorMargins = value

    @property
    def mirrormargins(self):
        """Alias for MirrorMargins"""
        return self.MirrorMargins

    @mirrormargins.setter
    def mirrormargins(self, value):
        """Alias for MirrorMargins.setter"""
        self.MirrorMargins = value

    @property
    def mirror_margins(self):
        """Alias for MirrorMargins"""
        return self.MirrorMargins

    @mirror_margins.setter
    def mirror_margins(self, value):
        """Alias for MirrorMargins.setter"""
        self.MirrorMargins = value

    @property
    def OddAndEvenPagesHeaderFooter(self):
        return self.com_object.OddAndEvenPagesHeaderFooter

    @OddAndEvenPagesHeaderFooter.setter
    def OddAndEvenPagesHeaderFooter(self, value):
        self.com_object.OddAndEvenPagesHeaderFooter = value

    @property
    def oddandevenpagesheaderfooter(self):
        """Alias for OddAndEvenPagesHeaderFooter"""
        return self.OddAndEvenPagesHeaderFooter

    @oddandevenpagesheaderfooter.setter
    def oddandevenpagesheaderfooter(self, value):
        """Alias for OddAndEvenPagesHeaderFooter.setter"""
        self.OddAndEvenPagesHeaderFooter = value

    @property
    def odd_and_even_pages_header_footer(self):
        """Alias for OddAndEvenPagesHeaderFooter"""
        return self.OddAndEvenPagesHeaderFooter

    @odd_and_even_pages_header_footer.setter
    def odd_and_even_pages_header_footer(self, value):
        """Alias for OddAndEvenPagesHeaderFooter.setter"""
        self.OddAndEvenPagesHeaderFooter = value

    @property
    def Orientation(self):
        return WdOrientation(self.com_object.Orientation)

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def OtherPagesTray(self):
        return WdPaperTray(self.com_object.OtherPagesTray)

    @OtherPagesTray.setter
    def OtherPagesTray(self, value):
        self.com_object.OtherPagesTray = value

    @property
    def otherpagestray(self):
        """Alias for OtherPagesTray"""
        return self.OtherPagesTray

    @otherpagestray.setter
    def otherpagestray(self, value):
        """Alias for OtherPagesTray.setter"""
        self.OtherPagesTray = value

    @property
    def other_pages_tray(self):
        """Alias for OtherPagesTray"""
        return self.OtherPagesTray

    @other_pages_tray.setter
    def other_pages_tray(self, value):
        """Alias for OtherPagesTray.setter"""
        self.OtherPagesTray = value

    @property
    def PageHeight(self):
        return self.com_object.PageHeight

    @PageHeight.setter
    def PageHeight(self, value):
        self.com_object.PageHeight = value

    @property
    def pageheight(self):
        """Alias for PageHeight"""
        return self.PageHeight

    @pageheight.setter
    def pageheight(self, value):
        """Alias for PageHeight.setter"""
        self.PageHeight = value

    @property
    def page_height(self):
        """Alias for PageHeight"""
        return self.PageHeight

    @page_height.setter
    def page_height(self, value):
        """Alias for PageHeight.setter"""
        self.PageHeight = value

    @property
    def PageWidth(self):
        return self.com_object.PageWidth

    @PageWidth.setter
    def PageWidth(self, value):
        self.com_object.PageWidth = value

    @property
    def pagewidth(self):
        """Alias for PageWidth"""
        return self.PageWidth

    @pagewidth.setter
    def pagewidth(self, value):
        """Alias for PageWidth.setter"""
        self.PageWidth = value

    @property
    def page_width(self):
        """Alias for PageWidth"""
        return self.PageWidth

    @page_width.setter
    def page_width(self, value):
        """Alias for PageWidth.setter"""
        self.PageWidth = value

    @property
    def PaperSize(self):
        return WdPaperSize(self.com_object.PaperSize)

    @PaperSize.setter
    def PaperSize(self, value):
        self.com_object.PaperSize = value

    @property
    def papersize(self):
        """Alias for PaperSize"""
        return self.PaperSize

    @papersize.setter
    def papersize(self, value):
        """Alias for PaperSize.setter"""
        self.PaperSize = value

    @property
    def paper_size(self):
        """Alias for PaperSize"""
        return self.PaperSize

    @paper_size.setter
    def paper_size(self, value):
        """Alias for PaperSize.setter"""
        self.PaperSize = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RightMargin(self):
        return self.com_object.RightMargin

    @RightMargin.setter
    def RightMargin(self, value):
        self.com_object.RightMargin = value

    @property
    def rightmargin(self):
        """Alias for RightMargin"""
        return self.RightMargin

    @rightmargin.setter
    def rightmargin(self, value):
        """Alias for RightMargin.setter"""
        self.RightMargin = value

    @property
    def right_margin(self):
        """Alias for RightMargin"""
        return self.RightMargin

    @right_margin.setter
    def right_margin(self, value):
        """Alias for RightMargin.setter"""
        self.RightMargin = value

    @property
    def SectionDirection(self):
        return WdSectionDirection(self.com_object.SectionDirection)

    @SectionDirection.setter
    def SectionDirection(self, value):
        self.com_object.SectionDirection = value

    @property
    def sectiondirection(self):
        """Alias for SectionDirection"""
        return self.SectionDirection

    @sectiondirection.setter
    def sectiondirection(self, value):
        """Alias for SectionDirection.setter"""
        self.SectionDirection = value

    @property
    def section_direction(self):
        """Alias for SectionDirection"""
        return self.SectionDirection

    @section_direction.setter
    def section_direction(self, value):
        """Alias for SectionDirection.setter"""
        self.SectionDirection = value

    @property
    def SectionStart(self):
        return WdSectionStart(self.com_object.SectionStart)

    @SectionStart.setter
    def SectionStart(self, value):
        self.com_object.SectionStart = value

    @property
    def sectionstart(self):
        """Alias for SectionStart"""
        return self.SectionStart

    @sectionstart.setter
    def sectionstart(self, value):
        """Alias for SectionStart.setter"""
        self.SectionStart = value

    @property
    def section_start(self):
        """Alias for SectionStart"""
        return self.SectionStart

    @section_start.setter
    def section_start(self, value):
        """Alias for SectionStart.setter"""
        self.SectionStart = value

    @property
    def ShowGrid(self):
        return self.com_object.ShowGrid

    @ShowGrid.setter
    def ShowGrid(self, value):
        self.com_object.ShowGrid = value

    @property
    def showgrid(self):
        """Alias for ShowGrid"""
        return self.ShowGrid

    @showgrid.setter
    def showgrid(self, value):
        """Alias for ShowGrid.setter"""
        self.ShowGrid = value

    @property
    def show_grid(self):
        """Alias for ShowGrid"""
        return self.ShowGrid

    @show_grid.setter
    def show_grid(self, value):
        """Alias for ShowGrid.setter"""
        self.ShowGrid = value

    @property
    def SuppressEndnotes(self):
        return self.com_object.SuppressEndnotes

    @SuppressEndnotes.setter
    def SuppressEndnotes(self, value):
        self.com_object.SuppressEndnotes = value

    @property
    def suppressendnotes(self):
        """Alias for SuppressEndnotes"""
        return self.SuppressEndnotes

    @suppressendnotes.setter
    def suppressendnotes(self, value):
        """Alias for SuppressEndnotes.setter"""
        self.SuppressEndnotes = value

    @property
    def suppress_endnotes(self):
        """Alias for SuppressEndnotes"""
        return self.SuppressEndnotes

    @suppress_endnotes.setter
    def suppress_endnotes(self, value):
        """Alias for SuppressEndnotes.setter"""
        self.SuppressEndnotes = value

    @property
    def TextColumns(self):
        return self.com_object.TextColumns

    @property
    def textcolumns(self):
        """Alias for TextColumns"""
        return self.TextColumns

    @property
    def text_columns(self):
        """Alias for TextColumns"""
        return self.TextColumns

    @property
    def TopMargin(self):
        return self.com_object.TopMargin

    @TopMargin.setter
    def TopMargin(self, value):
        self.com_object.TopMargin = value

    @property
    def topmargin(self):
        """Alias for TopMargin"""
        return self.TopMargin

    @topmargin.setter
    def topmargin(self, value):
        """Alias for TopMargin.setter"""
        self.TopMargin = value

    @property
    def top_margin(self):
        """Alias for TopMargin"""
        return self.TopMargin

    @top_margin.setter
    def top_margin(self, value):
        """Alias for TopMargin.setter"""
        self.TopMargin = value

    @property
    def TwoPagesOnOne(self):
        return self.com_object.TwoPagesOnOne

    @TwoPagesOnOne.setter
    def TwoPagesOnOne(self, value):
        self.com_object.TwoPagesOnOne = value

    @property
    def twopagesonone(self):
        """Alias for TwoPagesOnOne"""
        return self.TwoPagesOnOne

    @twopagesonone.setter
    def twopagesonone(self, value):
        """Alias for TwoPagesOnOne.setter"""
        self.TwoPagesOnOne = value

    @property
    def two_pages_on_one(self):
        """Alias for TwoPagesOnOne"""
        return self.TwoPagesOnOne

    @two_pages_on_one.setter
    def two_pages_on_one(self, value):
        """Alias for TwoPagesOnOne.setter"""
        self.TwoPagesOnOne = value

    @property
    def VerticalAlignment(self):
        return WdVerticalAlignment(self.com_object.VerticalAlignment)

    @VerticalAlignment.setter
    def VerticalAlignment(self, value):
        self.com_object.VerticalAlignment = value

    @property
    def verticalalignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @verticalalignment.setter
    def verticalalignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def vertical_alignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @vertical_alignment.setter
    def vertical_alignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    def SetAsTemplateDefault(self):
        self.com_object.SetAsTemplateDefault()

    def setastemplatedefault(self):
        """Alias for SetAsTemplateDefault"""
        return self.SetAsTemplateDefault()

    def set_as_template_default(self):
        """Alias for SetAsTemplateDefault"""
        return self.SetAsTemplateDefault()

    def TogglePortrait(self):
        self.com_object.TogglePortrait()

    def toggleportrait(self):
        """Alias for TogglePortrait"""
        return self.TogglePortrait()

    def toggle_portrait(self):
        """Alias for TogglePortrait"""
        return self.TogglePortrait()


class Pane:

    def __init__(self, pane=None):
        self.com_object= pane

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BrowseWidth(self):
        return self.com_object.BrowseWidth

    @property
    def browsewidth(self):
        """Alias for BrowseWidth"""
        return self.BrowseWidth

    @property
    def browse_width(self):
        """Alias for BrowseWidth"""
        return self.BrowseWidth

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DisplayRulers(self):
        return self.com_object.DisplayRulers

    @DisplayRulers.setter
    def DisplayRulers(self, value):
        self.com_object.DisplayRulers = value

    @property
    def displayrulers(self):
        """Alias for DisplayRulers"""
        return self.DisplayRulers

    @displayrulers.setter
    def displayrulers(self, value):
        """Alias for DisplayRulers.setter"""
        self.DisplayRulers = value

    @property
    def display_rulers(self):
        """Alias for DisplayRulers"""
        return self.DisplayRulers

    @display_rulers.setter
    def display_rulers(self, value):
        """Alias for DisplayRulers.setter"""
        self.DisplayRulers = value

    @property
    def DisplayVerticalRuler(self):
        return self.com_object.DisplayVerticalRuler

    @DisplayVerticalRuler.setter
    def DisplayVerticalRuler(self, value):
        self.com_object.DisplayVerticalRuler = value

    @property
    def displayverticalruler(self):
        """Alias for DisplayVerticalRuler"""
        return self.DisplayVerticalRuler

    @displayverticalruler.setter
    def displayverticalruler(self, value):
        """Alias for DisplayVerticalRuler.setter"""
        self.DisplayVerticalRuler = value

    @property
    def display_vertical_ruler(self):
        """Alias for DisplayVerticalRuler"""
        return self.DisplayVerticalRuler

    @display_vertical_ruler.setter
    def display_vertical_ruler(self, value):
        """Alias for DisplayVerticalRuler.setter"""
        self.DisplayVerticalRuler = value

    @property
    def Document(self):
        return Document(self.com_object.Document)

    @property
    def document(self):
        """Alias for Document"""
        return self.Document

    @property
    def Frameset(self):
        return Frameset(self.com_object.Frameset)

    @property
    def frameset(self):
        """Alias for Frameset"""
        return self.Frameset

    @property
    def HorizontalPercentScrolled(self):
        return self.com_object.HorizontalPercentScrolled

    @HorizontalPercentScrolled.setter
    def HorizontalPercentScrolled(self, value):
        self.com_object.HorizontalPercentScrolled = value

    @property
    def horizontalpercentscrolled(self):
        """Alias for HorizontalPercentScrolled"""
        return self.HorizontalPercentScrolled

    @horizontalpercentscrolled.setter
    def horizontalpercentscrolled(self, value):
        """Alias for HorizontalPercentScrolled.setter"""
        self.HorizontalPercentScrolled = value

    @property
    def horizontal_percent_scrolled(self):
        """Alias for HorizontalPercentScrolled"""
        return self.HorizontalPercentScrolled

    @horizontal_percent_scrolled.setter
    def horizontal_percent_scrolled(self, value):
        """Alias for HorizontalPercentScrolled.setter"""
        self.HorizontalPercentScrolled = value

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def MinimumFontSize(self):
        return self.com_object.MinimumFontSize

    @MinimumFontSize.setter
    def MinimumFontSize(self, value):
        self.com_object.MinimumFontSize = value

    @property
    def minimumfontsize(self):
        """Alias for MinimumFontSize"""
        return self.MinimumFontSize

    @minimumfontsize.setter
    def minimumfontsize(self, value):
        """Alias for MinimumFontSize.setter"""
        self.MinimumFontSize = value

    @property
    def minimum_font_size(self):
        """Alias for MinimumFontSize"""
        return self.MinimumFontSize

    @minimum_font_size.setter
    def minimum_font_size(self, value):
        """Alias for MinimumFontSize.setter"""
        self.MinimumFontSize = value

    @property
    def Next(self):
        return Pane(self.com_object.Next)

    @property
    def next(self):
        """Alias for Next"""
        return self.Next

    @property
    def Pages(self):
        return Pages(self.com_object.Pages)

    @property
    def pages(self):
        """Alias for Pages"""
        return self.Pages

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Previous(self):
        return Pane(self.com_object.Previous)

    @property
    def previous(self):
        """Alias for Previous"""
        return self.Previous

    @property
    def Selection(self):
        return Selection(self.com_object.Selection)

    @property
    def selection(self):
        """Alias for Selection"""
        return self.Selection

    @property
    def VerticalPercentScrolled(self):
        return self.com_object.VerticalPercentScrolled

    @VerticalPercentScrolled.setter
    def VerticalPercentScrolled(self, value):
        self.com_object.VerticalPercentScrolled = value

    @property
    def verticalpercentscrolled(self):
        """Alias for VerticalPercentScrolled"""
        return self.VerticalPercentScrolled

    @verticalpercentscrolled.setter
    def verticalpercentscrolled(self, value):
        """Alias for VerticalPercentScrolled.setter"""
        self.VerticalPercentScrolled = value

    @property
    def vertical_percent_scrolled(self):
        """Alias for VerticalPercentScrolled"""
        return self.VerticalPercentScrolled

    @vertical_percent_scrolled.setter
    def vertical_percent_scrolled(self, value):
        """Alias for VerticalPercentScrolled.setter"""
        self.VerticalPercentScrolled = value

    @property
    def View(self):
        return View(self.com_object.View)

    @property
    def view(self):
        """Alias for View"""
        return self.View

    @property
    def Zooms(self):
        return Zooms(self.com_object.Zooms)

    @property
    def zooms(self):
        """Alias for Zooms"""
        return self.Zooms

    def Activate(self):
        self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()

    def AutoScroll(self, Velocity=None):
        arguments = com_arguments([unwrap(a) for a in [Velocity]])
        self.com_object.AutoScroll(*arguments)

    def autoscroll(self, Velocity=None):
        """Alias for AutoScroll"""
        arguments = [Velocity]
        return self.AutoScroll(*arguments)

    def auto_scroll(self, Velocity=None):
        """Alias for AutoScroll"""
        arguments = [Velocity]
        return self.AutoScroll(*arguments)

    def Close(self):
        self.com_object.Close()

    def close(self):
        """Alias for Close"""
        return self.Close()

    def LargeScroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        arguments = com_arguments([unwrap(a) for a in [Down, Up, ToRight, ToLeft]])
        self.com_object.LargeScroll(*arguments)

    def largescroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        """Alias for LargeScroll"""
        arguments = [Down, Up, ToRight, ToLeft]
        return self.LargeScroll(*arguments)

    def large_scroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        """Alias for LargeScroll"""
        arguments = [Down, Up, ToRight, ToLeft]
        return self.LargeScroll(*arguments)

    def NewFrameset(self):
        self.com_object.NewFrameset()

    def newframeset(self):
        """Alias for NewFrameset"""
        return self.NewFrameset()

    def new_frameset(self):
        """Alias for NewFrameset"""
        return self.NewFrameset()

    def PageScroll(self, Down=None, Up=None):
        arguments = com_arguments([unwrap(a) for a in [Down, Up]])
        self.com_object.PageScroll(*arguments)

    def pagescroll(self, Down=None, Up=None):
        """Alias for PageScroll"""
        arguments = [Down, Up]
        return self.PageScroll(*arguments)

    def page_scroll(self, Down=None, Up=None):
        """Alias for PageScroll"""
        arguments = [Down, Up]
        return self.PageScroll(*arguments)

    def SmallScroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        arguments = com_arguments([unwrap(a) for a in [Down, Up, ToRight, ToLeft]])
        self.com_object.SmallScroll(*arguments)

    def smallscroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        """Alias for SmallScroll"""
        arguments = [Down, Up, ToRight, ToLeft]
        return self.SmallScroll(*arguments)

    def small_scroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        """Alias for SmallScroll"""
        arguments = [Down, Up, ToRight, ToLeft]
        return self.SmallScroll(*arguments)

    def TOCInFrameset(self):
        self.com_object.TOCInFrameset()

    def tocinframeset(self):
        """Alias for TOCInFrameset"""
        return self.TOCInFrameset()

    def t_o_c_in_frameset(self):
        """Alias for TOCInFrameset"""
        return self.TOCInFrameset()


class Panes:

    def __init__(self, panes=None):
        self.com_object= panes

    def __call__(self, item):
        return Pane(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, SplitVertical=None):
        arguments = com_arguments([unwrap(a) for a in [SplitVertical]])
        return Pane(self.com_object.Add(*arguments))

    def add(self, SplitVertical=None):
        """Alias for Add"""
        arguments = [SplitVertical]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Pane(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Paragraph:

    def __init__(self, paragraph=None):
        self.com_object= paragraph

    @property
    def AddSpaceBetweenFarEastAndAlpha(self):
        return self.com_object.AddSpaceBetweenFarEastAndAlpha

    @AddSpaceBetweenFarEastAndAlpha.setter
    def AddSpaceBetweenFarEastAndAlpha(self, value):
        self.com_object.AddSpaceBetweenFarEastAndAlpha = value

    @property
    def addspacebetweenfareastandalpha(self):
        """Alias for AddSpaceBetweenFarEastAndAlpha"""
        return self.AddSpaceBetweenFarEastAndAlpha

    @addspacebetweenfareastandalpha.setter
    def addspacebetweenfareastandalpha(self, value):
        """Alias for AddSpaceBetweenFarEastAndAlpha.setter"""
        self.AddSpaceBetweenFarEastAndAlpha = value

    @property
    def add_space_between_far_east_and_alpha(self):
        """Alias for AddSpaceBetweenFarEastAndAlpha"""
        return self.AddSpaceBetweenFarEastAndAlpha

    @add_space_between_far_east_and_alpha.setter
    def add_space_between_far_east_and_alpha(self, value):
        """Alias for AddSpaceBetweenFarEastAndAlpha.setter"""
        self.AddSpaceBetweenFarEastAndAlpha = value

    @property
    def AddSpaceBetweenFarEastAndDigit(self):
        return self.com_object.AddSpaceBetweenFarEastAndDigit

    @AddSpaceBetweenFarEastAndDigit.setter
    def AddSpaceBetweenFarEastAndDigit(self, value):
        self.com_object.AddSpaceBetweenFarEastAndDigit = value

    @property
    def addspacebetweenfareastanddigit(self):
        """Alias for AddSpaceBetweenFarEastAndDigit"""
        return self.AddSpaceBetweenFarEastAndDigit

    @addspacebetweenfareastanddigit.setter
    def addspacebetweenfareastanddigit(self, value):
        """Alias for AddSpaceBetweenFarEastAndDigit.setter"""
        self.AddSpaceBetweenFarEastAndDigit = value

    @property
    def add_space_between_far_east_and_digit(self):
        """Alias for AddSpaceBetweenFarEastAndDigit"""
        return self.AddSpaceBetweenFarEastAndDigit

    @add_space_between_far_east_and_digit.setter
    def add_space_between_far_east_and_digit(self, value):
        """Alias for AddSpaceBetweenFarEastAndDigit.setter"""
        self.AddSpaceBetweenFarEastAndDigit = value

    @property
    def Alignment(self):
        return WdParagraphAlignment(self.com_object.Alignment)

    @Alignment.setter
    def Alignment(self, value):
        self.com_object.Alignment = value

    @property
    def alignment(self):
        """Alias for Alignment"""
        return self.Alignment

    @alignment.setter
    def alignment(self, value):
        """Alias for Alignment.setter"""
        self.Alignment = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoAdjustRightIndent(self):
        return self.com_object.AutoAdjustRightIndent

    @AutoAdjustRightIndent.setter
    def AutoAdjustRightIndent(self, value):
        self.com_object.AutoAdjustRightIndent = value

    @property
    def autoadjustrightindent(self):
        """Alias for AutoAdjustRightIndent"""
        return self.AutoAdjustRightIndent

    @autoadjustrightindent.setter
    def autoadjustrightindent(self, value):
        """Alias for AutoAdjustRightIndent.setter"""
        self.AutoAdjustRightIndent = value

    @property
    def auto_adjust_right_indent(self):
        """Alias for AutoAdjustRightIndent"""
        return self.AutoAdjustRightIndent

    @auto_adjust_right_indent.setter
    def auto_adjust_right_indent(self, value):
        """Alias for AutoAdjustRightIndent.setter"""
        self.AutoAdjustRightIndent = value

    @property
    def BaseLineAlignment(self):
        return WdBaselineAlignment(self.com_object.BaseLineAlignment)

    @BaseLineAlignment.setter
    def BaseLineAlignment(self, value):
        self.com_object.BaseLineAlignment = value

    @property
    def baselinealignment(self):
        """Alias for BaseLineAlignment"""
        return self.BaseLineAlignment

    @baselinealignment.setter
    def baselinealignment(self, value):
        """Alias for BaseLineAlignment.setter"""
        self.BaseLineAlignment = value

    @property
    def base_line_alignment(self):
        """Alias for BaseLineAlignment"""
        return self.BaseLineAlignment

    @base_line_alignment.setter
    def base_line_alignment(self, value):
        """Alias for BaseLineAlignment.setter"""
        self.BaseLineAlignment = value

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def CharacterUnitFirstLineIndent(self):
        return self.com_object.CharacterUnitFirstLineIndent

    @CharacterUnitFirstLineIndent.setter
    def CharacterUnitFirstLineIndent(self, value):
        self.com_object.CharacterUnitFirstLineIndent = value

    @property
    def characterunitfirstlineindent(self):
        """Alias for CharacterUnitFirstLineIndent"""
        return self.CharacterUnitFirstLineIndent

    @characterunitfirstlineindent.setter
    def characterunitfirstlineindent(self, value):
        """Alias for CharacterUnitFirstLineIndent.setter"""
        self.CharacterUnitFirstLineIndent = value

    @property
    def character_unit_first_line_indent(self):
        """Alias for CharacterUnitFirstLineIndent"""
        return self.CharacterUnitFirstLineIndent

    @character_unit_first_line_indent.setter
    def character_unit_first_line_indent(self, value):
        """Alias for CharacterUnitFirstLineIndent.setter"""
        self.CharacterUnitFirstLineIndent = value

    @property
    def CharacterUnitLeftIndent(self):
        return self.com_object.CharacterUnitLeftIndent

    @CharacterUnitLeftIndent.setter
    def CharacterUnitLeftIndent(self, value):
        self.com_object.CharacterUnitLeftIndent = value

    @property
    def characterunitleftindent(self):
        """Alias for CharacterUnitLeftIndent"""
        return self.CharacterUnitLeftIndent

    @characterunitleftindent.setter
    def characterunitleftindent(self, value):
        """Alias for CharacterUnitLeftIndent.setter"""
        self.CharacterUnitLeftIndent = value

    @property
    def character_unit_left_indent(self):
        """Alias for CharacterUnitLeftIndent"""
        return self.CharacterUnitLeftIndent

    @character_unit_left_indent.setter
    def character_unit_left_indent(self, value):
        """Alias for CharacterUnitLeftIndent.setter"""
        self.CharacterUnitLeftIndent = value

    @property
    def CharacterUnitRightIndent(self):
        return self.com_object.CharacterUnitRightIndent

    @CharacterUnitRightIndent.setter
    def CharacterUnitRightIndent(self, value):
        self.com_object.CharacterUnitRightIndent = value

    @property
    def characterunitrightindent(self):
        """Alias for CharacterUnitRightIndent"""
        return self.CharacterUnitRightIndent

    @characterunitrightindent.setter
    def characterunitrightindent(self, value):
        """Alias for CharacterUnitRightIndent.setter"""
        self.CharacterUnitRightIndent = value

    @property
    def character_unit_right_indent(self):
        """Alias for CharacterUnitRightIndent"""
        return self.CharacterUnitRightIndent

    @character_unit_right_indent.setter
    def character_unit_right_indent(self, value):
        """Alias for CharacterUnitRightIndent.setter"""
        self.CharacterUnitRightIndent = value

    @property
    def CollapsedState(self):
        return self.com_object.CollapsedState

    @CollapsedState.setter
    def CollapsedState(self, value):
        self.com_object.CollapsedState = value

    @property
    def collapsedstate(self):
        """Alias for CollapsedState"""
        return self.CollapsedState

    @collapsedstate.setter
    def collapsedstate(self, value):
        """Alias for CollapsedState.setter"""
        self.CollapsedState = value

    @property
    def collapsed_state(self):
        """Alias for CollapsedState"""
        return self.CollapsedState

    @collapsed_state.setter
    def collapsed_state(self, value):
        """Alias for CollapsedState.setter"""
        self.CollapsedState = value

    @property
    def CollapseHeadingByDefault(self):
        return self.com_object.CollapseHeadingByDefault

    @CollapseHeadingByDefault.setter
    def CollapseHeadingByDefault(self, value):
        self.com_object.CollapseHeadingByDefault = value

    @property
    def collapseheadingbydefault(self):
        """Alias for CollapseHeadingByDefault"""
        return self.CollapseHeadingByDefault

    @collapseheadingbydefault.setter
    def collapseheadingbydefault(self, value):
        """Alias for CollapseHeadingByDefault.setter"""
        self.CollapseHeadingByDefault = value

    @property
    def collapse_heading_by_default(self):
        """Alias for CollapseHeadingByDefault"""
        return self.CollapseHeadingByDefault

    @collapse_heading_by_default.setter
    def collapse_heading_by_default(self, value):
        """Alias for CollapseHeadingByDefault.setter"""
        self.CollapseHeadingByDefault = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DisableLineHeightGrid(self):
        return self.com_object.DisableLineHeightGrid

    @DisableLineHeightGrid.setter
    def DisableLineHeightGrid(self, value):
        self.com_object.DisableLineHeightGrid = value

    @property
    def disablelineheightgrid(self):
        """Alias for DisableLineHeightGrid"""
        return self.DisableLineHeightGrid

    @disablelineheightgrid.setter
    def disablelineheightgrid(self, value):
        """Alias for DisableLineHeightGrid.setter"""
        self.DisableLineHeightGrid = value

    @property
    def disable_line_height_grid(self):
        """Alias for DisableLineHeightGrid"""
        return self.DisableLineHeightGrid

    @disable_line_height_grid.setter
    def disable_line_height_grid(self, value):
        """Alias for DisableLineHeightGrid.setter"""
        self.DisableLineHeightGrid = value

    @property
    def DropCap(self):
        return DropCap(self.com_object.DropCap)

    @property
    def dropcap(self):
        """Alias for DropCap"""
        return self.DropCap

    @property
    def drop_cap(self):
        """Alias for DropCap"""
        return self.DropCap

    @property
    def FarEastLineBreakControl(self):
        return self.com_object.FarEastLineBreakControl

    @FarEastLineBreakControl.setter
    def FarEastLineBreakControl(self, value):
        self.com_object.FarEastLineBreakControl = value

    @property
    def fareastlinebreakcontrol(self):
        """Alias for FarEastLineBreakControl"""
        return self.FarEastLineBreakControl

    @fareastlinebreakcontrol.setter
    def fareastlinebreakcontrol(self, value):
        """Alias for FarEastLineBreakControl.setter"""
        self.FarEastLineBreakControl = value

    @property
    def far_east_line_break_control(self):
        """Alias for FarEastLineBreakControl"""
        return self.FarEastLineBreakControl

    @far_east_line_break_control.setter
    def far_east_line_break_control(self, value):
        """Alias for FarEastLineBreakControl.setter"""
        self.FarEastLineBreakControl = value

    @property
    def FirstLineIndent(self):
        return self.com_object.FirstLineIndent

    @FirstLineIndent.setter
    def FirstLineIndent(self, value):
        self.com_object.FirstLineIndent = value

    @property
    def firstlineindent(self):
        """Alias for FirstLineIndent"""
        return self.FirstLineIndent

    @firstlineindent.setter
    def firstlineindent(self, value):
        """Alias for FirstLineIndent.setter"""
        self.FirstLineIndent = value

    @property
    def first_line_indent(self):
        """Alias for FirstLineIndent"""
        return self.FirstLineIndent

    @first_line_indent.setter
    def first_line_indent(self, value):
        """Alias for FirstLineIndent.setter"""
        self.FirstLineIndent = value

    @property
    def Format(self):
        return ParagraphFormat(self.com_object.Format)

    @Format.setter
    def Format(self, value):
        self.com_object.Format = value

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @format.setter
    def format(self, value):
        """Alias for Format.setter"""
        self.Format = value

    @property
    def HalfWidthPunctuationOnTopOfLine(self):
        return self.com_object.HalfWidthPunctuationOnTopOfLine

    @HalfWidthPunctuationOnTopOfLine.setter
    def HalfWidthPunctuationOnTopOfLine(self, value):
        self.com_object.HalfWidthPunctuationOnTopOfLine = value

    @property
    def halfwidthpunctuationontopofline(self):
        """Alias for HalfWidthPunctuationOnTopOfLine"""
        return self.HalfWidthPunctuationOnTopOfLine

    @halfwidthpunctuationontopofline.setter
    def halfwidthpunctuationontopofline(self, value):
        """Alias for HalfWidthPunctuationOnTopOfLine.setter"""
        self.HalfWidthPunctuationOnTopOfLine = value

    @property
    def half_width_punctuation_on_top_of_line(self):
        """Alias for HalfWidthPunctuationOnTopOfLine"""
        return self.HalfWidthPunctuationOnTopOfLine

    @half_width_punctuation_on_top_of_line.setter
    def half_width_punctuation_on_top_of_line(self, value):
        """Alias for HalfWidthPunctuationOnTopOfLine.setter"""
        self.HalfWidthPunctuationOnTopOfLine = value

    @property
    def HangingPunctuation(self):
        return self.com_object.HangingPunctuation

    @HangingPunctuation.setter
    def HangingPunctuation(self, value):
        self.com_object.HangingPunctuation = value

    @property
    def hangingpunctuation(self):
        """Alias for HangingPunctuation"""
        return self.HangingPunctuation

    @hangingpunctuation.setter
    def hangingpunctuation(self, value):
        """Alias for HangingPunctuation.setter"""
        self.HangingPunctuation = value

    @property
    def hanging_punctuation(self):
        """Alias for HangingPunctuation"""
        return self.HangingPunctuation

    @hanging_punctuation.setter
    def hanging_punctuation(self, value):
        """Alias for HangingPunctuation.setter"""
        self.HangingPunctuation = value

    @property
    def Hyphenation(self):
        return self.com_object.Hyphenation

    @Hyphenation.setter
    def Hyphenation(self, value):
        self.com_object.Hyphenation = value

    @property
    def hyphenation(self):
        """Alias for Hyphenation"""
        return self.Hyphenation

    @hyphenation.setter
    def hyphenation(self, value):
        """Alias for Hyphenation.setter"""
        self.Hyphenation = value

    @property
    def ID(self):
        return self.com_object.ID

    @ID.setter
    def ID(self, value):
        self.com_object.ID = value

    @property
    def id(self):
        """Alias for ID"""
        return self.ID

    @id.setter
    def id(self, value):
        """Alias for ID.setter"""
        self.ID = value

    @property
    def i_d(self):
        """Alias for ID"""
        return self.ID

    @i_d.setter
    def i_d(self, value):
        """Alias for ID.setter"""
        self.ID = value

    @property
    def IsStyleSeparator(self):
        return self.com_object.IsStyleSeparator

    @property
    def isstyleseparator(self):
        """Alias for IsStyleSeparator"""
        return self.IsStyleSeparator

    @property
    def is_style_separator(self):
        """Alias for IsStyleSeparator"""
        return self.IsStyleSeparator

    @property
    def KeepTogether(self):
        return self.com_object.KeepTogether

    @KeepTogether.setter
    def KeepTogether(self, value):
        self.com_object.KeepTogether = value

    @property
    def keeptogether(self):
        """Alias for KeepTogether"""
        return self.KeepTogether

    @keeptogether.setter
    def keeptogether(self, value):
        """Alias for KeepTogether.setter"""
        self.KeepTogether = value

    @property
    def keep_together(self):
        """Alias for KeepTogether"""
        return self.KeepTogether

    @keep_together.setter
    def keep_together(self, value):
        """Alias for KeepTogether.setter"""
        self.KeepTogether = value

    @property
    def KeepWithNext(self):
        return self.com_object.KeepWithNext

    @KeepWithNext.setter
    def KeepWithNext(self, value):
        self.com_object.KeepWithNext = value

    @property
    def keepwithnext(self):
        """Alias for KeepWithNext"""
        return self.KeepWithNext

    @keepwithnext.setter
    def keepwithnext(self, value):
        """Alias for KeepWithNext.setter"""
        self.KeepWithNext = value

    @property
    def keep_with_next(self):
        """Alias for KeepWithNext"""
        return self.KeepWithNext

    @keep_with_next.setter
    def keep_with_next(self, value):
        """Alias for KeepWithNext.setter"""
        self.KeepWithNext = value

    @property
    def LeftIndent(self):
        return self.com_object.LeftIndent

    @LeftIndent.setter
    def LeftIndent(self, value):
        self.com_object.LeftIndent = value

    @property
    def leftindent(self):
        """Alias for LeftIndent"""
        return self.LeftIndent

    @leftindent.setter
    def leftindent(self, value):
        """Alias for LeftIndent.setter"""
        self.LeftIndent = value

    @property
    def left_indent(self):
        """Alias for LeftIndent"""
        return self.LeftIndent

    @left_indent.setter
    def left_indent(self, value):
        """Alias for LeftIndent.setter"""
        self.LeftIndent = value

    @property
    def LineSpacing(self):
        return self.com_object.LineSpacing

    @LineSpacing.setter
    def LineSpacing(self, value):
        self.com_object.LineSpacing = value

    @property
    def linespacing(self):
        """Alias for LineSpacing"""
        return self.LineSpacing

    @linespacing.setter
    def linespacing(self, value):
        """Alias for LineSpacing.setter"""
        self.LineSpacing = value

    @property
    def line_spacing(self):
        """Alias for LineSpacing"""
        return self.LineSpacing

    @line_spacing.setter
    def line_spacing(self, value):
        """Alias for LineSpacing.setter"""
        self.LineSpacing = value

    @property
    def LineSpacingRule(self):
        return WdLineSpacing(self.com_object.LineSpacingRule)

    @LineSpacingRule.setter
    def LineSpacingRule(self, value):
        self.com_object.LineSpacingRule = value

    @property
    def linespacingrule(self):
        """Alias for LineSpacingRule"""
        return self.LineSpacingRule

    @linespacingrule.setter
    def linespacingrule(self, value):
        """Alias for LineSpacingRule.setter"""
        self.LineSpacingRule = value

    @property
    def line_spacing_rule(self):
        """Alias for LineSpacingRule"""
        return self.LineSpacingRule

    @line_spacing_rule.setter
    def line_spacing_rule(self, value):
        """Alias for LineSpacingRule.setter"""
        self.LineSpacingRule = value

    @property
    def LineUnitAfter(self):
        return self.com_object.LineUnitAfter

    @LineUnitAfter.setter
    def LineUnitAfter(self, value):
        self.com_object.LineUnitAfter = value

    @property
    def lineunitafter(self):
        """Alias for LineUnitAfter"""
        return self.LineUnitAfter

    @lineunitafter.setter
    def lineunitafter(self, value):
        """Alias for LineUnitAfter.setter"""
        self.LineUnitAfter = value

    @property
    def line_unit_after(self):
        """Alias for LineUnitAfter"""
        return self.LineUnitAfter

    @line_unit_after.setter
    def line_unit_after(self, value):
        """Alias for LineUnitAfter.setter"""
        self.LineUnitAfter = value

    @property
    def LineUnitBefore(self):
        return self.com_object.LineUnitBefore

    @LineUnitBefore.setter
    def LineUnitBefore(self, value):
        self.com_object.LineUnitBefore = value

    @property
    def lineunitbefore(self):
        """Alias for LineUnitBefore"""
        return self.LineUnitBefore

    @lineunitbefore.setter
    def lineunitbefore(self, value):
        """Alias for LineUnitBefore.setter"""
        self.LineUnitBefore = value

    @property
    def line_unit_before(self):
        """Alias for LineUnitBefore"""
        return self.LineUnitBefore

    @line_unit_before.setter
    def line_unit_before(self, value):
        """Alias for LineUnitBefore.setter"""
        self.LineUnitBefore = value

    def ListNumberOriginal(self, Level=None):
        arguments = com_arguments([unwrap(a) for a in [Level]])
        if hasattr(self.com_object, "GetListNumberOriginal"):
            return self.com_object.GetListNumberOriginal(*arguments)
        else:
            return self.com_object.ListNumberOriginal(*arguments)

    def listnumberoriginal(self, Level=None):
        """Alias for ListNumberOriginal"""
        arguments = [Level]
        return self.ListNumberOriginal(*arguments)

    def list_number_original(self, Level=None):
        """Alias for ListNumberOriginal"""
        arguments = [Level]
        return self.ListNumberOriginal(*arguments)

    @property
    def MirrorIndents(self):
        return self.com_object.MirrorIndents

    @MirrorIndents.setter
    def MirrorIndents(self, value):
        self.com_object.MirrorIndents = value

    @property
    def mirrorindents(self):
        """Alias for MirrorIndents"""
        return self.MirrorIndents

    @mirrorindents.setter
    def mirrorindents(self, value):
        """Alias for MirrorIndents.setter"""
        self.MirrorIndents = value

    @property
    def mirror_indents(self):
        """Alias for MirrorIndents"""
        return self.MirrorIndents

    @mirror_indents.setter
    def mirror_indents(self, value):
        """Alias for MirrorIndents.setter"""
        self.MirrorIndents = value

    @property
    def NoLineNumber(self):
        return self.com_object.NoLineNumber

    @NoLineNumber.setter
    def NoLineNumber(self, value):
        self.com_object.NoLineNumber = value

    @property
    def nolinenumber(self):
        """Alias for NoLineNumber"""
        return self.NoLineNumber

    @nolinenumber.setter
    def nolinenumber(self, value):
        """Alias for NoLineNumber.setter"""
        self.NoLineNumber = value

    @property
    def no_line_number(self):
        """Alias for NoLineNumber"""
        return self.NoLineNumber

    @no_line_number.setter
    def no_line_number(self, value):
        """Alias for NoLineNumber.setter"""
        self.NoLineNumber = value

    @property
    def OutlineLevel(self):
        return WdOutlineLevel(self.com_object.OutlineLevel)

    @OutlineLevel.setter
    def OutlineLevel(self, value):
        self.com_object.OutlineLevel = value

    @property
    def outlinelevel(self):
        """Alias for OutlineLevel"""
        return self.OutlineLevel

    @outlinelevel.setter
    def outlinelevel(self, value):
        """Alias for OutlineLevel.setter"""
        self.OutlineLevel = value

    @property
    def outline_level(self):
        """Alias for OutlineLevel"""
        return self.OutlineLevel

    @outline_level.setter
    def outline_level(self, value):
        """Alias for OutlineLevel.setter"""
        self.OutlineLevel = value

    @property
    def PageBreakBefore(self):
        return self.com_object.PageBreakBefore

    @PageBreakBefore.setter
    def PageBreakBefore(self, value):
        self.com_object.PageBreakBefore = value

    @property
    def pagebreakbefore(self):
        """Alias for PageBreakBefore"""
        return self.PageBreakBefore

    @pagebreakbefore.setter
    def pagebreakbefore(self, value):
        """Alias for PageBreakBefore.setter"""
        self.PageBreakBefore = value

    @property
    def page_break_before(self):
        """Alias for PageBreakBefore"""
        return self.PageBreakBefore

    @page_break_before.setter
    def page_break_before(self, value):
        """Alias for PageBreakBefore.setter"""
        self.PageBreakBefore = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def ReadingOrder(self):
        return WdReadingOrder(self.com_object.ReadingOrder)

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def RightIndent(self):
        return self.com_object.RightIndent

    @RightIndent.setter
    def RightIndent(self, value):
        self.com_object.RightIndent = value

    @property
    def rightindent(self):
        """Alias for RightIndent"""
        return self.RightIndent

    @rightindent.setter
    def rightindent(self, value):
        """Alias for RightIndent.setter"""
        self.RightIndent = value

    @property
    def right_indent(self):
        """Alias for RightIndent"""
        return self.RightIndent

    @right_indent.setter
    def right_indent(self, value):
        """Alias for RightIndent.setter"""
        self.RightIndent = value

    @property
    def Shading(self):
        return Shading(self.com_object.Shading)

    @property
    def shading(self):
        """Alias for Shading"""
        return self.Shading

    @property
    def SpaceAfter(self):
        return self.com_object.SpaceAfter

    @SpaceAfter.setter
    def SpaceAfter(self, value):
        self.com_object.SpaceAfter = value

    @property
    def spaceafter(self):
        """Alias for SpaceAfter"""
        return self.SpaceAfter

    @spaceafter.setter
    def spaceafter(self, value):
        """Alias for SpaceAfter.setter"""
        self.SpaceAfter = value

    @property
    def space_after(self):
        """Alias for SpaceAfter"""
        return self.SpaceAfter

    @space_after.setter
    def space_after(self, value):
        """Alias for SpaceAfter.setter"""
        self.SpaceAfter = value

    @property
    def SpaceAfterAuto(self):
        return self.com_object.SpaceAfterAuto

    @SpaceAfterAuto.setter
    def SpaceAfterAuto(self, value):
        self.com_object.SpaceAfterAuto = value

    @property
    def spaceafterauto(self):
        """Alias for SpaceAfterAuto"""
        return self.SpaceAfterAuto

    @spaceafterauto.setter
    def spaceafterauto(self, value):
        """Alias for SpaceAfterAuto.setter"""
        self.SpaceAfterAuto = value

    @property
    def space_after_auto(self):
        """Alias for SpaceAfterAuto"""
        return self.SpaceAfterAuto

    @space_after_auto.setter
    def space_after_auto(self, value):
        """Alias for SpaceAfterAuto.setter"""
        self.SpaceAfterAuto = value

    @property
    def SpaceBefore(self):
        return self.com_object.SpaceBefore

    @SpaceBefore.setter
    def SpaceBefore(self, value):
        self.com_object.SpaceBefore = value

    @property
    def spacebefore(self):
        """Alias for SpaceBefore"""
        return self.SpaceBefore

    @spacebefore.setter
    def spacebefore(self, value):
        """Alias for SpaceBefore.setter"""
        self.SpaceBefore = value

    @property
    def space_before(self):
        """Alias for SpaceBefore"""
        return self.SpaceBefore

    @space_before.setter
    def space_before(self, value):
        """Alias for SpaceBefore.setter"""
        self.SpaceBefore = value

    @property
    def SpaceBeforeAuto(self):
        return self.com_object.SpaceBeforeAuto

    @SpaceBeforeAuto.setter
    def SpaceBeforeAuto(self, value):
        self.com_object.SpaceBeforeAuto = value

    @property
    def spacebeforeauto(self):
        """Alias for SpaceBeforeAuto"""
        return self.SpaceBeforeAuto

    @spacebeforeauto.setter
    def spacebeforeauto(self, value):
        """Alias for SpaceBeforeAuto.setter"""
        self.SpaceBeforeAuto = value

    @property
    def space_before_auto(self):
        """Alias for SpaceBeforeAuto"""
        return self.SpaceBeforeAuto

    @space_before_auto.setter
    def space_before_auto(self, value):
        """Alias for SpaceBeforeAuto.setter"""
        self.SpaceBeforeAuto = value

    @property
    def Style(self):
        return self.com_object.Style

    @Style.setter
    def Style(self, value):
        self.com_object.Style = value

    @property
    def style(self):
        """Alias for Style"""
        return self.Style

    @style.setter
    def style(self, value):
        """Alias for Style.setter"""
        self.Style = value

    @property
    def TabStops(self):
        return TabStops(self.com_object.TabStops)

    @TabStops.setter
    def TabStops(self, value):
        self.com_object.TabStops = value

    @property
    def tabstops(self):
        """Alias for TabStops"""
        return self.TabStops

    @tabstops.setter
    def tabstops(self, value):
        """Alias for TabStops.setter"""
        self.TabStops = value

    @property
    def tab_stops(self):
        """Alias for TabStops"""
        return self.TabStops

    @tab_stops.setter
    def tab_stops(self, value):
        """Alias for TabStops.setter"""
        self.TabStops = value

    @property
    def TextboxTightWrap(self):
        return WdTextboxTightWrap(self.com_object.TextboxTightWrap)

    @TextboxTightWrap.setter
    def TextboxTightWrap(self, value):
        self.com_object.TextboxTightWrap = value

    @property
    def textboxtightwrap(self):
        """Alias for TextboxTightWrap"""
        return self.TextboxTightWrap

    @textboxtightwrap.setter
    def textboxtightwrap(self, value):
        """Alias for TextboxTightWrap.setter"""
        self.TextboxTightWrap = value

    @property
    def textbox_tight_wrap(self):
        """Alias for TextboxTightWrap"""
        return self.TextboxTightWrap

    @textbox_tight_wrap.setter
    def textbox_tight_wrap(self, value):
        """Alias for TextboxTightWrap.setter"""
        self.TextboxTightWrap = value

    @property
    def WidowControl(self):
        return self.com_object.WidowControl

    @WidowControl.setter
    def WidowControl(self, value):
        self.com_object.WidowControl = value

    @property
    def widowcontrol(self):
        """Alias for WidowControl"""
        return self.WidowControl

    @widowcontrol.setter
    def widowcontrol(self, value):
        """Alias for WidowControl.setter"""
        self.WidowControl = value

    @property
    def widow_control(self):
        """Alias for WidowControl"""
        return self.WidowControl

    @widow_control.setter
    def widow_control(self, value):
        """Alias for WidowControl.setter"""
        self.WidowControl = value

    @property
    def WordWrap(self):
        return self.com_object.WordWrap

    @WordWrap.setter
    def WordWrap(self, value):
        self.com_object.WordWrap = value

    @property
    def wordwrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @wordwrap.setter
    def wordwrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value

    @property
    def word_wrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @word_wrap.setter
    def word_wrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value

    def CloseUp(self):
        self.com_object.CloseUp()

    def closeup(self):
        """Alias for CloseUp"""
        return self.CloseUp()

    def close_up(self):
        """Alias for CloseUp"""
        return self.CloseUp()

    def Indent(self):
        self.com_object.Indent()

    def indent(self):
        """Alias for Indent"""
        return self.Indent()

    def IndentCharWidth(self, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Count]])
        self.com_object.IndentCharWidth(*arguments)

    def indentcharwidth(self, Count=None):
        """Alias for IndentCharWidth"""
        arguments = [Count]
        return self.IndentCharWidth(*arguments)

    def indent_char_width(self, Count=None):
        """Alias for IndentCharWidth"""
        arguments = [Count]
        return self.IndentCharWidth(*arguments)

    def IndentFirstLineCharWidth(self, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Count]])
        self.com_object.IndentFirstLineCharWidth(*arguments)

    def indentfirstlinecharwidth(self, Count=None):
        """Alias for IndentFirstLineCharWidth"""
        arguments = [Count]
        return self.IndentFirstLineCharWidth(*arguments)

    def indent_first_line_char_width(self, Count=None):
        """Alias for IndentFirstLineCharWidth"""
        arguments = [Count]
        return self.IndentFirstLineCharWidth(*arguments)

    def JoinList(self):
        self.com_object.JoinList()

    def joinlist(self):
        """Alias for JoinList"""
        return self.JoinList()

    def join_list(self):
        """Alias for JoinList"""
        return self.JoinList()

    def ListAdvanceTo(self, Level1=None, Level2=None, Level3=None, Level4=None, Level5=None, Level6=None, Level7=None, Level8=None, Level9=None):
        arguments = com_arguments([unwrap(a) for a in [Level1, Level2, Level3, Level4, Level5, Level6, Level7, Level8, Level9]])
        self.com_object.ListAdvanceTo(*arguments)

    def listadvanceto(self, Level1=None, Level2=None, Level3=None, Level4=None, Level5=None, Level6=None, Level7=None, Level8=None, Level9=None):
        """Alias for ListAdvanceTo"""
        arguments = [Level1, Level2, Level3, Level4, Level5, Level6, Level7, Level8, Level9]
        return self.ListAdvanceTo(*arguments)

    def list_advance_to(self, Level1=None, Level2=None, Level3=None, Level4=None, Level5=None, Level6=None, Level7=None, Level8=None, Level9=None):
        """Alias for ListAdvanceTo"""
        arguments = [Level1, Level2, Level3, Level4, Level5, Level6, Level7, Level8, Level9]
        return self.ListAdvanceTo(*arguments)

    def Next(self, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Count]])
        return Paragraph(self.com_object.Next(*arguments))

    def next(self, Count=None):
        """Alias for Next"""
        arguments = [Count]
        return self.Next(*arguments)

    def OpenOrCloseUp(self):
        self.com_object.OpenOrCloseUp()

    def openorcloseup(self):
        """Alias for OpenOrCloseUp"""
        return self.OpenOrCloseUp()

    def open_or_close_up(self):
        """Alias for OpenOrCloseUp"""
        return self.OpenOrCloseUp()

    def OpenUp(self):
        self.com_object.OpenUp()

    def openup(self):
        """Alias for OpenUp"""
        return self.OpenUp()

    def open_up(self):
        """Alias for OpenUp"""
        return self.OpenUp()

    def Outdent(self):
        self.com_object.Outdent()

    def outdent(self):
        """Alias for Outdent"""
        return self.Outdent()

    def OutlineDemote(self):
        self.com_object.OutlineDemote()

    def outlinedemote(self):
        """Alias for OutlineDemote"""
        return self.OutlineDemote()

    def outline_demote(self):
        """Alias for OutlineDemote"""
        return self.OutlineDemote()

    def OutlineDemoteToBody(self):
        self.com_object.OutlineDemoteToBody()

    def outlinedemotetobody(self):
        """Alias for OutlineDemoteToBody"""
        return self.OutlineDemoteToBody()

    def outline_demote_to_body(self):
        """Alias for OutlineDemoteToBody"""
        return self.OutlineDemoteToBody()

    def OutlinePromote(self):
        self.com_object.OutlinePromote()

    def outlinepromote(self):
        """Alias for OutlinePromote"""
        return self.OutlinePromote()

    def outline_promote(self):
        """Alias for OutlinePromote"""
        return self.OutlinePromote()

    def Previous(self, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Count]])
        return Paragraph(self.com_object.Previous(*arguments))

    def previous(self, Count=None):
        """Alias for Previous"""
        arguments = [Count]
        return self.Previous(*arguments)

    def Reset(self):
        self.com_object.Reset()

    def reset(self):
        """Alias for Reset"""
        return self.Reset()

    def ResetAdvanceTo(self):
        self.com_object.ResetAdvanceTo()

    def resetadvanceto(self):
        """Alias for ResetAdvanceTo"""
        return self.ResetAdvanceTo()

    def reset_advance_to(self):
        """Alias for ResetAdvanceTo"""
        return self.ResetAdvanceTo()

    def SelectNumber(self):
        self.com_object.SelectNumber()

    def selectnumber(self):
        """Alias for SelectNumber"""
        return self.SelectNumber()

    def select_number(self):
        """Alias for SelectNumber"""
        return self.SelectNumber()

    def SeparateList(self):
        self.com_object.SeparateList()

    def separatelist(self):
        """Alias for SeparateList"""
        return self.SeparateList()

    def separate_list(self):
        """Alias for SeparateList"""
        return self.SeparateList()

    def Space1(self):
        self.com_object.Space1()

    def space1(self):
        """Alias for Space1"""
        return self.Space1()

    def Space15(self):
        self.com_object.Space15()

    def space15(self):
        """Alias for Space15"""
        return self.Space15()

    def Space2(self):
        self.com_object.Space2()

    def space2(self):
        """Alias for Space2"""
        return self.Space2()

    def TabHangingIndent(self, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Count]])
        self.com_object.TabHangingIndent(*arguments)

    def tabhangingindent(self, Count=None):
        """Alias for TabHangingIndent"""
        arguments = [Count]
        return self.TabHangingIndent(*arguments)

    def tab_hanging_indent(self, Count=None):
        """Alias for TabHangingIndent"""
        arguments = [Count]
        return self.TabHangingIndent(*arguments)

    def TabIndent(self, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Count]])
        self.com_object.TabIndent(*arguments)

    def tabindent(self, Count=None):
        """Alias for TabIndent"""
        arguments = [Count]
        return self.TabIndent(*arguments)

    def tab_indent(self, Count=None):
        """Alias for TabIndent"""
        arguments = [Count]
        return self.TabIndent(*arguments)


class ParagraphFormat:

    def __init__(self, paragraphformat=None):
        self.com_object= paragraphformat

    @property
    def AddSpaceBetweenFarEastAndAlpha(self):
        return self.com_object.AddSpaceBetweenFarEastAndAlpha

    @AddSpaceBetweenFarEastAndAlpha.setter
    def AddSpaceBetweenFarEastAndAlpha(self, value):
        self.com_object.AddSpaceBetweenFarEastAndAlpha = value

    @property
    def addspacebetweenfareastandalpha(self):
        """Alias for AddSpaceBetweenFarEastAndAlpha"""
        return self.AddSpaceBetweenFarEastAndAlpha

    @addspacebetweenfareastandalpha.setter
    def addspacebetweenfareastandalpha(self, value):
        """Alias for AddSpaceBetweenFarEastAndAlpha.setter"""
        self.AddSpaceBetweenFarEastAndAlpha = value

    @property
    def add_space_between_far_east_and_alpha(self):
        """Alias for AddSpaceBetweenFarEastAndAlpha"""
        return self.AddSpaceBetweenFarEastAndAlpha

    @add_space_between_far_east_and_alpha.setter
    def add_space_between_far_east_and_alpha(self, value):
        """Alias for AddSpaceBetweenFarEastAndAlpha.setter"""
        self.AddSpaceBetweenFarEastAndAlpha = value

    @property
    def AddSpaceBetweenFarEastAndDigit(self):
        return self.com_object.AddSpaceBetweenFarEastAndDigit

    @AddSpaceBetweenFarEastAndDigit.setter
    def AddSpaceBetweenFarEastAndDigit(self, value):
        self.com_object.AddSpaceBetweenFarEastAndDigit = value

    @property
    def addspacebetweenfareastanddigit(self):
        """Alias for AddSpaceBetweenFarEastAndDigit"""
        return self.AddSpaceBetweenFarEastAndDigit

    @addspacebetweenfareastanddigit.setter
    def addspacebetweenfareastanddigit(self, value):
        """Alias for AddSpaceBetweenFarEastAndDigit.setter"""
        self.AddSpaceBetweenFarEastAndDigit = value

    @property
    def add_space_between_far_east_and_digit(self):
        """Alias for AddSpaceBetweenFarEastAndDigit"""
        return self.AddSpaceBetweenFarEastAndDigit

    @add_space_between_far_east_and_digit.setter
    def add_space_between_far_east_and_digit(self, value):
        """Alias for AddSpaceBetweenFarEastAndDigit.setter"""
        self.AddSpaceBetweenFarEastAndDigit = value

    @property
    def Alignment(self):
        return WdParagraphAlignment(self.com_object.Alignment)

    @Alignment.setter
    def Alignment(self, value):
        self.com_object.Alignment = value

    @property
    def alignment(self):
        """Alias for Alignment"""
        return self.Alignment

    @alignment.setter
    def alignment(self, value):
        """Alias for Alignment.setter"""
        self.Alignment = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoAdjustRightIndent(self):
        return self.com_object.AutoAdjustRightIndent

    @AutoAdjustRightIndent.setter
    def AutoAdjustRightIndent(self, value):
        self.com_object.AutoAdjustRightIndent = value

    @property
    def autoadjustrightindent(self):
        """Alias for AutoAdjustRightIndent"""
        return self.AutoAdjustRightIndent

    @autoadjustrightindent.setter
    def autoadjustrightindent(self, value):
        """Alias for AutoAdjustRightIndent.setter"""
        self.AutoAdjustRightIndent = value

    @property
    def auto_adjust_right_indent(self):
        """Alias for AutoAdjustRightIndent"""
        return self.AutoAdjustRightIndent

    @auto_adjust_right_indent.setter
    def auto_adjust_right_indent(self, value):
        """Alias for AutoAdjustRightIndent.setter"""
        self.AutoAdjustRightIndent = value

    @property
    def BaseLineAlignment(self):
        return WdBaselineAlignment(self.com_object.BaseLineAlignment)

    @BaseLineAlignment.setter
    def BaseLineAlignment(self, value):
        self.com_object.BaseLineAlignment = value

    @property
    def baselinealignment(self):
        """Alias for BaseLineAlignment"""
        return self.BaseLineAlignment

    @baselinealignment.setter
    def baselinealignment(self, value):
        """Alias for BaseLineAlignment.setter"""
        self.BaseLineAlignment = value

    @property
    def base_line_alignment(self):
        """Alias for BaseLineAlignment"""
        return self.BaseLineAlignment

    @base_line_alignment.setter
    def base_line_alignment(self, value):
        """Alias for BaseLineAlignment.setter"""
        self.BaseLineAlignment = value

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def CharacterUnitFirstLineIndent(self):
        return self.com_object.CharacterUnitFirstLineIndent

    @CharacterUnitFirstLineIndent.setter
    def CharacterUnitFirstLineIndent(self, value):
        self.com_object.CharacterUnitFirstLineIndent = value

    @property
    def characterunitfirstlineindent(self):
        """Alias for CharacterUnitFirstLineIndent"""
        return self.CharacterUnitFirstLineIndent

    @characterunitfirstlineindent.setter
    def characterunitfirstlineindent(self, value):
        """Alias for CharacterUnitFirstLineIndent.setter"""
        self.CharacterUnitFirstLineIndent = value

    @property
    def character_unit_first_line_indent(self):
        """Alias for CharacterUnitFirstLineIndent"""
        return self.CharacterUnitFirstLineIndent

    @character_unit_first_line_indent.setter
    def character_unit_first_line_indent(self, value):
        """Alias for CharacterUnitFirstLineIndent.setter"""
        self.CharacterUnitFirstLineIndent = value

    @property
    def CharacterUnitLeftIndent(self):
        return self.com_object.CharacterUnitLeftIndent

    @CharacterUnitLeftIndent.setter
    def CharacterUnitLeftIndent(self, value):
        self.com_object.CharacterUnitLeftIndent = value

    @property
    def characterunitleftindent(self):
        """Alias for CharacterUnitLeftIndent"""
        return self.CharacterUnitLeftIndent

    @characterunitleftindent.setter
    def characterunitleftindent(self, value):
        """Alias for CharacterUnitLeftIndent.setter"""
        self.CharacterUnitLeftIndent = value

    @property
    def character_unit_left_indent(self):
        """Alias for CharacterUnitLeftIndent"""
        return self.CharacterUnitLeftIndent

    @character_unit_left_indent.setter
    def character_unit_left_indent(self, value):
        """Alias for CharacterUnitLeftIndent.setter"""
        self.CharacterUnitLeftIndent = value

    @property
    def CharacterUnitRightIndent(self):
        return self.com_object.CharacterUnitRightIndent

    @CharacterUnitRightIndent.setter
    def CharacterUnitRightIndent(self, value):
        self.com_object.CharacterUnitRightIndent = value

    @property
    def characterunitrightindent(self):
        """Alias for CharacterUnitRightIndent"""
        return self.CharacterUnitRightIndent

    @characterunitrightindent.setter
    def characterunitrightindent(self, value):
        """Alias for CharacterUnitRightIndent.setter"""
        self.CharacterUnitRightIndent = value

    @property
    def character_unit_right_indent(self):
        """Alias for CharacterUnitRightIndent"""
        return self.CharacterUnitRightIndent

    @character_unit_right_indent.setter
    def character_unit_right_indent(self, value):
        """Alias for CharacterUnitRightIndent.setter"""
        self.CharacterUnitRightIndent = value

    @property
    def CollapsedByDefault(self):
        return self.com_object.CollapsedByDefault

    @CollapsedByDefault.setter
    def CollapsedByDefault(self, value):
        self.com_object.CollapsedByDefault = value

    @property
    def collapsedbydefault(self):
        """Alias for CollapsedByDefault"""
        return self.CollapsedByDefault

    @collapsedbydefault.setter
    def collapsedbydefault(self, value):
        """Alias for CollapsedByDefault.setter"""
        self.CollapsedByDefault = value

    @property
    def collapsed_by_default(self):
        """Alias for CollapsedByDefault"""
        return self.CollapsedByDefault

    @collapsed_by_default.setter
    def collapsed_by_default(self, value):
        """Alias for CollapsedByDefault.setter"""
        self.CollapsedByDefault = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DisableLineHeightGrid(self):
        return self.com_object.DisableLineHeightGrid

    @DisableLineHeightGrid.setter
    def DisableLineHeightGrid(self, value):
        self.com_object.DisableLineHeightGrid = value

    @property
    def disablelineheightgrid(self):
        """Alias for DisableLineHeightGrid"""
        return self.DisableLineHeightGrid

    @disablelineheightgrid.setter
    def disablelineheightgrid(self, value):
        """Alias for DisableLineHeightGrid.setter"""
        self.DisableLineHeightGrid = value

    @property
    def disable_line_height_grid(self):
        """Alias for DisableLineHeightGrid"""
        return self.DisableLineHeightGrid

    @disable_line_height_grid.setter
    def disable_line_height_grid(self, value):
        """Alias for DisableLineHeightGrid.setter"""
        self.DisableLineHeightGrid = value

    @property
    def Duplicate(self):
        return ParagraphFormat(self.com_object.Duplicate)

    @property
    def duplicate(self):
        """Alias for Duplicate"""
        return self.Duplicate

    @property
    def FarEastLineBreakControl(self):
        return self.com_object.FarEastLineBreakControl

    @FarEastLineBreakControl.setter
    def FarEastLineBreakControl(self, value):
        self.com_object.FarEastLineBreakControl = value

    @property
    def fareastlinebreakcontrol(self):
        """Alias for FarEastLineBreakControl"""
        return self.FarEastLineBreakControl

    @fareastlinebreakcontrol.setter
    def fareastlinebreakcontrol(self, value):
        """Alias for FarEastLineBreakControl.setter"""
        self.FarEastLineBreakControl = value

    @property
    def far_east_line_break_control(self):
        """Alias for FarEastLineBreakControl"""
        return self.FarEastLineBreakControl

    @far_east_line_break_control.setter
    def far_east_line_break_control(self, value):
        """Alias for FarEastLineBreakControl.setter"""
        self.FarEastLineBreakControl = value

    @property
    def FirstLineIndent(self):
        return self.com_object.FirstLineIndent

    @FirstLineIndent.setter
    def FirstLineIndent(self, value):
        self.com_object.FirstLineIndent = value

    @property
    def firstlineindent(self):
        """Alias for FirstLineIndent"""
        return self.FirstLineIndent

    @firstlineindent.setter
    def firstlineindent(self, value):
        """Alias for FirstLineIndent.setter"""
        self.FirstLineIndent = value

    @property
    def first_line_indent(self):
        """Alias for FirstLineIndent"""
        return self.FirstLineIndent

    @first_line_indent.setter
    def first_line_indent(self, value):
        """Alias for FirstLineIndent.setter"""
        self.FirstLineIndent = value

    @property
    def HalfWidthPunctuationOnTopOfLine(self):
        return self.com_object.HalfWidthPunctuationOnTopOfLine

    @HalfWidthPunctuationOnTopOfLine.setter
    def HalfWidthPunctuationOnTopOfLine(self, value):
        self.com_object.HalfWidthPunctuationOnTopOfLine = value

    @property
    def halfwidthpunctuationontopofline(self):
        """Alias for HalfWidthPunctuationOnTopOfLine"""
        return self.HalfWidthPunctuationOnTopOfLine

    @halfwidthpunctuationontopofline.setter
    def halfwidthpunctuationontopofline(self, value):
        """Alias for HalfWidthPunctuationOnTopOfLine.setter"""
        self.HalfWidthPunctuationOnTopOfLine = value

    @property
    def half_width_punctuation_on_top_of_line(self):
        """Alias for HalfWidthPunctuationOnTopOfLine"""
        return self.HalfWidthPunctuationOnTopOfLine

    @half_width_punctuation_on_top_of_line.setter
    def half_width_punctuation_on_top_of_line(self, value):
        """Alias for HalfWidthPunctuationOnTopOfLine.setter"""
        self.HalfWidthPunctuationOnTopOfLine = value

    @property
    def HangingPunctuation(self):
        return self.com_object.HangingPunctuation

    @HangingPunctuation.setter
    def HangingPunctuation(self, value):
        self.com_object.HangingPunctuation = value

    @property
    def hangingpunctuation(self):
        """Alias for HangingPunctuation"""
        return self.HangingPunctuation

    @hangingpunctuation.setter
    def hangingpunctuation(self, value):
        """Alias for HangingPunctuation.setter"""
        self.HangingPunctuation = value

    @property
    def hanging_punctuation(self):
        """Alias for HangingPunctuation"""
        return self.HangingPunctuation

    @hanging_punctuation.setter
    def hanging_punctuation(self, value):
        """Alias for HangingPunctuation.setter"""
        self.HangingPunctuation = value

    @property
    def Hyphenation(self):
        return self.com_object.Hyphenation

    @Hyphenation.setter
    def Hyphenation(self, value):
        self.com_object.Hyphenation = value

    @property
    def hyphenation(self):
        """Alias for Hyphenation"""
        return self.Hyphenation

    @hyphenation.setter
    def hyphenation(self, value):
        """Alias for Hyphenation.setter"""
        self.Hyphenation = value

    @property
    def KeepTogether(self):
        return self.com_object.KeepTogether

    @KeepTogether.setter
    def KeepTogether(self, value):
        self.com_object.KeepTogether = value

    @property
    def keeptogether(self):
        """Alias for KeepTogether"""
        return self.KeepTogether

    @keeptogether.setter
    def keeptogether(self, value):
        """Alias for KeepTogether.setter"""
        self.KeepTogether = value

    @property
    def keep_together(self):
        """Alias for KeepTogether"""
        return self.KeepTogether

    @keep_together.setter
    def keep_together(self, value):
        """Alias for KeepTogether.setter"""
        self.KeepTogether = value

    @property
    def KeepWithNext(self):
        return self.com_object.KeepWithNext

    @KeepWithNext.setter
    def KeepWithNext(self, value):
        self.com_object.KeepWithNext = value

    @property
    def keepwithnext(self):
        """Alias for KeepWithNext"""
        return self.KeepWithNext

    @keepwithnext.setter
    def keepwithnext(self, value):
        """Alias for KeepWithNext.setter"""
        self.KeepWithNext = value

    @property
    def keep_with_next(self):
        """Alias for KeepWithNext"""
        return self.KeepWithNext

    @keep_with_next.setter
    def keep_with_next(self, value):
        """Alias for KeepWithNext.setter"""
        self.KeepWithNext = value

    @property
    def LeftIndent(self):
        return self.com_object.LeftIndent

    @LeftIndent.setter
    def LeftIndent(self, value):
        self.com_object.LeftIndent = value

    @property
    def leftindent(self):
        """Alias for LeftIndent"""
        return self.LeftIndent

    @leftindent.setter
    def leftindent(self, value):
        """Alias for LeftIndent.setter"""
        self.LeftIndent = value

    @property
    def left_indent(self):
        """Alias for LeftIndent"""
        return self.LeftIndent

    @left_indent.setter
    def left_indent(self, value):
        """Alias for LeftIndent.setter"""
        self.LeftIndent = value

    @property
    def LineSpacing(self):
        return self.com_object.LineSpacing

    @LineSpacing.setter
    def LineSpacing(self, value):
        self.com_object.LineSpacing = value

    @property
    def linespacing(self):
        """Alias for LineSpacing"""
        return self.LineSpacing

    @linespacing.setter
    def linespacing(self, value):
        """Alias for LineSpacing.setter"""
        self.LineSpacing = value

    @property
    def line_spacing(self):
        """Alias for LineSpacing"""
        return self.LineSpacing

    @line_spacing.setter
    def line_spacing(self, value):
        """Alias for LineSpacing.setter"""
        self.LineSpacing = value

    @property
    def LineSpacingRule(self):
        return WdLineSpacing(self.com_object.LineSpacingRule)

    @LineSpacingRule.setter
    def LineSpacingRule(self, value):
        self.com_object.LineSpacingRule = value

    @property
    def linespacingrule(self):
        """Alias for LineSpacingRule"""
        return self.LineSpacingRule

    @linespacingrule.setter
    def linespacingrule(self, value):
        """Alias for LineSpacingRule.setter"""
        self.LineSpacingRule = value

    @property
    def line_spacing_rule(self):
        """Alias for LineSpacingRule"""
        return self.LineSpacingRule

    @line_spacing_rule.setter
    def line_spacing_rule(self, value):
        """Alias for LineSpacingRule.setter"""
        self.LineSpacingRule = value

    @property
    def LineUnitAfter(self):
        return self.com_object.LineUnitAfter

    @LineUnitAfter.setter
    def LineUnitAfter(self, value):
        self.com_object.LineUnitAfter = value

    @property
    def lineunitafter(self):
        """Alias for LineUnitAfter"""
        return self.LineUnitAfter

    @lineunitafter.setter
    def lineunitafter(self, value):
        """Alias for LineUnitAfter.setter"""
        self.LineUnitAfter = value

    @property
    def line_unit_after(self):
        """Alias for LineUnitAfter"""
        return self.LineUnitAfter

    @line_unit_after.setter
    def line_unit_after(self, value):
        """Alias for LineUnitAfter.setter"""
        self.LineUnitAfter = value

    @property
    def LineUnitBefore(self):
        return self.com_object.LineUnitBefore

    @LineUnitBefore.setter
    def LineUnitBefore(self, value):
        self.com_object.LineUnitBefore = value

    @property
    def lineunitbefore(self):
        """Alias for LineUnitBefore"""
        return self.LineUnitBefore

    @lineunitbefore.setter
    def lineunitbefore(self, value):
        """Alias for LineUnitBefore.setter"""
        self.LineUnitBefore = value

    @property
    def line_unit_before(self):
        """Alias for LineUnitBefore"""
        return self.LineUnitBefore

    @line_unit_before.setter
    def line_unit_before(self, value):
        """Alias for LineUnitBefore.setter"""
        self.LineUnitBefore = value

    @property
    def MirrorIndents(self):
        return self.com_object.MirrorIndents

    @MirrorIndents.setter
    def MirrorIndents(self, value):
        self.com_object.MirrorIndents = value

    @property
    def mirrorindents(self):
        """Alias for MirrorIndents"""
        return self.MirrorIndents

    @mirrorindents.setter
    def mirrorindents(self, value):
        """Alias for MirrorIndents.setter"""
        self.MirrorIndents = value

    @property
    def mirror_indents(self):
        """Alias for MirrorIndents"""
        return self.MirrorIndents

    @mirror_indents.setter
    def mirror_indents(self, value):
        """Alias for MirrorIndents.setter"""
        self.MirrorIndents = value

    @property
    def NoLineNumber(self):
        return self.com_object.NoLineNumber

    @NoLineNumber.setter
    def NoLineNumber(self, value):
        self.com_object.NoLineNumber = value

    @property
    def nolinenumber(self):
        """Alias for NoLineNumber"""
        return self.NoLineNumber

    @nolinenumber.setter
    def nolinenumber(self, value):
        """Alias for NoLineNumber.setter"""
        self.NoLineNumber = value

    @property
    def no_line_number(self):
        """Alias for NoLineNumber"""
        return self.NoLineNumber

    @no_line_number.setter
    def no_line_number(self, value):
        """Alias for NoLineNumber.setter"""
        self.NoLineNumber = value

    @property
    def OutlineLevel(self):
        return WdOutlineLevel(self.com_object.OutlineLevel)

    @OutlineLevel.setter
    def OutlineLevel(self, value):
        self.com_object.OutlineLevel = value

    @property
    def outlinelevel(self):
        """Alias for OutlineLevel"""
        return self.OutlineLevel

    @outlinelevel.setter
    def outlinelevel(self, value):
        """Alias for OutlineLevel.setter"""
        self.OutlineLevel = value

    @property
    def outline_level(self):
        """Alias for OutlineLevel"""
        return self.OutlineLevel

    @outline_level.setter
    def outline_level(self, value):
        """Alias for OutlineLevel.setter"""
        self.OutlineLevel = value

    @property
    def PageBreakBefore(self):
        return self.com_object.PageBreakBefore

    @PageBreakBefore.setter
    def PageBreakBefore(self, value):
        self.com_object.PageBreakBefore = value

    @property
    def pagebreakbefore(self):
        """Alias for PageBreakBefore"""
        return self.PageBreakBefore

    @pagebreakbefore.setter
    def pagebreakbefore(self, value):
        """Alias for PageBreakBefore.setter"""
        self.PageBreakBefore = value

    @property
    def page_break_before(self):
        """Alias for PageBreakBefore"""
        return self.PageBreakBefore

    @page_break_before.setter
    def page_break_before(self, value):
        """Alias for PageBreakBefore.setter"""
        self.PageBreakBefore = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ReadingOrder(self):
        return WdReadingOrder(self.com_object.ReadingOrder)

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def RightIndent(self):
        return self.com_object.RightIndent

    @RightIndent.setter
    def RightIndent(self, value):
        self.com_object.RightIndent = value

    @property
    def rightindent(self):
        """Alias for RightIndent"""
        return self.RightIndent

    @rightindent.setter
    def rightindent(self, value):
        """Alias for RightIndent.setter"""
        self.RightIndent = value

    @property
    def right_indent(self):
        """Alias for RightIndent"""
        return self.RightIndent

    @right_indent.setter
    def right_indent(self, value):
        """Alias for RightIndent.setter"""
        self.RightIndent = value

    @property
    def Shading(self):
        return Shading(self.com_object.Shading)

    @property
    def shading(self):
        """Alias for Shading"""
        return self.Shading

    @property
    def SpaceAfter(self):
        return self.com_object.SpaceAfter

    @SpaceAfter.setter
    def SpaceAfter(self, value):
        self.com_object.SpaceAfter = value

    @property
    def spaceafter(self):
        """Alias for SpaceAfter"""
        return self.SpaceAfter

    @spaceafter.setter
    def spaceafter(self, value):
        """Alias for SpaceAfter.setter"""
        self.SpaceAfter = value

    @property
    def space_after(self):
        """Alias for SpaceAfter"""
        return self.SpaceAfter

    @space_after.setter
    def space_after(self, value):
        """Alias for SpaceAfter.setter"""
        self.SpaceAfter = value

    @property
    def SpaceAfterAuto(self):
        return self.com_object.SpaceAfterAuto

    @SpaceAfterAuto.setter
    def SpaceAfterAuto(self, value):
        self.com_object.SpaceAfterAuto = value

    @property
    def spaceafterauto(self):
        """Alias for SpaceAfterAuto"""
        return self.SpaceAfterAuto

    @spaceafterauto.setter
    def spaceafterauto(self, value):
        """Alias for SpaceAfterAuto.setter"""
        self.SpaceAfterAuto = value

    @property
    def space_after_auto(self):
        """Alias for SpaceAfterAuto"""
        return self.SpaceAfterAuto

    @space_after_auto.setter
    def space_after_auto(self, value):
        """Alias for SpaceAfterAuto.setter"""
        self.SpaceAfterAuto = value

    @property
    def SpaceBefore(self):
        return self.com_object.SpaceBefore

    @SpaceBefore.setter
    def SpaceBefore(self, value):
        self.com_object.SpaceBefore = value

    @property
    def spacebefore(self):
        """Alias for SpaceBefore"""
        return self.SpaceBefore

    @spacebefore.setter
    def spacebefore(self, value):
        """Alias for SpaceBefore.setter"""
        self.SpaceBefore = value

    @property
    def space_before(self):
        """Alias for SpaceBefore"""
        return self.SpaceBefore

    @space_before.setter
    def space_before(self, value):
        """Alias for SpaceBefore.setter"""
        self.SpaceBefore = value

    @property
    def SpaceBeforeAuto(self):
        return self.com_object.SpaceBeforeAuto

    @SpaceBeforeAuto.setter
    def SpaceBeforeAuto(self, value):
        self.com_object.SpaceBeforeAuto = value

    @property
    def spacebeforeauto(self):
        """Alias for SpaceBeforeAuto"""
        return self.SpaceBeforeAuto

    @spacebeforeauto.setter
    def spacebeforeauto(self, value):
        """Alias for SpaceBeforeAuto.setter"""
        self.SpaceBeforeAuto = value

    @property
    def space_before_auto(self):
        """Alias for SpaceBeforeAuto"""
        return self.SpaceBeforeAuto

    @space_before_auto.setter
    def space_before_auto(self, value):
        """Alias for SpaceBeforeAuto.setter"""
        self.SpaceBeforeAuto = value

    @property
    def Style(self):
        return self.com_object.Style

    @Style.setter
    def Style(self, value):
        self.com_object.Style = value

    @property
    def style(self):
        """Alias for Style"""
        return self.Style

    @style.setter
    def style(self, value):
        """Alias for Style.setter"""
        self.Style = value

    @property
    def TabStops(self):
        return TabStops(self.com_object.TabStops)

    @TabStops.setter
    def TabStops(self, value):
        self.com_object.TabStops = value

    @property
    def tabstops(self):
        """Alias for TabStops"""
        return self.TabStops

    @tabstops.setter
    def tabstops(self, value):
        """Alias for TabStops.setter"""
        self.TabStops = value

    @property
    def tab_stops(self):
        """Alias for TabStops"""
        return self.TabStops

    @tab_stops.setter
    def tab_stops(self, value):
        """Alias for TabStops.setter"""
        self.TabStops = value

    @property
    def TextboxTightWrap(self):
        return WdTextboxTightWrap(self.com_object.TextboxTightWrap)

    @TextboxTightWrap.setter
    def TextboxTightWrap(self, value):
        self.com_object.TextboxTightWrap = value

    @property
    def textboxtightwrap(self):
        """Alias for TextboxTightWrap"""
        return self.TextboxTightWrap

    @textboxtightwrap.setter
    def textboxtightwrap(self, value):
        """Alias for TextboxTightWrap.setter"""
        self.TextboxTightWrap = value

    @property
    def textbox_tight_wrap(self):
        """Alias for TextboxTightWrap"""
        return self.TextboxTightWrap

    @textbox_tight_wrap.setter
    def textbox_tight_wrap(self, value):
        """Alias for TextboxTightWrap.setter"""
        self.TextboxTightWrap = value

    @property
    def WidowControl(self):
        return self.com_object.WidowControl

    @WidowControl.setter
    def WidowControl(self, value):
        self.com_object.WidowControl = value

    @property
    def widowcontrol(self):
        """Alias for WidowControl"""
        return self.WidowControl

    @widowcontrol.setter
    def widowcontrol(self, value):
        """Alias for WidowControl.setter"""
        self.WidowControl = value

    @property
    def widow_control(self):
        """Alias for WidowControl"""
        return self.WidowControl

    @widow_control.setter
    def widow_control(self, value):
        """Alias for WidowControl.setter"""
        self.WidowControl = value

    @property
    def WordWrap(self):
        return self.com_object.WordWrap

    @WordWrap.setter
    def WordWrap(self, value):
        self.com_object.WordWrap = value

    @property
    def wordwrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @wordwrap.setter
    def wordwrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value

    @property
    def word_wrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @word_wrap.setter
    def word_wrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value

    def CloseUp(self):
        self.com_object.CloseUp()

    def closeup(self):
        """Alias for CloseUp"""
        return self.CloseUp()

    def close_up(self):
        """Alias for CloseUp"""
        return self.CloseUp()

    def IndentCharWidth(self, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Count]])
        self.com_object.IndentCharWidth(*arguments)

    def indentcharwidth(self, Count=None):
        """Alias for IndentCharWidth"""
        arguments = [Count]
        return self.IndentCharWidth(*arguments)

    def indent_char_width(self, Count=None):
        """Alias for IndentCharWidth"""
        arguments = [Count]
        return self.IndentCharWidth(*arguments)

    def IndentFirstLineCharWidth(self, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Count]])
        self.com_object.IndentFirstLineCharWidth(*arguments)

    def indentfirstlinecharwidth(self, Count=None):
        """Alias for IndentFirstLineCharWidth"""
        arguments = [Count]
        return self.IndentFirstLineCharWidth(*arguments)

    def indent_first_line_char_width(self, Count=None):
        """Alias for IndentFirstLineCharWidth"""
        arguments = [Count]
        return self.IndentFirstLineCharWidth(*arguments)

    def OpenOrCloseUp(self):
        self.com_object.OpenOrCloseUp()

    def openorcloseup(self):
        """Alias for OpenOrCloseUp"""
        return self.OpenOrCloseUp()

    def open_or_close_up(self):
        """Alias for OpenOrCloseUp"""
        return self.OpenOrCloseUp()

    def OpenUp(self):
        self.com_object.OpenUp()

    def openup(self):
        """Alias for OpenUp"""
        return self.OpenUp()

    def open_up(self):
        """Alias for OpenUp"""
        return self.OpenUp()

    def Reset(self):
        self.com_object.Reset()

    def reset(self):
        """Alias for Reset"""
        return self.Reset()

    def Space1(self):
        self.com_object.Space1()

    def space1(self):
        """Alias for Space1"""
        return self.Space1()

    def Space15(self):
        self.com_object.Space15()

    def space15(self):
        """Alias for Space15"""
        return self.Space15()

    def Space2(self):
        self.com_object.Space2()

    def space2(self):
        """Alias for Space2"""
        return self.Space2()

    def TabHangingIndent(self, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Count]])
        self.com_object.TabHangingIndent(*arguments)

    def tabhangingindent(self, Count=None):
        """Alias for TabHangingIndent"""
        arguments = [Count]
        return self.TabHangingIndent(*arguments)

    def tab_hanging_indent(self, Count=None):
        """Alias for TabHangingIndent"""
        arguments = [Count]
        return self.TabHangingIndent(*arguments)

    def TabIndent(self, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Count]])
        self.com_object.TabIndent(*arguments)

    def tabindent(self, Count=None):
        """Alias for TabIndent"""
        arguments = [Count]
        return self.TabIndent(*arguments)

    def tab_indent(self, Count=None):
        """Alias for TabIndent"""
        arguments = [Count]
        return self.TabIndent(*arguments)


class Paragraphs:

    def __init__(self, paragraphs=None):
        self.com_object= paragraphs

    def __call__(self, item):
        return Paragraph(self.com_object(item))

    @property
    def AddSpaceBetweenFarEastAndAlpha(self):
        return self.com_object.AddSpaceBetweenFarEastAndAlpha

    @AddSpaceBetweenFarEastAndAlpha.setter
    def AddSpaceBetweenFarEastAndAlpha(self, value):
        self.com_object.AddSpaceBetweenFarEastAndAlpha = value

    @property
    def addspacebetweenfareastandalpha(self):
        """Alias for AddSpaceBetweenFarEastAndAlpha"""
        return self.AddSpaceBetweenFarEastAndAlpha

    @addspacebetweenfareastandalpha.setter
    def addspacebetweenfareastandalpha(self, value):
        """Alias for AddSpaceBetweenFarEastAndAlpha.setter"""
        self.AddSpaceBetweenFarEastAndAlpha = value

    @property
    def add_space_between_far_east_and_alpha(self):
        """Alias for AddSpaceBetweenFarEastAndAlpha"""
        return self.AddSpaceBetweenFarEastAndAlpha

    @add_space_between_far_east_and_alpha.setter
    def add_space_between_far_east_and_alpha(self, value):
        """Alias for AddSpaceBetweenFarEastAndAlpha.setter"""
        self.AddSpaceBetweenFarEastAndAlpha = value

    @property
    def AddSpaceBetweenFarEastAndDigit(self):
        return self.com_object.AddSpaceBetweenFarEastAndDigit

    @AddSpaceBetweenFarEastAndDigit.setter
    def AddSpaceBetweenFarEastAndDigit(self, value):
        self.com_object.AddSpaceBetweenFarEastAndDigit = value

    @property
    def addspacebetweenfareastanddigit(self):
        """Alias for AddSpaceBetweenFarEastAndDigit"""
        return self.AddSpaceBetweenFarEastAndDigit

    @addspacebetweenfareastanddigit.setter
    def addspacebetweenfareastanddigit(self, value):
        """Alias for AddSpaceBetweenFarEastAndDigit.setter"""
        self.AddSpaceBetweenFarEastAndDigit = value

    @property
    def add_space_between_far_east_and_digit(self):
        """Alias for AddSpaceBetweenFarEastAndDigit"""
        return self.AddSpaceBetweenFarEastAndDigit

    @add_space_between_far_east_and_digit.setter
    def add_space_between_far_east_and_digit(self, value):
        """Alias for AddSpaceBetweenFarEastAndDigit.setter"""
        self.AddSpaceBetweenFarEastAndDigit = value

    @property
    def Alignment(self):
        return WdParagraphAlignment(self.com_object.Alignment)

    @Alignment.setter
    def Alignment(self, value):
        self.com_object.Alignment = value

    @property
    def alignment(self):
        """Alias for Alignment"""
        return self.Alignment

    @alignment.setter
    def alignment(self, value):
        """Alias for Alignment.setter"""
        self.Alignment = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoAdjustRightIndent(self):
        return self.com_object.AutoAdjustRightIndent

    @AutoAdjustRightIndent.setter
    def AutoAdjustRightIndent(self, value):
        self.com_object.AutoAdjustRightIndent = value

    @property
    def autoadjustrightindent(self):
        """Alias for AutoAdjustRightIndent"""
        return self.AutoAdjustRightIndent

    @autoadjustrightindent.setter
    def autoadjustrightindent(self, value):
        """Alias for AutoAdjustRightIndent.setter"""
        self.AutoAdjustRightIndent = value

    @property
    def auto_adjust_right_indent(self):
        """Alias for AutoAdjustRightIndent"""
        return self.AutoAdjustRightIndent

    @auto_adjust_right_indent.setter
    def auto_adjust_right_indent(self, value):
        """Alias for AutoAdjustRightIndent.setter"""
        self.AutoAdjustRightIndent = value

    @property
    def BaseLineAlignment(self):
        return WdBaselineAlignment(self.com_object.BaseLineAlignment)

    @BaseLineAlignment.setter
    def BaseLineAlignment(self, value):
        self.com_object.BaseLineAlignment = value

    @property
    def baselinealignment(self):
        """Alias for BaseLineAlignment"""
        return self.BaseLineAlignment

    @baselinealignment.setter
    def baselinealignment(self, value):
        """Alias for BaseLineAlignment.setter"""
        self.BaseLineAlignment = value

    @property
    def base_line_alignment(self):
        """Alias for BaseLineAlignment"""
        return self.BaseLineAlignment

    @base_line_alignment.setter
    def base_line_alignment(self, value):
        """Alias for BaseLineAlignment.setter"""
        self.BaseLineAlignment = value

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def CharacterUnitFirstLineIndent(self):
        return self.com_object.CharacterUnitFirstLineIndent

    @CharacterUnitFirstLineIndent.setter
    def CharacterUnitFirstLineIndent(self, value):
        self.com_object.CharacterUnitFirstLineIndent = value

    @property
    def characterunitfirstlineindent(self):
        """Alias for CharacterUnitFirstLineIndent"""
        return self.CharacterUnitFirstLineIndent

    @characterunitfirstlineindent.setter
    def characterunitfirstlineindent(self, value):
        """Alias for CharacterUnitFirstLineIndent.setter"""
        self.CharacterUnitFirstLineIndent = value

    @property
    def character_unit_first_line_indent(self):
        """Alias for CharacterUnitFirstLineIndent"""
        return self.CharacterUnitFirstLineIndent

    @character_unit_first_line_indent.setter
    def character_unit_first_line_indent(self, value):
        """Alias for CharacterUnitFirstLineIndent.setter"""
        self.CharacterUnitFirstLineIndent = value

    @property
    def CharacterUnitLeftIndent(self):
        return self.com_object.CharacterUnitLeftIndent

    @CharacterUnitLeftIndent.setter
    def CharacterUnitLeftIndent(self, value):
        self.com_object.CharacterUnitLeftIndent = value

    @property
    def characterunitleftindent(self):
        """Alias for CharacterUnitLeftIndent"""
        return self.CharacterUnitLeftIndent

    @characterunitleftindent.setter
    def characterunitleftindent(self, value):
        """Alias for CharacterUnitLeftIndent.setter"""
        self.CharacterUnitLeftIndent = value

    @property
    def character_unit_left_indent(self):
        """Alias for CharacterUnitLeftIndent"""
        return self.CharacterUnitLeftIndent

    @character_unit_left_indent.setter
    def character_unit_left_indent(self, value):
        """Alias for CharacterUnitLeftIndent.setter"""
        self.CharacterUnitLeftIndent = value

    @property
    def CharacterUnitRightIndent(self):
        return self.com_object.CharacterUnitRightIndent

    @CharacterUnitRightIndent.setter
    def CharacterUnitRightIndent(self, value):
        self.com_object.CharacterUnitRightIndent = value

    @property
    def characterunitrightindent(self):
        """Alias for CharacterUnitRightIndent"""
        return self.CharacterUnitRightIndent

    @characterunitrightindent.setter
    def characterunitrightindent(self, value):
        """Alias for CharacterUnitRightIndent.setter"""
        self.CharacterUnitRightIndent = value

    @property
    def character_unit_right_indent(self):
        """Alias for CharacterUnitRightIndent"""
        return self.CharacterUnitRightIndent

    @character_unit_right_indent.setter
    def character_unit_right_indent(self, value):
        """Alias for CharacterUnitRightIndent.setter"""
        self.CharacterUnitRightIndent = value

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DisableLineHeightGrid(self):
        return self.com_object.DisableLineHeightGrid

    @DisableLineHeightGrid.setter
    def DisableLineHeightGrid(self, value):
        self.com_object.DisableLineHeightGrid = value

    @property
    def disablelineheightgrid(self):
        """Alias for DisableLineHeightGrid"""
        return self.DisableLineHeightGrid

    @disablelineheightgrid.setter
    def disablelineheightgrid(self, value):
        """Alias for DisableLineHeightGrid.setter"""
        self.DisableLineHeightGrid = value

    @property
    def disable_line_height_grid(self):
        """Alias for DisableLineHeightGrid"""
        return self.DisableLineHeightGrid

    @disable_line_height_grid.setter
    def disable_line_height_grid(self, value):
        """Alias for DisableLineHeightGrid.setter"""
        self.DisableLineHeightGrid = value

    @property
    def FarEastLineBreakControl(self):
        return self.com_object.FarEastLineBreakControl

    @FarEastLineBreakControl.setter
    def FarEastLineBreakControl(self, value):
        self.com_object.FarEastLineBreakControl = value

    @property
    def fareastlinebreakcontrol(self):
        """Alias for FarEastLineBreakControl"""
        return self.FarEastLineBreakControl

    @fareastlinebreakcontrol.setter
    def fareastlinebreakcontrol(self, value):
        """Alias for FarEastLineBreakControl.setter"""
        self.FarEastLineBreakControl = value

    @property
    def far_east_line_break_control(self):
        """Alias for FarEastLineBreakControl"""
        return self.FarEastLineBreakControl

    @far_east_line_break_control.setter
    def far_east_line_break_control(self, value):
        """Alias for FarEastLineBreakControl.setter"""
        self.FarEastLineBreakControl = value

    @property
    def First(self):
        return Paragraph(self.com_object.First)

    @property
    def first(self):
        """Alias for First"""
        return self.First

    @property
    def FirstLineIndent(self):
        return self.com_object.FirstLineIndent

    @FirstLineIndent.setter
    def FirstLineIndent(self, value):
        self.com_object.FirstLineIndent = value

    @property
    def firstlineindent(self):
        """Alias for FirstLineIndent"""
        return self.FirstLineIndent

    @firstlineindent.setter
    def firstlineindent(self, value):
        """Alias for FirstLineIndent.setter"""
        self.FirstLineIndent = value

    @property
    def first_line_indent(self):
        """Alias for FirstLineIndent"""
        return self.FirstLineIndent

    @first_line_indent.setter
    def first_line_indent(self, value):
        """Alias for FirstLineIndent.setter"""
        self.FirstLineIndent = value

    @property
    def Format(self):
        return ParagraphFormat(self.com_object.Format)

    @Format.setter
    def Format(self, value):
        self.com_object.Format = value

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @format.setter
    def format(self, value):
        """Alias for Format.setter"""
        self.Format = value

    @property
    def HalfWidthPunctuationOnTopOfLine(self):
        return self.com_object.HalfWidthPunctuationOnTopOfLine

    @HalfWidthPunctuationOnTopOfLine.setter
    def HalfWidthPunctuationOnTopOfLine(self, value):
        self.com_object.HalfWidthPunctuationOnTopOfLine = value

    @property
    def halfwidthpunctuationontopofline(self):
        """Alias for HalfWidthPunctuationOnTopOfLine"""
        return self.HalfWidthPunctuationOnTopOfLine

    @halfwidthpunctuationontopofline.setter
    def halfwidthpunctuationontopofline(self, value):
        """Alias for HalfWidthPunctuationOnTopOfLine.setter"""
        self.HalfWidthPunctuationOnTopOfLine = value

    @property
    def half_width_punctuation_on_top_of_line(self):
        """Alias for HalfWidthPunctuationOnTopOfLine"""
        return self.HalfWidthPunctuationOnTopOfLine

    @half_width_punctuation_on_top_of_line.setter
    def half_width_punctuation_on_top_of_line(self, value):
        """Alias for HalfWidthPunctuationOnTopOfLine.setter"""
        self.HalfWidthPunctuationOnTopOfLine = value

    @property
    def HangingPunctuation(self):
        return self.com_object.HangingPunctuation

    @HangingPunctuation.setter
    def HangingPunctuation(self, value):
        self.com_object.HangingPunctuation = value

    @property
    def hangingpunctuation(self):
        """Alias for HangingPunctuation"""
        return self.HangingPunctuation

    @hangingpunctuation.setter
    def hangingpunctuation(self, value):
        """Alias for HangingPunctuation.setter"""
        self.HangingPunctuation = value

    @property
    def hanging_punctuation(self):
        """Alias for HangingPunctuation"""
        return self.HangingPunctuation

    @hanging_punctuation.setter
    def hanging_punctuation(self, value):
        """Alias for HangingPunctuation.setter"""
        self.HangingPunctuation = value

    @property
    def Hyphenation(self):
        return self.com_object.Hyphenation

    @Hyphenation.setter
    def Hyphenation(self, value):
        self.com_object.Hyphenation = value

    @property
    def hyphenation(self):
        """Alias for Hyphenation"""
        return self.Hyphenation

    @hyphenation.setter
    def hyphenation(self, value):
        """Alias for Hyphenation.setter"""
        self.Hyphenation = value

    @property
    def KeepTogether(self):
        return self.com_object.KeepTogether

    @KeepTogether.setter
    def KeepTogether(self, value):
        self.com_object.KeepTogether = value

    @property
    def keeptogether(self):
        """Alias for KeepTogether"""
        return self.KeepTogether

    @keeptogether.setter
    def keeptogether(self, value):
        """Alias for KeepTogether.setter"""
        self.KeepTogether = value

    @property
    def keep_together(self):
        """Alias for KeepTogether"""
        return self.KeepTogether

    @keep_together.setter
    def keep_together(self, value):
        """Alias for KeepTogether.setter"""
        self.KeepTogether = value

    @property
    def KeepWithNext(self):
        return self.com_object.KeepWithNext

    @KeepWithNext.setter
    def KeepWithNext(self, value):
        self.com_object.KeepWithNext = value

    @property
    def keepwithnext(self):
        """Alias for KeepWithNext"""
        return self.KeepWithNext

    @keepwithnext.setter
    def keepwithnext(self, value):
        """Alias for KeepWithNext.setter"""
        self.KeepWithNext = value

    @property
    def keep_with_next(self):
        """Alias for KeepWithNext"""
        return self.KeepWithNext

    @keep_with_next.setter
    def keep_with_next(self, value):
        """Alias for KeepWithNext.setter"""
        self.KeepWithNext = value

    @property
    def Last(self):
        return Paragraph(self.com_object.Last)

    @property
    def last(self):
        """Alias for Last"""
        return self.Last

    @property
    def LeftIndent(self):
        return self.com_object.LeftIndent

    @LeftIndent.setter
    def LeftIndent(self, value):
        self.com_object.LeftIndent = value

    @property
    def leftindent(self):
        """Alias for LeftIndent"""
        return self.LeftIndent

    @leftindent.setter
    def leftindent(self, value):
        """Alias for LeftIndent.setter"""
        self.LeftIndent = value

    @property
    def left_indent(self):
        """Alias for LeftIndent"""
        return self.LeftIndent

    @left_indent.setter
    def left_indent(self, value):
        """Alias for LeftIndent.setter"""
        self.LeftIndent = value

    @property
    def LineSpacing(self):
        return self.com_object.LineSpacing

    @LineSpacing.setter
    def LineSpacing(self, value):
        self.com_object.LineSpacing = value

    @property
    def linespacing(self):
        """Alias for LineSpacing"""
        return self.LineSpacing

    @linespacing.setter
    def linespacing(self, value):
        """Alias for LineSpacing.setter"""
        self.LineSpacing = value

    @property
    def line_spacing(self):
        """Alias for LineSpacing"""
        return self.LineSpacing

    @line_spacing.setter
    def line_spacing(self, value):
        """Alias for LineSpacing.setter"""
        self.LineSpacing = value

    @property
    def LineSpacingRule(self):
        return WdLineSpacing(self.com_object.LineSpacingRule)

    @LineSpacingRule.setter
    def LineSpacingRule(self, value):
        self.com_object.LineSpacingRule = value

    @property
    def linespacingrule(self):
        """Alias for LineSpacingRule"""
        return self.LineSpacingRule

    @linespacingrule.setter
    def linespacingrule(self, value):
        """Alias for LineSpacingRule.setter"""
        self.LineSpacingRule = value

    @property
    def line_spacing_rule(self):
        """Alias for LineSpacingRule"""
        return self.LineSpacingRule

    @line_spacing_rule.setter
    def line_spacing_rule(self, value):
        """Alias for LineSpacingRule.setter"""
        self.LineSpacingRule = value

    @property
    def LineUnitAfter(self):
        return self.com_object.LineUnitAfter

    @LineUnitAfter.setter
    def LineUnitAfter(self, value):
        self.com_object.LineUnitAfter = value

    @property
    def lineunitafter(self):
        """Alias for LineUnitAfter"""
        return self.LineUnitAfter

    @lineunitafter.setter
    def lineunitafter(self, value):
        """Alias for LineUnitAfter.setter"""
        self.LineUnitAfter = value

    @property
    def line_unit_after(self):
        """Alias for LineUnitAfter"""
        return self.LineUnitAfter

    @line_unit_after.setter
    def line_unit_after(self, value):
        """Alias for LineUnitAfter.setter"""
        self.LineUnitAfter = value

    @property
    def LineUnitBefore(self):
        return self.com_object.LineUnitBefore

    @LineUnitBefore.setter
    def LineUnitBefore(self, value):
        self.com_object.LineUnitBefore = value

    @property
    def lineunitbefore(self):
        """Alias for LineUnitBefore"""
        return self.LineUnitBefore

    @lineunitbefore.setter
    def lineunitbefore(self, value):
        """Alias for LineUnitBefore.setter"""
        self.LineUnitBefore = value

    @property
    def line_unit_before(self):
        """Alias for LineUnitBefore"""
        return self.LineUnitBefore

    @line_unit_before.setter
    def line_unit_before(self, value):
        """Alias for LineUnitBefore.setter"""
        self.LineUnitBefore = value

    @property
    def NoLineNumber(self):
        return self.com_object.NoLineNumber

    @NoLineNumber.setter
    def NoLineNumber(self, value):
        self.com_object.NoLineNumber = value

    @property
    def nolinenumber(self):
        """Alias for NoLineNumber"""
        return self.NoLineNumber

    @nolinenumber.setter
    def nolinenumber(self, value):
        """Alias for NoLineNumber.setter"""
        self.NoLineNumber = value

    @property
    def no_line_number(self):
        """Alias for NoLineNumber"""
        return self.NoLineNumber

    @no_line_number.setter
    def no_line_number(self, value):
        """Alias for NoLineNumber.setter"""
        self.NoLineNumber = value

    @property
    def OutlineLevel(self):
        return WdOutlineLevel(self.com_object.OutlineLevel)

    @OutlineLevel.setter
    def OutlineLevel(self, value):
        self.com_object.OutlineLevel = value

    @property
    def outlinelevel(self):
        """Alias for OutlineLevel"""
        return self.OutlineLevel

    @outlinelevel.setter
    def outlinelevel(self, value):
        """Alias for OutlineLevel.setter"""
        self.OutlineLevel = value

    @property
    def outline_level(self):
        """Alias for OutlineLevel"""
        return self.OutlineLevel

    @outline_level.setter
    def outline_level(self, value):
        """Alias for OutlineLevel.setter"""
        self.OutlineLevel = value

    @property
    def PageBreakBefore(self):
        return self.com_object.PageBreakBefore

    @PageBreakBefore.setter
    def PageBreakBefore(self, value):
        self.com_object.PageBreakBefore = value

    @property
    def pagebreakbefore(self):
        """Alias for PageBreakBefore"""
        return self.PageBreakBefore

    @pagebreakbefore.setter
    def pagebreakbefore(self, value):
        """Alias for PageBreakBefore.setter"""
        self.PageBreakBefore = value

    @property
    def page_break_before(self):
        """Alias for PageBreakBefore"""
        return self.PageBreakBefore

    @page_break_before.setter
    def page_break_before(self, value):
        """Alias for PageBreakBefore.setter"""
        self.PageBreakBefore = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ReadingOrder(self):
        return WdReadingOrder(self.com_object.ReadingOrder)

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def RightIndent(self):
        return self.com_object.RightIndent

    @RightIndent.setter
    def RightIndent(self, value):
        self.com_object.RightIndent = value

    @property
    def rightindent(self):
        """Alias for RightIndent"""
        return self.RightIndent

    @rightindent.setter
    def rightindent(self, value):
        """Alias for RightIndent.setter"""
        self.RightIndent = value

    @property
    def right_indent(self):
        """Alias for RightIndent"""
        return self.RightIndent

    @right_indent.setter
    def right_indent(self, value):
        """Alias for RightIndent.setter"""
        self.RightIndent = value

    @property
    def Shading(self):
        return Shading(self.com_object.Shading)

    @property
    def shading(self):
        """Alias for Shading"""
        return self.Shading

    @property
    def SpaceAfter(self):
        return self.com_object.SpaceAfter

    @SpaceAfter.setter
    def SpaceAfter(self, value):
        self.com_object.SpaceAfter = value

    @property
    def spaceafter(self):
        """Alias for SpaceAfter"""
        return self.SpaceAfter

    @spaceafter.setter
    def spaceafter(self, value):
        """Alias for SpaceAfter.setter"""
        self.SpaceAfter = value

    @property
    def space_after(self):
        """Alias for SpaceAfter"""
        return self.SpaceAfter

    @space_after.setter
    def space_after(self, value):
        """Alias for SpaceAfter.setter"""
        self.SpaceAfter = value

    @property
    def SpaceAfterAuto(self):
        return self.com_object.SpaceAfterAuto

    @SpaceAfterAuto.setter
    def SpaceAfterAuto(self, value):
        self.com_object.SpaceAfterAuto = value

    @property
    def spaceafterauto(self):
        """Alias for SpaceAfterAuto"""
        return self.SpaceAfterAuto

    @spaceafterauto.setter
    def spaceafterauto(self, value):
        """Alias for SpaceAfterAuto.setter"""
        self.SpaceAfterAuto = value

    @property
    def space_after_auto(self):
        """Alias for SpaceAfterAuto"""
        return self.SpaceAfterAuto

    @space_after_auto.setter
    def space_after_auto(self, value):
        """Alias for SpaceAfterAuto.setter"""
        self.SpaceAfterAuto = value

    @property
    def SpaceBefore(self):
        return self.com_object.SpaceBefore

    @SpaceBefore.setter
    def SpaceBefore(self, value):
        self.com_object.SpaceBefore = value

    @property
    def spacebefore(self):
        """Alias for SpaceBefore"""
        return self.SpaceBefore

    @spacebefore.setter
    def spacebefore(self, value):
        """Alias for SpaceBefore.setter"""
        self.SpaceBefore = value

    @property
    def space_before(self):
        """Alias for SpaceBefore"""
        return self.SpaceBefore

    @space_before.setter
    def space_before(self, value):
        """Alias for SpaceBefore.setter"""
        self.SpaceBefore = value

    @property
    def SpaceBeforeAuto(self):
        return self.com_object.SpaceBeforeAuto

    @SpaceBeforeAuto.setter
    def SpaceBeforeAuto(self, value):
        self.com_object.SpaceBeforeAuto = value

    @property
    def spacebeforeauto(self):
        """Alias for SpaceBeforeAuto"""
        return self.SpaceBeforeAuto

    @spacebeforeauto.setter
    def spacebeforeauto(self, value):
        """Alias for SpaceBeforeAuto.setter"""
        self.SpaceBeforeAuto = value

    @property
    def space_before_auto(self):
        """Alias for SpaceBeforeAuto"""
        return self.SpaceBeforeAuto

    @space_before_auto.setter
    def space_before_auto(self, value):
        """Alias for SpaceBeforeAuto.setter"""
        self.SpaceBeforeAuto = value

    @property
    def Style(self):
        return self.com_object.Style

    @Style.setter
    def Style(self, value):
        self.com_object.Style = value

    @property
    def style(self):
        """Alias for Style"""
        return self.Style

    @style.setter
    def style(self, value):
        """Alias for Style.setter"""
        self.Style = value

    @property
    def TabStops(self):
        return TabStops(self.com_object.TabStops)

    @TabStops.setter
    def TabStops(self, value):
        self.com_object.TabStops = value

    @property
    def tabstops(self):
        """Alias for TabStops"""
        return self.TabStops

    @tabstops.setter
    def tabstops(self, value):
        """Alias for TabStops.setter"""
        self.TabStops = value

    @property
    def tab_stops(self):
        """Alias for TabStops"""
        return self.TabStops

    @tab_stops.setter
    def tab_stops(self, value):
        """Alias for TabStops.setter"""
        self.TabStops = value

    @property
    def WidowControl(self):
        return self.com_object.WidowControl

    @WidowControl.setter
    def WidowControl(self, value):
        self.com_object.WidowControl = value

    @property
    def widowcontrol(self):
        """Alias for WidowControl"""
        return self.WidowControl

    @widowcontrol.setter
    def widowcontrol(self, value):
        """Alias for WidowControl.setter"""
        self.WidowControl = value

    @property
    def widow_control(self):
        """Alias for WidowControl"""
        return self.WidowControl

    @widow_control.setter
    def widow_control(self, value):
        """Alias for WidowControl.setter"""
        self.WidowControl = value

    @property
    def WordWrap(self):
        return self.com_object.WordWrap

    @WordWrap.setter
    def WordWrap(self, value):
        self.com_object.WordWrap = value

    @property
    def wordwrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @wordwrap.setter
    def wordwrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value

    @property
    def word_wrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @word_wrap.setter
    def word_wrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value

    def Add(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        return Paragraph(self.com_object.Add(*arguments))

    def add(self, Range=None):
        """Alias for Add"""
        arguments = [Range]
        return self.Add(*arguments)

    def CloseUp(self):
        self.com_object.CloseUp()

    def closeup(self):
        """Alias for CloseUp"""
        return self.CloseUp()

    def close_up(self):
        """Alias for CloseUp"""
        return self.CloseUp()

    def DecreaseSpacing(self):
        self.com_object.DecreaseSpacing()

    def decreasespacing(self):
        """Alias for DecreaseSpacing"""
        return self.DecreaseSpacing()

    def decrease_spacing(self):
        """Alias for DecreaseSpacing"""
        return self.DecreaseSpacing()

    def IncreaseSpacing(self):
        self.com_object.IncreaseSpacing()

    def increasespacing(self):
        """Alias for IncreaseSpacing"""
        return self.IncreaseSpacing()

    def increase_spacing(self):
        """Alias for IncreaseSpacing"""
        return self.IncreaseSpacing()

    def Indent(self):
        self.com_object.Indent()

    def indent(self):
        """Alias for Indent"""
        return self.Indent()

    def IndentCharWidth(self, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Count]])
        self.com_object.IndentCharWidth(*arguments)

    def indentcharwidth(self, Count=None):
        """Alias for IndentCharWidth"""
        arguments = [Count]
        return self.IndentCharWidth(*arguments)

    def indent_char_width(self, Count=None):
        """Alias for IndentCharWidth"""
        arguments = [Count]
        return self.IndentCharWidth(*arguments)

    def IndentFirstLineCharWidth(self, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Count]])
        self.com_object.IndentFirstLineCharWidth(*arguments)

    def indentfirstlinecharwidth(self, Count=None):
        """Alias for IndentFirstLineCharWidth"""
        arguments = [Count]
        return self.IndentFirstLineCharWidth(*arguments)

    def indent_first_line_char_width(self, Count=None):
        """Alias for IndentFirstLineCharWidth"""
        arguments = [Count]
        return self.IndentFirstLineCharWidth(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Paragraph(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def OpenOrCloseUp(self):
        self.com_object.OpenOrCloseUp()

    def openorcloseup(self):
        """Alias for OpenOrCloseUp"""
        return self.OpenOrCloseUp()

    def open_or_close_up(self):
        """Alias for OpenOrCloseUp"""
        return self.OpenOrCloseUp()

    def OpenUp(self):
        self.com_object.OpenUp()

    def openup(self):
        """Alias for OpenUp"""
        return self.OpenUp()

    def open_up(self):
        """Alias for OpenUp"""
        return self.OpenUp()

    def Outdent(self):
        self.com_object.Outdent()

    def outdent(self):
        """Alias for Outdent"""
        return self.Outdent()

    def OutlineDemote(self):
        self.com_object.OutlineDemote()

    def outlinedemote(self):
        """Alias for OutlineDemote"""
        return self.OutlineDemote()

    def outline_demote(self):
        """Alias for OutlineDemote"""
        return self.OutlineDemote()

    def OutlineDemoteToBody(self):
        self.com_object.OutlineDemoteToBody()

    def outlinedemotetobody(self):
        """Alias for OutlineDemoteToBody"""
        return self.OutlineDemoteToBody()

    def outline_demote_to_body(self):
        """Alias for OutlineDemoteToBody"""
        return self.OutlineDemoteToBody()

    def OutlinePromote(self):
        self.com_object.OutlinePromote()

    def outlinepromote(self):
        """Alias for OutlinePromote"""
        return self.OutlinePromote()

    def outline_promote(self):
        """Alias for OutlinePromote"""
        return self.OutlinePromote()

    def Reset(self):
        self.com_object.Reset()

    def reset(self):
        """Alias for Reset"""
        return self.Reset()

    def Space1(self):
        self.com_object.Space1()

    def space1(self):
        """Alias for Space1"""
        return self.Space1()

    def Space15(self):
        self.com_object.Space15()

    def space15(self):
        """Alias for Space15"""
        return self.Space15()

    def Space2(self):
        self.com_object.Space2()

    def space2(self):
        """Alias for Space2"""
        return self.Space2()

    def TabHangingIndent(self, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Count]])
        self.com_object.TabHangingIndent(*arguments)

    def tabhangingindent(self, Count=None):
        """Alias for TabHangingIndent"""
        arguments = [Count]
        return self.TabHangingIndent(*arguments)

    def tab_hanging_indent(self, Count=None):
        """Alias for TabHangingIndent"""
        arguments = [Count]
        return self.TabHangingIndent(*arguments)

    def TabIndent(self, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Count]])
        self.com_object.TabIndent(*arguments)

    def tabindent(self, Count=None):
        """Alias for TabIndent"""
        arguments = [Count]
        return self.TabIndent(*arguments)

    def tab_indent(self, Count=None):
        """Alias for TabIndent"""
        arguments = [Count]
        return self.TabIndent(*arguments)


class PictureFormat:

    def __init__(self, pictureformat=None):
        self.com_object= pictureformat

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Brightness(self):
        return self.com_object.Brightness

    @Brightness.setter
    def Brightness(self, value):
        self.com_object.Brightness = value

    @property
    def brightness(self):
        """Alias for Brightness"""
        return self.Brightness

    @brightness.setter
    def brightness(self, value):
        """Alias for Brightness.setter"""
        self.Brightness = value

    @property
    def ColorType(self):
        return self.com_object.ColorType

    @ColorType.setter
    def ColorType(self, value):
        self.com_object.ColorType = value

    @property
    def colortype(self):
        """Alias for ColorType"""
        return self.ColorType

    @colortype.setter
    def colortype(self, value):
        """Alias for ColorType.setter"""
        self.ColorType = value

    @property
    def color_type(self):
        """Alias for ColorType"""
        return self.ColorType

    @color_type.setter
    def color_type(self, value):
        """Alias for ColorType.setter"""
        self.ColorType = value

    @property
    def Contrast(self):
        return self.com_object.Contrast

    @Contrast.setter
    def Contrast(self, value):
        self.com_object.Contrast = value

    @property
    def contrast(self):
        """Alias for Contrast"""
        return self.Contrast

    @contrast.setter
    def contrast(self, value):
        """Alias for Contrast.setter"""
        self.Contrast = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Crop(self):
        return self.com_object.Crop

    @Crop.setter
    def Crop(self, value):
        self.com_object.Crop = value

    @property
    def crop(self):
        """Alias for Crop"""
        return self.Crop

    @crop.setter
    def crop(self, value):
        """Alias for Crop.setter"""
        self.Crop = value

    @property
    def CropBottom(self):
        return self.com_object.CropBottom

    @CropBottom.setter
    def CropBottom(self, value):
        self.com_object.CropBottom = value

    @property
    def cropbottom(self):
        """Alias for CropBottom"""
        return self.CropBottom

    @cropbottom.setter
    def cropbottom(self, value):
        """Alias for CropBottom.setter"""
        self.CropBottom = value

    @property
    def crop_bottom(self):
        """Alias for CropBottom"""
        return self.CropBottom

    @crop_bottom.setter
    def crop_bottom(self, value):
        """Alias for CropBottom.setter"""
        self.CropBottom = value

    @property
    def CropLeft(self):
        return self.com_object.CropLeft

    @CropLeft.setter
    def CropLeft(self, value):
        self.com_object.CropLeft = value

    @property
    def cropleft(self):
        """Alias for CropLeft"""
        return self.CropLeft

    @cropleft.setter
    def cropleft(self, value):
        """Alias for CropLeft.setter"""
        self.CropLeft = value

    @property
    def crop_left(self):
        """Alias for CropLeft"""
        return self.CropLeft

    @crop_left.setter
    def crop_left(self, value):
        """Alias for CropLeft.setter"""
        self.CropLeft = value

    @property
    def CropRight(self):
        return self.com_object.CropRight

    @CropRight.setter
    def CropRight(self, value):
        self.com_object.CropRight = value

    @property
    def cropright(self):
        """Alias for CropRight"""
        return self.CropRight

    @cropright.setter
    def cropright(self, value):
        """Alias for CropRight.setter"""
        self.CropRight = value

    @property
    def crop_right(self):
        """Alias for CropRight"""
        return self.CropRight

    @crop_right.setter
    def crop_right(self, value):
        """Alias for CropRight.setter"""
        self.CropRight = value

    @property
    def CropTop(self):
        return self.com_object.CropTop

    @CropTop.setter
    def CropTop(self, value):
        self.com_object.CropTop = value

    @property
    def croptop(self):
        """Alias for CropTop"""
        return self.CropTop

    @croptop.setter
    def croptop(self, value):
        """Alias for CropTop.setter"""
        self.CropTop = value

    @property
    def crop_top(self):
        """Alias for CropTop"""
        return self.CropTop

    @crop_top.setter
    def crop_top(self, value):
        """Alias for CropTop.setter"""
        self.CropTop = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def TransparencyColor(self):
        return self.com_object.TransparencyColor

    @TransparencyColor.setter
    def TransparencyColor(self, value):
        self.com_object.TransparencyColor = value

    @property
    def transparencycolor(self):
        """Alias for TransparencyColor"""
        return self.TransparencyColor

    @transparencycolor.setter
    def transparencycolor(self, value):
        """Alias for TransparencyColor.setter"""
        self.TransparencyColor = value

    @property
    def transparency_color(self):
        """Alias for TransparencyColor"""
        return self.TransparencyColor

    @transparency_color.setter
    def transparency_color(self, value):
        """Alias for TransparencyColor.setter"""
        self.TransparencyColor = value

    @property
    def TransparentBackground(self):
        return self.com_object.TransparentBackground

    @TransparentBackground.setter
    def TransparentBackground(self, value):
        self.com_object.TransparentBackground = value

    @property
    def transparentbackground(self):
        """Alias for TransparentBackground"""
        return self.TransparentBackground

    @transparentbackground.setter
    def transparentbackground(self, value):
        """Alias for TransparentBackground.setter"""
        self.TransparentBackground = value

    @property
    def transparent_background(self):
        """Alias for TransparentBackground"""
        return self.TransparentBackground

    @transparent_background.setter
    def transparent_background(self, value):
        """Alias for TransparentBackground.setter"""
        self.TransparentBackground = value

    def IncrementBrightness(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementBrightness(*arguments)

    def incrementbrightness(self, Increment=None):
        """Alias for IncrementBrightness"""
        arguments = [Increment]
        return self.IncrementBrightness(*arguments)

    def increment_brightness(self, Increment=None):
        """Alias for IncrementBrightness"""
        arguments = [Increment]
        return self.IncrementBrightness(*arguments)

    def IncrementContrast(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementContrast(*arguments)

    def incrementcontrast(self, Increment=None):
        """Alias for IncrementContrast"""
        arguments = [Increment]
        return self.IncrementContrast(*arguments)

    def increment_contrast(self, Increment=None):
        """Alias for IncrementContrast"""
        arguments = [Increment]
        return self.IncrementContrast(*arguments)


class PlotArea:

    def __init__(self, plotarea=None):
        self.com_object= plotarea

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def InsideHeight(self):
        return self.com_object.InsideHeight

    @InsideHeight.setter
    def InsideHeight(self, value):
        self.com_object.InsideHeight = value

    @property
    def insideheight(self):
        """Alias for InsideHeight"""
        return self.InsideHeight

    @insideheight.setter
    def insideheight(self, value):
        """Alias for InsideHeight.setter"""
        self.InsideHeight = value

    @property
    def inside_height(self):
        """Alias for InsideHeight"""
        return self.InsideHeight

    @inside_height.setter
    def inside_height(self, value):
        """Alias for InsideHeight.setter"""
        self.InsideHeight = value

    @property
    def InsideLeft(self):
        return self.com_object.InsideLeft

    @InsideLeft.setter
    def InsideLeft(self, value):
        self.com_object.InsideLeft = value

    @property
    def insideleft(self):
        """Alias for InsideLeft"""
        return self.InsideLeft

    @insideleft.setter
    def insideleft(self, value):
        """Alias for InsideLeft.setter"""
        self.InsideLeft = value

    @property
    def inside_left(self):
        """Alias for InsideLeft"""
        return self.InsideLeft

    @inside_left.setter
    def inside_left(self, value):
        """Alias for InsideLeft.setter"""
        self.InsideLeft = value

    @property
    def InsideTop(self):
        return self.com_object.InsideTop

    @InsideTop.setter
    def InsideTop(self, value):
        self.com_object.InsideTop = value

    @property
    def insidetop(self):
        """Alias for InsideTop"""
        return self.InsideTop

    @insidetop.setter
    def insidetop(self, value):
        """Alias for InsideTop.setter"""
        self.InsideTop = value

    @property
    def inside_top(self):
        """Alias for InsideTop"""
        return self.InsideTop

    @inside_top.setter
    def inside_top(self, value):
        """Alias for InsideTop.setter"""
        self.InsideTop = value

    @property
    def InsideWidth(self):
        return self.com_object.InsideWidth

    @InsideWidth.setter
    def InsideWidth(self, value):
        self.com_object.InsideWidth = value

    @property
    def insidewidth(self):
        """Alias for InsideWidth"""
        return self.InsideWidth

    @insidewidth.setter
    def insidewidth(self, value):
        """Alias for InsideWidth.setter"""
        self.InsideWidth = value

    @property
    def inside_width(self):
        """Alias for InsideWidth"""
        return self.InsideWidth

    @inside_width.setter
    def inside_width(self, value):
        """Alias for InsideWidth.setter"""
        self.InsideWidth = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return XlChartElementPosition(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def ClearFormats(self):
        self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Point:

    def __init__(self, point=None):
        self.com_object= point

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ApplyPictToEnd(self):
        return self.com_object.ApplyPictToEnd

    @ApplyPictToEnd.setter
    def ApplyPictToEnd(self, value):
        self.com_object.ApplyPictToEnd = value

    @property
    def applypicttoend(self):
        """Alias for ApplyPictToEnd"""
        return self.ApplyPictToEnd

    @applypicttoend.setter
    def applypicttoend(self, value):
        """Alias for ApplyPictToEnd.setter"""
        self.ApplyPictToEnd = value

    @property
    def apply_pict_to_end(self):
        """Alias for ApplyPictToEnd"""
        return self.ApplyPictToEnd

    @apply_pict_to_end.setter
    def apply_pict_to_end(self, value):
        """Alias for ApplyPictToEnd.setter"""
        self.ApplyPictToEnd = value

    @property
    def ApplyPictToFront(self):
        return self.com_object.ApplyPictToFront

    @ApplyPictToFront.setter
    def ApplyPictToFront(self, value):
        self.com_object.ApplyPictToFront = value

    @property
    def applypicttofront(self):
        """Alias for ApplyPictToFront"""
        return self.ApplyPictToFront

    @applypicttofront.setter
    def applypicttofront(self, value):
        """Alias for ApplyPictToFront.setter"""
        self.ApplyPictToFront = value

    @property
    def apply_pict_to_front(self):
        """Alias for ApplyPictToFront"""
        return self.ApplyPictToFront

    @apply_pict_to_front.setter
    def apply_pict_to_front(self, value):
        """Alias for ApplyPictToFront.setter"""
        self.ApplyPictToFront = value

    @property
    def ApplyPictToSides(self):
        return self.com_object.ApplyPictToSides

    @ApplyPictToSides.setter
    def ApplyPictToSides(self, value):
        self.com_object.ApplyPictToSides = value

    @property
    def applypicttosides(self):
        """Alias for ApplyPictToSides"""
        return self.ApplyPictToSides

    @applypicttosides.setter
    def applypicttosides(self, value):
        """Alias for ApplyPictToSides.setter"""
        self.ApplyPictToSides = value

    @property
    def apply_pict_to_sides(self):
        """Alias for ApplyPictToSides"""
        return self.ApplyPictToSides

    @apply_pict_to_sides.setter
    def apply_pict_to_sides(self, value):
        """Alias for ApplyPictToSides.setter"""
        self.ApplyPictToSides = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DataLabel(self):
        return DataLabel(self.com_object.DataLabel)

    @property
    def datalabel(self):
        """Alias for DataLabel"""
        return self.DataLabel

    @property
    def data_label(self):
        """Alias for DataLabel"""
        return self.DataLabel

    @property
    def Explosion(self):
        return self.com_object.Explosion

    @Explosion.setter
    def Explosion(self, value):
        self.com_object.Explosion = value

    @property
    def explosion(self):
        """Alias for Explosion"""
        return self.Explosion

    @explosion.setter
    def explosion(self, value):
        """Alias for Explosion.setter"""
        self.Explosion = value

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Has3DEffect(self):
        return self.com_object.Has3DEffect

    @Has3DEffect.setter
    def Has3DEffect(self, value):
        self.com_object.Has3DEffect = value

    @property
    def has3deffect(self):
        """Alias for Has3DEffect"""
        return self.Has3DEffect

    @has3deffect.setter
    def has3deffect(self, value):
        """Alias for Has3DEffect.setter"""
        self.Has3DEffect = value

    @property
    def has3_d_effect(self):
        """Alias for Has3DEffect"""
        return self.Has3DEffect

    @has3_d_effect.setter
    def has3_d_effect(self, value):
        """Alias for Has3DEffect.setter"""
        self.Has3DEffect = value

    @property
    def HasDataLabel(self):
        return self.com_object.HasDataLabel

    @HasDataLabel.setter
    def HasDataLabel(self, value):
        self.com_object.HasDataLabel = value

    @property
    def hasdatalabel(self):
        """Alias for HasDataLabel"""
        return self.HasDataLabel

    @hasdatalabel.setter
    def hasdatalabel(self, value):
        """Alias for HasDataLabel.setter"""
        self.HasDataLabel = value

    @property
    def has_data_label(self):
        """Alias for HasDataLabel"""
        return self.HasDataLabel

    @has_data_label.setter
    def has_data_label(self, value):
        """Alias for HasDataLabel.setter"""
        self.HasDataLabel = value

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def InvertIfNegative(self):
        return self.com_object.InvertIfNegative

    @InvertIfNegative.setter
    def InvertIfNegative(self, value):
        self.com_object.InvertIfNegative = value

    @property
    def invertifnegative(self):
        """Alias for InvertIfNegative"""
        return self.InvertIfNegative

    @invertifnegative.setter
    def invertifnegative(self, value):
        """Alias for InvertIfNegative.setter"""
        self.InvertIfNegative = value

    @property
    def invert_if_negative(self):
        """Alias for InvertIfNegative"""
        return self.InvertIfNegative

    @invert_if_negative.setter
    def invert_if_negative(self, value):
        """Alias for InvertIfNegative.setter"""
        self.InvertIfNegative = value

    @property
    def IsTotal(self):
        return self.com_object.IsTotal

    @IsTotal.setter
    def IsTotal(self, value):
        self.com_object.IsTotal = value

    @property
    def istotal(self):
        """Alias for IsTotal"""
        return self.IsTotal

    @istotal.setter
    def istotal(self, value):
        """Alias for IsTotal.setter"""
        self.IsTotal = value

    @property
    def is_total(self):
        """Alias for IsTotal"""
        return self.IsTotal

    @is_total.setter
    def is_total(self, value):
        """Alias for IsTotal.setter"""
        self.IsTotal = value

    @property
    def Left(self):
        return self.com_object.Left

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @property
    def MarkerBackgroundColor(self):
        return self.com_object.MarkerBackgroundColor

    @MarkerBackgroundColor.setter
    def MarkerBackgroundColor(self, value):
        self.com_object.MarkerBackgroundColor = value

    @property
    def markerbackgroundcolor(self):
        """Alias for MarkerBackgroundColor"""
        return self.MarkerBackgroundColor

    @markerbackgroundcolor.setter
    def markerbackgroundcolor(self, value):
        """Alias for MarkerBackgroundColor.setter"""
        self.MarkerBackgroundColor = value

    @property
    def marker_background_color(self):
        """Alias for MarkerBackgroundColor"""
        return self.MarkerBackgroundColor

    @marker_background_color.setter
    def marker_background_color(self, value):
        """Alias for MarkerBackgroundColor.setter"""
        self.MarkerBackgroundColor = value

    @property
    def MarkerBackgroundColorIndex(self):
        return XlColorIndex(self.com_object.MarkerBackgroundColorIndex)

    @MarkerBackgroundColorIndex.setter
    def MarkerBackgroundColorIndex(self, value):
        self.com_object.MarkerBackgroundColorIndex = value

    @property
    def markerbackgroundcolorindex(self):
        """Alias for MarkerBackgroundColorIndex"""
        return self.MarkerBackgroundColorIndex

    @markerbackgroundcolorindex.setter
    def markerbackgroundcolorindex(self, value):
        """Alias for MarkerBackgroundColorIndex.setter"""
        self.MarkerBackgroundColorIndex = value

    @property
    def marker_background_color_index(self):
        """Alias for MarkerBackgroundColorIndex"""
        return self.MarkerBackgroundColorIndex

    @marker_background_color_index.setter
    def marker_background_color_index(self, value):
        """Alias for MarkerBackgroundColorIndex.setter"""
        self.MarkerBackgroundColorIndex = value

    @property
    def MarkerForegroundColor(self):
        return self.com_object.MarkerForegroundColor

    @MarkerForegroundColor.setter
    def MarkerForegroundColor(self, value):
        self.com_object.MarkerForegroundColor = value

    @property
    def markerforegroundcolor(self):
        """Alias for MarkerForegroundColor"""
        return self.MarkerForegroundColor

    @markerforegroundcolor.setter
    def markerforegroundcolor(self, value):
        """Alias for MarkerForegroundColor.setter"""
        self.MarkerForegroundColor = value

    @property
    def marker_foreground_color(self):
        """Alias for MarkerForegroundColor"""
        return self.MarkerForegroundColor

    @marker_foreground_color.setter
    def marker_foreground_color(self, value):
        """Alias for MarkerForegroundColor.setter"""
        self.MarkerForegroundColor = value

    @property
    def MarkerForegroundColorIndex(self):
        return XlColorIndex(self.com_object.MarkerForegroundColorIndex)

    @MarkerForegroundColorIndex.setter
    def MarkerForegroundColorIndex(self, value):
        self.com_object.MarkerForegroundColorIndex = value

    @property
    def markerforegroundcolorindex(self):
        """Alias for MarkerForegroundColorIndex"""
        return self.MarkerForegroundColorIndex

    @markerforegroundcolorindex.setter
    def markerforegroundcolorindex(self, value):
        """Alias for MarkerForegroundColorIndex.setter"""
        self.MarkerForegroundColorIndex = value

    @property
    def marker_foreground_color_index(self):
        """Alias for MarkerForegroundColorIndex"""
        return self.MarkerForegroundColorIndex

    @marker_foreground_color_index.setter
    def marker_foreground_color_index(self, value):
        """Alias for MarkerForegroundColorIndex.setter"""
        self.MarkerForegroundColorIndex = value

    @property
    def MarkerSize(self):
        return self.com_object.MarkerSize

    @MarkerSize.setter
    def MarkerSize(self, value):
        self.com_object.MarkerSize = value

    @property
    def markersize(self):
        """Alias for MarkerSize"""
        return self.MarkerSize

    @markersize.setter
    def markersize(self, value):
        """Alias for MarkerSize.setter"""
        self.MarkerSize = value

    @property
    def marker_size(self):
        """Alias for MarkerSize"""
        return self.MarkerSize

    @marker_size.setter
    def marker_size(self, value):
        """Alias for MarkerSize.setter"""
        self.MarkerSize = value

    @property
    def MarkerStyle(self):
        return XlMarkerStyle(self.com_object.MarkerStyle)

    @MarkerStyle.setter
    def MarkerStyle(self, value):
        self.com_object.MarkerStyle = value

    @property
    def markerstyle(self):
        """Alias for MarkerStyle"""
        return self.MarkerStyle

    @markerstyle.setter
    def markerstyle(self, value):
        """Alias for MarkerStyle.setter"""
        self.MarkerStyle = value

    @property
    def marker_style(self):
        """Alias for MarkerStyle"""
        return self.MarkerStyle

    @marker_style.setter
    def marker_style(self, value):
        """Alias for MarkerStyle.setter"""
        self.MarkerStyle = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PictureType(self):
        return XlChartPictureType(self.com_object.PictureType)

    @PictureType.setter
    def PictureType(self, value):
        self.com_object.PictureType = value

    @property
    def picturetype(self):
        """Alias for PictureType"""
        return self.PictureType

    @picturetype.setter
    def picturetype(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def picture_type(self):
        """Alias for PictureType"""
        return self.PictureType

    @picture_type.setter
    def picture_type(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def PictureUnit2(self):
        return self.com_object.PictureUnit2

    @PictureUnit2.setter
    def PictureUnit2(self, value):
        self.com_object.PictureUnit2 = value

    @property
    def pictureunit2(self):
        """Alias for PictureUnit2"""
        return self.PictureUnit2

    @pictureunit2.setter
    def pictureunit2(self, value):
        """Alias for PictureUnit2.setter"""
        self.PictureUnit2 = value

    @property
    def picture_unit2(self):
        """Alias for PictureUnit2"""
        return self.PictureUnit2

    @picture_unit2.setter
    def picture_unit2(self, value):
        """Alias for PictureUnit2.setter"""
        self.PictureUnit2 = value

    @property
    def SecondaryPlot(self):
        return self.com_object.SecondaryPlot

    @SecondaryPlot.setter
    def SecondaryPlot(self, value):
        self.com_object.SecondaryPlot = value

    @property
    def secondaryplot(self):
        """Alias for SecondaryPlot"""
        return self.SecondaryPlot

    @secondaryplot.setter
    def secondaryplot(self, value):
        """Alias for SecondaryPlot.setter"""
        self.SecondaryPlot = value

    @property
    def secondary_plot(self):
        """Alias for SecondaryPlot"""
        return self.SecondaryPlot

    @secondary_plot.setter
    def secondary_plot(self, value):
        """Alias for SecondaryPlot.setter"""
        self.SecondaryPlot = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Top(self):
        return self.com_object.Top

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    def ApplyDataLabels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        arguments = com_arguments([unwrap(a) for a in [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]])
        self.com_object.ApplyDataLabels(*arguments)

    def applydatalabels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        """Alias for ApplyDataLabels"""
        arguments = [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]
        return self.ApplyDataLabels(*arguments)

    def apply_data_labels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        """Alias for ApplyDataLabels"""
        arguments = [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]
        return self.ApplyDataLabels(*arguments)

    def ClearFormats(self):
        self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Paste(self):
        self.com_object.Paste()

    def paste(self):
        """Alias for Paste"""
        return self.Paste()

    def PieSliceLocation(self, loc=None, Index=None):
        arguments = com_arguments([unwrap(a) for a in [loc, Index]])
        return self.com_object.PieSliceLocation(*arguments)

    def pieslicelocation(self, loc=None, Index=None):
        """Alias for PieSliceLocation"""
        arguments = [loc, Index]
        return self.PieSliceLocation(*arguments)

    def pie_slice_location(self, loc=None, Index=None):
        """Alias for PieSliceLocation"""
        arguments = [loc, Index]
        return self.PieSliceLocation(*arguments)

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Points:

    def __init__(self, points=None):
        self.com_object= points

    def __call__(self, item):
        return Point(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Point(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ProofreadingErrors:

    def __init__(self, proofreadingerrors=None):
        self.com_object= proofreadingerrors

    def __call__(self, item):
        return ProofreadingError(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Type(self):
        return WdProofreadingErrorType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Range(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ProtectedViewWindow:

    def __init__(self, protectedviewwindow=None):
        self.com_object= protectedviewwindow

    @property
    def Active(self):
        return self.com_object.Active

    @property
    def active(self):
        """Alias for Active"""
        return self.Active

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Document(self):
        return self.com_object.Document

    @property
    def document(self):
        """Alias for Document"""
        return self.Document

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SourceName(self):
        return self.com_object.SourceName

    @property
    def sourcename(self):
        """Alias for SourceName"""
        return self.SourceName

    @property
    def source_name(self):
        """Alias for SourceName"""
        return self.SourceName

    @property
    def SourcePath(self):
        return self.com_object.SourcePath

    @property
    def sourcepath(self):
        """Alias for SourcePath"""
        return self.SourcePath

    @property
    def source_path(self):
        """Alias for SourcePath"""
        return self.SourcePath

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def WindowState(self):
        return self.com_object.WindowState

    @WindowState.setter
    def WindowState(self, value):
        self.com_object.WindowState = value

    @property
    def windowstate(self):
        """Alias for WindowState"""
        return self.WindowState

    @windowstate.setter
    def windowstate(self, value):
        """Alias for WindowState.setter"""
        self.WindowState = value

    @property
    def window_state(self):
        """Alias for WindowState"""
        return self.WindowState

    @window_state.setter
    def window_state(self, value):
        """Alias for WindowState.setter"""
        self.WindowState = value

    def Activate(self):
        return self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()

    def Close(self):
        return self.com_object.Close()

    def close(self):
        """Alias for Close"""
        return self.Close()

    def ToggleRibbon(self):
        self.com_object.ToggleRibbon()

    def toggleribbon(self):
        """Alias for ToggleRibbon"""
        return self.ToggleRibbon()

    def toggle_ribbon(self):
        """Alias for ToggleRibbon"""
        return self.ToggleRibbon()


class ProtectedViewWindows:

    def __init__(self, protectedviewwindows=None):
        self.com_object= protectedviewwindows

    def __call__(self, item):
        return ProtectedViewWindow(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ProtectedViewWindow(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Open(self, FileName=None, AddToRecentFiles=None, PasswordDocument=None, Visible=None, OpenAndRepair=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, AddToRecentFiles, PasswordDocument, Visible, OpenAndRepair]])
        return ProtectedViewWindow(self.com_object.Open(*arguments))

    def open(self, FileName=None, AddToRecentFiles=None, PasswordDocument=None, Visible=None, OpenAndRepair=None):
        """Alias for Open"""
        arguments = [FileName, AddToRecentFiles, PasswordDocument, Visible, OpenAndRepair]
        return self.Open(*arguments)


class Range:

    def __init__(self, range=None):
        self.com_object= range

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Bold(self):
        return self.com_object.Bold

    @Bold.setter
    def Bold(self, value):
        self.com_object.Bold = value

    @property
    def bold(self):
        """Alias for Bold"""
        return self.Bold

    @bold.setter
    def bold(self, value):
        """Alias for Bold.setter"""
        self.Bold = value

    @property
    def BoldBi(self):
        return self.com_object.BoldBi

    @BoldBi.setter
    def BoldBi(self, value):
        self.com_object.BoldBi = value

    @property
    def boldbi(self):
        """Alias for BoldBi"""
        return self.BoldBi

    @boldbi.setter
    def boldbi(self, value):
        """Alias for BoldBi.setter"""
        self.BoldBi = value

    @property
    def bold_bi(self):
        """Alias for BoldBi"""
        return self.BoldBi

    @bold_bi.setter
    def bold_bi(self, value):
        """Alias for BoldBi.setter"""
        self.BoldBi = value

    @property
    def BookmarkID(self):
        return self.com_object.BookmarkID

    @property
    def bookmarkid(self):
        """Alias for BookmarkID"""
        return self.BookmarkID

    @property
    def bookmark_i_d(self):
        """Alias for BookmarkID"""
        return self.BookmarkID

    @property
    def Bookmarks(self):
        return Bookmarks(self.com_object.Bookmarks)

    @property
    def bookmarks(self):
        """Alias for Bookmarks"""
        return self.Bookmarks

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def Case(self):
        return WdCharacterCase(self.com_object.Case)

    @Case.setter
    def Case(self, value):
        self.com_object.Case = value

    @property
    def case(self):
        """Alias for Case"""
        return self.Case

    @case.setter
    def case(self, value):
        """Alias for Case.setter"""
        self.Case = value

    def Cells(self, RowIndex=None, ColumnIndex=None):
        arguments = com_arguments([unwrap(a) for a in [RowIndex, ColumnIndex]])
        if hasattr(self.com_object, "GetCells"):
            return Cells(self.com_object.GetCells(*arguments))
        else:
            return Cells(self.com_object.Cells(*arguments))

    def cells(self, RowIndex=None, ColumnIndex=None):
        """Alias for Cells"""
        arguments = [RowIndex, ColumnIndex]
        return self.Cells(*arguments)

    @property
    def Characters(self):
        return Characters(self.com_object.Characters)

    @property
    def characters(self):
        """Alias for Characters"""
        return self.Characters

    @property
    def CharacterStyle(self):
        return self.com_object.CharacterStyle

    @property
    def characterstyle(self):
        """Alias for CharacterStyle"""
        return self.CharacterStyle

    @property
    def character_style(self):
        """Alias for CharacterStyle"""
        return self.CharacterStyle

    @property
    def CharacterWidth(self):
        return WdCharacterWidth(self.com_object.CharacterWidth)

    @CharacterWidth.setter
    def CharacterWidth(self, value):
        self.com_object.CharacterWidth = value

    @property
    def characterwidth(self):
        """Alias for CharacterWidth"""
        return self.CharacterWidth

    @characterwidth.setter
    def characterwidth(self, value):
        """Alias for CharacterWidth.setter"""
        self.CharacterWidth = value

    @property
    def character_width(self):
        """Alias for CharacterWidth"""
        return self.CharacterWidth

    @character_width.setter
    def character_width(self, value):
        """Alias for CharacterWidth.setter"""
        self.CharacterWidth = value

    @property
    def Columns(self):
        return Columns(self.com_object.Columns)

    @property
    def columns(self):
        """Alias for Columns"""
        return self.Columns

    @property
    def CombineCharacters(self):
        return self.com_object.CombineCharacters

    @CombineCharacters.setter
    def CombineCharacters(self, value):
        self.com_object.CombineCharacters = value

    @property
    def combinecharacters(self):
        """Alias for CombineCharacters"""
        return self.CombineCharacters

    @combinecharacters.setter
    def combinecharacters(self, value):
        """Alias for CombineCharacters.setter"""
        self.CombineCharacters = value

    @property
    def combine_characters(self):
        """Alias for CombineCharacters"""
        return self.CombineCharacters

    @combine_characters.setter
    def combine_characters(self, value):
        """Alias for CombineCharacters.setter"""
        self.CombineCharacters = value

    @property
    def Comments(self):
        return Comments(self.com_object.Comments)

    @property
    def comments(self):
        """Alias for Comments"""
        return self.Comments

    @property
    def Conflicts(self):
        return self.com_object.Conflicts

    @property
    def conflicts(self):
        """Alias for Conflicts"""
        return self.Conflicts

    @property
    def ContentControls(self):
        return ContentControls(self.com_object.ContentControls)

    @property
    def contentcontrols(self):
        """Alias for ContentControls"""
        return self.ContentControls

    @property
    def content_controls(self):
        """Alias for ContentControls"""
        return self.ContentControls

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DisableCharacterSpaceGrid(self):
        return self.com_object.DisableCharacterSpaceGrid

    @DisableCharacterSpaceGrid.setter
    def DisableCharacterSpaceGrid(self, value):
        self.com_object.DisableCharacterSpaceGrid = value

    @property
    def disablecharacterspacegrid(self):
        """Alias for DisableCharacterSpaceGrid"""
        return self.DisableCharacterSpaceGrid

    @disablecharacterspacegrid.setter
    def disablecharacterspacegrid(self, value):
        """Alias for DisableCharacterSpaceGrid.setter"""
        self.DisableCharacterSpaceGrid = value

    @property
    def disable_character_space_grid(self):
        """Alias for DisableCharacterSpaceGrid"""
        return self.DisableCharacterSpaceGrid

    @disable_character_space_grid.setter
    def disable_character_space_grid(self, value):
        """Alias for DisableCharacterSpaceGrid.setter"""
        self.DisableCharacterSpaceGrid = value

    @property
    def Document(self):
        return Document(self.com_object.Document)

    @property
    def document(self):
        """Alias for Document"""
        return self.Document

    @property
    def Duplicate(self):
        return Range(self.com_object.Duplicate)

    @property
    def duplicate(self):
        """Alias for Duplicate"""
        return self.Duplicate

    @property
    def Editors(self):
        return Editors(self.com_object.Editors)

    @property
    def editors(self):
        """Alias for Editors"""
        return self.Editors

    @property
    def EmphasisMark(self):
        return WdEmphasisMark(self.com_object.EmphasisMark)

    @EmphasisMark.setter
    def EmphasisMark(self, value):
        self.com_object.EmphasisMark = value

    @property
    def emphasismark(self):
        """Alias for EmphasisMark"""
        return self.EmphasisMark

    @emphasismark.setter
    def emphasismark(self, value):
        """Alias for EmphasisMark.setter"""
        self.EmphasisMark = value

    @property
    def emphasis_mark(self):
        """Alias for EmphasisMark"""
        return self.EmphasisMark

    @emphasis_mark.setter
    def emphasis_mark(self, value):
        """Alias for EmphasisMark.setter"""
        self.EmphasisMark = value

    @property
    def End(self):
        return self.com_object.End

    @End.setter
    def End(self, value):
        self.com_object.End = value

    @property
    def end(self):
        """Alias for End"""
        return self.End

    @end.setter
    def end(self, value):
        """Alias for End.setter"""
        self.End = value

    @property
    def EndnoteOptions(self):
        return EndnoteOptions(self.com_object.EndnoteOptions)

    @property
    def endnoteoptions(self):
        """Alias for EndnoteOptions"""
        return self.EndnoteOptions

    @property
    def endnote_options(self):
        """Alias for EndnoteOptions"""
        return self.EndnoteOptions

    @property
    def Endnotes(self):
        return Endnotes(self.com_object.Endnotes)

    @property
    def endnotes(self):
        """Alias for Endnotes"""
        return self.Endnotes

    @property
    def EnhMetaFileBits(self):
        return self.com_object.EnhMetaFileBits

    @property
    def enhmetafilebits(self):
        """Alias for EnhMetaFileBits"""
        return self.EnhMetaFileBits

    @property
    def enh_meta_file_bits(self):
        """Alias for EnhMetaFileBits"""
        return self.EnhMetaFileBits

    @property
    def Fields(self):
        return Fields(self.com_object.Fields)

    @property
    def fields(self):
        """Alias for Fields"""
        return self.Fields

    @property
    def Find(self):
        return Find(self.com_object.Find)

    @property
    def find(self):
        """Alias for Find"""
        return self.Find

    @property
    def FitTextWidth(self):
        return self.com_object.FitTextWidth

    @FitTextWidth.setter
    def FitTextWidth(self, value):
        self.com_object.FitTextWidth = value

    @property
    def fittextwidth(self):
        """Alias for FitTextWidth"""
        return self.FitTextWidth

    @fittextwidth.setter
    def fittextwidth(self, value):
        """Alias for FitTextWidth.setter"""
        self.FitTextWidth = value

    @property
    def fit_text_width(self):
        """Alias for FitTextWidth"""
        return self.FitTextWidth

    @fit_text_width.setter
    def fit_text_width(self, value):
        """Alias for FitTextWidth.setter"""
        self.FitTextWidth = value

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @Font.setter
    def Font(self, value):
        self.com_object.Font = value

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @font.setter
    def font(self, value):
        """Alias for Font.setter"""
        self.Font = value

    @property
    def FootnoteOptions(self):
        return FootnoteOptions(self.com_object.FootnoteOptions)

    @property
    def footnoteoptions(self):
        """Alias for FootnoteOptions"""
        return self.FootnoteOptions

    @property
    def footnote_options(self):
        """Alias for FootnoteOptions"""
        return self.FootnoteOptions

    @property
    def Footnotes(self):
        return Footnotes(self.com_object.Footnotes)

    @property
    def footnotes(self):
        """Alias for Footnotes"""
        return self.Footnotes

    @property
    def FormattedText(self):
        return Range(self.com_object.FormattedText)

    @FormattedText.setter
    def FormattedText(self, value):
        self.com_object.FormattedText = value

    @property
    def formattedtext(self):
        """Alias for FormattedText"""
        return self.FormattedText

    @formattedtext.setter
    def formattedtext(self, value):
        """Alias for FormattedText.setter"""
        self.FormattedText = value

    @property
    def formatted_text(self):
        """Alias for FormattedText"""
        return self.FormattedText

    @formatted_text.setter
    def formatted_text(self, value):
        """Alias for FormattedText.setter"""
        self.FormattedText = value

    @property
    def FormFields(self):
        return FormFields(self.com_object.FormFields)

    @property
    def formfields(self):
        """Alias for FormFields"""
        return self.FormFields

    @property
    def form_fields(self):
        """Alias for FormFields"""
        return self.FormFields

    @property
    def Frames(self):
        return Frames(self.com_object.Frames)

    @property
    def frames(self):
        """Alias for Frames"""
        return self.Frames

    @property
    def GrammarChecked(self):
        return self.com_object.GrammarChecked

    @GrammarChecked.setter
    def GrammarChecked(self, value):
        self.com_object.GrammarChecked = value

    @property
    def grammarchecked(self):
        """Alias for GrammarChecked"""
        return self.GrammarChecked

    @grammarchecked.setter
    def grammarchecked(self, value):
        """Alias for GrammarChecked.setter"""
        self.GrammarChecked = value

    @property
    def grammar_checked(self):
        """Alias for GrammarChecked"""
        return self.GrammarChecked

    @grammar_checked.setter
    def grammar_checked(self, value):
        """Alias for GrammarChecked.setter"""
        self.GrammarChecked = value

    @property
    def GrammaticalErrors(self):
        return ProofreadingErrors(self.com_object.GrammaticalErrors)

    @property
    def grammaticalerrors(self):
        """Alias for GrammaticalErrors"""
        return self.GrammaticalErrors

    @property
    def grammatical_errors(self):
        """Alias for GrammaticalErrors"""
        return self.GrammaticalErrors

    @property
    def HighlightColorIndex(self):
        return WdColorIndex(self.com_object.HighlightColorIndex)

    @HighlightColorIndex.setter
    def HighlightColorIndex(self, value):
        self.com_object.HighlightColorIndex = value

    @property
    def highlightcolorindex(self):
        """Alias for HighlightColorIndex"""
        return self.HighlightColorIndex

    @highlightcolorindex.setter
    def highlightcolorindex(self, value):
        """Alias for HighlightColorIndex.setter"""
        self.HighlightColorIndex = value

    @property
    def highlight_color_index(self):
        """Alias for HighlightColorIndex"""
        return self.HighlightColorIndex

    @highlight_color_index.setter
    def highlight_color_index(self, value):
        """Alias for HighlightColorIndex.setter"""
        self.HighlightColorIndex = value

    @property
    def HorizontalInVertical(self):
        return WdHorizontalInVerticalType(self.com_object.HorizontalInVertical)

    @HorizontalInVertical.setter
    def HorizontalInVertical(self, value):
        self.com_object.HorizontalInVertical = value

    @property
    def horizontalinvertical(self):
        """Alias for HorizontalInVertical"""
        return self.HorizontalInVertical

    @horizontalinvertical.setter
    def horizontalinvertical(self, value):
        """Alias for HorizontalInVertical.setter"""
        self.HorizontalInVertical = value

    @property
    def horizontal_in_vertical(self):
        """Alias for HorizontalInVertical"""
        return self.HorizontalInVertical

    @horizontal_in_vertical.setter
    def horizontal_in_vertical(self, value):
        """Alias for HorizontalInVertical.setter"""
        self.HorizontalInVertical = value

    @property
    def HTMLDivisions(self):
        return HTMLDivisions(self.com_object.HTMLDivisions)

    @property
    def htmldivisions(self):
        """Alias for HTMLDivisions"""
        return self.HTMLDivisions

    @property
    def h_t_m_l_divisions(self):
        """Alias for HTMLDivisions"""
        return self.HTMLDivisions

    @property
    def Hyperlinks(self):
        return Hyperlinks(self.com_object.Hyperlinks)

    @property
    def hyperlinks(self):
        """Alias for Hyperlinks"""
        return self.Hyperlinks

    @property
    def ID(self):
        return self.com_object.ID

    @ID.setter
    def ID(self, value):
        self.com_object.ID = value

    @property
    def id(self):
        """Alias for ID"""
        return self.ID

    @id.setter
    def id(self, value):
        """Alias for ID.setter"""
        self.ID = value

    @property
    def i_d(self):
        """Alias for ID"""
        return self.ID

    @i_d.setter
    def i_d(self, value):
        """Alias for ID.setter"""
        self.ID = value

    def Information(self, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Type]])
        if hasattr(self.com_object, "GetInformation"):
            return self.com_object.GetInformation(*arguments)
        else:
            return self.com_object.Information(*arguments)

    def information(self, Type=None):
        """Alias for Information"""
        arguments = [Type]
        return self.Information(*arguments)

    @property
    def InlineShapes(self):
        return InlineShapes(self.com_object.InlineShapes)

    @property
    def inlineshapes(self):
        """Alias for InlineShapes"""
        return self.InlineShapes

    @property
    def inline_shapes(self):
        """Alias for InlineShapes"""
        return self.InlineShapes

    @property
    def IsEndOfRowMark(self):
        return self.com_object.IsEndOfRowMark

    @property
    def isendofrowmark(self):
        """Alias for IsEndOfRowMark"""
        return self.IsEndOfRowMark

    @property
    def is_end_of_row_mark(self):
        """Alias for IsEndOfRowMark"""
        return self.IsEndOfRowMark

    @property
    def Italic(self):
        return self.com_object.Italic

    @Italic.setter
    def Italic(self, value):
        self.com_object.Italic = value

    @property
    def italic(self):
        """Alias for Italic"""
        return self.Italic

    @italic.setter
    def italic(self, value):
        """Alias for Italic.setter"""
        self.Italic = value

    @property
    def ItalicBi(self):
        return self.com_object.ItalicBi

    @ItalicBi.setter
    def ItalicBi(self, value):
        self.com_object.ItalicBi = value

    @property
    def italicbi(self):
        """Alias for ItalicBi"""
        return self.ItalicBi

    @italicbi.setter
    def italicbi(self, value):
        """Alias for ItalicBi.setter"""
        self.ItalicBi = value

    @property
    def italic_bi(self):
        """Alias for ItalicBi"""
        return self.ItalicBi

    @italic_bi.setter
    def italic_bi(self, value):
        """Alias for ItalicBi.setter"""
        self.ItalicBi = value

    @property
    def Kana(self):
        return WdKana(self.com_object.Kana)

    @Kana.setter
    def Kana(self, value):
        self.com_object.Kana = value

    @property
    def kana(self):
        """Alias for Kana"""
        return self.Kana

    @kana.setter
    def kana(self, value):
        """Alias for Kana.setter"""
        self.Kana = value

    @property
    def LanguageDetected(self):
        return self.com_object.LanguageDetected

    @LanguageDetected.setter
    def LanguageDetected(self, value):
        self.com_object.LanguageDetected = value

    @property
    def languagedetected(self):
        """Alias for LanguageDetected"""
        return self.LanguageDetected

    @languagedetected.setter
    def languagedetected(self, value):
        """Alias for LanguageDetected.setter"""
        self.LanguageDetected = value

    @property
    def language_detected(self):
        """Alias for LanguageDetected"""
        return self.LanguageDetected

    @language_detected.setter
    def language_detected(self, value):
        """Alias for LanguageDetected.setter"""
        self.LanguageDetected = value

    @property
    def LanguageID(self):
        return WdLanguageID(self.com_object.LanguageID)

    @LanguageID.setter
    def LanguageID(self, value):
        self.com_object.LanguageID = value

    @property
    def languageid(self):
        """Alias for LanguageID"""
        return self.LanguageID

    @languageid.setter
    def languageid(self, value):
        """Alias for LanguageID.setter"""
        self.LanguageID = value

    @property
    def language_i_d(self):
        """Alias for LanguageID"""
        return self.LanguageID

    @language_i_d.setter
    def language_i_d(self, value):
        """Alias for LanguageID.setter"""
        self.LanguageID = value

    @property
    def LanguageIDFarEast(self):
        return WdLanguageID(self.com_object.LanguageIDFarEast)

    @LanguageIDFarEast.setter
    def LanguageIDFarEast(self, value):
        self.com_object.LanguageIDFarEast = value

    @property
    def languageidfareast(self):
        """Alias for LanguageIDFarEast"""
        return self.LanguageIDFarEast

    @languageidfareast.setter
    def languageidfareast(self, value):
        """Alias for LanguageIDFarEast.setter"""
        self.LanguageIDFarEast = value

    @property
    def language_i_d_far_east(self):
        """Alias for LanguageIDFarEast"""
        return self.LanguageIDFarEast

    @language_i_d_far_east.setter
    def language_i_d_far_east(self, value):
        """Alias for LanguageIDFarEast.setter"""
        self.LanguageIDFarEast = value

    @property
    def LanguageIDOther(self):
        return WdLanguageID(self.com_object.LanguageIDOther)

    @LanguageIDOther.setter
    def LanguageIDOther(self, value):
        self.com_object.LanguageIDOther = value

    @property
    def languageidother(self):
        """Alias for LanguageIDOther"""
        return self.LanguageIDOther

    @languageidother.setter
    def languageidother(self, value):
        """Alias for LanguageIDOther.setter"""
        self.LanguageIDOther = value

    @property
    def language_i_d_other(self):
        """Alias for LanguageIDOther"""
        return self.LanguageIDOther

    @language_i_d_other.setter
    def language_i_d_other(self, value):
        """Alias for LanguageIDOther.setter"""
        self.LanguageIDOther = value

    @property
    def ListFormat(self):
        return ListFormat(self.com_object.ListFormat)

    @property
    def listformat(self):
        """Alias for ListFormat"""
        return self.ListFormat

    @property
    def list_format(self):
        """Alias for ListFormat"""
        return self.ListFormat

    @property
    def ListParagraphs(self):
        return ListParagraphs(self.com_object.ListParagraphs)

    @property
    def listparagraphs(self):
        """Alias for ListParagraphs"""
        return self.ListParagraphs

    @property
    def list_paragraphs(self):
        """Alias for ListParagraphs"""
        return self.ListParagraphs

    @property
    def ListStyle(self):
        return self.com_object.ListStyle

    @property
    def liststyle(self):
        """Alias for ListStyle"""
        return self.ListStyle

    @property
    def list_style(self):
        """Alias for ListStyle"""
        return self.ListStyle

    @property
    def Locks(self):
        return CoAuthLocks(self.com_object.Locks)

    @property
    def locks(self):
        """Alias for Locks"""
        return self.Locks

    @property
    def NextStoryRange(self):
        return Range(self.com_object.NextStoryRange)

    @property
    def nextstoryrange(self):
        """Alias for NextStoryRange"""
        return self.NextStoryRange

    @property
    def next_story_range(self):
        """Alias for NextStoryRange"""
        return self.NextStoryRange

    @property
    def NoProofing(self):
        return self.com_object.NoProofing

    @NoProofing.setter
    def NoProofing(self, value):
        self.com_object.NoProofing = value

    @property
    def noproofing(self):
        """Alias for NoProofing"""
        return self.NoProofing

    @noproofing.setter
    def noproofing(self, value):
        """Alias for NoProofing.setter"""
        self.NoProofing = value

    @property
    def no_proofing(self):
        """Alias for NoProofing"""
        return self.NoProofing

    @no_proofing.setter
    def no_proofing(self, value):
        """Alias for NoProofing.setter"""
        self.NoProofing = value

    @property
    def OMaths(self):
        return OMaths(self.com_object.OMaths)

    @property
    def omaths(self):
        """Alias for OMaths"""
        return self.OMaths

    @property
    def o_maths(self):
        """Alias for OMaths"""
        return self.OMaths

    @property
    def Orientation(self):
        return WdTextOrientation(self.com_object.Orientation)

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def PageSetup(self):
        return PageSetup(self.com_object.PageSetup)

    @property
    def pagesetup(self):
        """Alias for PageSetup"""
        return self.PageSetup

    @property
    def page_setup(self):
        """Alias for PageSetup"""
        return self.PageSetup

    @property
    def ParagraphFormat(self):
        return ParagraphFormat(self.com_object.ParagraphFormat)

    @ParagraphFormat.setter
    def ParagraphFormat(self, value):
        self.com_object.ParagraphFormat = value

    @property
    def paragraphformat(self):
        """Alias for ParagraphFormat"""
        return self.ParagraphFormat

    @paragraphformat.setter
    def paragraphformat(self, value):
        """Alias for ParagraphFormat.setter"""
        self.ParagraphFormat = value

    @property
    def paragraph_format(self):
        """Alias for ParagraphFormat"""
        return self.ParagraphFormat

    @paragraph_format.setter
    def paragraph_format(self, value):
        """Alias for ParagraphFormat.setter"""
        self.ParagraphFormat = value

    @property
    def Paragraphs(self):
        return Paragraphs(self.com_object.Paragraphs)

    @property
    def paragraphs(self):
        """Alias for Paragraphs"""
        return self.Paragraphs

    @property
    def ParagraphStyle(self):
        return self.com_object.ParagraphStyle

    @property
    def paragraphstyle(self):
        """Alias for ParagraphStyle"""
        return self.ParagraphStyle

    @property
    def paragraph_style(self):
        """Alias for ParagraphStyle"""
        return self.ParagraphStyle

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ParentContentControl(self):
        return ContentControl(self.com_object.ParentContentControl)

    @property
    def parentcontentcontrol(self):
        """Alias for ParentContentControl"""
        return self.ParentContentControl

    @property
    def parent_content_control(self):
        """Alias for ParentContentControl"""
        return self.ParentContentControl

    @property
    def PreviousBookmarkID(self):
        return self.com_object.PreviousBookmarkID

    @property
    def previousbookmarkid(self):
        """Alias for PreviousBookmarkID"""
        return self.PreviousBookmarkID

    @property
    def previous_bookmark_i_d(self):
        """Alias for PreviousBookmarkID"""
        return self.PreviousBookmarkID

    @property
    def ReadabilityStatistics(self):
        return ReadabilityStatistics(self.com_object.ReadabilityStatistics)

    @property
    def readabilitystatistics(self):
        """Alias for ReadabilityStatistics"""
        return self.ReadabilityStatistics

    @property
    def readability_statistics(self):
        """Alias for ReadabilityStatistics"""
        return self.ReadabilityStatistics

    @property
    def Revisions(self):
        return Revisions(self.com_object.Revisions)

    @property
    def revisions(self):
        """Alias for Revisions"""
        return self.Revisions

    @property
    def Rows(self):
        return Rows(self.com_object.Rows)

    @property
    def rows(self):
        """Alias for Rows"""
        return self.Rows

    @property
    def Scripts(self):
        return self.com_object.Scripts

    @property
    def scripts(self):
        """Alias for Scripts"""
        return self.Scripts

    @property
    def Sections(self):
        return Sections(self.com_object.Sections)

    @property
    def sections(self):
        """Alias for Sections"""
        return self.Sections

    @property
    def Sentences(self):
        return Sentences(self.com_object.Sentences)

    @property
    def sentences(self):
        """Alias for Sentences"""
        return self.Sentences

    @property
    def Shading(self):
        return Shading(self.com_object.Shading)

    @property
    def shading(self):
        """Alias for Shading"""
        return self.Shading

    @property
    def ShapeRange(self):
        return ShapeRange(self.com_object.ShapeRange)

    @property
    def shaperange(self):
        """Alias for ShapeRange"""
        return self.ShapeRange

    @property
    def shape_range(self):
        """Alias for ShapeRange"""
        return self.ShapeRange

    @property
    def ShowAll(self):
        return self.com_object.ShowAll

    @ShowAll.setter
    def ShowAll(self, value):
        self.com_object.ShowAll = value

    @property
    def showall(self):
        """Alias for ShowAll"""
        return self.ShowAll

    @showall.setter
    def showall(self, value):
        """Alias for ShowAll.setter"""
        self.ShowAll = value

    @property
    def show_all(self):
        """Alias for ShowAll"""
        return self.ShowAll

    @show_all.setter
    def show_all(self, value):
        """Alias for ShowAll.setter"""
        self.ShowAll = value

    @property
    def SpellingChecked(self):
        return self.com_object.SpellingChecked

    @SpellingChecked.setter
    def SpellingChecked(self, value):
        self.com_object.SpellingChecked = value

    @property
    def spellingchecked(self):
        """Alias for SpellingChecked"""
        return self.SpellingChecked

    @spellingchecked.setter
    def spellingchecked(self, value):
        """Alias for SpellingChecked.setter"""
        self.SpellingChecked = value

    @property
    def spelling_checked(self):
        """Alias for SpellingChecked"""
        return self.SpellingChecked

    @spelling_checked.setter
    def spelling_checked(self, value):
        """Alias for SpellingChecked.setter"""
        self.SpellingChecked = value

    @property
    def SpellingErrors(self):
        return ProofreadingErrors(self.com_object.SpellingErrors)

    @property
    def spellingerrors(self):
        """Alias for SpellingErrors"""
        return self.SpellingErrors

    @property
    def spelling_errors(self):
        """Alias for SpellingErrors"""
        return self.SpellingErrors

    @property
    def Start(self):
        return self.com_object.Start

    @Start.setter
    def Start(self, value):
        self.com_object.Start = value

    @property
    def start(self):
        """Alias for Start"""
        return self.Start

    @start.setter
    def start(self, value):
        """Alias for Start.setter"""
        self.Start = value

    @property
    def StoryLength(self):
        return self.com_object.StoryLength

    @property
    def storylength(self):
        """Alias for StoryLength"""
        return self.StoryLength

    @property
    def story_length(self):
        """Alias for StoryLength"""
        return self.StoryLength

    @property
    def StoryType(self):
        return WdStoryType(self.com_object.StoryType)

    @property
    def storytype(self):
        """Alias for StoryType"""
        return self.StoryType

    @property
    def story_type(self):
        """Alias for StoryType"""
        return self.StoryType

    @property
    def Style(self):
        return self.com_object.Style

    @Style.setter
    def Style(self, value):
        self.com_object.Style = value

    @property
    def style(self):
        """Alias for Style"""
        return self.Style

    @style.setter
    def style(self, value):
        """Alias for Style.setter"""
        self.Style = value

    @property
    def Subdocuments(self):
        return Subdocuments(self.com_object.Subdocuments)

    @property
    def subdocuments(self):
        """Alias for Subdocuments"""
        return self.Subdocuments

    @property
    def SynonymInfo(self):
        return SynonymInfo(self.com_object.SynonymInfo)

    @property
    def synonyminfo(self):
        """Alias for SynonymInfo"""
        return self.SynonymInfo

    @property
    def synonym_info(self):
        """Alias for SynonymInfo"""
        return self.SynonymInfo

    @property
    def Tables(self):
        return Tables(self.com_object.Tables)

    @property
    def tables(self):
        """Alias for Tables"""
        return self.Tables

    @property
    def TableStyle(self):
        return self.com_object.TableStyle

    @property
    def tablestyle(self):
        """Alias for TableStyle"""
        return self.TableStyle

    @property
    def table_style(self):
        """Alias for TableStyle"""
        return self.TableStyle

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def TextRetrievalMode(self):
        return TextRetrievalMode(self.com_object.TextRetrievalMode)

    @TextRetrievalMode.setter
    def TextRetrievalMode(self, value):
        self.com_object.TextRetrievalMode = value

    @property
    def textretrievalmode(self):
        """Alias for TextRetrievalMode"""
        return self.TextRetrievalMode

    @textretrievalmode.setter
    def textretrievalmode(self, value):
        """Alias for TextRetrievalMode.setter"""
        self.TextRetrievalMode = value

    @property
    def text_retrieval_mode(self):
        """Alias for TextRetrievalMode"""
        return self.TextRetrievalMode

    @text_retrieval_mode.setter
    def text_retrieval_mode(self, value):
        """Alias for TextRetrievalMode.setter"""
        self.TextRetrievalMode = value

    @property
    def TextVisibleOnScreen(self):
        return self.com_object.TextVisibleOnScreen

    @property
    def textvisibleonscreen(self):
        """Alias for TextVisibleOnScreen"""
        return self.TextVisibleOnScreen

    @property
    def text_visible_on_screen(self):
        """Alias for TextVisibleOnScreen"""
        return self.TextVisibleOnScreen

    @property
    def TopLevelTables(self):
        return Tables(self.com_object.TopLevelTables)

    @property
    def topleveltables(self):
        """Alias for TopLevelTables"""
        return self.TopLevelTables

    @property
    def top_level_tables(self):
        """Alias for TopLevelTables"""
        return self.TopLevelTables

    @property
    def TwoLinesInOne(self):
        return WdTwoLinesInOneType(self.com_object.TwoLinesInOne)

    @TwoLinesInOne.setter
    def TwoLinesInOne(self, value):
        self.com_object.TwoLinesInOne = value

    @property
    def twolinesinone(self):
        """Alias for TwoLinesInOne"""
        return self.TwoLinesInOne

    @twolinesinone.setter
    def twolinesinone(self, value):
        """Alias for TwoLinesInOne.setter"""
        self.TwoLinesInOne = value

    @property
    def two_lines_in_one(self):
        """Alias for TwoLinesInOne"""
        return self.TwoLinesInOne

    @two_lines_in_one.setter
    def two_lines_in_one(self, value):
        """Alias for TwoLinesInOne.setter"""
        self.TwoLinesInOne = value

    @property
    def Underline(self):
        return WdUnderline(self.com_object.Underline)

    @Underline.setter
    def Underline(self, value):
        self.com_object.Underline = value

    @property
    def underline(self):
        """Alias for Underline"""
        return self.Underline

    @underline.setter
    def underline(self, value):
        """Alias for Underline.setter"""
        self.Underline = value

    @property
    def Updates(self):
        return self.com_object.Updates

    @property
    def updates(self):
        """Alias for Updates"""
        return self.Updates

    @property
    def WordOpenXML(self):
        return self.com_object.WordOpenXML

    @property
    def wordopenxml(self):
        """Alias for WordOpenXML"""
        return self.WordOpenXML

    @property
    def word_open_x_m_l(self):
        """Alias for WordOpenXML"""
        return self.WordOpenXML

    @property
    def Words(self):
        return Words(self.com_object.Words)

    @property
    def words(self):
        """Alias for Words"""
        return self.Words

    def XML(self, DataOnly=None):
        arguments = com_arguments([unwrap(a) for a in [DataOnly]])
        if hasattr(self.com_object, "GetXML"):
            return self.com_object.GetXML(*arguments)
        else:
            return self.com_object.XML(*arguments)

    def xml(self, DataOnly=None):
        """Alias for XML"""
        arguments = [DataOnly]
        return self.XML(*arguments)

    def x_m_l(self, DataOnly=None):
        """Alias for XML"""
        arguments = [DataOnly]
        return self.XML(*arguments)

    def AutoFormat(self):
        self.com_object.AutoFormat()

    def autoformat(self):
        """Alias for AutoFormat"""
        return self.AutoFormat()

    def auto_format(self):
        """Alias for AutoFormat"""
        return self.AutoFormat()

    def Calculate(self):
        self.com_object.Calculate()

    def calculate(self):
        """Alias for Calculate"""
        return self.Calculate()

    def CheckGrammar(self):
        self.com_object.CheckGrammar()

    def checkgrammar(self):
        """Alias for CheckGrammar"""
        return self.CheckGrammar()

    def check_grammar(self):
        """Alias for CheckGrammar"""
        return self.CheckGrammar()

    def CheckSpelling(self, CustomDictionary=None, IgnoreUppercase=None, AlwaysSuggest=None, CustomDictionary2=None, CustomDictionary3=None, CustomDictionary4=None, CustomDictionary5=None, CustomDictionary6=None, CustomDictionary7=None, CustomDictionary8=None, CustomDictionary9=None, CustomDictionary10=None):
        arguments = com_arguments([unwrap(a) for a in [CustomDictionary, IgnoreUppercase, AlwaysSuggest, CustomDictionary2, CustomDictionary3, CustomDictionary4, CustomDictionary5, CustomDictionary6, CustomDictionary7, CustomDictionary8, CustomDictionary9, CustomDictionary10]])
        self.com_object.CheckSpelling(*arguments)

    def checkspelling(self, CustomDictionary=None, IgnoreUppercase=None, AlwaysSuggest=None, CustomDictionary2=None, CustomDictionary3=None, CustomDictionary4=None, CustomDictionary5=None, CustomDictionary6=None, CustomDictionary7=None, CustomDictionary8=None, CustomDictionary9=None, CustomDictionary10=None):
        """Alias for CheckSpelling"""
        arguments = [CustomDictionary, IgnoreUppercase, AlwaysSuggest, CustomDictionary2, CustomDictionary3, CustomDictionary4, CustomDictionary5, CustomDictionary6, CustomDictionary7, CustomDictionary8, CustomDictionary9, CustomDictionary10]
        return self.CheckSpelling(*arguments)

    def check_spelling(self, CustomDictionary=None, IgnoreUppercase=None, AlwaysSuggest=None, CustomDictionary2=None, CustomDictionary3=None, CustomDictionary4=None, CustomDictionary5=None, CustomDictionary6=None, CustomDictionary7=None, CustomDictionary8=None, CustomDictionary9=None, CustomDictionary10=None):
        """Alias for CheckSpelling"""
        arguments = [CustomDictionary, IgnoreUppercase, AlwaysSuggest, CustomDictionary2, CustomDictionary3, CustomDictionary4, CustomDictionary5, CustomDictionary6, CustomDictionary7, CustomDictionary8, CustomDictionary9, CustomDictionary10]
        return self.CheckSpelling(*arguments)

    def CheckSynonyms(self):
        self.com_object.CheckSynonyms()

    def checksynonyms(self):
        """Alias for CheckSynonyms"""
        return self.CheckSynonyms()

    def check_synonyms(self):
        """Alias for CheckSynonyms"""
        return self.CheckSynonyms()

    def Collapse(self, Direction=None):
        arguments = com_arguments([unwrap(a) for a in [Direction]])
        self.com_object.Collapse(*arguments)

    def collapse(self, Direction=None):
        """Alias for Collapse"""
        arguments = [Direction]
        return self.Collapse(*arguments)

    def ComputeStatistics(self, Statistic=None):
        arguments = com_arguments([unwrap(a) for a in [Statistic]])
        self.com_object.ComputeStatistics(*arguments)

    def computestatistics(self, Statistic=None):
        """Alias for ComputeStatistics"""
        arguments = [Statistic]
        return self.ComputeStatistics(*arguments)

    def compute_statistics(self, Statistic=None):
        """Alias for ComputeStatistics"""
        arguments = [Statistic]
        return self.ComputeStatistics(*arguments)

    def ConvertHangulAndHanja(self, ConversionsMode=None, FastConversion=None, CheckHangulEnding=None, EnableRecentOrdering=None, CustomDictionary=None):
        arguments = com_arguments([unwrap(a) for a in [ConversionsMode, FastConversion, CheckHangulEnding, EnableRecentOrdering, CustomDictionary]])
        self.com_object.ConvertHangulAndHanja(*arguments)

    def converthangulandhanja(self, ConversionsMode=None, FastConversion=None, CheckHangulEnding=None, EnableRecentOrdering=None, CustomDictionary=None):
        """Alias for ConvertHangulAndHanja"""
        arguments = [ConversionsMode, FastConversion, CheckHangulEnding, EnableRecentOrdering, CustomDictionary]
        return self.ConvertHangulAndHanja(*arguments)

    def convert_hangul_and_hanja(self, ConversionsMode=None, FastConversion=None, CheckHangulEnding=None, EnableRecentOrdering=None, CustomDictionary=None):
        """Alias for ConvertHangulAndHanja"""
        arguments = [ConversionsMode, FastConversion, CheckHangulEnding, EnableRecentOrdering, CustomDictionary]
        return self.ConvertHangulAndHanja(*arguments)

    def ConvertToTable(self, Separator=None, NumRows=None, NumColumns=None, InitialColumnWidth=None, Format=None, ApplyBorders=None, ApplyShading=None, ApplyFont=None, ApplyColor=None, ApplyHeadingRows=None, ApplyLastRow=None, ApplyFirstColumn=None, ApplyLastColumn=None, AutoFit=None, AutoFitBehavior=None, DefaultTableBehavior=None):
        arguments = com_arguments([unwrap(a) for a in [Separator, NumRows, NumColumns, InitialColumnWidth, Format, ApplyBorders, ApplyShading, ApplyFont, ApplyColor, ApplyHeadingRows, ApplyLastRow, ApplyFirstColumn, ApplyLastColumn, AutoFit, AutoFitBehavior, DefaultTableBehavior]])
        return Table(self.com_object.ConvertToTable(*arguments))

    def converttotable(self, Separator=None, NumRows=None, NumColumns=None, InitialColumnWidth=None, Format=None, ApplyBorders=None, ApplyShading=None, ApplyFont=None, ApplyColor=None, ApplyHeadingRows=None, ApplyLastRow=None, ApplyFirstColumn=None, ApplyLastColumn=None, AutoFit=None, AutoFitBehavior=None, DefaultTableBehavior=None):
        """Alias for ConvertToTable"""
        arguments = [Separator, NumRows, NumColumns, InitialColumnWidth, Format, ApplyBorders, ApplyShading, ApplyFont, ApplyColor, ApplyHeadingRows, ApplyLastRow, ApplyFirstColumn, ApplyLastColumn, AutoFit, AutoFitBehavior, DefaultTableBehavior]
        return self.ConvertToTable(*arguments)

    def convert_to_table(self, Separator=None, NumRows=None, NumColumns=None, InitialColumnWidth=None, Format=None, ApplyBorders=None, ApplyShading=None, ApplyFont=None, ApplyColor=None, ApplyHeadingRows=None, ApplyLastRow=None, ApplyFirstColumn=None, ApplyLastColumn=None, AutoFit=None, AutoFitBehavior=None, DefaultTableBehavior=None):
        """Alias for ConvertToTable"""
        arguments = [Separator, NumRows, NumColumns, InitialColumnWidth, Format, ApplyBorders, ApplyShading, ApplyFont, ApplyColor, ApplyHeadingRows, ApplyLastRow, ApplyFirstColumn, ApplyLastColumn, AutoFit, AutoFitBehavior, DefaultTableBehavior]
        return self.ConvertToTable(*arguments)

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def CopyAsPicture(self):
        self.com_object.CopyAsPicture()

    def copyaspicture(self):
        """Alias for CopyAsPicture"""
        return self.CopyAsPicture()

    def copy_as_picture(self):
        """Alias for CopyAsPicture"""
        return self.CopyAsPicture()

    def Cut(self):
        self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def Delete(self, Unit=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Unit, Count]])
        return self.com_object.Delete(*arguments)

    def delete(self, Unit=None, Count=None):
        """Alias for Delete"""
        arguments = [Unit, Count]
        return self.Delete(*arguments)

    def DetectLanguage(self):
        self.com_object.DetectLanguage()

    def detectlanguage(self):
        """Alias for DetectLanguage"""
        return self.DetectLanguage()

    def detect_language(self):
        """Alias for DetectLanguage"""
        return self.DetectLanguage()

    def EndOf(self, Unit=None, Extend=None):
        arguments = com_arguments([unwrap(a) for a in [Unit, Extend]])
        self.com_object.EndOf(*arguments)

    def endof(self, Unit=None, Extend=None):
        """Alias for EndOf"""
        arguments = [Unit, Extend]
        return self.EndOf(*arguments)

    def end_of(self, Unit=None, Extend=None):
        """Alias for EndOf"""
        arguments = [Unit, Extend]
        return self.EndOf(*arguments)

    def Expand(self, Unit=None):
        arguments = com_arguments([unwrap(a) for a in [Unit]])
        self.com_object.Expand(*arguments)

    def expand(self, Unit=None):
        """Alias for Expand"""
        arguments = [Unit]
        return self.Expand(*arguments)

    def ExportAsFixedFormat(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, ExportCurrentPage=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, FixedFormatExtClassPtr=None):
        arguments = com_arguments([unwrap(a) for a in [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, ExportCurrentPage, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, FixedFormatExtClassPtr]])
        self.com_object.ExportAsFixedFormat(*arguments)

    def exportasfixedformat(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, ExportCurrentPage=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat"""
        arguments = [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, ExportCurrentPage, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat(*arguments)

    def export_as_fixed_format(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, ExportCurrentPage=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat"""
        arguments = [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, ExportCurrentPage, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat(*arguments)

    def ExportAsFixedFormat2(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, ExportCurrentPage=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, OptimizeForImageQuality=None, FixedFormatExtClassPtr=None):
        arguments = com_arguments([unwrap(a) for a in [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, ExportCurrentPage, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, OptimizeForImageQuality, FixedFormatExtClassPtr]])
        self.com_object.ExportAsFixedFormat2(*arguments)

    def exportasfixedformat2(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, ExportCurrentPage=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, OptimizeForImageQuality=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat2"""
        arguments = [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, ExportCurrentPage, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, OptimizeForImageQuality, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat2(*arguments)

    def export_as_fixed_format2(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, ExportCurrentPage=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, OptimizeForImageQuality=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat2"""
        arguments = [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, ExportCurrentPage, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, OptimizeForImageQuality, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat2(*arguments)

    def ExportAsFixedFormat3(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, ExportCurrentPage=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, OptimizeForImageQuality=None, ImproveExportTagging=None, FixedFormatExtClassPtr=None):
        arguments = com_arguments([unwrap(a) for a in [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, ExportCurrentPage, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, OptimizeForImageQuality, ImproveExportTagging, FixedFormatExtClassPtr]])
        self.com_object.ExportAsFixedFormat3(*arguments)

    def exportasfixedformat3(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, ExportCurrentPage=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, OptimizeForImageQuality=None, ImproveExportTagging=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat3"""
        arguments = [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, ExportCurrentPage, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, OptimizeForImageQuality, ImproveExportTagging, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat3(*arguments)

    def export_as_fixed_format3(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, ExportCurrentPage=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, OptimizeForImageQuality=None, ImproveExportTagging=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat3"""
        arguments = [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, ExportCurrentPage, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, OptimizeForImageQuality, ImproveExportTagging, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat3(*arguments)

    def ExportFragment(self, FileName=None, Format=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, Format]])
        return self.com_object.ExportFragment(*arguments)

    def exportfragment(self, FileName=None, Format=None):
        """Alias for ExportFragment"""
        arguments = [FileName, Format]
        return self.ExportFragment(*arguments)

    def export_fragment(self, FileName=None, Format=None):
        """Alias for ExportFragment"""
        arguments = [FileName, Format]
        return self.ExportFragment(*arguments)

    def GetSpellingSuggestions(self, CustomDictionary=None, IgnoreUppercase=None, MainDictionary=None, SuggestionMode=None, CustomDictionary2=None, CustomDictionary3=None, CustomDictionary4=None, CustomDictionary5=None, CustomDictionary6=None, CustomDictionary7=None, CustomDictionary8=None, CustomDictionary9=None, CustomDictionary10=None):
        arguments = com_arguments([unwrap(a) for a in [CustomDictionary, IgnoreUppercase, MainDictionary, SuggestionMode, CustomDictionary2, CustomDictionary3, CustomDictionary4, CustomDictionary5, CustomDictionary6, CustomDictionary7, CustomDictionary8, CustomDictionary9, CustomDictionary10]])
        return SpellingSuggestions(self.com_object.GetSpellingSuggestions(*arguments))

    def getspellingsuggestions(self, CustomDictionary=None, IgnoreUppercase=None, MainDictionary=None, SuggestionMode=None, CustomDictionary2=None, CustomDictionary3=None, CustomDictionary4=None, CustomDictionary5=None, CustomDictionary6=None, CustomDictionary7=None, CustomDictionary8=None, CustomDictionary9=None, CustomDictionary10=None):
        """Alias for GetSpellingSuggestions"""
        arguments = [CustomDictionary, IgnoreUppercase, MainDictionary, SuggestionMode, CustomDictionary2, CustomDictionary3, CustomDictionary4, CustomDictionary5, CustomDictionary6, CustomDictionary7, CustomDictionary8, CustomDictionary9, CustomDictionary10]
        return self.GetSpellingSuggestions(*arguments)

    def get_spelling_suggestions(self, CustomDictionary=None, IgnoreUppercase=None, MainDictionary=None, SuggestionMode=None, CustomDictionary2=None, CustomDictionary3=None, CustomDictionary4=None, CustomDictionary5=None, CustomDictionary6=None, CustomDictionary7=None, CustomDictionary8=None, CustomDictionary9=None, CustomDictionary10=None):
        """Alias for GetSpellingSuggestions"""
        arguments = [CustomDictionary, IgnoreUppercase, MainDictionary, SuggestionMode, CustomDictionary2, CustomDictionary3, CustomDictionary4, CustomDictionary5, CustomDictionary6, CustomDictionary7, CustomDictionary8, CustomDictionary9, CustomDictionary10]
        return self.GetSpellingSuggestions(*arguments)

    def GoTo(self, What=None, Which=None, Count=None, Name=None):
        arguments = com_arguments([unwrap(a) for a in [What, Which, Count, Name]])
        self.com_object.GoTo(*arguments)

    def goto(self, What=None, Which=None, Count=None, Name=None):
        """Alias for GoTo"""
        arguments = [What, Which, Count, Name]
        return self.GoTo(*arguments)

    def go_to(self, What=None, Which=None, Count=None, Name=None):
        """Alias for GoTo"""
        arguments = [What, Which, Count, Name]
        return self.GoTo(*arguments)

    def GoToEditableRange(self, EditorID=None):
        arguments = com_arguments([unwrap(a) for a in [EditorID]])
        self.com_object.GoToEditableRange(*arguments)

    def gotoeditablerange(self, EditorID=None):
        """Alias for GoToEditableRange"""
        arguments = [EditorID]
        return self.GoToEditableRange(*arguments)

    def go_to_editable_range(self, EditorID=None):
        """Alias for GoToEditableRange"""
        arguments = [EditorID]
        return self.GoToEditableRange(*arguments)

    def GoToNext(self, What=None):
        arguments = com_arguments([unwrap(a) for a in [What]])
        self.com_object.GoToNext(*arguments)

    def gotonext(self, What=None):
        """Alias for GoToNext"""
        arguments = [What]
        return self.GoToNext(*arguments)

    def go_to_next(self, What=None):
        """Alias for GoToNext"""
        arguments = [What]
        return self.GoToNext(*arguments)

    def GoToPrevious(self, What=None):
        arguments = com_arguments([unwrap(a) for a in [What]])
        self.com_object.GoToPrevious(*arguments)

    def gotoprevious(self, What=None):
        """Alias for GoToPrevious"""
        arguments = [What]
        return self.GoToPrevious(*arguments)

    def go_to_previous(self, What=None):
        """Alias for GoToPrevious"""
        arguments = [What]
        return self.GoToPrevious(*arguments)

    def ImportFragment(self, FileName=None, MatchDestination=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, MatchDestination]])
        return self.com_object.ImportFragment(*arguments)

    def importfragment(self, FileName=None, MatchDestination=None):
        """Alias for ImportFragment"""
        arguments = [FileName, MatchDestination]
        return self.ImportFragment(*arguments)

    def import_fragment(self, FileName=None, MatchDestination=None):
        """Alias for ImportFragment"""
        arguments = [FileName, MatchDestination]
        return self.ImportFragment(*arguments)

    def InRange(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        return self.com_object.InRange(*arguments)

    def inrange(self, Range=None):
        """Alias for InRange"""
        arguments = [Range]
        return self.InRange(*arguments)

    def in_range(self, Range=None):
        """Alias for InRange"""
        arguments = [Range]
        return self.InRange(*arguments)

    def InsertAfter(self, Text=None):
        arguments = com_arguments([unwrap(a) for a in [Text]])
        self.com_object.InsertAfter(*arguments)

    def insertafter(self, Text=None):
        """Alias for InsertAfter"""
        arguments = [Text]
        return self.InsertAfter(*arguments)

    def insert_after(self, Text=None):
        """Alias for InsertAfter"""
        arguments = [Text]
        return self.InsertAfter(*arguments)

    def InsertAlignmentTab(self, Alignment=None, RelativeTo=None):
        arguments = com_arguments([unwrap(a) for a in [Alignment, RelativeTo]])
        self.com_object.InsertAlignmentTab(*arguments)

    def insertalignmenttab(self, Alignment=None, RelativeTo=None):
        """Alias for InsertAlignmentTab"""
        arguments = [Alignment, RelativeTo]
        return self.InsertAlignmentTab(*arguments)

    def insert_alignment_tab(self, Alignment=None, RelativeTo=None):
        """Alias for InsertAlignmentTab"""
        arguments = [Alignment, RelativeTo]
        return self.InsertAlignmentTab(*arguments)

    def InsertAutoText(self):
        self.com_object.InsertAutoText()

    def insertautotext(self):
        """Alias for InsertAutoText"""
        return self.InsertAutoText()

    def insert_auto_text(self):
        """Alias for InsertAutoText"""
        return self.InsertAutoText()

    def InsertBefore(self, Text=None):
        arguments = com_arguments([unwrap(a) for a in [Text]])
        self.com_object.InsertBefore(*arguments)

    def insertbefore(self, Text=None):
        """Alias for InsertBefore"""
        arguments = [Text]
        return self.InsertBefore(*arguments)

    def insert_before(self, Text=None):
        """Alias for InsertBefore"""
        arguments = [Text]
        return self.InsertBefore(*arguments)

    def InsertBreak(self, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Type]])
        self.com_object.InsertBreak(*arguments)

    def insertbreak(self, Type=None):
        """Alias for InsertBreak"""
        arguments = [Type]
        return self.InsertBreak(*arguments)

    def insert_break(self, Type=None):
        """Alias for InsertBreak"""
        arguments = [Type]
        return self.InsertBreak(*arguments)

    def InsertCaption(self, Label=None, Title=None, TitleAutoText=None, Position=None, ExcludeLabel=None):
        arguments = com_arguments([unwrap(a) for a in [Label, Title, TitleAutoText, Position, ExcludeLabel]])
        self.com_object.InsertCaption(*arguments)

    def insertcaption(self, Label=None, Title=None, TitleAutoText=None, Position=None, ExcludeLabel=None):
        """Alias for InsertCaption"""
        arguments = [Label, Title, TitleAutoText, Position, ExcludeLabel]
        return self.InsertCaption(*arguments)

    def insert_caption(self, Label=None, Title=None, TitleAutoText=None, Position=None, ExcludeLabel=None):
        """Alias for InsertCaption"""
        arguments = [Label, Title, TitleAutoText, Position, ExcludeLabel]
        return self.InsertCaption(*arguments)

    def InsertCrossReference(self, ReferenceType=None, ReferenceKind=None, ReferenceItem=None, InsertAsHyperlink=None, IncludePosition=None, SeparateNumbers=None, SeparatorString=None):
        arguments = com_arguments([unwrap(a) for a in [ReferenceType, ReferenceKind, ReferenceItem, InsertAsHyperlink, IncludePosition, SeparateNumbers, SeparatorString]])
        self.com_object.InsertCrossReference(*arguments)

    def insertcrossreference(self, ReferenceType=None, ReferenceKind=None, ReferenceItem=None, InsertAsHyperlink=None, IncludePosition=None, SeparateNumbers=None, SeparatorString=None):
        """Alias for InsertCrossReference"""
        arguments = [ReferenceType, ReferenceKind, ReferenceItem, InsertAsHyperlink, IncludePosition, SeparateNumbers, SeparatorString]
        return self.InsertCrossReference(*arguments)

    def insert_cross_reference(self, ReferenceType=None, ReferenceKind=None, ReferenceItem=None, InsertAsHyperlink=None, IncludePosition=None, SeparateNumbers=None, SeparatorString=None):
        """Alias for InsertCrossReference"""
        arguments = [ReferenceType, ReferenceKind, ReferenceItem, InsertAsHyperlink, IncludePosition, SeparateNumbers, SeparatorString]
        return self.InsertCrossReference(*arguments)

    def InsertDatabase(self, Format=None, Style=None, LinkToSource=None, Connection=None, SQLStatement=None, SQLStatement1=None, PasswordDocument=None, PasswordTemplate=None, WritePasswordDocument=None, WritePasswordTemplate=None, DataSource=None, From=None, To=None, IncludeFields=None):
        arguments = com_arguments([unwrap(a) for a in [Format, Style, LinkToSource, Connection, SQLStatement, SQLStatement1, PasswordDocument, PasswordTemplate, WritePasswordDocument, WritePasswordTemplate, DataSource, From, To, IncludeFields]])
        self.com_object.InsertDatabase(*arguments)

    def insertdatabase(self, Format=None, Style=None, LinkToSource=None, Connection=None, SQLStatement=None, SQLStatement1=None, PasswordDocument=None, PasswordTemplate=None, WritePasswordDocument=None, WritePasswordTemplate=None, DataSource=None, From=None, To=None, IncludeFields=None):
        """Alias for InsertDatabase"""
        arguments = [Format, Style, LinkToSource, Connection, SQLStatement, SQLStatement1, PasswordDocument, PasswordTemplate, WritePasswordDocument, WritePasswordTemplate, DataSource, From, To, IncludeFields]
        return self.InsertDatabase(*arguments)

    def insert_database(self, Format=None, Style=None, LinkToSource=None, Connection=None, SQLStatement=None, SQLStatement1=None, PasswordDocument=None, PasswordTemplate=None, WritePasswordDocument=None, WritePasswordTemplate=None, DataSource=None, From=None, To=None, IncludeFields=None):
        """Alias for InsertDatabase"""
        arguments = [Format, Style, LinkToSource, Connection, SQLStatement, SQLStatement1, PasswordDocument, PasswordTemplate, WritePasswordDocument, WritePasswordTemplate, DataSource, From, To, IncludeFields]
        return self.InsertDatabase(*arguments)

    def InsertDateTime(self, DateTimeFormat=None, InsertAsField=None, InsertAsFullWidth=None, DateLanguage=None, CalendarType=None):
        arguments = com_arguments([unwrap(a) for a in [DateTimeFormat, InsertAsField, InsertAsFullWidth, DateLanguage, CalendarType]])
        self.com_object.InsertDateTime(*arguments)

    def insertdatetime(self, DateTimeFormat=None, InsertAsField=None, InsertAsFullWidth=None, DateLanguage=None, CalendarType=None):
        """Alias for InsertDateTime"""
        arguments = [DateTimeFormat, InsertAsField, InsertAsFullWidth, DateLanguage, CalendarType]
        return self.InsertDateTime(*arguments)

    def insert_date_time(self, DateTimeFormat=None, InsertAsField=None, InsertAsFullWidth=None, DateLanguage=None, CalendarType=None):
        """Alias for InsertDateTime"""
        arguments = [DateTimeFormat, InsertAsField, InsertAsFullWidth, DateLanguage, CalendarType]
        return self.InsertDateTime(*arguments)

    def InsertFile(self, FileName=None, Range=None, ConfirmConversions=None, Link=None, Attachment=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, Range, ConfirmConversions, Link, Attachment]])
        self.com_object.InsertFile(*arguments)

    def insertfile(self, FileName=None, Range=None, ConfirmConversions=None, Link=None, Attachment=None):
        """Alias for InsertFile"""
        arguments = [FileName, Range, ConfirmConversions, Link, Attachment]
        return self.InsertFile(*arguments)

    def insert_file(self, FileName=None, Range=None, ConfirmConversions=None, Link=None, Attachment=None):
        """Alias for InsertFile"""
        arguments = [FileName, Range, ConfirmConversions, Link, Attachment]
        return self.InsertFile(*arguments)

    def InsertParagraph(self):
        self.com_object.InsertParagraph()

    def insertparagraph(self):
        """Alias for InsertParagraph"""
        return self.InsertParagraph()

    def insert_paragraph(self):
        """Alias for InsertParagraph"""
        return self.InsertParagraph()

    def InsertParagraphAfter(self):
        self.com_object.InsertParagraphAfter()

    def insertparagraphafter(self):
        """Alias for InsertParagraphAfter"""
        return self.InsertParagraphAfter()

    def insert_paragraph_after(self):
        """Alias for InsertParagraphAfter"""
        return self.InsertParagraphAfter()

    def InsertParagraphBefore(self):
        self.com_object.InsertParagraphBefore()

    def insertparagraphbefore(self):
        """Alias for InsertParagraphBefore"""
        return self.InsertParagraphBefore()

    def insert_paragraph_before(self):
        """Alias for InsertParagraphBefore"""
        return self.InsertParagraphBefore()

    def InsertSymbol(self, CharacterNumber=None, Font=None, Unicode=None, Bias=None):
        arguments = com_arguments([unwrap(a) for a in [CharacterNumber, Font, Unicode, Bias]])
        self.com_object.InsertSymbol(*arguments)

    def insertsymbol(self, CharacterNumber=None, Font=None, Unicode=None, Bias=None):
        """Alias for InsertSymbol"""
        arguments = [CharacterNumber, Font, Unicode, Bias]
        return self.InsertSymbol(*arguments)

    def insert_symbol(self, CharacterNumber=None, Font=None, Unicode=None, Bias=None):
        """Alias for InsertSymbol"""
        arguments = [CharacterNumber, Font, Unicode, Bias]
        return self.InsertSymbol(*arguments)

    def InsertXML(self, XML=None, Transform=None):
        arguments = com_arguments([unwrap(a) for a in [XML, Transform]])
        return self.com_object.InsertXML(*arguments)

    def insertxml(self, XML=None, Transform=None):
        """Alias for InsertXML"""
        arguments = [XML, Transform]
        return self.InsertXML(*arguments)

    def insert_x_m_l(self, XML=None, Transform=None):
        """Alias for InsertXML"""
        arguments = [XML, Transform]
        return self.InsertXML(*arguments)

    def InStory(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        return self.com_object.InStory(*arguments)

    def instory(self, Range=None):
        """Alias for InStory"""
        arguments = [Range]
        return self.InStory(*arguments)

    def in_story(self, Range=None):
        """Alias for InStory"""
        arguments = [Range]
        return self.InStory(*arguments)

    def IsEqual(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        return self.com_object.IsEqual(*arguments)

    def isequal(self, Range=None):
        """Alias for IsEqual"""
        arguments = [Range]
        return self.IsEqual(*arguments)

    def is_equal(self, Range=None):
        """Alias for IsEqual"""
        arguments = [Range]
        return self.IsEqual(*arguments)

    def LookupNameProperties(self):
        self.com_object.LookupNameProperties()

    def lookupnameproperties(self):
        """Alias for LookupNameProperties"""
        return self.LookupNameProperties()

    def lookup_name_properties(self):
        """Alias for LookupNameProperties"""
        return self.LookupNameProperties()

    def ModifyEnclosure(self, Style=None, Symbol=None, EnclosedText=None):
        arguments = com_arguments([unwrap(a) for a in [Style, Symbol, EnclosedText]])
        self.com_object.ModifyEnclosure(*arguments)

    def modifyenclosure(self, Style=None, Symbol=None, EnclosedText=None):
        """Alias for ModifyEnclosure"""
        arguments = [Style, Symbol, EnclosedText]
        return self.ModifyEnclosure(*arguments)

    def modify_enclosure(self, Style=None, Symbol=None, EnclosedText=None):
        """Alias for ModifyEnclosure"""
        arguments = [Style, Symbol, EnclosedText]
        return self.ModifyEnclosure(*arguments)

    def Move(self, Unit=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Unit, Count]])
        return self.com_object.Move(*arguments)

    def move(self, Unit=None, Count=None):
        """Alias for Move"""
        arguments = [Unit, Count]
        return self.Move(*arguments)

    def MoveEnd(self, Unit=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Unit, Count]])
        self.com_object.MoveEnd(*arguments)

    def moveend(self, Unit=None, Count=None):
        """Alias for MoveEnd"""
        arguments = [Unit, Count]
        return self.MoveEnd(*arguments)

    def move_end(self, Unit=None, Count=None):
        """Alias for MoveEnd"""
        arguments = [Unit, Count]
        return self.MoveEnd(*arguments)

    def MoveEndUntil(self, Cset=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Cset, Count]])
        self.com_object.MoveEndUntil(*arguments)

    def moveenduntil(self, Cset=None, Count=None):
        """Alias for MoveEndUntil"""
        arguments = [Cset, Count]
        return self.MoveEndUntil(*arguments)

    def move_end_until(self, Cset=None, Count=None):
        """Alias for MoveEndUntil"""
        arguments = [Cset, Count]
        return self.MoveEndUntil(*arguments)

    def MoveEndWhile(self, Cset=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Cset, Count]])
        self.com_object.MoveEndWhile(*arguments)

    def moveendwhile(self, Cset=None, Count=None):
        """Alias for MoveEndWhile"""
        arguments = [Cset, Count]
        return self.MoveEndWhile(*arguments)

    def move_end_while(self, Cset=None, Count=None):
        """Alias for MoveEndWhile"""
        arguments = [Cset, Count]
        return self.MoveEndWhile(*arguments)

    def MoveStart(self, Unit=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Unit, Count]])
        return self.com_object.MoveStart(*arguments)

    def movestart(self, Unit=None, Count=None):
        """Alias for MoveStart"""
        arguments = [Unit, Count]
        return self.MoveStart(*arguments)

    def move_start(self, Unit=None, Count=None):
        """Alias for MoveStart"""
        arguments = [Unit, Count]
        return self.MoveStart(*arguments)

    def MoveStartUntil(self, Cset=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Cset, Count]])
        self.com_object.MoveStartUntil(*arguments)

    def movestartuntil(self, Cset=None, Count=None):
        """Alias for MoveStartUntil"""
        arguments = [Cset, Count]
        return self.MoveStartUntil(*arguments)

    def move_start_until(self, Cset=None, Count=None):
        """Alias for MoveStartUntil"""
        arguments = [Cset, Count]
        return self.MoveStartUntil(*arguments)

    def MoveStartWhile(self, Cset=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Cset, Count]])
        self.com_object.MoveStartWhile(*arguments)

    def movestartwhile(self, Cset=None, Count=None):
        """Alias for MoveStartWhile"""
        arguments = [Cset, Count]
        return self.MoveStartWhile(*arguments)

    def move_start_while(self, Cset=None, Count=None):
        """Alias for MoveStartWhile"""
        arguments = [Cset, Count]
        return self.MoveStartWhile(*arguments)

    def MoveUntil(self, Cset=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Cset, Count]])
        self.com_object.MoveUntil(*arguments)

    def moveuntil(self, Cset=None, Count=None):
        """Alias for MoveUntil"""
        arguments = [Cset, Count]
        return self.MoveUntil(*arguments)

    def move_until(self, Cset=None, Count=None):
        """Alias for MoveUntil"""
        arguments = [Cset, Count]
        return self.MoveUntil(*arguments)

    def MoveWhile(self, Cset=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Cset, Count]])
        self.com_object.MoveWhile(*arguments)

    def movewhile(self, Cset=None, Count=None):
        """Alias for MoveWhile"""
        arguments = [Cset, Count]
        return self.MoveWhile(*arguments)

    def move_while(self, Cset=None, Count=None):
        """Alias for MoveWhile"""
        arguments = [Cset, Count]
        return self.MoveWhile(*arguments)

    def Next(self, Unit=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Unit, Count]])
        return Range(self.com_object.Next(*arguments))

    def next(self, Unit=None, Count=None):
        """Alias for Next"""
        arguments = [Unit, Count]
        return self.Next(*arguments)

    def NextSubdocument(self):
        self.com_object.NextSubdocument()

    def nextsubdocument(self):
        """Alias for NextSubdocument"""
        return self.NextSubdocument()

    def next_subdocument(self):
        """Alias for NextSubdocument"""
        return self.NextSubdocument()

    def Paste(self):
        self.com_object.Paste()

    def paste(self):
        """Alias for Paste"""
        return self.Paste()

    def PasteAndFormat(self, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Type]])
        self.com_object.PasteAndFormat(*arguments)

    def pasteandformat(self, Type=None):
        """Alias for PasteAndFormat"""
        arguments = [Type]
        return self.PasteAndFormat(*arguments)

    def paste_and_format(self, Type=None):
        """Alias for PasteAndFormat"""
        arguments = [Type]
        return self.PasteAndFormat(*arguments)

    def PasteAppendTable(self):
        self.com_object.PasteAppendTable()

    def pasteappendtable(self):
        """Alias for PasteAppendTable"""
        return self.PasteAppendTable()

    def paste_append_table(self):
        """Alias for PasteAppendTable"""
        return self.PasteAppendTable()

    def PasteAsNestedTable(self):
        self.com_object.PasteAsNestedTable()

    def pasteasnestedtable(self):
        """Alias for PasteAsNestedTable"""
        return self.PasteAsNestedTable()

    def paste_as_nested_table(self):
        """Alias for PasteAsNestedTable"""
        return self.PasteAsNestedTable()

    def PasteExcelTable(self, LinkedToExcel=None, WordFormatting=None, RTF=None):
        arguments = com_arguments([unwrap(a) for a in [LinkedToExcel, WordFormatting, RTF]])
        self.com_object.PasteExcelTable(*arguments)

    def pasteexceltable(self, LinkedToExcel=None, WordFormatting=None, RTF=None):
        """Alias for PasteExcelTable"""
        arguments = [LinkedToExcel, WordFormatting, RTF]
        return self.PasteExcelTable(*arguments)

    def paste_excel_table(self, LinkedToExcel=None, WordFormatting=None, RTF=None):
        """Alias for PasteExcelTable"""
        arguments = [LinkedToExcel, WordFormatting, RTF]
        return self.PasteExcelTable(*arguments)

    def PasteSpecial(self, IconIndex=None, Link=None, Placement=None, DisplayAsIcon=None, DataType=None, IconFileName=None, IconLabel=None):
        arguments = com_arguments([unwrap(a) for a in [IconIndex, Link, Placement, DisplayAsIcon, DataType, IconFileName, IconLabel]])
        self.com_object.PasteSpecial(*arguments)

    def pastespecial(self, IconIndex=None, Link=None, Placement=None, DisplayAsIcon=None, DataType=None, IconFileName=None, IconLabel=None):
        """Alias for PasteSpecial"""
        arguments = [IconIndex, Link, Placement, DisplayAsIcon, DataType, IconFileName, IconLabel]
        return self.PasteSpecial(*arguments)

    def paste_special(self, IconIndex=None, Link=None, Placement=None, DisplayAsIcon=None, DataType=None, IconFileName=None, IconLabel=None):
        """Alias for PasteSpecial"""
        arguments = [IconIndex, Link, Placement, DisplayAsIcon, DataType, IconFileName, IconLabel]
        return self.PasteSpecial(*arguments)

    def PhoneticGuide(self, Text=None, Alignment=None, Raise=None, FontSize=None, FontName=None):
        arguments = com_arguments([unwrap(a) for a in [Text, Alignment, Raise, FontSize, FontName]])
        self.com_object.PhoneticGuide(*arguments)

    def phoneticguide(self, Text=None, Alignment=None, Raise=None, FontSize=None, FontName=None):
        """Alias for PhoneticGuide"""
        arguments = [Text, Alignment, Raise, FontSize, FontName]
        return self.PhoneticGuide(*arguments)

    def phonetic_guide(self, Text=None, Alignment=None, Raise=None, FontSize=None, FontName=None):
        """Alias for PhoneticGuide"""
        arguments = [Text, Alignment, Raise, FontSize, FontName]
        return self.PhoneticGuide(*arguments)

    def Previous(self, Unit=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Unit, Count]])
        return Range(self.com_object.Previous(*arguments))

    def previous(self, Unit=None, Count=None):
        """Alias for Previous"""
        arguments = [Unit, Count]
        return self.Previous(*arguments)

    def PreviousSubdocument(self):
        self.com_object.PreviousSubdocument()

    def previoussubdocument(self):
        """Alias for PreviousSubdocument"""
        return self.PreviousSubdocument()

    def previous_subdocument(self):
        """Alias for PreviousSubdocument"""
        return self.PreviousSubdocument()

    def Relocate(self, Direction=None):
        arguments = com_arguments([unwrap(a) for a in [Direction]])
        self.com_object.Relocate(*arguments)

    def relocate(self, Direction=None):
        """Alias for Relocate"""
        arguments = [Direction]
        return self.Relocate(*arguments)

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()

    def SetListLevel(self, Level=None):
        arguments = com_arguments([unwrap(a) for a in [Level]])
        self.com_object.SetListLevel(*arguments)

    def setlistlevel(self, Level=None):
        """Alias for SetListLevel"""
        arguments = [Level]
        return self.SetListLevel(*arguments)

    def set_list_level(self, Level=None):
        """Alias for SetListLevel"""
        arguments = [Level]
        return self.SetListLevel(*arguments)

    def SetRange(self, Start=None, End=None):
        arguments = com_arguments([unwrap(a) for a in [Start, End]])
        self.com_object.SetRange(*arguments)

    def setrange(self, Start=None, End=None):
        """Alias for SetRange"""
        arguments = [Start, End]
        return self.SetRange(*arguments)

    def set_range(self, Start=None, End=None):
        """Alias for SetRange"""
        arguments = [Start, End]
        return self.SetRange(*arguments)

    def Sort(self, ExcludeHeader=None, FieldNumber=None, SortFieldType=None, SortOrder=None, FieldNumber2=None, SortFieldType2=None, SortOrder2=None, FieldNumber3=None, SortFieldType3=None, SortOrder3=None, SortColumn=None, Separator=None, CaseSensitive=None, BidiSort=None, IgnoreThe=None, IgnoreKashida=None, IgnoreDiacritics=None, IgnoreHe=None, LanguageID=None):
        arguments = com_arguments([unwrap(a) for a in [ExcludeHeader, FieldNumber, SortFieldType, SortOrder, FieldNumber2, SortFieldType2, SortOrder2, FieldNumber3, SortFieldType3, SortOrder3, SortColumn, Separator, CaseSensitive, BidiSort, IgnoreThe, IgnoreKashida, IgnoreDiacritics, IgnoreHe, LanguageID]])
        self.com_object.Sort(*arguments)

    def sort(self, ExcludeHeader=None, FieldNumber=None, SortFieldType=None, SortOrder=None, FieldNumber2=None, SortFieldType2=None, SortOrder2=None, FieldNumber3=None, SortFieldType3=None, SortOrder3=None, SortColumn=None, Separator=None, CaseSensitive=None, BidiSort=None, IgnoreThe=None, IgnoreKashida=None, IgnoreDiacritics=None, IgnoreHe=None, LanguageID=None):
        """Alias for Sort"""
        arguments = [ExcludeHeader, FieldNumber, SortFieldType, SortOrder, FieldNumber2, SortFieldType2, SortOrder2, FieldNumber3, SortFieldType3, SortOrder3, SortColumn, Separator, CaseSensitive, BidiSort, IgnoreThe, IgnoreKashida, IgnoreDiacritics, IgnoreHe, LanguageID]
        return self.Sort(*arguments)

    def SortAscending(self):
        self.com_object.SortAscending()

    def sortascending(self):
        """Alias for SortAscending"""
        return self.SortAscending()

    def sort_ascending(self):
        """Alias for SortAscending"""
        return self.SortAscending()

    def SortByHeadings(self, SortFieldType=None, SortOrder=None, CaseSensitive=None, BidiSort=None, IgnoreThe=None, IgnoreKashida=None, IgnoreDiacritics=None, IgnoreHe=None, LanguageID=None):
        arguments = com_arguments([unwrap(a) for a in [SortFieldType, SortOrder, CaseSensitive, BidiSort, IgnoreThe, IgnoreKashida, IgnoreDiacritics, IgnoreHe, LanguageID]])
        return self.com_object.SortByHeadings(*arguments)

    def sortbyheadings(self, SortFieldType=None, SortOrder=None, CaseSensitive=None, BidiSort=None, IgnoreThe=None, IgnoreKashida=None, IgnoreDiacritics=None, IgnoreHe=None, LanguageID=None):
        """Alias for SortByHeadings"""
        arguments = [SortFieldType, SortOrder, CaseSensitive, BidiSort, IgnoreThe, IgnoreKashida, IgnoreDiacritics, IgnoreHe, LanguageID]
        return self.SortByHeadings(*arguments)

    def sort_by_headings(self, SortFieldType=None, SortOrder=None, CaseSensitive=None, BidiSort=None, IgnoreThe=None, IgnoreKashida=None, IgnoreDiacritics=None, IgnoreHe=None, LanguageID=None):
        """Alias for SortByHeadings"""
        arguments = [SortFieldType, SortOrder, CaseSensitive, BidiSort, IgnoreThe, IgnoreKashida, IgnoreDiacritics, IgnoreHe, LanguageID]
        return self.SortByHeadings(*arguments)

    def SortDescending(self):
        self.com_object.SortDescending()

    def sortdescending(self):
        """Alias for SortDescending"""
        return self.SortDescending()

    def sort_descending(self):
        """Alias for SortDescending"""
        return self.SortDescending()

    def StartOf(self, Unit=None, Extend=None):
        arguments = com_arguments([unwrap(a) for a in [Unit, Extend]])
        self.com_object.StartOf(*arguments)

    def startof(self, Unit=None, Extend=None):
        """Alias for StartOf"""
        arguments = [Unit, Extend]
        return self.StartOf(*arguments)

    def start_of(self, Unit=None, Extend=None):
        """Alias for StartOf"""
        arguments = [Unit, Extend]
        return self.StartOf(*arguments)

    def TCSCConverter(self, WdTCSCConverterDirection=None, CommonTerms=None, UseVariants=None):
        arguments = com_arguments([unwrap(a) for a in [WdTCSCConverterDirection, CommonTerms, UseVariants]])
        self.com_object.TCSCConverter(*arguments)

    def tcscconverter(self, WdTCSCConverterDirection=None, CommonTerms=None, UseVariants=None):
        """Alias for TCSCConverter"""
        arguments = [WdTCSCConverterDirection, CommonTerms, UseVariants]
        return self.TCSCConverter(*arguments)

    def t_c_s_c_converter(self, WdTCSCConverterDirection=None, CommonTerms=None, UseVariants=None):
        """Alias for TCSCConverter"""
        arguments = [WdTCSCConverterDirection, CommonTerms, UseVariants]
        return self.TCSCConverter(*arguments)

    def WholeStory(self):
        self.com_object.WholeStory()

    def wholestory(self):
        """Alias for WholeStory"""
        return self.WholeStory()

    def whole_story(self):
        """Alias for WholeStory"""
        return self.WholeStory()


class ReadabilityStatistic:

    def __init__(self, readabilitystatistic=None):
        self.com_object= readabilitystatistic

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Value(self):
        return self.com_object.Value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value


class ReadabilityStatistics:

    def __init__(self, readabilitystatistics=None):
        self.com_object= readabilitystatistics

    def __call__(self, item):
        return ReadabilityStatistic(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ReadabilityStatistic(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class RecentFile:

    def __init__(self, recentfile=None):
        self.com_object= recentfile

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Path(self):
        return self.com_object.Path

    @property
    def path(self):
        """Alias for Path"""
        return self.Path

    @property
    def ReadOnly(self):
        return self.com_object.ReadOnly

    @ReadOnly.setter
    def ReadOnly(self, value):
        self.com_object.ReadOnly = value

    @property
    def readonly(self):
        """Alias for ReadOnly"""
        return self.ReadOnly

    @readonly.setter
    def readonly(self, value):
        """Alias for ReadOnly.setter"""
        self.ReadOnly = value

    @property
    def read_only(self):
        """Alias for ReadOnly"""
        return self.ReadOnly

    @read_only.setter
    def read_only(self, value):
        """Alias for ReadOnly.setter"""
        self.ReadOnly = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Open(self):
        return Document(self.com_object.Open())

    def open(self):
        """Alias for Open"""
        return self.Open()


class RecentFiles:

    def __init__(self, recentfiles=None):
        self.com_object= recentfiles

    def __call__(self, item):
        return RecentFile(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Maximum(self):
        return self.com_object.Maximum

    @Maximum.setter
    def Maximum(self, value):
        self.com_object.Maximum = value

    @property
    def maximum(self):
        """Alias for Maximum"""
        return self.Maximum

    @maximum.setter
    def maximum(self, value):
        """Alias for Maximum.setter"""
        self.Maximum = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Document=None, ReadOnly=None):
        arguments = com_arguments([unwrap(a) for a in [Document, ReadOnly]])
        return RecentFile(self.com_object.Add(*arguments))

    def add(self, Document=None, ReadOnly=None):
        """Alias for Add"""
        arguments = [Document, ReadOnly]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return RecentFile(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Rectangle:

    def __init__(self, rectangle=None):
        self.com_object= rectangle

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def Left(self):
        return self.com_object.Left

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @property
    def Lines(self):
        return Lines(self.com_object.Lines)

    @property
    def lines(self):
        """Alias for Lines"""
        return self.Lines

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def RectangleType(self):
        return WdRectangleType(self.com_object.RectangleType)

    @property
    def rectangletype(self):
        """Alias for RectangleType"""
        return self.RectangleType

    @property
    def rectangle_type(self):
        """Alias for RectangleType"""
        return self.RectangleType

    @property
    def Top(self):
        return self.com_object.Top

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value


class Rectangles:

    def __init__(self, rectangles=None):
        self.com_object= rectangles

    def __call__(self, item):
        return Rectangle(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Rectangle(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ReflectionFormat:

    def __init__(self, reflectionformat=None):
        self.com_object= reflectionformat

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Blur(self):
        return self.com_object.Blur

    @Blur.setter
    def Blur(self, value):
        self.com_object.Blur = value

    @property
    def blur(self):
        """Alias for Blur"""
        return self.Blur

    @blur.setter
    def blur(self, value):
        """Alias for Blur.setter"""
        self.Blur = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Offset(self):
        return self.com_object.Offset

    @Offset.setter
    def Offset(self, value):
        self.com_object.Offset = value

    @property
    def offset(self):
        """Alias for Offset"""
        return self.Offset

    @offset.setter
    def offset(self, value):
        """Alias for Offset.setter"""
        self.Offset = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Size(self):
        return self.com_object.Size

    @Size.setter
    def Size(self, value):
        self.com_object.Size = value

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @size.setter
    def size(self, value):
        """Alias for Size.setter"""
        self.Size = value

    @property
    def Transparency(self):
        return self.com_object.Transparency

    @Transparency.setter
    def Transparency(self, value):
        self.com_object.Transparency = value

    @property
    def transparency(self):
        """Alias for Transparency"""
        return self.Transparency

    @transparency.setter
    def transparency(self, value):
        """Alias for Transparency.setter"""
        self.Transparency = value

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value


class RepeatingSectionItem:

    def __init__(self, repeatingsectionitem=None):
        self.com_object= repeatingsectionitem

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return self.com_object.Range

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def InsertItemAfter(self):
        return REPEATINGSECTIONITEM(self.com_object.InsertItemAfter())

    def insertitemafter(self):
        """Alias for InsertItemAfter"""
        return self.InsertItemAfter()

    def insert_item_after(self):
        """Alias for InsertItemAfter"""
        return self.InsertItemAfter()

    def InsertItemBefore(self):
        return REPEATINGSECTIONITEM(self.com_object.InsertItemBefore())

    def insertitembefore(self):
        """Alias for InsertItemBefore"""
        return self.InsertItemBefore()

    def insert_item_before(self):
        """Alias for InsertItemBefore"""
        return self.InsertItemBefore()


class RepeatingSectionItemColl:

    def __init__(self, repeatingsectionitemcoll=None):
        self.com_object= repeatingsectionitemcoll

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return REPEATINGSECTIONITEM(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Replacement:

    def __init__(self, replacement=None):
        self.com_object= replacement

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @Font.setter
    def Font(self, value):
        self.com_object.Font = value

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @font.setter
    def font(self, value):
        """Alias for Font.setter"""
        self.Font = value

    @property
    def Frame(self):
        return Frame(self.com_object.Frame)

    @property
    def frame(self):
        """Alias for Frame"""
        return self.Frame

    @property
    def Highlight(self):
        return self.com_object.Highlight

    @Highlight.setter
    def Highlight(self, value):
        self.com_object.Highlight = value

    @property
    def highlight(self):
        """Alias for Highlight"""
        return self.Highlight

    @highlight.setter
    def highlight(self, value):
        """Alias for Highlight.setter"""
        self.Highlight = value

    @property
    def LanguageID(self):
        return WdLanguageID(self.com_object.LanguageID)

    @LanguageID.setter
    def LanguageID(self, value):
        self.com_object.LanguageID = value

    @property
    def languageid(self):
        """Alias for LanguageID"""
        return self.LanguageID

    @languageid.setter
    def languageid(self, value):
        """Alias for LanguageID.setter"""
        self.LanguageID = value

    @property
    def language_i_d(self):
        """Alias for LanguageID"""
        return self.LanguageID

    @language_i_d.setter
    def language_i_d(self, value):
        """Alias for LanguageID.setter"""
        self.LanguageID = value

    @property
    def LanguageIDFarEast(self):
        return WdLanguageID(self.com_object.LanguageIDFarEast)

    @LanguageIDFarEast.setter
    def LanguageIDFarEast(self, value):
        self.com_object.LanguageIDFarEast = value

    @property
    def languageidfareast(self):
        """Alias for LanguageIDFarEast"""
        return self.LanguageIDFarEast

    @languageidfareast.setter
    def languageidfareast(self, value):
        """Alias for LanguageIDFarEast.setter"""
        self.LanguageIDFarEast = value

    @property
    def language_i_d_far_east(self):
        """Alias for LanguageIDFarEast"""
        return self.LanguageIDFarEast

    @language_i_d_far_east.setter
    def language_i_d_far_east(self, value):
        """Alias for LanguageIDFarEast.setter"""
        self.LanguageIDFarEast = value

    @property
    def NoProofing(self):
        return self.com_object.NoProofing

    @NoProofing.setter
    def NoProofing(self, value):
        self.com_object.NoProofing = value

    @property
    def noproofing(self):
        """Alias for NoProofing"""
        return self.NoProofing

    @noproofing.setter
    def noproofing(self, value):
        """Alias for NoProofing.setter"""
        self.NoProofing = value

    @property
    def no_proofing(self):
        """Alias for NoProofing"""
        return self.NoProofing

    @no_proofing.setter
    def no_proofing(self, value):
        """Alias for NoProofing.setter"""
        self.NoProofing = value

    @property
    def ParagraphFormat(self):
        return ParagraphFormat(self.com_object.ParagraphFormat)

    @ParagraphFormat.setter
    def ParagraphFormat(self, value):
        self.com_object.ParagraphFormat = value

    @property
    def paragraphformat(self):
        """Alias for ParagraphFormat"""
        return self.ParagraphFormat

    @paragraphformat.setter
    def paragraphformat(self, value):
        """Alias for ParagraphFormat.setter"""
        self.ParagraphFormat = value

    @property
    def paragraph_format(self):
        """Alias for ParagraphFormat"""
        return self.ParagraphFormat

    @paragraph_format.setter
    def paragraph_format(self, value):
        """Alias for ParagraphFormat.setter"""
        self.ParagraphFormat = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Style(self):
        return WdBuiltinStyle(self.com_object.Style)

    @Style.setter
    def Style(self, value):
        self.com_object.Style = value

    @property
    def style(self):
        """Alias for Style"""
        return self.Style

    @style.setter
    def style(self, value):
        """Alias for Style.setter"""
        self.Style = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    def ClearFormatting(self):
        self.com_object.ClearFormatting()

    def clearformatting(self):
        """Alias for ClearFormatting"""
        return self.ClearFormatting()

    def clear_formatting(self):
        """Alias for ClearFormatting"""
        return self.ClearFormatting()


class Research:

    def __init__(self, research=None):
        self.com_object= research

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def FavoriteService(self):
        return self.com_object.FavoriteService

    @FavoriteService.setter
    def FavoriteService(self, value):
        self.com_object.FavoriteService = value

    @property
    def favoriteservice(self):
        """Alias for FavoriteService"""
        return self.FavoriteService

    @favoriteservice.setter
    def favoriteservice(self, value):
        """Alias for FavoriteService.setter"""
        self.FavoriteService = value

    @property
    def favorite_service(self):
        """Alias for FavoriteService"""
        return self.FavoriteService

    @favorite_service.setter
    def favorite_service(self, value):
        """Alias for FavoriteService.setter"""
        self.FavoriteService = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def IsResearchService(self, ServiceID=None):
        arguments = com_arguments([unwrap(a) for a in [ServiceID]])
        return self.com_object.IsResearchService(*arguments)

    def isresearchservice(self, ServiceID=None):
        """Alias for IsResearchService"""
        arguments = [ServiceID]
        return self.IsResearchService(*arguments)

    def is_research_service(self, ServiceID=None):
        """Alias for IsResearchService"""
        arguments = [ServiceID]
        return self.IsResearchService(*arguments)

    def Query(self, ServiceID=None, QueryString=None, QueryLanguage=None, UseSelection=None, RequeryContextXML=None, NewQueryContextXML=None, LaunchQuery=None):
        arguments = com_arguments([unwrap(a) for a in [ServiceID, QueryString, QueryLanguage, UseSelection, RequeryContextXML, NewQueryContextXML, LaunchQuery]])
        return self.com_object.Query(*arguments)

    def query(self, ServiceID=None, QueryString=None, QueryLanguage=None, UseSelection=None, RequeryContextXML=None, NewQueryContextXML=None, LaunchQuery=None):
        """Alias for Query"""
        arguments = [ServiceID, QueryString, QueryLanguage, UseSelection, RequeryContextXML, NewQueryContextXML, LaunchQuery]
        return self.Query(*arguments)

    def SetLanguagePair(self, LanguageFrom=None, LanguageTo=None):
        arguments = com_arguments([unwrap(a) for a in [LanguageFrom, LanguageTo]])
        return self.com_object.SetLanguagePair(*arguments)

    def setlanguagepair(self, LanguageFrom=None, LanguageTo=None):
        """Alias for SetLanguagePair"""
        arguments = [LanguageFrom, LanguageTo]
        return self.SetLanguagePair(*arguments)

    def set_language_pair(self, LanguageFrom=None, LanguageTo=None):
        """Alias for SetLanguagePair"""
        arguments = [LanguageFrom, LanguageTo]
        return self.SetLanguagePair(*arguments)


class Reviewer:

    def __init__(self, reviewer=None):
        self.com_object= reviewer

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value


class Reviewers:

    def __init__(self, reviewers=None):
        self.com_object= reviewers

    def __call__(self, item):
        return Reviewer(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Reviewer(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Revision:

    def __init__(self, revision=None):
        self.com_object= revision

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Author(self):
        return self.com_object.Author

    @property
    def author(self):
        """Alias for Author"""
        return self.Author

    def Cells(self, RowIndex=None, ColumnIndex=None):
        arguments = com_arguments([unwrap(a) for a in [RowIndex, ColumnIndex]])
        if hasattr(self.com_object, "GetCells"):
            return Cells(self.com_object.GetCells(*arguments))
        else:
            return Cells(self.com_object.Cells(*arguments))

    def cells(self, RowIndex=None, ColumnIndex=None):
        """Alias for Cells"""
        arguments = [RowIndex, ColumnIndex]
        return self.Cells(*arguments)

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Date(self):
        return self.com_object.Date

    @property
    def date(self):
        """Alias for Date"""
        return self.Date

    @property
    def FormatDescription(self):
        return self.com_object.FormatDescription

    @property
    def formatdescription(self):
        """Alias for FormatDescription"""
        return self.FormatDescription

    @property
    def format_description(self):
        """Alias for FormatDescription"""
        return self.FormatDescription

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def MovedRange(self):
        return Range(self.com_object.MovedRange)

    @property
    def movedrange(self):
        """Alias for MovedRange"""
        return self.MovedRange

    @property
    def moved_range(self):
        """Alias for MovedRange"""
        return self.MovedRange

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def Style(self):
        return Style(self.com_object.Style)

    @property
    def style(self):
        """Alias for Style"""
        return self.Style

    @property
    def Type(self):
        return WdRevisionType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def Accept(self):
        self.com_object.Accept()

    def accept(self):
        """Alias for Accept"""
        return self.Accept()

    def Reject(self):
        self.com_object.Reject()

    def reject(self):
        """Alias for Reject"""
        return self.Reject()


class Revisions:

    def __init__(self, revisions=None):
        self.com_object= revisions

    def __call__(self, item):
        return Revision(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def AcceptAll(self):
        self.com_object.AcceptAll()

    def acceptall(self):
        """Alias for AcceptAll"""
        return self.AcceptAll()

    def accept_all(self):
        """Alias for AcceptAll"""
        return self.AcceptAll()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Revision(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class RevisionsFilter:

    def __init__(self, revisionsfilter=None):
        self.com_object= revisionsfilter

    @property
    def Markup(self):
        return self.com_object.Markup

    @Markup.setter
    def Markup(self, value):
        self.com_object.Markup = value

    @property
    def markup(self):
        """Alias for Markup"""
        return self.Markup

    @markup.setter
    def markup(self, value):
        """Alias for Markup.setter"""
        self.Markup = value

    @property
    def Reviewers(self):
        return self.com_object.Reviewers

    @property
    def reviewers(self):
        """Alias for Reviewers"""
        return self.Reviewers

    @property
    def View(self):
        return self.com_object.View

    @View.setter
    def View(self, value):
        self.com_object.View = value

    @property
    def view(self):
        """Alias for View"""
        return self.View

    @view.setter
    def view(self, value):
        """Alias for View.setter"""
        self.View = value

    def ToggleShowAllReviewers(self):
        return self.com_object.ToggleShowAllReviewers()

    def toggleshowallreviewers(self):
        """Alias for ToggleShowAllReviewers"""
        return self.ToggleShowAllReviewers()

    def toggle_show_all_reviewers(self):
        """Alias for ToggleShowAllReviewers"""
        return self.ToggleShowAllReviewers()


class Row:

    def __init__(self, row=None):
        self.com_object= row

    @property
    def Alignment(self):
        return WdRowAlignment(self.com_object.Alignment)

    @Alignment.setter
    def Alignment(self, value):
        self.com_object.Alignment = value

    @property
    def alignment(self):
        """Alias for Alignment"""
        return self.Alignment

    @alignment.setter
    def alignment(self, value):
        """Alias for Alignment.setter"""
        self.Alignment = value

    @property
    def AllowBreakAcrossPages(self):
        return self.com_object.AllowBreakAcrossPages

    @AllowBreakAcrossPages.setter
    def AllowBreakAcrossPages(self, value):
        self.com_object.AllowBreakAcrossPages = value

    @property
    def allowbreakacrosspages(self):
        """Alias for AllowBreakAcrossPages"""
        return self.AllowBreakAcrossPages

    @allowbreakacrosspages.setter
    def allowbreakacrosspages(self, value):
        """Alias for AllowBreakAcrossPages.setter"""
        self.AllowBreakAcrossPages = value

    @property
    def allow_break_across_pages(self):
        """Alias for AllowBreakAcrossPages"""
        return self.AllowBreakAcrossPages

    @allow_break_across_pages.setter
    def allow_break_across_pages(self, value):
        """Alias for AllowBreakAcrossPages.setter"""
        self.AllowBreakAcrossPages = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    def Cells(self, RowIndex=None, ColumnIndex=None):
        arguments = com_arguments([unwrap(a) for a in [RowIndex, ColumnIndex]])
        if hasattr(self.com_object, "GetCells"):
            return Cells(self.com_object.GetCells(*arguments))
        else:
            return Cells(self.com_object.Cells(*arguments))

    def cells(self, RowIndex=None, ColumnIndex=None):
        """Alias for Cells"""
        arguments = [RowIndex, ColumnIndex]
        return self.Cells(*arguments)

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def HeadingFormat(self):
        return self.com_object.HeadingFormat

    @HeadingFormat.setter
    def HeadingFormat(self, value):
        self.com_object.HeadingFormat = value

    @property
    def headingformat(self):
        """Alias for HeadingFormat"""
        return self.HeadingFormat

    @headingformat.setter
    def headingformat(self, value):
        """Alias for HeadingFormat.setter"""
        self.HeadingFormat = value

    @property
    def heading_format(self):
        """Alias for HeadingFormat"""
        return self.HeadingFormat

    @heading_format.setter
    def heading_format(self, value):
        """Alias for HeadingFormat.setter"""
        self.HeadingFormat = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HeightRule(self):
        return WdRowHeightRule(self.com_object.HeightRule)

    @HeightRule.setter
    def HeightRule(self, value):
        self.com_object.HeightRule = value

    @property
    def heightrule(self):
        """Alias for HeightRule"""
        return self.HeightRule

    @heightrule.setter
    def heightrule(self, value):
        """Alias for HeightRule.setter"""
        self.HeightRule = value

    @property
    def height_rule(self):
        """Alias for HeightRule"""
        return self.HeightRule

    @height_rule.setter
    def height_rule(self, value):
        """Alias for HeightRule.setter"""
        self.HeightRule = value

    @property
    def ID(self):
        return self.com_object.ID

    @ID.setter
    def ID(self, value):
        self.com_object.ID = value

    @property
    def id(self):
        """Alias for ID"""
        return self.ID

    @id.setter
    def id(self, value):
        """Alias for ID.setter"""
        self.ID = value

    @property
    def i_d(self):
        """Alias for ID"""
        return self.ID

    @i_d.setter
    def i_d(self, value):
        """Alias for ID.setter"""
        self.ID = value

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def IsFirst(self):
        return self.com_object.IsFirst

    @property
    def isfirst(self):
        """Alias for IsFirst"""
        return self.IsFirst

    @property
    def is_first(self):
        """Alias for IsFirst"""
        return self.IsFirst

    @property
    def IsLast(self):
        return self.com_object.IsLast

    @property
    def islast(self):
        """Alias for IsLast"""
        return self.IsLast

    @property
    def is_last(self):
        """Alias for IsLast"""
        return self.IsLast

    @property
    def LeftIndent(self):
        return self.com_object.LeftIndent

    @LeftIndent.setter
    def LeftIndent(self, value):
        self.com_object.LeftIndent = value

    @property
    def leftindent(self):
        """Alias for LeftIndent"""
        return self.LeftIndent

    @leftindent.setter
    def leftindent(self, value):
        """Alias for LeftIndent.setter"""
        self.LeftIndent = value

    @property
    def left_indent(self):
        """Alias for LeftIndent"""
        return self.LeftIndent

    @left_indent.setter
    def left_indent(self, value):
        """Alias for LeftIndent.setter"""
        self.LeftIndent = value

    @property
    def NestingLevel(self):
        return self.com_object.NestingLevel

    @property
    def nestinglevel(self):
        """Alias for NestingLevel"""
        return self.NestingLevel

    @property
    def nesting_level(self):
        """Alias for NestingLevel"""
        return self.NestingLevel

    @property
    def Next(self):
        return Row(self.com_object.Next)

    @property
    def next(self):
        """Alias for Next"""
        return self.Next

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Previous(self):
        return Row(self.com_object.Previous)

    @property
    def previous(self):
        """Alias for Previous"""
        return self.Previous

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def Shading(self):
        return Shading(self.com_object.Shading)

    @property
    def shading(self):
        """Alias for Shading"""
        return self.Shading

    @property
    def SpaceBetweenColumns(self):
        return self.com_object.SpaceBetweenColumns

    @SpaceBetweenColumns.setter
    def SpaceBetweenColumns(self, value):
        self.com_object.SpaceBetweenColumns = value

    @property
    def spacebetweencolumns(self):
        """Alias for SpaceBetweenColumns"""
        return self.SpaceBetweenColumns

    @spacebetweencolumns.setter
    def spacebetweencolumns(self, value):
        """Alias for SpaceBetweenColumns.setter"""
        self.SpaceBetweenColumns = value

    @property
    def space_between_columns(self):
        """Alias for SpaceBetweenColumns"""
        return self.SpaceBetweenColumns

    @space_between_columns.setter
    def space_between_columns(self, value):
        """Alias for SpaceBetweenColumns.setter"""
        self.SpaceBetweenColumns = value

    def ConvertToText(self, Separator=None, NestedTables=None):
        arguments = com_arguments([unwrap(a) for a in [Separator, NestedTables]])
        self.com_object.ConvertToText(*arguments)

    def converttotext(self, Separator=None, NestedTables=None):
        """Alias for ConvertToText"""
        arguments = [Separator, NestedTables]
        return self.ConvertToText(*arguments)

    def convert_to_text(self, Separator=None, NestedTables=None):
        """Alias for ConvertToText"""
        arguments = [Separator, NestedTables]
        return self.ConvertToText(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()

    def SetHeight(self, RowHeight=None, HeightRule=None):
        arguments = com_arguments([unwrap(a) for a in [RowHeight, HeightRule]])
        self.com_object.SetHeight(*arguments)

    def setheight(self, RowHeight=None, HeightRule=None):
        """Alias for SetHeight"""
        arguments = [RowHeight, HeightRule]
        return self.SetHeight(*arguments)

    def set_height(self, RowHeight=None, HeightRule=None):
        """Alias for SetHeight"""
        arguments = [RowHeight, HeightRule]
        return self.SetHeight(*arguments)

    def SetLeftIndent(self, LeftIndent=None, RulerStyle=None):
        arguments = com_arguments([unwrap(a) for a in [LeftIndent, RulerStyle]])
        self.com_object.SetLeftIndent(*arguments)

    def setleftindent(self, LeftIndent=None, RulerStyle=None):
        """Alias for SetLeftIndent"""
        arguments = [LeftIndent, RulerStyle]
        return self.SetLeftIndent(*arguments)

    def set_left_indent(self, LeftIndent=None, RulerStyle=None):
        """Alias for SetLeftIndent"""
        arguments = [LeftIndent, RulerStyle]
        return self.SetLeftIndent(*arguments)


class Rows:

    def __init__(self, rows=None):
        self.com_object= rows

    def __call__(self, item):
        return Row(self.com_object(item))

    @property
    def Alignment(self):
        return WdRowAlignment(self.com_object.Alignment)

    @Alignment.setter
    def Alignment(self, value):
        self.com_object.Alignment = value

    @property
    def alignment(self):
        """Alias for Alignment"""
        return self.Alignment

    @alignment.setter
    def alignment(self, value):
        """Alias for Alignment.setter"""
        self.Alignment = value

    @property
    def AllowBreakAcrossPages(self):
        return self.com_object.AllowBreakAcrossPages

    @AllowBreakAcrossPages.setter
    def AllowBreakAcrossPages(self, value):
        self.com_object.AllowBreakAcrossPages = value

    @property
    def allowbreakacrosspages(self):
        """Alias for AllowBreakAcrossPages"""
        return self.AllowBreakAcrossPages

    @allowbreakacrosspages.setter
    def allowbreakacrosspages(self, value):
        """Alias for AllowBreakAcrossPages.setter"""
        self.AllowBreakAcrossPages = value

    @property
    def allow_break_across_pages(self):
        """Alias for AllowBreakAcrossPages"""
        return self.AllowBreakAcrossPages

    @allow_break_across_pages.setter
    def allow_break_across_pages(self, value):
        """Alias for AllowBreakAcrossPages.setter"""
        self.AllowBreakAcrossPages = value

    @property
    def AllowOverlap(self):
        return self.com_object.AllowOverlap

    @AllowOverlap.setter
    def AllowOverlap(self, value):
        self.com_object.AllowOverlap = value

    @property
    def allowoverlap(self):
        """Alias for AllowOverlap"""
        return self.AllowOverlap

    @allowoverlap.setter
    def allowoverlap(self, value):
        """Alias for AllowOverlap.setter"""
        self.AllowOverlap = value

    @property
    def allow_overlap(self):
        """Alias for AllowOverlap"""
        return self.AllowOverlap

    @allow_overlap.setter
    def allow_overlap(self, value):
        """Alias for AllowOverlap.setter"""
        self.AllowOverlap = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DistanceBottom(self):
        return self.com_object.DistanceBottom

    @DistanceBottom.setter
    def DistanceBottom(self, value):
        self.com_object.DistanceBottom = value

    @property
    def distancebottom(self):
        """Alias for DistanceBottom"""
        return self.DistanceBottom

    @distancebottom.setter
    def distancebottom(self, value):
        """Alias for DistanceBottom.setter"""
        self.DistanceBottom = value

    @property
    def distance_bottom(self):
        """Alias for DistanceBottom"""
        return self.DistanceBottom

    @distance_bottom.setter
    def distance_bottom(self, value):
        """Alias for DistanceBottom.setter"""
        self.DistanceBottom = value

    @property
    def DistanceLeft(self):
        return self.com_object.DistanceLeft

    @DistanceLeft.setter
    def DistanceLeft(self, value):
        self.com_object.DistanceLeft = value

    @property
    def distanceleft(self):
        """Alias for DistanceLeft"""
        return self.DistanceLeft

    @distanceleft.setter
    def distanceleft(self, value):
        """Alias for DistanceLeft.setter"""
        self.DistanceLeft = value

    @property
    def distance_left(self):
        """Alias for DistanceLeft"""
        return self.DistanceLeft

    @distance_left.setter
    def distance_left(self, value):
        """Alias for DistanceLeft.setter"""
        self.DistanceLeft = value

    @property
    def DistanceRight(self):
        return self.com_object.DistanceRight

    @DistanceRight.setter
    def DistanceRight(self, value):
        self.com_object.DistanceRight = value

    @property
    def distanceright(self):
        """Alias for DistanceRight"""
        return self.DistanceRight

    @distanceright.setter
    def distanceright(self, value):
        """Alias for DistanceRight.setter"""
        self.DistanceRight = value

    @property
    def distance_right(self):
        """Alias for DistanceRight"""
        return self.DistanceRight

    @distance_right.setter
    def distance_right(self, value):
        """Alias for DistanceRight.setter"""
        self.DistanceRight = value

    @property
    def DistanceTop(self):
        return self.com_object.DistanceTop

    @DistanceTop.setter
    def DistanceTop(self, value):
        self.com_object.DistanceTop = value

    @property
    def distancetop(self):
        """Alias for DistanceTop"""
        return self.DistanceTop

    @distancetop.setter
    def distancetop(self, value):
        """Alias for DistanceTop.setter"""
        self.DistanceTop = value

    @property
    def distance_top(self):
        """Alias for DistanceTop"""
        return self.DistanceTop

    @distance_top.setter
    def distance_top(self, value):
        """Alias for DistanceTop.setter"""
        self.DistanceTop = value

    @property
    def First(self):
        return Row(self.com_object.First)

    @property
    def first(self):
        """Alias for First"""
        return self.First

    @property
    def HeadingFormat(self):
        return self.com_object.HeadingFormat

    @HeadingFormat.setter
    def HeadingFormat(self, value):
        self.com_object.HeadingFormat = value

    @property
    def headingformat(self):
        """Alias for HeadingFormat"""
        return self.HeadingFormat

    @headingformat.setter
    def headingformat(self, value):
        """Alias for HeadingFormat.setter"""
        self.HeadingFormat = value

    @property
    def heading_format(self):
        """Alias for HeadingFormat"""
        return self.HeadingFormat

    @heading_format.setter
    def heading_format(self, value):
        """Alias for HeadingFormat.setter"""
        self.HeadingFormat = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HeightRule(self):
        return WdRowHeightRule(self.com_object.HeightRule)

    @HeightRule.setter
    def HeightRule(self, value):
        self.com_object.HeightRule = value

    @property
    def heightrule(self):
        """Alias for HeightRule"""
        return self.HeightRule

    @heightrule.setter
    def heightrule(self, value):
        """Alias for HeightRule.setter"""
        self.HeightRule = value

    @property
    def height_rule(self):
        """Alias for HeightRule"""
        return self.HeightRule

    @height_rule.setter
    def height_rule(self, value):
        """Alias for HeightRule.setter"""
        self.HeightRule = value

    @property
    def HorizontalPosition(self):
        return self.com_object.HorizontalPosition

    @HorizontalPosition.setter
    def HorizontalPosition(self, value):
        self.com_object.HorizontalPosition = value

    @property
    def horizontalposition(self):
        """Alias for HorizontalPosition"""
        return self.HorizontalPosition

    @horizontalposition.setter
    def horizontalposition(self, value):
        """Alias for HorizontalPosition.setter"""
        self.HorizontalPosition = value

    @property
    def horizontal_position(self):
        """Alias for HorizontalPosition"""
        return self.HorizontalPosition

    @horizontal_position.setter
    def horizontal_position(self, value):
        """Alias for HorizontalPosition.setter"""
        self.HorizontalPosition = value

    @property
    def Last(self):
        return Rows(self.com_object.Last)

    @property
    def last(self):
        """Alias for Last"""
        return self.Last

    @property
    def LeftIndent(self):
        return self.com_object.LeftIndent

    @LeftIndent.setter
    def LeftIndent(self, value):
        self.com_object.LeftIndent = value

    @property
    def leftindent(self):
        """Alias for LeftIndent"""
        return self.LeftIndent

    @leftindent.setter
    def leftindent(self, value):
        """Alias for LeftIndent.setter"""
        self.LeftIndent = value

    @property
    def left_indent(self):
        """Alias for LeftIndent"""
        return self.LeftIndent

    @left_indent.setter
    def left_indent(self, value):
        """Alias for LeftIndent.setter"""
        self.LeftIndent = value

    @property
    def NestingLevel(self):
        return self.com_object.NestingLevel

    @property
    def nestinglevel(self):
        """Alias for NestingLevel"""
        return self.NestingLevel

    @property
    def nesting_level(self):
        """Alias for NestingLevel"""
        return self.NestingLevel

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RelativeHorizontalPosition(self):
        return self.com_object.RelativeHorizontalPosition

    @RelativeHorizontalPosition.setter
    def RelativeHorizontalPosition(self, value):
        self.com_object.RelativeHorizontalPosition = value

    @property
    def relativehorizontalposition(self):
        """Alias for RelativeHorizontalPosition"""
        return self.RelativeHorizontalPosition

    @relativehorizontalposition.setter
    def relativehorizontalposition(self, value):
        """Alias for RelativeHorizontalPosition.setter"""
        self.RelativeHorizontalPosition = value

    @property
    def relative_horizontal_position(self):
        """Alias for RelativeHorizontalPosition"""
        return self.RelativeHorizontalPosition

    @relative_horizontal_position.setter
    def relative_horizontal_position(self, value):
        """Alias for RelativeHorizontalPosition.setter"""
        self.RelativeHorizontalPosition = value

    @property
    def RelativeVerticalPosition(self):
        return self.com_object.RelativeVerticalPosition

    @RelativeVerticalPosition.setter
    def RelativeVerticalPosition(self, value):
        self.com_object.RelativeVerticalPosition = value

    @property
    def relativeverticalposition(self):
        """Alias for RelativeVerticalPosition"""
        return self.RelativeVerticalPosition

    @relativeverticalposition.setter
    def relativeverticalposition(self, value):
        """Alias for RelativeVerticalPosition.setter"""
        self.RelativeVerticalPosition = value

    @property
    def relative_vertical_position(self):
        """Alias for RelativeVerticalPosition"""
        return self.RelativeVerticalPosition

    @relative_vertical_position.setter
    def relative_vertical_position(self, value):
        """Alias for RelativeVerticalPosition.setter"""
        self.RelativeVerticalPosition = value

    @property
    def Shading(self):
        return Shading(self.com_object.Shading)

    @property
    def shading(self):
        """Alias for Shading"""
        return self.Shading

    @property
    def SpaceBetweenColumns(self):
        return self.com_object.SpaceBetweenColumns

    @SpaceBetweenColumns.setter
    def SpaceBetweenColumns(self, value):
        self.com_object.SpaceBetweenColumns = value

    @property
    def spacebetweencolumns(self):
        """Alias for SpaceBetweenColumns"""
        return self.SpaceBetweenColumns

    @spacebetweencolumns.setter
    def spacebetweencolumns(self, value):
        """Alias for SpaceBetweenColumns.setter"""
        self.SpaceBetweenColumns = value

    @property
    def space_between_columns(self):
        """Alias for SpaceBetweenColumns"""
        return self.SpaceBetweenColumns

    @space_between_columns.setter
    def space_between_columns(self, value):
        """Alias for SpaceBetweenColumns.setter"""
        self.SpaceBetweenColumns = value

    @property
    def TableDirection(self):
        return WdTableDirection(self.com_object.TableDirection)

    @TableDirection.setter
    def TableDirection(self, value):
        self.com_object.TableDirection = value

    @property
    def tabledirection(self):
        """Alias for TableDirection"""
        return self.TableDirection

    @tabledirection.setter
    def tabledirection(self, value):
        """Alias for TableDirection.setter"""
        self.TableDirection = value

    @property
    def table_direction(self):
        """Alias for TableDirection"""
        return self.TableDirection

    @table_direction.setter
    def table_direction(self, value):
        """Alias for TableDirection.setter"""
        self.TableDirection = value

    @property
    def VerticalPosition(self):
        return self.com_object.VerticalPosition

    @VerticalPosition.setter
    def VerticalPosition(self, value):
        self.com_object.VerticalPosition = value

    @property
    def verticalposition(self):
        """Alias for VerticalPosition"""
        return self.VerticalPosition

    @verticalposition.setter
    def verticalposition(self, value):
        """Alias for VerticalPosition.setter"""
        self.VerticalPosition = value

    @property
    def vertical_position(self):
        """Alias for VerticalPosition"""
        return self.VerticalPosition

    @vertical_position.setter
    def vertical_position(self, value):
        """Alias for VerticalPosition.setter"""
        self.VerticalPosition = value

    @property
    def WrapAroundText(self):
        return self.com_object.WrapAroundText

    @WrapAroundText.setter
    def WrapAroundText(self, value):
        self.com_object.WrapAroundText = value

    @property
    def wraparoundtext(self):
        """Alias for WrapAroundText"""
        return self.WrapAroundText

    @wraparoundtext.setter
    def wraparoundtext(self, value):
        """Alias for WrapAroundText.setter"""
        self.WrapAroundText = value

    @property
    def wrap_around_text(self):
        """Alias for WrapAroundText"""
        return self.WrapAroundText

    @wrap_around_text.setter
    def wrap_around_text(self, value):
        """Alias for WrapAroundText.setter"""
        self.WrapAroundText = value

    def Add(self, BeforeRow=None):
        arguments = com_arguments([unwrap(a) for a in [BeforeRow]])
        return Row(self.com_object.Add(*arguments))

    def add(self, BeforeRow=None):
        """Alias for Add"""
        arguments = [BeforeRow]
        return self.Add(*arguments)

    def ConvertToText(self, Separator=None, NestedTables=None):
        arguments = com_arguments([unwrap(a) for a in [Separator, NestedTables]])
        self.com_object.ConvertToText(*arguments)

    def converttotext(self, Separator=None, NestedTables=None):
        """Alias for ConvertToText"""
        arguments = [Separator, NestedTables]
        return self.ConvertToText(*arguments)

    def convert_to_text(self, Separator=None, NestedTables=None):
        """Alias for ConvertToText"""
        arguments = [Separator, NestedTables]
        return self.ConvertToText(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def DistributeHeight(self):
        self.com_object.DistributeHeight()

    def distributeheight(self):
        """Alias for DistributeHeight"""
        return self.DistributeHeight()

    def distribute_height(self):
        """Alias for DistributeHeight"""
        return self.DistributeHeight()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Row(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()

    def SetHeight(self, RowHeight=None, HeightRule=None):
        arguments = com_arguments([unwrap(a) for a in [RowHeight, HeightRule]])
        self.com_object.SetHeight(*arguments)

    def setheight(self, RowHeight=None, HeightRule=None):
        """Alias for SetHeight"""
        arguments = [RowHeight, HeightRule]
        return self.SetHeight(*arguments)

    def set_height(self, RowHeight=None, HeightRule=None):
        """Alias for SetHeight"""
        arguments = [RowHeight, HeightRule]
        return self.SetHeight(*arguments)

    def SetLeftIndent(self, LeftIndent=None, RulerStyle=None):
        arguments = com_arguments([unwrap(a) for a in [LeftIndent, RulerStyle]])
        self.com_object.SetLeftIndent(*arguments)

    def setleftindent(self, LeftIndent=None, RulerStyle=None):
        """Alias for SetLeftIndent"""
        arguments = [LeftIndent, RulerStyle]
        return self.SetLeftIndent(*arguments)

    def set_left_indent(self, LeftIndent=None, RulerStyle=None):
        """Alias for SetLeftIndent"""
        arguments = [LeftIndent, RulerStyle]
        return self.SetLeftIndent(*arguments)


class Section:

    def __init__(self, section=None):
        self.com_object= section

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Footers(self):
        return HeadersFooters(self.com_object.Footers)

    @property
    def footers(self):
        """Alias for Footers"""
        return self.Footers

    @property
    def Headers(self):
        return HeadersFooters(self.com_object.Headers)

    @property
    def headers(self):
        """Alias for Headers"""
        return self.Headers

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def PageSetup(self):
        return PageSetup(self.com_object.PageSetup)

    @property
    def pagesetup(self):
        """Alias for PageSetup"""
        return self.PageSetup

    @property
    def page_setup(self):
        """Alias for PageSetup"""
        return self.PageSetup

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ProtectedForForms(self):
        return self.com_object.ProtectedForForms

    @ProtectedForForms.setter
    def ProtectedForForms(self, value):
        self.com_object.ProtectedForForms = value

    @property
    def protectedforforms(self):
        """Alias for ProtectedForForms"""
        return self.ProtectedForForms

    @protectedforforms.setter
    def protectedforforms(self, value):
        """Alias for ProtectedForForms.setter"""
        self.ProtectedForForms = value

    @property
    def protected_for_forms(self):
        """Alias for ProtectedForForms"""
        return self.ProtectedForForms

    @protected_for_forms.setter
    def protected_for_forms(self, value):
        """Alias for ProtectedForForms.setter"""
        self.ProtectedForForms = value

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range


class Sections:

    def __init__(self, sections=None):
        self.com_object= sections

    def __call__(self, item):
        return Section(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def First(self):
        return Section(self.com_object.First)

    @property
    def first(self):
        """Alias for First"""
        return self.First

    @property
    def Last(self):
        return Sections(self.com_object.Last)

    @property
    def last(self):
        """Alias for Last"""
        return self.Last

    @property
    def PageSetup(self):
        return PageSetup(self.com_object.PageSetup)

    @property
    def pagesetup(self):
        """Alias for PageSetup"""
        return self.PageSetup

    @property
    def page_setup(self):
        """Alias for PageSetup"""
        return self.PageSetup

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Range=None, Start=None):
        arguments = com_arguments([unwrap(a) for a in [Range, Start]])
        self.com_object.Add(*arguments)

    def add(self, Range=None, Start=None):
        """Alias for Add"""
        arguments = [Range, Start]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Section(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Selection:

    def __init__(self, selection=None):
        self.com_object= selection

    @property
    def Active(self):
        return self.com_object.Active

    @property
    def active(self):
        """Alias for Active"""
        return self.Active

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BookmarkID(self):
        return self.com_object.BookmarkID

    @property
    def bookmarkid(self):
        """Alias for BookmarkID"""
        return self.BookmarkID

    @property
    def bookmark_i_d(self):
        """Alias for BookmarkID"""
        return self.BookmarkID

    @property
    def Bookmarks(self):
        return Bookmarks(self.com_object.Bookmarks)

    @property
    def bookmarks(self):
        """Alias for Bookmarks"""
        return self.Bookmarks

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    def Cells(self, RowIndex=None, ColumnIndex=None):
        arguments = com_arguments([unwrap(a) for a in [RowIndex, ColumnIndex]])
        if hasattr(self.com_object, "GetCells"):
            return Cells(self.com_object.GetCells(*arguments))
        else:
            return Cells(self.com_object.Cells(*arguments))

    def cells(self, RowIndex=None, ColumnIndex=None):
        """Alias for Cells"""
        arguments = [RowIndex, ColumnIndex]
        return self.Cells(*arguments)

    @property
    def Characters(self):
        return Characters(self.com_object.Characters)

    @property
    def characters(self):
        """Alias for Characters"""
        return self.Characters

    @property
    def ChildShapeRange(self):
        return ShapeRange(self.com_object.ChildShapeRange)

    @property
    def childshaperange(self):
        """Alias for ChildShapeRange"""
        return self.ChildShapeRange

    @property
    def child_shape_range(self):
        """Alias for ChildShapeRange"""
        return self.ChildShapeRange

    @property
    def Columns(self):
        return Columns(self.com_object.Columns)

    @property
    def columns(self):
        """Alias for Columns"""
        return self.Columns

    @property
    def ColumnSelectMode(self):
        return self.com_object.ColumnSelectMode

    @ColumnSelectMode.setter
    def ColumnSelectMode(self, value):
        self.com_object.ColumnSelectMode = value

    @property
    def columnselectmode(self):
        """Alias for ColumnSelectMode"""
        return self.ColumnSelectMode

    @columnselectmode.setter
    def columnselectmode(self, value):
        """Alias for ColumnSelectMode.setter"""
        self.ColumnSelectMode = value

    @property
    def column_select_mode(self):
        """Alias for ColumnSelectMode"""
        return self.ColumnSelectMode

    @column_select_mode.setter
    def column_select_mode(self, value):
        """Alias for ColumnSelectMode.setter"""
        self.ColumnSelectMode = value

    @property
    def Comments(self):
        return Comments(self.com_object.Comments)

    @property
    def comments(self):
        """Alias for Comments"""
        return self.Comments

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Document(self):
        return Document(self.com_object.Document)

    @property
    def document(self):
        """Alias for Document"""
        return self.Document

    @property
    def Editors(self):
        return Editors(self.com_object.Editors)

    @property
    def editors(self):
        """Alias for Editors"""
        return self.Editors

    @property
    def End(self):
        return self.com_object.End

    @End.setter
    def End(self, value):
        self.com_object.End = value

    @property
    def end(self):
        """Alias for End"""
        return self.End

    @end.setter
    def end(self, value):
        """Alias for End.setter"""
        self.End = value

    @property
    def EndnoteOptions(self):
        return EndnoteOptions(self.com_object.EndnoteOptions)

    @property
    def endnoteoptions(self):
        """Alias for EndnoteOptions"""
        return self.EndnoteOptions

    @property
    def endnote_options(self):
        """Alias for EndnoteOptions"""
        return self.EndnoteOptions

    @property
    def Endnotes(self):
        return Endnotes(self.com_object.Endnotes)

    @property
    def endnotes(self):
        """Alias for Endnotes"""
        return self.Endnotes

    @property
    def EnhMetaFileBits(self):
        return self.com_object.EnhMetaFileBits

    @property
    def enhmetafilebits(self):
        """Alias for EnhMetaFileBits"""
        return self.EnhMetaFileBits

    @property
    def enh_meta_file_bits(self):
        """Alias for EnhMetaFileBits"""
        return self.EnhMetaFileBits

    @property
    def ExtendMode(self):
        return self.com_object.ExtendMode

    @ExtendMode.setter
    def ExtendMode(self, value):
        self.com_object.ExtendMode = value

    @property
    def extendmode(self):
        """Alias for ExtendMode"""
        return self.ExtendMode

    @extendmode.setter
    def extendmode(self, value):
        """Alias for ExtendMode.setter"""
        self.ExtendMode = value

    @property
    def extend_mode(self):
        """Alias for ExtendMode"""
        return self.ExtendMode

    @extend_mode.setter
    def extend_mode(self, value):
        """Alias for ExtendMode.setter"""
        self.ExtendMode = value

    @property
    def Fields(self):
        return Fields(self.com_object.Fields)

    @property
    def fields(self):
        """Alias for Fields"""
        return self.Fields

    @property
    def Find(self):
        return Find(self.com_object.Find)

    @property
    def find(self):
        """Alias for Find"""
        return self.Find

    @property
    def FitTextWidth(self):
        return self.com_object.FitTextWidth

    @FitTextWidth.setter
    def FitTextWidth(self, value):
        self.com_object.FitTextWidth = value

    @property
    def fittextwidth(self):
        """Alias for FitTextWidth"""
        return self.FitTextWidth

    @fittextwidth.setter
    def fittextwidth(self, value):
        """Alias for FitTextWidth.setter"""
        self.FitTextWidth = value

    @property
    def fit_text_width(self):
        """Alias for FitTextWidth"""
        return self.FitTextWidth

    @fit_text_width.setter
    def fit_text_width(self, value):
        """Alias for FitTextWidth.setter"""
        self.FitTextWidth = value

    @property
    def Flags(self):
        return WdSelectionFlags(self.com_object.Flags)

    @Flags.setter
    def Flags(self, value):
        self.com_object.Flags = value

    @property
    def flags(self):
        """Alias for Flags"""
        return self.Flags

    @flags.setter
    def flags(self, value):
        """Alias for Flags.setter"""
        self.Flags = value

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @Font.setter
    def Font(self, value):
        self.com_object.Font = value

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @font.setter
    def font(self, value):
        """Alias for Font.setter"""
        self.Font = value

    @property
    def FootnoteOptions(self):
        return FootnoteOptions(self.com_object.FootnoteOptions)

    @property
    def footnoteoptions(self):
        """Alias for FootnoteOptions"""
        return self.FootnoteOptions

    @property
    def footnote_options(self):
        """Alias for FootnoteOptions"""
        return self.FootnoteOptions

    @property
    def Footnotes(self):
        return Footnotes(self.com_object.Footnotes)

    @property
    def footnotes(self):
        """Alias for Footnotes"""
        return self.Footnotes

    @property
    def FormattedText(self):
        return Range(self.com_object.FormattedText)

    @FormattedText.setter
    def FormattedText(self, value):
        self.com_object.FormattedText = value

    @property
    def formattedtext(self):
        """Alias for FormattedText"""
        return self.FormattedText

    @formattedtext.setter
    def formattedtext(self, value):
        """Alias for FormattedText.setter"""
        self.FormattedText = value

    @property
    def formatted_text(self):
        """Alias for FormattedText"""
        return self.FormattedText

    @formatted_text.setter
    def formatted_text(self, value):
        """Alias for FormattedText.setter"""
        self.FormattedText = value

    @property
    def FormFields(self):
        return FormFields(self.com_object.FormFields)

    @property
    def formfields(self):
        """Alias for FormFields"""
        return self.FormFields

    @property
    def form_fields(self):
        """Alias for FormFields"""
        return self.FormFields

    @property
    def Frames(self):
        return Frames(self.com_object.Frames)

    @property
    def frames(self):
        """Alias for Frames"""
        return self.Frames

    @property
    def HasChildShapeRange(self):
        return self.com_object.HasChildShapeRange

    @property
    def haschildshaperange(self):
        """Alias for HasChildShapeRange"""
        return self.HasChildShapeRange

    @property
    def has_child_shape_range(self):
        """Alias for HasChildShapeRange"""
        return self.HasChildShapeRange

    @property
    def HeaderFooter(self):
        return HeaderFooter(self.com_object.HeaderFooter)

    @property
    def headerfooter(self):
        """Alias for HeaderFooter"""
        return self.HeaderFooter

    @property
    def header_footer(self):
        """Alias for HeaderFooter"""
        return self.HeaderFooter

    @property
    def HTMLDivisions(self):
        return HTMLDivisions(self.com_object.HTMLDivisions)

    @property
    def htmldivisions(self):
        """Alias for HTMLDivisions"""
        return self.HTMLDivisions

    @property
    def h_t_m_l_divisions(self):
        """Alias for HTMLDivisions"""
        return self.HTMLDivisions

    @property
    def Hyperlinks(self):
        return Hyperlinks(self.com_object.Hyperlinks)

    @property
    def hyperlinks(self):
        """Alias for Hyperlinks"""
        return self.Hyperlinks

    def Information(self, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Type]])
        if hasattr(self.com_object, "GetInformation"):
            return self.com_object.GetInformation(*arguments)
        else:
            return self.com_object.Information(*arguments)

    def information(self, Type=None):
        """Alias for Information"""
        arguments = [Type]
        return self.Information(*arguments)

    @property
    def InlineShapes(self):
        return InlineShapes(self.com_object.InlineShapes)

    @property
    def inlineshapes(self):
        """Alias for InlineShapes"""
        return self.InlineShapes

    @property
    def inline_shapes(self):
        """Alias for InlineShapes"""
        return self.InlineShapes

    @property
    def IPAtEndOfLine(self):
        return self.com_object.IPAtEndOfLine

    @property
    def ipatendofline(self):
        """Alias for IPAtEndOfLine"""
        return self.IPAtEndOfLine

    @property
    def i_p_at_end_of_line(self):
        """Alias for IPAtEndOfLine"""
        return self.IPAtEndOfLine

    @property
    def IsEndOfRowMark(self):
        return self.com_object.IsEndOfRowMark

    @property
    def isendofrowmark(self):
        """Alias for IsEndOfRowMark"""
        return self.IsEndOfRowMark

    @property
    def is_end_of_row_mark(self):
        """Alias for IsEndOfRowMark"""
        return self.IsEndOfRowMark

    @property
    def LanguageDetected(self):
        return self.com_object.LanguageDetected

    @LanguageDetected.setter
    def LanguageDetected(self, value):
        self.com_object.LanguageDetected = value

    @property
    def languagedetected(self):
        """Alias for LanguageDetected"""
        return self.LanguageDetected

    @languagedetected.setter
    def languagedetected(self, value):
        """Alias for LanguageDetected.setter"""
        self.LanguageDetected = value

    @property
    def language_detected(self):
        """Alias for LanguageDetected"""
        return self.LanguageDetected

    @language_detected.setter
    def language_detected(self, value):
        """Alias for LanguageDetected.setter"""
        self.LanguageDetected = value

    @property
    def LanguageID(self):
        return self.com_object.LanguageID

    @LanguageID.setter
    def LanguageID(self, value):
        self.com_object.LanguageID = value

    @property
    def languageid(self):
        """Alias for LanguageID"""
        return self.LanguageID

    @languageid.setter
    def languageid(self, value):
        """Alias for LanguageID.setter"""
        self.LanguageID = value

    @property
    def language_i_d(self):
        """Alias for LanguageID"""
        return self.LanguageID

    @language_i_d.setter
    def language_i_d(self, value):
        """Alias for LanguageID.setter"""
        self.LanguageID = value

    @property
    def LanguageIDFarEast(self):
        return WdLanguageID(self.com_object.LanguageIDFarEast)

    @LanguageIDFarEast.setter
    def LanguageIDFarEast(self, value):
        self.com_object.LanguageIDFarEast = value

    @property
    def languageidfareast(self):
        """Alias for LanguageIDFarEast"""
        return self.LanguageIDFarEast

    @languageidfareast.setter
    def languageidfareast(self, value):
        """Alias for LanguageIDFarEast.setter"""
        self.LanguageIDFarEast = value

    @property
    def language_i_d_far_east(self):
        """Alias for LanguageIDFarEast"""
        return self.LanguageIDFarEast

    @language_i_d_far_east.setter
    def language_i_d_far_east(self, value):
        """Alias for LanguageIDFarEast.setter"""
        self.LanguageIDFarEast = value

    @property
    def LanguageIDOther(self):
        return WdLanguageID(self.com_object.LanguageIDOther)

    @LanguageIDOther.setter
    def LanguageIDOther(self, value):
        self.com_object.LanguageIDOther = value

    @property
    def languageidother(self):
        """Alias for LanguageIDOther"""
        return self.LanguageIDOther

    @languageidother.setter
    def languageidother(self, value):
        """Alias for LanguageIDOther.setter"""
        self.LanguageIDOther = value

    @property
    def language_i_d_other(self):
        """Alias for LanguageIDOther"""
        return self.LanguageIDOther

    @language_i_d_other.setter
    def language_i_d_other(self, value):
        """Alias for LanguageIDOther.setter"""
        self.LanguageIDOther = value

    @property
    def NoProofing(self):
        return self.com_object.NoProofing

    @NoProofing.setter
    def NoProofing(self, value):
        self.com_object.NoProofing = value

    @property
    def noproofing(self):
        """Alias for NoProofing"""
        return self.NoProofing

    @noproofing.setter
    def noproofing(self, value):
        """Alias for NoProofing.setter"""
        self.NoProofing = value

    @property
    def no_proofing(self):
        """Alias for NoProofing"""
        return self.NoProofing

    @no_proofing.setter
    def no_proofing(self, value):
        """Alias for NoProofing.setter"""
        self.NoProofing = value

    @property
    def OMaths(self):
        return OMaths(self.com_object.OMaths)

    @property
    def omaths(self):
        """Alias for OMaths"""
        return self.OMaths

    @property
    def o_maths(self):
        """Alias for OMaths"""
        return self.OMaths

    @property
    def Orientation(self):
        return WdTextOrientation(self.com_object.Orientation)

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def PageSetup(self):
        return PageSetup(self.com_object.PageSetup)

    @property
    def pagesetup(self):
        """Alias for PageSetup"""
        return self.PageSetup

    @property
    def page_setup(self):
        """Alias for PageSetup"""
        return self.PageSetup

    @property
    def ParagraphFormat(self):
        return ParagraphFormat(self.com_object.ParagraphFormat)

    @ParagraphFormat.setter
    def ParagraphFormat(self, value):
        self.com_object.ParagraphFormat = value

    @property
    def paragraphformat(self):
        """Alias for ParagraphFormat"""
        return self.ParagraphFormat

    @paragraphformat.setter
    def paragraphformat(self, value):
        """Alias for ParagraphFormat.setter"""
        self.ParagraphFormat = value

    @property
    def paragraph_format(self):
        """Alias for ParagraphFormat"""
        return self.ParagraphFormat

    @paragraph_format.setter
    def paragraph_format(self, value):
        """Alias for ParagraphFormat.setter"""
        self.ParagraphFormat = value

    @property
    def Paragraphs(self):
        return Paragraphs(self.com_object.Paragraphs)

    @property
    def paragraphs(self):
        """Alias for Paragraphs"""
        return self.Paragraphs

    @property
    def Parent(self):
        return Selection(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PreviousBookmarkID(self):
        return self.com_object.PreviousBookmarkID

    @property
    def previousbookmarkid(self):
        """Alias for PreviousBookmarkID"""
        return self.PreviousBookmarkID

    @property
    def previous_bookmark_i_d(self):
        """Alias for PreviousBookmarkID"""
        return self.PreviousBookmarkID

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def Rows(self):
        return Rows(self.com_object.Rows)

    @property
    def rows(self):
        """Alias for Rows"""
        return self.Rows

    @property
    def Sections(self):
        return Sections(self.com_object.Sections)

    @property
    def sections(self):
        """Alias for Sections"""
        return self.Sections

    @property
    def Sentences(self):
        return Sentences(self.com_object.Sentences)

    @property
    def sentences(self):
        """Alias for Sentences"""
        return self.Sentences

    @property
    def Shading(self):
        return Shading(self.com_object.Shading)

    @property
    def shading(self):
        """Alias for Shading"""
        return self.Shading

    @property
    def ShapeRange(self):
        return ShapeRange(self.com_object.ShapeRange)

    @property
    def shaperange(self):
        """Alias for ShapeRange"""
        return self.ShapeRange

    @property
    def shape_range(self):
        """Alias for ShapeRange"""
        return self.ShapeRange

    @property
    def Start(self):
        return self.com_object.Start

    @Start.setter
    def Start(self, value):
        self.com_object.Start = value

    @property
    def start(self):
        """Alias for Start"""
        return self.Start

    @start.setter
    def start(self, value):
        """Alias for Start.setter"""
        self.Start = value

    @property
    def StartIsActive(self):
        return self.com_object.StartIsActive

    @StartIsActive.setter
    def StartIsActive(self, value):
        self.com_object.StartIsActive = value

    @property
    def startisactive(self):
        """Alias for StartIsActive"""
        return self.StartIsActive

    @startisactive.setter
    def startisactive(self, value):
        """Alias for StartIsActive.setter"""
        self.StartIsActive = value

    @property
    def start_is_active(self):
        """Alias for StartIsActive"""
        return self.StartIsActive

    @start_is_active.setter
    def start_is_active(self, value):
        """Alias for StartIsActive.setter"""
        self.StartIsActive = value

    @property
    def StoryLength(self):
        return self.com_object.StoryLength

    @property
    def storylength(self):
        """Alias for StoryLength"""
        return self.StoryLength

    @property
    def story_length(self):
        """Alias for StoryLength"""
        return self.StoryLength

    @property
    def StoryType(self):
        return WdStoryType(self.com_object.StoryType)

    @property
    def storytype(self):
        """Alias for StoryType"""
        return self.StoryType

    @property
    def story_type(self):
        """Alias for StoryType"""
        return self.StoryType

    @property
    def Style(self):
        return WdBuiltinStyle(self.com_object.Style)

    @Style.setter
    def Style(self, value):
        self.com_object.Style = value

    @property
    def style(self):
        """Alias for Style"""
        return self.Style

    @style.setter
    def style(self, value):
        """Alias for Style.setter"""
        self.Style = value

    @property
    def Tables(self):
        return Tables(self.com_object.Tables)

    @property
    def tables(self):
        """Alias for Tables"""
        return self.Tables

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def TopLevelTables(self):
        return Tables(self.com_object.TopLevelTables)

    @property
    def topleveltables(self):
        """Alias for TopLevelTables"""
        return self.TopLevelTables

    @property
    def top_level_tables(self):
        """Alias for TopLevelTables"""
        return self.TopLevelTables

    @property
    def Type(self):
        return WdSelectionType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def WordOpenXML(self):
        return self.com_object.WordOpenXML

    @property
    def wordopenxml(self):
        """Alias for WordOpenXML"""
        return self.WordOpenXML

    @property
    def word_open_x_m_l(self):
        """Alias for WordOpenXML"""
        return self.WordOpenXML

    @property
    def Words(self):
        return Words(self.com_object.Words)

    @property
    def words(self):
        """Alias for Words"""
        return self.Words

    def XML(self, DataOnly=None):
        arguments = com_arguments([unwrap(a) for a in [DataOnly]])
        if hasattr(self.com_object, "GetXML"):
            return self.com_object.GetXML(*arguments)
        else:
            return self.com_object.XML(*arguments)

    def xml(self, DataOnly=None):
        """Alias for XML"""
        arguments = [DataOnly]
        return self.XML(*arguments)

    def x_m_l(self, DataOnly=None):
        """Alias for XML"""
        arguments = [DataOnly]
        return self.XML(*arguments)

    def BoldRun(self):
        self.com_object.BoldRun()

    def boldrun(self):
        """Alias for BoldRun"""
        return self.BoldRun()

    def bold_run(self):
        """Alias for BoldRun"""
        return self.BoldRun()

    def Calculate(self):
        self.com_object.Calculate()

    def calculate(self):
        """Alias for Calculate"""
        return self.Calculate()

    def ClearCharacterAllFormatting(self):
        self.com_object.ClearCharacterAllFormatting()

    def clearcharacterallformatting(self):
        """Alias for ClearCharacterAllFormatting"""
        return self.ClearCharacterAllFormatting()

    def clear_character_all_formatting(self):
        """Alias for ClearCharacterAllFormatting"""
        return self.ClearCharacterAllFormatting()

    def ClearCharacterDirectFormatting(self):
        self.com_object.ClearCharacterDirectFormatting()

    def clearcharacterdirectformatting(self):
        """Alias for ClearCharacterDirectFormatting"""
        return self.ClearCharacterDirectFormatting()

    def clear_character_direct_formatting(self):
        """Alias for ClearCharacterDirectFormatting"""
        return self.ClearCharacterDirectFormatting()

    def ClearCharacterStyle(self):
        self.com_object.ClearCharacterStyle()

    def clearcharacterstyle(self):
        """Alias for ClearCharacterStyle"""
        return self.ClearCharacterStyle()

    def clear_character_style(self):
        """Alias for ClearCharacterStyle"""
        return self.ClearCharacterStyle()

    def ClearFormatting(self):
        self.com_object.ClearFormatting()

    def clearformatting(self):
        """Alias for ClearFormatting"""
        return self.ClearFormatting()

    def clear_formatting(self):
        """Alias for ClearFormatting"""
        return self.ClearFormatting()

    def ClearParagraphAllFormatting(self):
        self.com_object.ClearParagraphAllFormatting()

    def clearparagraphallformatting(self):
        """Alias for ClearParagraphAllFormatting"""
        return self.ClearParagraphAllFormatting()

    def clear_paragraph_all_formatting(self):
        """Alias for ClearParagraphAllFormatting"""
        return self.ClearParagraphAllFormatting()

    def ClearParagraphDirectFormatting(self):
        self.com_object.ClearParagraphDirectFormatting()

    def clearparagraphdirectformatting(self):
        """Alias for ClearParagraphDirectFormatting"""
        return self.ClearParagraphDirectFormatting()

    def clear_paragraph_direct_formatting(self):
        """Alias for ClearParagraphDirectFormatting"""
        return self.ClearParagraphDirectFormatting()

    def ClearParagraphStyle(self):
        self.com_object.ClearParagraphStyle()

    def clearparagraphstyle(self):
        """Alias for ClearParagraphStyle"""
        return self.ClearParagraphStyle()

    def clear_paragraph_style(self):
        """Alias for ClearParagraphStyle"""
        return self.ClearParagraphStyle()

    def Collapse(self, Direction=None):
        arguments = com_arguments([unwrap(a) for a in [Direction]])
        self.com_object.Collapse(*arguments)

    def collapse(self, Direction=None):
        """Alias for Collapse"""
        arguments = [Direction]
        return self.Collapse(*arguments)

    def ConvertToTable(self, Separator=None, NumRows=None, NumColumns=None, InitialColumnWidth=None, Format=None, ApplyBorders=None, ApplyShading=None, ApplyFont=None, ApplyColor=None, ApplyHeadingRows=None, ApplyLastRow=None, ApplyFirstColumn=None, ApplyLastColumn=None, AutoFit=None, AutoFitBehavior=None, DefaultTableBehavior=None):
        arguments = com_arguments([unwrap(a) for a in [Separator, NumRows, NumColumns, InitialColumnWidth, Format, ApplyBorders, ApplyShading, ApplyFont, ApplyColor, ApplyHeadingRows, ApplyLastRow, ApplyFirstColumn, ApplyLastColumn, AutoFit, AutoFitBehavior, DefaultTableBehavior]])
        return Table(self.com_object.ConvertToTable(*arguments))

    def converttotable(self, Separator=None, NumRows=None, NumColumns=None, InitialColumnWidth=None, Format=None, ApplyBorders=None, ApplyShading=None, ApplyFont=None, ApplyColor=None, ApplyHeadingRows=None, ApplyLastRow=None, ApplyFirstColumn=None, ApplyLastColumn=None, AutoFit=None, AutoFitBehavior=None, DefaultTableBehavior=None):
        """Alias for ConvertToTable"""
        arguments = [Separator, NumRows, NumColumns, InitialColumnWidth, Format, ApplyBorders, ApplyShading, ApplyFont, ApplyColor, ApplyHeadingRows, ApplyLastRow, ApplyFirstColumn, ApplyLastColumn, AutoFit, AutoFitBehavior, DefaultTableBehavior]
        return self.ConvertToTable(*arguments)

    def convert_to_table(self, Separator=None, NumRows=None, NumColumns=None, InitialColumnWidth=None, Format=None, ApplyBorders=None, ApplyShading=None, ApplyFont=None, ApplyColor=None, ApplyHeadingRows=None, ApplyLastRow=None, ApplyFirstColumn=None, ApplyLastColumn=None, AutoFit=None, AutoFitBehavior=None, DefaultTableBehavior=None):
        """Alias for ConvertToTable"""
        arguments = [Separator, NumRows, NumColumns, InitialColumnWidth, Format, ApplyBorders, ApplyShading, ApplyFont, ApplyColor, ApplyHeadingRows, ApplyLastRow, ApplyFirstColumn, ApplyLastColumn, AutoFit, AutoFitBehavior, DefaultTableBehavior]
        return self.ConvertToTable(*arguments)

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def CopyAsPicture(self):
        self.com_object.CopyAsPicture()

    def copyaspicture(self):
        """Alias for CopyAsPicture"""
        return self.CopyAsPicture()

    def copy_as_picture(self):
        """Alias for CopyAsPicture"""
        return self.CopyAsPicture()

    def CopyFormat(self):
        self.com_object.CopyFormat()

    def copyformat(self):
        """Alias for CopyFormat"""
        return self.CopyFormat()

    def copy_format(self):
        """Alias for CopyFormat"""
        return self.CopyFormat()

    def CreateAutoTextEntry(self, Name=None, StyleName=None):
        arguments = com_arguments([unwrap(a) for a in [Name, StyleName]])
        self.com_object.CreateAutoTextEntry(*arguments)

    def createautotextentry(self, Name=None, StyleName=None):
        """Alias for CreateAutoTextEntry"""
        arguments = [Name, StyleName]
        return self.CreateAutoTextEntry(*arguments)

    def create_auto_text_entry(self, Name=None, StyleName=None):
        """Alias for CreateAutoTextEntry"""
        arguments = [Name, StyleName]
        return self.CreateAutoTextEntry(*arguments)

    def CreateTextbox(self):
        self.com_object.CreateTextbox()

    def createtextbox(self):
        """Alias for CreateTextbox"""
        return self.CreateTextbox()

    def create_textbox(self):
        """Alias for CreateTextbox"""
        return self.CreateTextbox()

    def Cut(self):
        self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def Delete(self, Unit=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Unit, Count]])
        return self.com_object.Delete(*arguments)

    def delete(self, Unit=None, Count=None):
        """Alias for Delete"""
        arguments = [Unit, Count]
        return self.Delete(*arguments)

    def DetectLanguage(self):
        self.com_object.DetectLanguage()

    def detectlanguage(self):
        """Alias for DetectLanguage"""
        return self.DetectLanguage()

    def detect_language(self):
        """Alias for DetectLanguage"""
        return self.DetectLanguage()

    def EndKey(self, Unit=None, Extend=None):
        arguments = com_arguments([unwrap(a) for a in [Unit, Extend]])
        self.com_object.EndKey(*arguments)

    def endkey(self, Unit=None, Extend=None):
        """Alias for EndKey"""
        arguments = [Unit, Extend]
        return self.EndKey(*arguments)

    def end_key(self, Unit=None, Extend=None):
        """Alias for EndKey"""
        arguments = [Unit, Extend]
        return self.EndKey(*arguments)

    def EndOf(self, Unit=None, Extend=None):
        arguments = com_arguments([unwrap(a) for a in [Unit, Extend]])
        self.com_object.EndOf(*arguments)

    def endof(self, Unit=None, Extend=None):
        """Alias for EndOf"""
        arguments = [Unit, Extend]
        return self.EndOf(*arguments)

    def end_of(self, Unit=None, Extend=None):
        """Alias for EndOf"""
        arguments = [Unit, Extend]
        return self.EndOf(*arguments)

    def EscapeKey(self):
        self.com_object.EscapeKey()

    def escapekey(self):
        """Alias for EscapeKey"""
        return self.EscapeKey()

    def escape_key(self):
        """Alias for EscapeKey"""
        return self.EscapeKey()

    def Expand(self, Unit=None):
        arguments = com_arguments([unwrap(a) for a in [Unit]])
        self.com_object.Expand(*arguments)

    def expand(self, Unit=None):
        """Alias for Expand"""
        arguments = [Unit]
        return self.Expand(*arguments)

    def ExportAsFixedFormat(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, ExportCurrentPage=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, FixedFormatExtClassPtr=None):
        arguments = com_arguments([unwrap(a) for a in [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, ExportCurrentPage, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, FixedFormatExtClassPtr]])
        self.com_object.ExportAsFixedFormat(*arguments)

    def exportasfixedformat(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, ExportCurrentPage=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat"""
        arguments = [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, ExportCurrentPage, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat(*arguments)

    def export_as_fixed_format(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, ExportCurrentPage=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat"""
        arguments = [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, ExportCurrentPage, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat(*arguments)

    def ExportAsFixedFormat2(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, ExportCurrentPage=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, OptimizeForImageQuality=None, FixedFormatExtClassPtr=None):
        arguments = com_arguments([unwrap(a) for a in [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, ExportCurrentPage, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, OptimizeForImageQuality, FixedFormatExtClassPtr]])
        self.com_object.ExportAsFixedFormat2(*arguments)

    def exportasfixedformat2(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, ExportCurrentPage=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, OptimizeForImageQuality=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat2"""
        arguments = [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, ExportCurrentPage, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, OptimizeForImageQuality, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat2(*arguments)

    def export_as_fixed_format2(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, ExportCurrentPage=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, OptimizeForImageQuality=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat2"""
        arguments = [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, ExportCurrentPage, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, OptimizeForImageQuality, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat2(*arguments)

    def ExportAsFixedFormat3(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, ExportCurrentPage=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, OptimizeForImageQuality=None, ImproveExportTagging=None, FixedFormatExtClassPtr=None):
        arguments = com_arguments([unwrap(a) for a in [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, ExportCurrentPage, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, OptimizeForImageQuality, ImproveExportTagging, FixedFormatExtClassPtr]])
        self.com_object.ExportAsFixedFormat3(*arguments)

    def exportasfixedformat3(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, ExportCurrentPage=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, OptimizeForImageQuality=None, ImproveExportTagging=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat3"""
        arguments = [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, ExportCurrentPage, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, OptimizeForImageQuality, ImproveExportTagging, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat3(*arguments)

    def export_as_fixed_format3(self, OutputFileName=None, ExportFormat=None, OpenAfterExport=None, OptimizeFor=None, ExportCurrentPage=None, Item=None, IncludeDocProps=None, KeepIRM=None, CreateBookmarks=None, DocStructureTags=None, BitmapMissingFonts=None, UseISO19005_1=None, OptimizeForImageQuality=None, ImproveExportTagging=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat3"""
        arguments = [OutputFileName, ExportFormat, OpenAfterExport, OptimizeFor, ExportCurrentPage, Item, IncludeDocProps, KeepIRM, CreateBookmarks, DocStructureTags, BitmapMissingFonts, UseISO19005_1, OptimizeForImageQuality, ImproveExportTagging, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat3(*arguments)

    def Extend(self, Character=None):
        arguments = com_arguments([unwrap(a) for a in [Character]])
        self.com_object.Extend(*arguments)

    def extend(self, Character=None):
        """Alias for Extend"""
        arguments = [Character]
        return self.Extend(*arguments)

    def GoTo(self, What=None, Which=None, Count=None, Name=None):
        arguments = com_arguments([unwrap(a) for a in [What, Which, Count, Name]])
        return self.com_object.GoTo(*arguments)

    def goto(self, What=None, Which=None, Count=None, Name=None):
        """Alias for GoTo"""
        arguments = [What, Which, Count, Name]
        return self.GoTo(*arguments)

    def go_to(self, What=None, Which=None, Count=None, Name=None):
        """Alias for GoTo"""
        arguments = [What, Which, Count, Name]
        return self.GoTo(*arguments)

    def GoToEditableRange(self, EditorID=None):
        arguments = com_arguments([unwrap(a) for a in [EditorID]])
        return Range(self.com_object.GoToEditableRange(*arguments))

    def gotoeditablerange(self, EditorID=None):
        """Alias for GoToEditableRange"""
        arguments = [EditorID]
        return self.GoToEditableRange(*arguments)

    def go_to_editable_range(self, EditorID=None):
        """Alias for GoToEditableRange"""
        arguments = [EditorID]
        return self.GoToEditableRange(*arguments)

    def GoToNext(self, What=None):
        arguments = com_arguments([unwrap(a) for a in [What]])
        self.com_object.GoToNext(*arguments)

    def gotonext(self, What=None):
        """Alias for GoToNext"""
        arguments = [What]
        return self.GoToNext(*arguments)

    def go_to_next(self, What=None):
        """Alias for GoToNext"""
        arguments = [What]
        return self.GoToNext(*arguments)

    def GoToPrevious(self, What=None):
        arguments = com_arguments([unwrap(a) for a in [What]])
        self.com_object.GoToPrevious(*arguments)

    def gotoprevious(self, What=None):
        """Alias for GoToPrevious"""
        arguments = [What]
        return self.GoToPrevious(*arguments)

    def go_to_previous(self, What=None):
        """Alias for GoToPrevious"""
        arguments = [What]
        return self.GoToPrevious(*arguments)

    def HomeKey(self, Unit=None, Extend=None):
        arguments = com_arguments([unwrap(a) for a in [Unit, Extend]])
        self.com_object.HomeKey(*arguments)

    def homekey(self, Unit=None, Extend=None):
        """Alias for HomeKey"""
        arguments = [Unit, Extend]
        return self.HomeKey(*arguments)

    def home_key(self, Unit=None, Extend=None):
        """Alias for HomeKey"""
        arguments = [Unit, Extend]
        return self.HomeKey(*arguments)

    def InRange(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        return self.com_object.InRange(*arguments)

    def inrange(self, Range=None):
        """Alias for InRange"""
        arguments = [Range]
        return self.InRange(*arguments)

    def in_range(self, Range=None):
        """Alias for InRange"""
        arguments = [Range]
        return self.InRange(*arguments)

    def InsertAfter(self, Text=None):
        arguments = com_arguments([unwrap(a) for a in [Text]])
        self.com_object.InsertAfter(*arguments)

    def insertafter(self, Text=None):
        """Alias for InsertAfter"""
        arguments = [Text]
        return self.InsertAfter(*arguments)

    def insert_after(self, Text=None):
        """Alias for InsertAfter"""
        arguments = [Text]
        return self.InsertAfter(*arguments)

    def InsertBefore(self, Text=None):
        arguments = com_arguments([unwrap(a) for a in [Text]])
        self.com_object.InsertBefore(*arguments)

    def insertbefore(self, Text=None):
        """Alias for InsertBefore"""
        arguments = [Text]
        return self.InsertBefore(*arguments)

    def insert_before(self, Text=None):
        """Alias for InsertBefore"""
        arguments = [Text]
        return self.InsertBefore(*arguments)

    def InsertBreak(self, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Type]])
        self.com_object.InsertBreak(*arguments)

    def insertbreak(self, Type=None):
        """Alias for InsertBreak"""
        arguments = [Type]
        return self.InsertBreak(*arguments)

    def insert_break(self, Type=None):
        """Alias for InsertBreak"""
        arguments = [Type]
        return self.InsertBreak(*arguments)

    def InsertCaption(self, Label=None, Title=None, TitleAutoText=None, Position=None, ExcludeLabel=None):
        arguments = com_arguments([unwrap(a) for a in [Label, Title, TitleAutoText, Position, ExcludeLabel]])
        self.com_object.InsertCaption(*arguments)

    def insertcaption(self, Label=None, Title=None, TitleAutoText=None, Position=None, ExcludeLabel=None):
        """Alias for InsertCaption"""
        arguments = [Label, Title, TitleAutoText, Position, ExcludeLabel]
        return self.InsertCaption(*arguments)

    def insert_caption(self, Label=None, Title=None, TitleAutoText=None, Position=None, ExcludeLabel=None):
        """Alias for InsertCaption"""
        arguments = [Label, Title, TitleAutoText, Position, ExcludeLabel]
        return self.InsertCaption(*arguments)

    def InsertCells(self, ShiftCells=None):
        arguments = com_arguments([unwrap(a) for a in [ShiftCells]])
        self.com_object.InsertCells(*arguments)

    def insertcells(self, ShiftCells=None):
        """Alias for InsertCells"""
        arguments = [ShiftCells]
        return self.InsertCells(*arguments)

    def insert_cells(self, ShiftCells=None):
        """Alias for InsertCells"""
        arguments = [ShiftCells]
        return self.InsertCells(*arguments)

    def InsertColumns(self):
        self.com_object.InsertColumns()

    def insertcolumns(self):
        """Alias for InsertColumns"""
        return self.InsertColumns()

    def insert_columns(self):
        """Alias for InsertColumns"""
        return self.InsertColumns()

    def InsertColumnsRight(self):
        self.com_object.InsertColumnsRight()

    def insertcolumnsright(self):
        """Alias for InsertColumnsRight"""
        return self.InsertColumnsRight()

    def insert_columns_right(self):
        """Alias for InsertColumnsRight"""
        return self.InsertColumnsRight()

    def InsertCrossReference(self, ReferenceType=None, ReferenceKind=None, ReferenceItem=None, InsertAsHyperlink=None, IncludePosition=None, SeparateNumbers=None, SeparatorString=None):
        arguments = com_arguments([unwrap(a) for a in [ReferenceType, ReferenceKind, ReferenceItem, InsertAsHyperlink, IncludePosition, SeparateNumbers, SeparatorString]])
        self.com_object.InsertCrossReference(*arguments)

    def insertcrossreference(self, ReferenceType=None, ReferenceKind=None, ReferenceItem=None, InsertAsHyperlink=None, IncludePosition=None, SeparateNumbers=None, SeparatorString=None):
        """Alias for InsertCrossReference"""
        arguments = [ReferenceType, ReferenceKind, ReferenceItem, InsertAsHyperlink, IncludePosition, SeparateNumbers, SeparatorString]
        return self.InsertCrossReference(*arguments)

    def insert_cross_reference(self, ReferenceType=None, ReferenceKind=None, ReferenceItem=None, InsertAsHyperlink=None, IncludePosition=None, SeparateNumbers=None, SeparatorString=None):
        """Alias for InsertCrossReference"""
        arguments = [ReferenceType, ReferenceKind, ReferenceItem, InsertAsHyperlink, IncludePosition, SeparateNumbers, SeparatorString]
        return self.InsertCrossReference(*arguments)

    def InsertDateTime(self, DateTimeFormat=None, InsertAsField=None, InsertAsFullWidth=None, DateLanguage=None, CalendarType=None):
        arguments = com_arguments([unwrap(a) for a in [DateTimeFormat, InsertAsField, InsertAsFullWidth, DateLanguage, CalendarType]])
        self.com_object.InsertDateTime(*arguments)

    def insertdatetime(self, DateTimeFormat=None, InsertAsField=None, InsertAsFullWidth=None, DateLanguage=None, CalendarType=None):
        """Alias for InsertDateTime"""
        arguments = [DateTimeFormat, InsertAsField, InsertAsFullWidth, DateLanguage, CalendarType]
        return self.InsertDateTime(*arguments)

    def insert_date_time(self, DateTimeFormat=None, InsertAsField=None, InsertAsFullWidth=None, DateLanguage=None, CalendarType=None):
        """Alias for InsertDateTime"""
        arguments = [DateTimeFormat, InsertAsField, InsertAsFullWidth, DateLanguage, CalendarType]
        return self.InsertDateTime(*arguments)

    def InsertFile(self, FileName=None, Range=None, ConfirmConversions=None, Link=None, Attachment=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, Range, ConfirmConversions, Link, Attachment]])
        self.com_object.InsertFile(*arguments)

    def insertfile(self, FileName=None, Range=None, ConfirmConversions=None, Link=None, Attachment=None):
        """Alias for InsertFile"""
        arguments = [FileName, Range, ConfirmConversions, Link, Attachment]
        return self.InsertFile(*arguments)

    def insert_file(self, FileName=None, Range=None, ConfirmConversions=None, Link=None, Attachment=None):
        """Alias for InsertFile"""
        arguments = [FileName, Range, ConfirmConversions, Link, Attachment]
        return self.InsertFile(*arguments)

    def InsertFormula(self, Formula=None, NumberFormat=None):
        arguments = com_arguments([unwrap(a) for a in [Formula, NumberFormat]])
        self.com_object.InsertFormula(*arguments)

    def insertformula(self, Formula=None, NumberFormat=None):
        """Alias for InsertFormula"""
        arguments = [Formula, NumberFormat]
        return self.InsertFormula(*arguments)

    def insert_formula(self, Formula=None, NumberFormat=None):
        """Alias for InsertFormula"""
        arguments = [Formula, NumberFormat]
        return self.InsertFormula(*arguments)

    def InsertNewPage(self):
        self.com_object.InsertNewPage()

    def insertnewpage(self):
        """Alias for InsertNewPage"""
        return self.InsertNewPage()

    def insert_new_page(self):
        """Alias for InsertNewPage"""
        return self.InsertNewPage()

    def InsertParagraph(self):
        self.com_object.InsertParagraph()

    def insertparagraph(self):
        """Alias for InsertParagraph"""
        return self.InsertParagraph()

    def insert_paragraph(self):
        """Alias for InsertParagraph"""
        return self.InsertParagraph()

    def InsertParagraphAfter(self):
        self.com_object.InsertParagraphAfter()

    def insertparagraphafter(self):
        """Alias for InsertParagraphAfter"""
        return self.InsertParagraphAfter()

    def insert_paragraph_after(self):
        """Alias for InsertParagraphAfter"""
        return self.InsertParagraphAfter()

    def InsertParagraphBefore(self):
        self.com_object.InsertParagraphBefore()

    def insertparagraphbefore(self):
        """Alias for InsertParagraphBefore"""
        return self.InsertParagraphBefore()

    def insert_paragraph_before(self):
        """Alias for InsertParagraphBefore"""
        return self.InsertParagraphBefore()

    def InsertRows(self, NumRows=None):
        arguments = com_arguments([unwrap(a) for a in [NumRows]])
        self.com_object.InsertRows(*arguments)

    def insertrows(self, NumRows=None):
        """Alias for InsertRows"""
        arguments = [NumRows]
        return self.InsertRows(*arguments)

    def insert_rows(self, NumRows=None):
        """Alias for InsertRows"""
        arguments = [NumRows]
        return self.InsertRows(*arguments)

    def InsertRowsAbove(self):
        self.com_object.InsertRowsAbove()

    def insertrowsabove(self):
        """Alias for InsertRowsAbove"""
        return self.InsertRowsAbove()

    def insert_rows_above(self):
        """Alias for InsertRowsAbove"""
        return self.InsertRowsAbove()

    def InsertRowsBelow(self):
        self.com_object.InsertRowsBelow()

    def insertrowsbelow(self):
        """Alias for InsertRowsBelow"""
        return self.InsertRowsBelow()

    def insert_rows_below(self):
        """Alias for InsertRowsBelow"""
        return self.InsertRowsBelow()

    def InsertStyleSeparator(self):
        self.com_object.InsertStyleSeparator()

    def insertstyleseparator(self):
        """Alias for InsertStyleSeparator"""
        return self.InsertStyleSeparator()

    def insert_style_separator(self):
        """Alias for InsertStyleSeparator"""
        return self.InsertStyleSeparator()

    def InsertSymbol(self, CharacterNumber=None, Font=None, Unicode=None, Bias=None):
        arguments = com_arguments([unwrap(a) for a in [CharacterNumber, Font, Unicode, Bias]])
        self.com_object.InsertSymbol(*arguments)

    def insertsymbol(self, CharacterNumber=None, Font=None, Unicode=None, Bias=None):
        """Alias for InsertSymbol"""
        arguments = [CharacterNumber, Font, Unicode, Bias]
        return self.InsertSymbol(*arguments)

    def insert_symbol(self, CharacterNumber=None, Font=None, Unicode=None, Bias=None):
        """Alias for InsertSymbol"""
        arguments = [CharacterNumber, Font, Unicode, Bias]
        return self.InsertSymbol(*arguments)

    def InsertXML(self, XML=None, Transform=None):
        arguments = com_arguments([unwrap(a) for a in [XML, Transform]])
        return self.com_object.InsertXML(*arguments)

    def insertxml(self, XML=None, Transform=None):
        """Alias for InsertXML"""
        arguments = [XML, Transform]
        return self.InsertXML(*arguments)

    def insert_x_m_l(self, XML=None, Transform=None):
        """Alias for InsertXML"""
        arguments = [XML, Transform]
        return self.InsertXML(*arguments)

    def InStory(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        return self.com_object.InStory(*arguments)

    def instory(self, Range=None):
        """Alias for InStory"""
        arguments = [Range]
        return self.InStory(*arguments)

    def in_story(self, Range=None):
        """Alias for InStory"""
        arguments = [Range]
        return self.InStory(*arguments)

    def IsEqual(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        return self.com_object.IsEqual(*arguments)

    def isequal(self, Range=None):
        """Alias for IsEqual"""
        arguments = [Range]
        return self.IsEqual(*arguments)

    def is_equal(self, Range=None):
        """Alias for IsEqual"""
        arguments = [Range]
        return self.IsEqual(*arguments)

    def ItalicRun(self):
        self.com_object.ItalicRun()

    def italicrun(self):
        """Alias for ItalicRun"""
        return self.ItalicRun()

    def italic_run(self):
        """Alias for ItalicRun"""
        return self.ItalicRun()

    def LtrPara(self):
        self.com_object.LtrPara()

    def ltrpara(self):
        """Alias for LtrPara"""
        return self.LtrPara()

    def ltr_para(self):
        """Alias for LtrPara"""
        return self.LtrPara()

    def LtrRun(self):
        self.com_object.LtrRun()

    def ltrrun(self):
        """Alias for LtrRun"""
        return self.LtrRun()

    def ltr_run(self):
        """Alias for LtrRun"""
        return self.LtrRun()

    def Move(self, Unit=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Unit, Count]])
        return self.com_object.Move(*arguments)

    def move(self, Unit=None, Count=None):
        """Alias for Move"""
        arguments = [Unit, Count]
        return self.Move(*arguments)

    def MoveDown(self, Unit=None, Count=None, Extend=None):
        arguments = com_arguments([unwrap(a) for a in [Unit, Count, Extend]])
        self.com_object.MoveDown(*arguments)

    def movedown(self, Unit=None, Count=None, Extend=None):
        """Alias for MoveDown"""
        arguments = [Unit, Count, Extend]
        return self.MoveDown(*arguments)

    def move_down(self, Unit=None, Count=None, Extend=None):
        """Alias for MoveDown"""
        arguments = [Unit, Count, Extend]
        return self.MoveDown(*arguments)

    def MoveEnd(self, Unit=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Unit, Count]])
        return self.com_object.MoveEnd(*arguments)

    def moveend(self, Unit=None, Count=None):
        """Alias for MoveEnd"""
        arguments = [Unit, Count]
        return self.MoveEnd(*arguments)

    def move_end(self, Unit=None, Count=None):
        """Alias for MoveEnd"""
        arguments = [Unit, Count]
        return self.MoveEnd(*arguments)

    def MoveEndUntil(self, Cset=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Cset, Count]])
        return self.com_object.MoveEndUntil(*arguments)

    def moveenduntil(self, Cset=None, Count=None):
        """Alias for MoveEndUntil"""
        arguments = [Cset, Count]
        return self.MoveEndUntil(*arguments)

    def move_end_until(self, Cset=None, Count=None):
        """Alias for MoveEndUntil"""
        arguments = [Cset, Count]
        return self.MoveEndUntil(*arguments)

    def MoveEndWhile(self, Cset=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Cset, Count]])
        self.com_object.MoveEndWhile(*arguments)

    def moveendwhile(self, Cset=None, Count=None):
        """Alias for MoveEndWhile"""
        arguments = [Cset, Count]
        return self.MoveEndWhile(*arguments)

    def move_end_while(self, Cset=None, Count=None):
        """Alias for MoveEndWhile"""
        arguments = [Cset, Count]
        return self.MoveEndWhile(*arguments)

    def MoveLeft(self, Unit=None, Count=None, Extend=None):
        arguments = com_arguments([unwrap(a) for a in [Unit, Count, Extend]])
        self.com_object.MoveLeft(*arguments)

    def moveleft(self, Unit=None, Count=None, Extend=None):
        """Alias for MoveLeft"""
        arguments = [Unit, Count, Extend]
        return self.MoveLeft(*arguments)

    def move_left(self, Unit=None, Count=None, Extend=None):
        """Alias for MoveLeft"""
        arguments = [Unit, Count, Extend]
        return self.MoveLeft(*arguments)

    def MoveRight(self, Unit=None, Count=None, Extend=None):
        arguments = com_arguments([unwrap(a) for a in [Unit, Count, Extend]])
        return self.com_object.MoveRight(*arguments)

    def moveright(self, Unit=None, Count=None, Extend=None):
        """Alias for MoveRight"""
        arguments = [Unit, Count, Extend]
        return self.MoveRight(*arguments)

    def move_right(self, Unit=None, Count=None, Extend=None):
        """Alias for MoveRight"""
        arguments = [Unit, Count, Extend]
        return self.MoveRight(*arguments)

    def MoveStart(self, Unit=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Unit, Count]])
        return self.com_object.MoveStart(*arguments)

    def movestart(self, Unit=None, Count=None):
        """Alias for MoveStart"""
        arguments = [Unit, Count]
        return self.MoveStart(*arguments)

    def move_start(self, Unit=None, Count=None):
        """Alias for MoveStart"""
        arguments = [Unit, Count]
        return self.MoveStart(*arguments)

    def MoveStartUntil(self, Cset=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Cset, Count]])
        self.com_object.MoveStartUntil(*arguments)

    def movestartuntil(self, Cset=None, Count=None):
        """Alias for MoveStartUntil"""
        arguments = [Cset, Count]
        return self.MoveStartUntil(*arguments)

    def move_start_until(self, Cset=None, Count=None):
        """Alias for MoveStartUntil"""
        arguments = [Cset, Count]
        return self.MoveStartUntil(*arguments)

    def MoveStartWhile(self, Cset=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Cset, Count]])
        self.com_object.MoveStartWhile(*arguments)

    def movestartwhile(self, Cset=None, Count=None):
        """Alias for MoveStartWhile"""
        arguments = [Cset, Count]
        return self.MoveStartWhile(*arguments)

    def move_start_while(self, Cset=None, Count=None):
        """Alias for MoveStartWhile"""
        arguments = [Cset, Count]
        return self.MoveStartWhile(*arguments)

    def MoveUntil(self, Cset=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Cset, Count]])
        self.com_object.MoveUntil(*arguments)

    def moveuntil(self, Cset=None, Count=None):
        """Alias for MoveUntil"""
        arguments = [Cset, Count]
        return self.MoveUntil(*arguments)

    def move_until(self, Cset=None, Count=None):
        """Alias for MoveUntil"""
        arguments = [Cset, Count]
        return self.MoveUntil(*arguments)

    def MoveUp(self, Unit=None, Count=None, Extend=None):
        arguments = com_arguments([unwrap(a) for a in [Unit, Count, Extend]])
        return self.com_object.MoveUp(*arguments)

    def moveup(self, Unit=None, Count=None, Extend=None):
        """Alias for MoveUp"""
        arguments = [Unit, Count, Extend]
        return self.MoveUp(*arguments)

    def move_up(self, Unit=None, Count=None, Extend=None):
        """Alias for MoveUp"""
        arguments = [Unit, Count, Extend]
        return self.MoveUp(*arguments)

    def MoveWhile(self, Cset=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Cset, Count]])
        self.com_object.MoveWhile(*arguments)

    def movewhile(self, Cset=None, Count=None):
        """Alias for MoveWhile"""
        arguments = [Cset, Count]
        return self.MoveWhile(*arguments)

    def move_while(self, Cset=None, Count=None):
        """Alias for MoveWhile"""
        arguments = [Cset, Count]
        return self.MoveWhile(*arguments)

    def Next(self, Unit=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Unit, Count]])
        return Range(self.com_object.Next(*arguments))

    def next(self, Unit=None, Count=None):
        """Alias for Next"""
        arguments = [Unit, Count]
        return self.Next(*arguments)

    def NextField(self):
        return Field(self.com_object.NextField())

    def nextfield(self):
        """Alias for NextField"""
        return self.NextField()

    def next_field(self):
        """Alias for NextField"""
        return self.NextField()

    def NextRevision(self, Wrap=None):
        arguments = com_arguments([unwrap(a) for a in [Wrap]])
        return Revision(self.com_object.NextRevision(*arguments))

    def nextrevision(self, Wrap=None):
        """Alias for NextRevision"""
        arguments = [Wrap]
        return self.NextRevision(*arguments)

    def next_revision(self, Wrap=None):
        """Alias for NextRevision"""
        arguments = [Wrap]
        return self.NextRevision(*arguments)

    def NextSubdocument(self):
        self.com_object.NextSubdocument()

    def nextsubdocument(self):
        """Alias for NextSubdocument"""
        return self.NextSubdocument()

    def next_subdocument(self):
        """Alias for NextSubdocument"""
        return self.NextSubdocument()

    def Paste(self):
        self.com_object.Paste()

    def paste(self):
        """Alias for Paste"""
        return self.Paste()

    def PasteAndFormat(self, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Type]])
        self.com_object.PasteAndFormat(*arguments)

    def pasteandformat(self, Type=None):
        """Alias for PasteAndFormat"""
        arguments = [Type]
        return self.PasteAndFormat(*arguments)

    def paste_and_format(self, Type=None):
        """Alias for PasteAndFormat"""
        arguments = [Type]
        return self.PasteAndFormat(*arguments)

    def PasteAppendTable(self):
        self.com_object.PasteAppendTable()

    def pasteappendtable(self):
        """Alias for PasteAppendTable"""
        return self.PasteAppendTable()

    def paste_append_table(self):
        """Alias for PasteAppendTable"""
        return self.PasteAppendTable()

    def PasteAsNestedTable(self):
        self.com_object.PasteAsNestedTable()

    def pasteasnestedtable(self):
        """Alias for PasteAsNestedTable"""
        return self.PasteAsNestedTable()

    def paste_as_nested_table(self):
        """Alias for PasteAsNestedTable"""
        return self.PasteAsNestedTable()

    def PasteExcelTable(self, LinkedToExcel=None, WordFormatting=None, RTF=None):
        arguments = com_arguments([unwrap(a) for a in [LinkedToExcel, WordFormatting, RTF]])
        self.com_object.PasteExcelTable(*arguments)

    def pasteexceltable(self, LinkedToExcel=None, WordFormatting=None, RTF=None):
        """Alias for PasteExcelTable"""
        arguments = [LinkedToExcel, WordFormatting, RTF]
        return self.PasteExcelTable(*arguments)

    def paste_excel_table(self, LinkedToExcel=None, WordFormatting=None, RTF=None):
        """Alias for PasteExcelTable"""
        arguments = [LinkedToExcel, WordFormatting, RTF]
        return self.PasteExcelTable(*arguments)

    def PasteFormat(self):
        self.com_object.PasteFormat()

    def pasteformat(self):
        """Alias for PasteFormat"""
        return self.PasteFormat()

    def paste_format(self):
        """Alias for PasteFormat"""
        return self.PasteFormat()

    def PasteSpecial(self, IconIndex=None, Link=None, Placement=None, DisplayAsIcon=None, DataType=None, IconFileName=None, IconLabel=None):
        arguments = com_arguments([unwrap(a) for a in [IconIndex, Link, Placement, DisplayAsIcon, DataType, IconFileName, IconLabel]])
        self.com_object.PasteSpecial(*arguments)

    def pastespecial(self, IconIndex=None, Link=None, Placement=None, DisplayAsIcon=None, DataType=None, IconFileName=None, IconLabel=None):
        """Alias for PasteSpecial"""
        arguments = [IconIndex, Link, Placement, DisplayAsIcon, DataType, IconFileName, IconLabel]
        return self.PasteSpecial(*arguments)

    def paste_special(self, IconIndex=None, Link=None, Placement=None, DisplayAsIcon=None, DataType=None, IconFileName=None, IconLabel=None):
        """Alias for PasteSpecial"""
        arguments = [IconIndex, Link, Placement, DisplayAsIcon, DataType, IconFileName, IconLabel]
        return self.PasteSpecial(*arguments)

    def Previous(self, Unit=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Unit, Count]])
        return Range(self.com_object.Previous(*arguments))

    def previous(self, Unit=None, Count=None):
        """Alias for Previous"""
        arguments = [Unit, Count]
        return self.Previous(*arguments)

    def PreviousField(self):
        return Field(self.com_object.PreviousField())

    def previousfield(self):
        """Alias for PreviousField"""
        return self.PreviousField()

    def previous_field(self):
        """Alias for PreviousField"""
        return self.PreviousField()

    def PreviousRevision(self, Wrap=None):
        arguments = com_arguments([unwrap(a) for a in [Wrap]])
        return Revision(self.com_object.PreviousRevision(*arguments))

    def previousrevision(self, Wrap=None):
        """Alias for PreviousRevision"""
        arguments = [Wrap]
        return self.PreviousRevision(*arguments)

    def previous_revision(self, Wrap=None):
        """Alias for PreviousRevision"""
        arguments = [Wrap]
        return self.PreviousRevision(*arguments)

    def PreviousSubdocument(self):
        self.com_object.PreviousSubdocument()

    def previoussubdocument(self):
        """Alias for PreviousSubdocument"""
        return self.PreviousSubdocument()

    def previous_subdocument(self):
        """Alias for PreviousSubdocument"""
        return self.PreviousSubdocument()

    def ReadingModeGrowFont(self):
        return self.com_object.ReadingModeGrowFont()

    def readingmodegrowfont(self):
        """Alias for ReadingModeGrowFont"""
        return self.ReadingModeGrowFont()

    def reading_mode_grow_font(self):
        """Alias for ReadingModeGrowFont"""
        return self.ReadingModeGrowFont()

    def ReadingModeShrinkFont(self):
        return self.com_object.ReadingModeShrinkFont()

    def readingmodeshrinkfont(self):
        """Alias for ReadingModeShrinkFont"""
        return self.ReadingModeShrinkFont()

    def reading_mode_shrink_font(self):
        """Alias for ReadingModeShrinkFont"""
        return self.ReadingModeShrinkFont()

    def RtlPara(self):
        self.com_object.RtlPara()

    def rtlpara(self):
        """Alias for RtlPara"""
        return self.RtlPara()

    def rtl_para(self):
        """Alias for RtlPara"""
        return self.RtlPara()

    def RtlRun(self):
        self.com_object.RtlRun()

    def rtlrun(self):
        """Alias for RtlRun"""
        return self.RtlRun()

    def rtl_run(self):
        """Alias for RtlRun"""
        return self.RtlRun()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()

    def SelectCell(self):
        self.com_object.SelectCell()

    def selectcell(self):
        """Alias for SelectCell"""
        return self.SelectCell()

    def select_cell(self):
        """Alias for SelectCell"""
        return self.SelectCell()

    def SelectColumn(self):
        self.com_object.SelectColumn()

    def selectcolumn(self):
        """Alias for SelectColumn"""
        return self.SelectColumn()

    def select_column(self):
        """Alias for SelectColumn"""
        return self.SelectColumn()

    def SelectCurrentAlignment(self):
        self.com_object.SelectCurrentAlignment()

    def selectcurrentalignment(self):
        """Alias for SelectCurrentAlignment"""
        return self.SelectCurrentAlignment()

    def select_current_alignment(self):
        """Alias for SelectCurrentAlignment"""
        return self.SelectCurrentAlignment()

    def SelectCurrentColor(self):
        self.com_object.SelectCurrentColor()

    def selectcurrentcolor(self):
        """Alias for SelectCurrentColor"""
        return self.SelectCurrentColor()

    def select_current_color(self):
        """Alias for SelectCurrentColor"""
        return self.SelectCurrentColor()

    def SelectCurrentFont(self):
        self.com_object.SelectCurrentFont()

    def selectcurrentfont(self):
        """Alias for SelectCurrentFont"""
        return self.SelectCurrentFont()

    def select_current_font(self):
        """Alias for SelectCurrentFont"""
        return self.SelectCurrentFont()

    def SelectCurrentIndent(self):
        self.com_object.SelectCurrentIndent()

    def selectcurrentindent(self):
        """Alias for SelectCurrentIndent"""
        return self.SelectCurrentIndent()

    def select_current_indent(self):
        """Alias for SelectCurrentIndent"""
        return self.SelectCurrentIndent()

    def SelectCurrentSpacing(self):
        self.com_object.SelectCurrentSpacing()

    def selectcurrentspacing(self):
        """Alias for SelectCurrentSpacing"""
        return self.SelectCurrentSpacing()

    def select_current_spacing(self):
        """Alias for SelectCurrentSpacing"""
        return self.SelectCurrentSpacing()

    def SelectCurrentTabs(self):
        self.com_object.SelectCurrentTabs()

    def selectcurrenttabs(self):
        """Alias for SelectCurrentTabs"""
        return self.SelectCurrentTabs()

    def select_current_tabs(self):
        """Alias for SelectCurrentTabs"""
        return self.SelectCurrentTabs()

    def SelectRow(self):
        self.com_object.SelectRow()

    def selectrow(self):
        """Alias for SelectRow"""
        return self.SelectRow()

    def select_row(self):
        """Alias for SelectRow"""
        return self.SelectRow()

    def SetRange(self, Start=None, End=None):
        arguments = com_arguments([unwrap(a) for a in [Start, End]])
        self.com_object.SetRange(*arguments)

    def setrange(self, Start=None, End=None):
        """Alias for SetRange"""
        arguments = [Start, End]
        return self.SetRange(*arguments)

    def set_range(self, Start=None, End=None):
        """Alias for SetRange"""
        arguments = [Start, End]
        return self.SetRange(*arguments)

    def Shrink(self):
        self.com_object.Shrink()

    def shrink(self):
        """Alias for Shrink"""
        return self.Shrink()

    def ShrinkDiscontiguousSelection(self):
        self.com_object.ShrinkDiscontiguousSelection()

    def shrinkdiscontiguousselection(self):
        """Alias for ShrinkDiscontiguousSelection"""
        return self.ShrinkDiscontiguousSelection()

    def shrink_discontiguous_selection(self):
        """Alias for ShrinkDiscontiguousSelection"""
        return self.ShrinkDiscontiguousSelection()

    def Sort(self, ExcludeHeader=None, FieldNumber=None, SortFieldType=None, SortOrder=None, FieldNumber2=None, SortFieldType2=None, SortOrder2=None, FieldNumber3=None, SortFieldType3=None, SortOrder3=None, SortColumn=None, Separator=None, CaseSensitive=None, BidiSort=None, IgnoreThe=None, IgnoreKashida=None, IgnoreDiacritics=None, IgnoreHe=None, LanguageID=None, SubFieldNumber=None, SubFieldNumber2=None, SubFieldNumber3=None):
        arguments = com_arguments([unwrap(a) for a in [ExcludeHeader, FieldNumber, SortFieldType, SortOrder, FieldNumber2, SortFieldType2, SortOrder2, FieldNumber3, SortFieldType3, SortOrder3, SortColumn, Separator, CaseSensitive, BidiSort, IgnoreThe, IgnoreKashida, IgnoreDiacritics, IgnoreHe, LanguageID, SubFieldNumber, SubFieldNumber2, SubFieldNumber3]])
        self.com_object.Sort(*arguments)

    def sort(self, ExcludeHeader=None, FieldNumber=None, SortFieldType=None, SortOrder=None, FieldNumber2=None, SortFieldType2=None, SortOrder2=None, FieldNumber3=None, SortFieldType3=None, SortOrder3=None, SortColumn=None, Separator=None, CaseSensitive=None, BidiSort=None, IgnoreThe=None, IgnoreKashida=None, IgnoreDiacritics=None, IgnoreHe=None, LanguageID=None, SubFieldNumber=None, SubFieldNumber2=None, SubFieldNumber3=None):
        """Alias for Sort"""
        arguments = [ExcludeHeader, FieldNumber, SortFieldType, SortOrder, FieldNumber2, SortFieldType2, SortOrder2, FieldNumber3, SortFieldType3, SortOrder3, SortColumn, Separator, CaseSensitive, BidiSort, IgnoreThe, IgnoreKashida, IgnoreDiacritics, IgnoreHe, LanguageID, SubFieldNumber, SubFieldNumber2, SubFieldNumber3]
        return self.Sort(*arguments)

    def SortAscending(self):
        self.com_object.SortAscending()

    def sortascending(self):
        """Alias for SortAscending"""
        return self.SortAscending()

    def sort_ascending(self):
        """Alias for SortAscending"""
        return self.SortAscending()

    def SortByHeadings(self, SortFieldType=None, SortOrder=None, CaseSensitive=None, BidiSort=None, IgnoreThe=None, IgnoreKashida=None, IgnoreDiacritics=None, IgnoreHe=None, LanguageID=None):
        arguments = com_arguments([unwrap(a) for a in [SortFieldType, SortOrder, CaseSensitive, BidiSort, IgnoreThe, IgnoreKashida, IgnoreDiacritics, IgnoreHe, LanguageID]])
        return self.com_object.SortByHeadings(*arguments)

    def sortbyheadings(self, SortFieldType=None, SortOrder=None, CaseSensitive=None, BidiSort=None, IgnoreThe=None, IgnoreKashida=None, IgnoreDiacritics=None, IgnoreHe=None, LanguageID=None):
        """Alias for SortByHeadings"""
        arguments = [SortFieldType, SortOrder, CaseSensitive, BidiSort, IgnoreThe, IgnoreKashida, IgnoreDiacritics, IgnoreHe, LanguageID]
        return self.SortByHeadings(*arguments)

    def sort_by_headings(self, SortFieldType=None, SortOrder=None, CaseSensitive=None, BidiSort=None, IgnoreThe=None, IgnoreKashida=None, IgnoreDiacritics=None, IgnoreHe=None, LanguageID=None):
        """Alias for SortByHeadings"""
        arguments = [SortFieldType, SortOrder, CaseSensitive, BidiSort, IgnoreThe, IgnoreKashida, IgnoreDiacritics, IgnoreHe, LanguageID]
        return self.SortByHeadings(*arguments)

    def SortDescending(self):
        self.com_object.SortDescending()

    def sortdescending(self):
        """Alias for SortDescending"""
        return self.SortDescending()

    def sort_descending(self):
        """Alias for SortDescending"""
        return self.SortDescending()

    def SplitTable(self):
        self.com_object.SplitTable()

    def splittable(self):
        """Alias for SplitTable"""
        return self.SplitTable()

    def split_table(self):
        """Alias for SplitTable"""
        return self.SplitTable()

    def StartOf(self, Unit=None, Extend=None):
        arguments = com_arguments([unwrap(a) for a in [Unit, Extend]])
        self.com_object.StartOf(*arguments)

    def startof(self, Unit=None, Extend=None):
        """Alias for StartOf"""
        arguments = [Unit, Extend]
        return self.StartOf(*arguments)

    def start_of(self, Unit=None, Extend=None):
        """Alias for StartOf"""
        arguments = [Unit, Extend]
        return self.StartOf(*arguments)

    def ToggleCharacterCode(self):
        self.com_object.ToggleCharacterCode()

    def togglecharactercode(self):
        """Alias for ToggleCharacterCode"""
        return self.ToggleCharacterCode()

    def toggle_character_code(self):
        """Alias for ToggleCharacterCode"""
        return self.ToggleCharacterCode()

    def TypeBackspace(self):
        self.com_object.TypeBackspace()

    def typebackspace(self):
        """Alias for TypeBackspace"""
        return self.TypeBackspace()

    def type_backspace(self):
        """Alias for TypeBackspace"""
        return self.TypeBackspace()

    def TypeParagraph(self):
        self.com_object.TypeParagraph()

    def typeparagraph(self):
        """Alias for TypeParagraph"""
        return self.TypeParagraph()

    def type_paragraph(self):
        """Alias for TypeParagraph"""
        return self.TypeParagraph()

    def TypeText(self, Text=None):
        arguments = com_arguments([unwrap(a) for a in [Text]])
        self.com_object.TypeText(*arguments)

    def typetext(self, Text=None):
        """Alias for TypeText"""
        arguments = [Text]
        return self.TypeText(*arguments)

    def type_text(self, Text=None):
        """Alias for TypeText"""
        arguments = [Text]
        return self.TypeText(*arguments)

    def WholeStory(self):
        self.com_object.WholeStory()

    def wholestory(self):
        """Alias for WholeStory"""
        return self.WholeStory()

    def whole_story(self):
        """Alias for WholeStory"""
        return self.WholeStory()


class Sentences:

    def __init__(self, sentences=None):
        self.com_object= sentences

    def __call__(self, item):
        return Sentence(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def First(self):
        return Range(self.com_object.First)

    @property
    def first(self):
        """Alias for First"""
        return self.First

    @property
    def Last(self):
        return Range(self.com_object.Last)

    @property
    def last(self):
        """Alias for Last"""
        return self.Last

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Range(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Series:

    def __init__(self, series=None):
        self.com_object= series

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ApplyPictToEnd(self):
        return self.com_object.ApplyPictToEnd

    @ApplyPictToEnd.setter
    def ApplyPictToEnd(self, value):
        self.com_object.ApplyPictToEnd = value

    @property
    def applypicttoend(self):
        """Alias for ApplyPictToEnd"""
        return self.ApplyPictToEnd

    @applypicttoend.setter
    def applypicttoend(self, value):
        """Alias for ApplyPictToEnd.setter"""
        self.ApplyPictToEnd = value

    @property
    def apply_pict_to_end(self):
        """Alias for ApplyPictToEnd"""
        return self.ApplyPictToEnd

    @apply_pict_to_end.setter
    def apply_pict_to_end(self, value):
        """Alias for ApplyPictToEnd.setter"""
        self.ApplyPictToEnd = value

    @property
    def ApplyPictToFront(self):
        return self.com_object.ApplyPictToFront

    @ApplyPictToFront.setter
    def ApplyPictToFront(self, value):
        self.com_object.ApplyPictToFront = value

    @property
    def applypicttofront(self):
        """Alias for ApplyPictToFront"""
        return self.ApplyPictToFront

    @applypicttofront.setter
    def applypicttofront(self, value):
        """Alias for ApplyPictToFront.setter"""
        self.ApplyPictToFront = value

    @property
    def apply_pict_to_front(self):
        """Alias for ApplyPictToFront"""
        return self.ApplyPictToFront

    @apply_pict_to_front.setter
    def apply_pict_to_front(self, value):
        """Alias for ApplyPictToFront.setter"""
        self.ApplyPictToFront = value

    @property
    def ApplyPictToSides(self):
        return self.com_object.ApplyPictToSides

    @ApplyPictToSides.setter
    def ApplyPictToSides(self, value):
        self.com_object.ApplyPictToSides = value

    @property
    def applypicttosides(self):
        """Alias for ApplyPictToSides"""
        return self.ApplyPictToSides

    @applypicttosides.setter
    def applypicttosides(self, value):
        """Alias for ApplyPictToSides.setter"""
        self.ApplyPictToSides = value

    @property
    def apply_pict_to_sides(self):
        """Alias for ApplyPictToSides"""
        return self.ApplyPictToSides

    @apply_pict_to_sides.setter
    def apply_pict_to_sides(self, value):
        """Alias for ApplyPictToSides.setter"""
        self.ApplyPictToSides = value

    @property
    def AxisGroup(self):
        return XlAxisGroup(self.com_object.AxisGroup)

    @AxisGroup.setter
    def AxisGroup(self, value):
        self.com_object.AxisGroup = value

    @property
    def axisgroup(self):
        """Alias for AxisGroup"""
        return self.AxisGroup

    @axisgroup.setter
    def axisgroup(self, value):
        """Alias for AxisGroup.setter"""
        self.AxisGroup = value

    @property
    def axis_group(self):
        """Alias for AxisGroup"""
        return self.AxisGroup

    @axis_group.setter
    def axis_group(self, value):
        """Alias for AxisGroup.setter"""
        self.AxisGroup = value

    @property
    def BarShape(self):
        return XlBarShape(self.com_object.BarShape)

    @BarShape.setter
    def BarShape(self, value):
        self.com_object.BarShape = value

    @property
    def barshape(self):
        """Alias for BarShape"""
        return self.BarShape

    @barshape.setter
    def barshape(self, value):
        """Alias for BarShape.setter"""
        self.BarShape = value

    @property
    def bar_shape(self):
        """Alias for BarShape"""
        return self.BarShape

    @bar_shape.setter
    def bar_shape(self, value):
        """Alias for BarShape.setter"""
        self.BarShape = value

    @property
    def Border(self):
        return ChartBorder(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def BubbleSizes(self):
        return self.com_object.BubbleSizes

    @BubbleSizes.setter
    def BubbleSizes(self, value):
        self.com_object.BubbleSizes = value

    @property
    def bubblesizes(self):
        """Alias for BubbleSizes"""
        return self.BubbleSizes

    @bubblesizes.setter
    def bubblesizes(self, value):
        """Alias for BubbleSizes.setter"""
        self.BubbleSizes = value

    @property
    def bubble_sizes(self):
        """Alias for BubbleSizes"""
        return self.BubbleSizes

    @bubble_sizes.setter
    def bubble_sizes(self, value):
        """Alias for BubbleSizes.setter"""
        self.BubbleSizes = value

    @property
    def ChartType(self):
        return self.com_object.ChartType

    @ChartType.setter
    def ChartType(self, value):
        self.com_object.ChartType = value

    @property
    def charttype(self):
        """Alias for ChartType"""
        return self.ChartType

    @charttype.setter
    def charttype(self, value):
        """Alias for ChartType.setter"""
        self.ChartType = value

    @property
    def chart_type(self):
        """Alias for ChartType"""
        return self.ChartType

    @chart_type.setter
    def chart_type(self, value):
        """Alias for ChartType.setter"""
        self.ChartType = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ErrorBars(self):
        return ErrorBars(self.com_object.ErrorBars)

    @property
    def errorbars(self):
        """Alias for ErrorBars"""
        return self.ErrorBars

    @property
    def error_bars(self):
        """Alias for ErrorBars"""
        return self.ErrorBars

    @property
    def Explosion(self):
        return self.com_object.Explosion

    @Explosion.setter
    def Explosion(self, value):
        self.com_object.Explosion = value

    @property
    def explosion(self):
        """Alias for Explosion"""
        return self.Explosion

    @explosion.setter
    def explosion(self, value):
        """Alias for Explosion.setter"""
        self.Explosion = value

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def FormulaLocal(self):
        return self.com_object.FormulaLocal

    @FormulaLocal.setter
    def FormulaLocal(self, value):
        self.com_object.FormulaLocal = value

    @property
    def formulalocal(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formulalocal.setter
    def formulalocal(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def formula_local(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formula_local.setter
    def formula_local(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def FormulaR1C1(self):
        return self.com_object.FormulaR1C1

    @FormulaR1C1.setter
    def FormulaR1C1(self, value):
        self.com_object.FormulaR1C1 = value

    @property
    def formular1c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formular1c1.setter
    def formular1c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def formula_r1_c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formula_r1_c1.setter
    def formula_r1_c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def FormulaR1C1Local(self):
        return self.com_object.FormulaR1C1Local

    @FormulaR1C1Local.setter
    def FormulaR1C1Local(self, value):
        self.com_object.FormulaR1C1Local = value

    @property
    def formular1c1local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formular1c1local.setter
    def formular1c1local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def formula_r1_c1_local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formula_r1_c1_local.setter
    def formula_r1_c1_local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def Has3DEffect(self):
        return self.com_object.Has3DEffect

    @Has3DEffect.setter
    def Has3DEffect(self, value):
        self.com_object.Has3DEffect = value

    @property
    def has3deffect(self):
        """Alias for Has3DEffect"""
        return self.Has3DEffect

    @has3deffect.setter
    def has3deffect(self, value):
        """Alias for Has3DEffect.setter"""
        self.Has3DEffect = value

    @property
    def has3_d_effect(self):
        """Alias for Has3DEffect"""
        return self.Has3DEffect

    @has3_d_effect.setter
    def has3_d_effect(self, value):
        """Alias for Has3DEffect.setter"""
        self.Has3DEffect = value

    @property
    def HasDataLabels(self):
        return self.com_object.HasDataLabels

    @HasDataLabels.setter
    def HasDataLabels(self, value):
        self.com_object.HasDataLabels = value

    @property
    def hasdatalabels(self):
        """Alias for HasDataLabels"""
        return self.HasDataLabels

    @hasdatalabels.setter
    def hasdatalabels(self, value):
        """Alias for HasDataLabels.setter"""
        self.HasDataLabels = value

    @property
    def has_data_labels(self):
        """Alias for HasDataLabels"""
        return self.HasDataLabels

    @has_data_labels.setter
    def has_data_labels(self, value):
        """Alias for HasDataLabels.setter"""
        self.HasDataLabels = value

    @property
    def HasErrorBars(self):
        return self.com_object.HasErrorBars

    @HasErrorBars.setter
    def HasErrorBars(self, value):
        self.com_object.HasErrorBars = value

    @property
    def haserrorbars(self):
        """Alias for HasErrorBars"""
        return self.HasErrorBars

    @haserrorbars.setter
    def haserrorbars(self, value):
        """Alias for HasErrorBars.setter"""
        self.HasErrorBars = value

    @property
    def has_error_bars(self):
        """Alias for HasErrorBars"""
        return self.HasErrorBars

    @has_error_bars.setter
    def has_error_bars(self, value):
        """Alias for HasErrorBars.setter"""
        self.HasErrorBars = value

    @property
    def HasLeaderLines(self):
        return self.com_object.HasLeaderLines

    @HasLeaderLines.setter
    def HasLeaderLines(self, value):
        self.com_object.HasLeaderLines = value

    @property
    def hasleaderlines(self):
        """Alias for HasLeaderLines"""
        return self.HasLeaderLines

    @hasleaderlines.setter
    def hasleaderlines(self, value):
        """Alias for HasLeaderLines.setter"""
        self.HasLeaderLines = value

    @property
    def has_leader_lines(self):
        """Alias for HasLeaderLines"""
        return self.HasLeaderLines

    @has_leader_lines.setter
    def has_leader_lines(self, value):
        """Alias for HasLeaderLines.setter"""
        self.HasLeaderLines = value

    @property
    def InvertColor(self):
        return self.com_object.InvertColor

    @InvertColor.setter
    def InvertColor(self, value):
        self.com_object.InvertColor = value

    @property
    def invertcolor(self):
        """Alias for InvertColor"""
        return self.InvertColor

    @invertcolor.setter
    def invertcolor(self, value):
        """Alias for InvertColor.setter"""
        self.InvertColor = value

    @property
    def invert_color(self):
        """Alias for InvertColor"""
        return self.InvertColor

    @invert_color.setter
    def invert_color(self, value):
        """Alias for InvertColor.setter"""
        self.InvertColor = value

    @property
    def InvertColorIndex(self):
        return self.com_object.InvertColorIndex

    @InvertColorIndex.setter
    def InvertColorIndex(self, value):
        self.com_object.InvertColorIndex = value

    @property
    def invertcolorindex(self):
        """Alias for InvertColorIndex"""
        return self.InvertColorIndex

    @invertcolorindex.setter
    def invertcolorindex(self, value):
        """Alias for InvertColorIndex.setter"""
        self.InvertColorIndex = value

    @property
    def invert_color_index(self):
        """Alias for InvertColorIndex"""
        return self.InvertColorIndex

    @invert_color_index.setter
    def invert_color_index(self, value):
        """Alias for InvertColorIndex.setter"""
        self.InvertColorIndex = value

    @property
    def InvertIfNegative(self):
        return self.com_object.InvertIfNegative

    @InvertIfNegative.setter
    def InvertIfNegative(self, value):
        self.com_object.InvertIfNegative = value

    @property
    def invertifnegative(self):
        """Alias for InvertIfNegative"""
        return self.InvertIfNegative

    @invertifnegative.setter
    def invertifnegative(self, value):
        """Alias for InvertIfNegative.setter"""
        self.InvertIfNegative = value

    @property
    def invert_if_negative(self):
        """Alias for InvertIfNegative"""
        return self.InvertIfNegative

    @invert_if_negative.setter
    def invert_if_negative(self, value):
        """Alias for InvertIfNegative.setter"""
        self.InvertIfNegative = value

    @property
    def IsFiltered(self):
        return self.com_object.IsFiltered

    @IsFiltered.setter
    def IsFiltered(self, value):
        self.com_object.IsFiltered = value

    @property
    def isfiltered(self):
        """Alias for IsFiltered"""
        return self.IsFiltered

    @isfiltered.setter
    def isfiltered(self, value):
        """Alias for IsFiltered.setter"""
        self.IsFiltered = value

    @property
    def is_filtered(self):
        """Alias for IsFiltered"""
        return self.IsFiltered

    @is_filtered.setter
    def is_filtered(self, value):
        """Alias for IsFiltered.setter"""
        self.IsFiltered = value

    @property
    def LeaderLines(self):
        return LeaderLines(self.com_object.LeaderLines)

    @property
    def leaderlines(self):
        """Alias for LeaderLines"""
        return self.LeaderLines

    @property
    def leader_lines(self):
        """Alias for LeaderLines"""
        return self.LeaderLines

    @property
    def MarkerBackgroundColor(self):
        return self.com_object.MarkerBackgroundColor

    @MarkerBackgroundColor.setter
    def MarkerBackgroundColor(self, value):
        self.com_object.MarkerBackgroundColor = value

    @property
    def markerbackgroundcolor(self):
        """Alias for MarkerBackgroundColor"""
        return self.MarkerBackgroundColor

    @markerbackgroundcolor.setter
    def markerbackgroundcolor(self, value):
        """Alias for MarkerBackgroundColor.setter"""
        self.MarkerBackgroundColor = value

    @property
    def marker_background_color(self):
        """Alias for MarkerBackgroundColor"""
        return self.MarkerBackgroundColor

    @marker_background_color.setter
    def marker_background_color(self, value):
        """Alias for MarkerBackgroundColor.setter"""
        self.MarkerBackgroundColor = value

    @property
    def MarkerBackgroundColorIndex(self):
        return XlColorIndex(self.com_object.MarkerBackgroundColorIndex)

    @MarkerBackgroundColorIndex.setter
    def MarkerBackgroundColorIndex(self, value):
        self.com_object.MarkerBackgroundColorIndex = value

    @property
    def markerbackgroundcolorindex(self):
        """Alias for MarkerBackgroundColorIndex"""
        return self.MarkerBackgroundColorIndex

    @markerbackgroundcolorindex.setter
    def markerbackgroundcolorindex(self, value):
        """Alias for MarkerBackgroundColorIndex.setter"""
        self.MarkerBackgroundColorIndex = value

    @property
    def marker_background_color_index(self):
        """Alias for MarkerBackgroundColorIndex"""
        return self.MarkerBackgroundColorIndex

    @marker_background_color_index.setter
    def marker_background_color_index(self, value):
        """Alias for MarkerBackgroundColorIndex.setter"""
        self.MarkerBackgroundColorIndex = value

    @property
    def MarkerForegroundColor(self):
        return self.com_object.MarkerForegroundColor

    @MarkerForegroundColor.setter
    def MarkerForegroundColor(self, value):
        self.com_object.MarkerForegroundColor = value

    @property
    def markerforegroundcolor(self):
        """Alias for MarkerForegroundColor"""
        return self.MarkerForegroundColor

    @markerforegroundcolor.setter
    def markerforegroundcolor(self, value):
        """Alias for MarkerForegroundColor.setter"""
        self.MarkerForegroundColor = value

    @property
    def marker_foreground_color(self):
        """Alias for MarkerForegroundColor"""
        return self.MarkerForegroundColor

    @marker_foreground_color.setter
    def marker_foreground_color(self, value):
        """Alias for MarkerForegroundColor.setter"""
        self.MarkerForegroundColor = value

    @property
    def MarkerForegroundColorIndex(self):
        return XlColorIndex(self.com_object.MarkerForegroundColorIndex)

    @MarkerForegroundColorIndex.setter
    def MarkerForegroundColorIndex(self, value):
        self.com_object.MarkerForegroundColorIndex = value

    @property
    def markerforegroundcolorindex(self):
        """Alias for MarkerForegroundColorIndex"""
        return self.MarkerForegroundColorIndex

    @markerforegroundcolorindex.setter
    def markerforegroundcolorindex(self, value):
        """Alias for MarkerForegroundColorIndex.setter"""
        self.MarkerForegroundColorIndex = value

    @property
    def marker_foreground_color_index(self):
        """Alias for MarkerForegroundColorIndex"""
        return self.MarkerForegroundColorIndex

    @marker_foreground_color_index.setter
    def marker_foreground_color_index(self, value):
        """Alias for MarkerForegroundColorIndex.setter"""
        self.MarkerForegroundColorIndex = value

    @property
    def MarkerSize(self):
        return self.com_object.MarkerSize

    @MarkerSize.setter
    def MarkerSize(self, value):
        self.com_object.MarkerSize = value

    @property
    def markersize(self):
        """Alias for MarkerSize"""
        return self.MarkerSize

    @markersize.setter
    def markersize(self, value):
        """Alias for MarkerSize.setter"""
        self.MarkerSize = value

    @property
    def marker_size(self):
        """Alias for MarkerSize"""
        return self.MarkerSize

    @marker_size.setter
    def marker_size(self, value):
        """Alias for MarkerSize.setter"""
        self.MarkerSize = value

    @property
    def MarkerStyle(self):
        return XlMarkerStyle(self.com_object.MarkerStyle)

    @MarkerStyle.setter
    def MarkerStyle(self, value):
        self.com_object.MarkerStyle = value

    @property
    def markerstyle(self):
        """Alias for MarkerStyle"""
        return self.MarkerStyle

    @markerstyle.setter
    def markerstyle(self, value):
        """Alias for MarkerStyle.setter"""
        self.MarkerStyle = value

    @property
    def marker_style(self):
        """Alias for MarkerStyle"""
        return self.MarkerStyle

    @marker_style.setter
    def marker_style(self, value):
        """Alias for MarkerStyle.setter"""
        self.MarkerStyle = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ParentDataLabelOption(self):
        return self.com_object.ParentDataLabelOption

    @ParentDataLabelOption.setter
    def ParentDataLabelOption(self, value):
        self.com_object.ParentDataLabelOption = value

    @property
    def parentdatalabeloption(self):
        """Alias for ParentDataLabelOption"""
        return self.ParentDataLabelOption

    @parentdatalabeloption.setter
    def parentdatalabeloption(self, value):
        """Alias for ParentDataLabelOption.setter"""
        self.ParentDataLabelOption = value

    @property
    def parent_data_label_option(self):
        """Alias for ParentDataLabelOption"""
        return self.ParentDataLabelOption

    @parent_data_label_option.setter
    def parent_data_label_option(self, value):
        """Alias for ParentDataLabelOption.setter"""
        self.ParentDataLabelOption = value

    @property
    def PictureType(self):
        return XlChartPictureType(self.com_object.PictureType)

    @PictureType.setter
    def PictureType(self, value):
        self.com_object.PictureType = value

    @property
    def picturetype(self):
        """Alias for PictureType"""
        return self.PictureType

    @picturetype.setter
    def picturetype(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def picture_type(self):
        """Alias for PictureType"""
        return self.PictureType

    @picture_type.setter
    def picture_type(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def PictureUnit2(self):
        return self.com_object.PictureUnit2

    @PictureUnit2.setter
    def PictureUnit2(self, value):
        self.com_object.PictureUnit2 = value

    @property
    def pictureunit2(self):
        """Alias for PictureUnit2"""
        return self.PictureUnit2

    @pictureunit2.setter
    def pictureunit2(self, value):
        """Alias for PictureUnit2.setter"""
        self.PictureUnit2 = value

    @property
    def picture_unit2(self):
        """Alias for PictureUnit2"""
        return self.PictureUnit2

    @picture_unit2.setter
    def picture_unit2(self, value):
        """Alias for PictureUnit2.setter"""
        self.PictureUnit2 = value

    @property
    def PlotColorIndex(self):
        return self.com_object.PlotColorIndex

    @property
    def plotcolorindex(self):
        """Alias for PlotColorIndex"""
        return self.PlotColorIndex

    @property
    def plot_color_index(self):
        """Alias for PlotColorIndex"""
        return self.PlotColorIndex

    @property
    def PlotOrder(self):
        return self.com_object.PlotOrder

    @PlotOrder.setter
    def PlotOrder(self, value):
        self.com_object.PlotOrder = value

    @property
    def plotorder(self):
        """Alias for PlotOrder"""
        return self.PlotOrder

    @plotorder.setter
    def plotorder(self, value):
        """Alias for PlotOrder.setter"""
        self.PlotOrder = value

    @property
    def plot_order(self):
        """Alias for PlotOrder"""
        return self.PlotOrder

    @plot_order.setter
    def plot_order(self, value):
        """Alias for PlotOrder.setter"""
        self.PlotOrder = value

    @property
    def QuartileCalculationInclusiveMedian(self):
        return self.com_object.QuartileCalculationInclusiveMedian

    @QuartileCalculationInclusiveMedian.setter
    def QuartileCalculationInclusiveMedian(self, value):
        self.com_object.QuartileCalculationInclusiveMedian = value

    @property
    def quartilecalculationinclusivemedian(self):
        """Alias for QuartileCalculationInclusiveMedian"""
        return self.QuartileCalculationInclusiveMedian

    @quartilecalculationinclusivemedian.setter
    def quartilecalculationinclusivemedian(self, value):
        """Alias for QuartileCalculationInclusiveMedian.setter"""
        self.QuartileCalculationInclusiveMedian = value

    @property
    def quartile_calculation_inclusive_median(self):
        """Alias for QuartileCalculationInclusiveMedian"""
        return self.QuartileCalculationInclusiveMedian

    @quartile_calculation_inclusive_median.setter
    def quartile_calculation_inclusive_median(self, value):
        """Alias for QuartileCalculationInclusiveMedian.setter"""
        self.QuartileCalculationInclusiveMedian = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Smooth(self):
        return self.com_object.Smooth

    @Smooth.setter
    def Smooth(self, value):
        self.com_object.Smooth = value

    @property
    def smooth(self):
        """Alias for Smooth"""
        return self.Smooth

    @smooth.setter
    def smooth(self, value):
        """Alias for Smooth.setter"""
        self.Smooth = value

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    @property
    def Values(self):
        return self.com_object.Values

    @Values.setter
    def Values(self, value):
        self.com_object.Values = value

    @property
    def values(self):
        """Alias for Values"""
        return self.Values

    @values.setter
    def values(self, value):
        """Alias for Values.setter"""
        self.Values = value

    @property
    def XValues(self):
        return self.com_object.XValues

    @XValues.setter
    def XValues(self, value):
        self.com_object.XValues = value

    @property
    def xvalues(self):
        """Alias for XValues"""
        return self.XValues

    @xvalues.setter
    def xvalues(self, value):
        """Alias for XValues.setter"""
        self.XValues = value

    @property
    def x_values(self):
        """Alias for XValues"""
        return self.XValues

    @x_values.setter
    def x_values(self, value):
        """Alias for XValues.setter"""
        self.XValues = value

    def ApplyDataLabels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        arguments = com_arguments([unwrap(a) for a in [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]])
        self.com_object.ApplyDataLabels(*arguments)

    def applydatalabels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        """Alias for ApplyDataLabels"""
        arguments = [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]
        return self.ApplyDataLabels(*arguments)

    def apply_data_labels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        """Alias for ApplyDataLabels"""
        arguments = [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]
        return self.ApplyDataLabels(*arguments)

    def ClearFormats(self):
        self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def DataLabels(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return DataLabel(self.com_object.DataLabels(*arguments))

    def datalabels(self, Index=None):
        """Alias for DataLabels"""
        arguments = [Index]
        return self.DataLabels(*arguments)

    def data_labels(self, Index=None):
        """Alias for DataLabels"""
        arguments = [Index]
        return self.DataLabels(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def ErrorBar(self, Direction=None, Include=None, Type=None, Amount=None, MinusValues=None):
        arguments = com_arguments([unwrap(a) for a in [Direction, Include, Type, Amount, MinusValues]])
        self.com_object.ErrorBar(*arguments)

    def errorbar(self, Direction=None, Include=None, Type=None, Amount=None, MinusValues=None):
        """Alias for ErrorBar"""
        arguments = [Direction, Include, Type, Amount, MinusValues]
        return self.ErrorBar(*arguments)

    def error_bar(self, Direction=None, Include=None, Type=None, Amount=None, MinusValues=None):
        """Alias for ErrorBar"""
        arguments = [Direction, Include, Type, Amount, MinusValues]
        return self.ErrorBar(*arguments)

    def Paste(self):
        self.com_object.Paste()

    def paste(self):
        """Alias for Paste"""
        return self.Paste()

    def Points(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Points(self.com_object.Points(*arguments))

    def points(self, Index=None):
        """Alias for Points"""
        arguments = [Index]
        return self.Points(*arguments)

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()

    def Trendlines(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Trendlines(self.com_object.Trendlines(*arguments))

    def trendlines(self, Index=None):
        """Alias for Trendlines"""
        arguments = [Index]
        return self.Trendlines(*arguments)


class SeriesCollection:

    def __init__(self, seriescollection=None):
        self.com_object= seriescollection

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Source=None, Rowcol=None, SeriesLabels=None, CategoryLabels=None, Replace=None):
        arguments = com_arguments([unwrap(a) for a in [Source, Rowcol, SeriesLabels, CategoryLabels, Replace]])
        return Series(self.com_object.Add(*arguments))

    def add(self, Source=None, Rowcol=None, SeriesLabels=None, CategoryLabels=None, Replace=None):
        """Alias for Add"""
        arguments = [Source, Rowcol, SeriesLabels, CategoryLabels, Replace]
        return self.Add(*arguments)

    def Extend(self, Source=None, Rowcol=None, CategoryLabels=None):
        arguments = com_arguments([unwrap(a) for a in [Source, Rowcol, CategoryLabels]])
        self.com_object.Extend(*arguments)

    def extend(self, Source=None, Rowcol=None, CategoryLabels=None):
        """Alias for Extend"""
        arguments = [Source, Rowcol, CategoryLabels]
        return self.Extend(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Series(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def NewSeries(self):
        return Series(self.com_object.NewSeries())

    def newseries(self):
        """Alias for NewSeries"""
        return self.NewSeries()

    def new_series(self):
        """Alias for NewSeries"""
        return self.NewSeries()


class SeriesLines:

    def __init__(self, serieslines=None):
        self.com_object= serieslines

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Border(self):
        return ChartBorder(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Shading:

    def __init__(self, shading=None):
        self.com_object= shading

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BackgroundPatternColor(self):
        return Shading(self.com_object.BackgroundPatternColor)

    @BackgroundPatternColor.setter
    def BackgroundPatternColor(self, value):
        self.com_object.BackgroundPatternColor = value

    @property
    def backgroundpatterncolor(self):
        """Alias for BackgroundPatternColor"""
        return self.BackgroundPatternColor

    @backgroundpatterncolor.setter
    def backgroundpatterncolor(self, value):
        """Alias for BackgroundPatternColor.setter"""
        self.BackgroundPatternColor = value

    @property
    def background_pattern_color(self):
        """Alias for BackgroundPatternColor"""
        return self.BackgroundPatternColor

    @background_pattern_color.setter
    def background_pattern_color(self, value):
        """Alias for BackgroundPatternColor.setter"""
        self.BackgroundPatternColor = value

    @property
    def BackgroundPatternColorIndex(self):
        return Shading(self.com_object.BackgroundPatternColorIndex)

    @BackgroundPatternColorIndex.setter
    def BackgroundPatternColorIndex(self, value):
        self.com_object.BackgroundPatternColorIndex = value

    @property
    def backgroundpatterncolorindex(self):
        """Alias for BackgroundPatternColorIndex"""
        return self.BackgroundPatternColorIndex

    @backgroundpatterncolorindex.setter
    def backgroundpatterncolorindex(self, value):
        """Alias for BackgroundPatternColorIndex.setter"""
        self.BackgroundPatternColorIndex = value

    @property
    def background_pattern_color_index(self):
        """Alias for BackgroundPatternColorIndex"""
        return self.BackgroundPatternColorIndex

    @background_pattern_color_index.setter
    def background_pattern_color_index(self, value):
        """Alias for BackgroundPatternColorIndex.setter"""
        self.BackgroundPatternColorIndex = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ForegroundPatternColor(self):
        return Shading(self.com_object.ForegroundPatternColor)

    @ForegroundPatternColor.setter
    def ForegroundPatternColor(self, value):
        self.com_object.ForegroundPatternColor = value

    @property
    def foregroundpatterncolor(self):
        """Alias for ForegroundPatternColor"""
        return self.ForegroundPatternColor

    @foregroundpatterncolor.setter
    def foregroundpatterncolor(self, value):
        """Alias for ForegroundPatternColor.setter"""
        self.ForegroundPatternColor = value

    @property
    def foreground_pattern_color(self):
        """Alias for ForegroundPatternColor"""
        return self.ForegroundPatternColor

    @foreground_pattern_color.setter
    def foreground_pattern_color(self, value):
        """Alias for ForegroundPatternColor.setter"""
        self.ForegroundPatternColor = value

    @property
    def ForegroundPatternColorIndex(self):
        return Shading(self.com_object.ForegroundPatternColorIndex)

    @ForegroundPatternColorIndex.setter
    def ForegroundPatternColorIndex(self, value):
        self.com_object.ForegroundPatternColorIndex = value

    @property
    def foregroundpatterncolorindex(self):
        """Alias for ForegroundPatternColorIndex"""
        return self.ForegroundPatternColorIndex

    @foregroundpatterncolorindex.setter
    def foregroundpatterncolorindex(self, value):
        """Alias for ForegroundPatternColorIndex.setter"""
        self.ForegroundPatternColorIndex = value

    @property
    def foreground_pattern_color_index(self):
        """Alias for ForegroundPatternColorIndex"""
        return self.ForegroundPatternColorIndex

    @foreground_pattern_color_index.setter
    def foreground_pattern_color_index(self, value):
        """Alias for ForegroundPatternColorIndex.setter"""
        self.ForegroundPatternColorIndex = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Texture(self):
        return WdTextureIndex(self.com_object.Texture)

    @Texture.setter
    def Texture(self, value):
        self.com_object.Texture = value

    @property
    def texture(self):
        """Alias for Texture"""
        return self.Texture

    @texture.setter
    def texture(self, value):
        """Alias for Texture.setter"""
        self.Texture = value


class ShadowFormat:

    def __init__(self, shadowformat=None):
        self.com_object= shadowformat

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Blur(self):
        return self.com_object.Blur

    @Blur.setter
    def Blur(self, value):
        self.com_object.Blur = value

    @property
    def blur(self):
        """Alias for Blur"""
        return self.Blur

    @blur.setter
    def blur(self, value):
        """Alias for Blur.setter"""
        self.Blur = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ForeColor(self):
        return ColorFormat(self.com_object.ForeColor)

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def Obscured(self):
        return self.com_object.Obscured

    @Obscured.setter
    def Obscured(self, value):
        self.com_object.Obscured = value

    @property
    def obscured(self):
        """Alias for Obscured"""
        return self.Obscured

    @obscured.setter
    def obscured(self, value):
        """Alias for Obscured.setter"""
        self.Obscured = value

    @property
    def OffsetX(self):
        return self.com_object.OffsetX

    @OffsetX.setter
    def OffsetX(self, value):
        self.com_object.OffsetX = value

    @property
    def offsetx(self):
        """Alias for OffsetX"""
        return self.OffsetX

    @offsetx.setter
    def offsetx(self, value):
        """Alias for OffsetX.setter"""
        self.OffsetX = value

    @property
    def offset_x(self):
        """Alias for OffsetX"""
        return self.OffsetX

    @offset_x.setter
    def offset_x(self, value):
        """Alias for OffsetX.setter"""
        self.OffsetX = value

    @property
    def OffsetY(self):
        return self.com_object.OffsetY

    @OffsetY.setter
    def OffsetY(self, value):
        self.com_object.OffsetY = value

    @property
    def offsety(self):
        """Alias for OffsetY"""
        return self.OffsetY

    @offsety.setter
    def offsety(self, value):
        """Alias for OffsetY.setter"""
        self.OffsetY = value

    @property
    def offset_y(self):
        """Alias for OffsetY"""
        return self.OffsetY

    @offset_y.setter
    def offset_y(self, value):
        """Alias for OffsetY.setter"""
        self.OffsetY = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RotateWithShape(self):
        return self.com_object.RotateWithShape

    @RotateWithShape.setter
    def RotateWithShape(self, value):
        self.com_object.RotateWithShape = value

    @property
    def rotatewithshape(self):
        """Alias for RotateWithShape"""
        return self.RotateWithShape

    @rotatewithshape.setter
    def rotatewithshape(self, value):
        """Alias for RotateWithShape.setter"""
        self.RotateWithShape = value

    @property
    def rotate_with_shape(self):
        """Alias for RotateWithShape"""
        return self.RotateWithShape

    @rotate_with_shape.setter
    def rotate_with_shape(self, value):
        """Alias for RotateWithShape.setter"""
        self.RotateWithShape = value

    @property
    def Size(self):
        return self.com_object.Size

    @Size.setter
    def Size(self, value):
        self.com_object.Size = value

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @size.setter
    def size(self, value):
        """Alias for Size.setter"""
        self.Size = value

    @property
    def Style(self):
        return self.com_object.Style

    @Style.setter
    def Style(self, value):
        self.com_object.Style = value

    @property
    def style(self):
        """Alias for Style"""
        return self.Style

    @style.setter
    def style(self, value):
        """Alias for Style.setter"""
        self.Style = value

    @property
    def Transparency(self):
        return self.com_object.Transparency

    @Transparency.setter
    def Transparency(self, value):
        self.com_object.Transparency = value

    @property
    def transparency(self):
        """Alias for Transparency"""
        return self.Transparency

    @transparency.setter
    def transparency(self, value):
        """Alias for Transparency.setter"""
        self.Transparency = value

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    def IncrementOffsetX(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementOffsetX(*arguments)

    def incrementoffsetx(self, Increment=None):
        """Alias for IncrementOffsetX"""
        arguments = [Increment]
        return self.IncrementOffsetX(*arguments)

    def increment_offset_x(self, Increment=None):
        """Alias for IncrementOffsetX"""
        arguments = [Increment]
        return self.IncrementOffsetX(*arguments)

    def IncrementOffsetY(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementOffsetY(*arguments)

    def incrementoffsety(self, Increment=None):
        """Alias for IncrementOffsetY"""
        arguments = [Increment]
        return self.IncrementOffsetY(*arguments)

    def increment_offset_y(self, Increment=None):
        """Alias for IncrementOffsetY"""
        arguments = [Increment]
        return self.IncrementOffsetY(*arguments)


class Shape:

    def __init__(self, shape=None):
        self.com_object= shape

    @property
    def Adjustments(self):
        return Adjustments(self.com_object.Adjustments)

    @property
    def adjustments(self):
        """Alias for Adjustments"""
        return self.Adjustments

    @property
    def AlternativeText(self):
        return self.com_object.AlternativeText

    @AlternativeText.setter
    def AlternativeText(self, value):
        self.com_object.AlternativeText = value

    @property
    def alternativetext(self):
        """Alias for AlternativeText"""
        return self.AlternativeText

    @alternativetext.setter
    def alternativetext(self, value):
        """Alias for AlternativeText.setter"""
        self.AlternativeText = value

    @property
    def alternative_text(self):
        """Alias for AlternativeText"""
        return self.AlternativeText

    @alternative_text.setter
    def alternative_text(self, value):
        """Alias for AlternativeText.setter"""
        self.AlternativeText = value

    @property
    def Anchor(self):
        return Range(self.com_object.Anchor)

    @property
    def anchor(self):
        """Alias for Anchor"""
        return self.Anchor

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoShapeType(self):
        return Shape(self.com_object.AutoShapeType)

    @AutoShapeType.setter
    def AutoShapeType(self, value):
        self.com_object.AutoShapeType = value

    @property
    def autoshapetype(self):
        """Alias for AutoShapeType"""
        return self.AutoShapeType

    @autoshapetype.setter
    def autoshapetype(self, value):
        """Alias for AutoShapeType.setter"""
        self.AutoShapeType = value

    @property
    def auto_shape_type(self):
        """Alias for AutoShapeType"""
        return self.AutoShapeType

    @auto_shape_type.setter
    def auto_shape_type(self, value):
        """Alias for AutoShapeType.setter"""
        self.AutoShapeType = value

    @property
    def BackgroundStyle(self):
        return self.com_object.BackgroundStyle

    @BackgroundStyle.setter
    def BackgroundStyle(self, value):
        self.com_object.BackgroundStyle = value

    @property
    def backgroundstyle(self):
        """Alias for BackgroundStyle"""
        return self.BackgroundStyle

    @backgroundstyle.setter
    def backgroundstyle(self, value):
        """Alias for BackgroundStyle.setter"""
        self.BackgroundStyle = value

    @property
    def background_style(self):
        """Alias for BackgroundStyle"""
        return self.BackgroundStyle

    @background_style.setter
    def background_style(self, value):
        """Alias for BackgroundStyle.setter"""
        self.BackgroundStyle = value

    @property
    def Callout(self):
        return CalloutFormat(self.com_object.Callout)

    @property
    def callout(self):
        """Alias for Callout"""
        return self.Callout

    @property
    def CanvasItems(self):
        return CanvasShapes(self.com_object.CanvasItems)

    @property
    def canvasitems(self):
        """Alias for CanvasItems"""
        return self.CanvasItems

    @property
    def canvas_items(self):
        """Alias for CanvasItems"""
        return self.CanvasItems

    @property
    def Chart(self):
        return Chart(self.com_object.Chart)

    @property
    def chart(self):
        """Alias for Chart"""
        return self.Chart

    @property
    def Child(self):
        return self.com_object.Child

    @property
    def child(self):
        """Alias for Child"""
        return self.Child

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Decorative(self):
        return self.com_object.Decorative

    @Decorative.setter
    def Decorative(self, value):
        self.com_object.Decorative = value

    @property
    def decorative(self):
        """Alias for Decorative"""
        return self.Decorative

    @decorative.setter
    def decorative(self, value):
        """Alias for Decorative.setter"""
        self.Decorative = value

    @property
    def Fill(self):
        return FillFormat(self.com_object.Fill)

    @property
    def fill(self):
        """Alias for Fill"""
        return self.Fill

    @property
    def Glow(self):
        return GlowFormat(self.com_object.Glow)

    @property
    def glow(self):
        """Alias for Glow"""
        return self.Glow

    @property
    def GraphicStyle(self):
        return self.com_object.GraphicStyle

    @GraphicStyle.setter
    def GraphicStyle(self, value):
        self.com_object.GraphicStyle = value

    @property
    def graphicstyle(self):
        """Alias for GraphicStyle"""
        return self.GraphicStyle

    @graphicstyle.setter
    def graphicstyle(self, value):
        """Alias for GraphicStyle.setter"""
        self.GraphicStyle = value

    @property
    def graphic_style(self):
        """Alias for GraphicStyle"""
        return self.GraphicStyle

    @graphic_style.setter
    def graphic_style(self, value):
        """Alias for GraphicStyle.setter"""
        self.GraphicStyle = value

    @property
    def GroupItems(self):
        return GroupShapes(self.com_object.GroupItems)

    @property
    def groupitems(self):
        """Alias for GroupItems"""
        return self.GroupItems

    @property
    def group_items(self):
        """Alias for GroupItems"""
        return self.GroupItems

    @property
    def HasChart(self):
        return self.com_object.HasChart

    @property
    def haschart(self):
        """Alias for HasChart"""
        return self.HasChart

    @property
    def has_chart(self):
        """Alias for HasChart"""
        return self.HasChart

    @property
    def HasSmartArt(self):
        return self.com_object.HasSmartArt

    @property
    def hassmartart(self):
        """Alias for HasSmartArt"""
        return self.HasSmartArt

    @property
    def has_smart_art(self):
        """Alias for HasSmartArt"""
        return self.HasSmartArt

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HeightRelative(self):
        return self.com_object.HeightRelative

    @HeightRelative.setter
    def HeightRelative(self, value):
        self.com_object.HeightRelative = value

    @property
    def heightrelative(self):
        """Alias for HeightRelative"""
        return self.HeightRelative

    @heightrelative.setter
    def heightrelative(self, value):
        """Alias for HeightRelative.setter"""
        self.HeightRelative = value

    @property
    def height_relative(self):
        """Alias for HeightRelative"""
        return self.HeightRelative

    @height_relative.setter
    def height_relative(self, value):
        """Alias for HeightRelative.setter"""
        self.HeightRelative = value

    @property
    def HorizontalFlip(self):
        return self.com_object.HorizontalFlip

    @property
    def horizontalflip(self):
        """Alias for HorizontalFlip"""
        return self.HorizontalFlip

    @property
    def horizontal_flip(self):
        """Alias for HorizontalFlip"""
        return self.HorizontalFlip

    @property
    def Hyperlink(self):
        return Hyperlink(self.com_object.Hyperlink)

    @property
    def hyperlink(self):
        """Alias for Hyperlink"""
        return self.Hyperlink

    @property
    def ID(self):
        return self.com_object.ID

    @property
    def id(self):
        """Alias for ID"""
        return self.ID

    @property
    def i_d(self):
        """Alias for ID"""
        return self.ID

    @property
    def LayoutInCell(self):
        return self.com_object.LayoutInCell

    @property
    def layoutincell(self):
        """Alias for LayoutInCell"""
        return self.LayoutInCell

    @property
    def layout_in_cell(self):
        """Alias for LayoutInCell"""
        return self.LayoutInCell

    @property
    def Left(self):
        return WdShapePosition(self.com_object.Left)

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def LeftRelative(self):
        return self.com_object.LeftRelative

    @LeftRelative.setter
    def LeftRelative(self, value):
        self.com_object.LeftRelative = value

    @property
    def leftrelative(self):
        """Alias for LeftRelative"""
        return self.LeftRelative

    @leftrelative.setter
    def leftrelative(self, value):
        """Alias for LeftRelative.setter"""
        self.LeftRelative = value

    @property
    def left_relative(self):
        """Alias for LeftRelative"""
        return self.LeftRelative

    @left_relative.setter
    def left_relative(self, value):
        """Alias for LeftRelative.setter"""
        self.LeftRelative = value

    @property
    def Line(self):
        return LineFormat(self.com_object.Line)

    @property
    def line(self):
        """Alias for Line"""
        return self.Line

    @property
    def LinkFormat(self):
        return LinkFormat(self.com_object.LinkFormat)

    @property
    def linkformat(self):
        """Alias for LinkFormat"""
        return self.LinkFormat

    @property
    def link_format(self):
        """Alias for LinkFormat"""
        return self.LinkFormat

    @property
    def LockAnchor(self):
        return self.com_object.LockAnchor

    @LockAnchor.setter
    def LockAnchor(self, value):
        self.com_object.LockAnchor = value

    @property
    def lockanchor(self):
        """Alias for LockAnchor"""
        return self.LockAnchor

    @lockanchor.setter
    def lockanchor(self, value):
        """Alias for LockAnchor.setter"""
        self.LockAnchor = value

    @property
    def lock_anchor(self):
        """Alias for LockAnchor"""
        return self.LockAnchor

    @lock_anchor.setter
    def lock_anchor(self, value):
        """Alias for LockAnchor.setter"""
        self.LockAnchor = value

    @property
    def LockAspectRatio(self):
        return self.com_object.LockAspectRatio

    @LockAspectRatio.setter
    def LockAspectRatio(self, value):
        self.com_object.LockAspectRatio = value

    @property
    def lockaspectratio(self):
        """Alias for LockAspectRatio"""
        return self.LockAspectRatio

    @lockaspectratio.setter
    def lockaspectratio(self, value):
        """Alias for LockAspectRatio.setter"""
        self.LockAspectRatio = value

    @property
    def lock_aspect_ratio(self):
        """Alias for LockAspectRatio"""
        return self.LockAspectRatio

    @lock_aspect_ratio.setter
    def lock_aspect_ratio(self, value):
        """Alias for LockAspectRatio.setter"""
        self.LockAspectRatio = value

    @property
    def Model3D(self):
        return Model3DFormat(self.com_object.Model3D)

    @property
    def model3d(self):
        """Alias for Model3D"""
        return self.Model3D

    @property
    def model3_d(self):
        """Alias for Model3D"""
        return self.Model3D

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Nodes(self):
        return ShapeNodes(self.com_object.Nodes)

    @property
    def nodes(self):
        """Alias for Nodes"""
        return self.Nodes

    @property
    def OLEFormat(self):
        return OLEFormat(self.com_object.OLEFormat)

    @property
    def oleformat(self):
        """Alias for OLEFormat"""
        return self.OLEFormat

    @property
    def o_l_e_format(self):
        """Alias for OLEFormat"""
        return self.OLEFormat

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ParentGroup(self):
        return Shape(self.com_object.ParentGroup)

    @property
    def parentgroup(self):
        """Alias for ParentGroup"""
        return self.ParentGroup

    @property
    def parent_group(self):
        """Alias for ParentGroup"""
        return self.ParentGroup

    @property
    def PictureFormat(self):
        return PictureFormat(self.com_object.PictureFormat)

    @property
    def pictureformat(self):
        """Alias for PictureFormat"""
        return self.PictureFormat

    @property
    def picture_format(self):
        """Alias for PictureFormat"""
        return self.PictureFormat

    @property
    def Reflection(self):
        return ReflectionFormat(self.com_object.Reflection)

    @property
    def reflection(self):
        """Alias for Reflection"""
        return self.Reflection

    @property
    def RelativeHorizontalPosition(self):
        return self.com_object.RelativeHorizontalPosition

    @RelativeHorizontalPosition.setter
    def RelativeHorizontalPosition(self, value):
        self.com_object.RelativeHorizontalPosition = value

    @property
    def relativehorizontalposition(self):
        """Alias for RelativeHorizontalPosition"""
        return self.RelativeHorizontalPosition

    @relativehorizontalposition.setter
    def relativehorizontalposition(self, value):
        """Alias for RelativeHorizontalPosition.setter"""
        self.RelativeHorizontalPosition = value

    @property
    def relative_horizontal_position(self):
        """Alias for RelativeHorizontalPosition"""
        return self.RelativeHorizontalPosition

    @relative_horizontal_position.setter
    def relative_horizontal_position(self, value):
        """Alias for RelativeHorizontalPosition.setter"""
        self.RelativeHorizontalPosition = value

    @property
    def RelativeHorizontalSize(self):
        return WdRelativeVerticalSize(self.com_object.RelativeHorizontalSize)

    @RelativeHorizontalSize.setter
    def RelativeHorizontalSize(self, value):
        self.com_object.RelativeHorizontalSize = value

    @property
    def relativehorizontalsize(self):
        """Alias for RelativeHorizontalSize"""
        return self.RelativeHorizontalSize

    @relativehorizontalsize.setter
    def relativehorizontalsize(self, value):
        """Alias for RelativeHorizontalSize.setter"""
        self.RelativeHorizontalSize = value

    @property
    def relative_horizontal_size(self):
        """Alias for RelativeHorizontalSize"""
        return self.RelativeHorizontalSize

    @relative_horizontal_size.setter
    def relative_horizontal_size(self, value):
        """Alias for RelativeHorizontalSize.setter"""
        self.RelativeHorizontalSize = value

    @property
    def RelativeVerticalPosition(self):
        return self.com_object.RelativeVerticalPosition

    @RelativeVerticalPosition.setter
    def RelativeVerticalPosition(self, value):
        self.com_object.RelativeVerticalPosition = value

    @property
    def relativeverticalposition(self):
        """Alias for RelativeVerticalPosition"""
        return self.RelativeVerticalPosition

    @relativeverticalposition.setter
    def relativeverticalposition(self, value):
        """Alias for RelativeVerticalPosition.setter"""
        self.RelativeVerticalPosition = value

    @property
    def relative_vertical_position(self):
        """Alias for RelativeVerticalPosition"""
        return self.RelativeVerticalPosition

    @relative_vertical_position.setter
    def relative_vertical_position(self, value):
        """Alias for RelativeVerticalPosition.setter"""
        self.RelativeVerticalPosition = value

    @property
    def RelativeVerticalSize(self):
        return WdRelativeVerticalSize(self.com_object.RelativeVerticalSize)

    @RelativeVerticalSize.setter
    def RelativeVerticalSize(self, value):
        self.com_object.RelativeVerticalSize = value

    @property
    def relativeverticalsize(self):
        """Alias for RelativeVerticalSize"""
        return self.RelativeVerticalSize

    @relativeverticalsize.setter
    def relativeverticalsize(self, value):
        """Alias for RelativeVerticalSize.setter"""
        self.RelativeVerticalSize = value

    @property
    def relative_vertical_size(self):
        """Alias for RelativeVerticalSize"""
        return self.RelativeVerticalSize

    @relative_vertical_size.setter
    def relative_vertical_size(self, value):
        """Alias for RelativeVerticalSize.setter"""
        self.RelativeVerticalSize = value

    @property
    def Rotation(self):
        return self.com_object.Rotation

    @Rotation.setter
    def Rotation(self, value):
        self.com_object.Rotation = value

    @property
    def rotation(self):
        """Alias for Rotation"""
        return self.Rotation

    @rotation.setter
    def rotation(self, value):
        """Alias for Rotation.setter"""
        self.Rotation = value

    @property
    def Script(self):
        return self.com_object.Script

    @property
    def script(self):
        """Alias for Script"""
        return self.Script

    @property
    def Shadow(self):
        return ShadowFormat(self.com_object.Shadow)

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @property
    def ShapeStyle(self):
        return self.com_object.ShapeStyle

    @ShapeStyle.setter
    def ShapeStyle(self, value):
        self.com_object.ShapeStyle = value

    @property
    def shapestyle(self):
        """Alias for ShapeStyle"""
        return self.ShapeStyle

    @shapestyle.setter
    def shapestyle(self, value):
        """Alias for ShapeStyle.setter"""
        self.ShapeStyle = value

    @property
    def shape_style(self):
        """Alias for ShapeStyle"""
        return self.ShapeStyle

    @shape_style.setter
    def shape_style(self, value):
        """Alias for ShapeStyle.setter"""
        self.ShapeStyle = value

    @property
    def SmartArt(self):
        return self.com_object.SmartArt

    @property
    def smartart(self):
        """Alias for SmartArt"""
        return self.SmartArt

    @property
    def smart_art(self):
        """Alias for SmartArt"""
        return self.SmartArt

    @property
    def SoftEdge(self):
        return SoftEdgeFormat(self.com_object.SoftEdge)

    @property
    def softedge(self):
        """Alias for SoftEdge"""
        return self.SoftEdge

    @property
    def soft_edge(self):
        """Alias for SoftEdge"""
        return self.SoftEdge

    @property
    def TextEffect(self):
        return TextEffectFormat(self.com_object.TextEffect)

    @property
    def texteffect(self):
        """Alias for TextEffect"""
        return self.TextEffect

    @property
    def text_effect(self):
        """Alias for TextEffect"""
        return self.TextEffect

    @property
    def TextFrame(self):
        return TextFrame(self.com_object.TextFrame)

    @property
    def textframe(self):
        """Alias for TextFrame"""
        return self.TextFrame

    @property
    def text_frame(self):
        """Alias for TextFrame"""
        return self.TextFrame

    @property
    def TextFrame2(self):
        return self.com_object.TextFrame2

    @property
    def textframe2(self):
        """Alias for TextFrame2"""
        return self.TextFrame2

    @property
    def text_frame2(self):
        """Alias for TextFrame2"""
        return self.TextFrame2

    @property
    def ThreeD(self):
        return ThreeDFormat(self.com_object.ThreeD)

    @property
    def threed(self):
        """Alias for ThreeD"""
        return self.ThreeD

    @property
    def three_d(self):
        """Alias for ThreeD"""
        return self.ThreeD

    @property
    def Title(self):
        return self.com_object.Title

    @Title.setter
    def Title(self, value):
        self.com_object.Title = value

    @property
    def title(self):
        """Alias for Title"""
        return self.Title

    @title.setter
    def title(self, value):
        """Alias for Title.setter"""
        self.Title = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TopRelative(self):
        return self.com_object.TopRelative

    @TopRelative.setter
    def TopRelative(self, value):
        self.com_object.TopRelative = value

    @property
    def toprelative(self):
        """Alias for TopRelative"""
        return self.TopRelative

    @toprelative.setter
    def toprelative(self, value):
        """Alias for TopRelative.setter"""
        self.TopRelative = value

    @property
    def top_relative(self):
        """Alias for TopRelative"""
        return self.TopRelative

    @top_relative.setter
    def top_relative(self, value):
        """Alias for TopRelative.setter"""
        self.TopRelative = value

    @property
    def Type(self):
        return self.com_object.Type

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def VerticalFlip(self):
        return self.com_object.VerticalFlip

    @property
    def verticalflip(self):
        """Alias for VerticalFlip"""
        return self.VerticalFlip

    @property
    def vertical_flip(self):
        """Alias for VerticalFlip"""
        return self.VerticalFlip

    @property
    def Vertices(self):
        return self.com_object.Vertices

    @property
    def vertices(self):
        """Alias for Vertices"""
        return self.Vertices

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def WidthRelative(self):
        return self.com_object.WidthRelative

    @WidthRelative.setter
    def WidthRelative(self, value):
        self.com_object.WidthRelative = value

    @property
    def widthrelative(self):
        """Alias for WidthRelative"""
        return self.WidthRelative

    @widthrelative.setter
    def widthrelative(self, value):
        """Alias for WidthRelative.setter"""
        self.WidthRelative = value

    @property
    def width_relative(self):
        """Alias for WidthRelative"""
        return self.WidthRelative

    @width_relative.setter
    def width_relative(self, value):
        """Alias for WidthRelative.setter"""
        self.WidthRelative = value

    @property
    def WrapFormat(self):
        return WrapFormat(self.com_object.WrapFormat)

    @property
    def wrapformat(self):
        """Alias for WrapFormat"""
        return self.WrapFormat

    @property
    def wrap_format(self):
        """Alias for WrapFormat"""
        return self.WrapFormat

    @property
    def ZOrderPosition(self):
        return self.com_object.ZOrderPosition

    @property
    def zorderposition(self):
        """Alias for ZOrderPosition"""
        return self.ZOrderPosition

    @property
    def z_order_position(self):
        """Alias for ZOrderPosition"""
        return self.ZOrderPosition

    def Apply(self):
        self.com_object.Apply()

    def apply(self):
        """Alias for Apply"""
        return self.Apply()

    def CanvasCropBottom(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.CanvasCropBottom(*arguments)

    def canvascropbottom(self, Increment=None):
        """Alias for CanvasCropBottom"""
        arguments = [Increment]
        return self.CanvasCropBottom(*arguments)

    def canvas_crop_bottom(self, Increment=None):
        """Alias for CanvasCropBottom"""
        arguments = [Increment]
        return self.CanvasCropBottom(*arguments)

    def CanvasCropLeft(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.CanvasCropLeft(*arguments)

    def canvascropleft(self, Increment=None):
        """Alias for CanvasCropLeft"""
        arguments = [Increment]
        return self.CanvasCropLeft(*arguments)

    def canvas_crop_left(self, Increment=None):
        """Alias for CanvasCropLeft"""
        arguments = [Increment]
        return self.CanvasCropLeft(*arguments)

    def CanvasCropRight(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.CanvasCropRight(*arguments)

    def canvascropright(self, Increment=None):
        """Alias for CanvasCropRight"""
        arguments = [Increment]
        return self.CanvasCropRight(*arguments)

    def canvas_crop_right(self, Increment=None):
        """Alias for CanvasCropRight"""
        arguments = [Increment]
        return self.CanvasCropRight(*arguments)

    def CanvasCropTop(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.CanvasCropTop(*arguments)

    def canvascroptop(self, Increment=None):
        """Alias for CanvasCropTop"""
        arguments = [Increment]
        return self.CanvasCropTop(*arguments)

    def canvas_crop_top(self, Increment=None):
        """Alias for CanvasCropTop"""
        arguments = [Increment]
        return self.CanvasCropTop(*arguments)

    def ConvertToInlineShape(self):
        self.com_object.ConvertToInlineShape()

    def converttoinlineshape(self):
        """Alias for ConvertToInlineShape"""
        return self.ConvertToInlineShape()

    def convert_to_inline_shape(self):
        """Alias for ConvertToInlineShape"""
        return self.ConvertToInlineShape()

    def Delete(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Delete(*arguments)

    def delete(self, Index=None):
        """Alias for Delete"""
        arguments = [Index]
        return self.Delete(*arguments)

    def Duplicate(self):
        self.com_object.Duplicate()

    def duplicate(self):
        """Alias for Duplicate"""
        return self.Duplicate()

    def Flip(self, FlipCmd=None):
        arguments = com_arguments([unwrap(a) for a in [FlipCmd]])
        self.com_object.Flip(*arguments)

    def flip(self, FlipCmd=None):
        """Alias for Flip"""
        arguments = [FlipCmd]
        return self.Flip(*arguments)

    def IncrementLeft(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementLeft(*arguments)

    def incrementleft(self, Increment=None):
        """Alias for IncrementLeft"""
        arguments = [Increment]
        return self.IncrementLeft(*arguments)

    def increment_left(self, Increment=None):
        """Alias for IncrementLeft"""
        arguments = [Increment]
        return self.IncrementLeft(*arguments)

    def IncrementRotation(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotation(*arguments)

    def incrementrotation(self, Increment=None):
        """Alias for IncrementRotation"""
        arguments = [Increment]
        return self.IncrementRotation(*arguments)

    def increment_rotation(self, Increment=None):
        """Alias for IncrementRotation"""
        arguments = [Increment]
        return self.IncrementRotation(*arguments)

    def IncrementTop(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementTop(*arguments)

    def incrementtop(self, Increment=None):
        """Alias for IncrementTop"""
        arguments = [Increment]
        return self.IncrementTop(*arguments)

    def increment_top(self, Increment=None):
        """Alias for IncrementTop"""
        arguments = [Increment]
        return self.IncrementTop(*arguments)

    def PickUp(self):
        self.com_object.PickUp()

    def pickup(self):
        """Alias for PickUp"""
        return self.PickUp()

    def pick_up(self):
        """Alias for PickUp"""
        return self.PickUp()

    def ScaleHeight(self, Factor=None, RelativeToOriginalSize=None, Scale=None):
        arguments = com_arguments([unwrap(a) for a in [Factor, RelativeToOriginalSize, Scale]])
        self.com_object.ScaleHeight(*arguments)

    def scaleheight(self, Factor=None, RelativeToOriginalSize=None, Scale=None):
        """Alias for ScaleHeight"""
        arguments = [Factor, RelativeToOriginalSize, Scale]
        return self.ScaleHeight(*arguments)

    def scale_height(self, Factor=None, RelativeToOriginalSize=None, Scale=None):
        """Alias for ScaleHeight"""
        arguments = [Factor, RelativeToOriginalSize, Scale]
        return self.ScaleHeight(*arguments)

    def ScaleWidth(self, Factor=None, RelativeToOriginalSize=None, Scale=None):
        arguments = com_arguments([unwrap(a) for a in [Factor, RelativeToOriginalSize, Scale]])
        self.com_object.ScaleWidth(*arguments)

    def scalewidth(self, Factor=None, RelativeToOriginalSize=None, Scale=None):
        """Alias for ScaleWidth"""
        arguments = [Factor, RelativeToOriginalSize, Scale]
        return self.ScaleWidth(*arguments)

    def scale_width(self, Factor=None, RelativeToOriginalSize=None, Scale=None):
        """Alias for ScaleWidth"""
        arguments = [Factor, RelativeToOriginalSize, Scale]
        return self.ScaleWidth(*arguments)

    def Select(self, Replace=None):
        arguments = com_arguments([unwrap(a) for a in [Replace]])
        self.com_object.Select(*arguments)

    def select(self, Replace=None):
        """Alias for Select"""
        arguments = [Replace]
        return self.Select(*arguments)

    def SetShapesDefaultProperties(self):
        self.com_object.SetShapesDefaultProperties()

    def setshapesdefaultproperties(self):
        """Alias for SetShapesDefaultProperties"""
        return self.SetShapesDefaultProperties()

    def set_shapes_default_properties(self):
        """Alias for SetShapesDefaultProperties"""
        return self.SetShapesDefaultProperties()

    def Ungroup(self):
        return ShapeRange(self.com_object.Ungroup())

    def ungroup(self):
        """Alias for Ungroup"""
        return self.Ungroup()

    def ZOrder(self, ZOrderCmd=None):
        arguments = com_arguments([unwrap(a) for a in [ZOrderCmd]])
        return self.com_object.ZOrder(*arguments)

    def zorder(self, ZOrderCmd=None):
        """Alias for ZOrder"""
        arguments = [ZOrderCmd]
        return self.ZOrder(*arguments)

    def z_order(self, ZOrderCmd=None):
        """Alias for ZOrder"""
        arguments = [ZOrderCmd]
        return self.ZOrder(*arguments)


class ShapeNode:

    def __init__(self, shapenode=None):
        self.com_object= shapenode

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def EditingType(self):
        return self.com_object.EditingType

    @property
    def editingtype(self):
        """Alias for EditingType"""
        return self.EditingType

    @property
    def editing_type(self):
        """Alias for EditingType"""
        return self.EditingType

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Points(self):
        return self.com_object.Points

    @property
    def points(self):
        """Alias for Points"""
        return self.Points

    @property
    def SegmentType(self):
        return self.com_object.SegmentType

    @property
    def segmenttype(self):
        """Alias for SegmentType"""
        return self.SegmentType

    @property
    def segment_type(self):
        """Alias for SegmentType"""
        return self.SegmentType


class ShapeNodes:

    def __init__(self, shapenodes=None):
        self.com_object= shapenodes

    def __call__(self, item):
        return ShapeNode(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Delete(*arguments)

    def delete(self, Index=None):
        """Alias for Delete"""
        arguments = [Index]
        return self.Delete(*arguments)

    def Insert(self, Index=None, SegmentType=None, EditingType=None, X1=None, Y1=None, X2=None, Y2=None, X3=None, Y3=None):
        arguments = com_arguments([unwrap(a) for a in [Index, SegmentType, EditingType, X1, Y1, X2, Y2, X3, Y3]])
        self.com_object.Insert(*arguments)

    def insert(self, Index=None, SegmentType=None, EditingType=None, X1=None, Y1=None, X2=None, Y2=None, X3=None, Y3=None):
        """Alias for Insert"""
        arguments = [Index, SegmentType, EditingType, X1, Y1, X2, Y2, X3, Y3]
        return self.Insert(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ShapeNode(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def SetEditingType(self, Index=None, EditingType=None):
        arguments = com_arguments([unwrap(a) for a in [Index, EditingType]])
        self.com_object.SetEditingType(*arguments)

    def seteditingtype(self, Index=None, EditingType=None):
        """Alias for SetEditingType"""
        arguments = [Index, EditingType]
        return self.SetEditingType(*arguments)

    def set_editing_type(self, Index=None, EditingType=None):
        """Alias for SetEditingType"""
        arguments = [Index, EditingType]
        return self.SetEditingType(*arguments)

    def SetPosition(self, Index=None, X1=None, Y1=None):
        arguments = com_arguments([unwrap(a) for a in [Index, X1, Y1]])
        self.com_object.SetPosition(*arguments)

    def setposition(self, Index=None, X1=None, Y1=None):
        """Alias for SetPosition"""
        arguments = [Index, X1, Y1]
        return self.SetPosition(*arguments)

    def set_position(self, Index=None, X1=None, Y1=None):
        """Alias for SetPosition"""
        arguments = [Index, X1, Y1]
        return self.SetPosition(*arguments)

    def SetSegmentType(self, Index=None, SegmentType=None):
        arguments = com_arguments([unwrap(a) for a in [Index, SegmentType]])
        self.com_object.SetSegmentType(*arguments)

    def setsegmenttype(self, Index=None, SegmentType=None):
        """Alias for SetSegmentType"""
        arguments = [Index, SegmentType]
        return self.SetSegmentType(*arguments)

    def set_segment_type(self, Index=None, SegmentType=None):
        """Alias for SetSegmentType"""
        arguments = [Index, SegmentType]
        return self.SetSegmentType(*arguments)


class ShapeRange:

    def __init__(self, shaperange=None):
        self.com_object= shaperange

    @property
    def Adjustments(self):
        return Adjustments(self.com_object.Adjustments)

    @property
    def adjustments(self):
        """Alias for Adjustments"""
        return self.Adjustments

    @property
    def AlternativeText(self):
        return self.com_object.AlternativeText

    @AlternativeText.setter
    def AlternativeText(self, value):
        self.com_object.AlternativeText = value

    @property
    def alternativetext(self):
        """Alias for AlternativeText"""
        return self.AlternativeText

    @alternativetext.setter
    def alternativetext(self, value):
        """Alias for AlternativeText.setter"""
        self.AlternativeText = value

    @property
    def alternative_text(self):
        """Alias for AlternativeText"""
        return self.AlternativeText

    @alternative_text.setter
    def alternative_text(self, value):
        """Alias for AlternativeText.setter"""
        self.AlternativeText = value

    @property
    def Anchor(self):
        return Range(self.com_object.Anchor)

    @property
    def anchor(self):
        """Alias for Anchor"""
        return self.Anchor

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoShapeType(self):
        return ShapeRange(self.com_object.AutoShapeType)

    @AutoShapeType.setter
    def AutoShapeType(self, value):
        self.com_object.AutoShapeType = value

    @property
    def autoshapetype(self):
        """Alias for AutoShapeType"""
        return self.AutoShapeType

    @autoshapetype.setter
    def autoshapetype(self, value):
        """Alias for AutoShapeType.setter"""
        self.AutoShapeType = value

    @property
    def auto_shape_type(self):
        """Alias for AutoShapeType"""
        return self.AutoShapeType

    @auto_shape_type.setter
    def auto_shape_type(self, value):
        """Alias for AutoShapeType.setter"""
        self.AutoShapeType = value

    @property
    def BackgroundStyle(self):
        return self.com_object.BackgroundStyle

    @BackgroundStyle.setter
    def BackgroundStyle(self, value):
        self.com_object.BackgroundStyle = value

    @property
    def backgroundstyle(self):
        """Alias for BackgroundStyle"""
        return self.BackgroundStyle

    @backgroundstyle.setter
    def backgroundstyle(self, value):
        """Alias for BackgroundStyle.setter"""
        self.BackgroundStyle = value

    @property
    def background_style(self):
        """Alias for BackgroundStyle"""
        return self.BackgroundStyle

    @background_style.setter
    def background_style(self, value):
        """Alias for BackgroundStyle.setter"""
        self.BackgroundStyle = value

    @property
    def Callout(self):
        return CalloutFormat(self.com_object.Callout)

    @property
    def callout(self):
        """Alias for Callout"""
        return self.Callout

    @property
    def CanvasItems(self):
        return CanvasShapes(self.com_object.CanvasItems)

    @property
    def canvasitems(self):
        """Alias for CanvasItems"""
        return self.CanvasItems

    @property
    def canvas_items(self):
        """Alias for CanvasItems"""
        return self.CanvasItems

    @property
    def Child(self):
        return self.com_object.Child

    @property
    def child(self):
        """Alias for Child"""
        return self.Child

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Decorative(self):
        return self.com_object.Decorative

    @Decorative.setter
    def Decorative(self, value):
        self.com_object.Decorative = value

    @property
    def decorative(self):
        """Alias for Decorative"""
        return self.Decorative

    @decorative.setter
    def decorative(self, value):
        """Alias for Decorative.setter"""
        self.Decorative = value

    @property
    def Fill(self):
        return FillFormat(self.com_object.Fill)

    @property
    def fill(self):
        """Alias for Fill"""
        return self.Fill

    @property
    def Glow(self):
        return GlowFormat(self.com_object.Glow)

    @property
    def glow(self):
        """Alias for Glow"""
        return self.Glow

    @property
    def GraphicStyle(self):
        return self.com_object.GraphicStyle

    @GraphicStyle.setter
    def GraphicStyle(self, value):
        self.com_object.GraphicStyle = value

    @property
    def graphicstyle(self):
        """Alias for GraphicStyle"""
        return self.GraphicStyle

    @graphicstyle.setter
    def graphicstyle(self, value):
        """Alias for GraphicStyle.setter"""
        self.GraphicStyle = value

    @property
    def graphic_style(self):
        """Alias for GraphicStyle"""
        return self.GraphicStyle

    @graphic_style.setter
    def graphic_style(self, value):
        """Alias for GraphicStyle.setter"""
        self.GraphicStyle = value

    @property
    def GroupItems(self):
        return GroupShapes(self.com_object.GroupItems)

    @property
    def groupitems(self):
        """Alias for GroupItems"""
        return self.GroupItems

    @property
    def group_items(self):
        """Alias for GroupItems"""
        return self.GroupItems

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HeightRelative(self):
        return self.com_object.HeightRelative

    @HeightRelative.setter
    def HeightRelative(self, value):
        self.com_object.HeightRelative = value

    @property
    def heightrelative(self):
        """Alias for HeightRelative"""
        return self.HeightRelative

    @heightrelative.setter
    def heightrelative(self, value):
        """Alias for HeightRelative.setter"""
        self.HeightRelative = value

    @property
    def height_relative(self):
        """Alias for HeightRelative"""
        return self.HeightRelative

    @height_relative.setter
    def height_relative(self, value):
        """Alias for HeightRelative.setter"""
        self.HeightRelative = value

    @property
    def HorizontalFlip(self):
        return self.com_object.HorizontalFlip

    @property
    def horizontalflip(self):
        """Alias for HorizontalFlip"""
        return self.HorizontalFlip

    @property
    def horizontal_flip(self):
        """Alias for HorizontalFlip"""
        return self.HorizontalFlip

    @property
    def Hyperlink(self):
        return Hyperlink(self.com_object.Hyperlink)

    @property
    def hyperlink(self):
        """Alias for Hyperlink"""
        return self.Hyperlink

    @property
    def ID(self):
        return self.com_object.ID

    @property
    def id(self):
        """Alias for ID"""
        return self.ID

    @property
    def i_d(self):
        """Alias for ID"""
        return self.ID

    @property
    def LayoutInCell(self):
        return self.com_object.LayoutInCell

    @property
    def layoutincell(self):
        """Alias for LayoutInCell"""
        return self.LayoutInCell

    @property
    def layout_in_cell(self):
        """Alias for LayoutInCell"""
        return self.LayoutInCell

    @property
    def Left(self):
        return WdShapePosition(self.com_object.Left)

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def LeftRelative(self):
        return self.com_object.LeftRelative

    @LeftRelative.setter
    def LeftRelative(self, value):
        self.com_object.LeftRelative = value

    @property
    def leftrelative(self):
        """Alias for LeftRelative"""
        return self.LeftRelative

    @leftrelative.setter
    def leftrelative(self, value):
        """Alias for LeftRelative.setter"""
        self.LeftRelative = value

    @property
    def left_relative(self):
        """Alias for LeftRelative"""
        return self.LeftRelative

    @left_relative.setter
    def left_relative(self, value):
        """Alias for LeftRelative.setter"""
        self.LeftRelative = value

    @property
    def Line(self):
        return LineFormat(self.com_object.Line)

    @property
    def line(self):
        """Alias for Line"""
        return self.Line

    @property
    def LockAnchor(self):
        return self.com_object.LockAnchor

    @LockAnchor.setter
    def LockAnchor(self, value):
        self.com_object.LockAnchor = value

    @property
    def lockanchor(self):
        """Alias for LockAnchor"""
        return self.LockAnchor

    @lockanchor.setter
    def lockanchor(self, value):
        """Alias for LockAnchor.setter"""
        self.LockAnchor = value

    @property
    def lock_anchor(self):
        """Alias for LockAnchor"""
        return self.LockAnchor

    @lock_anchor.setter
    def lock_anchor(self, value):
        """Alias for LockAnchor.setter"""
        self.LockAnchor = value

    @property
    def LockAspectRatio(self):
        return self.com_object.LockAspectRatio

    @LockAspectRatio.setter
    def LockAspectRatio(self, value):
        self.com_object.LockAspectRatio = value

    @property
    def lockaspectratio(self):
        """Alias for LockAspectRatio"""
        return self.LockAspectRatio

    @lockaspectratio.setter
    def lockaspectratio(self, value):
        """Alias for LockAspectRatio.setter"""
        self.LockAspectRatio = value

    @property
    def lock_aspect_ratio(self):
        """Alias for LockAspectRatio"""
        return self.LockAspectRatio

    @lock_aspect_ratio.setter
    def lock_aspect_ratio(self, value):
        """Alias for LockAspectRatio.setter"""
        self.LockAspectRatio = value

    @property
    def Model3D(self):
        return Model3DFormat(self.com_object.Model3D)

    @property
    def model3d(self):
        """Alias for Model3D"""
        return self.Model3D

    @property
    def model3_d(self):
        """Alias for Model3D"""
        return self.Model3D

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Nodes(self):
        return ShapeNodes(self.com_object.Nodes)

    @property
    def nodes(self):
        """Alias for Nodes"""
        return self.Nodes

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ParentGroup(self):
        return Shape(self.com_object.ParentGroup)

    @property
    def parentgroup(self):
        """Alias for ParentGroup"""
        return self.ParentGroup

    @property
    def parent_group(self):
        """Alias for ParentGroup"""
        return self.ParentGroup

    @property
    def PictureFormat(self):
        return PictureFormat(self.com_object.PictureFormat)

    @property
    def pictureformat(self):
        """Alias for PictureFormat"""
        return self.PictureFormat

    @property
    def picture_format(self):
        """Alias for PictureFormat"""
        return self.PictureFormat

    @property
    def Reflection(self):
        return ReflectionFormat(self.com_object.Reflection)

    @property
    def reflection(self):
        """Alias for Reflection"""
        return self.Reflection

    @property
    def RelativeHorizontalPosition(self):
        return self.com_object.RelativeHorizontalPosition

    @RelativeHorizontalPosition.setter
    def RelativeHorizontalPosition(self, value):
        self.com_object.RelativeHorizontalPosition = value

    @property
    def relativehorizontalposition(self):
        """Alias for RelativeHorizontalPosition"""
        return self.RelativeHorizontalPosition

    @relativehorizontalposition.setter
    def relativehorizontalposition(self, value):
        """Alias for RelativeHorizontalPosition.setter"""
        self.RelativeHorizontalPosition = value

    @property
    def relative_horizontal_position(self):
        """Alias for RelativeHorizontalPosition"""
        return self.RelativeHorizontalPosition

    @relative_horizontal_position.setter
    def relative_horizontal_position(self, value):
        """Alias for RelativeHorizontalPosition.setter"""
        self.RelativeHorizontalPosition = value

    @property
    def RelativeHorizontalSize(self):
        return WdRelativeHorizontalSize(self.com_object.RelativeHorizontalSize)

    @RelativeHorizontalSize.setter
    def RelativeHorizontalSize(self, value):
        self.com_object.RelativeHorizontalSize = value

    @property
    def relativehorizontalsize(self):
        """Alias for RelativeHorizontalSize"""
        return self.RelativeHorizontalSize

    @relativehorizontalsize.setter
    def relativehorizontalsize(self, value):
        """Alias for RelativeHorizontalSize.setter"""
        self.RelativeHorizontalSize = value

    @property
    def relative_horizontal_size(self):
        """Alias for RelativeHorizontalSize"""
        return self.RelativeHorizontalSize

    @relative_horizontal_size.setter
    def relative_horizontal_size(self, value):
        """Alias for RelativeHorizontalSize.setter"""
        self.RelativeHorizontalSize = value

    @property
    def RelativeVerticalPosition(self):
        return self.com_object.RelativeVerticalPosition

    @RelativeVerticalPosition.setter
    def RelativeVerticalPosition(self, value):
        self.com_object.RelativeVerticalPosition = value

    @property
    def relativeverticalposition(self):
        """Alias for RelativeVerticalPosition"""
        return self.RelativeVerticalPosition

    @relativeverticalposition.setter
    def relativeverticalposition(self, value):
        """Alias for RelativeVerticalPosition.setter"""
        self.RelativeVerticalPosition = value

    @property
    def relative_vertical_position(self):
        """Alias for RelativeVerticalPosition"""
        return self.RelativeVerticalPosition

    @relative_vertical_position.setter
    def relative_vertical_position(self, value):
        """Alias for RelativeVerticalPosition.setter"""
        self.RelativeVerticalPosition = value

    @property
    def RelativeVerticalSize(self):
        return WdRelativeVerticalSize(self.com_object.RelativeVerticalSize)

    @RelativeVerticalSize.setter
    def RelativeVerticalSize(self, value):
        self.com_object.RelativeVerticalSize = value

    @property
    def relativeverticalsize(self):
        """Alias for RelativeVerticalSize"""
        return self.RelativeVerticalSize

    @relativeverticalsize.setter
    def relativeverticalsize(self, value):
        """Alias for RelativeVerticalSize.setter"""
        self.RelativeVerticalSize = value

    @property
    def relative_vertical_size(self):
        """Alias for RelativeVerticalSize"""
        return self.RelativeVerticalSize

    @relative_vertical_size.setter
    def relative_vertical_size(self, value):
        """Alias for RelativeVerticalSize.setter"""
        self.RelativeVerticalSize = value

    @property
    def Rotation(self):
        return self.com_object.Rotation

    @Rotation.setter
    def Rotation(self, value):
        self.com_object.Rotation = value

    @property
    def rotation(self):
        """Alias for Rotation"""
        return self.Rotation

    @rotation.setter
    def rotation(self, value):
        """Alias for Rotation.setter"""
        self.Rotation = value

    @property
    def Shadow(self):
        return ShadowFormat(self.com_object.Shadow)

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @property
    def ShapeStyle(self):
        return self.com_object.ShapeStyle

    @ShapeStyle.setter
    def ShapeStyle(self, value):
        self.com_object.ShapeStyle = value

    @property
    def shapestyle(self):
        """Alias for ShapeStyle"""
        return self.ShapeStyle

    @shapestyle.setter
    def shapestyle(self, value):
        """Alias for ShapeStyle.setter"""
        self.ShapeStyle = value

    @property
    def shape_style(self):
        """Alias for ShapeStyle"""
        return self.ShapeStyle

    @shape_style.setter
    def shape_style(self, value):
        """Alias for ShapeStyle.setter"""
        self.ShapeStyle = value

    @property
    def SoftEdge(self):
        return SoftEdgeFormat(self.com_object.SoftEdge)

    @property
    def softedge(self):
        """Alias for SoftEdge"""
        return self.SoftEdge

    @property
    def soft_edge(self):
        """Alias for SoftEdge"""
        return self.SoftEdge

    @property
    def TextEffect(self):
        return TextEffectFormat(self.com_object.TextEffect)

    @property
    def texteffect(self):
        """Alias for TextEffect"""
        return self.TextEffect

    @property
    def text_effect(self):
        """Alias for TextEffect"""
        return self.TextEffect

    @property
    def TextFrame(self):
        return TextFrame(self.com_object.TextFrame)

    @property
    def textframe(self):
        """Alias for TextFrame"""
        return self.TextFrame

    @property
    def text_frame(self):
        """Alias for TextFrame"""
        return self.TextFrame

    @property
    def TextFrame2(self):
        return self.com_object.TextFrame2

    @property
    def textframe2(self):
        """Alias for TextFrame2"""
        return self.TextFrame2

    @property
    def text_frame2(self):
        """Alias for TextFrame2"""
        return self.TextFrame2

    @property
    def ThreeD(self):
        return ThreeDFormat(self.com_object.ThreeD)

    @property
    def threed(self):
        """Alias for ThreeD"""
        return self.ThreeD

    @property
    def three_d(self):
        """Alias for ThreeD"""
        return self.ThreeD

    @property
    def Title(self):
        return self.com_object.Title

    @Title.setter
    def Title(self, value):
        self.com_object.Title = value

    @property
    def title(self):
        """Alias for Title"""
        return self.Title

    @title.setter
    def title(self, value):
        """Alias for Title.setter"""
        self.Title = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TopRelative(self):
        return self.com_object.TopRelative

    @TopRelative.setter
    def TopRelative(self, value):
        self.com_object.TopRelative = value

    @property
    def toprelative(self):
        """Alias for TopRelative"""
        return self.TopRelative

    @toprelative.setter
    def toprelative(self, value):
        """Alias for TopRelative.setter"""
        self.TopRelative = value

    @property
    def top_relative(self):
        """Alias for TopRelative"""
        return self.TopRelative

    @top_relative.setter
    def top_relative(self, value):
        """Alias for TopRelative.setter"""
        self.TopRelative = value

    @property
    def Type(self):
        return self.com_object.Type

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def VerticalFlip(self):
        return self.com_object.VerticalFlip

    @property
    def verticalflip(self):
        """Alias for VerticalFlip"""
        return self.VerticalFlip

    @property
    def vertical_flip(self):
        """Alias for VerticalFlip"""
        return self.VerticalFlip

    @property
    def Vertices(self):
        return self.com_object.Vertices

    @property
    def vertices(self):
        """Alias for Vertices"""
        return self.Vertices

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def WidthRelative(self):
        return self.com_object.WidthRelative

    @WidthRelative.setter
    def WidthRelative(self, value):
        self.com_object.WidthRelative = value

    @property
    def widthrelative(self):
        """Alias for WidthRelative"""
        return self.WidthRelative

    @widthrelative.setter
    def widthrelative(self, value):
        """Alias for WidthRelative.setter"""
        self.WidthRelative = value

    @property
    def width_relative(self):
        """Alias for WidthRelative"""
        return self.WidthRelative

    @width_relative.setter
    def width_relative(self, value):
        """Alias for WidthRelative.setter"""
        self.WidthRelative = value

    @property
    def WrapFormat(self):
        return WrapFormat(self.com_object.WrapFormat)

    @property
    def wrapformat(self):
        """Alias for WrapFormat"""
        return self.WrapFormat

    @property
    def wrap_format(self):
        """Alias for WrapFormat"""
        return self.WrapFormat

    @property
    def ZOrderPosition(self):
        return self.com_object.ZOrderPosition

    @property
    def zorderposition(self):
        """Alias for ZOrderPosition"""
        return self.ZOrderPosition

    @property
    def z_order_position(self):
        """Alias for ZOrderPosition"""
        return self.ZOrderPosition

    def Align(self, Align=None, RelativeTo=None):
        arguments = com_arguments([unwrap(a) for a in [Align, RelativeTo]])
        self.com_object.Align(*arguments)

    def align(self, Align=None, RelativeTo=None):
        """Alias for Align"""
        arguments = [Align, RelativeTo]
        return self.Align(*arguments)

    def Apply(self):
        self.com_object.Apply()

    def apply(self):
        """Alias for Apply"""
        return self.Apply()

    def CanvasCropBottom(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.CanvasCropBottom(*arguments)

    def canvascropbottom(self, Increment=None):
        """Alias for CanvasCropBottom"""
        arguments = [Increment]
        return self.CanvasCropBottom(*arguments)

    def canvas_crop_bottom(self, Increment=None):
        """Alias for CanvasCropBottom"""
        arguments = [Increment]
        return self.CanvasCropBottom(*arguments)

    def CanvasCropLeft(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.CanvasCropLeft(*arguments)

    def canvascropleft(self, Increment=None):
        """Alias for CanvasCropLeft"""
        arguments = [Increment]
        return self.CanvasCropLeft(*arguments)

    def canvas_crop_left(self, Increment=None):
        """Alias for CanvasCropLeft"""
        arguments = [Increment]
        return self.CanvasCropLeft(*arguments)

    def CanvasCropRight(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.CanvasCropRight(*arguments)

    def canvascropright(self, Increment=None):
        """Alias for CanvasCropRight"""
        arguments = [Increment]
        return self.CanvasCropRight(*arguments)

    def canvas_crop_right(self, Increment=None):
        """Alias for CanvasCropRight"""
        arguments = [Increment]
        return self.CanvasCropRight(*arguments)

    def CanvasCropTop(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.CanvasCropTop(*arguments)

    def canvascroptop(self, Increment=None):
        """Alias for CanvasCropTop"""
        arguments = [Increment]
        return self.CanvasCropTop(*arguments)

    def canvas_crop_top(self, Increment=None):
        """Alias for CanvasCropTop"""
        arguments = [Increment]
        return self.CanvasCropTop(*arguments)

    def ConvertToInlineShape(self):
        return InlineShape(self.com_object.ConvertToInlineShape())

    def converttoinlineshape(self):
        """Alias for ConvertToInlineShape"""
        return self.ConvertToInlineShape()

    def convert_to_inline_shape(self):
        """Alias for ConvertToInlineShape"""
        return self.ConvertToInlineShape()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Distribute(self, Distribute=None, RelativeTo=None):
        arguments = com_arguments([unwrap(a) for a in [Distribute, RelativeTo]])
        self.com_object.Distribute(*arguments)

    def distribute(self, Distribute=None, RelativeTo=None):
        """Alias for Distribute"""
        arguments = [Distribute, RelativeTo]
        return self.Distribute(*arguments)

    def Duplicate(self):
        self.com_object.Duplicate()

    def duplicate(self):
        """Alias for Duplicate"""
        return self.Duplicate()

    def Flip(self, FlipCmd=None):
        arguments = com_arguments([unwrap(a) for a in [FlipCmd]])
        self.com_object.Flip(*arguments)

    def flip(self, FlipCmd=None):
        """Alias for Flip"""
        arguments = [FlipCmd]
        return self.Flip(*arguments)

    def Group(self):
        self.com_object.Group()

    def group(self):
        """Alias for Group"""
        return self.Group()

    def IncrementLeft(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementLeft(*arguments)

    def incrementleft(self, Increment=None):
        """Alias for IncrementLeft"""
        arguments = [Increment]
        return self.IncrementLeft(*arguments)

    def increment_left(self, Increment=None):
        """Alias for IncrementLeft"""
        arguments = [Increment]
        return self.IncrementLeft(*arguments)

    def IncrementRotation(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotation(*arguments)

    def incrementrotation(self, Increment=None):
        """Alias for IncrementRotation"""
        arguments = [Increment]
        return self.IncrementRotation(*arguments)

    def increment_rotation(self, Increment=None):
        """Alias for IncrementRotation"""
        arguments = [Increment]
        return self.IncrementRotation(*arguments)

    def IncrementTop(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementTop(*arguments)

    def incrementtop(self, Increment=None):
        """Alias for IncrementTop"""
        arguments = [Increment]
        return self.IncrementTop(*arguments)

    def increment_top(self, Increment=None):
        """Alias for IncrementTop"""
        arguments = [Increment]
        return self.IncrementTop(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Shape(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def PickUp(self):
        self.com_object.PickUp()

    def pickup(self):
        """Alias for PickUp"""
        return self.PickUp()

    def pick_up(self):
        """Alias for PickUp"""
        return self.PickUp()

    def ScaleHeight(self, Factor=None, RelativeToOriginalSize=None, Scale=None):
        arguments = com_arguments([unwrap(a) for a in [Factor, RelativeToOriginalSize, Scale]])
        self.com_object.ScaleHeight(*arguments)

    def scaleheight(self, Factor=None, RelativeToOriginalSize=None, Scale=None):
        """Alias for ScaleHeight"""
        arguments = [Factor, RelativeToOriginalSize, Scale]
        return self.ScaleHeight(*arguments)

    def scale_height(self, Factor=None, RelativeToOriginalSize=None, Scale=None):
        """Alias for ScaleHeight"""
        arguments = [Factor, RelativeToOriginalSize, Scale]
        return self.ScaleHeight(*arguments)

    def ScaleWidth(self, Factor=None, RelativeToOriginalSize=None, Scale=None):
        arguments = com_arguments([unwrap(a) for a in [Factor, RelativeToOriginalSize, Scale]])
        self.com_object.ScaleWidth(*arguments)

    def scalewidth(self, Factor=None, RelativeToOriginalSize=None, Scale=None):
        """Alias for ScaleWidth"""
        arguments = [Factor, RelativeToOriginalSize, Scale]
        return self.ScaleWidth(*arguments)

    def scale_width(self, Factor=None, RelativeToOriginalSize=None, Scale=None):
        """Alias for ScaleWidth"""
        arguments = [Factor, RelativeToOriginalSize, Scale]
        return self.ScaleWidth(*arguments)

    def Select(self, Replace=None):
        arguments = com_arguments([unwrap(a) for a in [Replace]])
        self.com_object.Select(*arguments)

    def select(self, Replace=None):
        """Alias for Select"""
        arguments = [Replace]
        return self.Select(*arguments)

    def SetShapesDefaultProperties(self):
        self.com_object.SetShapesDefaultProperties()

    def setshapesdefaultproperties(self):
        """Alias for SetShapesDefaultProperties"""
        return self.SetShapesDefaultProperties()

    def set_shapes_default_properties(self):
        """Alias for SetShapesDefaultProperties"""
        return self.SetShapesDefaultProperties()

    def Ungroup(self):
        return ShapeRange(self.com_object.Ungroup())

    def ungroup(self):
        """Alias for Ungroup"""
        return self.Ungroup()

    def ZOrder(self, ZOrderCmd=None):
        arguments = com_arguments([unwrap(a) for a in [ZOrderCmd]])
        return self.com_object.ZOrder(*arguments)

    def zorder(self, ZOrderCmd=None):
        """Alias for ZOrder"""
        arguments = [ZOrderCmd]
        return self.ZOrder(*arguments)

    def z_order(self, ZOrderCmd=None):
        """Alias for ZOrder"""
        arguments = [ZOrderCmd]
        return self.ZOrder(*arguments)


class Shapes:

    def __init__(self, shapes=None):
        self.com_object= shapes

    def __call__(self, item):
        return Shape(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add3DModel(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height]])
        return Shape(self.com_object.Add3DModel(*arguments))

    def add3dmodel(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for Add3DModel"""
        arguments = [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height]
        return self.Add3DModel(*arguments)

    def add3_d_model(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for Add3DModel"""
        arguments = [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height]
        return self.Add3DModel(*arguments)

    def AddCallout(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Left, Top, Width, Height]])
        return Shape(self.com_object.AddCallout(*arguments))

    def addcallout(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddCallout"""
        arguments = [Type, Left, Top, Width, Height]
        return self.AddCallout(*arguments)

    def add_callout(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddCallout"""
        arguments = [Type, Left, Top, Width, Height]
        return self.AddCallout(*arguments)

    def AddCanvas(self, Left=None, Top=None, Width=None, Height=None, Anchor=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height, Anchor]])
        return Shape(self.com_object.AddCanvas(*arguments))

    def addcanvas(self, Left=None, Top=None, Width=None, Height=None, Anchor=None):
        """Alias for AddCanvas"""
        arguments = [Left, Top, Width, Height, Anchor]
        return self.AddCanvas(*arguments)

    def add_canvas(self, Left=None, Top=None, Width=None, Height=None, Anchor=None):
        """Alias for AddCanvas"""
        arguments = [Left, Top, Width, Height, Anchor]
        return self.AddCanvas(*arguments)

    def AddChart2(self, Style=None, Type=None, Left=None, Top=None, Width=None, Height=None, Anchor=None, NewLayout=None):
        arguments = com_arguments([unwrap(a) for a in [Style, Type, Left, Top, Width, Height, Anchor, NewLayout]])
        return SHAPE(self.com_object.AddChart2(*arguments))

    def addchart2(self, Style=None, Type=None, Left=None, Top=None, Width=None, Height=None, Anchor=None, NewLayout=None):
        """Alias for AddChart2"""
        arguments = [Style, Type, Left, Top, Width, Height, Anchor, NewLayout]
        return self.AddChart2(*arguments)

    def add_chart2(self, Style=None, Type=None, Left=None, Top=None, Width=None, Height=None, Anchor=None, NewLayout=None):
        """Alias for AddChart2"""
        arguments = [Style, Type, Left, Top, Width, Height, Anchor, NewLayout]
        return self.AddChart2(*arguments)

    def AddCurve(self, SafeArrayOfPoints=None):
        arguments = com_arguments([unwrap(a) for a in [SafeArrayOfPoints]])
        return Shape(self.com_object.AddCurve(*arguments))

    def addcurve(self, SafeArrayOfPoints=None):
        """Alias for AddCurve"""
        arguments = [SafeArrayOfPoints]
        return self.AddCurve(*arguments)

    def add_curve(self, SafeArrayOfPoints=None):
        """Alias for AddCurve"""
        arguments = [SafeArrayOfPoints]
        return self.AddCurve(*arguments)

    def AddLabel(self, Orientation=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Orientation, Left, Top, Width, Height]])
        return Shapes(self.com_object.AddLabel(*arguments))

    def addlabel(self, Orientation=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddLabel"""
        arguments = [Orientation, Left, Top, Width, Height]
        return self.AddLabel(*arguments)

    def add_label(self, Orientation=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddLabel"""
        arguments = [Orientation, Left, Top, Width, Height]
        return self.AddLabel(*arguments)

    def AddLine(self, BeginX=None, BeginY=None, EndX=None, EndY=None):
        arguments = com_arguments([unwrap(a) for a in [BeginX, BeginY, EndX, EndY]])
        return Shape(self.com_object.AddLine(*arguments))

    def addline(self, BeginX=None, BeginY=None, EndX=None, EndY=None):
        """Alias for AddLine"""
        arguments = [BeginX, BeginY, EndX, EndY]
        return self.AddLine(*arguments)

    def add_line(self, BeginX=None, BeginY=None, EndX=None, EndY=None):
        """Alias for AddLine"""
        arguments = [BeginX, BeginY, EndX, EndY]
        return self.AddLine(*arguments)

    def AddOLEControl(self, ClassType=None, Range=None):
        arguments = com_arguments([unwrap(a) for a in [ClassType, Range]])
        return InlineShape(self.com_object.AddOLEControl(*arguments))

    def addolecontrol(self, ClassType=None, Range=None):
        """Alias for AddOLEControl"""
        arguments = [ClassType, Range]
        return self.AddOLEControl(*arguments)

    def add_o_l_e_control(self, ClassType=None, Range=None):
        """Alias for AddOLEControl"""
        arguments = [ClassType, Range]
        return self.AddOLEControl(*arguments)

    def AddOLEObject(self, ClassType=None, FileName=None, LinkToFile=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, Range=None):
        arguments = com_arguments([unwrap(a) for a in [ClassType, FileName, LinkToFile, DisplayAsIcon, IconFileName, IconIndex, IconLabel, Range]])
        return InlineShape(self.com_object.AddOLEObject(*arguments))

    def addoleobject(self, ClassType=None, FileName=None, LinkToFile=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, Range=None):
        """Alias for AddOLEObject"""
        arguments = [ClassType, FileName, LinkToFile, DisplayAsIcon, IconFileName, IconIndex, IconLabel, Range]
        return self.AddOLEObject(*arguments)

    def add_o_l_e_object(self, ClassType=None, FileName=None, LinkToFile=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, Range=None):
        """Alias for AddOLEObject"""
        arguments = [ClassType, FileName, LinkToFile, DisplayAsIcon, IconFileName, IconIndex, IconLabel, Range]
        return self.AddOLEObject(*arguments)

    def AddPicture(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None, Anchor=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height, Anchor]])
        return Shape(self.com_object.AddPicture(*arguments))

    def addpicture(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None, Anchor=None):
        """Alias for AddPicture"""
        arguments = [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height, Anchor]
        return self.AddPicture(*arguments)

    def add_picture(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None, Anchor=None):
        """Alias for AddPicture"""
        arguments = [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height, Anchor]
        return self.AddPicture(*arguments)

    def AddPolyline(self, SafeArrayOfPoints=None):
        arguments = com_arguments([unwrap(a) for a in [SafeArrayOfPoints]])
        self.com_object.AddPolyline(*arguments)

    def addpolyline(self, SafeArrayOfPoints=None):
        """Alias for AddPolyline"""
        arguments = [SafeArrayOfPoints]
        return self.AddPolyline(*arguments)

    def add_polyline(self, SafeArrayOfPoints=None):
        """Alias for AddPolyline"""
        arguments = [SafeArrayOfPoints]
        return self.AddPolyline(*arguments)

    def AddShape(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Left, Top, Width, Height]])
        return Shape(self.com_object.AddShape(*arguments))

    def addshape(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddShape"""
        arguments = [Type, Left, Top, Width, Height]
        return self.AddShape(*arguments)

    def add_shape(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddShape"""
        arguments = [Type, Left, Top, Width, Height]
        return self.AddShape(*arguments)

    def AddSmartArt(self, Layout=None, Left=None, Top=None, Width=None, Height=None, Anchor=None):
        arguments = com_arguments([unwrap(a) for a in [Layout, Left, Top, Width, Height, Anchor]])
        return self.com_object.AddSmartArt(*arguments)

    def addsmartart(self, Layout=None, Left=None, Top=None, Width=None, Height=None, Anchor=None):
        """Alias for AddSmartArt"""
        arguments = [Layout, Left, Top, Width, Height, Anchor]
        return self.AddSmartArt(*arguments)

    def add_smart_art(self, Layout=None, Left=None, Top=None, Width=None, Height=None, Anchor=None):
        """Alias for AddSmartArt"""
        arguments = [Layout, Left, Top, Width, Height, Anchor]
        return self.AddSmartArt(*arguments)

    def AddTextbox(self, Orientation=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Orientation, Left, Top, Width, Height]])
        return Shape(self.com_object.AddTextbox(*arguments))

    def addtextbox(self, Orientation=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddTextbox"""
        arguments = [Orientation, Left, Top, Width, Height]
        return self.AddTextbox(*arguments)

    def add_textbox(self, Orientation=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddTextbox"""
        arguments = [Orientation, Left, Top, Width, Height]
        return self.AddTextbox(*arguments)

    def AddTextEffect(self, PresetTextEffect=None, Text=None, FontName=None, FontSize=None, FontBold=None, FontItalic=None, Left=None, Top=None):
        arguments = com_arguments([unwrap(a) for a in [PresetTextEffect, Text, FontName, FontSize, FontBold, FontItalic, Left, Top]])
        self.com_object.AddTextEffect(*arguments)

    def addtexteffect(self, PresetTextEffect=None, Text=None, FontName=None, FontSize=None, FontBold=None, FontItalic=None, Left=None, Top=None):
        """Alias for AddTextEffect"""
        arguments = [PresetTextEffect, Text, FontName, FontSize, FontBold, FontItalic, Left, Top]
        return self.AddTextEffect(*arguments)

    def add_text_effect(self, PresetTextEffect=None, Text=None, FontName=None, FontSize=None, FontBold=None, FontItalic=None, Left=None, Top=None):
        """Alias for AddTextEffect"""
        arguments = [PresetTextEffect, Text, FontName, FontSize, FontBold, FontItalic, Left, Top]
        return self.AddTextEffect(*arguments)

    def AddWebVideo(self, EmbedCode=None, VideoWidth=None, VideoHeight=None, PosterFrameImage=None, Url=None, Left=None, Top=None, Width=None, Height=None, Anchor=None):
        arguments = com_arguments([unwrap(a) for a in [EmbedCode, VideoWidth, VideoHeight, PosterFrameImage, Url, Left, Top, Width, Height, Anchor]])
        return SHAPE(self.com_object.AddWebVideo(*arguments))

    def addwebvideo(self, EmbedCode=None, VideoWidth=None, VideoHeight=None, PosterFrameImage=None, Url=None, Left=None, Top=None, Width=None, Height=None, Anchor=None):
        """Alias for AddWebVideo"""
        arguments = [EmbedCode, VideoWidth, VideoHeight, PosterFrameImage, Url, Left, Top, Width, Height, Anchor]
        return self.AddWebVideo(*arguments)

    def add_web_video(self, EmbedCode=None, VideoWidth=None, VideoHeight=None, PosterFrameImage=None, Url=None, Left=None, Top=None, Width=None, Height=None, Anchor=None):
        """Alias for AddWebVideo"""
        arguments = [EmbedCode, VideoWidth, VideoHeight, PosterFrameImage, Url, Left, Top, Width, Height, Anchor]
        return self.AddWebVideo(*arguments)

    def BuildFreeform(self, EditingType=None, X1=None, Y1=None):
        arguments = com_arguments([unwrap(a) for a in [EditingType, X1, Y1]])
        return FreeformBuilder(self.com_object.BuildFreeform(*arguments))

    def buildfreeform(self, EditingType=None, X1=None, Y1=None):
        """Alias for BuildFreeform"""
        arguments = [EditingType, X1, Y1]
        return self.BuildFreeform(*arguments)

    def build_freeform(self, EditingType=None, X1=None, Y1=None):
        """Alias for BuildFreeform"""
        arguments = [EditingType, X1, Y1]
        return self.BuildFreeform(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Shape(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Range(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ShapeRange(self.com_object.Range(*arguments))

    def range(self, Index=None):
        """Alias for Range"""
        arguments = [Index]
        return self.Range(*arguments)

    def SelectAll(self):
        self.com_object.SelectAll()

    def selectall(self):
        """Alias for SelectAll"""
        return self.SelectAll()

    def select_all(self):
        """Alias for SelectAll"""
        return self.SelectAll()


class SoftEdgeFormat:

    def __init__(self, softedgeformat=None):
        self.com_object= softedgeformat

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Radius(self):
        return self.com_object.Radius

    @Radius.setter
    def Radius(self, value):
        self.com_object.Radius = value

    @property
    def radius(self):
        """Alias for Radius"""
        return self.Radius

    @radius.setter
    def radius(self, value):
        """Alias for Radius.setter"""
        self.Radius = value

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value


class Source:

    def __init__(self, source=None):
        self.com_object= source

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Cited(self):
        return self.com_object.Cited

    @property
    def cited(self):
        """Alias for Cited"""
        return self.Cited

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Field(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        if hasattr(self.com_object, "GetField"):
            return self.com_object.GetField(*arguments)
        else:
            return self.com_object.Field(*arguments)

    def field(self, Name=None):
        """Alias for Field"""
        arguments = [Name]
        return self.Field(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Tag(self):
        return self.com_object.Tag

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @property
    def XML(self):
        return self.com_object.XML

    @property
    def xml(self):
        """Alias for XML"""
        return self.XML

    @property
    def x_m_l(self):
        """Alias for XML"""
        return self.XML

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class Sources:

    def __init__(self, sources=None):
        self.com_object= sources

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return Sources(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Data=None):
        arguments = com_arguments([unwrap(a) for a in [Data]])
        self.com_object.Add(*arguments)

    def add(self, Data=None):
        """Alias for Add"""
        arguments = [Data]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Source(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class SpellingSuggestion:

    def __init__(self, spellingsuggestion=None):
        self.com_object= spellingsuggestion

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class SpellingSuggestions:

    def __init__(self, spellingsuggestions=None):
        self.com_object= spellingsuggestions

    def __call__(self, item):
        return SpellingSuggestion(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SpellingErrorType(self):
        return WdSpellingErrorType(self.com_object.SpellingErrorType)

    @property
    def spellingerrortype(self):
        """Alias for SpellingErrorType"""
        return self.SpellingErrorType

    @property
    def spelling_error_type(self):
        """Alias for SpellingErrorType"""
        return self.SpellingErrorType

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return SpellingSuggestion(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class StoryRanges:

    def __init__(self, storyranges=None):
        self.com_object= storyranges

    def __call__(self, item):
        return StoryRange(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Range(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Style:

    def __init__(self, style=None):
        self.com_object= style

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutomaticallyUpdate(self):
        return self.com_object.AutomaticallyUpdate

    @AutomaticallyUpdate.setter
    def AutomaticallyUpdate(self, value):
        self.com_object.AutomaticallyUpdate = value

    @property
    def automaticallyupdate(self):
        """Alias for AutomaticallyUpdate"""
        return self.AutomaticallyUpdate

    @automaticallyupdate.setter
    def automaticallyupdate(self, value):
        """Alias for AutomaticallyUpdate.setter"""
        self.AutomaticallyUpdate = value

    @property
    def automatically_update(self):
        """Alias for AutomaticallyUpdate"""
        return self.AutomaticallyUpdate

    @automatically_update.setter
    def automatically_update(self, value):
        """Alias for AutomaticallyUpdate.setter"""
        self.AutomaticallyUpdate = value

    @property
    def BaseStyle(self):
        return self.com_object.BaseStyle

    @BaseStyle.setter
    def BaseStyle(self, value):
        self.com_object.BaseStyle = value

    @property
    def basestyle(self):
        """Alias for BaseStyle"""
        return self.BaseStyle

    @basestyle.setter
    def basestyle(self, value):
        """Alias for BaseStyle.setter"""
        self.BaseStyle = value

    @property
    def base_style(self):
        """Alias for BaseStyle"""
        return self.BaseStyle

    @base_style.setter
    def base_style(self, value):
        """Alias for BaseStyle.setter"""
        self.BaseStyle = value

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def BuiltIn(self):
        return self.com_object.BuiltIn

    @property
    def builtin(self):
        """Alias for BuiltIn"""
        return self.BuiltIn

    @property
    def built_in(self):
        """Alias for BuiltIn"""
        return self.BuiltIn

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Description(self):
        return self.com_object.Description

    @property
    def description(self):
        """Alias for Description"""
        return self.Description

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @Font.setter
    def Font(self, value):
        self.com_object.Font = value

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @font.setter
    def font(self, value):
        """Alias for Font.setter"""
        self.Font = value

    @property
    def Frame(self):
        return Frame(self.com_object.Frame)

    @property
    def frame(self):
        """Alias for Frame"""
        return self.Frame

    @property
    def Hidden(self):
        return self.com_object.Hidden

    @Hidden.setter
    def Hidden(self, value):
        self.com_object.Hidden = value

    @property
    def hidden(self):
        """Alias for Hidden"""
        return self.Hidden

    @hidden.setter
    def hidden(self, value):
        """Alias for Hidden.setter"""
        self.Hidden = value

    @property
    def InUse(self):
        return self.com_object.InUse

    @property
    def inuse(self):
        """Alias for InUse"""
        return self.InUse

    @property
    def in_use(self):
        """Alias for InUse"""
        return self.InUse

    @property
    def LanguageID(self):
        return WdLanguageID(self.com_object.LanguageID)

    @LanguageID.setter
    def LanguageID(self, value):
        self.com_object.LanguageID = value

    @property
    def languageid(self):
        """Alias for LanguageID"""
        return self.LanguageID

    @languageid.setter
    def languageid(self, value):
        """Alias for LanguageID.setter"""
        self.LanguageID = value

    @property
    def language_i_d(self):
        """Alias for LanguageID"""
        return self.LanguageID

    @language_i_d.setter
    def language_i_d(self, value):
        """Alias for LanguageID.setter"""
        self.LanguageID = value

    @property
    def LanguageIDFarEast(self):
        return WdLanguageID(self.com_object.LanguageIDFarEast)

    @LanguageIDFarEast.setter
    def LanguageIDFarEast(self, value):
        self.com_object.LanguageIDFarEast = value

    @property
    def languageidfareast(self):
        """Alias for LanguageIDFarEast"""
        return self.LanguageIDFarEast

    @languageidfareast.setter
    def languageidfareast(self, value):
        """Alias for LanguageIDFarEast.setter"""
        self.LanguageIDFarEast = value

    @property
    def language_i_d_far_east(self):
        """Alias for LanguageIDFarEast"""
        return self.LanguageIDFarEast

    @language_i_d_far_east.setter
    def language_i_d_far_east(self, value):
        """Alias for LanguageIDFarEast.setter"""
        self.LanguageIDFarEast = value

    @property
    def Linked(self):
        return self.com_object.Linked

    @property
    def linked(self):
        """Alias for Linked"""
        return self.Linked

    @property
    def LinkStyle(self):
        return self.com_object.LinkStyle

    @LinkStyle.setter
    def LinkStyle(self, value):
        self.com_object.LinkStyle = value

    @property
    def linkstyle(self):
        """Alias for LinkStyle"""
        return self.LinkStyle

    @linkstyle.setter
    def linkstyle(self, value):
        """Alias for LinkStyle.setter"""
        self.LinkStyle = value

    @property
    def link_style(self):
        """Alias for LinkStyle"""
        return self.LinkStyle

    @link_style.setter
    def link_style(self, value):
        """Alias for LinkStyle.setter"""
        self.LinkStyle = value

    @property
    def ListLevelNumber(self):
        return self.com_object.ListLevelNumber

    @property
    def listlevelnumber(self):
        """Alias for ListLevelNumber"""
        return self.ListLevelNumber

    @property
    def list_level_number(self):
        """Alias for ListLevelNumber"""
        return self.ListLevelNumber

    @property
    def ListTemplate(self):
        return ListTemplate(self.com_object.ListTemplate)

    @property
    def listtemplate(self):
        """Alias for ListTemplate"""
        return self.ListTemplate

    @property
    def list_template(self):
        """Alias for ListTemplate"""
        return self.ListTemplate

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def NameLocal(self):
        return self.com_object.NameLocal

    @NameLocal.setter
    def NameLocal(self, value):
        self.com_object.NameLocal = value

    @property
    def namelocal(self):
        """Alias for NameLocal"""
        return self.NameLocal

    @namelocal.setter
    def namelocal(self, value):
        """Alias for NameLocal.setter"""
        self.NameLocal = value

    @property
    def name_local(self):
        """Alias for NameLocal"""
        return self.NameLocal

    @name_local.setter
    def name_local(self, value):
        """Alias for NameLocal.setter"""
        self.NameLocal = value

    @property
    def NextParagraphStyle(self):
        return self.com_object.NextParagraphStyle

    @NextParagraphStyle.setter
    def NextParagraphStyle(self, value):
        self.com_object.NextParagraphStyle = value

    @property
    def nextparagraphstyle(self):
        """Alias for NextParagraphStyle"""
        return self.NextParagraphStyle

    @nextparagraphstyle.setter
    def nextparagraphstyle(self, value):
        """Alias for NextParagraphStyle.setter"""
        self.NextParagraphStyle = value

    @property
    def next_paragraph_style(self):
        """Alias for NextParagraphStyle"""
        return self.NextParagraphStyle

    @next_paragraph_style.setter
    def next_paragraph_style(self, value):
        """Alias for NextParagraphStyle.setter"""
        self.NextParagraphStyle = value

    @property
    def NoProofing(self):
        return self.com_object.NoProofing

    @NoProofing.setter
    def NoProofing(self, value):
        self.com_object.NoProofing = value

    @property
    def noproofing(self):
        """Alias for NoProofing"""
        return self.NoProofing

    @noproofing.setter
    def noproofing(self, value):
        """Alias for NoProofing.setter"""
        self.NoProofing = value

    @property
    def no_proofing(self):
        """Alias for NoProofing"""
        return self.NoProofing

    @no_proofing.setter
    def no_proofing(self, value):
        """Alias for NoProofing.setter"""
        self.NoProofing = value

    @property
    def NoSpaceBetweenParagraphsOfSameStyle(self):
        return self.com_object.NoSpaceBetweenParagraphsOfSameStyle

    @NoSpaceBetweenParagraphsOfSameStyle.setter
    def NoSpaceBetweenParagraphsOfSameStyle(self, value):
        self.com_object.NoSpaceBetweenParagraphsOfSameStyle = value

    @property
    def nospacebetweenparagraphsofsamestyle(self):
        """Alias for NoSpaceBetweenParagraphsOfSameStyle"""
        return self.NoSpaceBetweenParagraphsOfSameStyle

    @nospacebetweenparagraphsofsamestyle.setter
    def nospacebetweenparagraphsofsamestyle(self, value):
        """Alias for NoSpaceBetweenParagraphsOfSameStyle.setter"""
        self.NoSpaceBetweenParagraphsOfSameStyle = value

    @property
    def no_space_between_paragraphs_of_same_style(self):
        """Alias for NoSpaceBetweenParagraphsOfSameStyle"""
        return self.NoSpaceBetweenParagraphsOfSameStyle

    @no_space_between_paragraphs_of_same_style.setter
    def no_space_between_paragraphs_of_same_style(self, value):
        """Alias for NoSpaceBetweenParagraphsOfSameStyle.setter"""
        self.NoSpaceBetweenParagraphsOfSameStyle = value

    @property
    def ParagraphFormat(self):
        return ParagraphFormat(self.com_object.ParagraphFormat)

    @ParagraphFormat.setter
    def ParagraphFormat(self, value):
        self.com_object.ParagraphFormat = value

    @property
    def paragraphformat(self):
        """Alias for ParagraphFormat"""
        return self.ParagraphFormat

    @paragraphformat.setter
    def paragraphformat(self, value):
        """Alias for ParagraphFormat.setter"""
        self.ParagraphFormat = value

    @property
    def paragraph_format(self):
        """Alias for ParagraphFormat"""
        return self.ParagraphFormat

    @paragraph_format.setter
    def paragraph_format(self, value):
        """Alias for ParagraphFormat.setter"""
        self.ParagraphFormat = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Priority(self):
        return self.com_object.Priority

    @Priority.setter
    def Priority(self, value):
        self.com_object.Priority = value

    @property
    def priority(self):
        """Alias for Priority"""
        return self.Priority

    @priority.setter
    def priority(self, value):
        """Alias for Priority.setter"""
        self.Priority = value

    @property
    def QuickStyle(self):
        return self.com_object.QuickStyle

    @QuickStyle.setter
    def QuickStyle(self, value):
        self.com_object.QuickStyle = value

    @property
    def quickstyle(self):
        """Alias for QuickStyle"""
        return self.QuickStyle

    @quickstyle.setter
    def quickstyle(self, value):
        """Alias for QuickStyle.setter"""
        self.QuickStyle = value

    @property
    def quick_style(self):
        """Alias for QuickStyle"""
        return self.QuickStyle

    @quick_style.setter
    def quick_style(self, value):
        """Alias for QuickStyle.setter"""
        self.QuickStyle = value

    @property
    def Shading(self):
        return Shading(self.com_object.Shading)

    @property
    def shading(self):
        """Alias for Shading"""
        return self.Shading

    @property
    def Table(self):
        return TableStyle(self.com_object.Table)

    @property
    def table(self):
        """Alias for Table"""
        return self.Table

    @property
    def Type(self):
        return WdStyleType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def UnhideWhenUsed(self):
        return self.com_object.UnhideWhenUsed

    @UnhideWhenUsed.setter
    def UnhideWhenUsed(self, value):
        self.com_object.UnhideWhenUsed = value

    @property
    def unhidewhenused(self):
        """Alias for UnhideWhenUsed"""
        return self.UnhideWhenUsed

    @unhidewhenused.setter
    def unhidewhenused(self, value):
        """Alias for UnhideWhenUsed.setter"""
        self.UnhideWhenUsed = value

    @property
    def unhide_when_used(self):
        """Alias for UnhideWhenUsed"""
        return self.UnhideWhenUsed

    @unhide_when_used.setter
    def unhide_when_used(self, value):
        """Alias for UnhideWhenUsed.setter"""
        self.UnhideWhenUsed = value

    @property
    def Visibility(self):
        return self.com_object.Visibility

    @Visibility.setter
    def Visibility(self, value):
        self.com_object.Visibility = value

    @property
    def visibility(self):
        """Alias for Visibility"""
        return self.Visibility

    @visibility.setter
    def visibility(self, value):
        """Alias for Visibility.setter"""
        self.Visibility = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def LinkToListTemplate(self, ListTemplate=None, ListLevelNumber=None):
        arguments = com_arguments([unwrap(a) for a in [ListTemplate, ListLevelNumber]])
        self.com_object.LinkToListTemplate(*arguments)

    def linktolisttemplate(self, ListTemplate=None, ListLevelNumber=None):
        """Alias for LinkToListTemplate"""
        arguments = [ListTemplate, ListLevelNumber]
        return self.LinkToListTemplate(*arguments)

    def link_to_list_template(self, ListTemplate=None, ListLevelNumber=None):
        """Alias for LinkToListTemplate"""
        arguments = [ListTemplate, ListLevelNumber]
        return self.LinkToListTemplate(*arguments)


class Styles:

    def __init__(self, styles=None):
        self.com_object= styles

    def __call__(self, item):
        return Style(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Type]])
        return Style(self.com_object.Add(*arguments))

    def add(self, Name=None, Type=None):
        """Alias for Add"""
        arguments = [Name, Type]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Style(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class StyleSheet:

    def __init__(self, stylesheet=None):
        self.com_object= stylesheet

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def FullName(self):
        return self.com_object.FullName

    @property
    def fullname(self):
        """Alias for FullName"""
        return self.FullName

    @property
    def full_name(self):
        """Alias for FullName"""
        return self.FullName

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Path(self):
        return self.com_object.Path

    @property
    def path(self):
        """Alias for Path"""
        return self.Path

    @property
    def Title(self):
        return self.com_object.Title

    @Title.setter
    def Title(self, value):
        self.com_object.Title = value

    @property
    def title(self):
        """Alias for Title"""
        return self.Title

    @title.setter
    def title(self, value):
        """Alias for Title.setter"""
        self.Title = value

    @property
    def Type(self):
        return WdStyleSheetLinkType(self.com_object.Type)

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Move(self, Precedence=None):
        arguments = com_arguments([unwrap(a) for a in [Precedence]])
        self.com_object.Move(*arguments)

    def move(self, Precedence=None):
        """Alias for Move"""
        arguments = [Precedence]
        return self.Move(*arguments)


class StyleSheets:

    def __init__(self, stylesheets=None):
        self.com_object= stylesheets

    def __call__(self, item):
        return StyleSheet(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, FileName=None, LinkType=None, Title=None, Precedence=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, LinkType, Title, Precedence]])
        return StyleSheet(self.com_object.Add(*arguments))

    def add(self, FileName=None, LinkType=None, Title=None, Precedence=None):
        """Alias for Add"""
        arguments = [FileName, LinkType, Title, Precedence]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return StyleSheet(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Subdocument:

    def __init__(self, subdocument=None):
        self.com_object= subdocument

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def HasFile(self):
        return self.com_object.HasFile

    @property
    def hasfile(self):
        """Alias for HasFile"""
        return self.HasFile

    @property
    def has_file(self):
        """Alias for HasFile"""
        return self.HasFile

    @property
    def Level(self):
        return self.com_object.Level

    @property
    def level(self):
        """Alias for Level"""
        return self.Level

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Path(self):
        return self.com_object.Path

    @property
    def path(self):
        """Alias for Path"""
        return self.Path

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Open(self):
        return Document(self.com_object.Open())

    def open(self):
        """Alias for Open"""
        return self.Open()

    def Split(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        self.com_object.Split(*arguments)

    def split(self, Range=None):
        """Alias for Split"""
        arguments = [Range]
        return self.Split(*arguments)


class Subdocuments:

    def __init__(self, subdocuments=None):
        self.com_object= subdocuments

    def __call__(self, item):
        return Subdocument(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Expanded(self):
        return self.com_object.Expanded

    @Expanded.setter
    def Expanded(self, value):
        self.com_object.Expanded = value

    @property
    def expanded(self):
        """Alias for Expanded"""
        return self.Expanded

    @expanded.setter
    def expanded(self, value):
        """Alias for Expanded.setter"""
        self.Expanded = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def AddFromFile(self, Name=None, ConfirmConversions=None, ReadOnly=None, PasswordDocument=None, PasswordTemplate=None, Revert=None, WritePasswordDocument=None, WritePasswordTemplate=None):
        arguments = com_arguments([unwrap(a) for a in [Name, ConfirmConversions, ReadOnly, PasswordDocument, PasswordTemplate, Revert, WritePasswordDocument, WritePasswordTemplate]])
        return Subdocument(self.com_object.AddFromFile(*arguments))

    def addfromfile(self, Name=None, ConfirmConversions=None, ReadOnly=None, PasswordDocument=None, PasswordTemplate=None, Revert=None, WritePasswordDocument=None, WritePasswordTemplate=None):
        """Alias for AddFromFile"""
        arguments = [Name, ConfirmConversions, ReadOnly, PasswordDocument, PasswordTemplate, Revert, WritePasswordDocument, WritePasswordTemplate]
        return self.AddFromFile(*arguments)

    def add_from_file(self, Name=None, ConfirmConversions=None, ReadOnly=None, PasswordDocument=None, PasswordTemplate=None, Revert=None, WritePasswordDocument=None, WritePasswordTemplate=None):
        """Alias for AddFromFile"""
        arguments = [Name, ConfirmConversions, ReadOnly, PasswordDocument, PasswordTemplate, Revert, WritePasswordDocument, WritePasswordTemplate]
        return self.AddFromFile(*arguments)

    def AddFromRange(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        return SubDocument(self.com_object.AddFromRange(*arguments))

    def addfromrange(self, Range=None):
        """Alias for AddFromRange"""
        arguments = [Range]
        return self.AddFromRange(*arguments)

    def add_from_range(self, Range=None):
        """Alias for AddFromRange"""
        arguments = [Range]
        return self.AddFromRange(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Subdocument(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Merge(self, FirstSubdocument=None, LastSubdocument=None):
        arguments = com_arguments([unwrap(a) for a in [FirstSubdocument, LastSubdocument]])
        self.com_object.Merge(*arguments)

    def merge(self, FirstSubdocument=None, LastSubdocument=None):
        """Alias for Merge"""
        arguments = [FirstSubdocument, LastSubdocument]
        return self.Merge(*arguments)

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class SynonymInfo:

    def __init__(self, synonyminfo=None):
        self.com_object= synonyminfo

    @property
    def AntonymList(self):
        return self.com_object.AntonymList

    @property
    def antonymlist(self):
        """Alias for AntonymList"""
        return self.AntonymList

    @property
    def antonym_list(self):
        """Alias for AntonymList"""
        return self.AntonymList

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Found(self):
        return self.com_object.Found

    @property
    def found(self):
        """Alias for Found"""
        return self.Found

    @property
    def MeaningCount(self):
        return self.com_object.MeaningCount

    @property
    def meaningcount(self):
        """Alias for MeaningCount"""
        return self.MeaningCount

    @property
    def meaning_count(self):
        """Alias for MeaningCount"""
        return self.MeaningCount

    @property
    def MeaningList(self):
        return self.com_object.MeaningList

    @property
    def meaninglist(self):
        """Alias for MeaningList"""
        return self.MeaningList

    @property
    def meaning_list(self):
        """Alias for MeaningList"""
        return self.MeaningList

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PartOfSpeechList(self):
        return self.com_object.PartOfSpeechList

    @property
    def partofspeechlist(self):
        """Alias for PartOfSpeechList"""
        return self.PartOfSpeechList

    @property
    def part_of_speech_list(self):
        """Alias for PartOfSpeechList"""
        return self.PartOfSpeechList

    @property
    def RelatedExpressionList(self):
        return self.com_object.RelatedExpressionList

    @property
    def relatedexpressionlist(self):
        """Alias for RelatedExpressionList"""
        return self.RelatedExpressionList

    @property
    def related_expression_list(self):
        """Alias for RelatedExpressionList"""
        return self.RelatedExpressionList

    @property
    def RelatedWordList(self):
        return self.com_object.RelatedWordList

    @property
    def relatedwordlist(self):
        """Alias for RelatedWordList"""
        return self.RelatedWordList

    @property
    def related_word_list(self):
        """Alias for RelatedWordList"""
        return self.RelatedWordList

    def SynonymList(self, Meaning=None):
        arguments = com_arguments([unwrap(a) for a in [Meaning]])
        if hasattr(self.com_object, "GetSynonymList"):
            return self.com_object.GetSynonymList(*arguments)
        else:
            return self.com_object.SynonymList(*arguments)

    def synonymlist(self, Meaning=None):
        """Alias for SynonymList"""
        arguments = [Meaning]
        return self.SynonymList(*arguments)

    def synonym_list(self, Meaning=None):
        """Alias for SynonymList"""
        arguments = [Meaning]
        return self.SynonymList(*arguments)

    @property
    def Word(self):
        return self.com_object.Word

    @property
    def word(self):
        """Alias for Word"""
        return self.Word


class System:

    def __init__(self, system=None):
        self.com_object= system

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def CountryRegion(self):
        return WdCountry(self.com_object.CountryRegion)

    @property
    def countryregion(self):
        """Alias for CountryRegion"""
        return self.CountryRegion

    @property
    def country_region(self):
        """Alias for CountryRegion"""
        return self.CountryRegion

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Cursor(self):
        return WdCursorType(self.com_object.Cursor)

    @Cursor.setter
    def Cursor(self, value):
        self.com_object.Cursor = value

    @property
    def cursor(self):
        """Alias for Cursor"""
        return self.Cursor

    @cursor.setter
    def cursor(self, value):
        """Alias for Cursor.setter"""
        self.Cursor = value

    @property
    def FreeDiskSpace(self):
        return self.com_object.FreeDiskSpace

    @property
    def freediskspace(self):
        """Alias for FreeDiskSpace"""
        return self.FreeDiskSpace

    @property
    def free_disk_space(self):
        """Alias for FreeDiskSpace"""
        return self.FreeDiskSpace

    @property
    def HorizontalResolution(self):
        return self.com_object.HorizontalResolution

    @property
    def horizontalresolution(self):
        """Alias for HorizontalResolution"""
        return self.HorizontalResolution

    @property
    def horizontal_resolution(self):
        """Alias for HorizontalResolution"""
        return self.HorizontalResolution

    @property
    def LanguageDesignation(self):
        return self.com_object.LanguageDesignation

    @property
    def languagedesignation(self):
        """Alias for LanguageDesignation"""
        return self.LanguageDesignation

    @property
    def language_designation(self):
        """Alias for LanguageDesignation"""
        return self.LanguageDesignation

    @property
    def MathCoprocessorInstalled(self):
        return self.com_object.MathCoprocessorInstalled

    @property
    def mathcoprocessorinstalled(self):
        """Alias for MathCoprocessorInstalled"""
        return self.MathCoprocessorInstalled

    @property
    def math_coprocessor_installed(self):
        """Alias for MathCoprocessorInstalled"""
        return self.MathCoprocessorInstalled

    @property
    def OperatingSystem(self):
        return self.com_object.OperatingSystem

    @property
    def operatingsystem(self):
        """Alias for OperatingSystem"""
        return self.OperatingSystem

    @property
    def operating_system(self):
        """Alias for OperatingSystem"""
        return self.OperatingSystem

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PrivateProfileString(self):
        return self.com_object.PrivateProfileString

    @PrivateProfileString.setter
    def PrivateProfileString(self, value):
        self.com_object.PrivateProfileString = value

    @property
    def privateprofilestring(self):
        """Alias for PrivateProfileString"""
        return self.PrivateProfileString

    @privateprofilestring.setter
    def privateprofilestring(self, value):
        """Alias for PrivateProfileString.setter"""
        self.PrivateProfileString = value

    @property
    def private_profile_string(self):
        """Alias for PrivateProfileString"""
        return self.PrivateProfileString

    @private_profile_string.setter
    def private_profile_string(self, value):
        """Alias for PrivateProfileString.setter"""
        self.PrivateProfileString = value

    @property
    def ProfileString(self):
        return self.com_object.ProfileString

    @ProfileString.setter
    def ProfileString(self, value):
        self.com_object.ProfileString = value

    @property
    def profilestring(self):
        """Alias for ProfileString"""
        return self.ProfileString

    @profilestring.setter
    def profilestring(self, value):
        """Alias for ProfileString.setter"""
        self.ProfileString = value

    @property
    def profile_string(self):
        """Alias for ProfileString"""
        return self.ProfileString

    @profile_string.setter
    def profile_string(self, value):
        """Alias for ProfileString.setter"""
        self.ProfileString = value

    @property
    def ComputerType(self):
        return self.com_object.ComputerType

    @property
    def computertype(self):
        """Alias for ComputerType"""
        return self.ComputerType

    @property
    def computer_type(self):
        """Alias for ComputerType"""
        return self.ComputerType

    @property
    def MacintoshName(self):
        return self.com_object.MacintoshName

    @property
    def macintoshname(self):
        """Alias for MacintoshName"""
        return self.MacintoshName

    @property
    def macintosh_name(self):
        """Alias for MacintoshName"""
        return self.MacintoshName

    @property
    def QuickDrawInstalled(self):
        return self.com_object.QuickDrawInstalled

    @property
    def quickdrawinstalled(self):
        """Alias for QuickDrawInstalled"""
        return self.QuickDrawInstalled

    @property
    def quick_draw_installed(self):
        """Alias for QuickDrawInstalled"""
        return self.QuickDrawInstalled

    @property
    def Version(self):
        return self.com_object.Version

    @property
    def version(self):
        """Alias for Version"""
        return self.Version

    @property
    def VerticalResolution(self):
        return self.com_object.VerticalResolution

    @property
    def verticalresolution(self):
        """Alias for VerticalResolution"""
        return self.VerticalResolution

    @property
    def vertical_resolution(self):
        """Alias for VerticalResolution"""
        return self.VerticalResolution

    def Connect(self, Path=None, Drive=None, Password=None):
        arguments = com_arguments([unwrap(a) for a in [Path, Drive, Password]])
        self.com_object.Connect(*arguments)

    def connect(self, Path=None, Drive=None, Password=None):
        """Alias for Connect"""
        arguments = [Path, Drive, Password]
        return self.Connect(*arguments)

    def MSInfo(self):
        self.com_object.MSInfo()

    def msinfo(self):
        """Alias for MSInfo"""
        return self.MSInfo()

    def m_s_info(self):
        """Alias for MSInfo"""
        return self.MSInfo()


class Table:

    def __init__(self, table=None):
        self.com_object= table

    @property
    def AllowAutoFit(self):
        return self.com_object.AllowAutoFit

    @AllowAutoFit.setter
    def AllowAutoFit(self, value):
        self.com_object.AllowAutoFit = value

    @property
    def allowautofit(self):
        """Alias for AllowAutoFit"""
        return self.AllowAutoFit

    @allowautofit.setter
    def allowautofit(self, value):
        """Alias for AllowAutoFit.setter"""
        self.AllowAutoFit = value

    @property
    def allow_auto_fit(self):
        """Alias for AllowAutoFit"""
        return self.AllowAutoFit

    @allow_auto_fit.setter
    def allow_auto_fit(self, value):
        """Alias for AllowAutoFit.setter"""
        self.AllowAutoFit = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ApplyStyleColumnBands(self):
        return self.com_object.ApplyStyleColumnBands

    @ApplyStyleColumnBands.setter
    def ApplyStyleColumnBands(self, value):
        self.com_object.ApplyStyleColumnBands = value

    @property
    def applystylecolumnbands(self):
        """Alias for ApplyStyleColumnBands"""
        return self.ApplyStyleColumnBands

    @applystylecolumnbands.setter
    def applystylecolumnbands(self, value):
        """Alias for ApplyStyleColumnBands.setter"""
        self.ApplyStyleColumnBands = value

    @property
    def apply_style_column_bands(self):
        """Alias for ApplyStyleColumnBands"""
        return self.ApplyStyleColumnBands

    @apply_style_column_bands.setter
    def apply_style_column_bands(self, value):
        """Alias for ApplyStyleColumnBands.setter"""
        self.ApplyStyleColumnBands = value

    @property
    def ApplyStyleFirstColumn(self):
        return self.com_object.ApplyStyleFirstColumn

    @ApplyStyleFirstColumn.setter
    def ApplyStyleFirstColumn(self, value):
        self.com_object.ApplyStyleFirstColumn = value

    @property
    def applystylefirstcolumn(self):
        """Alias for ApplyStyleFirstColumn"""
        return self.ApplyStyleFirstColumn

    @applystylefirstcolumn.setter
    def applystylefirstcolumn(self, value):
        """Alias for ApplyStyleFirstColumn.setter"""
        self.ApplyStyleFirstColumn = value

    @property
    def apply_style_first_column(self):
        """Alias for ApplyStyleFirstColumn"""
        return self.ApplyStyleFirstColumn

    @apply_style_first_column.setter
    def apply_style_first_column(self, value):
        """Alias for ApplyStyleFirstColumn.setter"""
        self.ApplyStyleFirstColumn = value

    @property
    def ApplyStyleHeadingRows(self):
        return self.com_object.ApplyStyleHeadingRows

    @ApplyStyleHeadingRows.setter
    def ApplyStyleHeadingRows(self, value):
        self.com_object.ApplyStyleHeadingRows = value

    @property
    def applystyleheadingrows(self):
        """Alias for ApplyStyleHeadingRows"""
        return self.ApplyStyleHeadingRows

    @applystyleheadingrows.setter
    def applystyleheadingrows(self, value):
        """Alias for ApplyStyleHeadingRows.setter"""
        self.ApplyStyleHeadingRows = value

    @property
    def apply_style_heading_rows(self):
        """Alias for ApplyStyleHeadingRows"""
        return self.ApplyStyleHeadingRows

    @apply_style_heading_rows.setter
    def apply_style_heading_rows(self, value):
        """Alias for ApplyStyleHeadingRows.setter"""
        self.ApplyStyleHeadingRows = value

    @property
    def ApplyStyleLastColumn(self):
        return self.com_object.ApplyStyleLastColumn

    @ApplyStyleLastColumn.setter
    def ApplyStyleLastColumn(self, value):
        self.com_object.ApplyStyleLastColumn = value

    @property
    def applystylelastcolumn(self):
        """Alias for ApplyStyleLastColumn"""
        return self.ApplyStyleLastColumn

    @applystylelastcolumn.setter
    def applystylelastcolumn(self, value):
        """Alias for ApplyStyleLastColumn.setter"""
        self.ApplyStyleLastColumn = value

    @property
    def apply_style_last_column(self):
        """Alias for ApplyStyleLastColumn"""
        return self.ApplyStyleLastColumn

    @apply_style_last_column.setter
    def apply_style_last_column(self, value):
        """Alias for ApplyStyleLastColumn.setter"""
        self.ApplyStyleLastColumn = value

    @property
    def ApplyStyleLastRow(self):
        return self.com_object.ApplyStyleLastRow

    @ApplyStyleLastRow.setter
    def ApplyStyleLastRow(self, value):
        self.com_object.ApplyStyleLastRow = value

    @property
    def applystylelastrow(self):
        """Alias for ApplyStyleLastRow"""
        return self.ApplyStyleLastRow

    @applystylelastrow.setter
    def applystylelastrow(self, value):
        """Alias for ApplyStyleLastRow.setter"""
        self.ApplyStyleLastRow = value

    @property
    def apply_style_last_row(self):
        """Alias for ApplyStyleLastRow"""
        return self.ApplyStyleLastRow

    @apply_style_last_row.setter
    def apply_style_last_row(self, value):
        """Alias for ApplyStyleLastRow.setter"""
        self.ApplyStyleLastRow = value

    @property
    def ApplyStyleRowBands(self):
        return self.com_object.ApplyStyleRowBands

    @ApplyStyleRowBands.setter
    def ApplyStyleRowBands(self, value):
        self.com_object.ApplyStyleRowBands = value

    @property
    def applystylerowbands(self):
        """Alias for ApplyStyleRowBands"""
        return self.ApplyStyleRowBands

    @applystylerowbands.setter
    def applystylerowbands(self, value):
        """Alias for ApplyStyleRowBands.setter"""
        self.ApplyStyleRowBands = value

    @property
    def apply_style_row_bands(self):
        """Alias for ApplyStyleRowBands"""
        return self.ApplyStyleRowBands

    @apply_style_row_bands.setter
    def apply_style_row_bands(self, value):
        """Alias for ApplyStyleRowBands.setter"""
        self.ApplyStyleRowBands = value

    @property
    def AutoFormatType(self):
        return self.com_object.AutoFormatType

    @property
    def autoformattype(self):
        """Alias for AutoFormatType"""
        return self.AutoFormatType

    @property
    def auto_format_type(self):
        """Alias for AutoFormatType"""
        return self.AutoFormatType

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def BottomPadding(self):
        return self.com_object.BottomPadding

    @BottomPadding.setter
    def BottomPadding(self, value):
        self.com_object.BottomPadding = value

    @property
    def bottompadding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottompadding.setter
    def bottompadding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def bottom_padding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottom_padding.setter
    def bottom_padding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def Columns(self):
        return Columns(self.com_object.Columns)

    @property
    def columns(self):
        """Alias for Columns"""
        return self.Columns

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Descr(self):
        return self.com_object.Descr

    @Descr.setter
    def Descr(self, value):
        self.com_object.Descr = value

    @property
    def descr(self):
        """Alias for Descr"""
        return self.Descr

    @descr.setter
    def descr(self, value):
        """Alias for Descr.setter"""
        self.Descr = value

    @property
    def ID(self):
        return self.com_object.ID

    @ID.setter
    def ID(self, value):
        self.com_object.ID = value

    @property
    def id(self):
        """Alias for ID"""
        return self.ID

    @id.setter
    def id(self, value):
        """Alias for ID.setter"""
        self.ID = value

    @property
    def i_d(self):
        """Alias for ID"""
        return self.ID

    @i_d.setter
    def i_d(self, value):
        """Alias for ID.setter"""
        self.ID = value

    @property
    def LeftPadding(self):
        return self.com_object.LeftPadding

    @LeftPadding.setter
    def LeftPadding(self, value):
        self.com_object.LeftPadding = value

    @property
    def leftpadding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @leftpadding.setter
    def leftpadding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def left_padding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @left_padding.setter
    def left_padding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def NestingLevel(self):
        return self.com_object.NestingLevel

    @property
    def nestinglevel(self):
        """Alias for NestingLevel"""
        return self.NestingLevel

    @property
    def nesting_level(self):
        """Alias for NestingLevel"""
        return self.NestingLevel

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PreferredWidth(self):
        return self.com_object.PreferredWidth

    @PreferredWidth.setter
    def PreferredWidth(self, value):
        self.com_object.PreferredWidth = value

    @property
    def preferredwidth(self):
        """Alias for PreferredWidth"""
        return self.PreferredWidth

    @preferredwidth.setter
    def preferredwidth(self, value):
        """Alias for PreferredWidth.setter"""
        self.PreferredWidth = value

    @property
    def preferred_width(self):
        """Alias for PreferredWidth"""
        return self.PreferredWidth

    @preferred_width.setter
    def preferred_width(self, value):
        """Alias for PreferredWidth.setter"""
        self.PreferredWidth = value

    @property
    def PreferredWidthType(self):
        return WdPreferredWidthType(self.com_object.PreferredWidthType)

    @PreferredWidthType.setter
    def PreferredWidthType(self, value):
        self.com_object.PreferredWidthType = value

    @property
    def preferredwidthtype(self):
        """Alias for PreferredWidthType"""
        return self.PreferredWidthType

    @preferredwidthtype.setter
    def preferredwidthtype(self, value):
        """Alias for PreferredWidthType.setter"""
        self.PreferredWidthType = value

    @property
    def preferred_width_type(self):
        """Alias for PreferredWidthType"""
        return self.PreferredWidthType

    @preferred_width_type.setter
    def preferred_width_type(self, value):
        """Alias for PreferredWidthType.setter"""
        self.PreferredWidthType = value

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def RightPadding(self):
        return self.com_object.RightPadding

    @RightPadding.setter
    def RightPadding(self, value):
        self.com_object.RightPadding = value

    @property
    def rightpadding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @rightpadding.setter
    def rightpadding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def right_padding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @right_padding.setter
    def right_padding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def Rows(self):
        return Rows(self.com_object.Rows)

    @property
    def rows(self):
        """Alias for Rows"""
        return self.Rows

    @property
    def Shading(self):
        return Shading(self.com_object.Shading)

    @property
    def shading(self):
        """Alias for Shading"""
        return self.Shading

    @property
    def Spacing(self):
        return self.com_object.Spacing

    @Spacing.setter
    def Spacing(self, value):
        self.com_object.Spacing = value

    @property
    def spacing(self):
        """Alias for Spacing"""
        return self.Spacing

    @spacing.setter
    def spacing(self, value):
        """Alias for Spacing.setter"""
        self.Spacing = value

    @property
    def Style(self):
        return self.com_object.Style

    @Style.setter
    def Style(self, value):
        self.com_object.Style = value

    @property
    def style(self):
        """Alias for Style"""
        return self.Style

    @style.setter
    def style(self, value):
        """Alias for Style.setter"""
        self.Style = value

    @property
    def TableDirection(self):
        return WdTableDirection(self.com_object.TableDirection)

    @TableDirection.setter
    def TableDirection(self, value):
        self.com_object.TableDirection = value

    @property
    def tabledirection(self):
        """Alias for TableDirection"""
        return self.TableDirection

    @tabledirection.setter
    def tabledirection(self, value):
        """Alias for TableDirection.setter"""
        self.TableDirection = value

    @property
    def table_direction(self):
        """Alias for TableDirection"""
        return self.TableDirection

    @table_direction.setter
    def table_direction(self, value):
        """Alias for TableDirection.setter"""
        self.TableDirection = value

    @property
    def Tables(self):
        return Tables(self.com_object.Tables)

    @property
    def tables(self):
        """Alias for Tables"""
        return self.Tables

    @property
    def Title(self):
        return self.com_object.Title

    @Title.setter
    def Title(self, value):
        self.com_object.Title = value

    @property
    def title(self):
        """Alias for Title"""
        return self.Title

    @title.setter
    def title(self, value):
        """Alias for Title.setter"""
        self.Title = value

    @property
    def TopPadding(self):
        return self.com_object.TopPadding

    @TopPadding.setter
    def TopPadding(self, value):
        self.com_object.TopPadding = value

    @property
    def toppadding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @toppadding.setter
    def toppadding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def top_padding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @top_padding.setter
    def top_padding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def Uniform(self):
        return self.com_object.Uniform

    @property
    def uniform(self):
        """Alias for Uniform"""
        return self.Uniform

    def ApplyStyleDirectFormatting(self, StyleName=None):
        arguments = com_arguments([unwrap(a) for a in [StyleName]])
        self.com_object.ApplyStyleDirectFormatting(*arguments)

    def applystyledirectformatting(self, StyleName=None):
        """Alias for ApplyStyleDirectFormatting"""
        arguments = [StyleName]
        return self.ApplyStyleDirectFormatting(*arguments)

    def apply_style_direct_formatting(self, StyleName=None):
        """Alias for ApplyStyleDirectFormatting"""
        arguments = [StyleName]
        return self.ApplyStyleDirectFormatting(*arguments)

    def AutoFitBehavior(self, Behavior=None):
        arguments = com_arguments([unwrap(a) for a in [Behavior]])
        self.com_object.AutoFitBehavior(*arguments)

    def autofitbehavior(self, Behavior=None):
        """Alias for AutoFitBehavior"""
        arguments = [Behavior]
        return self.AutoFitBehavior(*arguments)

    def auto_fit_behavior(self, Behavior=None):
        """Alias for AutoFitBehavior"""
        arguments = [Behavior]
        return self.AutoFitBehavior(*arguments)

    def AutoFormat(self, Format=None, ApplyBorders=None, ApplyShading=None, ApplyFont=None, ApplyColor=None, ApplyHeadingRows=None, ApplyLastRow=None, ApplyFirstColumn=None, ApplyLastColumn=None, AutoFit=None):
        arguments = com_arguments([unwrap(a) for a in [Format, ApplyBorders, ApplyShading, ApplyFont, ApplyColor, ApplyHeadingRows, ApplyLastRow, ApplyFirstColumn, ApplyLastColumn, AutoFit]])
        self.com_object.AutoFormat(*arguments)

    def autoformat(self, Format=None, ApplyBorders=None, ApplyShading=None, ApplyFont=None, ApplyColor=None, ApplyHeadingRows=None, ApplyLastRow=None, ApplyFirstColumn=None, ApplyLastColumn=None, AutoFit=None):
        """Alias for AutoFormat"""
        arguments = [Format, ApplyBorders, ApplyShading, ApplyFont, ApplyColor, ApplyHeadingRows, ApplyLastRow, ApplyFirstColumn, ApplyLastColumn, AutoFit]
        return self.AutoFormat(*arguments)

    def auto_format(self, Format=None, ApplyBorders=None, ApplyShading=None, ApplyFont=None, ApplyColor=None, ApplyHeadingRows=None, ApplyLastRow=None, ApplyFirstColumn=None, ApplyLastColumn=None, AutoFit=None):
        """Alias for AutoFormat"""
        arguments = [Format, ApplyBorders, ApplyShading, ApplyFont, ApplyColor, ApplyHeadingRows, ApplyLastRow, ApplyFirstColumn, ApplyLastColumn, AutoFit]
        return self.AutoFormat(*arguments)

    def Cell(self, Row=None, Column=None):
        arguments = com_arguments([unwrap(a) for a in [Row, Column]])
        return Cell(self.com_object.Cell(*arguments))

    def cell(self, Row=None, Column=None):
        """Alias for Cell"""
        arguments = [Row, Column]
        return self.Cell(*arguments)

    def ConvertToText(self, Separator=None, NestedTables=None):
        arguments = com_arguments([unwrap(a) for a in [Separator, NestedTables]])
        self.com_object.ConvertToText(*arguments)

    def converttotext(self, Separator=None, NestedTables=None):
        """Alias for ConvertToText"""
        arguments = [Separator, NestedTables]
        return self.ConvertToText(*arguments)

    def convert_to_text(self, Separator=None, NestedTables=None):
        """Alias for ConvertToText"""
        arguments = [Separator, NestedTables]
        return self.ConvertToText(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()

    def Sort(self, ExcludeHeader=None, FieldNumber=None, SortFieldType=None, SortOrder=None, FieldNumber2=None, SortFieldType2=None, SortOrder2=None, FieldNumber3=None, SortFieldType3=None, SortOrder3=None, CaseSensitive=None, BidiSort=None, IgnoreThe=None, IgnoreKashida=None, IgnoreDiacritics=None, IgnoreHe=None, LanguageID=None):
        arguments = com_arguments([unwrap(a) for a in [ExcludeHeader, FieldNumber, SortFieldType, SortOrder, FieldNumber2, SortFieldType2, SortOrder2, FieldNumber3, SortFieldType3, SortOrder3, CaseSensitive, BidiSort, IgnoreThe, IgnoreKashida, IgnoreDiacritics, IgnoreHe, LanguageID]])
        self.com_object.Sort(*arguments)

    def sort(self, ExcludeHeader=None, FieldNumber=None, SortFieldType=None, SortOrder=None, FieldNumber2=None, SortFieldType2=None, SortOrder2=None, FieldNumber3=None, SortFieldType3=None, SortOrder3=None, CaseSensitive=None, BidiSort=None, IgnoreThe=None, IgnoreKashida=None, IgnoreDiacritics=None, IgnoreHe=None, LanguageID=None):
        """Alias for Sort"""
        arguments = [ExcludeHeader, FieldNumber, SortFieldType, SortOrder, FieldNumber2, SortFieldType2, SortOrder2, FieldNumber3, SortFieldType3, SortOrder3, CaseSensitive, BidiSort, IgnoreThe, IgnoreKashida, IgnoreDiacritics, IgnoreHe, LanguageID]
        return self.Sort(*arguments)

    def SortAscending(self):
        self.com_object.SortAscending()

    def sortascending(self):
        """Alias for SortAscending"""
        return self.SortAscending()

    def sort_ascending(self):
        """Alias for SortAscending"""
        return self.SortAscending()

    def SortDescending(self):
        self.com_object.SortDescending()

    def sortdescending(self):
        """Alias for SortDescending"""
        return self.SortDescending()

    def sort_descending(self):
        """Alias for SortDescending"""
        return self.SortDescending()

    def Split(self, BeforeRow=None):
        arguments = com_arguments([unwrap(a) for a in [BeforeRow]])
        return Table(self.com_object.Split(*arguments))

    def split(self, BeforeRow=None):
        """Alias for Split"""
        arguments = [BeforeRow]
        return self.Split(*arguments)

    def UpdateAutoFormat(self):
        self.com_object.UpdateAutoFormat()

    def updateautoformat(self):
        """Alias for UpdateAutoFormat"""
        return self.UpdateAutoFormat()

    def update_auto_format(self):
        """Alias for UpdateAutoFormat"""
        return self.UpdateAutoFormat()


class TableOfAuthorities:

    def __init__(self, tableofauthorities=None):
        self.com_object= tableofauthorities

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Bookmark(self):
        return self.com_object.Bookmark

    @Bookmark.setter
    def Bookmark(self, value):
        self.com_object.Bookmark = value

    @property
    def bookmark(self):
        """Alias for Bookmark"""
        return self.Bookmark

    @bookmark.setter
    def bookmark(self, value):
        """Alias for Bookmark.setter"""
        self.Bookmark = value

    @property
    def Category(self):
        return self.com_object.Category

    @Category.setter
    def Category(self, value):
        self.com_object.Category = value

    @property
    def category(self):
        """Alias for Category"""
        return self.Category

    @category.setter
    def category(self, value):
        """Alias for Category.setter"""
        self.Category = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def EntrySeparator(self):
        return self.com_object.EntrySeparator

    @EntrySeparator.setter
    def EntrySeparator(self, value):
        self.com_object.EntrySeparator = value

    @property
    def entryseparator(self):
        """Alias for EntrySeparator"""
        return self.EntrySeparator

    @entryseparator.setter
    def entryseparator(self, value):
        """Alias for EntrySeparator.setter"""
        self.EntrySeparator = value

    @property
    def entry_separator(self):
        """Alias for EntrySeparator"""
        return self.EntrySeparator

    @entry_separator.setter
    def entry_separator(self, value):
        """Alias for EntrySeparator.setter"""
        self.EntrySeparator = value

    @property
    def IncludeCategoryHeader(self):
        return self.com_object.IncludeCategoryHeader

    @IncludeCategoryHeader.setter
    def IncludeCategoryHeader(self, value):
        self.com_object.IncludeCategoryHeader = value

    @property
    def includecategoryheader(self):
        """Alias for IncludeCategoryHeader"""
        return self.IncludeCategoryHeader

    @includecategoryheader.setter
    def includecategoryheader(self, value):
        """Alias for IncludeCategoryHeader.setter"""
        self.IncludeCategoryHeader = value

    @property
    def include_category_header(self):
        """Alias for IncludeCategoryHeader"""
        return self.IncludeCategoryHeader

    @include_category_header.setter
    def include_category_header(self, value):
        """Alias for IncludeCategoryHeader.setter"""
        self.IncludeCategoryHeader = value

    @property
    def IncludeSequenceName(self):
        return self.com_object.IncludeSequenceName

    @IncludeSequenceName.setter
    def IncludeSequenceName(self, value):
        self.com_object.IncludeSequenceName = value

    @property
    def includesequencename(self):
        """Alias for IncludeSequenceName"""
        return self.IncludeSequenceName

    @includesequencename.setter
    def includesequencename(self, value):
        """Alias for IncludeSequenceName.setter"""
        self.IncludeSequenceName = value

    @property
    def include_sequence_name(self):
        """Alias for IncludeSequenceName"""
        return self.IncludeSequenceName

    @include_sequence_name.setter
    def include_sequence_name(self, value):
        """Alias for IncludeSequenceName.setter"""
        self.IncludeSequenceName = value

    @property
    def KeepEntryFormatting(self):
        return self.com_object.KeepEntryFormatting

    @KeepEntryFormatting.setter
    def KeepEntryFormatting(self, value):
        self.com_object.KeepEntryFormatting = value

    @property
    def keepentryformatting(self):
        """Alias for KeepEntryFormatting"""
        return self.KeepEntryFormatting

    @keepentryformatting.setter
    def keepentryformatting(self, value):
        """Alias for KeepEntryFormatting.setter"""
        self.KeepEntryFormatting = value

    @property
    def keep_entry_formatting(self):
        """Alias for KeepEntryFormatting"""
        return self.KeepEntryFormatting

    @keep_entry_formatting.setter
    def keep_entry_formatting(self, value):
        """Alias for KeepEntryFormatting.setter"""
        self.KeepEntryFormatting = value

    @property
    def PageNumberSeparator(self):
        return self.com_object.PageNumberSeparator

    @PageNumberSeparator.setter
    def PageNumberSeparator(self, value):
        self.com_object.PageNumberSeparator = value

    @property
    def pagenumberseparator(self):
        """Alias for PageNumberSeparator"""
        return self.PageNumberSeparator

    @pagenumberseparator.setter
    def pagenumberseparator(self, value):
        """Alias for PageNumberSeparator.setter"""
        self.PageNumberSeparator = value

    @property
    def page_number_separator(self):
        """Alias for PageNumberSeparator"""
        return self.PageNumberSeparator

    @page_number_separator.setter
    def page_number_separator(self, value):
        """Alias for PageNumberSeparator.setter"""
        self.PageNumberSeparator = value

    @property
    def PageRangeSeparator(self):
        return self.com_object.PageRangeSeparator

    @PageRangeSeparator.setter
    def PageRangeSeparator(self, value):
        self.com_object.PageRangeSeparator = value

    @property
    def pagerangeseparator(self):
        """Alias for PageRangeSeparator"""
        return self.PageRangeSeparator

    @pagerangeseparator.setter
    def pagerangeseparator(self, value):
        """Alias for PageRangeSeparator.setter"""
        self.PageRangeSeparator = value

    @property
    def page_range_separator(self):
        """Alias for PageRangeSeparator"""
        return self.PageRangeSeparator

    @page_range_separator.setter
    def page_range_separator(self, value):
        """Alias for PageRangeSeparator.setter"""
        self.PageRangeSeparator = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Passim(self):
        return self.com_object.Passim

    @Passim.setter
    def Passim(self, value):
        self.com_object.Passim = value

    @property
    def passim(self):
        """Alias for Passim"""
        return self.Passim

    @passim.setter
    def passim(self, value):
        """Alias for Passim.setter"""
        self.Passim = value

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def Separator(self):
        return self.com_object.Separator

    @Separator.setter
    def Separator(self, value):
        self.com_object.Separator = value

    @property
    def separator(self):
        """Alias for Separator"""
        return self.Separator

    @separator.setter
    def separator(self, value):
        """Alias for Separator.setter"""
        self.Separator = value

    @property
    def TabLeader(self):
        return WdTabLeader(self.com_object.TabLeader)

    @TabLeader.setter
    def TabLeader(self, value):
        self.com_object.TabLeader = value

    @property
    def tableader(self):
        """Alias for TabLeader"""
        return self.TabLeader

    @tableader.setter
    def tableader(self, value):
        """Alias for TabLeader.setter"""
        self.TabLeader = value

    @property
    def tab_leader(self):
        """Alias for TabLeader"""
        return self.TabLeader

    @tab_leader.setter
    def tab_leader(self, value):
        """Alias for TabLeader.setter"""
        self.TabLeader = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Update(self):
        self.com_object.Update()

    def update(self):
        """Alias for Update"""
        return self.Update()


class TableOfAuthoritiesCategory:

    def __init__(self, tableofauthoritiescategory=None):
        self.com_object= tableofauthoritiescategory

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class TableOfContents:

    def __init__(self, tableofcontents=None):
        self.com_object= tableofcontents

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def HeadingStyles(self):
        return HeadingStyles(self.com_object.HeadingStyles)

    @property
    def headingstyles(self):
        """Alias for HeadingStyles"""
        return self.HeadingStyles

    @property
    def heading_styles(self):
        """Alias for HeadingStyles"""
        return self.HeadingStyles

    @property
    def HidePageNumbersInWeb(self):
        return self.com_object.HidePageNumbersInWeb

    @HidePageNumbersInWeb.setter
    def HidePageNumbersInWeb(self, value):
        self.com_object.HidePageNumbersInWeb = value

    @property
    def hidepagenumbersinweb(self):
        """Alias for HidePageNumbersInWeb"""
        return self.HidePageNumbersInWeb

    @hidepagenumbersinweb.setter
    def hidepagenumbersinweb(self, value):
        """Alias for HidePageNumbersInWeb.setter"""
        self.HidePageNumbersInWeb = value

    @property
    def hide_page_numbers_in_web(self):
        """Alias for HidePageNumbersInWeb"""
        return self.HidePageNumbersInWeb

    @hide_page_numbers_in_web.setter
    def hide_page_numbers_in_web(self, value):
        """Alias for HidePageNumbersInWeb.setter"""
        self.HidePageNumbersInWeb = value

    @property
    def IncludePageNumbers(self):
        return self.com_object.IncludePageNumbers

    @IncludePageNumbers.setter
    def IncludePageNumbers(self, value):
        self.com_object.IncludePageNumbers = value

    @property
    def includepagenumbers(self):
        """Alias for IncludePageNumbers"""
        return self.IncludePageNumbers

    @includepagenumbers.setter
    def includepagenumbers(self, value):
        """Alias for IncludePageNumbers.setter"""
        self.IncludePageNumbers = value

    @property
    def include_page_numbers(self):
        """Alias for IncludePageNumbers"""
        return self.IncludePageNumbers

    @include_page_numbers.setter
    def include_page_numbers(self, value):
        """Alias for IncludePageNumbers.setter"""
        self.IncludePageNumbers = value

    @property
    def LowerHeadingLevel(self):
        return self.com_object.LowerHeadingLevel

    @LowerHeadingLevel.setter
    def LowerHeadingLevel(self, value):
        self.com_object.LowerHeadingLevel = value

    @property
    def lowerheadinglevel(self):
        """Alias for LowerHeadingLevel"""
        return self.LowerHeadingLevel

    @lowerheadinglevel.setter
    def lowerheadinglevel(self, value):
        """Alias for LowerHeadingLevel.setter"""
        self.LowerHeadingLevel = value

    @property
    def lower_heading_level(self):
        """Alias for LowerHeadingLevel"""
        return self.LowerHeadingLevel

    @lower_heading_level.setter
    def lower_heading_level(self, value):
        """Alias for LowerHeadingLevel.setter"""
        self.LowerHeadingLevel = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def RightAlignPageNumbers(self):
        return self.com_object.RightAlignPageNumbers

    @RightAlignPageNumbers.setter
    def RightAlignPageNumbers(self, value):
        self.com_object.RightAlignPageNumbers = value

    @property
    def rightalignpagenumbers(self):
        """Alias for RightAlignPageNumbers"""
        return self.RightAlignPageNumbers

    @rightalignpagenumbers.setter
    def rightalignpagenumbers(self, value):
        """Alias for RightAlignPageNumbers.setter"""
        self.RightAlignPageNumbers = value

    @property
    def right_align_page_numbers(self):
        """Alias for RightAlignPageNumbers"""
        return self.RightAlignPageNumbers

    @right_align_page_numbers.setter
    def right_align_page_numbers(self, value):
        """Alias for RightAlignPageNumbers.setter"""
        self.RightAlignPageNumbers = value

    @property
    def TabLeader(self):
        return WdTabLeader(self.com_object.TabLeader)

    @TabLeader.setter
    def TabLeader(self, value):
        self.com_object.TabLeader = value

    @property
    def tableader(self):
        """Alias for TabLeader"""
        return self.TabLeader

    @tableader.setter
    def tableader(self, value):
        """Alias for TabLeader.setter"""
        self.TabLeader = value

    @property
    def tab_leader(self):
        """Alias for TabLeader"""
        return self.TabLeader

    @tab_leader.setter
    def tab_leader(self, value):
        """Alias for TabLeader.setter"""
        self.TabLeader = value

    @property
    def TableID(self):
        return self.com_object.TableID

    @TableID.setter
    def TableID(self, value):
        self.com_object.TableID = value

    @property
    def tableid(self):
        """Alias for TableID"""
        return self.TableID

    @tableid.setter
    def tableid(self, value):
        """Alias for TableID.setter"""
        self.TableID = value

    @property
    def table_i_d(self):
        """Alias for TableID"""
        return self.TableID

    @table_i_d.setter
    def table_i_d(self, value):
        """Alias for TableID.setter"""
        self.TableID = value

    @property
    def UpperHeadingLevel(self):
        return self.com_object.UpperHeadingLevel

    @UpperHeadingLevel.setter
    def UpperHeadingLevel(self, value):
        self.com_object.UpperHeadingLevel = value

    @property
    def upperheadinglevel(self):
        """Alias for UpperHeadingLevel"""
        return self.UpperHeadingLevel

    @upperheadinglevel.setter
    def upperheadinglevel(self, value):
        """Alias for UpperHeadingLevel.setter"""
        self.UpperHeadingLevel = value

    @property
    def upper_heading_level(self):
        """Alias for UpperHeadingLevel"""
        return self.UpperHeadingLevel

    @upper_heading_level.setter
    def upper_heading_level(self, value):
        """Alias for UpperHeadingLevel.setter"""
        self.UpperHeadingLevel = value

    @property
    def UseFields(self):
        return self.com_object.UseFields

    @UseFields.setter
    def UseFields(self, value):
        self.com_object.UseFields = value

    @property
    def usefields(self):
        """Alias for UseFields"""
        return self.UseFields

    @usefields.setter
    def usefields(self, value):
        """Alias for UseFields.setter"""
        self.UseFields = value

    @property
    def use_fields(self):
        """Alias for UseFields"""
        return self.UseFields

    @use_fields.setter
    def use_fields(self, value):
        """Alias for UseFields.setter"""
        self.UseFields = value

    @property
    def UseHeadingStyles(self):
        return self.com_object.UseHeadingStyles

    @UseHeadingStyles.setter
    def UseHeadingStyles(self, value):
        self.com_object.UseHeadingStyles = value

    @property
    def useheadingstyles(self):
        """Alias for UseHeadingStyles"""
        return self.UseHeadingStyles

    @useheadingstyles.setter
    def useheadingstyles(self, value):
        """Alias for UseHeadingStyles.setter"""
        self.UseHeadingStyles = value

    @property
    def use_heading_styles(self):
        """Alias for UseHeadingStyles"""
        return self.UseHeadingStyles

    @use_heading_styles.setter
    def use_heading_styles(self, value):
        """Alias for UseHeadingStyles.setter"""
        self.UseHeadingStyles = value

    @property
    def UseHyperlinks(self):
        return self.com_object.UseHyperlinks

    @UseHyperlinks.setter
    def UseHyperlinks(self, value):
        self.com_object.UseHyperlinks = value

    @property
    def usehyperlinks(self):
        """Alias for UseHyperlinks"""
        return self.UseHyperlinks

    @usehyperlinks.setter
    def usehyperlinks(self, value):
        """Alias for UseHyperlinks.setter"""
        self.UseHyperlinks = value

    @property
    def use_hyperlinks(self):
        """Alias for UseHyperlinks"""
        return self.UseHyperlinks

    @use_hyperlinks.setter
    def use_hyperlinks(self, value):
        """Alias for UseHyperlinks.setter"""
        self.UseHyperlinks = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Update(self):
        self.com_object.Update()

    def update(self):
        """Alias for Update"""
        return self.Update()

    def UpdatePageNumbers(self):
        self.com_object.UpdatePageNumbers()

    def updatepagenumbers(self):
        """Alias for UpdatePageNumbers"""
        return self.UpdatePageNumbers()

    def update_page_numbers(self):
        """Alias for UpdatePageNumbers"""
        return self.UpdatePageNumbers()


class TableOfFigures:

    def __init__(self, tableoffigures=None):
        self.com_object= tableoffigures

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def HeadingStyles(self):
        return HeadingStyles(self.com_object.HeadingStyles)

    @property
    def headingstyles(self):
        """Alias for HeadingStyles"""
        return self.HeadingStyles

    @property
    def heading_styles(self):
        """Alias for HeadingStyles"""
        return self.HeadingStyles

    @property
    def HidePageNumbersInWeb(self):
        return self.com_object.HidePageNumbersInWeb

    @HidePageNumbersInWeb.setter
    def HidePageNumbersInWeb(self, value):
        self.com_object.HidePageNumbersInWeb = value

    @property
    def hidepagenumbersinweb(self):
        """Alias for HidePageNumbersInWeb"""
        return self.HidePageNumbersInWeb

    @hidepagenumbersinweb.setter
    def hidepagenumbersinweb(self, value):
        """Alias for HidePageNumbersInWeb.setter"""
        self.HidePageNumbersInWeb = value

    @property
    def hide_page_numbers_in_web(self):
        """Alias for HidePageNumbersInWeb"""
        return self.HidePageNumbersInWeb

    @hide_page_numbers_in_web.setter
    def hide_page_numbers_in_web(self, value):
        """Alias for HidePageNumbersInWeb.setter"""
        self.HidePageNumbersInWeb = value

    @property
    def IncludeLabel(self):
        return self.com_object.IncludeLabel

    @IncludeLabel.setter
    def IncludeLabel(self, value):
        self.com_object.IncludeLabel = value

    @property
    def includelabel(self):
        """Alias for IncludeLabel"""
        return self.IncludeLabel

    @includelabel.setter
    def includelabel(self, value):
        """Alias for IncludeLabel.setter"""
        self.IncludeLabel = value

    @property
    def include_label(self):
        """Alias for IncludeLabel"""
        return self.IncludeLabel

    @include_label.setter
    def include_label(self, value):
        """Alias for IncludeLabel.setter"""
        self.IncludeLabel = value

    @property
    def IncludePageNumbers(self):
        return self.com_object.IncludePageNumbers

    @IncludePageNumbers.setter
    def IncludePageNumbers(self, value):
        self.com_object.IncludePageNumbers = value

    @property
    def includepagenumbers(self):
        """Alias for IncludePageNumbers"""
        return self.IncludePageNumbers

    @includepagenumbers.setter
    def includepagenumbers(self, value):
        """Alias for IncludePageNumbers.setter"""
        self.IncludePageNumbers = value

    @property
    def include_page_numbers(self):
        """Alias for IncludePageNumbers"""
        return self.IncludePageNumbers

    @include_page_numbers.setter
    def include_page_numbers(self, value):
        """Alias for IncludePageNumbers.setter"""
        self.IncludePageNumbers = value

    @property
    def LowerHeadingLevel(self):
        return self.com_object.LowerHeadingLevel

    @LowerHeadingLevel.setter
    def LowerHeadingLevel(self, value):
        self.com_object.LowerHeadingLevel = value

    @property
    def lowerheadinglevel(self):
        """Alias for LowerHeadingLevel"""
        return self.LowerHeadingLevel

    @lowerheadinglevel.setter
    def lowerheadinglevel(self, value):
        """Alias for LowerHeadingLevel.setter"""
        self.LowerHeadingLevel = value

    @property
    def lower_heading_level(self):
        """Alias for LowerHeadingLevel"""
        return self.LowerHeadingLevel

    @lower_heading_level.setter
    def lower_heading_level(self, value):
        """Alias for LowerHeadingLevel.setter"""
        self.LowerHeadingLevel = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def RightAlignPageNumbers(self):
        return self.com_object.RightAlignPageNumbers

    @RightAlignPageNumbers.setter
    def RightAlignPageNumbers(self, value):
        self.com_object.RightAlignPageNumbers = value

    @property
    def rightalignpagenumbers(self):
        """Alias for RightAlignPageNumbers"""
        return self.RightAlignPageNumbers

    @rightalignpagenumbers.setter
    def rightalignpagenumbers(self, value):
        """Alias for RightAlignPageNumbers.setter"""
        self.RightAlignPageNumbers = value

    @property
    def right_align_page_numbers(self):
        """Alias for RightAlignPageNumbers"""
        return self.RightAlignPageNumbers

    @right_align_page_numbers.setter
    def right_align_page_numbers(self, value):
        """Alias for RightAlignPageNumbers.setter"""
        self.RightAlignPageNumbers = value

    @property
    def TabLeader(self):
        return WdTabLeader(self.com_object.TabLeader)

    @TabLeader.setter
    def TabLeader(self, value):
        self.com_object.TabLeader = value

    @property
    def tableader(self):
        """Alias for TabLeader"""
        return self.TabLeader

    @tableader.setter
    def tableader(self, value):
        """Alias for TabLeader.setter"""
        self.TabLeader = value

    @property
    def tab_leader(self):
        """Alias for TabLeader"""
        return self.TabLeader

    @tab_leader.setter
    def tab_leader(self, value):
        """Alias for TabLeader.setter"""
        self.TabLeader = value

    @property
    def TableID(self):
        return self.com_object.TableID

    @TableID.setter
    def TableID(self, value):
        self.com_object.TableID = value

    @property
    def tableid(self):
        """Alias for TableID"""
        return self.TableID

    @tableid.setter
    def tableid(self, value):
        """Alias for TableID.setter"""
        self.TableID = value

    @property
    def table_i_d(self):
        """Alias for TableID"""
        return self.TableID

    @table_i_d.setter
    def table_i_d(self, value):
        """Alias for TableID.setter"""
        self.TableID = value

    @property
    def UpperHeadingLevel(self):
        return self.com_object.UpperHeadingLevel

    @UpperHeadingLevel.setter
    def UpperHeadingLevel(self, value):
        self.com_object.UpperHeadingLevel = value

    @property
    def upperheadinglevel(self):
        """Alias for UpperHeadingLevel"""
        return self.UpperHeadingLevel

    @upperheadinglevel.setter
    def upperheadinglevel(self, value):
        """Alias for UpperHeadingLevel.setter"""
        self.UpperHeadingLevel = value

    @property
    def upper_heading_level(self):
        """Alias for UpperHeadingLevel"""
        return self.UpperHeadingLevel

    @upper_heading_level.setter
    def upper_heading_level(self, value):
        """Alias for UpperHeadingLevel.setter"""
        self.UpperHeadingLevel = value

    @property
    def UseFields(self):
        return self.com_object.UseFields

    @UseFields.setter
    def UseFields(self, value):
        self.com_object.UseFields = value

    @property
    def usefields(self):
        """Alias for UseFields"""
        return self.UseFields

    @usefields.setter
    def usefields(self, value):
        """Alias for UseFields.setter"""
        self.UseFields = value

    @property
    def use_fields(self):
        """Alias for UseFields"""
        return self.UseFields

    @use_fields.setter
    def use_fields(self, value):
        """Alias for UseFields.setter"""
        self.UseFields = value

    @property
    def UseHeadingStyles(self):
        return self.com_object.UseHeadingStyles

    @UseHeadingStyles.setter
    def UseHeadingStyles(self, value):
        self.com_object.UseHeadingStyles = value

    @property
    def useheadingstyles(self):
        """Alias for UseHeadingStyles"""
        return self.UseHeadingStyles

    @useheadingstyles.setter
    def useheadingstyles(self, value):
        """Alias for UseHeadingStyles.setter"""
        self.UseHeadingStyles = value

    @property
    def use_heading_styles(self):
        """Alias for UseHeadingStyles"""
        return self.UseHeadingStyles

    @use_heading_styles.setter
    def use_heading_styles(self, value):
        """Alias for UseHeadingStyles.setter"""
        self.UseHeadingStyles = value

    @property
    def UseHyperlinks(self):
        return self.com_object.UseHyperlinks

    @UseHyperlinks.setter
    def UseHyperlinks(self, value):
        self.com_object.UseHyperlinks = value

    @property
    def usehyperlinks(self):
        """Alias for UseHyperlinks"""
        return self.UseHyperlinks

    @usehyperlinks.setter
    def usehyperlinks(self, value):
        """Alias for UseHyperlinks.setter"""
        self.UseHyperlinks = value

    @property
    def use_hyperlinks(self):
        """Alias for UseHyperlinks"""
        return self.UseHyperlinks

    @use_hyperlinks.setter
    def use_hyperlinks(self, value):
        """Alias for UseHyperlinks.setter"""
        self.UseHyperlinks = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Update(self):
        self.com_object.Update()

    def update(self):
        """Alias for Update"""
        return self.Update()

    def UpdatePageNumbers(self):
        self.com_object.UpdatePageNumbers()

    def updatepagenumbers(self):
        """Alias for UpdatePageNumbers"""
        return self.UpdatePageNumbers()

    def update_page_numbers(self):
        """Alias for UpdatePageNumbers"""
        return self.UpdatePageNumbers()


class Tables:

    def __init__(self, tables=None):
        self.com_object= tables

    def __call__(self, item):
        return Table(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def NestingLevel(self):
        return self.com_object.NestingLevel

    @property
    def nestinglevel(self):
        """Alias for NestingLevel"""
        return self.NestingLevel

    @property
    def nesting_level(self):
        """Alias for NestingLevel"""
        return self.NestingLevel

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Range=None, NumRows=None, NumColumns=None, DefaultTableBehavior=None, AutoFitBehavior=None):
        arguments = com_arguments([unwrap(a) for a in [Range, NumRows, NumColumns, DefaultTableBehavior, AutoFitBehavior]])
        return Table(self.com_object.Add(*arguments))

    def add(self, Range=None, NumRows=None, NumColumns=None, DefaultTableBehavior=None, AutoFitBehavior=None):
        """Alias for Add"""
        arguments = [Range, NumRows, NumColumns, DefaultTableBehavior, AutoFitBehavior]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Table(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class TablesOfAuthorities:

    def __init__(self, tablesofauthorities=None):
        self.com_object= tablesofauthorities

    def __call__(self, item):
        return TablesOfAuthoritie(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return WdToaFormat(self.com_object.Format)

    @Format.setter
    def Format(self, value):
        self.com_object.Format = value

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @format.setter
    def format(self, value):
        """Alias for Format.setter"""
        self.Format = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Range=None, Category=None, Bookmark=None, Passim=None, KeepEntryFormatting=None, Separator=None, IncludeSequenceName=None, EntrySeparator=None, PageRangeSeparator=None, IncludeCategoryHeader=None, PageNumberSeparator=None):
        arguments = com_arguments([unwrap(a) for a in [Range, Category, Bookmark, Passim, KeepEntryFormatting, Separator, IncludeSequenceName, EntrySeparator, PageRangeSeparator, IncludeCategoryHeader, PageNumberSeparator]])
        return TableOfAuthorities(self.com_object.Add(*arguments))

    def add(self, Range=None, Category=None, Bookmark=None, Passim=None, KeepEntryFormatting=None, Separator=None, IncludeSequenceName=None, EntrySeparator=None, PageRangeSeparator=None, IncludeCategoryHeader=None, PageNumberSeparator=None):
        """Alias for Add"""
        arguments = [Range, Category, Bookmark, Passim, KeepEntryFormatting, Separator, IncludeSequenceName, EntrySeparator, PageRangeSeparator, IncludeCategoryHeader, PageNumberSeparator]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return TableOfAuthorities(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def MarkAllCitations(self, ShortCitation=None, LongCitation=None, LongCitationAutoText=None, Category=None):
        arguments = com_arguments([unwrap(a) for a in [ShortCitation, LongCitation, LongCitationAutoText, Category]])
        self.com_object.MarkAllCitations(*arguments)

    def markallcitations(self, ShortCitation=None, LongCitation=None, LongCitationAutoText=None, Category=None):
        """Alias for MarkAllCitations"""
        arguments = [ShortCitation, LongCitation, LongCitationAutoText, Category]
        return self.MarkAllCitations(*arguments)

    def mark_all_citations(self, ShortCitation=None, LongCitation=None, LongCitationAutoText=None, Category=None):
        """Alias for MarkAllCitations"""
        arguments = [ShortCitation, LongCitation, LongCitationAutoText, Category]
        return self.MarkAllCitations(*arguments)

    def MarkCitation(self, Range=None, ShortCitation=None, LongCitation=None, LongCitationAutoText=None, Category=None):
        arguments = com_arguments([unwrap(a) for a in [Range, ShortCitation, LongCitation, LongCitationAutoText, Category]])
        self.com_object.MarkCitation(*arguments)

    def markcitation(self, Range=None, ShortCitation=None, LongCitation=None, LongCitationAutoText=None, Category=None):
        """Alias for MarkCitation"""
        arguments = [Range, ShortCitation, LongCitation, LongCitationAutoText, Category]
        return self.MarkCitation(*arguments)

    def mark_citation(self, Range=None, ShortCitation=None, LongCitation=None, LongCitationAutoText=None, Category=None):
        """Alias for MarkCitation"""
        arguments = [Range, ShortCitation, LongCitation, LongCitationAutoText, Category]
        return self.MarkCitation(*arguments)

    def NextCitation(self, ShortCitation=None):
        arguments = com_arguments([unwrap(a) for a in [ShortCitation]])
        self.com_object.NextCitation(*arguments)

    def nextcitation(self, ShortCitation=None):
        """Alias for NextCitation"""
        arguments = [ShortCitation]
        return self.NextCitation(*arguments)

    def next_citation(self, ShortCitation=None):
        """Alias for NextCitation"""
        arguments = [ShortCitation]
        return self.NextCitation(*arguments)


class TablesOfAuthoritiesCategories:

    def __init__(self, tablesofauthoritiescategories=None):
        self.com_object= tablesofauthoritiescategories

    def __call__(self, item):
        return TablesOfAuthoritiesCategorie(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class TablesOfContents:

    def __init__(self, tablesofcontents=None):
        self.com_object= tablesofcontents

    def __call__(self, item):
        return TablesOfContent(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return WdTocFormat(self.com_object.Format)

    @Format.setter
    def Format(self, value):
        self.com_object.Format = value

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @format.setter
    def format(self, value):
        """Alias for Format.setter"""
        self.Format = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Range=None, UseHeadingStyles=None, UpperHeadingLevel=None, LowerHeadingLevel=None, UseFields=None, TableID=None, RightAlignPageNumbers=None, IncludePageNumbers=None, AddedStyles=None, UseHyperlinks=None, HidePageNumbersInWeb=None, UseOutlineLevels=None):
        arguments = com_arguments([unwrap(a) for a in [Range, UseHeadingStyles, UpperHeadingLevel, LowerHeadingLevel, UseFields, TableID, RightAlignPageNumbers, IncludePageNumbers, AddedStyles, UseHyperlinks, HidePageNumbersInWeb, UseOutlineLevels]])
        return TableOfContents(self.com_object.Add(*arguments))

    def add(self, Range=None, UseHeadingStyles=None, UpperHeadingLevel=None, LowerHeadingLevel=None, UseFields=None, TableID=None, RightAlignPageNumbers=None, IncludePageNumbers=None, AddedStyles=None, UseHyperlinks=None, HidePageNumbersInWeb=None, UseOutlineLevels=None):
        """Alias for Add"""
        arguments = [Range, UseHeadingStyles, UpperHeadingLevel, LowerHeadingLevel, UseFields, TableID, RightAlignPageNumbers, IncludePageNumbers, AddedStyles, UseHyperlinks, HidePageNumbersInWeb, UseOutlineLevels]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return TableOfContents(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def MarkEntry(self, Range=None, Entry=None, EntryAutoText=None, TableID=None, Level=None):
        arguments = com_arguments([unwrap(a) for a in [Range, Entry, EntryAutoText, TableID, Level]])
        return Field(self.com_object.MarkEntry(*arguments))

    def markentry(self, Range=None, Entry=None, EntryAutoText=None, TableID=None, Level=None):
        """Alias for MarkEntry"""
        arguments = [Range, Entry, EntryAutoText, TableID, Level]
        return self.MarkEntry(*arguments)

    def mark_entry(self, Range=None, Entry=None, EntryAutoText=None, TableID=None, Level=None):
        """Alias for MarkEntry"""
        arguments = [Range, Entry, EntryAutoText, TableID, Level]
        return self.MarkEntry(*arguments)


class TablesOfFigures:

    def __init__(self, tablesoffigures=None):
        self.com_object= tablesoffigures

    def __call__(self, item):
        return TablesOfFigure(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return WdTofFormat(self.com_object.Format)

    @Format.setter
    def Format(self, value):
        self.com_object.Format = value

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @format.setter
    def format(self, value):
        """Alias for Format.setter"""
        self.Format = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Range=None, Caption=None, IncludeLabel=None, UseHeadingStyles=None, UpperHeadingLevel=None, LowerHeadingLevel=None, UseFields=None, TableID=None, RightAlignPageNumbers=None, IncludePageNumbers=None, AddedStyles=None, UseHyperlinks=None, HidePageNumbersInWeb=None):
        arguments = com_arguments([unwrap(a) for a in [Range, Caption, IncludeLabel, UseHeadingStyles, UpperHeadingLevel, LowerHeadingLevel, UseFields, TableID, RightAlignPageNumbers, IncludePageNumbers, AddedStyles, UseHyperlinks, HidePageNumbersInWeb]])
        return TableOfFigures(self.com_object.Add(*arguments))

    def add(self, Range=None, Caption=None, IncludeLabel=None, UseHeadingStyles=None, UpperHeadingLevel=None, LowerHeadingLevel=None, UseFields=None, TableID=None, RightAlignPageNumbers=None, IncludePageNumbers=None, AddedStyles=None, UseHyperlinks=None, HidePageNumbersInWeb=None):
        """Alias for Add"""
        arguments = [Range, Caption, IncludeLabel, UseHeadingStyles, UpperHeadingLevel, LowerHeadingLevel, UseFields, TableID, RightAlignPageNumbers, IncludePageNumbers, AddedStyles, UseHyperlinks, HidePageNumbersInWeb]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return TableOfFigures(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def MarkEntry(self, Range=None, Entry=None, EntryAutoText=None, TableID=None, Level=None):
        arguments = com_arguments([unwrap(a) for a in [Range, Entry, EntryAutoText, TableID, Level]])
        return Field(self.com_object.MarkEntry(*arguments))

    def markentry(self, Range=None, Entry=None, EntryAutoText=None, TableID=None, Level=None):
        """Alias for MarkEntry"""
        arguments = [Range, Entry, EntryAutoText, TableID, Level]
        return self.MarkEntry(*arguments)

    def mark_entry(self, Range=None, Entry=None, EntryAutoText=None, TableID=None, Level=None):
        """Alias for MarkEntry"""
        arguments = [Range, Entry, EntryAutoText, TableID, Level]
        return self.MarkEntry(*arguments)


class TableStyle:

    def __init__(self, tablestyle=None):
        self.com_object= tablestyle

    @property
    def Alignment(self):
        return WdRowAlignment(self.com_object.Alignment)

    @Alignment.setter
    def Alignment(self, value):
        self.com_object.Alignment = value

    @property
    def alignment(self):
        """Alias for Alignment"""
        return self.Alignment

    @alignment.setter
    def alignment(self, value):
        """Alias for Alignment.setter"""
        self.Alignment = value

    @property
    def AllowBreakAcrossPage(self):
        return self.com_object.AllowBreakAcrossPage

    @AllowBreakAcrossPage.setter
    def AllowBreakAcrossPage(self, value):
        self.com_object.AllowBreakAcrossPage = value

    @property
    def allowbreakacrosspage(self):
        """Alias for AllowBreakAcrossPage"""
        return self.AllowBreakAcrossPage

    @allowbreakacrosspage.setter
    def allowbreakacrosspage(self, value):
        """Alias for AllowBreakAcrossPage.setter"""
        self.AllowBreakAcrossPage = value

    @property
    def allow_break_across_page(self):
        """Alias for AllowBreakAcrossPage"""
        return self.AllowBreakAcrossPage

    @allow_break_across_page.setter
    def allow_break_across_page(self, value):
        """Alias for AllowBreakAcrossPage.setter"""
        self.AllowBreakAcrossPage = value

    @property
    def AllowPageBreaks(self):
        return self.com_object.AllowPageBreaks

    @AllowPageBreaks.setter
    def AllowPageBreaks(self, value):
        self.com_object.AllowPageBreaks = value

    @property
    def allowpagebreaks(self):
        """Alias for AllowPageBreaks"""
        return self.AllowPageBreaks

    @allowpagebreaks.setter
    def allowpagebreaks(self, value):
        """Alias for AllowPageBreaks.setter"""
        self.AllowPageBreaks = value

    @property
    def allow_page_breaks(self):
        """Alias for AllowPageBreaks"""
        return self.AllowPageBreaks

    @allow_page_breaks.setter
    def allow_page_breaks(self, value):
        """Alias for AllowPageBreaks.setter"""
        self.AllowPageBreaks = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def BottomPadding(self):
        return self.com_object.BottomPadding

    @BottomPadding.setter
    def BottomPadding(self, value):
        self.com_object.BottomPadding = value

    @property
    def bottompadding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottompadding.setter
    def bottompadding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def bottom_padding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottom_padding.setter
    def bottom_padding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def ColumnStripe(self):
        return self.com_object.ColumnStripe

    @ColumnStripe.setter
    def ColumnStripe(self, value):
        self.com_object.ColumnStripe = value

    @property
    def columnstripe(self):
        """Alias for ColumnStripe"""
        return self.ColumnStripe

    @columnstripe.setter
    def columnstripe(self, value):
        """Alias for ColumnStripe.setter"""
        self.ColumnStripe = value

    @property
    def column_stripe(self):
        """Alias for ColumnStripe"""
        return self.ColumnStripe

    @column_stripe.setter
    def column_stripe(self, value):
        """Alias for ColumnStripe.setter"""
        self.ColumnStripe = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def LeftIndent(self):
        return self.com_object.LeftIndent

    @LeftIndent.setter
    def LeftIndent(self, value):
        self.com_object.LeftIndent = value

    @property
    def leftindent(self):
        """Alias for LeftIndent"""
        return self.LeftIndent

    @leftindent.setter
    def leftindent(self, value):
        """Alias for LeftIndent.setter"""
        self.LeftIndent = value

    @property
    def left_indent(self):
        """Alias for LeftIndent"""
        return self.LeftIndent

    @left_indent.setter
    def left_indent(self, value):
        """Alias for LeftIndent.setter"""
        self.LeftIndent = value

    @property
    def LeftPadding(self):
        return self.com_object.LeftPadding

    @LeftPadding.setter
    def LeftPadding(self, value):
        self.com_object.LeftPadding = value

    @property
    def leftpadding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @leftpadding.setter
    def leftpadding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def left_padding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @left_padding.setter
    def left_padding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RightPadding(self):
        return self.com_object.RightPadding

    @RightPadding.setter
    def RightPadding(self, value):
        self.com_object.RightPadding = value

    @property
    def rightpadding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @rightpadding.setter
    def rightpadding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def right_padding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @right_padding.setter
    def right_padding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def RowStripe(self):
        return self.com_object.RowStripe

    @RowStripe.setter
    def RowStripe(self, value):
        self.com_object.RowStripe = value

    @property
    def rowstripe(self):
        """Alias for RowStripe"""
        return self.RowStripe

    @rowstripe.setter
    def rowstripe(self, value):
        """Alias for RowStripe.setter"""
        self.RowStripe = value

    @property
    def row_stripe(self):
        """Alias for RowStripe"""
        return self.RowStripe

    @row_stripe.setter
    def row_stripe(self, value):
        """Alias for RowStripe.setter"""
        self.RowStripe = value

    @property
    def Shading(self):
        return Shading(self.com_object.Shading)

    @property
    def shading(self):
        """Alias for Shading"""
        return self.Shading

    @property
    def Spacing(self):
        return self.com_object.Spacing

    @Spacing.setter
    def Spacing(self, value):
        self.com_object.Spacing = value

    @property
    def spacing(self):
        """Alias for Spacing"""
        return self.Spacing

    @spacing.setter
    def spacing(self, value):
        """Alias for Spacing.setter"""
        self.Spacing = value

    @property
    def TableDirection(self):
        return WdTableDirection(self.com_object.TableDirection)

    @TableDirection.setter
    def TableDirection(self, value):
        self.com_object.TableDirection = value

    @property
    def tabledirection(self):
        """Alias for TableDirection"""
        return self.TableDirection

    @tabledirection.setter
    def tabledirection(self, value):
        """Alias for TableDirection.setter"""
        self.TableDirection = value

    @property
    def table_direction(self):
        """Alias for TableDirection"""
        return self.TableDirection

    @table_direction.setter
    def table_direction(self, value):
        """Alias for TableDirection.setter"""
        self.TableDirection = value

    @property
    def TopPadding(self):
        return self.com_object.TopPadding

    @TopPadding.setter
    def TopPadding(self, value):
        self.com_object.TopPadding = value

    @property
    def toppadding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @toppadding.setter
    def toppadding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def top_padding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @top_padding.setter
    def top_padding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    def Condition(self, ConditionCode=None):
        arguments = com_arguments([unwrap(a) for a in [ConditionCode]])
        self.com_object.Condition(*arguments)

    def condition(self, ConditionCode=None):
        """Alias for Condition"""
        arguments = [ConditionCode]
        return self.Condition(*arguments)


class TabStop:

    def __init__(self, tabstop=None):
        self.com_object= tabstop

    @property
    def Alignment(self):
        return WdTabAlignment(self.com_object.Alignment)

    @Alignment.setter
    def Alignment(self, value):
        self.com_object.Alignment = value

    @property
    def alignment(self):
        """Alias for Alignment"""
        return self.Alignment

    @alignment.setter
    def alignment(self, value):
        """Alias for Alignment.setter"""
        self.Alignment = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def CustomTab(self):
        return self.com_object.CustomTab

    @property
    def customtab(self):
        """Alias for CustomTab"""
        return self.CustomTab

    @property
    def custom_tab(self):
        """Alias for CustomTab"""
        return self.CustomTab

    @property
    def Leader(self):
        return TabStop(self.com_object.Leader)

    @Leader.setter
    def Leader(self, value):
        self.com_object.Leader = value

    @property
    def leader(self):
        """Alias for Leader"""
        return self.Leader

    @leader.setter
    def leader(self, value):
        """Alias for Leader.setter"""
        self.Leader = value

    @property
    def Next(self):
        return self.com_object.Next

    @property
    def next(self):
        """Alias for Next"""
        return self.Next

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return self.com_object.Position

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def Previous(self):
        return self.com_object.Previous

    @property
    def previous(self):
        """Alias for Previous"""
        return self.Previous

    def Clear(self):
        self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()


class TabStops:

    def __init__(self, tabstops=None):
        self.com_object= tabstops

    def __call__(self, item):
        return TabStop(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Position=None, Alignment=None, Leader=None):
        arguments = com_arguments([unwrap(a) for a in [Position, Alignment, Leader]])
        return TabStop(self.com_object.Add(*arguments))

    def add(self, Position=None, Alignment=None, Leader=None):
        """Alias for Add"""
        arguments = [Position, Alignment, Leader]
        return self.Add(*arguments)

    def After(self, Position=None):
        arguments = com_arguments([unwrap(a) for a in [Position]])
        self.com_object.After(*arguments)

    def after(self, Position=None):
        """Alias for After"""
        arguments = [Position]
        return self.After(*arguments)

    def Before(self, Position=None):
        arguments = com_arguments([unwrap(a) for a in [Position]])
        self.com_object.Before(*arguments)

    def before(self, Position=None):
        """Alias for Before"""
        arguments = [Position]
        return self.Before(*arguments)

    def ClearAll(self):
        self.com_object.ClearAll()

    def clearall(self):
        """Alias for ClearAll"""
        return self.ClearAll()

    def clear_all(self):
        """Alias for ClearAll"""
        return self.ClearAll()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return TabStop(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Task:

    def __init__(self, task=None):
        self.com_object= task

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return Task(self.com_object.Width)

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def WindowState(self):
        return WdWindowState(self.com_object.WindowState)

    @WindowState.setter
    def WindowState(self, value):
        self.com_object.WindowState = value

    @property
    def windowstate(self):
        """Alias for WindowState"""
        return self.WindowState

    @windowstate.setter
    def windowstate(self, value):
        """Alias for WindowState.setter"""
        self.WindowState = value

    @property
    def window_state(self):
        """Alias for WindowState"""
        return self.WindowState

    @window_state.setter
    def window_state(self, value):
        """Alias for WindowState.setter"""
        self.WindowState = value

    def Activate(self, Wait=None):
        arguments = com_arguments([unwrap(a) for a in [Wait]])
        self.com_object.Activate(*arguments)

    def activate(self, Wait=None):
        """Alias for Activate"""
        arguments = [Wait]
        return self.Activate(*arguments)

    def Close(self):
        self.com_object.Close()

    def close(self):
        """Alias for Close"""
        return self.Close()

    def Move(self, Left=None, Top=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None):
        """Alias for Move"""
        arguments = [Left, Top]
        return self.Move(*arguments)

    def Resize(self, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Width, Height]])
        self.com_object.Resize(*arguments)

    def resize(self, Width=None, Height=None):
        """Alias for Resize"""
        arguments = [Width, Height]
        return self.Resize(*arguments)

    def SendWindowMessage(self, Message=None, wParam=None, IParam=None):
        arguments = com_arguments([unwrap(a) for a in [Message, wParam, IParam]])
        self.com_object.SendWindowMessage(*arguments)

    def sendwindowmessage(self, Message=None, wParam=None, IParam=None):
        """Alias for SendWindowMessage"""
        arguments = [Message, wParam, IParam]
        return self.SendWindowMessage(*arguments)

    def send_window_message(self, Message=None, wParam=None, IParam=None):
        """Alias for SendWindowMessage"""
        arguments = [Message, wParam, IParam]
        return self.SendWindowMessage(*arguments)


class TaskPane:

    def __init__(self, taskpane=None):
        self.com_object= taskpane

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value


class TaskPanes:

    def __init__(self, taskpanes=None):
        self.com_object= taskpanes

    def __call__(self, item):
        return TaskPane(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return TaskPane(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Tasks:

    def __init__(self, tasks=None):
        self.com_object= tasks

    def __call__(self, item):
        return Task(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Exists(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        return self.com_object.Exists(*arguments)

    def exists(self, Name=None):
        """Alias for Exists"""
        arguments = [Name]
        return self.Exists(*arguments)

    def ExitWindows(self):
        self.com_object.ExitWindows()

    def exitwindows(self):
        """Alias for ExitWindows"""
        return self.ExitWindows()

    def exit_windows(self):
        """Alias for ExitWindows"""
        return self.ExitWindows()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Task(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Template:

    def __init__(self, template=None):
        self.com_object= template

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BuildingBlockEntries(self):
        return BuildingBlockEntries(self.com_object.BuildingBlockEntries)

    @property
    def buildingblockentries(self):
        """Alias for BuildingBlockEntries"""
        return self.BuildingBlockEntries

    @property
    def building_block_entries(self):
        """Alias for BuildingBlockEntries"""
        return self.BuildingBlockEntries

    @property
    def BuildingBlockTypes(self):
        return BuildingBlockTypes(self.com_object.BuildingBlockTypes)

    @property
    def buildingblocktypes(self):
        """Alias for BuildingBlockTypes"""
        return self.BuildingBlockTypes

    @property
    def building_block_types(self):
        """Alias for BuildingBlockTypes"""
        return self.BuildingBlockTypes

    @property
    def BuiltInDocumentProperties(self):
        return self.com_object.BuiltInDocumentProperties

    @property
    def builtindocumentproperties(self):
        """Alias for BuiltInDocumentProperties"""
        return self.BuiltInDocumentProperties

    @property
    def built_in_document_properties(self):
        """Alias for BuiltInDocumentProperties"""
        return self.BuiltInDocumentProperties

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def CustomDocumentProperties(self):
        return self.com_object.CustomDocumentProperties

    @property
    def customdocumentproperties(self):
        """Alias for CustomDocumentProperties"""
        return self.CustomDocumentProperties

    @property
    def custom_document_properties(self):
        """Alias for CustomDocumentProperties"""
        return self.CustomDocumentProperties

    @property
    def FarEastLineBreakLanguage(self):
        return WdFarEastLineBreakLanguageID(self.com_object.FarEastLineBreakLanguage)

    @FarEastLineBreakLanguage.setter
    def FarEastLineBreakLanguage(self, value):
        self.com_object.FarEastLineBreakLanguage = value

    @property
    def fareastlinebreaklanguage(self):
        """Alias for FarEastLineBreakLanguage"""
        return self.FarEastLineBreakLanguage

    @fareastlinebreaklanguage.setter
    def fareastlinebreaklanguage(self, value):
        """Alias for FarEastLineBreakLanguage.setter"""
        self.FarEastLineBreakLanguage = value

    @property
    def far_east_line_break_language(self):
        """Alias for FarEastLineBreakLanguage"""
        return self.FarEastLineBreakLanguage

    @far_east_line_break_language.setter
    def far_east_line_break_language(self, value):
        """Alias for FarEastLineBreakLanguage.setter"""
        self.FarEastLineBreakLanguage = value

    @property
    def FarEastLineBreakLevel(self):
        return WdFarEastLineBreakLevel(self.com_object.FarEastLineBreakLevel)

    @FarEastLineBreakLevel.setter
    def FarEastLineBreakLevel(self, value):
        self.com_object.FarEastLineBreakLevel = value

    @property
    def fareastlinebreaklevel(self):
        """Alias for FarEastLineBreakLevel"""
        return self.FarEastLineBreakLevel

    @fareastlinebreaklevel.setter
    def fareastlinebreaklevel(self, value):
        """Alias for FarEastLineBreakLevel.setter"""
        self.FarEastLineBreakLevel = value

    @property
    def far_east_line_break_level(self):
        """Alias for FarEastLineBreakLevel"""
        return self.FarEastLineBreakLevel

    @far_east_line_break_level.setter
    def far_east_line_break_level(self, value):
        """Alias for FarEastLineBreakLevel.setter"""
        self.FarEastLineBreakLevel = value

    @property
    def FullName(self):
        return self.com_object.FullName

    @property
    def fullname(self):
        """Alias for FullName"""
        return self.FullName

    @property
    def full_name(self):
        """Alias for FullName"""
        return self.FullName

    @property
    def JustificationMode(self):
        return WdJustificationMode(self.com_object.JustificationMode)

    @JustificationMode.setter
    def JustificationMode(self, value):
        self.com_object.JustificationMode = value

    @property
    def justificationmode(self):
        """Alias for JustificationMode"""
        return self.JustificationMode

    @justificationmode.setter
    def justificationmode(self, value):
        """Alias for JustificationMode.setter"""
        self.JustificationMode = value

    @property
    def justification_mode(self):
        """Alias for JustificationMode"""
        return self.JustificationMode

    @justification_mode.setter
    def justification_mode(self, value):
        """Alias for JustificationMode.setter"""
        self.JustificationMode = value

    @property
    def KerningByAlgorithm(self):
        return self.com_object.KerningByAlgorithm

    @KerningByAlgorithm.setter
    def KerningByAlgorithm(self, value):
        self.com_object.KerningByAlgorithm = value

    @property
    def kerningbyalgorithm(self):
        """Alias for KerningByAlgorithm"""
        return self.KerningByAlgorithm

    @kerningbyalgorithm.setter
    def kerningbyalgorithm(self, value):
        """Alias for KerningByAlgorithm.setter"""
        self.KerningByAlgorithm = value

    @property
    def kerning_by_algorithm(self):
        """Alias for KerningByAlgorithm"""
        return self.KerningByAlgorithm

    @kerning_by_algorithm.setter
    def kerning_by_algorithm(self, value):
        """Alias for KerningByAlgorithm.setter"""
        self.KerningByAlgorithm = value

    @property
    def LanguageID(self):
        return WdLanguageID(self.com_object.LanguageID)

    @LanguageID.setter
    def LanguageID(self, value):
        self.com_object.LanguageID = value

    @property
    def languageid(self):
        """Alias for LanguageID"""
        return self.LanguageID

    @languageid.setter
    def languageid(self, value):
        """Alias for LanguageID.setter"""
        self.LanguageID = value

    @property
    def language_i_d(self):
        """Alias for LanguageID"""
        return self.LanguageID

    @language_i_d.setter
    def language_i_d(self, value):
        """Alias for LanguageID.setter"""
        self.LanguageID = value

    @property
    def LanguageIDFarEast(self):
        return WdLanguageID(self.com_object.LanguageIDFarEast)

    @LanguageIDFarEast.setter
    def LanguageIDFarEast(self, value):
        self.com_object.LanguageIDFarEast = value

    @property
    def languageidfareast(self):
        """Alias for LanguageIDFarEast"""
        return self.LanguageIDFarEast

    @languageidfareast.setter
    def languageidfareast(self, value):
        """Alias for LanguageIDFarEast.setter"""
        self.LanguageIDFarEast = value

    @property
    def language_i_d_far_east(self):
        """Alias for LanguageIDFarEast"""
        return self.LanguageIDFarEast

    @language_i_d_far_east.setter
    def language_i_d_far_east(self, value):
        """Alias for LanguageIDFarEast.setter"""
        self.LanguageIDFarEast = value

    @property
    def ListTemplates(self):
        return ListTemplates(self.com_object.ListTemplates)

    @property
    def listtemplates(self):
        """Alias for ListTemplates"""
        return self.ListTemplates

    @property
    def list_templates(self):
        """Alias for ListTemplates"""
        return self.ListTemplates

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NoLineBreakAfter(self):
        return self.com_object.NoLineBreakAfter

    @NoLineBreakAfter.setter
    def NoLineBreakAfter(self, value):
        self.com_object.NoLineBreakAfter = value

    @property
    def nolinebreakafter(self):
        """Alias for NoLineBreakAfter"""
        return self.NoLineBreakAfter

    @nolinebreakafter.setter
    def nolinebreakafter(self, value):
        """Alias for NoLineBreakAfter.setter"""
        self.NoLineBreakAfter = value

    @property
    def no_line_break_after(self):
        """Alias for NoLineBreakAfter"""
        return self.NoLineBreakAfter

    @no_line_break_after.setter
    def no_line_break_after(self, value):
        """Alias for NoLineBreakAfter.setter"""
        self.NoLineBreakAfter = value

    @property
    def NoLineBreakBefore(self):
        return self.com_object.NoLineBreakBefore

    @NoLineBreakBefore.setter
    def NoLineBreakBefore(self, value):
        self.com_object.NoLineBreakBefore = value

    @property
    def nolinebreakbefore(self):
        """Alias for NoLineBreakBefore"""
        return self.NoLineBreakBefore

    @nolinebreakbefore.setter
    def nolinebreakbefore(self, value):
        """Alias for NoLineBreakBefore.setter"""
        self.NoLineBreakBefore = value

    @property
    def no_line_break_before(self):
        """Alias for NoLineBreakBefore"""
        return self.NoLineBreakBefore

    @no_line_break_before.setter
    def no_line_break_before(self, value):
        """Alias for NoLineBreakBefore.setter"""
        self.NoLineBreakBefore = value

    @property
    def NoProofing(self):
        return self.com_object.NoProofing

    @NoProofing.setter
    def NoProofing(self, value):
        self.com_object.NoProofing = value

    @property
    def noproofing(self):
        """Alias for NoProofing"""
        return self.NoProofing

    @noproofing.setter
    def noproofing(self, value):
        """Alias for NoProofing.setter"""
        self.NoProofing = value

    @property
    def no_proofing(self):
        """Alias for NoProofing"""
        return self.NoProofing

    @no_proofing.setter
    def no_proofing(self, value):
        """Alias for NoProofing.setter"""
        self.NoProofing = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Path(self):
        return self.com_object.Path

    @property
    def path(self):
        """Alias for Path"""
        return self.Path

    @property
    def Saved(self):
        return self.com_object.Saved

    @Saved.setter
    def Saved(self, value):
        self.com_object.Saved = value

    @property
    def saved(self):
        """Alias for Saved"""
        return self.Saved

    @saved.setter
    def saved(self, value):
        """Alias for Saved.setter"""
        self.Saved = value

    @property
    def Type(self):
        return WdTemplateType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def VBProject(self):
        return self.com_object.VBProject

    @property
    def vbproject(self):
        """Alias for VBProject"""
        return self.VBProject

    @property
    def v_b_project(self):
        """Alias for VBProject"""
        return self.VBProject

    def OpenAsDocument(self):
        return Document(self.com_object.OpenAsDocument())

    def openasdocument(self):
        """Alias for OpenAsDocument"""
        return self.OpenAsDocument()

    def open_as_document(self):
        """Alias for OpenAsDocument"""
        return self.OpenAsDocument()

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()


class Templates:

    def __init__(self, templates=None):
        self.com_object= templates

    def __call__(self, item):
        return Template(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Template(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def LoadBuildingBlocks(self):
        self.com_object.LoadBuildingBlocks()

    def loadbuildingblocks(self):
        """Alias for LoadBuildingBlocks"""
        return self.LoadBuildingBlocks()

    def load_building_blocks(self):
        """Alias for LoadBuildingBlocks"""
        return self.LoadBuildingBlocks()


class TextColumn:

    def __init__(self, textcolumn=None):
        self.com_object= textcolumn

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SpaceAfter(self):
        return self.com_object.SpaceAfter

    @SpaceAfter.setter
    def SpaceAfter(self, value):
        self.com_object.SpaceAfter = value

    @property
    def spaceafter(self):
        """Alias for SpaceAfter"""
        return self.SpaceAfter

    @spaceafter.setter
    def spaceafter(self, value):
        """Alias for SpaceAfter.setter"""
        self.SpaceAfter = value

    @property
    def space_after(self):
        """Alias for SpaceAfter"""
        return self.SpaceAfter

    @space_after.setter
    def space_after(self, value):
        """Alias for SpaceAfter.setter"""
        self.SpaceAfter = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value


class TextEffectFormat:

    def __init__(self, texteffectformat=None):
        self.com_object= texteffectformat

    @property
    def Alignment(self):
        return self.com_object.Alignment

    @Alignment.setter
    def Alignment(self, value):
        self.com_object.Alignment = value

    @property
    def alignment(self):
        """Alias for Alignment"""
        return self.Alignment

    @alignment.setter
    def alignment(self, value):
        """Alias for Alignment.setter"""
        self.Alignment = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def FontBold(self):
        return self.com_object.FontBold

    @FontBold.setter
    def FontBold(self, value):
        self.com_object.FontBold = value

    @property
    def fontbold(self):
        """Alias for FontBold"""
        return self.FontBold

    @fontbold.setter
    def fontbold(self, value):
        """Alias for FontBold.setter"""
        self.FontBold = value

    @property
    def font_bold(self):
        """Alias for FontBold"""
        return self.FontBold

    @font_bold.setter
    def font_bold(self, value):
        """Alias for FontBold.setter"""
        self.FontBold = value

    @property
    def FontItalic(self):
        return self.com_object.FontItalic

    @FontItalic.setter
    def FontItalic(self, value):
        self.com_object.FontItalic = value

    @property
    def fontitalic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @fontitalic.setter
    def fontitalic(self, value):
        """Alias for FontItalic.setter"""
        self.FontItalic = value

    @property
    def font_italic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @font_italic.setter
    def font_italic(self, value):
        """Alias for FontItalic.setter"""
        self.FontItalic = value

    @property
    def FontName(self):
        return self.com_object.FontName

    @FontName.setter
    def FontName(self, value):
        self.com_object.FontName = value

    @property
    def fontname(self):
        """Alias for FontName"""
        return self.FontName

    @fontname.setter
    def fontname(self, value):
        """Alias for FontName.setter"""
        self.FontName = value

    @property
    def font_name(self):
        """Alias for FontName"""
        return self.FontName

    @font_name.setter
    def font_name(self, value):
        """Alias for FontName.setter"""
        self.FontName = value

    @property
    def FontSize(self):
        return self.com_object.FontSize

    @FontSize.setter
    def FontSize(self, value):
        self.com_object.FontSize = value

    @property
    def fontsize(self):
        """Alias for FontSize"""
        return self.FontSize

    @fontsize.setter
    def fontsize(self, value):
        """Alias for FontSize.setter"""
        self.FontSize = value

    @property
    def font_size(self):
        """Alias for FontSize"""
        return self.FontSize

    @font_size.setter
    def font_size(self, value):
        """Alias for FontSize.setter"""
        self.FontSize = value

    @property
    def KernedPairs(self):
        return self.com_object.KernedPairs

    @KernedPairs.setter
    def KernedPairs(self, value):
        self.com_object.KernedPairs = value

    @property
    def kernedpairs(self):
        """Alias for KernedPairs"""
        return self.KernedPairs

    @kernedpairs.setter
    def kernedpairs(self, value):
        """Alias for KernedPairs.setter"""
        self.KernedPairs = value

    @property
    def kerned_pairs(self):
        """Alias for KernedPairs"""
        return self.KernedPairs

    @kerned_pairs.setter
    def kerned_pairs(self, value):
        """Alias for KernedPairs.setter"""
        self.KernedPairs = value

    @property
    def NormalizedHeight(self):
        return self.com_object.NormalizedHeight

    @NormalizedHeight.setter
    def NormalizedHeight(self, value):
        self.com_object.NormalizedHeight = value

    @property
    def normalizedheight(self):
        """Alias for NormalizedHeight"""
        return self.NormalizedHeight

    @normalizedheight.setter
    def normalizedheight(self, value):
        """Alias for NormalizedHeight.setter"""
        self.NormalizedHeight = value

    @property
    def normalized_height(self):
        """Alias for NormalizedHeight"""
        return self.NormalizedHeight

    @normalized_height.setter
    def normalized_height(self, value):
        """Alias for NormalizedHeight.setter"""
        self.NormalizedHeight = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PresetShape(self):
        return self.com_object.PresetShape

    @PresetShape.setter
    def PresetShape(self, value):
        self.com_object.PresetShape = value

    @property
    def presetshape(self):
        """Alias for PresetShape"""
        return self.PresetShape

    @presetshape.setter
    def presetshape(self, value):
        """Alias for PresetShape.setter"""
        self.PresetShape = value

    @property
    def preset_shape(self):
        """Alias for PresetShape"""
        return self.PresetShape

    @preset_shape.setter
    def preset_shape(self, value):
        """Alias for PresetShape.setter"""
        self.PresetShape = value

    @property
    def PresetTextEffect(self):
        return self.com_object.PresetTextEffect

    @PresetTextEffect.setter
    def PresetTextEffect(self, value):
        self.com_object.PresetTextEffect = value

    @property
    def presettexteffect(self):
        """Alias for PresetTextEffect"""
        return self.PresetTextEffect

    @presettexteffect.setter
    def presettexteffect(self, value):
        """Alias for PresetTextEffect.setter"""
        self.PresetTextEffect = value

    @property
    def preset_text_effect(self):
        """Alias for PresetTextEffect"""
        return self.PresetTextEffect

    @preset_text_effect.setter
    def preset_text_effect(self, value):
        """Alias for PresetTextEffect.setter"""
        self.PresetTextEffect = value

    @property
    def RotatedChars(self):
        return self.com_object.RotatedChars

    @RotatedChars.setter
    def RotatedChars(self, value):
        self.com_object.RotatedChars = value

    @property
    def rotatedchars(self):
        """Alias for RotatedChars"""
        return self.RotatedChars

    @rotatedchars.setter
    def rotatedchars(self, value):
        """Alias for RotatedChars.setter"""
        self.RotatedChars = value

    @property
    def rotated_chars(self):
        """Alias for RotatedChars"""
        return self.RotatedChars

    @rotated_chars.setter
    def rotated_chars(self, value):
        """Alias for RotatedChars.setter"""
        self.RotatedChars = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def Tracking(self):
        return self.com_object.Tracking

    @Tracking.setter
    def Tracking(self, value):
        self.com_object.Tracking = value

    @property
    def tracking(self):
        """Alias for Tracking"""
        return self.Tracking

    @tracking.setter
    def tracking(self, value):
        """Alias for Tracking.setter"""
        self.Tracking = value

    def ToggleVerticalText(self):
        self.com_object.ToggleVerticalText()

    def toggleverticaltext(self):
        """Alias for ToggleVerticalText"""
        return self.ToggleVerticalText()

    def toggle_vertical_text(self):
        """Alias for ToggleVerticalText"""
        return self.ToggleVerticalText()


class TextFrame:

    def __init__(self, textframe=None):
        self.com_object= textframe

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoSize(self):
        return self.com_object.AutoSize

    @AutoSize.setter
    def AutoSize(self, value):
        self.com_object.AutoSize = value

    @property
    def autosize(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @autosize.setter
    def autosize(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def auto_size(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @auto_size.setter
    def auto_size(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def Column(self):
        return self.com_object.Column

    @property
    def column(self):
        """Alias for Column"""
        return self.Column

    @property
    def ContainingRange(self):
        return Range(self.com_object.ContainingRange)

    @property
    def containingrange(self):
        """Alias for ContainingRange"""
        return self.ContainingRange

    @property
    def containing_range(self):
        """Alias for ContainingRange"""
        return self.ContainingRange

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def HasText(self):
        return self.com_object.HasText

    @property
    def hastext(self):
        """Alias for HasText"""
        return self.HasText

    @property
    def has_text(self):
        """Alias for HasText"""
        return self.HasText

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def MarginBottom(self):
        return self.com_object.MarginBottom

    @MarginBottom.setter
    def MarginBottom(self, value):
        self.com_object.MarginBottom = value

    @property
    def marginbottom(self):
        """Alias for MarginBottom"""
        return self.MarginBottom

    @marginbottom.setter
    def marginbottom(self, value):
        """Alias for MarginBottom.setter"""
        self.MarginBottom = value

    @property
    def margin_bottom(self):
        """Alias for MarginBottom"""
        return self.MarginBottom

    @margin_bottom.setter
    def margin_bottom(self, value):
        """Alias for MarginBottom.setter"""
        self.MarginBottom = value

    @property
    def MarginLeft(self):
        return self.com_object.MarginLeft

    @MarginLeft.setter
    def MarginLeft(self, value):
        self.com_object.MarginLeft = value

    @property
    def marginleft(self):
        """Alias for MarginLeft"""
        return self.MarginLeft

    @marginleft.setter
    def marginleft(self, value):
        """Alias for MarginLeft.setter"""
        self.MarginLeft = value

    @property
    def margin_left(self):
        """Alias for MarginLeft"""
        return self.MarginLeft

    @margin_left.setter
    def margin_left(self, value):
        """Alias for MarginLeft.setter"""
        self.MarginLeft = value

    @property
    def MarginRight(self):
        return self.com_object.MarginRight

    @MarginRight.setter
    def MarginRight(self, value):
        self.com_object.MarginRight = value

    @property
    def marginright(self):
        """Alias for MarginRight"""
        return self.MarginRight

    @marginright.setter
    def marginright(self, value):
        """Alias for MarginRight.setter"""
        self.MarginRight = value

    @property
    def margin_right(self):
        """Alias for MarginRight"""
        return self.MarginRight

    @margin_right.setter
    def margin_right(self, value):
        """Alias for MarginRight.setter"""
        self.MarginRight = value

    @property
    def MarginTop(self):
        return self.com_object.MarginTop

    @MarginTop.setter
    def MarginTop(self, value):
        self.com_object.MarginTop = value

    @property
    def margintop(self):
        """Alias for MarginTop"""
        return self.MarginTop

    @margintop.setter
    def margintop(self, value):
        """Alias for MarginTop.setter"""
        self.MarginTop = value

    @property
    def margin_top(self):
        """Alias for MarginTop"""
        return self.MarginTop

    @margin_top.setter
    def margin_top(self, value):
        """Alias for MarginTop.setter"""
        self.MarginTop = value

    @property
    def Next(self):
        return TextFrame(self.com_object.Next)

    @property
    def next(self):
        """Alias for Next"""
        return self.Next

    @property
    def NoTextRotation(self):
        return self.com_object.NoTextRotation

    @NoTextRotation.setter
    def NoTextRotation(self, value):
        self.com_object.NoTextRotation = value

    @property
    def notextrotation(self):
        """Alias for NoTextRotation"""
        return self.NoTextRotation

    @notextrotation.setter
    def notextrotation(self, value):
        """Alias for NoTextRotation.setter"""
        self.NoTextRotation = value

    @property
    def no_text_rotation(self):
        """Alias for NoTextRotation"""
        return self.NoTextRotation

    @no_text_rotation.setter
    def no_text_rotation(self, value):
        """Alias for NoTextRotation.setter"""
        self.NoTextRotation = value

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Overflowing(self):
        return self.com_object.Overflowing

    @property
    def overflowing(self):
        """Alias for Overflowing"""
        return self.Overflowing

    @property
    def Parent(self):
        return Shape(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PathFormat(self):
        return self.com_object.PathFormat

    @PathFormat.setter
    def PathFormat(self, value):
        self.com_object.PathFormat = value

    @property
    def pathformat(self):
        """Alias for PathFormat"""
        return self.PathFormat

    @pathformat.setter
    def pathformat(self, value):
        """Alias for PathFormat.setter"""
        self.PathFormat = value

    @property
    def path_format(self):
        """Alias for PathFormat"""
        return self.PathFormat

    @path_format.setter
    def path_format(self, value):
        """Alias for PathFormat.setter"""
        self.PathFormat = value

    @property
    def Previous(self):
        return TextFrame(self.com_object.Previous)

    @property
    def previous(self):
        """Alias for Previous"""
        return self.Previous

    @property
    def TextRange(self):
        return Range(self.com_object.TextRange)

    @property
    def textrange(self):
        """Alias for TextRange"""
        return self.TextRange

    @property
    def text_range(self):
        """Alias for TextRange"""
        return self.TextRange

    @property
    def ThreeD(self):
        return self.com_object.ThreeD

    @property
    def threed(self):
        """Alias for ThreeD"""
        return self.ThreeD

    @property
    def three_d(self):
        """Alias for ThreeD"""
        return self.ThreeD

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def WarpFormat(self):
        return self.com_object.WarpFormat

    @WarpFormat.setter
    def WarpFormat(self, value):
        self.com_object.WarpFormat = value

    @property
    def warpformat(self):
        """Alias for WarpFormat"""
        return self.WarpFormat

    @warpformat.setter
    def warpformat(self, value):
        """Alias for WarpFormat.setter"""
        self.WarpFormat = value

    @property
    def warp_format(self):
        """Alias for WarpFormat"""
        return self.WarpFormat

    @warp_format.setter
    def warp_format(self, value):
        """Alias for WarpFormat.setter"""
        self.WarpFormat = value

    @property
    def WordWrap(self):
        return self.com_object.WordWrap

    @WordWrap.setter
    def WordWrap(self, value):
        self.com_object.WordWrap = value

    @property
    def wordwrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @wordwrap.setter
    def wordwrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value

    @property
    def word_wrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @word_wrap.setter
    def word_wrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value

    def BreakForwardLink(self):
        self.com_object.BreakForwardLink()

    def breakforwardlink(self):
        """Alias for BreakForwardLink"""
        return self.BreakForwardLink()

    def break_forward_link(self):
        """Alias for BreakForwardLink"""
        return self.BreakForwardLink()

    def DeleteText(self):
        self.com_object.DeleteText()

    def deletetext(self):
        """Alias for DeleteText"""
        return self.DeleteText()

    def delete_text(self):
        """Alias for DeleteText"""
        return self.DeleteText()

    def ValidLinkTarget(self, TargetTextFrame=None):
        arguments = com_arguments([unwrap(a) for a in [TargetTextFrame]])
        return self.com_object.ValidLinkTarget(*arguments)

    def validlinktarget(self, TargetTextFrame=None):
        """Alias for ValidLinkTarget"""
        arguments = [TargetTextFrame]
        return self.ValidLinkTarget(*arguments)

    def valid_link_target(self, TargetTextFrame=None):
        """Alias for ValidLinkTarget"""
        arguments = [TargetTextFrame]
        return self.ValidLinkTarget(*arguments)


class TextInput:

    def __init__(self, textinput=None):
        self.com_object= textinput

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Default(self):
        return self.com_object.Default

    @Default.setter
    def Default(self, value):
        self.com_object.Default = value

    @property
    def default(self):
        """Alias for Default"""
        return self.Default

    @default.setter
    def default(self, value):
        """Alias for Default.setter"""
        self.Default = value

    @property
    def Format(self):
        return self.com_object.Format

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Type(self):
        return WdTextFormFieldType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def Valid(self):
        return self.com_object.Valid

    @property
    def valid(self):
        """Alias for Valid"""
        return self.Valid

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Clear(self):
        self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()

    def EditType(self, Type=None, Default=None, Format=None, Enabled=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Default, Format, Enabled]])
        self.com_object.EditType(*arguments)

    def edittype(self, Type=None, Default=None, Format=None, Enabled=None):
        """Alias for EditType"""
        arguments = [Type, Default, Format, Enabled]
        return self.EditType(*arguments)

    def edit_type(self, Type=None, Default=None, Format=None, Enabled=None):
        """Alias for EditType"""
        arguments = [Type, Default, Format, Enabled]
        return self.EditType(*arguments)


class TextRetrievalMode:

    def __init__(self, textretrievalmode=None):
        self.com_object= textretrievalmode

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Duplicate(self):
        return TextRetrievalMode(self.com_object.Duplicate)

    @property
    def duplicate(self):
        """Alias for Duplicate"""
        return self.Duplicate

    @property
    def IncludeFieldCodes(self):
        return self.com_object.IncludeFieldCodes

    @IncludeFieldCodes.setter
    def IncludeFieldCodes(self, value):
        self.com_object.IncludeFieldCodes = value

    @property
    def includefieldcodes(self):
        """Alias for IncludeFieldCodes"""
        return self.IncludeFieldCodes

    @includefieldcodes.setter
    def includefieldcodes(self, value):
        """Alias for IncludeFieldCodes.setter"""
        self.IncludeFieldCodes = value

    @property
    def include_field_codes(self):
        """Alias for IncludeFieldCodes"""
        return self.IncludeFieldCodes

    @include_field_codes.setter
    def include_field_codes(self, value):
        """Alias for IncludeFieldCodes.setter"""
        self.IncludeFieldCodes = value

    @property
    def IncludeHiddenText(self):
        return self.com_object.IncludeHiddenText

    @IncludeHiddenText.setter
    def IncludeHiddenText(self, value):
        self.com_object.IncludeHiddenText = value

    @property
    def includehiddentext(self):
        """Alias for IncludeHiddenText"""
        return self.IncludeHiddenText

    @includehiddentext.setter
    def includehiddentext(self, value):
        """Alias for IncludeHiddenText.setter"""
        self.IncludeHiddenText = value

    @property
    def include_hidden_text(self):
        """Alias for IncludeHiddenText"""
        return self.IncludeHiddenText

    @include_hidden_text.setter
    def include_hidden_text(self, value):
        """Alias for IncludeHiddenText.setter"""
        self.IncludeHiddenText = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ViewType(self):
        return TextRetrievalMode(self.com_object.ViewType)

    @ViewType.setter
    def ViewType(self, value):
        self.com_object.ViewType = value

    @property
    def viewtype(self):
        """Alias for ViewType"""
        return self.ViewType

    @viewtype.setter
    def viewtype(self, value):
        """Alias for ViewType.setter"""
        self.ViewType = value

    @property
    def view_type(self):
        """Alias for ViewType"""
        return self.ViewType

    @view_type.setter
    def view_type(self, value):
        """Alias for ViewType.setter"""
        self.ViewType = value


class ThreeDFormat:

    def __init__(self, threedformat=None):
        self.com_object= threedformat

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BevelBottomDepth(self):
        return self.com_object.BevelBottomDepth

    @BevelBottomDepth.setter
    def BevelBottomDepth(self, value):
        self.com_object.BevelBottomDepth = value

    @property
    def bevelbottomdepth(self):
        """Alias for BevelBottomDepth"""
        return self.BevelBottomDepth

    @bevelbottomdepth.setter
    def bevelbottomdepth(self, value):
        """Alias for BevelBottomDepth.setter"""
        self.BevelBottomDepth = value

    @property
    def bevel_bottom_depth(self):
        """Alias for BevelBottomDepth"""
        return self.BevelBottomDepth

    @bevel_bottom_depth.setter
    def bevel_bottom_depth(self, value):
        """Alias for BevelBottomDepth.setter"""
        self.BevelBottomDepth = value

    @property
    def BevelBottomInset(self):
        return self.com_object.BevelBottomInset

    @BevelBottomInset.setter
    def BevelBottomInset(self, value):
        self.com_object.BevelBottomInset = value

    @property
    def bevelbottominset(self):
        """Alias for BevelBottomInset"""
        return self.BevelBottomInset

    @bevelbottominset.setter
    def bevelbottominset(self, value):
        """Alias for BevelBottomInset.setter"""
        self.BevelBottomInset = value

    @property
    def bevel_bottom_inset(self):
        """Alias for BevelBottomInset"""
        return self.BevelBottomInset

    @bevel_bottom_inset.setter
    def bevel_bottom_inset(self, value):
        """Alias for BevelBottomInset.setter"""
        self.BevelBottomInset = value

    @property
    def BevelBottomType(self):
        return self.com_object.BevelBottomType

    @BevelBottomType.setter
    def BevelBottomType(self, value):
        self.com_object.BevelBottomType = value

    @property
    def bevelbottomtype(self):
        """Alias for BevelBottomType"""
        return self.BevelBottomType

    @bevelbottomtype.setter
    def bevelbottomtype(self, value):
        """Alias for BevelBottomType.setter"""
        self.BevelBottomType = value

    @property
    def bevel_bottom_type(self):
        """Alias for BevelBottomType"""
        return self.BevelBottomType

    @bevel_bottom_type.setter
    def bevel_bottom_type(self, value):
        """Alias for BevelBottomType.setter"""
        self.BevelBottomType = value

    @property
    def BevelTopDepth(self):
        return self.com_object.BevelTopDepth

    @BevelTopDepth.setter
    def BevelTopDepth(self, value):
        self.com_object.BevelTopDepth = value

    @property
    def beveltopdepth(self):
        """Alias for BevelTopDepth"""
        return self.BevelTopDepth

    @beveltopdepth.setter
    def beveltopdepth(self, value):
        """Alias for BevelTopDepth.setter"""
        self.BevelTopDepth = value

    @property
    def bevel_top_depth(self):
        """Alias for BevelTopDepth"""
        return self.BevelTopDepth

    @bevel_top_depth.setter
    def bevel_top_depth(self, value):
        """Alias for BevelTopDepth.setter"""
        self.BevelTopDepth = value

    @property
    def BevelTopInset(self):
        return self.com_object.BevelTopInset

    @BevelTopInset.setter
    def BevelTopInset(self, value):
        self.com_object.BevelTopInset = value

    @property
    def beveltopinset(self):
        """Alias for BevelTopInset"""
        return self.BevelTopInset

    @beveltopinset.setter
    def beveltopinset(self, value):
        """Alias for BevelTopInset.setter"""
        self.BevelTopInset = value

    @property
    def bevel_top_inset(self):
        """Alias for BevelTopInset"""
        return self.BevelTopInset

    @bevel_top_inset.setter
    def bevel_top_inset(self, value):
        """Alias for BevelTopInset.setter"""
        self.BevelTopInset = value

    @property
    def BevelTopType(self):
        return self.com_object.BevelTopType

    @BevelTopType.setter
    def BevelTopType(self, value):
        self.com_object.BevelTopType = value

    @property
    def beveltoptype(self):
        """Alias for BevelTopType"""
        return self.BevelTopType

    @beveltoptype.setter
    def beveltoptype(self, value):
        """Alias for BevelTopType.setter"""
        self.BevelTopType = value

    @property
    def bevel_top_type(self):
        """Alias for BevelTopType"""
        return self.BevelTopType

    @bevel_top_type.setter
    def bevel_top_type(self, value):
        """Alias for BevelTopType.setter"""
        self.BevelTopType = value

    @property
    def ContourColor(self):
        return ColorFormat(self.com_object.ContourColor)

    @ContourColor.setter
    def ContourColor(self, value):
        self.com_object.ContourColor = value

    @property
    def contourcolor(self):
        """Alias for ContourColor"""
        return self.ContourColor

    @contourcolor.setter
    def contourcolor(self, value):
        """Alias for ContourColor.setter"""
        self.ContourColor = value

    @property
    def contour_color(self):
        """Alias for ContourColor"""
        return self.ContourColor

    @contour_color.setter
    def contour_color(self, value):
        """Alias for ContourColor.setter"""
        self.ContourColor = value

    @property
    def ContourWidth(self):
        return self.com_object.ContourWidth

    @ContourWidth.setter
    def ContourWidth(self, value):
        self.com_object.ContourWidth = value

    @property
    def contourwidth(self):
        """Alias for ContourWidth"""
        return self.ContourWidth

    @contourwidth.setter
    def contourwidth(self, value):
        """Alias for ContourWidth.setter"""
        self.ContourWidth = value

    @property
    def contour_width(self):
        """Alias for ContourWidth"""
        return self.ContourWidth

    @contour_width.setter
    def contour_width(self, value):
        """Alias for ContourWidth.setter"""
        self.ContourWidth = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Depth(self):
        return self.com_object.Depth

    @Depth.setter
    def Depth(self, value):
        self.com_object.Depth = value

    @property
    def depth(self):
        """Alias for Depth"""
        return self.Depth

    @depth.setter
    def depth(self, value):
        """Alias for Depth.setter"""
        self.Depth = value

    @property
    def ExtrusionColor(self):
        return ColorFormat(self.com_object.ExtrusionColor)

    @property
    def extrusioncolor(self):
        """Alias for ExtrusionColor"""
        return self.ExtrusionColor

    @property
    def extrusion_color(self):
        """Alias for ExtrusionColor"""
        return self.ExtrusionColor

    @property
    def ExtrusionColorType(self):
        return self.com_object.ExtrusionColorType

    @ExtrusionColorType.setter
    def ExtrusionColorType(self, value):
        self.com_object.ExtrusionColorType = value

    @property
    def extrusioncolortype(self):
        """Alias for ExtrusionColorType"""
        return self.ExtrusionColorType

    @extrusioncolortype.setter
    def extrusioncolortype(self, value):
        """Alias for ExtrusionColorType.setter"""
        self.ExtrusionColorType = value

    @property
    def extrusion_color_type(self):
        """Alias for ExtrusionColorType"""
        return self.ExtrusionColorType

    @extrusion_color_type.setter
    def extrusion_color_type(self, value):
        """Alias for ExtrusionColorType.setter"""
        self.ExtrusionColorType = value

    @property
    def FieldOfView(self):
        return self.com_object.FieldOfView

    @FieldOfView.setter
    def FieldOfView(self, value):
        self.com_object.FieldOfView = value

    @property
    def fieldofview(self):
        """Alias for FieldOfView"""
        return self.FieldOfView

    @fieldofview.setter
    def fieldofview(self, value):
        """Alias for FieldOfView.setter"""
        self.FieldOfView = value

    @property
    def field_of_view(self):
        """Alias for FieldOfView"""
        return self.FieldOfView

    @field_of_view.setter
    def field_of_view(self, value):
        """Alias for FieldOfView.setter"""
        self.FieldOfView = value

    @property
    def LightAngle(self):
        return self.com_object.LightAngle

    @LightAngle.setter
    def LightAngle(self, value):
        self.com_object.LightAngle = value

    @property
    def lightangle(self):
        """Alias for LightAngle"""
        return self.LightAngle

    @lightangle.setter
    def lightangle(self, value):
        """Alias for LightAngle.setter"""
        self.LightAngle = value

    @property
    def light_angle(self):
        """Alias for LightAngle"""
        return self.LightAngle

    @light_angle.setter
    def light_angle(self, value):
        """Alias for LightAngle.setter"""
        self.LightAngle = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Perspective(self):
        return self.com_object.Perspective

    @Perspective.setter
    def Perspective(self, value):
        self.com_object.Perspective = value

    @property
    def perspective(self):
        """Alias for Perspective"""
        return self.Perspective

    @perspective.setter
    def perspective(self, value):
        """Alias for Perspective.setter"""
        self.Perspective = value

    @property
    def PresetCamera(self):
        return self.com_object.PresetCamera

    @property
    def presetcamera(self):
        """Alias for PresetCamera"""
        return self.PresetCamera

    @property
    def preset_camera(self):
        """Alias for PresetCamera"""
        return self.PresetCamera

    @property
    def PresetExtrusionDirection(self):
        return self.com_object.PresetExtrusionDirection

    @PresetExtrusionDirection.setter
    def PresetExtrusionDirection(self, value):
        self.com_object.PresetExtrusionDirection = value

    @property
    def presetextrusiondirection(self):
        """Alias for PresetExtrusionDirection"""
        return self.PresetExtrusionDirection

    @presetextrusiondirection.setter
    def presetextrusiondirection(self, value):
        """Alias for PresetExtrusionDirection.setter"""
        self.PresetExtrusionDirection = value

    @property
    def preset_extrusion_direction(self):
        """Alias for PresetExtrusionDirection"""
        return self.PresetExtrusionDirection

    @preset_extrusion_direction.setter
    def preset_extrusion_direction(self, value):
        """Alias for PresetExtrusionDirection.setter"""
        self.PresetExtrusionDirection = value

    @property
    def PresetLighting(self):
        return self.com_object.PresetLighting

    @PresetLighting.setter
    def PresetLighting(self, value):
        self.com_object.PresetLighting = value

    @property
    def presetlighting(self):
        """Alias for PresetLighting"""
        return self.PresetLighting

    @presetlighting.setter
    def presetlighting(self, value):
        """Alias for PresetLighting.setter"""
        self.PresetLighting = value

    @property
    def preset_lighting(self):
        """Alias for PresetLighting"""
        return self.PresetLighting

    @preset_lighting.setter
    def preset_lighting(self, value):
        """Alias for PresetLighting.setter"""
        self.PresetLighting = value

    @property
    def PresetLightingDirection(self):
        return self.com_object.PresetLightingDirection

    @PresetLightingDirection.setter
    def PresetLightingDirection(self, value):
        self.com_object.PresetLightingDirection = value

    @property
    def presetlightingdirection(self):
        """Alias for PresetLightingDirection"""
        return self.PresetLightingDirection

    @presetlightingdirection.setter
    def presetlightingdirection(self, value):
        """Alias for PresetLightingDirection.setter"""
        self.PresetLightingDirection = value

    @property
    def preset_lighting_direction(self):
        """Alias for PresetLightingDirection"""
        return self.PresetLightingDirection

    @preset_lighting_direction.setter
    def preset_lighting_direction(self, value):
        """Alias for PresetLightingDirection.setter"""
        self.PresetLightingDirection = value

    @property
    def PresetLightingSoftness(self):
        return self.com_object.PresetLightingSoftness

    @PresetLightingSoftness.setter
    def PresetLightingSoftness(self, value):
        self.com_object.PresetLightingSoftness = value

    @property
    def presetlightingsoftness(self):
        """Alias for PresetLightingSoftness"""
        return self.PresetLightingSoftness

    @presetlightingsoftness.setter
    def presetlightingsoftness(self, value):
        """Alias for PresetLightingSoftness.setter"""
        self.PresetLightingSoftness = value

    @property
    def preset_lighting_softness(self):
        """Alias for PresetLightingSoftness"""
        return self.PresetLightingSoftness

    @preset_lighting_softness.setter
    def preset_lighting_softness(self, value):
        """Alias for PresetLightingSoftness.setter"""
        self.PresetLightingSoftness = value

    @property
    def PresetMaterial(self):
        return self.com_object.PresetMaterial

    @PresetMaterial.setter
    def PresetMaterial(self, value):
        self.com_object.PresetMaterial = value

    @property
    def presetmaterial(self):
        """Alias for PresetMaterial"""
        return self.PresetMaterial

    @presetmaterial.setter
    def presetmaterial(self, value):
        """Alias for PresetMaterial.setter"""
        self.PresetMaterial = value

    @property
    def preset_material(self):
        """Alias for PresetMaterial"""
        return self.PresetMaterial

    @preset_material.setter
    def preset_material(self, value):
        """Alias for PresetMaterial.setter"""
        self.PresetMaterial = value

    @property
    def PresetThreeDFormat(self):
        return self.com_object.PresetThreeDFormat

    @property
    def presetthreedformat(self):
        """Alias for PresetThreeDFormat"""
        return self.PresetThreeDFormat

    @property
    def preset_three_d_format(self):
        """Alias for PresetThreeDFormat"""
        return self.PresetThreeDFormat

    @property
    def ProjectText(self):
        return self.com_object.ProjectText

    @ProjectText.setter
    def ProjectText(self, value):
        self.com_object.ProjectText = value

    @property
    def projecttext(self):
        """Alias for ProjectText"""
        return self.ProjectText

    @projecttext.setter
    def projecttext(self, value):
        """Alias for ProjectText.setter"""
        self.ProjectText = value

    @property
    def project_text(self):
        """Alias for ProjectText"""
        return self.ProjectText

    @project_text.setter
    def project_text(self, value):
        """Alias for ProjectText.setter"""
        self.ProjectText = value

    @property
    def RotationX(self):
        return self.com_object.RotationX

    @RotationX.setter
    def RotationX(self, value):
        self.com_object.RotationX = value

    @property
    def rotationx(self):
        """Alias for RotationX"""
        return self.RotationX

    @rotationx.setter
    def rotationx(self, value):
        """Alias for RotationX.setter"""
        self.RotationX = value

    @property
    def rotation_x(self):
        """Alias for RotationX"""
        return self.RotationX

    @rotation_x.setter
    def rotation_x(self, value):
        """Alias for RotationX.setter"""
        self.RotationX = value

    @property
    def RotationY(self):
        return self.com_object.RotationY

    @RotationY.setter
    def RotationY(self, value):
        self.com_object.RotationY = value

    @property
    def rotationy(self):
        """Alias for RotationY"""
        return self.RotationY

    @rotationy.setter
    def rotationy(self, value):
        """Alias for RotationY.setter"""
        self.RotationY = value

    @property
    def rotation_y(self):
        """Alias for RotationY"""
        return self.RotationY

    @rotation_y.setter
    def rotation_y(self, value):
        """Alias for RotationY.setter"""
        self.RotationY = value

    @property
    def RotationZ(self):
        return self.com_object.RotationZ

    @RotationZ.setter
    def RotationZ(self, value):
        self.com_object.RotationZ = value

    @property
    def rotationz(self):
        """Alias for RotationZ"""
        return self.RotationZ

    @rotationz.setter
    def rotationz(self, value):
        """Alias for RotationZ.setter"""
        self.RotationZ = value

    @property
    def rotation_z(self):
        """Alias for RotationZ"""
        return self.RotationZ

    @rotation_z.setter
    def rotation_z(self, value):
        """Alias for RotationZ.setter"""
        self.RotationZ = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Z(self):
        return self.com_object.Z

    @Z.setter
    def Z(self, value):
        self.com_object.Z = value

    @property
    def z(self):
        """Alias for Z"""
        return self.Z

    @z.setter
    def z(self, value):
        """Alias for Z.setter"""
        self.Z = value

    def IncrementRotationHorizontal(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotationHorizontal(*arguments)

    def incrementrotationhorizontal(self, Increment=None):
        """Alias for IncrementRotationHorizontal"""
        arguments = [Increment]
        return self.IncrementRotationHorizontal(*arguments)

    def increment_rotation_horizontal(self, Increment=None):
        """Alias for IncrementRotationHorizontal"""
        arguments = [Increment]
        return self.IncrementRotationHorizontal(*arguments)

    def IncrementRotationVertical(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotationVertical(*arguments)

    def incrementrotationvertical(self, Increment=None):
        """Alias for IncrementRotationVertical"""
        arguments = [Increment]
        return self.IncrementRotationVertical(*arguments)

    def increment_rotation_vertical(self, Increment=None):
        """Alias for IncrementRotationVertical"""
        arguments = [Increment]
        return self.IncrementRotationVertical(*arguments)

    def IncrementRotationX(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotationX(*arguments)

    def incrementrotationx(self, Increment=None):
        """Alias for IncrementRotationX"""
        arguments = [Increment]
        return self.IncrementRotationX(*arguments)

    def increment_rotation_x(self, Increment=None):
        """Alias for IncrementRotationX"""
        arguments = [Increment]
        return self.IncrementRotationX(*arguments)

    def IncrementRotationY(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotationY(*arguments)

    def incrementrotationy(self, Increment=None):
        """Alias for IncrementRotationY"""
        arguments = [Increment]
        return self.IncrementRotationY(*arguments)

    def increment_rotation_y(self, Increment=None):
        """Alias for IncrementRotationY"""
        arguments = [Increment]
        return self.IncrementRotationY(*arguments)

    def IncrementRotationZ(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotationZ(*arguments)

    def incrementrotationz(self, Increment=None):
        """Alias for IncrementRotationZ"""
        arguments = [Increment]
        return self.IncrementRotationZ(*arguments)

    def increment_rotation_z(self, Increment=None):
        """Alias for IncrementRotationZ"""
        arguments = [Increment]
        return self.IncrementRotationZ(*arguments)

    def ResetRotation(self):
        self.com_object.ResetRotation()

    def resetrotation(self):
        """Alias for ResetRotation"""
        return self.ResetRotation()

    def reset_rotation(self):
        """Alias for ResetRotation"""
        return self.ResetRotation()

    def SetExtrusionDirection(self, PresetExtrusionDirection=None):
        arguments = com_arguments([unwrap(a) for a in [PresetExtrusionDirection]])
        self.com_object.SetExtrusionDirection(*arguments)

    def setextrusiondirection(self, PresetExtrusionDirection=None):
        """Alias for SetExtrusionDirection"""
        arguments = [PresetExtrusionDirection]
        return self.SetExtrusionDirection(*arguments)

    def set_extrusion_direction(self, PresetExtrusionDirection=None):
        """Alias for SetExtrusionDirection"""
        arguments = [PresetExtrusionDirection]
        return self.SetExtrusionDirection(*arguments)

    def SetPresetCamera(self, PresetCamera=None):
        arguments = com_arguments([unwrap(a) for a in [PresetCamera]])
        self.com_object.SetPresetCamera(*arguments)

    def setpresetcamera(self, PresetCamera=None):
        """Alias for SetPresetCamera"""
        arguments = [PresetCamera]
        return self.SetPresetCamera(*arguments)

    def set_preset_camera(self, PresetCamera=None):
        """Alias for SetPresetCamera"""
        arguments = [PresetCamera]
        return self.SetPresetCamera(*arguments)

    def SetThreeDFormat(self, PresetThreeDFormat=None):
        arguments = com_arguments([unwrap(a) for a in [PresetThreeDFormat]])
        self.com_object.SetThreeDFormat(*arguments)

    def setthreedformat(self, PresetThreeDFormat=None):
        """Alias for SetThreeDFormat"""
        arguments = [PresetThreeDFormat]
        return self.SetThreeDFormat(*arguments)

    def set_three_d_format(self, PresetThreeDFormat=None):
        """Alias for SetThreeDFormat"""
        arguments = [PresetThreeDFormat]
        return self.SetThreeDFormat(*arguments)


class TickLabels:

    def __init__(self, ticklabels=None):
        self.com_object= ticklabels

    @property
    def Alignment(self):
        return self.com_object.Alignment

    @Alignment.setter
    def Alignment(self, value):
        self.com_object.Alignment = value

    @property
    def alignment(self):
        """Alias for Alignment"""
        return self.Alignment

    @alignment.setter
    def alignment(self, value):
        """Alias for Alignment.setter"""
        self.Alignment = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Depth(self):
        return self.com_object.Depth

    @property
    def depth(self):
        """Alias for Depth"""
        return self.Depth

    @property
    def Font(self):
        return ChartFont(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def MultiLevel(self):
        return self.com_object.MultiLevel

    @MultiLevel.setter
    def MultiLevel(self, value):
        self.com_object.MultiLevel = value

    @property
    def multilevel(self):
        """Alias for MultiLevel"""
        return self.MultiLevel

    @multilevel.setter
    def multilevel(self, value):
        """Alias for MultiLevel.setter"""
        self.MultiLevel = value

    @property
    def multi_level(self):
        """Alias for MultiLevel"""
        return self.MultiLevel

    @multi_level.setter
    def multi_level(self, value):
        """Alias for MultiLevel.setter"""
        self.MultiLevel = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NumberFormat(self):
        return self.com_object.NumberFormat

    @NumberFormat.setter
    def NumberFormat(self, value):
        self.com_object.NumberFormat = value

    @property
    def numberformat(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @numberformat.setter
    def numberformat(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def number_format(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @number_format.setter
    def number_format(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def NumberFormatLinked(self):
        return self.com_object.NumberFormatLinked

    @NumberFormatLinked.setter
    def NumberFormatLinked(self, value):
        self.com_object.NumberFormatLinked = value

    @property
    def numberformatlinked(self):
        """Alias for NumberFormatLinked"""
        return self.NumberFormatLinked

    @numberformatlinked.setter
    def numberformatlinked(self, value):
        """Alias for NumberFormatLinked.setter"""
        self.NumberFormatLinked = value

    @property
    def number_format_linked(self):
        """Alias for NumberFormatLinked"""
        return self.NumberFormatLinked

    @number_format_linked.setter
    def number_format_linked(self, value):
        """Alias for NumberFormatLinked.setter"""
        self.NumberFormatLinked = value

    @property
    def NumberFormatLocal(self):
        return self.com_object.NumberFormatLocal

    @NumberFormatLocal.setter
    def NumberFormatLocal(self, value):
        self.com_object.NumberFormatLocal = value

    @property
    def numberformatlocal(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @numberformatlocal.setter
    def numberformatlocal(self, value):
        """Alias for NumberFormatLocal.setter"""
        self.NumberFormatLocal = value

    @property
    def number_format_local(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @number_format_local.setter
    def number_format_local(self, value):
        """Alias for NumberFormatLocal.setter"""
        self.NumberFormatLocal = value

    @property
    def Offset(self):
        return self.com_object.Offset

    @Offset.setter
    def Offset(self, value):
        self.com_object.Offset = value

    @property
    def offset(self):
        """Alias for Offset"""
        return self.Offset

    @offset.setter
    def offset(self, value):
        """Alias for Offset.setter"""
        self.Offset = value

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ReadingOrder(self):
        return XlReadingOrder(self.com_object.ReadingOrder)

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Trendline:

    def __init__(self, trendline=None):
        self.com_object= trendline

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Backward2(self):
        return self.com_object.Backward2

    @Backward2.setter
    def Backward2(self, value):
        self.com_object.Backward2 = value

    @property
    def backward2(self):
        """Alias for Backward2"""
        return self.Backward2

    @backward2.setter
    def backward2(self, value):
        """Alias for Backward2.setter"""
        self.Backward2 = value

    @property
    def Border(self):
        return ChartBorder(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DataLabel(self):
        return DataLabel(self.com_object.DataLabel)

    @property
    def datalabel(self):
        """Alias for DataLabel"""
        return self.DataLabel

    @property
    def data_label(self):
        """Alias for DataLabel"""
        return self.DataLabel

    @property
    def DisplayEquation(self):
        return self.com_object.DisplayEquation

    @DisplayEquation.setter
    def DisplayEquation(self, value):
        self.com_object.DisplayEquation = value

    @property
    def displayequation(self):
        """Alias for DisplayEquation"""
        return self.DisplayEquation

    @displayequation.setter
    def displayequation(self, value):
        """Alias for DisplayEquation.setter"""
        self.DisplayEquation = value

    @property
    def display_equation(self):
        """Alias for DisplayEquation"""
        return self.DisplayEquation

    @display_equation.setter
    def display_equation(self, value):
        """Alias for DisplayEquation.setter"""
        self.DisplayEquation = value

    @property
    def DisplayRSquared(self):
        return self.com_object.DisplayRSquared

    @DisplayRSquared.setter
    def DisplayRSquared(self, value):
        self.com_object.DisplayRSquared = value

    @property
    def displayrsquared(self):
        """Alias for DisplayRSquared"""
        return self.DisplayRSquared

    @displayrsquared.setter
    def displayrsquared(self, value):
        """Alias for DisplayRSquared.setter"""
        self.DisplayRSquared = value

    @property
    def display_r_squared(self):
        """Alias for DisplayRSquared"""
        return self.DisplayRSquared

    @display_r_squared.setter
    def display_r_squared(self, value):
        """Alias for DisplayRSquared.setter"""
        self.DisplayRSquared = value

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Forward2(self):
        return self.com_object.Forward2

    @Forward2.setter
    def Forward2(self, value):
        self.com_object.Forward2 = value

    @property
    def forward2(self):
        """Alias for Forward2"""
        return self.Forward2

    @forward2.setter
    def forward2(self, value):
        """Alias for Forward2.setter"""
        self.Forward2 = value

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Intercept(self):
        return self.com_object.Intercept

    @Intercept.setter
    def Intercept(self, value):
        self.com_object.Intercept = value

    @property
    def intercept(self):
        """Alias for Intercept"""
        return self.Intercept

    @intercept.setter
    def intercept(self, value):
        """Alias for Intercept.setter"""
        self.Intercept = value

    @property
    def InterceptIsAuto(self):
        return self.com_object.InterceptIsAuto

    @InterceptIsAuto.setter
    def InterceptIsAuto(self, value):
        self.com_object.InterceptIsAuto = value

    @property
    def interceptisauto(self):
        """Alias for InterceptIsAuto"""
        return self.InterceptIsAuto

    @interceptisauto.setter
    def interceptisauto(self, value):
        """Alias for InterceptIsAuto.setter"""
        self.InterceptIsAuto = value

    @property
    def intercept_is_auto(self):
        """Alias for InterceptIsAuto"""
        return self.InterceptIsAuto

    @intercept_is_auto.setter
    def intercept_is_auto(self, value):
        """Alias for InterceptIsAuto.setter"""
        self.InterceptIsAuto = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def NameIsAuto(self):
        return self.com_object.NameIsAuto

    @NameIsAuto.setter
    def NameIsAuto(self, value):
        self.com_object.NameIsAuto = value

    @property
    def nameisauto(self):
        """Alias for NameIsAuto"""
        return self.NameIsAuto

    @nameisauto.setter
    def nameisauto(self, value):
        """Alias for NameIsAuto.setter"""
        self.NameIsAuto = value

    @property
    def name_is_auto(self):
        """Alias for NameIsAuto"""
        return self.NameIsAuto

    @name_is_auto.setter
    def name_is_auto(self, value):
        """Alias for NameIsAuto.setter"""
        self.NameIsAuto = value

    @property
    def Order(self):
        return self.com_object.Order

    @Order.setter
    def Order(self, value):
        self.com_object.Order = value

    @property
    def order(self):
        """Alias for Order"""
        return self.Order

    @order.setter
    def order(self, value):
        """Alias for Order.setter"""
        self.Order = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Period(self):
        return self.com_object.Period

    @Period.setter
    def Period(self, value):
        self.com_object.Period = value

    @property
    def period(self):
        """Alias for Period"""
        return self.Period

    @period.setter
    def period(self, value):
        """Alias for Period.setter"""
        self.Period = value

    @property
    def Type(self):
        return XlTrendlineType(self.com_object.Type)

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    def ClearFormats(self):
        self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Trendlines:

    def __init__(self, trendlines=None):
        self.com_object= trendlines

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Type=None, Order=None, Period=None, Forward=None, Backward=None, Intercept=None, DisplayEquation=None, DisplayRSquared=None, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Order, Period, Forward, Backward, Intercept, DisplayEquation, DisplayRSquared, Name]])
        return Trendline(self.com_object.Add(*arguments))

    def add(self, Type=None, Order=None, Period=None, Forward=None, Backward=None, Intercept=None, DisplayEquation=None, DisplayRSquared=None, Name=None):
        """Alias for Add"""
        arguments = [Type, Order, Period, Forward, Backward, Intercept, DisplayEquation, DisplayRSquared, Name]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Trendline(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class TwoInitialCapsException:

    def __init__(self, twoinitialcapsexception=None):
        self.com_object= twoinitialcapsexception

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class TwoInitialCapsExceptions:

    def __init__(self, twoinitialcapsexceptions=None):
        self.com_object= twoinitialcapsexceptions

    def __call__(self, item):
        return TwoInitialCapsException(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        return TwoInitialCapsException(self.com_object.Add(*arguments))

    def add(self, Name=None):
        """Alias for Add"""
        arguments = [Name]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return TwoInitialCapsException(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class UndoRecord:

    def __init__(self, undorecord=None):
        self.com_object= undorecord

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def CustomRecordLevel(self):
        return self.com_object.CustomRecordLevel

    @property
    def customrecordlevel(self):
        """Alias for CustomRecordLevel"""
        return self.CustomRecordLevel

    @property
    def custom_record_level(self):
        """Alias for CustomRecordLevel"""
        return self.CustomRecordLevel

    @property
    def CustomRecordName(self):
        return self.com_object.CustomRecordName

    @property
    def customrecordname(self):
        """Alias for CustomRecordName"""
        return self.CustomRecordName

    @property
    def custom_record_name(self):
        """Alias for CustomRecordName"""
        return self.CustomRecordName

    @property
    def IsRecordingCustomRecord(self):
        return self.com_object.IsRecordingCustomRecord

    @property
    def isrecordingcustomrecord(self):
        """Alias for IsRecordingCustomRecord"""
        return self.IsRecordingCustomRecord

    @property
    def is_recording_custom_record(self):
        """Alias for IsRecordingCustomRecord"""
        return self.IsRecordingCustomRecord

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def EndCustomRecord(self):
        self.com_object.EndCustomRecord()

    def endcustomrecord(self):
        """Alias for EndCustomRecord"""
        return self.EndCustomRecord()

    def end_custom_record(self):
        """Alias for EndCustomRecord"""
        return self.EndCustomRecord()

    def StartCustomRecord(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        self.com_object.StartCustomRecord(*arguments)

    def startcustomrecord(self, Name=None):
        """Alias for StartCustomRecord"""
        arguments = [Name]
        return self.StartCustomRecord(*arguments)

    def start_custom_record(self, Name=None):
        """Alias for StartCustomRecord"""
        arguments = [Name]
        return self.StartCustomRecord(*arguments)


class UpBars:

    def __init__(self, upbars=None):
        self.com_object= upbars

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Border(self):
        return ChartBorder(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Fill(self):
        return FillFormat(self.com_object.Fill)

    @property
    def fill(self):
        """Alias for Fill"""
        return self.Fill

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Interior(self):
        return Interior(self.com_object.Interior)

    @property
    def interior(self):
        """Alias for Interior"""
        return self.Interior

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Variable:

    def __init__(self, variable=None):
        self.com_object= variable

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class Variables:

    def __init__(self, variables=None):
        self.com_object= variables

    def __call__(self, item):
        return Variable(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, Value=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Value]])
        return Variable(self.com_object.Add(*arguments))

    def add(self, Name=None, Value=None):
        """Alias for Add"""
        arguments = [Name, Value]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Variable(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Version:

    def __init__(self, version=None):
        self.com_object= version

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Comment(self):
        return self.com_object.Comment

    @property
    def comment(self):
        """Alias for Comment"""
        return self.Comment

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Date(self):
        return self.com_object.Date

    @property
    def date(self):
        """Alias for Date"""
        return self.Date

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SavedBy(self):
        return self.com_object.SavedBy

    @property
    def savedby(self):
        """Alias for SavedBy"""
        return self.SavedBy

    @property
    def saved_by(self):
        """Alias for SavedBy"""
        return self.SavedBy

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Open(self):
        return Document(self.com_object.Open())

    def open(self):
        """Alias for Open"""
        return self.Open()


class View:

    def __init__(self, view=None):
        self.com_object= view

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ColumnWidth(self):
        return self.com_object.ColumnWidth

    @ColumnWidth.setter
    def ColumnWidth(self, value):
        self.com_object.ColumnWidth = value

    @property
    def columnwidth(self):
        """Alias for ColumnWidth"""
        return self.ColumnWidth

    @columnwidth.setter
    def columnwidth(self, value):
        """Alias for ColumnWidth.setter"""
        self.ColumnWidth = value

    @property
    def column_width(self):
        """Alias for ColumnWidth"""
        return self.ColumnWidth

    @column_width.setter
    def column_width(self, value):
        """Alias for ColumnWidth.setter"""
        self.ColumnWidth = value

    @property
    def ConflictMode(self):
        return self.com_object.ConflictMode

    @ConflictMode.setter
    def ConflictMode(self, value):
        self.com_object.ConflictMode = value

    @property
    def conflictmode(self):
        """Alias for ConflictMode"""
        return self.ConflictMode

    @conflictmode.setter
    def conflictmode(self, value):
        """Alias for ConflictMode.setter"""
        self.ConflictMode = value

    @property
    def conflict_mode(self):
        """Alias for ConflictMode"""
        return self.ConflictMode

    @conflict_mode.setter
    def conflict_mode(self, value):
        """Alias for ConflictMode.setter"""
        self.ConflictMode = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DisplayBackgrounds(self):
        return self.com_object.DisplayBackgrounds

    @DisplayBackgrounds.setter
    def DisplayBackgrounds(self, value):
        self.com_object.DisplayBackgrounds = value

    @property
    def displaybackgrounds(self):
        """Alias for DisplayBackgrounds"""
        return self.DisplayBackgrounds

    @displaybackgrounds.setter
    def displaybackgrounds(self, value):
        """Alias for DisplayBackgrounds.setter"""
        self.DisplayBackgrounds = value

    @property
    def display_backgrounds(self):
        """Alias for DisplayBackgrounds"""
        return self.DisplayBackgrounds

    @display_backgrounds.setter
    def display_backgrounds(self, value):
        """Alias for DisplayBackgrounds.setter"""
        self.DisplayBackgrounds = value

    @property
    def DisplayPageBoundaries(self):
        return self.com_object.DisplayPageBoundaries

    @DisplayPageBoundaries.setter
    def DisplayPageBoundaries(self, value):
        self.com_object.DisplayPageBoundaries = value

    @property
    def displaypageboundaries(self):
        """Alias for DisplayPageBoundaries"""
        return self.DisplayPageBoundaries

    @displaypageboundaries.setter
    def displaypageboundaries(self, value):
        """Alias for DisplayPageBoundaries.setter"""
        self.DisplayPageBoundaries = value

    @property
    def display_page_boundaries(self):
        """Alias for DisplayPageBoundaries"""
        return self.DisplayPageBoundaries

    @display_page_boundaries.setter
    def display_page_boundaries(self, value):
        """Alias for DisplayPageBoundaries.setter"""
        self.DisplayPageBoundaries = value

    @property
    def Draft(self):
        return self.com_object.Draft

    @Draft.setter
    def Draft(self, value):
        self.com_object.Draft = value

    @property
    def draft(self):
        """Alias for Draft"""
        return self.Draft

    @draft.setter
    def draft(self, value):
        """Alias for Draft.setter"""
        self.Draft = value

    @property
    def FieldShading(self):
        return WdFieldShading(self.com_object.FieldShading)

    @FieldShading.setter
    def FieldShading(self, value):
        self.com_object.FieldShading = value

    @property
    def fieldshading(self):
        """Alias for FieldShading"""
        return self.FieldShading

    @fieldshading.setter
    def fieldshading(self, value):
        """Alias for FieldShading.setter"""
        self.FieldShading = value

    @property
    def field_shading(self):
        """Alias for FieldShading"""
        return self.FieldShading

    @field_shading.setter
    def field_shading(self, value):
        """Alias for FieldShading.setter"""
        self.FieldShading = value

    @property
    def FullScreen(self):
        return self.com_object.FullScreen

    @FullScreen.setter
    def FullScreen(self, value):
        self.com_object.FullScreen = value

    @property
    def fullscreen(self):
        """Alias for FullScreen"""
        return self.FullScreen

    @fullscreen.setter
    def fullscreen(self, value):
        """Alias for FullScreen.setter"""
        self.FullScreen = value

    @property
    def full_screen(self):
        """Alias for FullScreen"""
        return self.FullScreen

    @full_screen.setter
    def full_screen(self, value):
        """Alias for FullScreen.setter"""
        self.FullScreen = value

    @property
    def Magnifier(self):
        return self.com_object.Magnifier

    @Magnifier.setter
    def Magnifier(self, value):
        self.com_object.Magnifier = value

    @property
    def magnifier(self):
        """Alias for Magnifier"""
        return self.Magnifier

    @magnifier.setter
    def magnifier(self, value):
        """Alias for Magnifier.setter"""
        self.Magnifier = value

    @property
    def MailMergeDataView(self):
        return self.com_object.MailMergeDataView

    @MailMergeDataView.setter
    def MailMergeDataView(self, value):
        self.com_object.MailMergeDataView = value

    @property
    def mailmergedataview(self):
        """Alias for MailMergeDataView"""
        return self.MailMergeDataView

    @mailmergedataview.setter
    def mailmergedataview(self, value):
        """Alias for MailMergeDataView.setter"""
        self.MailMergeDataView = value

    @property
    def mail_merge_data_view(self):
        """Alias for MailMergeDataView"""
        return self.MailMergeDataView

    @mail_merge_data_view.setter
    def mail_merge_data_view(self, value):
        """Alias for MailMergeDataView.setter"""
        self.MailMergeDataView = value

    @property
    def MarkupMode(self):
        return WdRevisionsMode(self.com_object.MarkupMode)

    @MarkupMode.setter
    def MarkupMode(self, value):
        self.com_object.MarkupMode = value

    @property
    def markupmode(self):
        """Alias for MarkupMode"""
        return self.MarkupMode

    @markupmode.setter
    def markupmode(self, value):
        """Alias for MarkupMode.setter"""
        self.MarkupMode = value

    @property
    def markup_mode(self):
        """Alias for MarkupMode"""
        return self.MarkupMode

    @markup_mode.setter
    def markup_mode(self, value):
        """Alias for MarkupMode.setter"""
        self.MarkupMode = value

    @property
    def PageColor(self):
        return self.com_object.PageColor

    @PageColor.setter
    def PageColor(self, value):
        self.com_object.PageColor = value

    @property
    def pagecolor(self):
        """Alias for PageColor"""
        return self.PageColor

    @pagecolor.setter
    def pagecolor(self, value):
        """Alias for PageColor.setter"""
        self.PageColor = value

    @property
    def page_color(self):
        """Alias for PageColor"""
        return self.PageColor

    @page_color.setter
    def page_color(self, value):
        """Alias for PageColor.setter"""
        self.PageColor = value

    @property
    def PageMovementType(self):
        return WdPageMovementType(self.com_object.PageMovementType)

    @PageMovementType.setter
    def PageMovementType(self, value):
        self.com_object.PageMovementType = value

    @property
    def pagemovementtype(self):
        """Alias for PageMovementType"""
        return self.PageMovementType

    @pagemovementtype.setter
    def pagemovementtype(self, value):
        """Alias for PageMovementType.setter"""
        self.PageMovementType = value

    @property
    def page_movement_type(self):
        """Alias for PageMovementType"""
        return self.PageMovementType

    @page_movement_type.setter
    def page_movement_type(self, value):
        """Alias for PageMovementType.setter"""
        self.PageMovementType = value

    @property
    def Panning(self):
        return self.com_object.Panning

    @Panning.setter
    def Panning(self, value):
        self.com_object.Panning = value

    @property
    def panning(self):
        """Alias for Panning"""
        return self.Panning

    @panning.setter
    def panning(self, value):
        """Alias for Panning.setter"""
        self.Panning = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ReadingLayout(self):
        return self.com_object.ReadingLayout

    @property
    def readinglayout(self):
        """Alias for ReadingLayout"""
        return self.ReadingLayout

    @property
    def reading_layout(self):
        """Alias for ReadingLayout"""
        return self.ReadingLayout

    @property
    def ReadingLayoutActualView(self):
        return self.com_object.ReadingLayoutActualView

    @property
    def readinglayoutactualview(self):
        """Alias for ReadingLayoutActualView"""
        return self.ReadingLayoutActualView

    @property
    def reading_layout_actual_view(self):
        """Alias for ReadingLayoutActualView"""
        return self.ReadingLayoutActualView

    @property
    def ReadingLayoutTruncateMargins(self):
        return WdReadingLayoutMargin(self.com_object.ReadingLayoutTruncateMargins)

    @ReadingLayoutTruncateMargins.setter
    def ReadingLayoutTruncateMargins(self, value):
        self.com_object.ReadingLayoutTruncateMargins = value

    @property
    def readinglayouttruncatemargins(self):
        """Alias for ReadingLayoutTruncateMargins"""
        return self.ReadingLayoutTruncateMargins

    @readinglayouttruncatemargins.setter
    def readinglayouttruncatemargins(self, value):
        """Alias for ReadingLayoutTruncateMargins.setter"""
        self.ReadingLayoutTruncateMargins = value

    @property
    def reading_layout_truncate_margins(self):
        """Alias for ReadingLayoutTruncateMargins"""
        return self.ReadingLayoutTruncateMargins

    @reading_layout_truncate_margins.setter
    def reading_layout_truncate_margins(self, value):
        """Alias for ReadingLayoutTruncateMargins.setter"""
        self.ReadingLayoutTruncateMargins = value

    @property
    def RevisionsBalloonShowConnectingLines(self):
        return self.com_object.RevisionsBalloonShowConnectingLines

    @RevisionsBalloonShowConnectingLines.setter
    def RevisionsBalloonShowConnectingLines(self, value):
        self.com_object.RevisionsBalloonShowConnectingLines = value

    @property
    def revisionsballoonshowconnectinglines(self):
        """Alias for RevisionsBalloonShowConnectingLines"""
        return self.RevisionsBalloonShowConnectingLines

    @revisionsballoonshowconnectinglines.setter
    def revisionsballoonshowconnectinglines(self, value):
        """Alias for RevisionsBalloonShowConnectingLines.setter"""
        self.RevisionsBalloonShowConnectingLines = value

    @property
    def revisions_balloon_show_connecting_lines(self):
        """Alias for RevisionsBalloonShowConnectingLines"""
        return self.RevisionsBalloonShowConnectingLines

    @revisions_balloon_show_connecting_lines.setter
    def revisions_balloon_show_connecting_lines(self, value):
        """Alias for RevisionsBalloonShowConnectingLines.setter"""
        self.RevisionsBalloonShowConnectingLines = value

    @property
    def RevisionsBalloonSide(self):
        return self.com_object.RevisionsBalloonSide

    @property
    def revisionsballoonside(self):
        """Alias for RevisionsBalloonSide"""
        return self.RevisionsBalloonSide

    @property
    def revisions_balloon_side(self):
        """Alias for RevisionsBalloonSide"""
        return self.RevisionsBalloonSide

    @property
    def RevisionsBalloonWidth(self):
        return self.com_object.RevisionsBalloonWidth

    @RevisionsBalloonWidth.setter
    def RevisionsBalloonWidth(self, value):
        self.com_object.RevisionsBalloonWidth = value

    @property
    def revisionsballoonwidth(self):
        """Alias for RevisionsBalloonWidth"""
        return self.RevisionsBalloonWidth

    @revisionsballoonwidth.setter
    def revisionsballoonwidth(self, value):
        """Alias for RevisionsBalloonWidth.setter"""
        self.RevisionsBalloonWidth = value

    @property
    def revisions_balloon_width(self):
        """Alias for RevisionsBalloonWidth"""
        return self.RevisionsBalloonWidth

    @revisions_balloon_width.setter
    def revisions_balloon_width(self, value):
        """Alias for RevisionsBalloonWidth.setter"""
        self.RevisionsBalloonWidth = value

    @property
    def RevisionsBalloonWidthType(self):
        return self.com_object.RevisionsBalloonWidthType

    @RevisionsBalloonWidthType.setter
    def RevisionsBalloonWidthType(self, value):
        self.com_object.RevisionsBalloonWidthType = value

    @property
    def revisionsballoonwidthtype(self):
        """Alias for RevisionsBalloonWidthType"""
        return self.RevisionsBalloonWidthType

    @revisionsballoonwidthtype.setter
    def revisionsballoonwidthtype(self, value):
        """Alias for RevisionsBalloonWidthType.setter"""
        self.RevisionsBalloonWidthType = value

    @property
    def revisions_balloon_width_type(self):
        """Alias for RevisionsBalloonWidthType"""
        return self.RevisionsBalloonWidthType

    @revisions_balloon_width_type.setter
    def revisions_balloon_width_type(self, value):
        """Alias for RevisionsBalloonWidthType.setter"""
        self.RevisionsBalloonWidthType = value

    @property
    def RevisionsFilter(self):
        return RevisionsFilter(self.com_object.RevisionsFilter)

    @property
    def revisionsfilter(self):
        """Alias for RevisionsFilter"""
        return self.RevisionsFilter

    @property
    def revisions_filter(self):
        """Alias for RevisionsFilter"""
        return self.RevisionsFilter

    @property
    def SeekView(self):
        return WdSeekView(self.com_object.SeekView)

    @SeekView.setter
    def SeekView(self, value):
        self.com_object.SeekView = value

    @property
    def seekview(self):
        """Alias for SeekView"""
        return self.SeekView

    @seekview.setter
    def seekview(self, value):
        """Alias for SeekView.setter"""
        self.SeekView = value

    @property
    def seek_view(self):
        """Alias for SeekView"""
        return self.SeekView

    @seek_view.setter
    def seek_view(self, value):
        """Alias for SeekView.setter"""
        self.SeekView = value

    @property
    def ShadeEditableRanges(self):
        return self.com_object.ShadeEditableRanges

    @ShadeEditableRanges.setter
    def ShadeEditableRanges(self, value):
        self.com_object.ShadeEditableRanges = value

    @property
    def shadeeditableranges(self):
        """Alias for ShadeEditableRanges"""
        return self.ShadeEditableRanges

    @shadeeditableranges.setter
    def shadeeditableranges(self, value):
        """Alias for ShadeEditableRanges.setter"""
        self.ShadeEditableRanges = value

    @property
    def shade_editable_ranges(self):
        """Alias for ShadeEditableRanges"""
        return self.ShadeEditableRanges

    @shade_editable_ranges.setter
    def shade_editable_ranges(self, value):
        """Alias for ShadeEditableRanges.setter"""
        self.ShadeEditableRanges = value

    @property
    def ShowAll(self):
        return self.com_object.ShowAll

    @ShowAll.setter
    def ShowAll(self, value):
        self.com_object.ShowAll = value

    @property
    def showall(self):
        """Alias for ShowAll"""
        return self.ShowAll

    @showall.setter
    def showall(self, value):
        """Alias for ShowAll.setter"""
        self.ShowAll = value

    @property
    def show_all(self):
        """Alias for ShowAll"""
        return self.ShowAll

    @show_all.setter
    def show_all(self, value):
        """Alias for ShowAll.setter"""
        self.ShowAll = value

    @property
    def ShowBookmarks(self):
        return self.com_object.ShowBookmarks

    @ShowBookmarks.setter
    def ShowBookmarks(self, value):
        self.com_object.ShowBookmarks = value

    @property
    def showbookmarks(self):
        """Alias for ShowBookmarks"""
        return self.ShowBookmarks

    @showbookmarks.setter
    def showbookmarks(self, value):
        """Alias for ShowBookmarks.setter"""
        self.ShowBookmarks = value

    @property
    def show_bookmarks(self):
        """Alias for ShowBookmarks"""
        return self.ShowBookmarks

    @show_bookmarks.setter
    def show_bookmarks(self, value):
        """Alias for ShowBookmarks.setter"""
        self.ShowBookmarks = value

    @property
    def ShowComments(self):
        return self.com_object.ShowComments

    @ShowComments.setter
    def ShowComments(self, value):
        self.com_object.ShowComments = value

    @property
    def showcomments(self):
        """Alias for ShowComments"""
        return self.ShowComments

    @showcomments.setter
    def showcomments(self, value):
        """Alias for ShowComments.setter"""
        self.ShowComments = value

    @property
    def show_comments(self):
        """Alias for ShowComments"""
        return self.ShowComments

    @show_comments.setter
    def show_comments(self, value):
        """Alias for ShowComments.setter"""
        self.ShowComments = value

    @property
    def ShowCropMarks(self):
        return self.com_object.ShowCropMarks

    @ShowCropMarks.setter
    def ShowCropMarks(self, value):
        self.com_object.ShowCropMarks = value

    @property
    def showcropmarks(self):
        """Alias for ShowCropMarks"""
        return self.ShowCropMarks

    @showcropmarks.setter
    def showcropmarks(self, value):
        """Alias for ShowCropMarks.setter"""
        self.ShowCropMarks = value

    @property
    def show_crop_marks(self):
        """Alias for ShowCropMarks"""
        return self.ShowCropMarks

    @show_crop_marks.setter
    def show_crop_marks(self, value):
        """Alias for ShowCropMarks.setter"""
        self.ShowCropMarks = value

    @property
    def ShowDrawings(self):
        return self.com_object.ShowDrawings

    @ShowDrawings.setter
    def ShowDrawings(self, value):
        self.com_object.ShowDrawings = value

    @property
    def showdrawings(self):
        """Alias for ShowDrawings"""
        return self.ShowDrawings

    @showdrawings.setter
    def showdrawings(self, value):
        """Alias for ShowDrawings.setter"""
        self.ShowDrawings = value

    @property
    def show_drawings(self):
        """Alias for ShowDrawings"""
        return self.ShowDrawings

    @show_drawings.setter
    def show_drawings(self, value):
        """Alias for ShowDrawings.setter"""
        self.ShowDrawings = value

    @property
    def ShowFieldCodes(self):
        return self.com_object.ShowFieldCodes

    @ShowFieldCodes.setter
    def ShowFieldCodes(self, value):
        self.com_object.ShowFieldCodes = value

    @property
    def showfieldcodes(self):
        """Alias for ShowFieldCodes"""
        return self.ShowFieldCodes

    @showfieldcodes.setter
    def showfieldcodes(self, value):
        """Alias for ShowFieldCodes.setter"""
        self.ShowFieldCodes = value

    @property
    def show_field_codes(self):
        """Alias for ShowFieldCodes"""
        return self.ShowFieldCodes

    @show_field_codes.setter
    def show_field_codes(self, value):
        """Alias for ShowFieldCodes.setter"""
        self.ShowFieldCodes = value

    @property
    def ShowFirstLineOnly(self):
        return self.com_object.ShowFirstLineOnly

    @ShowFirstLineOnly.setter
    def ShowFirstLineOnly(self, value):
        self.com_object.ShowFirstLineOnly = value

    @property
    def showfirstlineonly(self):
        """Alias for ShowFirstLineOnly"""
        return self.ShowFirstLineOnly

    @showfirstlineonly.setter
    def showfirstlineonly(self, value):
        """Alias for ShowFirstLineOnly.setter"""
        self.ShowFirstLineOnly = value

    @property
    def show_first_line_only(self):
        """Alias for ShowFirstLineOnly"""
        return self.ShowFirstLineOnly

    @show_first_line_only.setter
    def show_first_line_only(self, value):
        """Alias for ShowFirstLineOnly.setter"""
        self.ShowFirstLineOnly = value

    @property
    def ShowFormat(self):
        return self.com_object.ShowFormat

    @ShowFormat.setter
    def ShowFormat(self, value):
        self.com_object.ShowFormat = value

    @property
    def showformat(self):
        """Alias for ShowFormat"""
        return self.ShowFormat

    @showformat.setter
    def showformat(self, value):
        """Alias for ShowFormat.setter"""
        self.ShowFormat = value

    @property
    def show_format(self):
        """Alias for ShowFormat"""
        return self.ShowFormat

    @show_format.setter
    def show_format(self, value):
        """Alias for ShowFormat.setter"""
        self.ShowFormat = value

    @property
    def ShowFormatChanges(self):
        return self.com_object.ShowFormatChanges

    @ShowFormatChanges.setter
    def ShowFormatChanges(self, value):
        self.com_object.ShowFormatChanges = value

    @property
    def showformatchanges(self):
        """Alias for ShowFormatChanges"""
        return self.ShowFormatChanges

    @showformatchanges.setter
    def showformatchanges(self, value):
        """Alias for ShowFormatChanges.setter"""
        self.ShowFormatChanges = value

    @property
    def show_format_changes(self):
        """Alias for ShowFormatChanges"""
        return self.ShowFormatChanges

    @show_format_changes.setter
    def show_format_changes(self, value):
        """Alias for ShowFormatChanges.setter"""
        self.ShowFormatChanges = value

    @property
    def ShowHiddenText(self):
        return self.com_object.ShowHiddenText

    @ShowHiddenText.setter
    def ShowHiddenText(self, value):
        self.com_object.ShowHiddenText = value

    @property
    def showhiddentext(self):
        """Alias for ShowHiddenText"""
        return self.ShowHiddenText

    @showhiddentext.setter
    def showhiddentext(self, value):
        """Alias for ShowHiddenText.setter"""
        self.ShowHiddenText = value

    @property
    def show_hidden_text(self):
        """Alias for ShowHiddenText"""
        return self.ShowHiddenText

    @show_hidden_text.setter
    def show_hidden_text(self, value):
        """Alias for ShowHiddenText.setter"""
        self.ShowHiddenText = value

    @property
    def ShowHighlight(self):
        return self.com_object.ShowHighlight

    @ShowHighlight.setter
    def ShowHighlight(self, value):
        self.com_object.ShowHighlight = value

    @property
    def showhighlight(self):
        """Alias for ShowHighlight"""
        return self.ShowHighlight

    @showhighlight.setter
    def showhighlight(self, value):
        """Alias for ShowHighlight.setter"""
        self.ShowHighlight = value

    @property
    def show_highlight(self):
        """Alias for ShowHighlight"""
        return self.ShowHighlight

    @show_highlight.setter
    def show_highlight(self, value):
        """Alias for ShowHighlight.setter"""
        self.ShowHighlight = value

    @property
    def ShowHyphens(self):
        return self.com_object.ShowHyphens

    @ShowHyphens.setter
    def ShowHyphens(self, value):
        self.com_object.ShowHyphens = value

    @property
    def showhyphens(self):
        """Alias for ShowHyphens"""
        return self.ShowHyphens

    @showhyphens.setter
    def showhyphens(self, value):
        """Alias for ShowHyphens.setter"""
        self.ShowHyphens = value

    @property
    def show_hyphens(self):
        """Alias for ShowHyphens"""
        return self.ShowHyphens

    @show_hyphens.setter
    def show_hyphens(self, value):
        """Alias for ShowHyphens.setter"""
        self.ShowHyphens = value

    @property
    def ShowInkAnnotations(self):
        return self.com_object.ShowInkAnnotations

    @ShowInkAnnotations.setter
    def ShowInkAnnotations(self, value):
        self.com_object.ShowInkAnnotations = value

    @property
    def showinkannotations(self):
        """Alias for ShowInkAnnotations"""
        return self.ShowInkAnnotations

    @showinkannotations.setter
    def showinkannotations(self, value):
        """Alias for ShowInkAnnotations.setter"""
        self.ShowInkAnnotations = value

    @property
    def show_ink_annotations(self):
        """Alias for ShowInkAnnotations"""
        return self.ShowInkAnnotations

    @show_ink_annotations.setter
    def show_ink_annotations(self, value):
        """Alias for ShowInkAnnotations.setter"""
        self.ShowInkAnnotations = value

    @property
    def ShowInsertionsAndDeletions(self):
        return self.com_object.ShowInsertionsAndDeletions

    @ShowInsertionsAndDeletions.setter
    def ShowInsertionsAndDeletions(self, value):
        self.com_object.ShowInsertionsAndDeletions = value

    @property
    def showinsertionsanddeletions(self):
        """Alias for ShowInsertionsAndDeletions"""
        return self.ShowInsertionsAndDeletions

    @showinsertionsanddeletions.setter
    def showinsertionsanddeletions(self, value):
        """Alias for ShowInsertionsAndDeletions.setter"""
        self.ShowInsertionsAndDeletions = value

    @property
    def show_insertions_and_deletions(self):
        """Alias for ShowInsertionsAndDeletions"""
        return self.ShowInsertionsAndDeletions

    @show_insertions_and_deletions.setter
    def show_insertions_and_deletions(self, value):
        """Alias for ShowInsertionsAndDeletions.setter"""
        self.ShowInsertionsAndDeletions = value

    @property
    def ShowMainTextLayer(self):
        return self.com_object.ShowMainTextLayer

    @ShowMainTextLayer.setter
    def ShowMainTextLayer(self, value):
        self.com_object.ShowMainTextLayer = value

    @property
    def showmaintextlayer(self):
        """Alias for ShowMainTextLayer"""
        return self.ShowMainTextLayer

    @showmaintextlayer.setter
    def showmaintextlayer(self, value):
        """Alias for ShowMainTextLayer.setter"""
        self.ShowMainTextLayer = value

    @property
    def show_main_text_layer(self):
        """Alias for ShowMainTextLayer"""
        return self.ShowMainTextLayer

    @show_main_text_layer.setter
    def show_main_text_layer(self, value):
        """Alias for ShowMainTextLayer.setter"""
        self.ShowMainTextLayer = value

    @property
    def ShowMarkupAreaHighlight(self):
        return self.com_object.ShowMarkupAreaHighlight

    @ShowMarkupAreaHighlight.setter
    def ShowMarkupAreaHighlight(self, value):
        self.com_object.ShowMarkupAreaHighlight = value

    @property
    def showmarkupareahighlight(self):
        """Alias for ShowMarkupAreaHighlight"""
        return self.ShowMarkupAreaHighlight

    @showmarkupareahighlight.setter
    def showmarkupareahighlight(self, value):
        """Alias for ShowMarkupAreaHighlight.setter"""
        self.ShowMarkupAreaHighlight = value

    @property
    def show_markup_area_highlight(self):
        """Alias for ShowMarkupAreaHighlight"""
        return self.ShowMarkupAreaHighlight

    @show_markup_area_highlight.setter
    def show_markup_area_highlight(self, value):
        """Alias for ShowMarkupAreaHighlight.setter"""
        self.ShowMarkupAreaHighlight = value

    @property
    def ShowObjectAnchors(self):
        return self.com_object.ShowObjectAnchors

    @ShowObjectAnchors.setter
    def ShowObjectAnchors(self, value):
        self.com_object.ShowObjectAnchors = value

    @property
    def showobjectanchors(self):
        """Alias for ShowObjectAnchors"""
        return self.ShowObjectAnchors

    @showobjectanchors.setter
    def showobjectanchors(self, value):
        """Alias for ShowObjectAnchors.setter"""
        self.ShowObjectAnchors = value

    @property
    def show_object_anchors(self):
        """Alias for ShowObjectAnchors"""
        return self.ShowObjectAnchors

    @show_object_anchors.setter
    def show_object_anchors(self, value):
        """Alias for ShowObjectAnchors.setter"""
        self.ShowObjectAnchors = value

    @property
    def ShowOptionalBreaks(self):
        return self.com_object.ShowOptionalBreaks

    @ShowOptionalBreaks.setter
    def ShowOptionalBreaks(self, value):
        self.com_object.ShowOptionalBreaks = value

    @property
    def showoptionalbreaks(self):
        """Alias for ShowOptionalBreaks"""
        return self.ShowOptionalBreaks

    @showoptionalbreaks.setter
    def showoptionalbreaks(self, value):
        """Alias for ShowOptionalBreaks.setter"""
        self.ShowOptionalBreaks = value

    @property
    def show_optional_breaks(self):
        """Alias for ShowOptionalBreaks"""
        return self.ShowOptionalBreaks

    @show_optional_breaks.setter
    def show_optional_breaks(self, value):
        """Alias for ShowOptionalBreaks.setter"""
        self.ShowOptionalBreaks = value

    @property
    def ShowOtherAuthors(self):
        return self.com_object.ShowOtherAuthors

    @ShowOtherAuthors.setter
    def ShowOtherAuthors(self, value):
        self.com_object.ShowOtherAuthors = value

    @property
    def showotherauthors(self):
        """Alias for ShowOtherAuthors"""
        return self.ShowOtherAuthors

    @showotherauthors.setter
    def showotherauthors(self, value):
        """Alias for ShowOtherAuthors.setter"""
        self.ShowOtherAuthors = value

    @property
    def show_other_authors(self):
        """Alias for ShowOtherAuthors"""
        return self.ShowOtherAuthors

    @show_other_authors.setter
    def show_other_authors(self, value):
        """Alias for ShowOtherAuthors.setter"""
        self.ShowOtherAuthors = value

    @property
    def ShowParagraphs(self):
        return self.com_object.ShowParagraphs

    @ShowParagraphs.setter
    def ShowParagraphs(self, value):
        self.com_object.ShowParagraphs = value

    @property
    def showparagraphs(self):
        """Alias for ShowParagraphs"""
        return self.ShowParagraphs

    @showparagraphs.setter
    def showparagraphs(self, value):
        """Alias for ShowParagraphs.setter"""
        self.ShowParagraphs = value

    @property
    def show_paragraphs(self):
        """Alias for ShowParagraphs"""
        return self.ShowParagraphs

    @show_paragraphs.setter
    def show_paragraphs(self, value):
        """Alias for ShowParagraphs.setter"""
        self.ShowParagraphs = value

    @property
    def ShowPicturePlaceHolders(self):
        return self.com_object.ShowPicturePlaceHolders

    @ShowPicturePlaceHolders.setter
    def ShowPicturePlaceHolders(self, value):
        self.com_object.ShowPicturePlaceHolders = value

    @property
    def showpictureplaceholders(self):
        """Alias for ShowPicturePlaceHolders"""
        return self.ShowPicturePlaceHolders

    @showpictureplaceholders.setter
    def showpictureplaceholders(self, value):
        """Alias for ShowPicturePlaceHolders.setter"""
        self.ShowPicturePlaceHolders = value

    @property
    def show_picture_place_holders(self):
        """Alias for ShowPicturePlaceHolders"""
        return self.ShowPicturePlaceHolders

    @show_picture_place_holders.setter
    def show_picture_place_holders(self, value):
        """Alias for ShowPicturePlaceHolders.setter"""
        self.ShowPicturePlaceHolders = value

    @property
    def ShowRevisionsAndComments(self):
        return self.com_object.ShowRevisionsAndComments

    @ShowRevisionsAndComments.setter
    def ShowRevisionsAndComments(self, value):
        self.com_object.ShowRevisionsAndComments = value

    @property
    def showrevisionsandcomments(self):
        """Alias for ShowRevisionsAndComments"""
        return self.ShowRevisionsAndComments

    @showrevisionsandcomments.setter
    def showrevisionsandcomments(self, value):
        """Alias for ShowRevisionsAndComments.setter"""
        self.ShowRevisionsAndComments = value

    @property
    def show_revisions_and_comments(self):
        """Alias for ShowRevisionsAndComments"""
        return self.ShowRevisionsAndComments

    @show_revisions_and_comments.setter
    def show_revisions_and_comments(self, value):
        """Alias for ShowRevisionsAndComments.setter"""
        self.ShowRevisionsAndComments = value

    @property
    def ShowSpaces(self):
        return self.com_object.ShowSpaces

    @ShowSpaces.setter
    def ShowSpaces(self, value):
        self.com_object.ShowSpaces = value

    @property
    def showspaces(self):
        """Alias for ShowSpaces"""
        return self.ShowSpaces

    @showspaces.setter
    def showspaces(self, value):
        """Alias for ShowSpaces.setter"""
        self.ShowSpaces = value

    @property
    def show_spaces(self):
        """Alias for ShowSpaces"""
        return self.ShowSpaces

    @show_spaces.setter
    def show_spaces(self, value):
        """Alias for ShowSpaces.setter"""
        self.ShowSpaces = value

    @property
    def ShowTabs(self):
        return self.com_object.ShowTabs

    @ShowTabs.setter
    def ShowTabs(self, value):
        self.com_object.ShowTabs = value

    @property
    def showtabs(self):
        """Alias for ShowTabs"""
        return self.ShowTabs

    @showtabs.setter
    def showtabs(self, value):
        """Alias for ShowTabs.setter"""
        self.ShowTabs = value

    @property
    def show_tabs(self):
        """Alias for ShowTabs"""
        return self.ShowTabs

    @show_tabs.setter
    def show_tabs(self, value):
        """Alias for ShowTabs.setter"""
        self.ShowTabs = value

    @property
    def ShowTextBoundaries(self):
        return self.com_object.ShowTextBoundaries

    @ShowTextBoundaries.setter
    def ShowTextBoundaries(self, value):
        self.com_object.ShowTextBoundaries = value

    @property
    def showtextboundaries(self):
        """Alias for ShowTextBoundaries"""
        return self.ShowTextBoundaries

    @showtextboundaries.setter
    def showtextboundaries(self, value):
        """Alias for ShowTextBoundaries.setter"""
        self.ShowTextBoundaries = value

    @property
    def show_text_boundaries(self):
        """Alias for ShowTextBoundaries"""
        return self.ShowTextBoundaries

    @show_text_boundaries.setter
    def show_text_boundaries(self, value):
        """Alias for ShowTextBoundaries.setter"""
        self.ShowTextBoundaries = value

    @property
    def ShowXMLMarkup(self):
        return self.com_object.ShowXMLMarkup

    @property
    def showxmlmarkup(self):
        """Alias for ShowXMLMarkup"""
        return self.ShowXMLMarkup

    @property
    def show_x_m_l_markup(self):
        """Alias for ShowXMLMarkup"""
        return self.ShowXMLMarkup

    @property
    def SplitSpecial(self):
        return WdSpecialPane(self.com_object.SplitSpecial)

    @SplitSpecial.setter
    def SplitSpecial(self, value):
        self.com_object.SplitSpecial = value

    @property
    def splitspecial(self):
        """Alias for SplitSpecial"""
        return self.SplitSpecial

    @splitspecial.setter
    def splitspecial(self, value):
        """Alias for SplitSpecial.setter"""
        self.SplitSpecial = value

    @property
    def split_special(self):
        """Alias for SplitSpecial"""
        return self.SplitSpecial

    @split_special.setter
    def split_special(self, value):
        """Alias for SplitSpecial.setter"""
        self.SplitSpecial = value

    @property
    def TableGridlines(self):
        return self.com_object.TableGridlines

    @TableGridlines.setter
    def TableGridlines(self, value):
        self.com_object.TableGridlines = value

    @property
    def tablegridlines(self):
        """Alias for TableGridlines"""
        return self.TableGridlines

    @tablegridlines.setter
    def tablegridlines(self, value):
        """Alias for TableGridlines.setter"""
        self.TableGridlines = value

    @property
    def table_gridlines(self):
        """Alias for TableGridlines"""
        return self.TableGridlines

    @table_gridlines.setter
    def table_gridlines(self, value):
        """Alias for TableGridlines.setter"""
        self.TableGridlines = value

    @property
    def Type(self):
        return WdViewType(self.com_object.Type)

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    @property
    def WrapToWindow(self):
        return self.com_object.WrapToWindow

    @WrapToWindow.setter
    def WrapToWindow(self, value):
        self.com_object.WrapToWindow = value

    @property
    def wraptowindow(self):
        """Alias for WrapToWindow"""
        return self.WrapToWindow

    @wraptowindow.setter
    def wraptowindow(self, value):
        """Alias for WrapToWindow.setter"""
        self.WrapToWindow = value

    @property
    def wrap_to_window(self):
        """Alias for WrapToWindow"""
        return self.WrapToWindow

    @wrap_to_window.setter
    def wrap_to_window(self, value):
        """Alias for WrapToWindow.setter"""
        self.WrapToWindow = value

    @property
    def Zoom(self):
        return Zoom(self.com_object.Zoom)

    @property
    def zoom(self):
        """Alias for Zoom"""
        return self.Zoom

    def CollapseAllHeadings(self):
        return self.com_object.CollapseAllHeadings()

    def collapseallheadings(self):
        """Alias for CollapseAllHeadings"""
        return self.CollapseAllHeadings()

    def collapse_all_headings(self):
        """Alias for CollapseAllHeadings"""
        return self.CollapseAllHeadings()

    def CollapseOutline(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        self.com_object.CollapseOutline(*arguments)

    def collapseoutline(self, Range=None):
        """Alias for CollapseOutline"""
        arguments = [Range]
        return self.CollapseOutline(*arguments)

    def collapse_outline(self, Range=None):
        """Alias for CollapseOutline"""
        arguments = [Range]
        return self.CollapseOutline(*arguments)

    def ExpandAllHeadings(self):
        return self.com_object.ExpandAllHeadings()

    def expandallheadings(self):
        """Alias for ExpandAllHeadings"""
        return self.ExpandAllHeadings()

    def expand_all_headings(self):
        """Alias for ExpandAllHeadings"""
        return self.ExpandAllHeadings()

    def ExpandOutline(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        self.com_object.ExpandOutline(*arguments)

    def expandoutline(self, Range=None):
        """Alias for ExpandOutline"""
        arguments = [Range]
        return self.ExpandOutline(*arguments)

    def expand_outline(self, Range=None):
        """Alias for ExpandOutline"""
        arguments = [Range]
        return self.ExpandOutline(*arguments)

    def NextHeaderFooter(self):
        self.com_object.NextHeaderFooter()

    def nextheaderfooter(self):
        """Alias for NextHeaderFooter"""
        return self.NextHeaderFooter()

    def next_header_footer(self):
        """Alias for NextHeaderFooter"""
        return self.NextHeaderFooter()

    def PreviousHeaderFooter(self):
        self.com_object.PreviousHeaderFooter()

    def previousheaderfooter(self):
        """Alias for PreviousHeaderFooter"""
        return self.PreviousHeaderFooter()

    def previous_header_footer(self):
        """Alias for PreviousHeaderFooter"""
        return self.PreviousHeaderFooter()

    def ShowAllHeadings(self):
        self.com_object.ShowAllHeadings()

    def showallheadings(self):
        """Alias for ShowAllHeadings"""
        return self.ShowAllHeadings()

    def show_all_headings(self):
        """Alias for ShowAllHeadings"""
        return self.ShowAllHeadings()

    def ShowHeading(self, Level=None):
        arguments = com_arguments([unwrap(a) for a in [Level]])
        self.com_object.ShowHeading(*arguments)

    def showheading(self, Level=None):
        """Alias for ShowHeading"""
        arguments = [Level]
        return self.ShowHeading(*arguments)

    def show_heading(self, Level=None):
        """Alias for ShowHeading"""
        arguments = [Level]
        return self.ShowHeading(*arguments)


class Walls:

    def __init__(self, walls=None):
        self.com_object= walls

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PictureType(self):
        return self.com_object.PictureType

    @PictureType.setter
    def PictureType(self, value):
        self.com_object.PictureType = value

    @property
    def picturetype(self):
        """Alias for PictureType"""
        return self.PictureType

    @picturetype.setter
    def picturetype(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def picture_type(self):
        """Alias for PictureType"""
        return self.PictureType

    @picture_type.setter
    def picture_type(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def PictureUnit(self):
        return self.com_object.PictureUnit

    @PictureUnit.setter
    def PictureUnit(self, value):
        self.com_object.PictureUnit = value

    @property
    def pictureunit(self):
        """Alias for PictureUnit"""
        return self.PictureUnit

    @pictureunit.setter
    def pictureunit(self, value):
        """Alias for PictureUnit.setter"""
        self.PictureUnit = value

    @property
    def picture_unit(self):
        """Alias for PictureUnit"""
        return self.PictureUnit

    @picture_unit.setter
    def picture_unit(self, value):
        """Alias for PictureUnit.setter"""
        self.PictureUnit = value

    @property
    def Thickness(self):
        return self.com_object.Thickness

    @Thickness.setter
    def Thickness(self, value):
        self.com_object.Thickness = value

    @property
    def thickness(self):
        """Alias for Thickness"""
        return self.Thickness

    @thickness.setter
    def thickness(self, value):
        """Alias for Thickness.setter"""
        self.Thickness = value

    def ClearFormats(self):
        self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Paste(self):
        self.com_object.Paste()

    def paste(self):
        """Alias for Paste"""
        return self.Paste()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


# WdAlertLevel enumeration
wdAlertsAll = -1
wdAlertsMessageBox = -2
wdAlertsNone = 0

# WdAlignmentTabAlignment enumeration
wdCenter = 1
wdLeft = 0
wdRight = 2

# WdAlignmentTabRelative enumeration
wdIndent = 1
wdMargin = 0

# WdApplyQuickStyleSets enumeration
wdSessionStartSet = 1
wdTemplateSet = 2

# WdArabicNumeral enumeration
wdNumeralArabic = 0
wdNumeralContext = 2
wdNumeralHindi = 1
wdNumeralSystem = 3

# WdAraSpeller enumeration
wdBoth = 3
wdFinalYaa = 2
wdInitialAlef = 1
wdNone = 0

# WdArrangeStyle enumeration
wdIcons = 1
wdTiled = 0

# WdAutoFitBehavior enumeration
wdAutoFitContent = 1
wdAutoFitFixed = 0
wdAutoFitWindow = 2

# WdAutoMacros enumeration
wdAutoClose = 3
wdAutoExec = 0
wdAutoExit = 4
wdAutoNew = 1
wdAutoOpen = 2
wdAutoSync = 5

# WdAutoVersions enumeration
wdAutoVersionOff = 0
wdAutoVersionOnClose = 1

# WdBaselineAlignment enumeration
wdBaselineAlignAuto = 4
wdBaselineAlignBaseline = 2
wdBaselineAlignCenter = 1
wdBaselineAlignFarEast50 = 3
wdBaselineAlignTop = 0

# WdBookmarkSortBy enumeration
wdSortByLocation = 1
wdSortByName = 0

# WdBorderDistanceFrom enumeration
wdBorderDistanceFromPageEdge = 1
wdBorderDistanceFromText = 0

# WdBorderType enumeration
wdBorderBottom = -3
wdBorderDiagonalDown = -7
wdBorderDiagonalUp = -8
wdBorderHorizontal = -5
wdBorderLeft = -2
wdBorderRight = -4
wdBorderTop = -1
wdBorderVertical = -6

# WdBreakType enumeration
wdColumnBreak = 8
wdLineBreak = 6
wdLineBreakClearLeft = 9
wdLineBreakClearRight = 10
wdPageBreak = 7
wdSectionBreakContinuous = 3
wdSectionBreakEvenPage = 4
wdSectionBreakNextPage = 2
wdSectionBreakOddPage = 5
wdTextWrappingBreak = 11

# WdBrowserLevel enumeration
wdBrowserLevelMicrosoftInternetExplorer5 = 1
wdBrowserLevelMicrosoftInternetExplorer6 = 2
wdBrowserLevelV4 = 0

# WdBrowseTarget enumeration
wdBrowseComment = 3
wdBrowseEdit = 10
wdBrowseEndnote = 5
wdBrowseField = 6
wdBrowseFind = 11
wdBrowseFootnote = 4
wdBrowseGoTo = 12
wdBrowseGraphic = 8
wdBrowseHeading = 9
wdBrowsePage = 1
wdBrowseSection = 2
wdBrowseTable = 7

# WdBuildingBlockTypes enumeration
wdTypeAutoText = 9
wdTypeBibliography = 34
wdTypeCoverPage = 2
wdTypeCustom1 = 29
wdTypeCustom2 = 30
wdTypeCustom3 = 31
wdTypeCustom4 = 32
wdTypeCustom5 = 33
wdTypeCustomAutoText = 23
wdTypeCustomBibliography = 35
wdTypeCustomCoverPage = 16
wdTypeCustomEquations = 17
wdTypeCustomFooters = 18
wdTypeCustomHeaders = 19
wdTypeCustomPageNumber = 20
wdTypeCustomPageNumberBottom = 26
wdTypeCustomPageNumberPage = 27
wdTypeCustomPageNumberTop = 25
wdTypeCustomQuickParts = 15
wdTypeCustomTableOfContents = 28
wdTypeCustomTables = 21
wdTypeCustomTextBox = 24
wdTypeCustomWatermarks = 22
wdTypeEquations = 3
wdTypeFooters = 4
wdTypeHeaders = 5
wdTypePageNumber = 6
wdTypePageNumberBottom = 12
wdTypePageNumberPage = 13
wdTypePageNumberTop = 11
wdTypeQuickParts = 1
wdTypeTableOfContents = 14
wdTypeTables = 7
wdTypeTextBox = 10
wdTypeWatermarks = 8

# WdBuiltInProperty enumeration
wdPropertyAppName = 9
wdPropertyAuthor = 3
wdPropertyBytes = 22
wdPropertyCategory = 18
wdPropertyCharacters = 16
wdPropertyCharsWSpaces = 30
wdPropertyComments = 5
wdPropertyCompany = 21
wdPropertyFormat = 19
wdPropertyHiddenSlides = 27
wdPropertyHyperlinkBase = 29
wdPropertyKeywords = 4
wdPropertyLastAuthor = 7
wdPropertyLines = 23
wdPropertyManager = 20
wdPropertyMMClips = 28
wdPropertyNotes = 26
wdPropertyPages = 14
wdPropertyParas = 24
wdPropertyRevision = 8
wdPropertySecurity = 17
wdPropertySlides = 25
wdPropertySubject = 2
wdPropertyTemplate = 6
wdPropertyTimeCreated = 11
wdPropertyTimeLastPrinted = 10
wdPropertyTimeLastSaved = 12
wdPropertyTitle = 1
wdPropertyVBATotalEdit = 13
wdPropertyWords = 15

# WdBuiltinStyle enumeration
wdStyleBlockQuotation = -85
wdStyleBodyText = -67
wdStyleBodyText2 = -81
wdStyleBodyText3 = -82
wdStyleBodyTextFirstIndent = -78
wdStyleBodyTextFirstIndent2 = -79
wdStyleBodyTextIndent = -68
wdStyleBodyTextIndent2 = -83
wdStyleBodyTextIndent3 = -84
wdStyleBookTitle = -265
wdStyleCaption = -35
wdStyleClosing = -64
wdStyleCommentReference = -40
wdStyleCommentText = -31
wdStyleDate = -77
wdStyleDefaultParagraphFont = -66
wdStyleEmphasis = -89
wdStyleEndnoteReference = -43
wdStyleEndnoteText = -44
wdStyleEnvelopeAddress = -37
wdStyleEnvelopeReturn = -38
wdStyleFooter = -33
wdStyleFootnoteReference = -39
wdStyleFootnoteText = -30
wdStyleHeader = -32
wdStyleHeading1 = -2
wdStyleHeading2 = -3
wdStyleHeading3 = -4
wdStyleHeading4 = -5
wdStyleHeading5 = -6
wdStyleHeading6 = -7
wdStyleHeading7 = -8
wdStyleHeading8 = -9
wdStyleHeading9 = -10
wdStyleHtmlAcronym = -96
wdStyleHtmlAddress = -97
wdStyleHtmlCite = -98
wdStyleHtmlCode = -99
wdStyleHtmlDfn = -100
wdStyleHtmlKbd = -101
wdStyleHtmlNormal = -95
wdStyleHtmlPre = -102
wdStyleHtmlSamp = -103
wdStyleHtmlTt = -104
wdStyleHtmlVar = -105
wdStyleHyperlink = -86
wdStyleHyperlinkFollowed = -87
wdStyleIndex1 = -11
wdStyleIndex2 = -12
wdStyleIndex3 = -13
wdStyleIndex4 = -14
wdStyleIndex5 = -15
wdStyleIndex6 = -16
wdStyleIndex7 = -17
wdStyleIndex8 = -18
wdStyleIndex9 = -19
wdStyleIndexHeading = -34
wdStyleIntenseEmphasis = -262
wdStyleIntenseQuote = -182
wdStyleIntenseReference = -264
wdStyleLineNumber = -41
wdStyleList = -48
wdStyleList2 = -51
wdStyleList3 = -52
wdStyleList4 = -53
wdStyleList5 = -54
wdStyleListBullet = -49
wdStyleListBullet2 = -55
wdStyleListBullet3 = -56
wdStyleListBullet4 = -57
wdStyleListBullet5 = -58
wdStyleListContinue = -69
wdStyleListContinue2 = -70
wdStyleListContinue3 = -71
wdStyleListContinue4 = -72
wdStyleListContinue5 = -73
wdStyleListNumber = -50
wdStyleListNumber2 = -59
wdStyleListNumber3 = -60
wdStyleListNumber4 = -61
wdStyleListNumber5 = -62
wdStyleListParagraph = -180
wdStyleMacroText = -46
wdStyleMessageHeader = -74
wdStyleNavPane = -90
wdStyleNormal = -1
wdStyleNormalIndent = -29
wdStyleNormalObject = -158
wdStyleNormalTable = -106
wdStyleNoteHeading = -80
wdStylePageNumber = -42
wdStylePlainText = -91
wdStyleQuote = -181
wdStyleSalutation = -76
wdStyleSignature = -65
wdStyleStrong = -88
wdStyleSubtitle = -75
wdStyleSubtleEmphasis = -261
wdStyleSubtleReference = -263
wdStyleTableColorfulGrid = -172
wdStyleTableColorfulList = -171
wdStyleTableColorfulShading = -170
wdStyleTableDarkList = -169
wdStyleTableLightGrid = -161
wdStyleTableLightGridAccent1 = -175
wdStyleTableLightList = -160
wdStyleTableLightListAccent1 = -174
wdStyleTableLightShading = -159
wdStyleTableLightShadingAccent1 = -173
wdStyleTableMediumGrid1 = -166
wdStyleTableMediumGrid2 = -167
wdStyleTableMediumGrid3 = -168
wdStyleTableMediumList1 = -164
wdStyleTableMediumList1Accent1 = -178
wdStyleTableMediumList2 = -165
wdStyleTableMediumShading1 = -162
wdStyleTableMediumShading1Accent1 = -176
wdStyleTableMediumShading2 = -163
wdStyleTableMediumShading2Accent1 = -177
wdStyleTableOfAuthorities = -45
wdStyleTableOfFigures = -36
wdStyleTitle = -63
wdStyleTOAHeading = -47
wdStyleTOC1 = -20
wdStyleTOC2 = -21
wdStyleTOC3 = -22
wdStyleTOC4 = -23
wdStyleTOC5 = -24
wdStyleTOC6 = -25
wdStyleTOC7 = -26
wdStyleTOC8 = -27
wdStyleTOC9 = -28

# WdCalendarType enumeration
wdCalendarArabic = 1
wdCalendarHebrew = 2
wdCalendarJapan = 4
wdCalendarKorean = 6
wdCalendarSakaEra = 7
wdCalendarTaiwan = 3
wdCalendarThai = 5
wdCalendarTranslitEnglish = 8
wdCalendarTranslitFrench = 9
wdCalendarUmalqura = 13
wdCalendarWestern = 0

# WdCalendarTypeBi enumeration
wdCalendarTypeBidi = 99
wdCalendarTypeGregorian = 100

# WdCaptionLabelID enumeration
wdCaptionEquation = -3
wdCaptionFigure = -1
wdCaptionTable = -2

# WdCaptionNumberStyle enumeration
wdCaptionNumberStyleArabic = 0
wdCaptionNumberStyleArabicFullWidth = 14
wdCaptionNumberStyleArabicLetter1 = 46
wdCaptionNumberStyleArabicLetter2 = 48
wdCaptionNumberStyleChosung = 25
wdCaptionNumberStyleGanada = 24
wdCaptionNumberStyleHanjaRead = 41
wdCaptionNumberStyleHanjaReadDigit = 42
wdCaptionNumberStyleHebrewLetter1 = 45
wdCaptionNumberStyleHebrewLetter2 = 47
wdCaptionNumberStyleHindiArabic = 51
wdCaptionNumberStyleHindiCardinalText = 52
wdCaptionNumberStyleHindiLetter1 = 49
wdCaptionNumberStyleHindiLetter2 = 50
wdCaptionNumberStyleKanji = 10
wdCaptionNumberStyleKanjiDigit = 11
wdCaptionNumberStyleKanjiTraditional = 16
wdCaptionNumberStyleLowercaseLetter = 4
wdCaptionNumberStyleLowercaseRoman = 2
wdCaptionNumberStyleNumberInCircle = 18
wdCaptionNumberStyleSimpChinNum2 = 38
wdCaptionNumberStyleSimpChinNum3 = 39
wdCaptionNumberStyleThaiArabic = 54
wdCaptionNumberStyleThaiCardinalText = 55
wdCaptionNumberStyleThaiLetter = 53
wdCaptionNumberStyleTradChinNum2 = 34
wdCaptionNumberStyleTradChinNum3 = 35
wdCaptionNumberStyleUppercaseLetter = 3
wdCaptionNumberStyleUppercaseRoman = 1
wdCaptionNumberStyleVietCardinalText = 56
wdCaptionNumberStyleZodiac1 = 30
wdCaptionNumberStyleZodiac2 = 31

# WdCaptionPosition enumeration
wdCaptionPositionAbove = 0
wdCaptionPositionBelow = 1

# WdCellColor enumeration
wdCellColorByAuthor = -1
wdCellColorLightBlue = 2
wdCellColorLightGray = 7
wdCellColorLightGreen = 6
wdCellColorLightOrange = 5
wdCellColorLightPurple = 4
wdCellColorLightYellow = 3
wdCellColorNoHighlight = 0
wdCellColorPink = 1

# WdCellVerticalAlignment enumeration
wdCellAlignVerticalBottom = 3
wdCellAlignVerticalCenter = 1
wdCellAlignVerticalTop = 0

# WdCharacterCase enumeration
wdFullWidth = 7
wdHalfWidth = 6
wdHiragana = 9
wdKatakana = 8
wdLowerCase = 0
wdNextCase = -1
wdTitleSentence = 4
wdTitleWord = 2
wdToggleCase = 5
wdUpperCase = 1

# WdCharacterWidth enumeration
wdWidthFullWidth = 7
wdWidthHalfWidth = 6

# WdCheckInVersionType enumeration
wdCheckInMajorVersion = 1
wdCheckInMinorVersion = 0
wdCheckInOverwriteVersion = 2

# WdChevronConvertRule enumeration
wdAlwaysConvert = 1
wdAskToConvert = 3
wdAskToNotConvert = 2
wdNeverConvert = 0

# WdCollapseDirection enumeration
wdCollapseEnd = 0
wdCollapseStart = 1

# WdColorIndex enumeration
wdAuto = 0
wdBlack = 1
wdBlue = 2
wdBrightGreen = 4
wdByAuthor = -1
wdDarkBlue = 9
wdDarkRed = 13
wdDarkYellow = 14
wdGray25 = 16
wdGray50 = 15
wdGreen = 11
wdNoHighlight = 0
wdPink = 5
wdRed = 6
wdTeal = 10
wdTurquoise = 3
wdViolet = 12
wdWhite = 8
wdYellow = 7

# WdColumnWidth enumeration
wdColumnWidthDefault = 2
wdColumnWidthNarrow = 1
wdColumnWidthWide = 3

# WdCompareDestination enumeration
wdCompareDestinationNew = 2
wdCompareDestinationOriginal = 0
wdCompareDestinationRevised = 1

# WdCompareTarget enumeration
wdCompareTargetCurrent = 1
wdCompareTargetNew = 2
wdCompareTargetSelected = 0

# WdCompatibility enumeration
wdAlignTablesRowByRow = 39
wdApplyBreakingRules = 46
wdAutospaceLikeWW7 = 38
wdConvMailMergeEsc = 6
wdDontAdjustLineHeightInTable = 36
wdDontBalanceSingleByteDoubleByteWidth = 16
wdDontBreakWrappedTables = 43
wdDontSnapTextToGridInTableWithObjects = 44
wdDontULTrailSpace = 15
wdDontUseAsianBreakRulesInGrid = 48
wdDontUseHTMLParagraphAutoSpacing = 35
wdDontWrapTextWithPunctuation = 47
wdExactOnTop = 28
wdExpandShiftReturn = 14
wdFootnoteLayoutLikeWW8 = 34
wdForgetLastTabAlignment = 37
wdGrowAutofit = 50
wdLayoutRawTableWidth = 40
wdLayoutTableRowsApart = 41
wdLeaveBackslashAlone = 13
wdLineWrapLikeWord6 = 32
wdMWSmallCaps = 22
wdNoColumnBalance = 5
wdNoExtraLineSpacing = 23
wdNoLeading = 20
wdNoSpaceForUL = 21
wdNoSpaceRaiseLower = 2
wdNoTabHangIndent = 1
wdOrigWordTableRules = 9
wdPrintBodyTextBeforeHeader = 19
wdPrintColBlack = 3
wdSelectFieldWithFirstOrLastCharacter = 45
wdShapeLayoutLikeWW8 = 33
wdShowBreaksInFrames = 11
wdSpacingInWholePoints = 18
wdSubFontBySize = 25
wdSuppressBottomSpacing = 29
wdSuppressSpBfAfterPgBrk = 7
wdSuppressTopSpacing = 8
wdSuppressTopSpacingMac5 = 17
wdSwapBordersFacingPages = 12
wdTransparentMetafiles = 10
wdTruncateFontHeight = 24
wdUsePrinterMetrics = 26
wdUseWord2002TableStyleRules = 49
wdUseWord2010TableStyleRules = 69
wdUseWord97LineBreakingRules = 42
wdWPJustification = 31
wdWPSpaceWidth = 30
wdWrapTrailSpaces = 4
wdWW6BorderRules = 27
wdAllowSpaceOfSameStyleInTable = 54
wdAutofitLikeWW11 = 57
wdDontAutofitConstrainedTables = 56
wdDontUseIndentAsNumberingTabStop = 52
wdFELineBreak11 = 53
wdHangulWidthLikeWW11 = 59
wdSplitPgBreakAndParaMark = 60
wdUnderlineTabInNumList = 58
wdUseNormalStyleForList = 51
wdWW11IndentRules = 55

# WdCompatibilityMode enumeration
wdCurrent = 65535
wdWord2003 = 11
wdWord2007 = 12
wdWord2010 = 14
wdWord2013 = 15

# WdConditionCode enumeration
wdEvenColumnBanding = 7
wdEvenRowBanding = 3
wdFirstColumn = 4
wdFirstRow = 0
wdLastColumn = 5
wdLastRow = 1
wdNECell = 8
wdNWCell = 9
wdOddColumnBanding = 6
wdOddRowBanding = 2
wdSECell = 10
wdSWCell = 11

# WdConstants enumeration
wdAutoPosition = 0
wdBackward = -1073741823
wdCreatorCode = 1297307460
wdFirst = 1
wdForward = 1073741823
wdToggle = 9999998
wdUndefined = 9999999

# WdContentControlAppearance enumeration
wdContentControlBoundingBox = 0
wdContentControlTags = 1
wdContentControlHidden = 2

# WdContentControlDateStorageFormat enumeration
wdContentControlDateStorageDate = 1
wdContentControlDateStorageDateTime = 2
wdContentControlDateStorageText = 0

# WdContentControlLevel enumeration
wdContentControlLevelCell = 3
wdContentControlLevelInline = 0
wdContentControlLevelParagraph = 1
wdContentControlLevelRow = 2

# WdContentControlType enumeration
wdContentControlBuildingBlockGallery = 5
wdContentControlCheckbox = 8
wdContentControlComboBox = 3
wdContentControlDate = 6
wdContentControlGroup = 7
wdContentControlDropdownList = 4
wdContentControlPicture = 2
wdContentControlRepeatingSection = 9
wdContentControlRichText = 0
wdContentControlText = 1

# WdContinue enumeration
wdContinueDisabled = 0
wdContinueList = 2
wdResetList = 1

# WdCountry enumeration
wdArgentina = 54
wdBrazil = 55
wdCanada = 2
wdChile = 56
wdChina = 86
wdDenmark = 45
wdFinland = 358
wdFrance = 33
wdGermany = 49
wdIceland = 354
wdItaly = 39
wdJapan = 81
wdKorea = 82
wdLatinAmerica = 3
wdMexico = 52
wdNetherlands = 31
wdNorway = 47
wdPeru = 51
wdSpain = 34
wdSweden = 46
wdTaiwan = 886
wdUK = 44
wdUS = 1
wdVenezuela = 58

# WdCursorMovement enumeration
wdCursorMovementLogical = 0
wdCursorMovementVisual = 1

# WdCursorType enumeration
wdCursorIBeam = 1
wdCursorNormal = 2
wdCursorNorthwestArrow = 3
wdCursorWait = 0

# WdCustomLabelPageSize enumeration
wdCustomLabelA4 = 2
wdCustomLabelA4LS = 3
wdCustomLabelA5 = 4
wdCustomLabelA5LS = 5
wdCustomLabelB4JIS = 13
wdCustomLabelB5 = 6
wdCustomLabelFanfold = 8
wdCustomLabelHigaki = 11
wdCustomLabelHigakiLS = 12
wdCustomLabelLetter = 0
wdCustomLabelLetterLS = 1
wdCustomLabelMini = 7
wdCustomLabelVertHalfSheet = 9
wdCustomLabelVertHalfSheetLS = 10

# WdDateLanguage enumeration
wdDateLanguageBidi = 10
wdDateLanguageLatin = 1033

# WdDefaultFilePath enumeration
wdAutoRecoverPath = 5
wdBorderArtPath = 19
wdCurrentFolderPath = 14
wdDocumentsPath = 0
wdGraphicsFiltersPath = 10
wdPicturesPath = 1
wdProgramPath = 9
wdProofingToolsPath = 12
wdStartupPath = 8
wdStyleGalleryPath = 15
wdTempFilePath = 13
wdTextConvertersPath = 11
wdToolsPath = 6
wdTutorialPath = 7
wdUserOptionsPath = 4
wdUserTemplatesPath = 2
wdWorkgroupTemplatesPath = 3

# WdDefaultListBehavior enumeration
wdWord10ListBehavior = 2
wdWord8ListBehavior = 0
wdWord9ListBehavior = 1

# WdDefaultTableBehavior enumeration
wdWord8TableBehavior = 0
wdWord9TableBehavior = 1

# WdDeleteCells enumeration
wdDeleteCellsEntireColumn = 3
wdDeleteCellsEntireRow = 2
wdDeleteCellsShiftLeft = 0
wdDeleteCellsShiftUp = 1

# WdDeletedTextMark enumeration
wdDeletedTextMarkBold = 5
wdDeletedTextMarkCaret = 2
wdDeletedTextMarkColorOnly = 9
wdDeletedTextMarkDoubleUnderline = 8
wdDeletedTextMarkHidden = 0
wdDeletedTextMarkItalic = 6
wdDeletedTextMarkNone = 4
wdDeletedTextMarkPound = 3
wdDeletedTextMarkStrikeThrough = 1
wdDeletedTextMarkUnderline = 7
wdDeletedTextMarkDoubleStrikeThrough = 10

# WdDiacriticColor enumeration
wdDiacriticColorBidi = 0
wdDiacriticColorLatin = 1

# WdDictionaryType enumeration
wdGrammar = 1
wdHangulHanjaConversion = 8
wdHangulHanjaConversionCustom = 9
wdHyphenation = 3
wdSpelling = 0
wdSpellingComplete = 4
wdSpellingCustom = 5
wdSpellingLegal = 6
wdSpellingMedical = 7
wdThesaurus = 2

# WdDisableFeaturesIntroducedAfter enumeration
wd70 = 0
wd70FE = 1
wd80 = 2

# WdDocPartInsertOptions enumeration
wdInsertContent = 0
wdInsertPage = 2
wdInsertParagraph = 1

# WdDocumentDirection enumeration
wdLeftToRight = 0
wdRightToLeft = 1

# WdDocumentKind enumeration
wdDocumentEmail = 2
wdDocumentLetter = 1
wdDocumentNotSpecified = 0

# WdDocumentMedium enumeration
wdDocument = 1
wdEmailMessage = 0
wdWebPage = 2

# WdDocumentType enumeration
wdTypeDocument = 0
wdTypeFrameset = 2
wdTypeTemplate = 1

# WdDocumentViewDirection enumeration
wdDocumentViewLtr = 1
wdDocumentViewRtl = 0

# WdDropPosition enumeration
wdDropMargin = 2
wdDropNone = 0
wdDropNormal = 1

# WdEditionOption enumeration
wdAutomaticUpdate = 3
wdCancelPublisher = 0
wdChangeAttributes = 5
wdManualUpdate = 4
wdOpenSource = 7
wdSelectPublisher = 2
wdSendPublisher = 1
wdUpdateSubscriber = 6

# WdEditionType enumeration
wdPublisher = 0
wdSubscriber = 1

# WdEditorType enumeration
wdEditorCurrent = -6
wdEditorEditors = -5
wdEditorEveryone = -1
wdEditorOwners = -4

# WdEmailHTMLFidelity enumeration
wdEmailHTMLFidelityHigh = 3
wdEmailHTMLFidelityLow = 1
wdEmailHTMLFidelityMedium = 2

# WdEmphasisMark enumeration
wdEmphasisMarkNone = 0
wdEmphasisMarkOverComma = 2
wdEmphasisMarkOverSolidCircle = 1
wdEmphasisMarkOverWhiteCircle = 3
wdEmphasisMarkUnderSolidCircle = 4

# WdEnableCancelKey enumeration
wdCancelDisabled = 0
wdCancelInterrupt = 1

# WdEncloseStyle enumeration
wdEncloseStyleLarge = 2
wdEncloseStyleNone = 0
wdEncloseStyleSmall = 1

# WdEnclosureType enumeration
wdEnclosureCircle = 0
wdEnclosureDiamond = 3
wdEnclosureSquare = 1
wdEnclosureTriangle = 2

# WdEndnoteLocation enumeration
wdEndOfDocument = 1
wdEndOfSection = 0

# WdEnvelopeOrientation enumeration
wdCenterClockwise = 7
wdCenterLandscape = 4
wdCenterPortrait = 1
wdLeftClockwise = 6
wdLeftLandscape = 3
wdLeftPortrait = 0
wdRightClockwise = 8
wdRightLandscape = 5
wdRightPortrait = 2

# WdExportCreateBookmarks enumeration
wdExportCreateHeadingBookmarks = 1
wdExportCreateNoBookmarks = 0
wdExportCreateWordBookmarks = 2

# WdExportFormat enumeration
wdExportFormatPDF = 17
wdExportFormatXPS = 18

# WdExportItem enumeration
wdExportDocumentContent = 0
wdExportDocumentWithMarkup = 7

# WdExportOptimizeFor enumeration
wdExportOptimizeForOnScreen = 1
wdExportOptimizeForPrint = 0

# WdExportRange enumeration
wdExportAllDocument = 0
wdExportCurrentPage = 2
wdExportFromTo = 3
wdExportSelection = 1

# WdFarEastLineBreakLanguageID enumeration
wdLineBreakJapanese = 1041
wdLineBreakKorean = 1042
wdLineBreakSimplifiedChinese = 2052
wdLineBreakTraditionalChinese = 1028

# WdFarEastLineBreakLevel enumeration
wdFarEastLineBreakLevelCustom = 2
wdFarEastLineBreakLevelNormal = 0
wdFarEastLineBreakLevelStrict = 1

# WdFieldKind enumeration
wdFieldKindCold = 3
wdFieldKindHot = 1
wdFieldKindNone = 0
wdFieldKindWarm = 2

# WdFieldShading enumeration
wdFieldShadingAlways = 1
wdFieldShadingNever = 0
wdFieldShadingWhenSelected = 2

# WdFieldType enumeration
wdFieldAddin = 81
wdFieldAddressBlock = 93
wdFieldAdvance = 84
wdFieldAsk = 38
wdFieldAuthor = 17
wdFieldAutoNum = 54
wdFieldAutoNumLegal = 53
wdFieldAutoNumOutline = 52
wdFieldAutoText = 79
wdFieldAutoTextList = 89
wdFieldBarCode = 63
wdFieldBidiOutline = 92
wdFieldComments = 19
wdFieldCompare = 80
wdFieldCreateDate = 21
wdFieldData = 40
wdFieldDatabase = 78
wdFieldDate = 31
wdFieldDDE = 45
wdFieldDDEAuto = 46
wdFieldDisplayBarcode = 99
wdFieldDocProperty = 85
wdFieldDocVariable = 64
wdFieldEditTime = 25
wdFieldEmbed = 58
wdFieldEmpty = -1
wdFieldExpression = 34
wdFieldFileName = 29
wdFieldFileSize = 69
wdFieldFillIn = 39
wdFieldFootnoteRef = 5
wdFieldFormCheckBox = 71
wdFieldFormDropDown = 83
wdFieldFormTextInput = 70
wdFieldFormula = 49
wdFieldGlossary = 47
wdFieldGoToButton = 50
wdFieldGreetingLine = 94
wdFieldHTMLActiveX = 91
wdFieldHyperlink = 88
wdFieldIf = 7
wdFieldImport = 55
wdFieldInclude = 36
wdFieldIncludePicture = 67
wdFieldIncludeText = 68
wdFieldIndex = 8
wdFieldIndexEntry = 4
wdFieldInfo = 14
wdFieldKeyWord = 18
wdFieldLastSavedBy = 20
wdFieldLink = 56
wdFieldListNum = 90
wdFieldMacroButton = 51
wdFieldMergeBarcode = 98
wdFieldMergeField = 59
wdFieldMergeRec = 44
wdFieldMergeSeq = 75
wdFieldNext = 41
wdFieldNextIf = 42
wdFieldNoteRef = 72
wdFieldNumChars = 28
wdFieldNumPages = 26
wdFieldNumWords = 27
wdFieldOCX = 87
wdFieldPage = 33
wdFieldPageRef = 37
wdFieldPrint = 48
wdFieldPrintDate = 23
wdFieldPrivate = 77
wdFieldQuote = 35
wdFieldRef = 3
wdFieldRefDoc = 11
wdFieldRevisionNum = 24
wdFieldSaveDate = 22
wdFieldSection = 65
wdFieldSectionPages = 66
wdFieldSequence = 12
wdFieldSet = 6
wdFieldShape = 95
wdFieldSkipIf = 43
wdFieldStyleRef = 10
wdFieldSubject = 16
wdFieldSubscriber = 82
wdFieldSymbol = 57
wdFieldTemplate = 30
wdFieldTime = 32
wdFieldTitle = 15
wdFieldTOA = 73
wdFieldTOAEntry = 74
wdFieldTOC = 13
wdFieldTOCEntry = 9
wdFieldUserAddress = 62
wdFieldUserInitials = 61
wdFieldUserName = 60
wdFieldBibliography = 97
wdFieldCitation = 96

# WdFindMatch enumeration
wdMatchAnyCharacter = 65599
wdMatchAnyDigit = 65567
wdMatchAnyLetter = 65583
wdMatchCaretCharacter = 11
wdMatchColumnBreak = 14
wdMatchCommentMark = 5
wdMatchEmDash = 8212
wdMatchEnDash = 8211
wdMatchEndnoteMark = 65555
wdMatchField = 19
wdMatchFootnoteMark = 65554
wdMatchGraphic = 1
wdMatchManualLineBreak = 65551
wdMatchManualPageBreak = 65564
wdMatchNonbreakingHyphen = 30
wdMatchNonbreakingSpace = 160
wdMatchOptionalHyphen = 31
wdMatchParagraphMark = 65551
wdMatchSectionBreak = 65580
wdMatchTabCharacter = 9
wdMatchWhiteSpace = 65655

# WdFindWrap enumeration
wdFindAsk = 2
wdFindContinue = 1
wdFindStop = 0

# WdFlowDirection enumeration
wdFlowLtr = 0
wdFlowRtl = 1

# WdFontBias enumeration
wdFontBiasDefault = 0
wdFontBiasDontCare = 255
wdFontBiasFareast = 1

# WdFootnoteLocation enumeration
wdBeneathText = 1
wdBottomOfPage = 0

# WdFramePosition enumeration
wdFrameBottom = -999997
wdFrameCenter = -999995
wdFrameInside = -999994
wdFrameLeft = -999998
wdFrameOutside = -999993
wdFrameRight = -999996
wdFrameTop = -999999

# WdFramesetNewFrameLocation enumeration
wdFramesetNewFrameAbove = 0
wdFramesetNewFrameBelow = 1
wdFramesetNewFrameLeft = 3
wdFramesetNewFrameRight = 2

# WdFramesetSizeType enumeration
wdFramesetSizeTypeFixed = 1
wdFramesetSizeTypePercent = 0
wdFramesetSizeTypeRelative = 2

# WdFramesetType enumeration
wdFramesetTypeFrame = 1
wdFramesetTypeFrameset = 0

# WdFrameSizeRule enumeration
wdFrameAtLeast = 1
wdFrameAuto = 0
wdFrameExact = 2

# WdFrenchSpeller enumeration
wdFrenchBoth = 0
wdFrenchPostReform = 2
wdFrenchPreReform = 1

# WdGoToDirection enumeration
wdGoToAbsolute = 1
wdGoToFirst = 1
wdGoToLast = -1
wdGoToNext = 2
wdGoToPrevious = 3
wdGoToRelative = 2

# WdGoToItem enumeration
wdGoToBookmark = -1
wdGoToComment = 6
wdGoToEndnote = 5
wdGoToEquation = 10
wdGoToField = 7
wdGoToFootnote = 4
wdGoToGrammaticalError = 14
wdGoToGraphic = 8
wdGoToHeading = 11
wdGoToLine = 3
wdGoToObject = 9
wdGoToPage = 1
wdGoToPercent = 12
wdGoToProofreadingError = 15
wdGoToSection = 0
wdGoToSpellingError = 13
wdGoToTable = 2

# WdGranularity enumeration
wdGranularityCharLevel = 0
wdGranularityWordLevel = 1

# WdGutterStyle enumeration
wdGutterPosLeft = 0
wdGutterPosRight = 2
wdGutterPosTop = 1

# WdGutterStyleOld enumeration
wdGutterStyleBidi = 2
wdGutterStyleLatin = -10

# WdHeaderFooterIndex enumeration
wdHeaderFooterEvenPages = 3
wdHeaderFooterFirstPage = 2
wdHeaderFooterPrimary = 1

# WdHeadingSeparator enumeration
wdHeadingSeparatorBlankLine = 1
wdHeadingSeparatorLetter = 2
wdHeadingSeparatorLetterFull = 4
wdHeadingSeparatorLetterLow = 3
wdHeadingSeparatorNone = 0

# WdHebSpellStart enumeration
wdFullScript = 0
wdMixedAuthorizedScript = 3
wdMixedScript = 2
wdPartialScript = 1

# WdHelpType enumeration
wdHelp = 0
wdHelpAbout = 1
wdHelpActiveWindow = 2
wdHelpContents = 3
wdHelpExamplesAndDemos = 4
wdHelpHWP = 13
wdHelpIchitaro = 11
wdHelpIndex = 5
wdHelpKeyboard = 6
wdHelpPE2 = 12
wdHelpPSSHelp = 7
wdHelpQuickPreview = 8
wdHelpSearch = 9
wdHelpUsingHelp = 10

# WdHighAnsiText enumeration
wdAutoDetectHighAnsiFarEast = 2
wdHighAnsiIsFarEast = 0
wdHighAnsiIsHighAnsi = 1

# WdHorizontalInVerticalType enumeration
wdHorizontalInVerticalFitInLine = 1
wdHorizontalInVerticalNone = 0
wdHorizontalInVerticalResizeLine = 2

# WdHorizontalLineAlignment enumeration
wdHorizontalLineAlignCenter = 1
wdHorizontalLineAlignLeft = 0
wdHorizontalLineAlignRight = 2

# WdHorizontalLineWidthType enumeration
wdHorizontalLineFixedWidth = -2
wdHorizontalLinePercentWidth = -1

# WdIMEMode enumeration
wdIMEModeAlpha = 8
wdIMEModeAlphaFull = 7
wdIMEModeHangul = 10
wdIMEModeHangulFull = 9
wdIMEModeHiragana = 4
wdIMEModeKatakana = 5
wdIMEModeKatakanaHalf = 6
wdIMEModeNoControl = 0
wdIMEModeOff = 2
wdIMEModeOn = 1

# WdIndexFilter enumeration
wdIndexFilterAiueo = 1
wdIndexFilterAkasatana = 2
wdIndexFilterChosung = 3
wdIndexFilterFull = 6
wdIndexFilterLow = 4
wdIndexFilterMedium = 5
wdIndexFilterNone = 0

# WdIndexFormat enumeration
wdIndexBulleted = 4
wdIndexClassic = 1
wdIndexFancy = 2
wdIndexFormal = 5
wdIndexModern = 3
wdIndexSimple = 6
wdIndexTemplate = 0

# WdIndexSortBy enumeration
wdIndexSortByStroke = 0
wdIndexSortBySyllable = 1

# WdIndexType enumeration
wdIndexIndent = 0
wdIndexRunin = 1

# WdInformation enumeration
wdActiveEndAdjustedPageNumber = 1
wdActiveEndPageNumber = 3
wdActiveEndSectionNumber = 2
wdAtEndOfRowMarker = 31
wdCapsLock = 21
wdEndOfRangeColumnNumber = 17
wdEndOfRangeRowNumber = 14
wdFirstCharacterColumnNumber = 9
wdFirstCharacterLineNumber = 10
wdFrameIsSelected = 11
wdHeaderFooterType = 33
wdHorizontalPositionRelativeToPage = 5
wdHorizontalPositionRelativeToTextBoundary = 7
wdInBibliography = 42
wdInCitation = 43
wdInClipboard = 38
wdInCommentPane = 26
wdInContentControl = 46
wdInCoverPage = 41
wdInEndnote = 36
wdInFieldCode = 44
wdInFieldResult = 45
wdInFootnote = 35
wdInFootnoteEndnotePane = 25
wdInHeaderFooter = 28
wdInMasterDocument = 34
wdInWordMail = 37
wdMaximumNumberOfColumns = 18
wdMaximumNumberOfRows = 15
wdNumberOfPagesInDocument = 4
wdNumLock = 22
wdOverType = 23
wdReferenceOfType = 32
wdRevisionMarking = 24
wdSelectionMode = 20
wdStartOfRangeColumnNumber = 16
wdStartOfRangeRowNumber = 13
wdVerticalPositionRelativeToPage = 6
wdVerticalPositionRelativeToTextBoundary = 8
wdWithInTable = 12
wdZoomPercentage = 19

# WdInlineShapeType enumeration
wdInlineShape3DModel = 19
wdInlineShapeChart = 12
wdInlineShapeDiagram = 13
wdInlineShapeEmbeddedOLEObject = 1
wdInlineShapeHorizontalLine = 6
wdInlineShapeLinked3DModel = 20
wdInlineShapeLinkedOLEObject = 2
wdInlineShapeLinkedPicture = 4
wdInlineShapeLinkedPictureHorizontalLine = 8
wdInlineShapeLockedCanvas = 14
wdInlineShapeOLEControlObject = 5
wdInlineShapeOWSAnchor = 11
wdInlineShapePicture = 3
wdInlineShapePictureBullet = 9
wdInlineShapePictureHorizontalLine = 7
wdInlineShapeScriptAnchor = 10
wdInlineShapeSmartArt = 15
wdInlineShapeWebVideo = 16

# WdInsertCells enumeration
wdInsertCellsEntireColumn = 3
wdInsertCellsEntireRow = 2
wdInsertCellsShiftDown = 1
wdInsertCellsShiftRight = 0

# WdInsertedTextMark enumeration
wdInsertedTextMarkBold = 1
wdInsertedTextMarkColorOnly = 5
wdInsertedTextMarkDoubleUnderline = 4
wdInsertedTextMarkItalic = 2
wdInsertedTextMarkNone = 0
wdInsertedTextMarkStrikeThrough = 6
wdInsertedTextMarkUnderline = 3
wdInsertedTextMarkDoubleStrikeThrough = 7

# WdInternationalIndex enumeration
wd24HourClock = 21
wdCurrencyCode = 20
wdDateSeparator = 25
wdDecimalSeparator = 18
wdInternationalAM = 22
wdInternationalPM = 23
wdListSeparator = 17
wdProductLanguageID = 26
wdThousandsSeparator = 19
wdTimeSeparator = 24

# WdJustificationMode enumeration
wdJustificationModeCompress = 1
wdJustificationModeCompressKana = 2
wdJustificationModeExpand = 0

# WdKana enumeration
wdKanaHiragana = 9
wdKanaKatakana = 8

# WdKey enumeration
wdKey0 = 48
wdKey1 = 49
wdKey2 = 50
wdKey3 = 51
wdKey4 = 52
wdKey5 = 53
wdKey6 = 54
wdKey7 = 55
wdKey8 = 56
wdKey9 = 57
wdKeyA = 65
wdKeyAlt = 1024
wdKeyB = 66
wdKeyBackSingleQuote = 192
wdKeyBackSlash = 220
wdKeyBackspace = 8
wdKeyC = 67
wdKeyCloseSquareBrace = 221
wdKeyComma = 188
wdKeyCommand = 512
wdKeyControl = 512
wdKeyD = 68
wdKeyDelete = 46
wdKeyE = 69
wdKeyEnd = 35
wdKeyEquals = 187
wdKeyEsc = 27
wdKeyF = 70
wdKeyF1 = 112
wdKeyF10 = 121
wdKeyF11 = 122
wdKeyF12 = 123
wdKeyF13 = 124
wdKeyF14 = 125
wdKeyF15 = 126
wdKeyF16 = 127
wdKeyF2 = 113
wdKeyF3 = 114
wdKeyF4 = 115
wdKeyF5 = 116
wdKeyF6 = 117
wdKeyF7 = 118
wdKeyF8 = 119
wdKeyF9 = 120
wdKeyG = 71
wdKeyH = 72
wdKeyHome = 36
wdKeyHyphen = 189
wdKeyI = 73
wdKeyInsert = 45
wdKeyJ = 74
wdKeyK = 75
wdKeyL = 76
wdKeyM = 77
wdKeyN = 78
wdKeyNumeric0 = 96
wdKeyNumeric1 = 97
wdKeyNumeric2 = 98
wdKeyNumeric3 = 99
wdKeyNumeric4 = 100
wdKeyNumeric5 = 101
wdKeyNumeric5Special = 12
wdKeyNumeric6 = 102
wdKeyNumeric7 = 103
wdKeyNumeric8 = 104
wdKeyNumeric9 = 105
wdKeyNumericAdd = 107
wdKeyNumericDecimal = 110
wdKeyNumericDivide = 111
wdKeyNumericMultiply = 106
wdKeyNumericSubtract = 109
wdKeyO = 79
wdKeyOpenSquareBrace = 219
wdKeyOption = 1024
wdKeyP = 80
wdKeyPageDown = 34
wdKeyPageUp = 33
wdKeyPause = 19
wdKeyPeriod = 190
wdKeyQ = 81
wdKeyR = 82
wdKeyReturn = 13
wdKeyS = 83
wdKeyScrollLock = 145
wdKeySemiColon = 186
wdKeyShift = 256
wdKeySingleQuote = 222
wdKeySlash = 191
wdKeySpacebar = 32
wdKeyT = 84
wdKeyTab = 9
wdKeyU = 85
wdKeyV = 86
wdKeyW = 87
wdKeyX = 88
wdKeyY = 89
wdKeyZ = 90
wdNoKey = 255

# WdKeyCategory enumeration
wdKeyCategoryAutoText = 4
wdKeyCategoryCommand = 1
wdKeyCategoryDisable = 0
wdKeyCategoryFont = 3
wdKeyCategoryMacro = 2
wdKeyCategoryNil = -1
wdKeyCategoryPrefix = 7
wdKeyCategoryStyle = 5
wdKeyCategorySymbol = 6

# WdLanguageID enumeration
wdAfrikaans = 1078
wdAlbanian = 1052
wdAmharic = 1118
wdArabic = 1025
wdArabicAlgeria = 5121
wdArabicBahrain = 15361
wdArabicEgypt = 3073
wdArabicIraq = 2049
wdArabicJordan = 11265
wdArabicKuwait = 13313
wdArabicLebanon = 12289
wdArabicLibya = 4097
wdArabicMorocco = 6145
wdArabicOman = 8193
wdArabicQatar = 16385
wdArabicSyria = 10241
wdArabicTunisia = 7169
wdArabicUAE = 14337
wdArabicYemen = 9217
wdArmenian = 1067
wdAssamese = 1101
wdAzeriCyrillic = 2092
wdAzeriLatin = 1068
wdBasque = 1069
wdBelgianDutch = 2067
wdBelgianFrench = 2060
wdBengali = 1093
wdBulgarian = 1026
wdBurmese = 1109
wdByelorussian = 1059
wdCatalan = 1027
wdCherokee = 1116
wdChineseHongKongSAR = 3076
wdChineseMacaoSAR = 5124
wdChineseSingapore = 4100
wdCroatian = 1050
wdCzech = 1029
wdDanish = 1030
wdDivehi = 1125
wdDutch = 1043
wdEdo = 1126
wdEnglishAUS = 3081
wdEnglishBelize = 10249
wdEnglishCanadian = 4105
wdEnglishCaribbean = 9225
wdEnglishIndonesia = 14345
wdEnglishIreland = 6153
wdEnglishJamaica = 8201
wdEnglishNewZealand = 5129
wdEnglishPhilippines = 13321
wdEnglishSouthAfrica = 7177
wdEnglishTrinidadTobago = 11273
wdEnglishUK = 2057
wdEnglishUS = 1033
wdEnglishZimbabwe = 12297
wdEstonian = 1061
wdFaeroese = 1080
wdFilipino = 1124
wdFinnish = 1035
wdFrench = 1036
wdFrenchCameroon = 11276
wdFrenchCanadian = 3084
wdFrenchCongoDRC = 9228
wdFrenchCotedIvoire = 12300
wdFrenchHaiti = 15372
wdFrenchLuxembourg = 5132
wdFrenchMali = 13324
wdFrenchMonaco = 6156
wdFrenchMorocco = 14348
wdFrenchReunion = 8204
wdFrenchSenegal = 10252
wdFrenchWestIndies = 7180
wdFrisianNetherlands = 1122
wdFulfulde = 1127
wdGaelicIreland = 2108
wdGaelicScotland = 1084
wdGalician = 1110
wdGeorgian = 1079
wdGerman = 1031
wdGermanAustria = 3079
wdGermanLiechtenstein = 5127
wdGermanLuxembourg = 4103
wdGreek = 1032
wdGuarani = 1140
wdGujarati = 1095
wdHausa = 1128
wdHawaiian = 1141
wdHebrew = 1037
wdHindi = 1081
wdHungarian = 1038
wdIbibio = 1129
wdIcelandic = 1039
wdIgbo = 1136
wdIndonesian = 1057
wdInuktitut = 1117
wdItalian = 1040
wdJapanese = 1041
wdKannada = 1099
wdKanuri = 1137
wdKashmiri = 1120
wdKazakh = 1087
wdKhmer = 1107
wdKirghiz = 1088
wdKonkani = 1111
wdKorean = 1042
wdKyrgyz = 1088
wdLanguageNone = 0
wdLao = 1108
wdLatin = 1142
wdLatvian = 1062
wdLithuanian = 1063
wdMacedonianFYROM = 1071
wdMalayalam = 1100
wdMalayBruneiDarussalam = 2110
wdMalaysian = 1086
wdMaltese = 1082
wdManipuri = 1112
wdMarathi = 1102
wdMexicanSpanish = 2058
wdMongolian = 1104
wdNepali = 1121
wdNoProofing = 1024
wdNorwegianBokmol = 1044
wdNorwegianNynorsk = 2068
wdOriya = 1096
wdOromo = 1138
wdPashto = 1123
wdPersian = 1065
wdPolish = 1045
wdPortuguese = 2070
wdPortugueseBrazil = 1046
wdPunjabi = 1094
wdRhaetoRomanic = 1047
wdRomanian = 1048
wdRomanianMoldova = 2072
wdRussian = 1049
wdRussianMoldova = 2073
wdSamiLappish = 1083
wdSanskrit = 1103
wdSerbianCyrillic = 3098
wdSerbianLatin = 2074
wdSesotho = 1072
wdSimplifiedChinese = 2052
wdSindhi = 1113
wdSindhiPakistan = 2137
wdSinhalese = 1115
wdSlovak = 1051
wdSlovenian = 1060
wdSomali = 1143
wdSorbian = 1070
wdSpanish = 1034
wdSpanishArgentina = 11274
wdSpanishBolivia = 16394
wdSpanishChile = 13322
wdSpanishColombia = 9226
wdSpanishCostaRica = 5130
wdSpanishDominicanRepublic = 7178
wdSpanishEcuador = 12298
wdSpanishElSalvador = 17418
wdSpanishGuatemala = 4106
wdSpanishHonduras = 18442
wdSpanishModernSort = 3082
wdSpanishNicaragua = 19466
wdSpanishPanama = 6154
wdSpanishParaguay = 15370
wdSpanishPeru = 10250
wdSpanishPuertoRico = 20490
wdSpanishUruguay = 14346
wdSpanishVenezuela = 8202
wdSutu = 1072
wdSwahili = 1089
wdSwedish = 1053
wdSwedishFinland = 2077
wdSwissFrench = 4108
wdSwissGerman = 2055
wdSwissItalian = 2064
wdSyriac = 1114
wdTajik = 1064
wdTamazight = 1119
wdTamazightLatin = 2143
wdTamil = 1097
wdTatar = 1092
wdTelugu = 1098
wdThai = 1054
wdTibetan = 1105
wdTigrignaEritrea = 2163
wdTigrignaEthiopic = 1139
wdTraditionalChinese = 1028
wdTsonga = 1073
wdTswana = 1074
wdTurkish = 1055
wdTurkmen = 1090
wdUkrainian = 1058
wdUrdu = 1056
wdUzbekCyrillic = 2115
wdUzbekLatin = 1091
wdVenda = 1075
wdVietnamese = 1066
wdWelsh = 1106
wdXhosa = 1076
wdYi = 1144
wdYiddish = 1085
wdYoruba = 1130
wdZulu = 1077

# WdLayoutMode enumeration
wdLayoutModeDefault = 0
wdLayoutModeGenko = 3
wdLayoutModeGrid = 1
wdLayoutModeLineGrid = 2

# WdLetterheadLocation enumeration
wdLetterBottom = 1
wdLetterLeft = 2
wdLetterRight = 3
wdLetterTop = 0

# WdLetterStyle enumeration
wdFullBlock = 0
wdModifiedBlock = 1
wdSemiBlock = 2

# WdLigatures enumeration
wdLigaturesAll = 15
wdLigaturesContextual = 2
wdLigaturesContextualDiscretional = 10
wdLigaturesContextualHistorical = 6
wdLigaturesContextualHistoricalDiscretional = 14
wdLigaturesDiscretional = 8
wdLigaturesHistorical = 4
wdLigaturesHistoricalDiscretional = 12
wdLigaturesNone = 0
wdLigaturesStandard = 1
wdLigaturesStandardContextual = 3
wdLigaturesStandardContextualDiscretional = 11
wdLigaturesStandardContextualHistorical = 7
wdLigaturesStandardDiscretional = 9
wdLigaturesStandardHistorical = 5
wdLigaturesStandardHistoricalDiscretional = 13

# WdLineEndingType enumeration
wdCRLF = 0
wdCROnly = 1
wdLFCR = 3
wdLFOnly = 2
wdLSPS = 4

# WdLineSpacing enumeration
wdLineSpace1pt5 = 1
wdLineSpaceAtLeast = 3
wdLineSpaceDouble = 2
wdLineSpaceExactly = 4
wdLineSpaceMultiple = 5
wdLineSpaceSingle = 0

# WdLineStyle enumeration
wdLineStyleDashDot = 5
wdLineStyleDashDotDot = 6
wdLineStyleDashDotStroked = 20
wdLineStyleDashLargeGap = 4
wdLineStyleDashSmallGap = 3
wdLineStyleDot = 2
wdLineStyleDouble = 7
wdLineStyleDoubleWavy = 19
wdLineStyleEmboss3D = 21
wdLineStyleEngrave3D = 22
wdLineStyleInset = 24
wdLineStyleNone = 0
wdLineStyleOutset = 23
wdLineStyleSingle = 1
wdLineStyleSingleWavy = 18
wdLineStyleThickThinLargeGap = 16
wdLineStyleThickThinMedGap = 13
wdLineStyleThickThinSmallGap = 10
wdLineStyleThinThickLargeGap = 15
wdLineStyleThinThickMedGap = 12
wdLineStyleThinThickSmallGap = 9
wdLineStyleThinThickThinLargeGap = 17
wdLineStyleThinThickThinMedGap = 14
wdLineStyleThinThickThinSmallGap = 11
wdLineStyleTriple = 8

# WdLineType enumeration
wdTableRow = 1
wdTextLine = 0

# WdLineWidth enumeration
wdLineWidth025pt = 2
wdLineWidth050pt = 4
wdLineWidth075pt = 6
wdLineWidth100pt = 8
wdLineWidth150pt = 12
wdLineWidth225pt = 18
wdLineWidth300pt = 24
wdLineWidth450pt = 36
wdLineWidth600pt = 48

# WdLinkType enumeration
wdLinkTypeChart = 8
wdLinkTypeDDE = 6
wdLinkTypeDDEAuto = 7
wdLinkTypeImport = 5
wdLinkTypeInclude = 4
wdLinkTypeOLE = 0
wdLinkTypePicture = 1
wdLinkTypeReference = 3
wdLinkTypeText = 2

# WdListApplyTo enumeration
wdListApplyToSelection = 2
wdListApplyToThisPointForward = 1
wdListApplyToWholeList = 0

# WdListGalleryType enumeration
wdBulletGallery = 1
wdNumberGallery = 2
wdOutlineNumberGallery = 3

# WdListLevelAlignment enumeration
wdListLevelAlignCenter = 1
wdListLevelAlignLeft = 0
wdListLevelAlignRight = 2

# WdListNumberStyle enumeration
wdListNumberStyleAiueo = 20
wdListNumberStyleAiueoHalfWidth = 12
wdListNumberStyleArabic = 0
wdListNumberStyleArabic1 = 46
wdListNumberStyleArabic2 = 48
wdListNumberStyleArabicFullWidth = 14
wdListNumberStyleArabicLZ = 22
wdListNumberStyleArabicLZ2 = 62
wdListNumberStyleArabicLZ3 = 63
wdListNumberStyleArabicLZ4 = 64
wdListNumberStyleBullet = 23
wdListNumberStyleCardinalText = 6
wdListNumberStyleChosung = 25
wdListNumberStyleGanada = 24
wdListNumberStyleGBNum1 = 26
wdListNumberStyleGBNum2 = 27
wdListNumberStyleGBNum3 = 28
wdListNumberStyleGBNum4 = 29
wdListNumberStyleHangul = 43
wdListNumberStyleHanja = 44
wdListNumberStyleHanjaRead = 41
wdListNumberStyleHanjaReadDigit = 42
wdListNumberStyleHebrew1 = 45
wdListNumberStyleHebrew2 = 47
wdListNumberStyleHindiArabic = 51
wdListNumberStyleHindiCardinalText = 52
wdListNumberStyleHindiLetter1 = 49
wdListNumberStyleHindiLetter2 = 50
wdListNumberStyleIroha = 21
wdListNumberStyleIrohaHalfWidth = 13
wdListNumberStyleKanji = 10
wdListNumberStyleKanjiDigit = 11
wdListNumberStyleKanjiTraditional = 16
wdListNumberStyleKanjiTraditional2 = 17
wdListNumberStyleLegal = 253
wdListNumberStyleLegalLZ = 254
wdListNumberStyleLowercaseBulgarian = 67
wdListNumberStyleLowercaseGreek = 60
wdListNumberStyleLowercaseLetter = 4
wdListNumberStyleLowercaseRoman = 2
wdListNumberStyleLowercaseRussian = 58
wdListNumberStyleLowercaseTurkish = 65
wdListNumberStyleNone = 255
wdListNumberStyleNumberInCircle = 18
wdListNumberStyleOrdinal = 5
wdListNumberStyleOrdinalText = 7
wdListNumberStylePictureBullet = 249
wdListNumberStyleSimpChinNum1 = 37
wdListNumberStyleSimpChinNum2 = 38
wdListNumberStyleSimpChinNum3 = 39
wdListNumberStyleSimpChinNum4 = 40
wdListNumberStyleThaiArabic = 54
wdListNumberStyleThaiCardinalText = 55
wdListNumberStyleThaiLetter = 53
wdListNumberStyleTradChinNum1 = 33
wdListNumberStyleTradChinNum2 = 34
wdListNumberStyleTradChinNum3 = 35
wdListNumberStyleTradChinNum4 = 36
wdListNumberStyleUppercaseBulgarian = 68
wdListNumberStyleUppercaseGreek = 61
wdListNumberStyleUppercaseLetter = 3
wdListNumberStyleUppercaseRoman = 1
wdListNumberStyleUppercaseRussian = 59
wdListNumberStyleUppercaseTurkish = 66
wdListNumberStyleVietCardinalText = 56
wdListNumberStyleZodiac1 = 30
wdListNumberStyleZodiac2 = 31
wdListNumberStyleZodiac3 = 32

# WdListType enumeration
wdListBullet = 2
wdListListNumOnly = 1
wdListMixedNumbering = 5
wdListNoNumbering = 0
wdListOutlineNumbering = 4
wdListPictureBullet = 6
wdListSimpleNumbering = 3

# WdLockType enumeration
wdLockChanged = 3
wdLockEphemeral = 2
wdLockNone = 0
wdLockReservation = 1

# WdMailerPriority enumeration
wdPriorityHigh = 3
wdPriorityLow = 2
wdPriorityNormal = 1

# WdMailMergeActiveRecord enumeration
wdFirstDataSourceRecord = -6
wdFirstRecord = -4
wdLastDataSourceRecord = -7
wdLastRecord = -5
wdNextDataSourceRecord = -8
wdNextRecord = -2
wdNoActiveRecord = -1
wdPreviousDataSourceRecord = -9
wdPreviousRecord = -3

# WdMailMergeComparison enumeration
wdMergeIfEqual = 0
wdMergeIfGreaterThan = 3
wdMergeIfGreaterThanOrEqual = 5
wdMergeIfIsBlank = 6
wdMergeIfIsNotBlank = 7
wdMergeIfLessThan = 2
wdMergeIfLessThanOrEqual = 4
wdMergeIfNotEqual = 1

# WdMailMergeDataSource enumeration
wdMergeInfoFromAccessDDE = 1
wdMergeInfoFromExcelDDE = 2
wdMergeInfoFromMSQueryDDE = 3
wdMergeInfoFromODBC = 4
wdMergeInfoFromODSO = 5
wdMergeInfoFromWord = 0
wdNoMergeInfo = -1

# WdMailMergeDefaultRecord enumeration
wdDefaultFirstRecord = 1
wdDefaultLastRecord = -16

# WdMailMergeDestination enumeration
wdSendToEmail = 2
wdSendToFax = 3
wdSendToNewDocument = 0
wdSendToPrinter = 1

# WdMailMergeMailFormat enumeration
wdMailFormatHTML = 1
wdMailFormatPlainText = 0

# WdMailMergeMainDocType enumeration
wdCatalog = 3
wdDirectory = 3
wdEMail = 4
wdEnvelopes = 2
wdFax = 5
wdFormLetters = 0
wdMailingLabels = 1
wdNotAMergeDocument = -1

# WdMailMergeState enumeration
wdDataSource = 5
wdMainAndDataSource = 2
wdMainAndHeader = 3
wdMainAndSourceAndHeader = 4
wdMainDocumentOnly = 1
wdNormalDocument = 0

# WdMailSystem enumeration
wdMAPI = 1
wdMAPIandPowerTalk = 3
wdNoMailSystem = 0
wdPowerTalk = 2

# WdMappedDataFields enumeration
wdAddress1 = 10
wdAddress2 = 11
wdAddress3 = 29
wdBusinessFax = 17
wdBusinessPhone = 16
wdCity = 12
wdCompany = 9
wdCountryRegion = 15
wdCourtesyTitle = 2
wdDepartment = 30
wdEmailAddress = 20
wdFirstName = 3
wdHomeFax = 19
wdHomePhone = 18
wdJobTitle = 8
wdLastName = 5
wdMiddleName = 4
wdNickname = 7
wdPostalCode = 14
wdRubyFirstName = 27
wdRubyLastName = 28
wdSpouseCourtesyTitle = 22
wdSpouseFirstName = 23
wdSpouseLastName = 25
wdSpouseMiddleName = 24
wdSpouseNickname = 26
wdState = 13
wdSuffix = 6
wdUniqueIdentifier = 1
wdWebPageURL = 21

# WdMeasurementUnits enumeration
wdCentimeters = 1
wdInches = 0
wdMillimeters = 2
wdPicas = 4
wdPoints = 3

# WdMergeFormatFrom enumeration
wdMergeFormatFromOriginal = 0
wdMergeFormatFromPrompt = 2
wdMergeFormatFromRevised = 1

# WdMergeSubType enumeration
wdMergeSubTypeAccess = 1
wdMergeSubTypeOAL = 2
wdMergeSubTypeOLEDBText = 5
wdMergeSubTypeOLEDBWord = 3
wdMergeSubTypeOther = 0
wdMergeSubTypeOutlook = 6
wdMergeSubTypeWord = 7
wdMergeSubTypeWord2000 = 8
wdMergeSubTypeWorks = 4

# WdMergeTarget enumeration
wdMergeTargetCurrent = 1
wdMergeTargetNew = 2
wdMergeTargetSelected = 0

# WdMonthNames enumeration
wdMonthNamesArabic = 0
wdMonthNamesEnglish = 1
wdMonthNamesFrench = 2

# WdMoveFromTextMark enumeration
wdMoveFromTextMarkBold = 6
wdMoveFromTextMarkCaret = 3
wdMoveFromTextMarkColorOnly = 10
wdMoveFromTextMarkDoubleStrikeThrough = 1
wdMoveFromTextMarkDoubleUnderline = 9
wdMoveFromTextMarkHidden = 0
wdMoveFromTextMarkItalic = 7
wdMoveFromTextMarkNone = 5
wdMoveFromTextMarkPound = 4
wdMoveFromTextMarkStrikeThrough = 2
wdMoveFromTextMarkUnderline = 8

# WdMovementType enumeration
wdExtend = 1
wdMove = 0

# WdMoveToTextMark enumeration
wdMoveToTextMarkBold = 1
wdMoveToTextMarkColorOnly = 5
wdMoveToTextMarkDoubleStrikeThrough = 7
wdMoveToTextMarkDoubleUnderline = 4
wdMoveToTextMarkItalic = 2
wdMoveToTextMarkNone = 0
wdMoveToTextMarkStrikeThrough = 6
wdMoveToTextMarkUnderline = 3

# WdMultipleWordConversionsMode enumeration
wdHangulToHanja = 0
wdHanjaToHangul = 1

# WdNewDocumentType enumeration
wdNewBlankDocument = 0
wdNewEmailMessage = 2
wdNewFrameset = 3
wdNewWebPage = 1
wdNewXMLDocument = 4

# WdNoteNumberStyle enumeration
wdNoteNumberStyleArabic = 0
wdNoteNumberStyleArabicFullWidth = 14
wdNoteNumberStyleArabicLetter1 = 46
wdNoteNumberStyleArabicLetter2 = 48
wdNoteNumberStyleHanjaRead = 41
wdNoteNumberStyleHanjaReadDigit = 42
wdNoteNumberStyleHebrewLetter1 = 45
wdNoteNumberStyleHebrewLetter2 = 47
wdNoteNumberStyleHindiArabic = 51
wdNoteNumberStyleHindiCardinalText = 52
wdNoteNumberStyleHindiLetter1 = 49
wdNoteNumberStyleHindiLetter2 = 50
wdNoteNumberStyleKanji = 10
wdNoteNumberStyleKanjiDigit = 11
wdNoteNumberStyleKanjiTraditional = 16
wdNoteNumberStyleLowercaseLetter = 4
wdNoteNumberStyleLowercaseRoman = 2
wdNoteNumberStyleNumberInCircle = 18
wdNoteNumberStyleSimpChinNum1 = 37
wdNoteNumberStyleSimpChinNum2 = 38
wdNoteNumberStyleSymbol = 9
wdNoteNumberStyleThaiArabic = 54
wdNoteNumberStyleThaiCardinalText = 55
wdNoteNumberStyleThaiLetter = 53
wdNoteNumberStyleTradChinNum1 = 33
wdNoteNumberStyleTradChinNum2 = 34
wdNoteNumberStyleUppercaseLetter = 3
wdNoteNumberStyleUppercaseRoman = 1
wdNoteNumberStyleVietCardinalText = 56

# WdNumberForm enumeration
wdNumberFormDefault = 0
wdNumberFormLining = 1
wdNumberFormOldstyle = 2

# WdNumberingRule enumeration
wdRestartContinuous = 0
wdRestartPage = 2
wdRestartSection = 1

# WdNumberSpacing enumeration
wdNumberSpacingDefault = 0
wdNumberSpacingProportional = 1
wdNumberSpacingTabular = 2

# WdNumberStyleWordBasicBiDi enumeration
wdCaptionNumberStyleBidiLetter1 = 49
wdCaptionNumberStyleBidiLetter2 = 50
wdListNumberStyleBidi1 = 49
wdListNumberStyleBidi2 = 50
wdNoteNumberStyleBidiLetter1 = 49
wdNoteNumberStyleBidiLetter2 = 50
wdPageNumberStyleBidiLetter1 = 49
wdPageNumberStyleBidiLetter2 = 50

# WdNumberType enumeration
wdNumberAllNumbers = 3
wdNumberListNum = 2
wdNumberParagraph = 1

# WdOLEPlacement enumeration
wdFloatOverText = 1
wdInLine = 0

# WdOLEType enumeration
wdOLEControl = 2
wdOLEEmbed = 1
wdOLELink = 0

# WdOLEVerb enumeration
wdOLEVerbDiscardUndoState = -6
wdOLEVerbHide = -3
wdOLEVerbInPlaceActivate = -5
wdOLEVerbOpen = -2
wdOLEVerbPrimary = 0
wdOLEVerbShow = -1
wdOLEVerbUIActivate = -4

# WdOMathBreakBin enumeration
wdOMathBreakBinAfter = 1
wdOMathBreakBinBefore = 0
wdOMathBreakBinRepeat = 2

# WdOMathBreakSub enumeration
wdOMathBreakSubMinusMinus = 0
wdOMathBreakSubMinusPlus = 2
wdOMathBreakSubPlusMinus = 1

# WdOMathFracType enumeration
wdOMathFracBar = 0
wdOMathFracLin = 3
wdOMathFracNoBar = 1
wdOMathFracSkw = 2

# WdOMathFunctionType enumeration
wdOMathFunctionAcc = 1
wdOMathFunctionBar = 2
wdOMathFunctionBorderBox = 4
wdOMathFunctionBox = 3
wdOMathFunctionDelim = 5
wdOMathFunctionEqArray = 6
wdOMathFunctionFrac = 7
wdOMathFunctionFunc = 8
wdOMathFunctionGroupChar = 9
wdOMathFunctionLimLow = 10
wdOMathFunctionLimUpp = 11
wdOMathFunctionMat = 12
wdOMathFunctionNary = 13
wdOMathFunctionNormalText = 21
wdOMathFunctionPhantom = 14
wdOMathFunctionRad = 16
wdOMathFunctionScrPre = 15
wdOMathFunctionScrSub = 17
wdOMathFunctionScrSubSup = 18
wdOMathFunctionScrSup = 19
wdOMathFunctionText = 20

# WdOMathHorizAlignType enumeration
wdOMathHorizAlignCenter = 0
wdOMathHorizAlignLeft = 1
wdOMathHorizAlignRight = 2

# WdOMathJc enumeration
wdOMathJcCenter = 2
wdOMathJcCenterGroup = 1
wdOMathJcInline = 7
wdOMathJcLeft = 3
wdOMathJcRight = 4

# WdOMathShapeType enumeration
wdOMathShapeCentered = 0
wdOMathShapeMatch = 1

# WdOMathSpacingRule enumeration
wdOMathSpacing1pt5 = 1
wdOMathSpacingDouble = 2
wdOMathSpacingExactly = 3
wdOMathSpacingMultiple = 4
wdOMathSpacingSingle = 0

# WdOMathType enumeration
wdOMathDisplay = 0
wdOMathInline = 1

# WdOMathVertAlignType enumeration
wdOMathVertAlignBottom = 2
wdOMathVertAlignCenter = 0
wdOMathVertAlignTop = 1

# WdOpenFormat enumeration
wdOpenFormatAllWord = 6
wdOpenFormatAuto = 0
wdOpenFormatDocument = 1
wdOpenFormatEncodedText = 5
wdOpenFormatRTF = 3
wdOpenFormatTemplate = 2
wdOpenFormatText = 4
wdOpenFormatOpenDocumentText = "18 (&H12)"
wdOpenFormatUnicodeText = 5
wdOpenFormatWebPages = 7
wdOpenFormatXML = 8
wdOpenFormatAllWordTemplates = 13
wdOpenFormatDocument97 = 1
wdOpenFormatTemplate97 = 2
wdOpenFormatXMLDocument = 9
wdOpenFormatXMLDocumentSerialized = 14
wdOpenFormatXMLDocumentMacroEnabled = 10
wdOpenFormatXMLDocumentMacroEnabledSerialized = 15
wdOpenFormatXMLTemplate = 11
wdOpenFormatXMLTemplateSerialized = "16 (&H10)"
wdOpenFormatXMLTemplateMacroEnabled = 12
wdOpenFormatXMLTemplateMacroEnabledSerialized = "17 (&H11)"

# WdOrganizerObject enumeration
wdOrganizerObjectAutoText = 1
wdOrganizerObjectCommandBars = 2
wdOrganizerObjectProjectItems = 3
wdOrganizerObjectStyles = 0

# WdOrientation enumeration
wdOrientLandscape = 1
wdOrientPortrait = 0

# WdOriginalFormat enumeration
wdOriginalDocumentFormat = 1
wdPromptUser = 2
wdWordDocument = 0

# WdOutlineLevel enumeration
wdOutlineLevel1 = 1
wdOutlineLevel2 = 2
wdOutlineLevel3 = 3
wdOutlineLevel4 = 4
wdOutlineLevel5 = 5
wdOutlineLevel6 = 6
wdOutlineLevel7 = 7
wdOutlineLevel8 = 8
wdOutlineLevel9 = 9
wdOutlineLevelBodyText = 10

# WdPageBorderArt enumeration
wdArtApples = 1
wdArtArchedScallops = 97
wdArtBabyPacifier = 70
wdArtBabyRattle = 71
wdArtBalloons3Colors = 11
wdArtBalloonsHotAir = 12
wdArtBasicBlackDashes = 155
wdArtBasicBlackDots = 156
wdArtBasicBlackSquares = 154
wdArtBasicThinLines = 151
wdArtBasicWhiteDashes = 152
wdArtBasicWhiteDots = 147
wdArtBasicWhiteSquares = 153
wdArtBasicWideInline = 150
wdArtBasicWideMidline = 148
wdArtBasicWideOutline = 149
wdArtBats = 37
wdArtBirds = 102
wdArtBirdsFlight = 35
wdArtCabins = 72
wdArtCakeSlice = 3
wdArtCandyCorn = 4
wdArtCelticKnotwork = 99
wdArtCertificateBanner = 158
wdArtChainLink = 128
wdArtChampagneBottle = 6
wdArtCheckedBarBlack = 145
wdArtCheckedBarColor = 61
wdArtCheckered = 144
wdArtChristmasTree = 8
wdArtCirclesLines = 91
wdArtCirclesRectangles = 140
wdArtClassicalWave = 56
wdArtClocks = 27
wdArtCompass = 54
wdArtConfetti = 31
wdArtConfettiGrays = 115
wdArtConfettiOutline = 116
wdArtConfettiStreamers = 14
wdArtConfettiWhite = 117
wdArtCornerTriangles = 141
wdArtCouponCutoutDashes = 163
wdArtCouponCutoutDots = 164
wdArtCrazyMaze = 100
wdArtCreaturesButterfly = 32
wdArtCreaturesFish = 34
wdArtCreaturesInsects = 142
wdArtCreaturesLadyBug = 33
wdArtCrossStitch = 138
wdArtCup = 67
wdArtDecoArch = 89
wdArtDecoArchColor = 50
wdArtDecoBlocks = 90
wdArtDiamondsGray = 88
wdArtDoubleD = 55
wdArtDoubleDiamonds = 127
wdArtEarth1 = 22
wdArtEarth2 = 21
wdArtEclipsingSquares1 = 101
wdArtEclipsingSquares2 = 86
wdArtEggsBlack = 66
wdArtFans = 51
wdArtFilm = 52
wdArtFirecrackers = 28
wdArtFlowersBlockPrint = 49
wdArtFlowersDaisies = 48
wdArtFlowersModern1 = 45
wdArtFlowersModern2 = 44
wdArtFlowersPansy = 43
wdArtFlowersRedRose = 39
wdArtFlowersRoses = 38
wdArtFlowersTeacup = 103
wdArtFlowersTiny = 42
wdArtGems = 139
wdArtGingerbreadMan = 69
wdArtGradient = 122
wdArtHandmade1 = 159
wdArtHandmade2 = 160
wdArtHeartBalloon = 16
wdArtHeartGray = 68
wdArtHearts = 15
wdArtHeebieJeebies = 120
wdArtHolly = 41
wdArtHouseFunky = 73
wdArtHypnotic = 87
wdArtIceCreamCones = 5
wdArtLightBulb = 121
wdArtLightning1 = 53
wdArtLightning2 = 119
wdArtMapleLeaf = 81
wdArtMapleMuffins = 2
wdArtMapPins = 30
wdArtMarquee = 146
wdArtMarqueeToothed = 131
wdArtMoons = 125
wdArtMosaic = 118
wdArtMusicNotes = 79
wdArtNorthwest = 104
wdArtOvals = 126
wdArtPackages = 26
wdArtPalmsBlack = 80
wdArtPalmsColor = 10
wdArtPaperClips = 82
wdArtPapyrus = 92
wdArtPartyFavor = 13
wdArtPartyGlass = 7
wdArtPencils = 25
wdArtPeople = 84
wdArtPeopleHats = 23
wdArtPeopleWaving = 85
wdArtPoinsettias = 40
wdArtPostageStamp = 135
wdArtPumpkin1 = 65
wdArtPushPinNote1 = 63
wdArtPushPinNote2 = 64
wdArtPyramids = 113
wdArtPyramidsAbove = 114
wdArtQuadrants = 60
wdArtRings = 29
wdArtSafari = 98
wdArtSawtooth = 133
wdArtSawtoothGray = 134
wdArtScaredCat = 36
wdArtSeattle = 78
wdArtShadowedSquares = 57
wdArtSharksTeeth = 132
wdArtShorebirdTracks = 83
wdArtSkyrocket = 77
wdArtSnowflakeFancy = 76
wdArtSnowflakes = 75
wdArtSombrero = 24
wdArtSouthwest = 105
wdArtStars = 19
wdArtStars3D = 17
wdArtStarsBlack = 74
wdArtStarsShadowed = 18
wdArtStarsTop = 157
wdArtSun = 20
wdArtSwirligig = 62
wdArtTornPaper = 161
wdArtTornPaperBlack = 162
wdArtTrees = 9
wdArtTriangleParty = 123
wdArtTriangles = 129
wdArtTribal1 = 130
wdArtTribal2 = 109
wdArtTribal3 = 108
wdArtTribal4 = 107
wdArtTribal5 = 110
wdArtTribal6 = 106
wdArtTwistedLines1 = 58
wdArtTwistedLines2 = 124
wdArtVine = 47
wdArtWaveline = 59
wdArtWeavingAngles = 96
wdArtWeavingBraid = 94
wdArtWeavingRibbon = 95
wdArtWeavingStrips = 136
wdArtWhiteFlowers = 46
wdArtWoodwork = 93
wdArtXIllusions = 111
wdArtZanyTriangles = 112
wdArtZigZag = 137
wdArtZigZagStitch = 143

# WdPageColor enumeration
wdPageColorInverse = 2
wdPageColorNone = 0
wdPageColorSepia = 1

# WdPageFit enumeration
wdPageFitBestFit = 2
wdPageFitFullPage = 1
wdPageFitNone = 0
wdPageFitTextFit = 3

# WdPageMovementType enumeration
wdVertical = 1
wdSideToSide = 2

# WdPageNumberAlignment enumeration
wdAlignPageNumberCenter = 1
wdAlignPageNumberInside = 3
wdAlignPageNumberLeft = 0
wdAlignPageNumberOutside = 4
wdAlignPageNumberRight = 2

# WdPageNumberStyle enumeration
wdPageNumberStyleArabic = 0
wdPageNumberStyleArabicFullWidth = 14
wdPageNumberStyleArabicLetter1 = 46
wdPageNumberStyleArabicLetter2 = 48
wdPageNumberStyleHanjaRead = 41
wdPageNumberStyleHanjaReadDigit = 42
wdPageNumberStyleHebrewLetter1 = 45
wdPageNumberStyleHebrewLetter2 = 47
wdPageNumberStyleHindiArabic = 51
wdPageNumberStyleHindiCardinalText = 52
wdPageNumberStyleHindiLetter1 = 49
wdPageNumberStyleHindiLetter2 = 50
wdPageNumberStyleKanji = 10
wdPageNumberStyleKanjiDigit = 11
wdPageNumberStyleKanjiTraditional = 16
wdPageNumberStyleLowercaseLetter = 4
wdPageNumberStyleLowercaseRoman = 2
wdPageNumberStyleNumberInCircle = 18
wdPageNumberStyleNumberInDash = 57
wdPageNumberStyleSimpChinNum1 = 37
wdPageNumberStyleSimpChinNum2 = 38
wdPageNumberStyleThaiArabic = 54
wdPageNumberStyleThaiCardinalText = 55
wdPageNumberStyleThaiLetter = 53
wdPageNumberStyleTradChinNum1 = 33
wdPageNumberStyleTradChinNum2 = 34
wdPageNumberStyleUppercaseLetter = 3
wdPageNumberStyleUppercaseRoman = 1
wdPageNumberStyleVietCardinalText = 56

# WdPaperSize enumeration
wdPaper10x14 = 0
wdPaper11x17 = 1
wdPaperA3 = 6
wdPaperA4 = 7
wdPaperA4Small = 8
wdPaperA5 = 9
wdPaperB4 = 10
wdPaperB5 = 11
wdPaperCSheet = 12
wdPaperCustom = 41
wdPaperDSheet = 13
wdPaperEnvelope10 = 25
wdPaperEnvelope11 = 26
wdPaperEnvelope12 = 27
wdPaperEnvelope14 = 28
wdPaperEnvelope9 = 24
wdPaperEnvelopeB4 = 29
wdPaperEnvelopeB5 = 30
wdPaperEnvelopeB6 = 31
wdPaperEnvelopeC3 = 32
wdPaperEnvelopeC4 = 33
wdPaperEnvelopeC5 = 34
wdPaperEnvelopeC6 = 35
wdPaperEnvelopeC65 = 36
wdPaperEnvelopeDL = 37
wdPaperEnvelopeItaly = 38
wdPaperEnvelopeMonarch = 39
wdPaperEnvelopePersonal = 40
wdPaperESheet = 14
wdPaperExecutive = 5
wdPaperFanfoldLegalGerman = 15
wdPaperFanfoldStdGerman = 16
wdPaperFanfoldUS = 17
wdPaperFolio = 18
wdPaperLedger = 19
wdPaperLegal = 4
wdPaperLetter = 2
wdPaperLetterSmall = 3
wdPaperNote = 20
wdPaperQuarto = 21
wdPaperStatement = 22
wdPaperTabloid = 23

# WdPaperTray enumeration
wdPrinterAutomaticSheetFeed = 7
wdPrinterDefaultBin = 0
wdPrinterEnvelopeFeed = 5
wdPrinterFormSource = 15
wdPrinterLargeCapacityBin = 11
wdPrinterLargeFormatBin = 10
wdPrinterLowerBin = 2
wdPrinterManualEnvelopeFeed = 6
wdPrinterManualFeed = 4
wdPrinterMiddleBin = 3
wdPrinterOnlyBin = 1
wdPrinterPaperCassette = 14
wdPrinterSmallFormatBin = 9
wdPrinterTractorFeed = 8
wdPrinterUpperBin = 1

# WdParagraphAlignment enumeration
wdAlignParagraphCenter = 1
wdAlignParagraphDistribute = 4
wdAlignParagraphJustify = 3
wdAlignParagraphJustifyHi = 7
wdAlignParagraphJustifyLow = 8
wdAlignParagraphJustifyMed = 5
wdAlignParagraphLeft = 0
wdAlignParagraphRight = 2
wdAlignParagraphThaiJustify = 9

# WdPartOfSpeech enumeration
wdAdjective = 0
wdAdverb = 2
wdConjunction = 5
wdIdiom = 8
wdInterjection = 7
wdNoun = 1
wdOther = 9
wdPreposition = 6
wdPronoun = 4
wdVerb = 3

# WdPasteDataType enumeration
wdPasteBitmap = 4
wdPasteDeviceIndependentBitmap = 5
wdPasteEnhancedMetafile = 9
wdPasteHTML = 10
wdPasteHyperlink = 7
wdPasteMetafilePicture = 3
wdPasteOLEObject = 0
wdPasteRTF = 1
wdPasteShape = 8
wdPasteText = 2

# WdPasteOptions enumeration
wdKeepSourceFormatting = 0
wdKeepTextOnly = 2
wdMatchDestinationFormatting = 1
wdUseDestinationStyles = 3

# WdPhoneticGuideAlignmentType enumeration
wdPhoneticGuideAlignmentCenter = 0
wdPhoneticGuideAlignmentLeft = 3
wdPhoneticGuideAlignmentOneTwoOne = 2
wdPhoneticGuideAlignmentRight = 4
wdPhoneticGuideAlignmentRightVertical = 5
wdPhoneticGuideAlignmentZeroOneZero = 1

# WdPictureLinkType enumeration
wdLinkDataInDoc = 1
wdLinkDataOnDisk = 2
wdLinkNone = 0

# WdPortugueseReform enumeration
wdPortugueseBoth = 3
wdPortuguesePostReform = 2
wdPortuguesePreReform = 1

# WdPreferredWidthType enumeration
wdPreferredWidthAuto = 1
wdPreferredWidthPercent = 2
wdPreferredWidthPoints = 3

# WdPrintOutItem enumeration
wdPrintAutoTextEntries = 4
wdPrintComments = 2
wdPrintDocumentContent = 0
wdPrintDocumentWithMarkup = 7
wdPrintEnvelope = 6
wdPrintKeyAssignments = 5
wdPrintMarkup = 2
wdPrintProperties = 1
wdPrintStyles = 3

# WdPrintOutPages enumeration
wdPrintAllPages = 0
wdPrintEvenPagesOnly = 2
wdPrintOddPagesOnly = 1

# WdPrintOutRange enumeration
wdPrintAllDocument = 0
wdPrintCurrentPage = 2
wdPrintFromTo = 3
wdPrintRangeOfPages = 4
wdPrintSelection = 1

# WdProofreadingErrorType enumeration
wdGrammaticalError = 1
wdSpellingError = 0

# WdProtectedViewCloseReason enumeration
wdProtectedViewCloseEdit = 1
wdProtectedViewCloseForced = 2
wdProtectedViewCloseNormal = 0

# WdProtectionType enumeration
wdAllowOnlyComments = 1
wdAllowOnlyFormFields = 2
wdAllowOnlyReading = 3
wdAllowOnlyRevisions = 0
wdNoProtection = -1

# WdReadingLayoutMargin enumeration
wdAutomaticMargin = 0
wdFullMargin = 2
wdSuppressMargin = 1

# WdReadingOrder enumeration
wdReadingOrderLtr = 1
wdReadingOrderRtl = 0

# WdRecoveryType enumeration
wdChart = 14
wdChartLinked = 15
wdChartPicture = 13
wdFormatOriginalFormatting = 16
wdFormatPlainText = 22
wdFormatSurroundingFormattingWithEmphasis = 20
wdListCombineWithExistingList = 24
wdListContinueNumbering = 7
wdListDontMerge = 25
wdListRestartNumbering = 8
wdPasteDefault = 0
wdSingleCellTable = 6
wdSingleCellText = 5
wdTableAppendTable = 10
wdTableInsertAsRows = 11
wdTableOriginalFormatting = 12
wdTableOverwriteCells = 23
wdUseDestinationStylesRecovery = 19

# WdRectangleType enumeration
wdLineBetweenColumnRectangle = 5
wdMarkupRectangle = 2
wdMarkupRectangleButton = 3
wdPageBorderRectangle = 4
wdSelection = 6
wdShapeRectangle = 1
wdSystem = 7
wdTextRectangle = 0
wdDocumentControlRectangle = 13
wdMailNavArea = 12
wdMarkupRectangleArea = 8
wdMarkupRectangleMoveMatch = 10
wdReadingModeNavigation = 9
wdReadingModePanningArea = 11

# WdReferenceKind enumeration
wdContentText = -1
wdEndnoteNumber = 6
wdEndnoteNumberFormatted = 17
wdEntireCaption = 2
wdFootnoteNumber = 5
wdFootnoteNumberFormatted = 16
wdNumberFullContext = -4
wdNumberNoContext = -3
wdNumberRelativeContext = -2
wdOnlyCaptionText = 4
wdOnlyLabelAndNumber = 3
wdPageNumber = 7
wdPosition = 15

# WdReferenceType enumeration
wdRefTypeBookmark = 2
wdRefTypeEndnote = 4
wdRefTypeFootnote = 3
wdRefTypeHeading = 1
wdRefTypeNumberedItem = 0

# WdRelativeHorizontalPosition enumeration
wdRelativeHorizontalPositionCharacter = 3
wdRelativeHorizontalPositionColumn = 2
wdRelativeHorizontalPositionMargin = 0
wdRelativeHorizontalPositionPage = 1
wdRelativeHorizontalPositionInnerMarginArea = 6
wdRelativeHorizontalPositionLeftMarginArea = 4
wdRelativeHorizontalPositionOuterMarginArea = 7
wdRelativeHorizontalPositionRightMarginArea = 5

# WdRelativeHorizontalSize enumeration
wdRelativeHorizontalSizeInnerMarginArea = 4
wdRelativeHorizontalSizeLeftMarginArea = 2
wdRelativeHorizontalSizeMargin = 0
wdRelativeHorizontalSizeOuterMarginArea = 5
wdRelativeHorizontalSizePage = 1
wdRelativeHorizontalSizeRightMarginArea = 3

# WdRelativeVerticalPosition enumeration
wdRelativeVerticalPositionLine = 3
wdRelativeVerticalPositionMargin = 0
wdRelativeVerticalPositionPage = 1
wdRelativeVerticalPositionParagraph = 2
wdRelativeVerticalPositionBottomMarginArea = 5
wdRelativeVerticalPositionInnerMarginArea = 6
wdRelativeVerticalPositionOuterMarginArea = 7
wdRelativeVerticalPositionTopMarginArea = 4

# WdRelativeVerticalSize enumeration
wdRelativeVerticalSizeBottomMarginArea = 3
wdRelativeVerticalSizeInnerMarginArea = 4
wdRelativeVerticalSizeMargin = 0
wdRelativeVerticalSizeOuterMarginArea = 5
wdRelativeVerticalSizePage = 1
wdRelativeVerticalSizeTopMarginArea = 2

# WdRelocate enumeration
wdRelocateDown = 1
wdRelocateUp = 0

# WdRemoveDocInfoType enumeration
wdRDIAll = 99
wdRDIComments = 1
wdRDIContentType = 16
wdRDIDocumentManagementPolicy = 15
wdRDIDocumentProperties = 8
wdRDIDocumentServerProperties = 14
wdRDIDocumentWorkspace = 10
wdRDIEmailHeader = 5
wdRDIInkAnnotations = 11
wdRDIRemovePersonalInformation = 4
wdRDIRevisions = 2
wdRDIRoutingSlip = 6
wdRDISendForReview = 7
wdRDITemplate = 9
wdRDITaskpaneWebExtensions = 17
wdRDIVersions = 3

# WdReplace enumeration
wdReplaceAll = 2
wdReplaceNone = 0
wdReplaceOne = 1

# WdRevisedLinesMark enumeration
wdRevisedLinesMarkLeftBorder = 1
wdRevisedLinesMarkNone = 0
wdRevisedLinesMarkOutsideBorder = 3
wdRevisedLinesMarkRightBorder = 2

# WdRevisedPropertiesMark enumeration
wdRevisedPropertiesMarkBold = 1
wdRevisedPropertiesMarkColorOnly = 5
wdRevisedPropertiesMarkDoubleStrikeThrough = 7
wdRevisedPropertiesMarkDoubleUnderline = 4
wdRevisedPropertiesMarkItalic = 2
wdRevisedPropertiesMarkNone = 0
wdRevisedPropertiesMarkStrikeThrough = 6
wdRevisedPropertiesMarkUnderline = 3

# WdRevisionsBalloonMargin enumeration
wdLeftMargin = 0
wdRightMargin = 1

# WdRevisionsBalloonPrintOrientation enumeration
wdBalloonPrintOrientationAuto = 0
wdBalloonPrintOrientationForceLandscape = 2
wdBalloonPrintOrientationPreserve = 1

# WdRevisionsBalloonWidthType enumeration
wdBalloonWidthPercent = 0
wdBalloonWidthPoints = 1

# WdRevisionsMarkup enumeration
wdRevisionsMarkupAll = 2
wdRevisionsMarkupNone = 0
wdRevisionsMarkupSimple = 1

# WdRevisionsMode enumeration
wdBalloonRevisions = 0
wdInLineRevisions = 1
wdMixedRevisions = 2

# WdRevisionsView enumeration
wdRevisionsViewFinal = 0
wdRevisionsViewOriginal = 1

# WdRevisionsWrap enumeration
wdWrapAlways = 1
wdWrapAsk = 2
wdWrapNever = 0

# WdRevisionType enumeration
wdNoRevision = 0
wdRevisionCellDeletion = 17
wdRevisionCellInsertion = 16
wdRevisionCellMerge = 18
wdRevisionCellSplit = 19
wdRevisionConflict = 7
wdRevisionConflictDelete = 21
wdRevisionConflictInsert = 20
wdRevisionDelete = 2
wdRevisionDisplayField = 5
wdRevisionInsert = 1
wdRevisionMovedFrom = 14
wdRevisionMovedTo = 15
wdRevisionParagraphNumber = 4
wdRevisionParagraphProperty = 10
wdRevisionProperty = 3
wdRevisionReconcile = 6
wdRevisionReplace = 9
wdRevisionSectionProperty = 12
wdRevisionStyle = 8
wdRevisionStyleDefinition = 13
wdRevisionTableProperty = 11

# WdRowAlignment enumeration
wdAlignRowCenter = 1
wdAlignRowLeft = 0
wdAlignRowRight = 2

# WdRowHeightRule enumeration
wdRowHeightAtLeast = 1
wdRowHeightAuto = 0
wdRowHeightExactly = 2

# WdRulerStyle enumeration
wdAdjustFirstColumn = 2
wdAdjustNone = 0
wdAdjustProportional = 1
wdAdjustSameWidth = 3

# WdSalutationGender enumeration
wdGenderFemale = 0
wdGenderMale = 1
wdGenderNeutral = 2
wdGenderUnknown = 3

# WdSalutationType enumeration
wdSalutationBusiness = 2
wdSalutationFormal = 1
wdSalutationInformal = 0
wdSalutationOther = 3

# WdSaveFormat enumeration
wdFormatDocument = 0
wdFormatDOSText = 4
wdFormatDOSTextLineBreaks = 5
wdFormatEncodedText = 7
wdFormatFilteredHTML = 10
wdFormatFlatXML = 19
wdFormatFlatXMLMacroEnabled = 20
wdFormatFlatXMLTemplate = 21
wdFormatFlatXMLTemplateMacroEnabled = 22
wdFormatOpenDocumentText = 23
wdFormatHTML = 8
wdFormatRTF = 6
wdFormatStrictOpenXMLDocument = 24
wdFormatTemplate = 1
wdFormatText = 2
wdFormatTextLineBreaks = 3
wdFormatUnicodeText = 7
wdFormatWebArchive = 9
wdFormatXML = 11
wdFormatDocument97 = 0
wdFormatDocumentDefault = 16
wdFormatPDF = 17
wdFormatTemplate97 = 1
wdFormatXMLDocument = 12
wdFormatXMLDocumentMacroEnabled = 13
wdFormatXMLTemplate = 14
wdFormatXMLTemplateMacroEnabled = 15
wdFormatXPS = 18

# WdSaveOptions enumeration
wdDoNotSaveChanges = 0
wdPromptToSaveChanges = -2
wdSaveChanges = -1

# WdScrollbarType enumeration
wdScrollbarTypeAuto = 0
wdScrollbarTypeNo = 2
wdScrollbarTypeYes = 1

# WdSectionDirection enumeration
wdSectionDirectionLtr = 1
wdSectionDirectionRtl = 0

# WdSectionStart enumeration
wdSectionContinuous = 0
wdSectionEvenPage = 3
wdSectionNewColumn = 1
wdSectionNewPage = 2
wdSectionOddPage = 4

# WdSeekView enumeration
wdSeekCurrentPageFooter = 10
wdSeekCurrentPageHeader = 9
wdSeekEndnotes = 8
wdSeekEvenPagesFooter = 6
wdSeekEvenPagesHeader = 3
wdSeekFirstPageFooter = 5
wdSeekFirstPageHeader = 2
wdSeekFootnotes = 7
wdSeekMainDocument = 0
wdSeekPrimaryFooter = 4
wdSeekPrimaryHeader = 1

# WdSelectionFlags enumeration
wdSelActive = 8
wdSelAtEOL = 2
wdSelOvertype = 4
wdSelReplace = 16
wdSelStartActive = 1

# WdSelectionType enumeration
wdNoSelection = 0
wdSelectionBlock = 6
wdSelectionColumn = 4
wdSelectionFrame = 3
wdSelectionInlineShape = 7
wdSelectionIP = 1
wdSelectionNormal = 2
wdSelectionRow = 5
wdSelectionShape = 8

# WdSeparatorType enumeration
wdSeparatorColon = 2
wdSeparatorEmDash = 3
wdSeparatorEnDash = 4
wdSeparatorHyphen = 0
wdSeparatorPeriod = 1

# WdShapePosition enumeration
wdShapeBottom = -999997
wdShapeCenter = -999995
wdShapeInside = -999994
wdShapeLeft = -999998
wdShapeOutside = -999993
wdShapeRight = -999996
wdShapeTop = -999999

# WdShapePositionRelative enumeration
wdShapePositionRelativeNone = -999999

# WdShapeSizeRelative enumeration
wdShapeSizeRelativeNone = -999999

# WdShowFilter enumeration
wdShowFilterFormattingAvailable = 4
wdShowFilterFormattingInUse = 3
wdShowFilterStylesAll = 2
wdShowFilterStylesAvailable = 0
wdShowFilterStylesInUse = 1
wdShowFilterFormattingRecommended = 5

# WdShowSourceDocuments enumeration
wdShowSourceDocumentsBoth = 3
wdShowSourceDocumentsNone = 0
wdShowSourceDocumentsOriginal = 1
wdShowSourceDocumentsRevised = 2

# WdSmartTagControlType enumeration
wdControlActiveX = 13
wdControlButton = 6
wdControlCheckbox = 9
wdControlCombo = 12
wdControlDocumentFragment = 14
wdControlDocumentFragmentURL = 15
wdControlHelp = 3
wdControlHelpURL = 4
wdControlImage = 8
wdControlLabel = 7
wdControlLink = 2
wdControlListbox = 11
wdControlRadioGroup = 16
wdControlSeparator = 5
wdControlSmartTag = 1
wdControlTextbox = 10

# WdSortFieldType enumeration
wdSortFieldAlphanumeric = 0
wdSortFieldDate = 2
wdSortFieldJapanJIS = 4
wdSortFieldKoreaKS = 6
wdSortFieldNumeric = 1
wdSortFieldStroke = 5
wdSortFieldSyllable = 3

# WdSortOrder enumeration
wdSortOrderAscending = 0
wdSortOrderDescending = 1

# WdSortSeparator enumeration
wdSortSeparateByCommas = 1
wdSortSeparateByDefaultTableSeparator = 2
wdSortSeparateByTabs = 0

# WdSpanishSpeller enumeration
wdSpanishTuteoAndVoseo = 1
wdSpanishTuteoOnly = 0
wdSpanishVoseoOnly = 2

# WdSpecialPane enumeration
wdPaneComments = 15
wdPaneCurrentPageFooter = 17
wdPaneCurrentPageHeader = 16
wdPaneEndnoteContinuationNotice = 12
wdPaneEndnoteContinuationSeparator = 13
wdPaneEndnotes = 8
wdPaneEndnoteSeparator = 14
wdPaneEvenPagesFooter = 6
wdPaneEvenPagesHeader = 3
wdPaneFirstPageFooter = 5
wdPaneFirstPageHeader = 2
wdPaneFootnoteContinuationNotice = 9
wdPaneFootnoteContinuationSeparator = 10
wdPaneFootnotes = 7
wdPaneFootnoteSeparator = 11
wdPaneNone = 0
wdPanePrimaryFooter = 4
wdPanePrimaryHeader = 1
wdPaneRevisions = 18
wdPaneRevisionsHoriz = 19
wdPaneRevisionsVert = 20

# WdSpellingErrorType enumeration
wdSpellingCapitalization = 2
wdSpellingCorrect = 0
wdSpellingNotInDictionary = 1

# WdSpellingWordType enumeration
wdAnagram = 2
wdSpellword = 0
wdWildcard = 1

# WdStatistic enumeration
wdStatisticCharacters = 3
wdStatisticCharactersWithSpaces = 5
wdStatisticFarEastCharacters = 6
wdStatisticLines = 1
wdStatisticPages = 2
wdStatisticParagraphs = 4
wdStatisticWords = 0

# WdStoryType enumeration
wdCommentsStory = 4
wdEndnoteContinuationNoticeStory = 17
wdEndnoteContinuationSeparatorStory = 16
wdEndnoteSeparatorStory = 15
wdEndnotesStory = 3
wdEvenPagesFooterStory = 8
wdEvenPagesHeaderStory = 6
wdFirstPageFooterStory = 11
wdFirstPageHeaderStory = 10
wdFootnoteContinuationNoticeStory = 14
wdFootnoteContinuationSeparatorStory = 13
wdFootnoteSeparatorStory = 12
wdFootnotesStory = 2
wdMainTextStory = 1
wdPrimaryFooterStory = 9
wdPrimaryHeaderStory = 7
wdTextFrameStory = 5

# WdStyleSheetLinkType enumeration
wdStyleSheetLinkTypeImported = 1
wdStyleSheetLinkTypeLinked = 0

# WdStyleSheetPrecedence enumeration
wdStyleSheetPrecedenceHigher = -1
wdStyleSheetPrecedenceHighest = 1
wdStyleSheetPrecedenceLower = -2
wdStyleSheetPrecedenceLowest = 0

# WdStyleSort enumeration
wdStyleSortByBasedOn = 3
wdStyleSortByFont = 2
wdStyleSortByName = 0
wdStyleSortByType = 4
wdStyleSortRecommended = 1

# WdStyleType enumeration
wdStyleTypeCharacter = 2
wdStyleTypeList = 4
wdStyleTypeParagraph = 1
wdStyleTypeTable = 3

# WdStylisticSet enumeration
wdStylisticSet01 = 1
wdStylisticSet02 = 2
wdStylisticSet03 = 4
wdStylisticSet04 = 8
wdStylisticSet05 = 16
wdStylisticSet06 = 32
wdStylisticSet07 = 64
wdStylisticSet08 = 128
wdStylisticSet09 = 256
wdStylisticSet10 = 512
wdStylisticSet11 = 1024
wdStylisticSet12 = 2048
wdStylisticSet13 = 4096
wdStylisticSet14 = 8192
wdStylisticSet15 = 16384
wdStylisticSet16 = 32768
wdStylisticSet17 = 65536
wdStylisticSet18 = 131072
wdStylisticSet19 = 262144
wdStylisticSet20 = 524288
wdStylisticSetDefault = 0

# WdSubscriberFormats enumeration
wdSubscriberBestFormat = 0
wdSubscriberPict = 4
wdSubscriberRTF = 1
wdSubscriberText = 2

# WdTabAlignment enumeration
wdAlignTabBar = 4
wdAlignTabCenter = 1
wdAlignTabDecimal = 3
wdAlignTabLeft = 0
wdAlignTabList = 6
wdAlignTabRight = 2

# WdTabLeader enumeration
wdTabLeaderDashes = 2
wdTabLeaderDots = 1
wdTabLeaderHeavy = 4
wdTabLeaderLines = 3
wdTabLeaderMiddleDot = 5
wdTabLeaderSpaces = 0

# WdTableDirection enumeration
wdTableDirectionLtr = 1
wdTableDirectionRtl = 0

# WdTableFieldSeparator enumeration
wdSeparateByCommas = 2
wdSeparateByDefaultListSeparator = 3
wdSeparateByParagraphs = 0
wdSeparateByTabs = 1

# WdTableFormat enumeration
wdTableFormat3DEffects1 = 32
wdTableFormat3DEffects2 = 33
wdTableFormat3DEffects3 = 34
wdTableFormatClassic1 = 4
wdTableFormatClassic2 = 5
wdTableFormatClassic3 = 6
wdTableFormatClassic4 = 7
wdTableFormatColorful1 = 8
wdTableFormatColorful2 = 9
wdTableFormatColorful3 = 10
wdTableFormatColumns1 = 11
wdTableFormatColumns2 = 12
wdTableFormatColumns3 = 13
wdTableFormatColumns4 = 14
wdTableFormatColumns5 = 15
wdTableFormatContemporary = 35
wdTableFormatElegant = 36
wdTableFormatGrid1 = 16
wdTableFormatGrid2 = 17
wdTableFormatGrid3 = 18
wdTableFormatGrid4 = 19
wdTableFormatGrid5 = 20
wdTableFormatGrid6 = 21
wdTableFormatGrid7 = 22
wdTableFormatGrid8 = 23
wdTableFormatList1 = 24
wdTableFormatList2 = 25
wdTableFormatList3 = 26
wdTableFormatList4 = 27
wdTableFormatList5 = 28
wdTableFormatList6 = 29
wdTableFormatList7 = 30
wdTableFormatList8 = 31
wdTableFormatNone = 0
wdTableFormatProfessional = 37
wdTableFormatSimple1 = 1
wdTableFormatSimple2 = 2
wdTableFormatSimple3 = 3
wdTableFormatSubtle1 = 38
wdTableFormatSubtle2 = 39
wdTableFormatWeb1 = 40
wdTableFormatWeb2 = 41
wdTableFormatWeb3 = 42

# WdTableFormatApply enumeration
wdTableFormatApplyAutoFit = 16
wdTableFormatApplyBorders = 1
wdTableFormatApplyColor = 8
wdTableFormatApplyFirstColumn = 128
wdTableFormatApplyFont = 4
wdTableFormatApplyHeadingRows = 32
wdTableFormatApplyLastColumn = 256
wdTableFormatApplyLastRow = 64
wdTableFormatApplyShading = 2

# WdTablePosition enumeration
wdTableBottom = -999997
wdTableCenter = -999995
wdTableInside = -999994
wdTableLeft = -999998
wdTableOutside = -999993
wdTableRight = -999996
wdTableTop = -999999

# WdTaskPanes enumeration
wdTaskPaneApplyStyles = 17
wdTaskPaneDocumentActions = 7
wdTaskPaneDocumentProtection = 6
wdTaskPaneFaxService = 11
wdTaskPaneFormatting = 0
wdTaskPaneHelp = 9
wdTaskPaneMailMerge = 2
wdTaskPaneProofing = 20
wdTaskPaneResearch = 10
wdTaskPaneRevealFormatting = 1
wdTaskPaneRevPaneFlex = 22
wdTaskPaneSearch = 4
wdTaskPaneSignature = 14
wdTaskPaneStyleInspector = 15
wdTaskPaneThesaurus = 23
wdTaskPaneTranslate = 3
wdTaskPaneXMLDocument = 12
wdTaskPaneXMLMapping = 21
wdTaskPaneXMLStructure = 5

# WdTCSCConverterDirection enumeration
wdTCSCConverterDirectionAuto = 2
wdTCSCConverterDirectionSCTC = 0
wdTCSCConverterDirectionTCSC = 1

# WdTemplateType enumeration
wdAttachedTemplate = 2
wdGlobalTemplate = 1
wdNormalTemplate = 0

# WdTextboxTightWrap enumeration
wdTightAll = 1
wdTightFirstAndLastLines = 2
wdTightFirstLineOnly = 3
wdTightLastLineOnly = 4
wdTightNone = 0

# WdTextFormFieldType enumeration
wdCalculationText = 5
wdCurrentDateText = 3
wdCurrentTimeText = 4
wdDateText = 2
wdNumberText = 1
wdRegularText = 0

# WdTextOrientation enumeration
wdTextOrientationDownward = 3
wdTextOrientationHorizontal = 0
wdTextOrientationHorizontalRotatedFarEast = 4
wdTextOrientationUpward = 2
wdTextOrientationVerticalFarEast = 1
wdTextOrientationVertical = 5

# WdTextureIndex enumeration
wdTexture10Percent = 100
wdTexture12Pt5Percent = 125
wdTexture15Percent = 150
wdTexture17Pt5Percent = 175
wdTexture20Percent = 200
wdTexture22Pt5Percent = 225
wdTexture25Percent = 250
wdTexture27Pt5Percent = 275
wdTexture2Pt5Percent = 25
wdTexture30Percent = 300
wdTexture32Pt5Percent = 325
wdTexture35Percent = 350
wdTexture37Pt5Percent = 375
wdTexture40Percent = 400
wdTexture42Pt5Percent = 425
wdTexture45Percent = 450
wdTexture47Pt5Percent = 475
wdTexture50Percent = 500
wdTexture52Pt5Percent = 525
wdTexture55Percent = 550
wdTexture57Pt5Percent = 575
wdTexture5Percent = 50
wdTexture60Percent = 600
wdTexture62Pt5Percent = 625
wdTexture65Percent = 650
wdTexture67Pt5Percent = 675
wdTexture70Percent = 700
wdTexture72Pt5Percent = 725
wdTexture75Percent = 750
wdTexture77Pt5Percent = 775
wdTexture7Pt5Percent = 75
wdTexture80Percent = 800
wdTexture82Pt5Percent = 825
wdTexture85Percent = 850
wdTexture87Pt5Percent = 875
wdTexture90Percent = 900
wdTexture92Pt5Percent = 925
wdTexture95Percent = 950
wdTexture97Pt5Percent = 975
wdTextureCross = -11
wdTextureDarkCross = -5
wdTextureDarkDiagonalCross = -6
wdTextureDarkDiagonalDown = -3
wdTextureDarkDiagonalUp = -4
wdTextureDarkHorizontal = -1
wdTextureDarkVertical = -2
wdTextureDiagonalCross = -12
wdTextureDiagonalDown = -9
wdTextureDiagonalUp = -10
wdTextureHorizontal = -7
wdTextureNone = 0
wdTextureSolid = 1000
wdTextureVertical = -8

# WdThemeColorIndex enumeration
wdNotThemeColor = -1
wdThemeColorAccent1 = 4
wdThemeColorAccent2 = 5
wdThemeColorAccent3 = 6
wdThemeColorAccent4 = 7
wdThemeColorAccent5 = 8
wdThemeColorAccent6 = 9
wdThemeColorBackground1 = 12
wdThemeColorBackground2 = 14
wdThemeColorHyperlink = 10
wdThemeColorHyperlinkFollowed = 11
wdThemeColorMainDark1 = 0
wdThemeColorMainDark2 = 2
wdThemeColorMainLight1 = 1
wdThemeColorMainLight2 = 3
wdThemeColorText1 = 13
wdThemeColorText2 = 15

# WdToaFormat enumeration
wdTOAClassic = 1
wdTOADistinctive = 2
wdTOAFormal = 3
wdTOASimple = 4
wdTOATemplate = 0

# WdTocFormat enumeration
wdTOCClassic = 1
wdTOCDistinctive = 2
wdTOCFancy = 3
wdTOCFormal = 5
wdTOCModern = 4
wdTOCSimple = 6
wdTOCTemplate = 0

# WdTofFormat enumeration
wdTOFCentered = 3
wdTOFClassic = 1
wdTOFDistinctive = 2
wdTOFFormal = 4
wdTOFSimple = 5
wdTOFTemplate = 0

# WdTrailingCharacter enumeration
wdTrailingNone = 2
wdTrailingSpace = 1
wdTrailingTab = 0

# WdTwoLinesInOneType enumeration
wdTwoLinesInOneAngleBrackets = 4
wdTwoLinesInOneCurlyBrackets = 5
wdTwoLinesInOneNoBrackets = 1
wdTwoLinesInOneNone = 0
wdTwoLinesInOneParentheses = 2
wdTwoLinesInOneSquareBrackets = 3

# WdUnderline enumeration
wdUnderlineDash = 7
wdUnderlineDashHeavy = 23
wdUnderlineDashLong = 39
wdUnderlineDashLongHeavy = 55
wdUnderlineDotDash = 9
wdUnderlineDotDashHeavy = 25
wdUnderlineDotDotDash = 10
wdUnderlineDotDotDashHeavy = 26
wdUnderlineDotted = 4
wdUnderlineDottedHeavy = 20
wdUnderlineDouble = 3
wdUnderlineNone = 0
wdUnderlineSingle = 1
wdUnderlineThick = 6
wdUnderlineWavy = 11
wdUnderlineWavyDouble = 43
wdUnderlineWavyHeavy = 27
wdUnderlineWords = 2

# WdUnits enumeration
wdCell = 12
wdCharacter = 1
wdCharacterFormatting = 13
wdColumn = 9
wdItem = 16
wdLine = 5
wdParagraph = 4
wdParagraphFormatting = 14
wdRow = 10
wdScreen = 7
wdSection = 8
wdSentence = 3
wdStory = 6
wdTable = 15
wdWindow = 11
wdWord = 2

# WdUpdateStyleListBehavior enumeration
wdListBehaviorAddBulletsNumbering = 1
wdListBehaviorKeepPreviousPattern = 0

# WdUseFormattingFrom enumeration
wdFormattingFromCurrent = 0
wdFormattingFromPrompt = 2
wdFormattingFromSelected = 1

# WdVerticalAlignment enumeration
wdAlignVerticalBottom = 3
wdAlignVerticalCenter = 1
wdAlignVerticalJustify = 2
wdAlignVerticalTop = 0

# WdViewType enumeration
wdMasterView = 5
wdNormalView = 1
wdOutlineView = 2
wdPrintPreview = 4
wdPrintView = 3
wdReadingView = 7
wdWebView = 6

# WdVisualSelection enumeration
wdVisualSelectionBlock = 0
wdVisualSelectionContinuous = 1

# WdWindowState enumeration
wdWindowStateMaximize = 1
wdWindowStateMinimize = 2
wdWindowStateNormal = 0

# WdWindowType enumeration
wdWindowDocument = 0
wdWindowTemplate = 1

# WdWordDialog enumeration
wdDialogBuildingBlockOrganizer = 2067
wdDialogConnect = 420
wdDialogConsistencyChecker = 1121
wdDialogContentControlProperties = 2394
wdDialogControlRun = 235
wdDialogConvertObject = 392
wdDialogCopyFile = 300
wdDialogCreateAutoText = 872
wdDialogCreateSource = 1922
wdDialogCSSLinks = 1261
wdDialogDocumentInspector = 1482
wdDialogDocumentStatistics = 78
wdDialogDrawAlign = 634
wdDialogDrawSnapToGrid = 633
wdDialogEditAutoText = 985
wdDialogEditCreatePublisher = 732
wdDialogEditFind = 112
wdDialogEditFrame = 458
wdDialogEditGoTo = 896
wdDialogEditGoToOld = 811
wdDialogEditLinks = 124
wdDialogEditObject = 125
wdDialogEditPasteSpecial = 111
wdDialogEditPublishOptions = 735
wdDialogEditReplace = 117
wdDialogEditStyle = 120
wdDialogEditSubscribeOptions = 736
wdDialogEditSubscribeTo = 733
wdDialogEditTOACategory = 625
wdDialogEmailOptions = 863
wdDialogFileDocumentLayout = 178
wdDialogFileFind = 99
wdDialogFileMacCustomPageSetupGX = 737
wdDialogFileMacPageSetup = 685
wdDialogFileMacPageSetupGX = 444
wdDialogFileNew = 79
wdDialogFileOpen = 80
wdDialogFilePageSetup = 178
wdDialogFilePrint = 88
wdDialogFilePrintOneCopy = 445
wdDialogFilePrintSetup = 97
wdDialogFileRoutingSlip = 624
wdDialogFileSaveAs = 84
wdDialogFileSaveVersion = 1007
wdDialogFileSummaryInfo = 86
wdDialogFileVersions = 945
wdDialogFitText = 983
wdDialogFontSubstitution = 581
wdDialogFormatAddrFonts = 103
wdDialogFormatBordersAndShading = 189
wdDialogFormatBulletsAndNumbering = 824
wdDialogFormatCallout = 610
wdDialogFormatChangeCase = 322
wdDialogFormatColumns = 177
wdDialogFormatDefineStyleBorders = 185
wdDialogFormatDefineStyleFont = 181
wdDialogFormatDefineStyleFrame = 184
wdDialogFormatDefineStyleLang = 186
wdDialogFormatDefineStylePara = 182
wdDialogFormatDefineStyleTabs = 183
wdDialogFormatDrawingObject = 960
wdDialogFormatDropCap = 488
wdDialogFormatEncloseCharacters = 1162
wdDialogFormatFont = 174
wdDialogFormatFrame = 190
wdDialogFormatPageNumber = 298
wdDialogFormatParagraph = 175
wdDialogFormatPicture = 187
wdDialogFormatRetAddrFonts = 221
wdDialogFormatSectionLayout = 176
wdDialogFormatStyle = 180
wdDialogFormatStyleGallery = 505
wdDialogFormatStylesCustom = 1248
wdDialogFormatTabs = 179
wdDialogFormatTheme = 855
wdDialogFormattingRestrictions = 1427
wdDialogFormFieldHelp = 361
wdDialogFormFieldOptions = 353
wdDialogFrameSetProperties = 1074
wdDialogHelpAbout = 9
wdDialogHelpWordPerfectHelp = 10
wdDialogHelpWordPerfectHelpOptions = 511
wdDialogHorizontalInVertical = 1160
wdDialogIMESetDefault = 1094
wdDialogInsertAddCaption = 402
wdDialogInsertAutoCaption = 359
wdDialogInsertBookmark = 168
wdDialogInsertBreak = 159
wdDialogInsertCaption = 357
wdDialogInsertCaptionNumbering = 358
wdDialogInsertCrossReference = 367
wdDialogInsertDatabase = 341
wdDialogInsertDateTime = 165
wdDialogInsertField = 166
wdDialogInsertFile = 164
wdDialogInsertFootnote = 370
wdDialogInsertFormField = 483
wdDialogInsertHyperlink = 925
wdDialogInsertIndex = 170
wdDialogInsertIndexAndTables = 473
wdDialogInsertMergeField = 167
wdDialogInsertNumber = 812
wdDialogInsertObject = 172
wdDialogInsertPageNumbers = 294
wdDialogInsertPicture = 163
wdDialogInsertPlaceholder = 2348
wdDialogInsertSource = 2120
wdDialogInsertSubdocument = 583
wdDialogInsertSymbol = 162
wdDialogInsertTableOfAuthorities = 471
wdDialogInsertTableOfContents = 171
wdDialogInsertTableOfFigures = 472
wdDialogInsertWebComponent = 1324
wdDialogLabelOptions = 1367
wdDialogLetterWizard = 821
wdDialogListCommands = 723
wdDialogMailMerge = 676
wdDialogMailMergeCheck = 677
wdDialogMailMergeCreateDataSource = 642
wdDialogMailMergeCreateHeaderSource = 643
wdDialogMailMergeFieldMapping = 1304
wdDialogMailMergeFindRecipient = 1326
wdDialogMailMergeFindRecord = 569
wdDialogMailMergeHelper = 680
wdDialogMailMergeInsertAddressBlock = 1305
wdDialogMailMergeInsertAsk = 4047
wdDialogMailMergeInsertFields = 1307
wdDialogMailMergeInsertFillIn = 4048
wdDialogMailMergeInsertGreetingLine = 1306
wdDialogMailMergeInsertIf = 4049
wdDialogMailMergeInsertNextIf = 4053
wdDialogMailMergeInsertSet = 4054
wdDialogMailMergeInsertSkipIf = 4055
wdDialogMailMergeOpenDataSource = 81
wdDialogMailMergeOpenHeaderSource = 82
wdDialogMailMergeQueryOptions = 681
wdDialogMailMergeRecipients = 1308
wdDialogMailMergeSetDocumentType = 1339
wdDialogMailMergeUseAddressBook = 779
wdDialogMarkCitation = 463
wdDialogMarkIndexEntry = 169
wdDialogMarkTableOfContentsEntry = 442
wdDialogMyPermission = 1437
wdDialogNewToolbar = 586
wdDialogNoteOptions = 373
wdDialogOMathRecognizedFunctions = 2165
wdDialogOrganizer = 222
wdDialogPermission = 1469
wdDialogPhoneticGuide = 986
wdDialogReviewAfmtRevisions = 570
wdDialogSchemaLibrary = 1417
wdDialogSearch = 1363
wdDialogShowRepairs = 1381
wdDialogSourceManager = 1920
wdDialogStyleManagement = 1948
wdDialogTableAutoFormat = 563
wdDialogTableCellOptions = 1081
wdDialogTableColumnWidth = 143
wdDialogTableDeleteCells = 133
wdDialogTableFormatCell = 612
wdDialogTableFormula = 348
wdDialogTableInsertCells = 130
wdDialogTableInsertRow = 131
wdDialogTableInsertTable = 129
wdDialogTableOfCaptionsOptions = 551
wdDialogTableOfContentsOptions = 470
wdDialogTableProperties = 861
wdDialogTableRowHeight = 142
wdDialogTableSort = 199
wdDialogTableSplitCells = 137
wdDialogTableTableOptions = 1080
wdDialogTableToText = 128
wdDialogTableWrapping = 854
wdDialogTCSCTranslator = 1156
wdDialogTextToTable = 127
wdDialogToolsAcceptRejectChanges = 506
wdDialogToolsAdvancedSettings = 206
wdDialogToolsAutoCorrect = 378
wdDialogToolsAutoCorrectExceptions = 762
wdDialogToolsAutoManager = 915
wdDialogToolsAutoSummarize = 874
wdDialogToolsBulletsNumbers = 196
wdDialogToolsCompareDocuments = 198
wdDialogToolsCreateDirectory = 833
wdDialogToolsCreateEnvelope = 173
wdDialogToolsCreateLabels = 489
wdDialogToolsCustomize = 152
wdDialogToolsCustomizeKeyboard = 432
wdDialogToolsCustomizeMenuBar = 615
wdDialogToolsCustomizeMenus = 433
wdDialogToolsDictionary = 989
wdDialogToolsEnvelopesAndLabels = 607
wdDialogToolsGrammarSettings = 885
wdDialogToolsHangulHanjaConversion = 784
wdDialogToolsHighlightChanges = 197
wdDialogToolsHyphenation = 195
wdDialogToolsLanguage = 188
wdDialogToolsMacro = 215
wdDialogToolsMacroRecord = 214
wdDialogToolsManageFields = 631
wdDialogToolsMergeDocuments = 435
wdDialogToolsOptions = 974
wdDialogToolsOptionsAutoFormat = 959
wdDialogToolsOptionsAutoFormatAsYouType = 778
wdDialogToolsOptionsBidi = 1029
wdDialogToolsOptionsCompatibility = 525
wdDialogToolsOptionsEdit = 224
wdDialogToolsOptionsEditCopyPaste = 1356
wdDialogToolsOptionsFileLocations = 225
wdDialogToolsOptionsFuzzy = 790
wdDialogToolsOptionsGeneral = 203
wdDialogToolsOptionsPrint = 208
wdDialogToolsOptionsSave = 209
wdDialogToolsOptionsSecurity = 1361
wdDialogToolsOptionsSmartTag = 1395
wdDialogToolsOptionsSpellingAndGrammar = 211
wdDialogToolsOptionsTrackChanges = 386
wdDialogToolsOptionsTypography = 739
wdDialogToolsOptionsUserInfo = 213
wdDialogToolsOptionsView = 204
wdDialogToolsProtectDocument = 503
wdDialogToolsProtectSection = 578
wdDialogToolsRevisions = 197
wdDialogToolsSpellingAndGrammar = 828
wdDialogToolsTemplates = 87
wdDialogToolsThesaurus = 194
wdDialogToolsUnprotectDocument = 521
wdDialogToolsWordCount = 228
wdDialogTwoLinesInOne = 1161
wdDialogUpdateTOC = 331
wdDialogViewZoom = 577
wdDialogWebOptions = 898
wdDialogWindowActivate = 220
wdDialogXMLElementAttributes = 1460
wdDialogXMLOptions = 1425

# WdWordDialogTab enumeration
wdDialogEmailOptionsTabQuoting = 1900002
wdDialogEmailOptionsTabSignature = 1900000
wdDialogEmailOptionsTabStationary = 1900001
wdDialogFilePageSetupTabCharsLines = 150004
wdDialogFilePageSetupTabLayout = 150003
wdDialogFilePageSetupTabMargins = 150000
wdDialogFilePageSetupTabPaper = 150001
wdDialogFormatBordersAndShadingTabBorders = 700000
wdDialogFormatBordersAndShadingTabPageBorder = 700001
wdDialogFormatBordersAndShadingTabShading = 700002
wdDialogFormatBulletsAndNumberingTabBulleted = 1500000
wdDialogFormatBulletsAndNumberingTabNumbered = 1500001
wdDialogFormatBulletsAndNumberingTabOutlineNumbered = 1500002
wdDialogFormatDrawingObjectTabColorsAndLines = 1200000
wdDialogFormatDrawingObjectTabHR = 1200007
wdDialogFormatDrawingObjectTabPicture = 1200004
wdDialogFormatDrawingObjectTabPosition = 1200002
wdDialogFormatDrawingObjectTabSize = 1200001
wdDialogFormatDrawingObjectTabTextbox = 1200005
wdDialogFormatDrawingObjectTabWeb = 1200006
wdDialogFormatDrawingObjectTabWrapping = 1200003
wdDialogFormatFontTabAnimation = 600002
wdDialogFormatFontTabCharacterSpacing = 600001
wdDialogFormatFontTabFont = 600000
wdDialogFormatParagraphTabIndentsAndSpacing = 1000000
wdDialogFormatParagraphTabTeisai = 1000002
wdDialogFormatParagraphTabTextFlow = 1000001
wdDialogInsertIndexAndTablesTabIndex = 400000
wdDialogInsertIndexAndTablesTabTableOfAuthorities = 400003
wdDialogInsertIndexAndTablesTabTableOfContents = 400001
wdDialogInsertIndexAndTablesTabTableOfFigures = 400002
wdDialogInsertSymbolTabSpecialCharacters = 200001
wdDialogInsertSymbolTabSymbols = 200000
wdDialogLetterWizardTabLetterFormat = 1600000
wdDialogLetterWizardTabOtherElements = 1600002
wdDialogLetterWizardTabRecipientInfo = 1600001
wdDialogLetterWizardTabSenderInfo = 1600003
wdDialogNoteOptionsTabAllEndnotes = 300001
wdDialogNoteOptionsTabAllFootnotes = 300000
wdDialogOrganizerTabAutoText = 500001
wdDialogOrganizerTabCommandBars = 500002
wdDialogOrganizerTabMacros = 500003
wdDialogOrganizerTabStyles = 500000
wdDialogTablePropertiesTabCell = 1800003
wdDialogTablePropertiesTabColumn = 1800002
wdDialogTablePropertiesTabRow = 1800001
wdDialogTablePropertiesTabTable = 1800000
wdDialogTemplates = 2100000
wdDialogTemplatesLinkedCSS = 2100003
wdDialogTemplatesXMLExpansionPacks = 2100002
wdDialogTemplatesXMLSchema = 2100001
wdDialogToolsAutoCorrectExceptionsTabFirstLetter = 1400000
wdDialogToolsAutoCorrectExceptionsTabHangulAndAlphabet = 1400002
wdDialogToolsAutoCorrectExceptionsTabIac = 1400003
wdDialogToolsAutoCorrectExceptionsTabInitialCaps = 1400001
wdDialogToolsAutoManagerTabAutoCorrect = 1700000
wdDialogToolsAutoManagerTabAutoFormat = 1700003
wdDialogToolsAutoManagerTabAutoFormatAsYouType = 1700001
wdDialogToolsAutoManagerTabAutoText = 1700002
wdDialogToolsAutoManagerTabSmartTags = 1700004
wdDialogToolsEnvelopesAndLabelsTabEnvelopes = 800000
wdDialogToolsEnvelopesAndLabelsTabLabels = 800001
wdDialogToolsOptionsTabAcetate = 1266
wdDialogToolsOptionsTabBidi = 1029
wdDialogToolsOptionsTabCompatibility = 525
wdDialogToolsOptionsTabEdit = 224
wdDialogToolsOptionsTabFileLocations = 225
wdDialogToolsOptionsTabFuzzy = 790
wdDialogToolsOptionsTabGeneral = 203
wdDialogToolsOptionsTabHangulHanjaConversion = 786
wdDialogToolsOptionsTabPrint = 208
wdDialogToolsOptionsTabProofread = 211
wdDialogToolsOptionsTabSave = 209
wdDialogToolsOptionsTabSecurity = 1361
wdDialogToolsOptionsTabTrackChanges = 386
wdDialogToolsOptionsTabTypography = 739
wdDialogToolsOptionsTabUserInfo = 213
wdDialogToolsOptionsTabView = 204
wdDialogWebOptionsBrowsers = 2000000
wdDialogWebOptionsEncoding = 2000003
wdDialogWebOptionsFiles = 2000001
wdDialogWebOptionsFonts = 2000004
wdDialogWebOptionsGeneral = 2000000
wdDialogWebOptionsPictures = 2000002
wdDialogStyleManagementTabEdit = 2200000
wdDialogStyleManagementTabRecommend = 2200001
wdDialogStyleManagementTabRestrict = 2200002

# WdWrapSideType enumeration
wdWrapBoth = 0
wdWrapLargest = 3
wdWrapLeft = 1
wdWrapRight = 2

# WdWrapType enumeration
wdWrapInline = 7
wdWrapNone = 3
wdWrapSquare = 0
wdWrapThrough = 2
wdWrapTight = 1
wdWrapTopBottom = 4
wdWrapBehind = 5
wdWrapFront = 3

# WdWrapTypeMerged enumeration
wdWrapMergeBehind = 3
wdWrapMergeFront = 4
wdWrapMergeInline = 0
wdWrapMergeSquare = 1
wdWrapMergeThrough = 5
wdWrapMergeTight = 2
wdWrapMergeTopBottom = 6

class WebOptions:

    def __init__(self, weboptions=None):
        self.com_object= weboptions

    @property
    def AllowPNG(self):
        return self.com_object.AllowPNG

    @AllowPNG.setter
    def AllowPNG(self, value):
        self.com_object.AllowPNG = value

    @property
    def allowpng(self):
        """Alias for AllowPNG"""
        return self.AllowPNG

    @allowpng.setter
    def allowpng(self, value):
        """Alias for AllowPNG.setter"""
        self.AllowPNG = value

    @property
    def allow_p_n_g(self):
        """Alias for AllowPNG"""
        return self.AllowPNG

    @allow_p_n_g.setter
    def allow_p_n_g(self, value):
        """Alias for AllowPNG.setter"""
        self.AllowPNG = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BrowserLevel(self):
        return WdBrowserLevel(self.com_object.BrowserLevel)

    @BrowserLevel.setter
    def BrowserLevel(self, value):
        self.com_object.BrowserLevel = value

    @property
    def browserlevel(self):
        """Alias for BrowserLevel"""
        return self.BrowserLevel

    @browserlevel.setter
    def browserlevel(self, value):
        """Alias for BrowserLevel.setter"""
        self.BrowserLevel = value

    @property
    def browser_level(self):
        """Alias for BrowserLevel"""
        return self.BrowserLevel

    @browser_level.setter
    def browser_level(self, value):
        """Alias for BrowserLevel.setter"""
        self.BrowserLevel = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Encoding(self):
        return self.com_object.Encoding

    @Encoding.setter
    def Encoding(self, value):
        self.com_object.Encoding = value

    @property
    def encoding(self):
        """Alias for Encoding"""
        return self.Encoding

    @encoding.setter
    def encoding(self, value):
        """Alias for Encoding.setter"""
        self.Encoding = value

    @property
    def FolderSuffix(self):
        return self.com_object.FolderSuffix

    @property
    def foldersuffix(self):
        """Alias for FolderSuffix"""
        return self.FolderSuffix

    @property
    def folder_suffix(self):
        """Alias for FolderSuffix"""
        return self.FolderSuffix

    @property
    def OptimizeForBrowser(self):
        return self.com_object.OptimizeForBrowser

    @OptimizeForBrowser.setter
    def OptimizeForBrowser(self, value):
        self.com_object.OptimizeForBrowser = value

    @property
    def optimizeforbrowser(self):
        """Alias for OptimizeForBrowser"""
        return self.OptimizeForBrowser

    @optimizeforbrowser.setter
    def optimizeforbrowser(self, value):
        """Alias for OptimizeForBrowser.setter"""
        self.OptimizeForBrowser = value

    @property
    def optimize_for_browser(self):
        """Alias for OptimizeForBrowser"""
        return self.OptimizeForBrowser

    @optimize_for_browser.setter
    def optimize_for_browser(self, value):
        """Alias for OptimizeForBrowser.setter"""
        self.OptimizeForBrowser = value

    @property
    def OrganizeInFolder(self):
        return self.com_object.OrganizeInFolder

    @OrganizeInFolder.setter
    def OrganizeInFolder(self, value):
        self.com_object.OrganizeInFolder = value

    @property
    def organizeinfolder(self):
        """Alias for OrganizeInFolder"""
        return self.OrganizeInFolder

    @organizeinfolder.setter
    def organizeinfolder(self, value):
        """Alias for OrganizeInFolder.setter"""
        self.OrganizeInFolder = value

    @property
    def organize_in_folder(self):
        """Alias for OrganizeInFolder"""
        return self.OrganizeInFolder

    @organize_in_folder.setter
    def organize_in_folder(self, value):
        """Alias for OrganizeInFolder.setter"""
        self.OrganizeInFolder = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PixelsPerInch(self):
        return self.com_object.PixelsPerInch

    @PixelsPerInch.setter
    def PixelsPerInch(self, value):
        self.com_object.PixelsPerInch = value

    @property
    def pixelsperinch(self):
        """Alias for PixelsPerInch"""
        return self.PixelsPerInch

    @pixelsperinch.setter
    def pixelsperinch(self, value):
        """Alias for PixelsPerInch.setter"""
        self.PixelsPerInch = value

    @property
    def pixels_per_inch(self):
        """Alias for PixelsPerInch"""
        return self.PixelsPerInch

    @pixels_per_inch.setter
    def pixels_per_inch(self, value):
        """Alias for PixelsPerInch.setter"""
        self.PixelsPerInch = value

    @property
    def RelyOnCSS(self):
        return self.com_object.RelyOnCSS

    @RelyOnCSS.setter
    def RelyOnCSS(self, value):
        self.com_object.RelyOnCSS = value

    @property
    def relyoncss(self):
        """Alias for RelyOnCSS"""
        return self.RelyOnCSS

    @relyoncss.setter
    def relyoncss(self, value):
        """Alias for RelyOnCSS.setter"""
        self.RelyOnCSS = value

    @property
    def rely_on_c_s_s(self):
        """Alias for RelyOnCSS"""
        return self.RelyOnCSS

    @rely_on_c_s_s.setter
    def rely_on_c_s_s(self, value):
        """Alias for RelyOnCSS.setter"""
        self.RelyOnCSS = value

    @property
    def RelyOnVML(self):
        return self.com_object.RelyOnVML

    @RelyOnVML.setter
    def RelyOnVML(self, value):
        self.com_object.RelyOnVML = value

    @property
    def relyonvml(self):
        """Alias for RelyOnVML"""
        return self.RelyOnVML

    @relyonvml.setter
    def relyonvml(self, value):
        """Alias for RelyOnVML.setter"""
        self.RelyOnVML = value

    @property
    def rely_on_v_m_l(self):
        """Alias for RelyOnVML"""
        return self.RelyOnVML

    @rely_on_v_m_l.setter
    def rely_on_v_m_l(self, value):
        """Alias for RelyOnVML.setter"""
        self.RelyOnVML = value

    @property
    def ScreenSize(self):
        return self.com_object.ScreenSize

    @ScreenSize.setter
    def ScreenSize(self, value):
        self.com_object.ScreenSize = value

    @property
    def screensize(self):
        """Alias for ScreenSize"""
        return self.ScreenSize

    @screensize.setter
    def screensize(self, value):
        """Alias for ScreenSize.setter"""
        self.ScreenSize = value

    @property
    def screen_size(self):
        """Alias for ScreenSize"""
        return self.ScreenSize

    @screen_size.setter
    def screen_size(self, value):
        """Alias for ScreenSize.setter"""
        self.ScreenSize = value

    @property
    def TargetBrowser(self):
        return self.com_object.TargetBrowser

    @TargetBrowser.setter
    def TargetBrowser(self, value):
        self.com_object.TargetBrowser = value

    @property
    def targetbrowser(self):
        """Alias for TargetBrowser"""
        return self.TargetBrowser

    @targetbrowser.setter
    def targetbrowser(self, value):
        """Alias for TargetBrowser.setter"""
        self.TargetBrowser = value

    @property
    def target_browser(self):
        """Alias for TargetBrowser"""
        return self.TargetBrowser

    @target_browser.setter
    def target_browser(self, value):
        """Alias for TargetBrowser.setter"""
        self.TargetBrowser = value

    @property
    def UseLongFileNames(self):
        return self.com_object.UseLongFileNames

    @UseLongFileNames.setter
    def UseLongFileNames(self, value):
        self.com_object.UseLongFileNames = value

    @property
    def uselongfilenames(self):
        """Alias for UseLongFileNames"""
        return self.UseLongFileNames

    @uselongfilenames.setter
    def uselongfilenames(self, value):
        """Alias for UseLongFileNames.setter"""
        self.UseLongFileNames = value

    @property
    def use_long_file_names(self):
        """Alias for UseLongFileNames"""
        return self.UseLongFileNames

    @use_long_file_names.setter
    def use_long_file_names(self, value):
        """Alias for UseLongFileNames.setter"""
        self.UseLongFileNames = value

    def UseDefaultFolderSuffix(self):
        self.com_object.UseDefaultFolderSuffix()

    def usedefaultfoldersuffix(self):
        """Alias for UseDefaultFolderSuffix"""
        return self.UseDefaultFolderSuffix()

    def use_default_folder_suffix(self):
        """Alias for UseDefaultFolderSuffix"""
        return self.UseDefaultFolderSuffix()


class Window:

    def __init__(self, window=None):
        self.com_object= window

    @property
    def Active(self):
        return self.com_object.Active

    @property
    def active(self):
        """Alias for Active"""
        return self.Active

    @property
    def ActivePane(self):
        return Pane(self.com_object.ActivePane)

    @property
    def activepane(self):
        """Alias for ActivePane"""
        return self.ActivePane

    @property
    def active_pane(self):
        """Alias for ActivePane"""
        return self.ActivePane

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DisplayHorizontalScrollBar(self):
        return self.com_object.DisplayHorizontalScrollBar

    @DisplayHorizontalScrollBar.setter
    def DisplayHorizontalScrollBar(self, value):
        self.com_object.DisplayHorizontalScrollBar = value

    @property
    def displayhorizontalscrollbar(self):
        """Alias for DisplayHorizontalScrollBar"""
        return self.DisplayHorizontalScrollBar

    @displayhorizontalscrollbar.setter
    def displayhorizontalscrollbar(self, value):
        """Alias for DisplayHorizontalScrollBar.setter"""
        self.DisplayHorizontalScrollBar = value

    @property
    def display_horizontal_scroll_bar(self):
        """Alias for DisplayHorizontalScrollBar"""
        return self.DisplayHorizontalScrollBar

    @display_horizontal_scroll_bar.setter
    def display_horizontal_scroll_bar(self, value):
        """Alias for DisplayHorizontalScrollBar.setter"""
        self.DisplayHorizontalScrollBar = value

    @property
    def DisplayLeftScrollBar(self):
        return self.com_object.DisplayLeftScrollBar

    @DisplayLeftScrollBar.setter
    def DisplayLeftScrollBar(self, value):
        self.com_object.DisplayLeftScrollBar = value

    @property
    def displayleftscrollbar(self):
        """Alias for DisplayLeftScrollBar"""
        return self.DisplayLeftScrollBar

    @displayleftscrollbar.setter
    def displayleftscrollbar(self, value):
        """Alias for DisplayLeftScrollBar.setter"""
        self.DisplayLeftScrollBar = value

    @property
    def display_left_scroll_bar(self):
        """Alias for DisplayLeftScrollBar"""
        return self.DisplayLeftScrollBar

    @display_left_scroll_bar.setter
    def display_left_scroll_bar(self, value):
        """Alias for DisplayLeftScrollBar.setter"""
        self.DisplayLeftScrollBar = value

    @property
    def DisplayRightRuler(self):
        return self.com_object.DisplayRightRuler

    @DisplayRightRuler.setter
    def DisplayRightRuler(self, value):
        self.com_object.DisplayRightRuler = value

    @property
    def displayrightruler(self):
        """Alias for DisplayRightRuler"""
        return self.DisplayRightRuler

    @displayrightruler.setter
    def displayrightruler(self, value):
        """Alias for DisplayRightRuler.setter"""
        self.DisplayRightRuler = value

    @property
    def display_right_ruler(self):
        """Alias for DisplayRightRuler"""
        return self.DisplayRightRuler

    @display_right_ruler.setter
    def display_right_ruler(self, value):
        """Alias for DisplayRightRuler.setter"""
        self.DisplayRightRuler = value

    @property
    def DisplayRulers(self):
        return self.com_object.DisplayRulers

    @DisplayRulers.setter
    def DisplayRulers(self, value):
        self.com_object.DisplayRulers = value

    @property
    def displayrulers(self):
        """Alias for DisplayRulers"""
        return self.DisplayRulers

    @displayrulers.setter
    def displayrulers(self, value):
        """Alias for DisplayRulers.setter"""
        self.DisplayRulers = value

    @property
    def display_rulers(self):
        """Alias for DisplayRulers"""
        return self.DisplayRulers

    @display_rulers.setter
    def display_rulers(self, value):
        """Alias for DisplayRulers.setter"""
        self.DisplayRulers = value

    @property
    def DisplayScreenTips(self):
        return self.com_object.DisplayScreenTips

    @DisplayScreenTips.setter
    def DisplayScreenTips(self, value):
        self.com_object.DisplayScreenTips = value

    @property
    def displayscreentips(self):
        """Alias for DisplayScreenTips"""
        return self.DisplayScreenTips

    @displayscreentips.setter
    def displayscreentips(self, value):
        """Alias for DisplayScreenTips.setter"""
        self.DisplayScreenTips = value

    @property
    def display_screen_tips(self):
        """Alias for DisplayScreenTips"""
        return self.DisplayScreenTips

    @display_screen_tips.setter
    def display_screen_tips(self, value):
        """Alias for DisplayScreenTips.setter"""
        self.DisplayScreenTips = value

    @property
    def DisplayVerticalRuler(self):
        return self.com_object.DisplayVerticalRuler

    @DisplayVerticalRuler.setter
    def DisplayVerticalRuler(self, value):
        self.com_object.DisplayVerticalRuler = value

    @property
    def displayverticalruler(self):
        """Alias for DisplayVerticalRuler"""
        return self.DisplayVerticalRuler

    @displayverticalruler.setter
    def displayverticalruler(self, value):
        """Alias for DisplayVerticalRuler.setter"""
        self.DisplayVerticalRuler = value

    @property
    def display_vertical_ruler(self):
        """Alias for DisplayVerticalRuler"""
        return self.DisplayVerticalRuler

    @display_vertical_ruler.setter
    def display_vertical_ruler(self, value):
        """Alias for DisplayVerticalRuler.setter"""
        self.DisplayVerticalRuler = value

    @property
    def DisplayVerticalScrollBar(self):
        return self.com_object.DisplayVerticalScrollBar

    @DisplayVerticalScrollBar.setter
    def DisplayVerticalScrollBar(self, value):
        self.com_object.DisplayVerticalScrollBar = value

    @property
    def displayverticalscrollbar(self):
        """Alias for DisplayVerticalScrollBar"""
        return self.DisplayVerticalScrollBar

    @displayverticalscrollbar.setter
    def displayverticalscrollbar(self, value):
        """Alias for DisplayVerticalScrollBar.setter"""
        self.DisplayVerticalScrollBar = value

    @property
    def display_vertical_scroll_bar(self):
        """Alias for DisplayVerticalScrollBar"""
        return self.DisplayVerticalScrollBar

    @display_vertical_scroll_bar.setter
    def display_vertical_scroll_bar(self, value):
        """Alias for DisplayVerticalScrollBar.setter"""
        self.DisplayVerticalScrollBar = value

    @property
    def Document(self):
        return Document(self.com_object.Document)

    @property
    def document(self):
        """Alias for Document"""
        return self.Document

    @property
    def DocumentMap(self):
        return self.com_object.DocumentMap

    @DocumentMap.setter
    def DocumentMap(self, value):
        self.com_object.DocumentMap = value

    @property
    def documentmap(self):
        """Alias for DocumentMap"""
        return self.DocumentMap

    @documentmap.setter
    def documentmap(self, value):
        """Alias for DocumentMap.setter"""
        self.DocumentMap = value

    @property
    def document_map(self):
        """Alias for DocumentMap"""
        return self.DocumentMap

    @document_map.setter
    def document_map(self, value):
        """Alias for DocumentMap.setter"""
        self.DocumentMap = value

    @property
    def EnvelopeVisible(self):
        return self.com_object.EnvelopeVisible

    @EnvelopeVisible.setter
    def EnvelopeVisible(self, value):
        self.com_object.EnvelopeVisible = value

    @property
    def envelopevisible(self):
        """Alias for EnvelopeVisible"""
        return self.EnvelopeVisible

    @envelopevisible.setter
    def envelopevisible(self, value):
        """Alias for EnvelopeVisible.setter"""
        self.EnvelopeVisible = value

    @property
    def envelope_visible(self):
        """Alias for EnvelopeVisible"""
        return self.EnvelopeVisible

    @envelope_visible.setter
    def envelope_visible(self, value):
        """Alias for EnvelopeVisible.setter"""
        self.EnvelopeVisible = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HorizontalPercentScrolled(self):
        return self.com_object.HorizontalPercentScrolled

    @HorizontalPercentScrolled.setter
    def HorizontalPercentScrolled(self, value):
        self.com_object.HorizontalPercentScrolled = value

    @property
    def horizontalpercentscrolled(self):
        """Alias for HorizontalPercentScrolled"""
        return self.HorizontalPercentScrolled

    @horizontalpercentscrolled.setter
    def horizontalpercentscrolled(self, value):
        """Alias for HorizontalPercentScrolled.setter"""
        self.HorizontalPercentScrolled = value

    @property
    def horizontal_percent_scrolled(self):
        """Alias for HorizontalPercentScrolled"""
        return self.HorizontalPercentScrolled

    @horizontal_percent_scrolled.setter
    def horizontal_percent_scrolled(self, value):
        """Alias for HorizontalPercentScrolled.setter"""
        self.HorizontalPercentScrolled = value

    @property
    def Hwnd(self):
        return self.com_object.Hwnd

    @property
    def hwnd(self):
        """Alias for Hwnd"""
        return self.Hwnd

    @property
    def IMEMode(self):
        return WdIMEMode(self.com_object.IMEMode)

    @IMEMode.setter
    def IMEMode(self, value):
        self.com_object.IMEMode = value

    @property
    def imemode(self):
        """Alias for IMEMode"""
        return self.IMEMode

    @imemode.setter
    def imemode(self, value):
        """Alias for IMEMode.setter"""
        self.IMEMode = value

    @property
    def i_m_e_mode(self):
        """Alias for IMEMode"""
        return self.IMEMode

    @i_m_e_mode.setter
    def i_m_e_mode(self, value):
        """Alias for IMEMode.setter"""
        self.IMEMode = value

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Next(self):
        return self.com_object.Next

    @property
    def next(self):
        """Alias for Next"""
        return self.Next

    @property
    def Panes(self):
        return Panes(self.com_object.Panes)

    @property
    def panes(self):
        """Alias for Panes"""
        return self.Panes

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Previous(self):
        return self.com_object.Previous

    @property
    def previous(self):
        """Alias for Previous"""
        return self.Previous

    @property
    def Selection(self):
        return Selection(self.com_object.Selection)

    @property
    def selection(self):
        """Alias for Selection"""
        return self.Selection

    @property
    def ShowSourceDocuments(self):
        return WdShowSourceDocuments(self.com_object.ShowSourceDocuments)

    @ShowSourceDocuments.setter
    def ShowSourceDocuments(self, value):
        self.com_object.ShowSourceDocuments = value

    @property
    def showsourcedocuments(self):
        """Alias for ShowSourceDocuments"""
        return self.ShowSourceDocuments

    @showsourcedocuments.setter
    def showsourcedocuments(self, value):
        """Alias for ShowSourceDocuments.setter"""
        self.ShowSourceDocuments = value

    @property
    def show_source_documents(self):
        """Alias for ShowSourceDocuments"""
        return self.ShowSourceDocuments

    @show_source_documents.setter
    def show_source_documents(self, value):
        """Alias for ShowSourceDocuments.setter"""
        self.ShowSourceDocuments = value

    @property
    def Split(self):
        return self.com_object.Split

    @Split.setter
    def Split(self, value):
        self.com_object.Split = value

    @property
    def split(self):
        """Alias for Split"""
        return self.Split

    @split.setter
    def split(self, value):
        """Alias for Split.setter"""
        self.Split = value

    @property
    def SplitVertical(self):
        return self.com_object.SplitVertical

    @SplitVertical.setter
    def SplitVertical(self, value):
        self.com_object.SplitVertical = value

    @property
    def splitvertical(self):
        """Alias for SplitVertical"""
        return self.SplitVertical

    @splitvertical.setter
    def splitvertical(self, value):
        """Alias for SplitVertical.setter"""
        self.SplitVertical = value

    @property
    def split_vertical(self):
        """Alias for SplitVertical"""
        return self.SplitVertical

    @split_vertical.setter
    def split_vertical(self, value):
        """Alias for SplitVertical.setter"""
        self.SplitVertical = value

    @property
    def StyleAreaWidth(self):
        return self.com_object.StyleAreaWidth

    @StyleAreaWidth.setter
    def StyleAreaWidth(self, value):
        self.com_object.StyleAreaWidth = value

    @property
    def styleareawidth(self):
        """Alias for StyleAreaWidth"""
        return self.StyleAreaWidth

    @styleareawidth.setter
    def styleareawidth(self, value):
        """Alias for StyleAreaWidth.setter"""
        self.StyleAreaWidth = value

    @property
    def style_area_width(self):
        """Alias for StyleAreaWidth"""
        return self.StyleAreaWidth

    @style_area_width.setter
    def style_area_width(self, value):
        """Alias for StyleAreaWidth.setter"""
        self.StyleAreaWidth = value

    @property
    def Thumbnails(self):
        return self.com_object.Thumbnails

    @property
    def thumbnails(self):
        """Alias for Thumbnails"""
        return self.Thumbnails

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def Type(self):
        return WdWindowType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def UsableHeight(self):
        return self.com_object.UsableHeight

    @property
    def usableheight(self):
        """Alias for UsableHeight"""
        return self.UsableHeight

    @property
    def usable_height(self):
        """Alias for UsableHeight"""
        return self.UsableHeight

    @property
    def UsableWidth(self):
        return self.com_object.UsableWidth

    @property
    def usablewidth(self):
        """Alias for UsableWidth"""
        return self.UsableWidth

    @property
    def usable_width(self):
        """Alias for UsableWidth"""
        return self.UsableWidth

    @property
    def VerticalPercentScrolled(self):
        return self.com_object.VerticalPercentScrolled

    @VerticalPercentScrolled.setter
    def VerticalPercentScrolled(self, value):
        self.com_object.VerticalPercentScrolled = value

    @property
    def verticalpercentscrolled(self):
        """Alias for VerticalPercentScrolled"""
        return self.VerticalPercentScrolled

    @verticalpercentscrolled.setter
    def verticalpercentscrolled(self, value):
        """Alias for VerticalPercentScrolled.setter"""
        self.VerticalPercentScrolled = value

    @property
    def vertical_percent_scrolled(self):
        """Alias for VerticalPercentScrolled"""
        return self.VerticalPercentScrolled

    @vertical_percent_scrolled.setter
    def vertical_percent_scrolled(self, value):
        """Alias for VerticalPercentScrolled.setter"""
        self.VerticalPercentScrolled = value

    @property
    def View(self):
        return View(self.com_object.View)

    @property
    def view(self):
        """Alias for View"""
        return self.View

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def WindowState(self):
        return WdWindowState(self.com_object.WindowState)

    @WindowState.setter
    def WindowState(self, value):
        self.com_object.WindowState = value

    @property
    def windowstate(self):
        """Alias for WindowState"""
        return self.WindowState

    @windowstate.setter
    def windowstate(self, value):
        """Alias for WindowState.setter"""
        self.WindowState = value

    @property
    def window_state(self):
        """Alias for WindowState"""
        return self.WindowState

    @window_state.setter
    def window_state(self, value):
        """Alias for WindowState.setter"""
        self.WindowState = value

    @property
    def WindowNumber(self):
        return self.com_object.WindowNumber

    @property
    def windownumber(self):
        """Alias for WindowNumber"""
        return self.WindowNumber

    @property
    def window_number(self):
        """Alias for WindowNumber"""
        return self.WindowNumber

    def Activate(self):
        self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()

    def Close(self, SaveChanges=None, RouteDocument=None):
        arguments = com_arguments([unwrap(a) for a in [SaveChanges, RouteDocument]])
        self.com_object.Close(*arguments)

    def close(self, SaveChanges=None, RouteDocument=None):
        """Alias for Close"""
        arguments = [SaveChanges, RouteDocument]
        return self.Close(*arguments)

    def GetPoint(self, ScreenPixelsLeft=None, ScreenPixelsTop=None, ScreenPixelsWidth=None, ScreenPixelsHeight=None, obj=None):
        arguments = com_arguments([unwrap(a) for a in [ScreenPixelsLeft, ScreenPixelsTop, ScreenPixelsWidth, ScreenPixelsHeight, obj]])
        self.com_object.GetPoint(*arguments)

    def getpoint(self, ScreenPixelsLeft=None, ScreenPixelsTop=None, ScreenPixelsWidth=None, ScreenPixelsHeight=None, obj=None):
        """Alias for GetPoint"""
        arguments = [ScreenPixelsLeft, ScreenPixelsTop, ScreenPixelsWidth, ScreenPixelsHeight, obj]
        return self.GetPoint(*arguments)

    def get_point(self, ScreenPixelsLeft=None, ScreenPixelsTop=None, ScreenPixelsWidth=None, ScreenPixelsHeight=None, obj=None):
        """Alias for GetPoint"""
        arguments = [ScreenPixelsLeft, ScreenPixelsTop, ScreenPixelsWidth, ScreenPixelsHeight, obj]
        return self.GetPoint(*arguments)

    def LargeScroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        arguments = com_arguments([unwrap(a) for a in [Down, Up, ToRight, ToLeft]])
        self.com_object.LargeScroll(*arguments)

    def largescroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        """Alias for LargeScroll"""
        arguments = [Down, Up, ToRight, ToLeft]
        return self.LargeScroll(*arguments)

    def large_scroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        """Alias for LargeScroll"""
        arguments = [Down, Up, ToRight, ToLeft]
        return self.LargeScroll(*arguments)

    def NewWindow(self):
        return Window(self.com_object.NewWindow())

    def newwindow(self):
        """Alias for NewWindow"""
        return self.NewWindow()

    def new_window(self):
        """Alias for NewWindow"""
        return self.NewWindow()

    def PageScroll(self, Down=None, Up=None):
        arguments = com_arguments([unwrap(a) for a in [Down, Up]])
        self.com_object.PageScroll(*arguments)

    def pagescroll(self, Down=None, Up=None):
        """Alias for PageScroll"""
        arguments = [Down, Up]
        return self.PageScroll(*arguments)

    def page_scroll(self, Down=None, Up=None):
        """Alias for PageScroll"""
        arguments = [Down, Up]
        return self.PageScroll(*arguments)

    def PrintOut(self, Background=None, Append=None, Range=None, OutputFileName=None, From=None, To=None, Item=None, Copies=None, Pages=None, PageType=None, PrintToFile=None, Collate=None, FileName=None, ActivePrinterMacGX=None, ManualDuplexPrint=None, PrintZoomColumn=None, PrintZoomRow=None, PrintZoomPaperWidth=None, PrintZoomPaperHeight=None):
        arguments = com_arguments([unwrap(a) for a in [Background, Append, Range, OutputFileName, From, To, Item, Copies, Pages, PageType, PrintToFile, Collate, FileName, ActivePrinterMacGX, ManualDuplexPrint, PrintZoomColumn, PrintZoomRow, PrintZoomPaperWidth, PrintZoomPaperHeight]])
        self.com_object.PrintOut(*arguments)

    def printout(self, Background=None, Append=None, Range=None, OutputFileName=None, From=None, To=None, Item=None, Copies=None, Pages=None, PageType=None, PrintToFile=None, Collate=None, FileName=None, ActivePrinterMacGX=None, ManualDuplexPrint=None, PrintZoomColumn=None, PrintZoomRow=None, PrintZoomPaperWidth=None, PrintZoomPaperHeight=None):
        """Alias for PrintOut"""
        arguments = [Background, Append, Range, OutputFileName, From, To, Item, Copies, Pages, PageType, PrintToFile, Collate, FileName, ActivePrinterMacGX, ManualDuplexPrint, PrintZoomColumn, PrintZoomRow, PrintZoomPaperWidth, PrintZoomPaperHeight]
        return self.PrintOut(*arguments)

    def print_out(self, Background=None, Append=None, Range=None, OutputFileName=None, From=None, To=None, Item=None, Copies=None, Pages=None, PageType=None, PrintToFile=None, Collate=None, FileName=None, ActivePrinterMacGX=None, ManualDuplexPrint=None, PrintZoomColumn=None, PrintZoomRow=None, PrintZoomPaperWidth=None, PrintZoomPaperHeight=None):
        """Alias for PrintOut"""
        arguments = [Background, Append, Range, OutputFileName, From, To, Item, Copies, Pages, PageType, PrintToFile, Collate, FileName, ActivePrinterMacGX, ManualDuplexPrint, PrintZoomColumn, PrintZoomRow, PrintZoomPaperWidth, PrintZoomPaperHeight]
        return self.PrintOut(*arguments)

    def RangeFromPoint(self, x=None, y=None):
        arguments = com_arguments([unwrap(a) for a in [x, y]])
        return self.com_object.RangeFromPoint(*arguments)

    def rangefrompoint(self, x=None, y=None):
        """Alias for RangeFromPoint"""
        arguments = [x, y]
        return self.RangeFromPoint(*arguments)

    def range_from_point(self, x=None, y=None):
        """Alias for RangeFromPoint"""
        arguments = [x, y]
        return self.RangeFromPoint(*arguments)

    def ScrollIntoView(self, Obj=None, Start=None):
        arguments = com_arguments([unwrap(a) for a in [Obj, Start]])
        self.com_object.ScrollIntoView(*arguments)

    def scrollintoview(self, Obj=None, Start=None):
        """Alias for ScrollIntoView"""
        arguments = [Obj, Start]
        return self.ScrollIntoView(*arguments)

    def scroll_into_view(self, Obj=None, Start=None):
        """Alias for ScrollIntoView"""
        arguments = [Obj, Start]
        return self.ScrollIntoView(*arguments)

    def SetFocus(self):
        self.com_object.SetFocus()

    def setfocus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def set_focus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def SmallScroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        arguments = com_arguments([unwrap(a) for a in [Down, Up, ToRight, ToLeft]])
        self.com_object.SmallScroll(*arguments)

    def smallscroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        """Alias for SmallScroll"""
        arguments = [Down, Up, ToRight, ToLeft]
        return self.SmallScroll(*arguments)

    def small_scroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        """Alias for SmallScroll"""
        arguments = [Down, Up, ToRight, ToLeft]
        return self.SmallScroll(*arguments)

    def ToggleRibbon(self):
        self.com_object.ToggleRibbon()

    def toggleribbon(self):
        """Alias for ToggleRibbon"""
        return self.ToggleRibbon()

    def toggle_ribbon(self):
        """Alias for ToggleRibbon"""
        return self.ToggleRibbon()


class Windows:

    def __init__(self, windows=None):
        self.com_object= windows

    def __call__(self, item):
        return Window(self.com_object(item))

    @property
    def SyncScrollingSideBySide(self):
        return self.com_object.SyncScrollingSideBySide

    @SyncScrollingSideBySide.setter
    def SyncScrollingSideBySide(self, value):
        self.com_object.SyncScrollingSideBySide = value

    @property
    def syncscrollingsidebyside(self):
        """Alias for SyncScrollingSideBySide"""
        return self.SyncScrollingSideBySide

    @syncscrollingsidebyside.setter
    def syncscrollingsidebyside(self, value):
        """Alias for SyncScrollingSideBySide.setter"""
        self.SyncScrollingSideBySide = value

    @property
    def sync_scrolling_side_by_side(self):
        """Alias for SyncScrollingSideBySide"""
        return self.SyncScrollingSideBySide

    @sync_scrolling_side_by_side.setter
    def sync_scrolling_side_by_side(self, value):
        """Alias for SyncScrollingSideBySide.setter"""
        self.SyncScrollingSideBySide = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Window=None):
        arguments = com_arguments([unwrap(a) for a in [Window]])
        return Window(self.com_object.Add(*arguments))

    def add(self, Window=None):
        """Alias for Add"""
        arguments = [Window]
        return self.Add(*arguments)

    def Arrange(self, ArrangeStyle=None):
        arguments = com_arguments([unwrap(a) for a in [ArrangeStyle]])
        self.com_object.Arrange(*arguments)

    def arrange(self, ArrangeStyle=None):
        """Alias for Arrange"""
        arguments = [ArrangeStyle]
        return self.Arrange(*arguments)

    def BreakSideBySide(self):
        return self.com_object.BreakSideBySide()

    def breaksidebyside(self):
        """Alias for BreakSideBySide"""
        return self.BreakSideBySide()

    def break_side_by_side(self):
        """Alias for BreakSideBySide"""
        return self.BreakSideBySide()

    def CompareSideBySideWith(self, Document=None):
        arguments = com_arguments([unwrap(a) for a in [Document]])
        return self.com_object.CompareSideBySideWith(*arguments)

    def comparesidebysidewith(self, Document=None):
        """Alias for CompareSideBySideWith"""
        arguments = [Document]
        return self.CompareSideBySideWith(*arguments)

    def compare_side_by_side_with(self, Document=None):
        """Alias for CompareSideBySideWith"""
        arguments = [Document]
        return self.CompareSideBySideWith(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Window(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def ResetPositionsSideBySide(self):
        self.com_object.ResetPositionsSideBySide()

    def resetpositionssidebyside(self):
        """Alias for ResetPositionsSideBySide"""
        return self.ResetPositionsSideBySide()

    def reset_positions_side_by_side(self):
        """Alias for ResetPositionsSideBySide"""
        return self.ResetPositionsSideBySide()


class Words:

    def __init__(self, words=None):
        self.com_object= words

    def __call__(self, item):
        return Word(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def First(self):
        return Range(self.com_object.First)

    @property
    def first(self):
        """Alias for First"""
        return self.First

    @property
    def Last(self):
        return Range(self.com_object.Last)

    @property
    def last(self):
        """Alias for Last"""
        return self.Last

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Range(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class WrapFormat:

    def __init__(self, wrapformat=None):
        self.com_object= wrapformat

    @property
    def AllowOverlap(self):
        return self.com_object.AllowOverlap

    @AllowOverlap.setter
    def AllowOverlap(self, value):
        self.com_object.AllowOverlap = value

    @property
    def allowoverlap(self):
        """Alias for AllowOverlap"""
        return self.AllowOverlap

    @allowoverlap.setter
    def allowoverlap(self, value):
        """Alias for AllowOverlap.setter"""
        self.AllowOverlap = value

    @property
    def allow_overlap(self):
        """Alias for AllowOverlap"""
        return self.AllowOverlap

    @allow_overlap.setter
    def allow_overlap(self, value):
        """Alias for AllowOverlap.setter"""
        self.AllowOverlap = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DistanceBottom(self):
        return self.com_object.DistanceBottom

    @DistanceBottom.setter
    def DistanceBottom(self, value):
        self.com_object.DistanceBottom = value

    @property
    def distancebottom(self):
        """Alias for DistanceBottom"""
        return self.DistanceBottom

    @distancebottom.setter
    def distancebottom(self, value):
        """Alias for DistanceBottom.setter"""
        self.DistanceBottom = value

    @property
    def distance_bottom(self):
        """Alias for DistanceBottom"""
        return self.DistanceBottom

    @distance_bottom.setter
    def distance_bottom(self, value):
        """Alias for DistanceBottom.setter"""
        self.DistanceBottom = value

    @property
    def DistanceLeft(self):
        return self.com_object.DistanceLeft

    @DistanceLeft.setter
    def DistanceLeft(self, value):
        self.com_object.DistanceLeft = value

    @property
    def distanceleft(self):
        """Alias for DistanceLeft"""
        return self.DistanceLeft

    @distanceleft.setter
    def distanceleft(self, value):
        """Alias for DistanceLeft.setter"""
        self.DistanceLeft = value

    @property
    def distance_left(self):
        """Alias for DistanceLeft"""
        return self.DistanceLeft

    @distance_left.setter
    def distance_left(self, value):
        """Alias for DistanceLeft.setter"""
        self.DistanceLeft = value

    @property
    def DistanceRight(self):
        return self.com_object.DistanceRight

    @DistanceRight.setter
    def DistanceRight(self, value):
        self.com_object.DistanceRight = value

    @property
    def distanceright(self):
        """Alias for DistanceRight"""
        return self.DistanceRight

    @distanceright.setter
    def distanceright(self, value):
        """Alias for DistanceRight.setter"""
        self.DistanceRight = value

    @property
    def distance_right(self):
        """Alias for DistanceRight"""
        return self.DistanceRight

    @distance_right.setter
    def distance_right(self, value):
        """Alias for DistanceRight.setter"""
        self.DistanceRight = value

    @property
    def DistanceTop(self):
        return self.com_object.DistanceTop

    @DistanceTop.setter
    def DistanceTop(self, value):
        self.com_object.DistanceTop = value

    @property
    def distancetop(self):
        """Alias for DistanceTop"""
        return self.DistanceTop

    @distancetop.setter
    def distancetop(self, value):
        """Alias for DistanceTop.setter"""
        self.DistanceTop = value

    @property
    def distance_top(self):
        """Alias for DistanceTop"""
        return self.DistanceTop

    @distance_top.setter
    def distance_top(self, value):
        """Alias for DistanceTop.setter"""
        self.DistanceTop = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Side(self):
        return WdWrapSideType(self.com_object.Side)

    @Side.setter
    def Side(self, value):
        self.com_object.Side = value

    @property
    def side(self):
        """Alias for Side"""
        return self.Side

    @side.setter
    def side(self, value):
        """Alias for Side.setter"""
        self.Side = value

    @property
    def Type(self):
        return WdWrapType(self.com_object.Type)

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value


# XlAxisCrosses enumeration
xlAxisCrossesAutomatic = -4105
xlAxisCrossesCustom = -4114
xlAxisCrossesMaximum = 2
xlAxisCrossesMinimum = 4

# XlAxisGroup enumeration
xlPrimary = 1
xlSecondary = 2

# XlAxisType enumeration
xlCategory = 1
xlSeriesAxis = 3
xlValue = 2

# XlBackground enumeration
xlBackgroundAutomatic = -4105
xlBackgroundOpaque = 3
xlBackgroundTransparent = 2

# XlBarShape enumeration
xlBox = 0
xlConeToMax = 5
xlConeToPoint = 4
xlCylinder = 3
xlPyramidToMax = 2
xlPyramidToPoint = 1

# XlBinsType enumeration
xlBinsTypeAutomatic = 0
xlBinsTypeCategorical = 1
xlBinsTypeManual = 2
xlBinsTypeBinSize = 3
xlBinsTypeBinCount = 4

# XlBorderWeight enumeration
xlHairline = 1
xlMedium = -4138
xlThick = 4
xlThin = 2

# XlCategoryLabelLevel enumeration
xlCategoryLabelLevelAll = -1
xlCategoryLabelLevelCustom = -2
xlCategoryLabelLevelNone = -3

# XlCategoryType enumeration
xlAutomaticScale = -4105
xlCategoryScale = 2
xlTimeScale = 3

# XlChartElementPosition enumeration
xlChartElementPositionAutomatic = -4105
xlChartElementPositionCustom = -4114

# XlChartGallery enumeration
xlAnyGallery = 23
xlBuiltIn = 21
xlUserDefined = 22

# XlChartItem enumeration
xlAxis = 21
xlAxisTitle = 17
xlChartArea = 2
xlChartTitle = 4
xlCorners = 6
xlDataLabel = 0
xlDataTable = 7
xlDisplayUnitLabel = 30
xlDownBars = 20
xlDropLines = 26
xlErrorBars = 9
xlFloor = 23
xlHiLoLines = 25
xlLeaderLines = 29
xlLegend = 24
xlLegendEntry = 12
xlLegendKey = 13
xlMajorGridlines = 15
xlMinorGridlines = 16
xlNothing = 28
xlPivotChartDropZone = 32
xlPivotChartFieldButton = 31
xlPlotArea = 19
xlRadarAxisLabels = 27
xlSeries = 3
xlSeriesLines = 22
xlShape = 14
xlTrendline = 8
xlUpBars = 18
xlWalls = 5
xlXErrorBars = 10
xlYErrorBars = 11

# XlChartPicturePlacement enumeration
xlAllFaces = 7
xlEnd = 2
xlEndSides = 3
xlFront = 4
xlFrontEnd = 6
xlFrontSides = 5
xlSides = 1

# XlChartPictureType enumeration
xlStack = 2
xlStackScale = 3
xlStretch = 1

# XlChartSplitType enumeration
xlSplitByCustomSplit = 4
xlSplitByPercentValue = 3
xlSplitByPosition = 1
xlSplitByValue = 2

# XlColorIndex enumeration
xlColorIndexAutomatic = -4105
xlColorIndexNone = -4142

# XlConstants enumeration
xl3DBar = -4099
xl3DSurface = -4103
xlAbove = 0
xlAutomatic = -4105
xlBar = 2
xlBelow = 1
xlBoth = 1
xlBottom = -4107
xlCenter = -4108
xlChecker = 9
xlCircle = 8
xlColumn = 3
xlCombination = -4111
xlCorner = 2
xlCrissCross = 16
xlCross = 4
xlCustom = -4114
xlDefaultAutoFormat = -1
xlDiamond = 2
xlDistributed = -4117
xlFill = 5
xlFixedValue = 1
xlGeneral = 1
xlGray16 = 17
xlGray25 = -4124
xlGray50 = -4125
xlGray75 = -4126
xlGray8 = 18
xlGrid = 15
xlHigh = -4127
xlInside = 2
xlJustify = -4130
xlLeft = -4131
xlLightDown = 13
xlLightHorizontal = 11
xlLightUp = 14
xlLightVertical = 12
xlLow = -4134
xlMaximum = 2
xlMinimum = 4
xlMinusValues = 3
xlNextToAxis = 4
xlNone = -4142
xlOpaque = 3
xlOutside = 3
xlPercent = 2
xlPlus = 9
xlPlusValues = 2
xlRight = -4152
xlScale = 3
xlSemiGray75 = 10
xlShowLabel = 4
xlShowLabelAndPercent = 5
xlShowPercent = 3
xlShowValue = 2
xlSingle = 2
xlSolid = 1
xlSquare = 1
xlStar = 5
xlStError = 4
xlTop = -4160
xlTransparent = 2
xlTriangle = 3

# XlCopyPictureFormat enumeration
xlBitmap = 2
xlPicture = -4147

# XlDataLabelPosition enumeration
xlLabelPositionAbove = 0
xlLabelPositionBelow = 1
xlLabelPositionBestFit = 5
xlLabelPositionCenter = -4108
xlLabelPositionCustom = 7
xlLabelPositionInsideBase = 4
xlLabelPositionInsideEnd = 3
xlLabelPositionLeft = -4131
xlLabelPositionMixed = 6
xlLabelPositionOutsideEnd = 2
xlLabelPositionRight = -4152

# XlDataLabelSeparator enumeration
xlDataLabelSeparatorDefault = 1

# XlDataLabelsType enumeration
xlDataLabelsShowBubbleSizes = 6
xlDataLabelsShowLabel = 4
xlDataLabelsShowLabelAndPercent = 5
xlDataLabelsShowNone = -4142
xlDataLabelsShowPercent = 3
xlDataLabelsShowValue = 2

# XlDisplayBlanksAs enumeration
xlInterpolated = 3
xlNotPlotted = 1
xlZero = 2

# XlDisplayUnit enumeration
xlHundredMillions = -8
xlHundreds = -2
xlHundredThousands = -5
xlMillionMillions = -10
xlMillions = -6
xlTenMillions = -7
xlTenThousands = -4
xlThousandMillions = -9
xlThousands = -3

# XlEndStyleCap enumeration
xlCap = 1
xlNoCap = 2

# XlErrorBarDirection enumeration
xlChartX = -4168
xlChartY = 1

# XlErrorBarInclude enumeration
xlErrorBarIncludeBoth = 1
xlErrorBarIncludeMinusValues = 3
xlErrorBarIncludeNone = -4142
xlErrorBarIncludePlusValues = 2

# XlErrorBarType enumeration
xlErrorBarTypeCustom = -4114
xlErrorBarTypeFixedValue = 1
xlErrorBarTypePercent = 2
xlErrorBarTypeStDev = -4155
xlErrorBarTypeStError = 4

# XlHAlign enumeration
xlHAlignCenter = -4108
xlHAlignCenterAcrossSelection = 7
xlHAlignDistributed = -4117
xlHAlignFill = 5
xlHAlignGeneral = 1
xlHAlignJustify = -4130
xlHAlignLeft = -4131
xlHAlignRight = -4152

# XlLegendPosition enumeration
xlLegendPositionBottom = -4107
xlLegendPositionCorner = 2
xlLegendPositionCustom = -4161
xlLegendPositionLeft = -4131
xlLegendPositionRight = -4152
xlLegendPositionTop = -4160

# XlLineStyle enumeration
xlContinuous = 1
xlDash = -4115
xlDashDot = 4
xlDashDotDot = 5
xlDot = -4118
xlDouble = -4119
xlLineStyleNone = -4142
xlSlantDashDot = 13

# XlMarkerStyle enumeration
xlMarkerStyleAutomatic = -4105
xlMarkerStyleCircle = 8
xlMarkerStyleDash = -4115
xlMarkerStyleDiamond = 2
xlMarkerStyleDot = -4118
xlMarkerStyleNone = -4142
xlMarkerStylePicture = -4147
xlMarkerStylePlus = 9
xlMarkerStyleSquare = 1
xlMarkerStyleStar = 5
xlMarkerStyleTriangle = 3
xlMarkerStyleX = -4168

# XlOrientation enumeration
xlDownward = -4170
xlHorizontal = -4128
xlUpward = -4171
xlVertical = -4166

# XlParentDataLabelOptions enumeration
xlParentDataLabelOptionsNone = 0
xlParentDataLabelOptionsBanner = 1
xlParentDataLabelOptionsOverlapping = 2

# XlPattern enumeration
xlPatternAutomatic = -4105
xlPatternChecker = 9
xlPatternCrissCross = 16
xlPatternDown = -4121
xlPatternGray16 = 17
xlPatternGray25 = -4124
xlPatternGray50 = -4125
xlPatternGray75 = -4126
xlPatternGray8 = 18
xlPatternGrid = 15
xlPatternHorizontal = -4128
xlPatternLightDown = 13
xlPatternLightHorizontal = 11
xlPatternLightUp = 14
xlPatternLightVertical = 12
xlPatternLinearGradient = 4000
xlPatternNone = -4142
xlPatternRectangularGradient = 4001
xlPatternSemiGray75 = 10
xlPatternSolid = 1
xlPatternUp = -4162
xlPatternVertical = -4166

# XlPictureAppearance enumeration
xlPrinter = 2
xlScreen = 1

# XlPieSliceIndex enumeration
xlCenterPoint = 5
xlInnerCenterPoint = 8
xlInnerClockwisePoint = 7
xlInnerCounterClockwisePoint = 9
xlMidClockwiseRadiusPoint = 4
xlMidCounterClockwiseRadiusPoint = 6
xlOuterCenterPoint = 2
xlOuterClockwisePoint = 3
xlOuterCounterClockwisePoint = 1

# XlPieSliceLocation enumeration
xlCenterPoint = 5
xlInnerCenterPoint = 8
xlInnerClockwisePoint = 7
xlInnerCounterClockwisePoint = 9
xlMidClockwiseRadiusPoint = 4
xlMidCounterClockwiseRadiusPoint = 6
xlOuterCenterPoint = 2
xlOuterClockwisePoint = 3
xlOuterCounterClockwisePoint = 1

# XlPivotFieldOrientation enumeration
xlColumnField = 2
xlDataField = 4
xlHidden = 0
xlPageField = 3
xlRowField = 1

# XlReadingOrder enumeration
xlContext = -5002
xlLTR = -5003
xlRTL = -5004

# XlRgbColor enumeration
xlAliceBlue = 16775408
xlAntiqueWhite = 14150650
xlAqua = 16776960
xlAquamarine = 13959039
xlAzure = 16777200
xlBeige = 14480885
xlBisque = 12903679
xlBlack = 0
xlBlanchedAlmond = 13495295
xlBlue = 16711680
xlBlueViolet = 14822282
xlBrown = 2763429
xlBurlyWood = 8894686
xlCadetBlue = 10526303
xlChartreuse = 65407
xlCoral = 5275647
xlCornflowerBlue = 15570276
xlCornsilk = 14481663
xlCrimson = 3937500
xlDarkBlue = 9109504
xlDarkCyan = 9145088
xlDarkGoldenrod = 755384
xlDarkGray = 11119017
xlDarkGreen = 25600
xlDarkGrey = 11119017
xlDarkKhaki = 7059389
xlDarkMagenta = 9109643
xlDarkOliveGreen = 3107669
xlDarkOrange = 36095
xlDarkOrchid = 13382297
xlDarkRed = 139
xlDarkSalmon = 8034025
xlDarkSeaGreen = 9419919
xlDarkSlateBlue = 9125192
xlDarkSlateGray = 5197615
xlDarkSlateGrey = 5197615
xlDarkTurquoise = 13749760
xlDarkViolet = 13828244
xlDeepPink = 9639167
xlDeepSkyBlue = 16760576
xlDimGray = 6908265
xlDimGrey = 6908265
xlDodgerBlue = 16748574
xlFireBrick = 2237106
xlFloralWhite = 15792895
xlForestGreen = 2263842
xlFuchsia = 16711935
xlGainsboro = 14474460
xlGhostWhite = 16775416
xlGold = 55295
xlGoldenrod = 2139610
xlGray = 8421504
xlGreen = 32768
xlGreenYellow = 3145645
xlGrey = 8421504
xlHoneydew = 15794160
xlHotPink = 11823615
xlIndianRed = 6053069
xlIndigo = 8519755
xlIvory = 15794175
xlKhaki = 9234160
xlLavender = 16443110
xlLavenderBlush = 16118015
xlLawnGreen = 64636
xlLemonChiffon = 13499135
xlLightBlue = 15128749
xlLightCoral = 8421616
xlLightCyan = 9145088
xlLightGoldenrodYellow = 13826810
xlLightGray = 13882323
xlLightGreen = 9498256
xlLightGrey = 13882323
xlLightPink = 12695295
xlLightSalmon = 8036607
xlLightSeaGreen = 11186720
xlLightSkyBlue = 16436871
xlLightSlateGray = 10061943
xlLightSlateGrey = 10061943
xlLightSteelBlue = 14599344
xlLightYellow = 14745599
xlLime = 65280
xlLimeGreen = 3329330
xlLinen = 15134970
xlMaroon = 128
xlMediumAquamarine = 11206502
xlMediumBlue = 13434880
xlMediumOrchid = 13850042
xlMediumPurple = 14381203
xlMediumSeaGreen = 7451452
xlMediumSlateBlue = 15624315
xlMediumSpringGreen = 10156544
xlMediumTurquoise = 13422920
xlMediumVioletRed = 8721863
xlMidnightBlue = 7346457
xlMintCream = 16449525
xlMistyRose = 14804223
xlMoccasin = 11920639
xlNavajoWhite = 11394815
xlNavy = 8388608
xlNavyBlue = 8388608
xlOldLace = 15136253
xlOlive = 32896
xlOliveDrab = 2330219
xlOrange = 42495
xlOrangeRed = 17919
xlOrchid = 14053594
xlPaleGoldenrod = 7071982
xlPaleGreen = 10025880
xlPaleTurquoise = 15658671
xlPaleVioletRed = 9662683
xlPapayaWhip = 14020607
xlPeachPuff = 12180223
xlPeru = 4163021
xlPink = 13353215
xlPlum = 14524637
xlPowderBlue = 15130800
xlPurple = 8388736
xlRed = 255
xlRosyBrown = 9408444
xlRoyalBlue = 14772545
xlSalmon = 7504122
xlSandyBrown = 6333684
xlSeaGreen = 5737262
xlSeashell = 15660543
xlSienna = 2970272
xlSilver = 12632256
xlSkyBlue = 15453831
xlSlateBlue = 13458026
xlSlateGray = 9470064
xlSlateGrey = 9470064
xlSnow = 16448255
xlSpringGreen = 8388352
xlSteelBlue = 11829830
xlTan = 9221330
xlTeal = 8421376
xlThistle = 14204888
xlTomato = 4678655
xlTurquoise = 13688896
xlViolet = 15631086
xlWheat = 11788021
xlWhite = 16777215
xlWhiteSmoke = 16119285
xlYellow = 65535
xlYellowGreen = 3329434

# XlRowCol enumeration
xlColumns = 2
xlRows = 1

# XlScaleType enumeration
xlScaleLinear = -4132
xlScaleLogarithmic = -4133

# XlSeriesNameLevel enumeration
xlSeriesNameLevelAll = -1
xlSeriesNameLevelCustom = -2
xlSeriesNameLevelNone = -3

# XlSizeRepresents enumeration
xlSizeIsArea = 1
xlSizeIsWidth = 2

# XlTickLabelOrientation enumeration
xlTickLabelOrientationAutomatic = -4105
xlTickLabelOrientationDownward = -4170
xlTickLabelOrientationHorizontal = -4128
xlTickLabelOrientationUpward = -4171
xlTickLabelOrientationVertical = -4166

# XlTickLabelPosition enumeration
xlTickLabelPositionHigh = -4127
xlTickLabelPositionLow = -4134
xlTickLabelPositionNextToAxis = 4
xlTickLabelPositionNone = -4142

# XlTickMark enumeration
xlTickMarkCross = 4
xlTickMarkInside = 2
xlTickMarkNone = -4142
xlTickMarkOutside = 3

# XlTimeUnit enumeration
xlDays = 0
xlMonths = 1
xlYears = 2

# XlTrendlineType enumeration
xlExponential = 5
xlLinear = -4132
xlLogarithmic = -4133
xlMovingAvg = 6
xlPolynomial = 3
xlPower = 4

# XlUnderlineStyle enumeration
xlUnderlineStyleDouble = -4119
xlUnderlineStyleDoubleAccounting = 5
xlUnderlineStyleNone = -4142
xlUnderlineStyleSingle = 2
xlUnderlineStyleSingleAccounting = 4

# XlVAlign enumeration
xlVAlignBottom = -4107
xlVAlignCenter = -4108
xlVAlignDistributed = -4117
xlVAlignJustify = -4130
xlVAlignTop = -4160

class XMLMapping:

    def __init__(self, xmlmapping=None):
        self.com_object= xmlmapping

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def CustomXMLNode(self):
        return self.com_object.CustomXMLNode

    @property
    def customxmlnode(self):
        """Alias for CustomXMLNode"""
        return self.CustomXMLNode

    @property
    def custom_x_m_l_node(self):
        """Alias for CustomXMLNode"""
        return self.CustomXMLNode

    @property
    def CustomXMLPart(self):
        return self.com_object.CustomXMLPart

    @property
    def customxmlpart(self):
        """Alias for CustomXMLPart"""
        return self.CustomXMLPart

    @property
    def custom_x_m_l_part(self):
        """Alias for CustomXMLPart"""
        return self.CustomXMLPart

    @property
    def IsMapped(self):
        return self.com_object.IsMapped

    @property
    def ismapped(self):
        """Alias for IsMapped"""
        return self.IsMapped

    @property
    def is_mapped(self):
        """Alias for IsMapped"""
        return self.IsMapped

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PrefixMappings(self):
        return self.com_object.PrefixMappings

    @property
    def prefixmappings(self):
        """Alias for PrefixMappings"""
        return self.PrefixMappings

    @property
    def prefix_mappings(self):
        """Alias for PrefixMappings"""
        return self.PrefixMappings

    @property
    def XPath(self):
        return self.com_object.XPath

    @property
    def xpath(self):
        """Alias for XPath"""
        return self.XPath

    @property
    def x_path(self):
        """Alias for XPath"""
        return self.XPath

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def SetMapping(self, XPath=None, PrefixMapping=None, Source=None):
        arguments = com_arguments([unwrap(a) for a in [XPath, PrefixMapping, Source]])
        return self.com_object.SetMapping(*arguments)

    def setmapping(self, XPath=None, PrefixMapping=None, Source=None):
        """Alias for SetMapping"""
        arguments = [XPath, PrefixMapping, Source]
        return self.SetMapping(*arguments)

    def set_mapping(self, XPath=None, PrefixMapping=None, Source=None):
        """Alias for SetMapping"""
        arguments = [XPath, PrefixMapping, Source]
        return self.SetMapping(*arguments)

    def SetMappingByNode(self, Node=None):
        arguments = com_arguments([unwrap(a) for a in [Node]])
        return self.com_object.SetMappingByNode(*arguments)

    def setmappingbynode(self, Node=None):
        """Alias for SetMappingByNode"""
        arguments = [Node]
        return self.SetMappingByNode(*arguments)

    def set_mapping_by_node(self, Node=None):
        """Alias for SetMappingByNode"""
        arguments = [Node]
        return self.SetMappingByNode(*arguments)


class XMLNamespace:

    def __init__(self, xmlnamespace=None):
        self.com_object= xmlnamespace

    @property
    def URI(self):
        return self.com_object.URI

    @property
    def uri(self):
        """Alias for URI"""
        return self.URI

    @property
    def u_r_i(self):
        """Alias for URI"""
        return self.URI

    @property
    def Alias(self):
        return self.com_object.Alias

    @property
    def alias(self):
        """Alias for Alias"""
        return self.Alias

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DefaultTransform(self):
        return XSLTransform(self.com_object.DefaultTransform)

    @property
    def defaulttransform(self):
        """Alias for DefaultTransform"""
        return self.DefaultTransform

    @property
    def default_transform(self):
        """Alias for DefaultTransform"""
        return self.DefaultTransform

    @property
    def Location(self):
        return self.com_object.Location

    @Location.setter
    def Location(self, value):
        self.com_object.Location = value

    @property
    def location(self):
        """Alias for Location"""
        return self.Location

    @location.setter
    def location(self, value):
        """Alias for Location.setter"""
        self.Location = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def XSLTransforms(self):
        return self.com_object.XSLTransforms

    @property
    def xsltransforms(self):
        """Alias for XSLTransforms"""
        return self.XSLTransforms

    @property
    def x_s_l_transforms(self):
        """Alias for XSLTransforms"""
        return self.XSLTransforms

    def AttachToDocument(self, Document=None):
        arguments = com_arguments([unwrap(a) for a in [Document]])
        self.com_object.AttachToDocument(*arguments)

    def attachtodocument(self, Document=None):
        """Alias for AttachToDocument"""
        arguments = [Document]
        return self.AttachToDocument(*arguments)

    def attach_to_document(self, Document=None):
        """Alias for AttachToDocument"""
        arguments = [Document]
        return self.AttachToDocument(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class XMLNode:

    def __init__(self, xmlnode=None):
        self.com_object= xmlnode

    def XML(self, DataOnly=None):
        arguments = com_arguments([unwrap(a) for a in [DataOnly]])
        if hasattr(self.com_object, "GetXML"):
            return self.com_object.GetXML(*arguments)
        else:
            return self.com_object.XML(*arguments)

    def xml(self, DataOnly=None):
        """Alias for XML"""
        arguments = [DataOnly]
        return self.XML(*arguments)

    def x_m_l(self, DataOnly=None):
        """Alias for XML"""
        arguments = [DataOnly]
        return self.XML(*arguments)

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Attributes(self):
        return XMLNodes(self.com_object.Attributes)

    @property
    def attributes(self):
        """Alias for Attributes"""
        return self.Attributes

    @property
    def BaseName(self):
        return self.com_object.BaseName

    @property
    def basename(self):
        """Alias for BaseName"""
        return self.BaseName

    @property
    def base_name(self):
        """Alias for BaseName"""
        return self.BaseName

    @property
    def ChildNodes(self):
        return XMLNodes(self.com_object.ChildNodes)

    @property
    def childnodes(self):
        """Alias for ChildNodes"""
        return self.ChildNodes

    @property
    def child_nodes(self):
        """Alias for ChildNodes"""
        return self.ChildNodes

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def FirstChild(self):
        return self.com_object.FirstChild

    @property
    def firstchild(self):
        """Alias for FirstChild"""
        return self.FirstChild

    @property
    def first_child(self):
        """Alias for FirstChild"""
        return self.FirstChild

    @property
    def HasChildNodes(self):
        return self.com_object.HasChildNodes

    @property
    def haschildnodes(self):
        """Alias for HasChildNodes"""
        return self.HasChildNodes

    @property
    def has_child_nodes(self):
        """Alias for HasChildNodes"""
        return self.HasChildNodes

    @property
    def LastChild(self):
        return XMLNode(self.com_object.LastChild)

    @property
    def lastchild(self):
        """Alias for LastChild"""
        return self.LastChild

    @property
    def last_child(self):
        """Alias for LastChild"""
        return self.LastChild

    @property
    def Level(self):
        return self.com_object.Level

    @property
    def level(self):
        """Alias for Level"""
        return self.Level

    @property
    def NamespaceURI(self):
        return self.com_object.NamespaceURI

    @property
    def namespaceuri(self):
        """Alias for NamespaceURI"""
        return self.NamespaceURI

    @property
    def namespace_u_r_i(self):
        """Alias for NamespaceURI"""
        return self.NamespaceURI

    @property
    def NextSibling(self):
        return XMLNode(self.com_object.NextSibling)

    @property
    def nextsibling(self):
        """Alias for NextSibling"""
        return self.NextSibling

    @property
    def next_sibling(self):
        """Alias for NextSibling"""
        return self.NextSibling

    @property
    def NodeType(self):
        return self.com_object.NodeType

    @property
    def nodetype(self):
        """Alias for NodeType"""
        return self.NodeType

    @property
    def node_type(self):
        """Alias for NodeType"""
        return self.NodeType

    @property
    def NodeValue(self):
        return self.com_object.NodeValue

    @NodeValue.setter
    def NodeValue(self, value):
        self.com_object.NodeValue = value

    @property
    def nodevalue(self):
        """Alias for NodeValue"""
        return self.NodeValue

    @nodevalue.setter
    def nodevalue(self, value):
        """Alias for NodeValue.setter"""
        self.NodeValue = value

    @property
    def node_value(self):
        """Alias for NodeValue"""
        return self.NodeValue

    @node_value.setter
    def node_value(self, value):
        """Alias for NodeValue.setter"""
        self.NodeValue = value

    @property
    def OwnerDocument(self):
        return Document(self.com_object.OwnerDocument)

    @property
    def ownerdocument(self):
        """Alias for OwnerDocument"""
        return self.OwnerDocument

    @property
    def owner_document(self):
        """Alias for OwnerDocument"""
        return self.OwnerDocument

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ParentNode(self):
        return XMLNode(self.com_object.ParentNode)

    @property
    def parentnode(self):
        """Alias for ParentNode"""
        return self.ParentNode

    @property
    def parent_node(self):
        """Alias for ParentNode"""
        return self.ParentNode

    @property
    def PlaceholderText(self):
        return self.com_object.PlaceholderText

    @property
    def placeholdertext(self):
        """Alias for PlaceholderText"""
        return self.PlaceholderText

    @property
    def placeholder_text(self):
        """Alias for PlaceholderText"""
        return self.PlaceholderText

    @property
    def PreviousSibling(self):
        return XMLNode(self.com_object.PreviousSibling)

    @property
    def previoussibling(self):
        """Alias for PreviousSibling"""
        return self.PreviousSibling

    @property
    def previous_sibling(self):
        """Alias for PreviousSibling"""
        return self.PreviousSibling

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    def ValidationErrorText(self, Advanced=None):
        arguments = com_arguments([unwrap(a) for a in [Advanced]])
        if hasattr(self.com_object, "GetValidationErrorText"):
            return self.com_object.GetValidationErrorText(*arguments)
        else:
            return self.com_object.ValidationErrorText(*arguments)

    def validationerrortext(self, Advanced=None):
        """Alias for ValidationErrorText"""
        arguments = [Advanced]
        return self.ValidationErrorText(*arguments)

    def validation_error_text(self, Advanced=None):
        """Alias for ValidationErrorText"""
        arguments = [Advanced]
        return self.ValidationErrorText(*arguments)

    @property
    def ValidationStatus(self):
        return self.com_object.ValidationStatus

    @property
    def validationstatus(self):
        """Alias for ValidationStatus"""
        return self.ValidationStatus

    @property
    def validation_status(self):
        """Alias for ValidationStatus"""
        return self.ValidationStatus

    @property
    def WordOpenXML(self):
        return self.com_object.WordOpenXML

    @property
    def wordopenxml(self):
        """Alias for WordOpenXML"""
        return self.WordOpenXML

    @property
    def word_open_x_m_l(self):
        """Alias for WordOpenXML"""
        return self.WordOpenXML

    def Copy(self):
        return self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Cut(self):
        self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def RemoveChild(self, ChildElement=None):
        arguments = com_arguments([unwrap(a) for a in [ChildElement]])
        return self.com_object.RemoveChild(*arguments)

    def removechild(self, ChildElement=None):
        """Alias for RemoveChild"""
        arguments = [ChildElement]
        return self.RemoveChild(*arguments)

    def remove_child(self, ChildElement=None):
        """Alias for RemoveChild"""
        arguments = [ChildElement]
        return self.RemoveChild(*arguments)

    def SelectNodes(self, XPath=None, PrefixMapping=None, FastSearchSkippingTextNodes=None):
        arguments = com_arguments([unwrap(a) for a in [XPath, PrefixMapping, FastSearchSkippingTextNodes]])
        return XMLNodes(self.com_object.SelectNodes(*arguments))

    def selectnodes(self, XPath=None, PrefixMapping=None, FastSearchSkippingTextNodes=None):
        """Alias for SelectNodes"""
        arguments = [XPath, PrefixMapping, FastSearchSkippingTextNodes]
        return self.SelectNodes(*arguments)

    def select_nodes(self, XPath=None, PrefixMapping=None, FastSearchSkippingTextNodes=None):
        """Alias for SelectNodes"""
        arguments = [XPath, PrefixMapping, FastSearchSkippingTextNodes]
        return self.SelectNodes(*arguments)

    def SelectSingleNode(self, XPath=None, PrefixMapping=None, FastSearchSkippingTextNodes=None):
        arguments = com_arguments([unwrap(a) for a in [XPath, PrefixMapping, FastSearchSkippingTextNodes]])
        return XMLNode(self.com_object.SelectSingleNode(*arguments))

    def selectsinglenode(self, XPath=None, PrefixMapping=None, FastSearchSkippingTextNodes=None):
        """Alias for SelectSingleNode"""
        arguments = [XPath, PrefixMapping, FastSearchSkippingTextNodes]
        return self.SelectSingleNode(*arguments)

    def select_single_node(self, XPath=None, PrefixMapping=None, FastSearchSkippingTextNodes=None):
        """Alias for SelectSingleNode"""
        arguments = [XPath, PrefixMapping, FastSearchSkippingTextNodes]
        return self.SelectSingleNode(*arguments)

    def SetValidationError(self, Status=None, ErrorText=None, ClearedAutomatically=None):
        arguments = com_arguments([unwrap(a) for a in [Status, ErrorText, ClearedAutomatically]])
        self.com_object.SetValidationError(*arguments)

    def setvalidationerror(self, Status=None, ErrorText=None, ClearedAutomatically=None):
        """Alias for SetValidationError"""
        arguments = [Status, ErrorText, ClearedAutomatically]
        return self.SetValidationError(*arguments)

    def set_validation_error(self, Status=None, ErrorText=None, ClearedAutomatically=None):
        """Alias for SetValidationError"""
        arguments = [Status, ErrorText, ClearedAutomatically]
        return self.SetValidationError(*arguments)

    def Validate(self):
        return self.com_object.Validate()

    def validate(self):
        """Alias for Validate"""
        return self.Validate()


class XMLNodes:

    def __init__(self, xmlnodes=None):
        self.com_object= xmlnodes

    def __call__(self, item):
        return XMLNode(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return XMLNode(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class XMLSchemaReference:

    def __init__(self, xmlschemareference=None):
        self.com_object= xmlschemareference

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Location(self):
        return self.com_object.Location

    @property
    def location(self):
        """Alias for Location"""
        return self.Location

    @property
    def NamespaceURI(self):
        return self.com_object.NamespaceURI

    @property
    def namespaceuri(self):
        """Alias for NamespaceURI"""
        return self.NamespaceURI

    @property
    def namespace_u_r_i(self):
        """Alias for NamespaceURI"""
        return self.NamespaceURI

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Reload(self):
        return self.com_object.Reload()

    def reload(self):
        """Alias for Reload"""
        return self.Reload()


class XMLSchemaReferences:

    def __init__(self, xmlschemareferences=None):
        self.com_object= xmlschemareferences

    def __call__(self, item):
        return XMLSchemaReference(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def HideValidationErrors(self):
        return self.com_object.HideValidationErrors

    @HideValidationErrors.setter
    def HideValidationErrors(self, value):
        self.com_object.HideValidationErrors = value

    @property
    def hidevalidationerrors(self):
        """Alias for HideValidationErrors"""
        return self.HideValidationErrors

    @hidevalidationerrors.setter
    def hidevalidationerrors(self, value):
        """Alias for HideValidationErrors.setter"""
        self.HideValidationErrors = value

    @property
    def hide_validation_errors(self):
        """Alias for HideValidationErrors"""
        return self.HideValidationErrors

    @hide_validation_errors.setter
    def hide_validation_errors(self, value):
        """Alias for HideValidationErrors.setter"""
        self.HideValidationErrors = value

    @property
    def IgnoreMixedContent(self):
        return self.com_object.IgnoreMixedContent

    @IgnoreMixedContent.setter
    def IgnoreMixedContent(self, value):
        self.com_object.IgnoreMixedContent = value

    @property
    def ignoremixedcontent(self):
        """Alias for IgnoreMixedContent"""
        return self.IgnoreMixedContent

    @ignoremixedcontent.setter
    def ignoremixedcontent(self, value):
        """Alias for IgnoreMixedContent.setter"""
        self.IgnoreMixedContent = value

    @property
    def ignore_mixed_content(self):
        """Alias for IgnoreMixedContent"""
        return self.IgnoreMixedContent

    @ignore_mixed_content.setter
    def ignore_mixed_content(self, value):
        """Alias for IgnoreMixedContent.setter"""
        self.IgnoreMixedContent = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ShowPlaceholderText(self):
        return self.com_object.ShowPlaceholderText

    @ShowPlaceholderText.setter
    def ShowPlaceholderText(self, value):
        self.com_object.ShowPlaceholderText = value

    @property
    def showplaceholdertext(self):
        """Alias for ShowPlaceholderText"""
        return self.ShowPlaceholderText

    @showplaceholdertext.setter
    def showplaceholdertext(self, value):
        """Alias for ShowPlaceholderText.setter"""
        self.ShowPlaceholderText = value

    @property
    def show_placeholder_text(self):
        """Alias for ShowPlaceholderText"""
        return self.ShowPlaceholderText

    @show_placeholder_text.setter
    def show_placeholder_text(self, value):
        """Alias for ShowPlaceholderText.setter"""
        self.ShowPlaceholderText = value

    def Add(self, NamespaceURI=None, Alias=None, FileName=None, InstallForAllUsers=None):
        arguments = com_arguments([unwrap(a) for a in [NamespaceURI, Alias, FileName, InstallForAllUsers]])
        return XMLSchemaReference(self.com_object.Add(*arguments))

    def add(self, NamespaceURI=None, Alias=None, FileName=None, InstallForAllUsers=None):
        """Alias for Add"""
        arguments = [NamespaceURI, Alias, FileName, InstallForAllUsers]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return XMLSchemaReference(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Validate(self):
        return self.com_object.Validate()

    def validate(self):
        """Alias for Validate"""
        return self.Validate()


class XSLTransform:

    def __init__(self, xsltransform=None):
        self.com_object= xsltransform

    @property
    def Alias(self):
        return self.com_object.Alias

    @property
    def alias(self):
        """Alias for Alias"""
        return self.Alias

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ID(self):
        return self.com_object.ID

    @property
    def id(self):
        """Alias for ID"""
        return self.ID

    @property
    def i_d(self):
        """Alias for ID"""
        return self.ID

    @property
    def Location(self):
        return self.com_object.Location

    @Location.setter
    def Location(self, value):
        self.com_object.Location = value

    @property
    def location(self):
        """Alias for Location"""
        return self.Location

    @location.setter
    def location(self, value):
        """Alias for Location.setter"""
        self.Location = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class Zoom:

    def __init__(self, zoom=None):
        self.com_object= zoom

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def PageColumns(self):
        return self.com_object.PageColumns

    @PageColumns.setter
    def PageColumns(self, value):
        self.com_object.PageColumns = value

    @property
    def pagecolumns(self):
        """Alias for PageColumns"""
        return self.PageColumns

    @pagecolumns.setter
    def pagecolumns(self, value):
        """Alias for PageColumns.setter"""
        self.PageColumns = value

    @property
    def page_columns(self):
        """Alias for PageColumns"""
        return self.PageColumns

    @page_columns.setter
    def page_columns(self, value):
        """Alias for PageColumns.setter"""
        self.PageColumns = value

    @property
    def PageFit(self):
        return WdPageFit(self.com_object.PageFit)

    @PageFit.setter
    def PageFit(self, value):
        self.com_object.PageFit = value

    @property
    def pagefit(self):
        """Alias for PageFit"""
        return self.PageFit

    @pagefit.setter
    def pagefit(self, value):
        """Alias for PageFit.setter"""
        self.PageFit = value

    @property
    def page_fit(self):
        """Alias for PageFit"""
        return self.PageFit

    @page_fit.setter
    def page_fit(self, value):
        """Alias for PageFit.setter"""
        self.PageFit = value

    @property
    def PageRows(self):
        return self.com_object.PageRows

    @PageRows.setter
    def PageRows(self, value):
        self.com_object.PageRows = value

    @property
    def pagerows(self):
        """Alias for PageRows"""
        return self.PageRows

    @pagerows.setter
    def pagerows(self, value):
        """Alias for PageRows.setter"""
        self.PageRows = value

    @property
    def page_rows(self):
        """Alias for PageRows"""
        return self.PageRows

    @page_rows.setter
    def page_rows(self, value):
        """Alias for PageRows.setter"""
        self.PageRows = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Percentage(self):
        return self.com_object.Percentage

    @Percentage.setter
    def Percentage(self, value):
        self.com_object.Percentage = value

    @property
    def percentage(self):
        """Alias for Percentage"""
        return self.Percentage

    @percentage.setter
    def percentage(self, value):
        """Alias for Percentage.setter"""
        self.Percentage = value


class Zooms:

    def __init__(self, zooms=None):
        self.com_object= zooms

    def __call__(self, item):
        return Zoom(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Zoom(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

