from . import com_arguments, unwrap
from .office import *

import win32com.client

class AboveAverage:

    def __init__(self, aboveaverage=None):
        self.com_object= aboveaverage

    @property
    def AboveBelow(self):
        return XlAboveBelow(self.com_object.AboveBelow)

    @AboveBelow.setter
    def AboveBelow(self, value):
        self.com_object.AboveBelow = value

    @property
    def abovebelow(self):
        """Alias for AboveBelow"""
        return self.AboveBelow

    @abovebelow.setter
    def abovebelow(self, value):
        """Alias for AboveBelow.setter"""
        self.AboveBelow = value

    @property
    def above_below(self):
        """Alias for AboveBelow"""
        return self.AboveBelow

    @above_below.setter
    def above_below(self, value):
        """Alias for AboveBelow.setter"""
        self.AboveBelow = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AppliesTo(self):
        return Range(self.com_object.AppliesTo)

    @property
    def appliesto(self):
        """Alias for AppliesTo"""
        return self.AppliesTo

    @property
    def applies_to(self):
        """Alias for AppliesTo"""
        return self.AppliesTo

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def CalcFor(self):
        return XlCalcFor(self.com_object.CalcFor)

    @CalcFor.setter
    def CalcFor(self, value):
        self.com_object.CalcFor = value

    @property
    def calcfor(self):
        """Alias for CalcFor"""
        return self.CalcFor

    @calcfor.setter
    def calcfor(self, value):
        """Alias for CalcFor.setter"""
        self.CalcFor = value

    @property
    def calc_for(self):
        """Alias for CalcFor"""
        return self.CalcFor

    @calc_for.setter
    def calc_for(self, value):
        """Alias for CalcFor.setter"""
        self.CalcFor = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def Interior(self):
        return Interior(self.com_object.Interior)

    @property
    def interior(self):
        """Alias for Interior"""
        return self.Interior

    @property
    def NumberFormat(self):
        return self.com_object.NumberFormat

    @NumberFormat.setter
    def NumberFormat(self, value):
        self.com_object.NumberFormat = value

    @property
    def numberformat(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @numberformat.setter
    def numberformat(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def number_format(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @number_format.setter
    def number_format(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def NumStdDev(self):
        return AboveAverage(self.com_object.NumStdDev)

    @NumStdDev.setter
    def NumStdDev(self, value):
        self.com_object.NumStdDev = value

    @property
    def numstddev(self):
        """Alias for NumStdDev"""
        return self.NumStdDev

    @numstddev.setter
    def numstddev(self, value):
        """Alias for NumStdDev.setter"""
        self.NumStdDev = value

    @property
    def num_std_dev(self):
        """Alias for NumStdDev"""
        return self.NumStdDev

    @num_std_dev.setter
    def num_std_dev(self, value):
        """Alias for NumStdDev.setter"""
        self.NumStdDev = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Priority(self):
        return self.com_object.Priority

    @Priority.setter
    def Priority(self, value):
        self.com_object.Priority = value

    @property
    def priority(self):
        """Alias for Priority"""
        return self.Priority

    @priority.setter
    def priority(self, value):
        """Alias for Priority.setter"""
        self.Priority = value

    @property
    def PTCondition(self):
        return self.com_object.PTCondition

    @property
    def ptcondition(self):
        """Alias for PTCondition"""
        return self.PTCondition

    @property
    def p_t_condition(self):
        """Alias for PTCondition"""
        return self.PTCondition

    @property
    def ScopeType(self):
        return XlPivotConditionScope(self.com_object.ScopeType)

    @ScopeType.setter
    def ScopeType(self, value):
        self.com_object.ScopeType = value

    @property
    def scopetype(self):
        """Alias for ScopeType"""
        return self.ScopeType

    @scopetype.setter
    def scopetype(self, value):
        """Alias for ScopeType.setter"""
        self.ScopeType = value

    @property
    def scope_type(self):
        """Alias for ScopeType"""
        return self.ScopeType

    @scope_type.setter
    def scope_type(self, value):
        """Alias for ScopeType.setter"""
        self.ScopeType = value

    @property
    def StopIfTrue(self):
        return self.com_object.StopIfTrue

    @StopIfTrue.setter
    def StopIfTrue(self, value):
        self.com_object.StopIfTrue = value

    @property
    def stopiftrue(self):
        """Alias for StopIfTrue"""
        return self.StopIfTrue

    @stopiftrue.setter
    def stopiftrue(self, value):
        """Alias for StopIfTrue.setter"""
        self.StopIfTrue = value

    @property
    def stop_if_true(self):
        """Alias for StopIfTrue"""
        return self.StopIfTrue

    @stop_if_true.setter
    def stop_if_true(self, value):
        """Alias for StopIfTrue.setter"""
        self.StopIfTrue = value

    @property
    def Type(self):
        return XlFormatConditionType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def ModifyAppliesToRange(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        self.com_object.ModifyAppliesToRange(*arguments)

    def modifyappliestorange(self, Range=None):
        """Alias for ModifyAppliesToRange"""
        arguments = [Range]
        return self.ModifyAppliesToRange(*arguments)

    def modify_applies_to_range(self, Range=None):
        """Alias for ModifyAppliesToRange"""
        arguments = [Range]
        return self.ModifyAppliesToRange(*arguments)

    def SetFirstPriority(self):
        self.com_object.SetFirstPriority()

    def setfirstpriority(self):
        """Alias for SetFirstPriority"""
        return self.SetFirstPriority()

    def set_first_priority(self):
        """Alias for SetFirstPriority"""
        return self.SetFirstPriority()

    def SetLastPriority(self):
        self.com_object.SetLastPriority()

    def setlastpriority(self):
        """Alias for SetLastPriority"""
        return self.SetLastPriority()

    def set_last_priority(self):
        """Alias for SetLastPriority"""
        return self.SetLastPriority()


class Action:

    def __init__(self, action=None):
        self.com_object= action

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Caption(self):
        return Action(self.com_object.Caption)

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @property
    def Content(self):
        return Action(self.com_object.Content)

    @property
    def content(self):
        """Alias for Content"""
        return self.Content

    @property
    def Coordinate(self):
        return Action(self.com_object.Coordinate)

    @property
    def coordinate(self):
        """Alias for Coordinate"""
        return self.Coordinate

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Type(self):
        return XlActionType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def Execute(self):
        self.com_object.Execute()

    def execute(self):
        """Alias for Execute"""
        return self.Execute()


class Actions:

    def __init__(self, actions=None):
        self.com_object= actions

    def __call__(self, item):
        return Action(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return Actions(self.com_object.GetItem(*arguments))
        else:
            return Actions(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class AddIn:

    def __init__(self, addin=None):
        self.com_object= addin

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def CLSID(self):
        return self.com_object.CLSID

    @property
    def clsid(self):
        """Alias for CLSID"""
        return self.CLSID

    @property
    def c_l_s_i_d(self):
        """Alias for CLSID"""
        return self.CLSID

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def FullName(self):
        return self.com_object.FullName

    @property
    def fullname(self):
        """Alias for FullName"""
        return self.FullName

    @property
    def full_name(self):
        """Alias for FullName"""
        return self.FullName

    @property
    def Installed(self):
        return self.com_object.Installed

    @Installed.setter
    def Installed(self, value):
        self.com_object.Installed = value

    @property
    def installed(self):
        """Alias for Installed"""
        return self.Installed

    @installed.setter
    def installed(self, value):
        """Alias for Installed.setter"""
        self.Installed = value

    @property
    def IsOpen(self):
        return self.com_object.IsOpen

    @property
    def isopen(self):
        """Alias for IsOpen"""
        return self.IsOpen

    @property
    def is_open(self):
        """Alias for IsOpen"""
        return self.IsOpen

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Path(self):
        return self.com_object.Path

    @property
    def path(self):
        """Alias for Path"""
        return self.Path

    @property
    def progID(self):
        return self.com_object.progID

    @property
    def progid(self):
        """Alias for progID"""
        return self.progID

    @property
    def prog_i_d(self):
        """Alias for progID"""
        return self.progID


class AddIns:

    def __init__(self, addins=None):
        self.com_object= addins

    def __call__(self, item):
        return AddIn(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, FileName=None, CopyFile=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, CopyFile]])
        return AddIn(self.com_object.Add(*arguments))

    def add(self, FileName=None, CopyFile=None):
        """Alias for Add"""
        arguments = [FileName, CopyFile]
        return self.Add(*arguments)


class AddIns2:

    def __init__(self, addins2=None):
        self.com_object= addins2

    def __call__(self, item):
        return AddIns2(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, FileName=None, CopyFile=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, CopyFile]])
        return AddIn(self.com_object.Add(*arguments))

    def add(self, FileName=None, CopyFile=None):
        """Alias for Add"""
        arguments = [FileName, CopyFile]
        return self.Add(*arguments)


class Adjustments:

    def __init__(self, adjustments=None):
        self.com_object= adjustments

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Item(self):
        return self.com_object.Item

    @Item.setter
    def Item(self, value):
        self.com_object.Item = value

    @property
    def item(self):
        """Alias for Item"""
        return self.Item

    @item.setter
    def item(self, value):
        """Alias for Item.setter"""
        self.Item = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class AllowEditRange:

    def __init__(self, alloweditrange=None):
        self.com_object= alloweditrange

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def Title(self):
        return self.com_object.Title

    @Title.setter
    def Title(self, value):
        self.com_object.Title = value

    @property
    def title(self):
        """Alias for Title"""
        return self.Title

    @title.setter
    def title(self, value):
        """Alias for Title.setter"""
        self.Title = value

    @property
    def Users(self):
        return UserAccessList(self.com_object.Users)

    @property
    def users(self):
        """Alias for Users"""
        return self.Users

    def ChangePassword(self, Password=None):
        arguments = com_arguments([unwrap(a) for a in [Password]])
        self.com_object.ChangePassword(*arguments)

    def changepassword(self, Password=None):
        """Alias for ChangePassword"""
        arguments = [Password]
        return self.ChangePassword(*arguments)

    def change_password(self, Password=None):
        """Alias for ChangePassword"""
        arguments = [Password]
        return self.ChangePassword(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Unprotect(self, Password=None):
        arguments = com_arguments([unwrap(a) for a in [Password]])
        self.com_object.Unprotect(*arguments)

    def unprotect(self, Password=None):
        """Alias for Unprotect"""
        arguments = [Password]
        return self.Unprotect(*arguments)


class AllowEditRanges:

    def __init__(self, alloweditranges=None):
        self.com_object= alloweditranges

    def __call__(self, item):
        return AllowEditRange(self.com_object(item))

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Add(self, Title=None, Range=None, Password=None):
        arguments = com_arguments([unwrap(a) for a in [Title, Range, Password]])
        return AllowEditRange(self.com_object.Add(*arguments))

    def add(self, Title=None, Range=None, Password=None):
        """Alias for Add"""
        arguments = [Title, Range, Password]
        return self.Add(*arguments)


class Application:

    def __init__(self, application=None):
        if application is None:
            self.com_object = win32com.client.gencache.EnsureDispatch("Excel.Application")
        else:
            self.com_object = application

    @property
    def ActiveCell(self):
        return Range(self.com_object.ActiveCell)

    @property
    def activecell(self):
        """Alias for ActiveCell"""
        return self.ActiveCell

    @property
    def active_cell(self):
        """Alias for ActiveCell"""
        return self.ActiveCell

    @property
    def ActiveChart(self):
        return Chart(self.com_object.ActiveChart)

    @property
    def activechart(self):
        """Alias for ActiveChart"""
        return self.ActiveChart

    @property
    def active_chart(self):
        """Alias for ActiveChart"""
        return self.ActiveChart

    @property
    def ActiveEncryptionSession(self):
        return self.com_object.ActiveEncryptionSession

    @property
    def activeencryptionsession(self):
        """Alias for ActiveEncryptionSession"""
        return self.ActiveEncryptionSession

    @property
    def active_encryption_session(self):
        """Alias for ActiveEncryptionSession"""
        return self.ActiveEncryptionSession

    @property
    def ActivePrinter(self):
        return self.com_object.ActivePrinter

    @ActivePrinter.setter
    def ActivePrinter(self, value):
        self.com_object.ActivePrinter = value

    @property
    def activeprinter(self):
        """Alias for ActivePrinter"""
        return self.ActivePrinter

    @activeprinter.setter
    def activeprinter(self, value):
        """Alias for ActivePrinter.setter"""
        self.ActivePrinter = value

    @property
    def active_printer(self):
        """Alias for ActivePrinter"""
        return self.ActivePrinter

    @active_printer.setter
    def active_printer(self, value):
        """Alias for ActivePrinter.setter"""
        self.ActivePrinter = value

    @property
    def ActiveProtectedViewWindow(self):
        return ProtectedViewWindow(self.com_object.ActiveProtectedViewWindow)

    @property
    def activeprotectedviewwindow(self):
        """Alias for ActiveProtectedViewWindow"""
        return self.ActiveProtectedViewWindow

    @property
    def active_protected_view_window(self):
        """Alias for ActiveProtectedViewWindow"""
        return self.ActiveProtectedViewWindow

    @property
    def ActiveSheet(self):
        return self.com_object.ActiveSheet

    @property
    def activesheet(self):
        """Alias for ActiveSheet"""
        return self.ActiveSheet

    @property
    def active_sheet(self):
        """Alias for ActiveSheet"""
        return self.ActiveSheet

    @property
    def ActiveWindow(self):
        return Window(self.com_object.ActiveWindow)

    @property
    def activewindow(self):
        """Alias for ActiveWindow"""
        return self.ActiveWindow

    @property
    def active_window(self):
        """Alias for ActiveWindow"""
        return self.ActiveWindow

    @property
    def ActiveWorkbook(self):
        return Workbook(self.com_object.ActiveWorkbook)

    @property
    def activeworkbook(self):
        """Alias for ActiveWorkbook"""
        return self.ActiveWorkbook

    @property
    def active_workbook(self):
        """Alias for ActiveWorkbook"""
        return self.ActiveWorkbook

    @property
    def AddIns(self):
        return AddIns(self.com_object.AddIns)

    @property
    def addins(self):
        """Alias for AddIns"""
        return self.AddIns

    @property
    def add_ins(self):
        """Alias for AddIns"""
        return self.AddIns

    @property
    def AddIns2(self):
        return AddIns2(self.com_object.AddIns2)

    @property
    def addins2(self):
        """Alias for AddIns2"""
        return self.AddIns2

    @property
    def add_ins2(self):
        """Alias for AddIns2"""
        return self.AddIns2

    @property
    def AlertBeforeOverwriting(self):
        return self.com_object.AlertBeforeOverwriting

    @AlertBeforeOverwriting.setter
    def AlertBeforeOverwriting(self, value):
        self.com_object.AlertBeforeOverwriting = value

    @property
    def alertbeforeoverwriting(self):
        """Alias for AlertBeforeOverwriting"""
        return self.AlertBeforeOverwriting

    @alertbeforeoverwriting.setter
    def alertbeforeoverwriting(self, value):
        """Alias for AlertBeforeOverwriting.setter"""
        self.AlertBeforeOverwriting = value

    @property
    def alert_before_overwriting(self):
        """Alias for AlertBeforeOverwriting"""
        return self.AlertBeforeOverwriting

    @alert_before_overwriting.setter
    def alert_before_overwriting(self, value):
        """Alias for AlertBeforeOverwriting.setter"""
        self.AlertBeforeOverwriting = value

    @property
    def AltStartupPath(self):
        return self.com_object.AltStartupPath

    @AltStartupPath.setter
    def AltStartupPath(self, value):
        self.com_object.AltStartupPath = value

    @property
    def altstartuppath(self):
        """Alias for AltStartupPath"""
        return self.AltStartupPath

    @altstartuppath.setter
    def altstartuppath(self, value):
        """Alias for AltStartupPath.setter"""
        self.AltStartupPath = value

    @property
    def alt_startup_path(self):
        """Alias for AltStartupPath"""
        return self.AltStartupPath

    @alt_startup_path.setter
    def alt_startup_path(self, value):
        """Alias for AltStartupPath.setter"""
        self.AltStartupPath = value

    @property
    def AlwaysUseClearType(self):
        return self.com_object.AlwaysUseClearType

    @AlwaysUseClearType.setter
    def AlwaysUseClearType(self, value):
        self.com_object.AlwaysUseClearType = value

    @property
    def alwaysusecleartype(self):
        """Alias for AlwaysUseClearType"""
        return self.AlwaysUseClearType

    @alwaysusecleartype.setter
    def alwaysusecleartype(self, value):
        """Alias for AlwaysUseClearType.setter"""
        self.AlwaysUseClearType = value

    @property
    def always_use_clear_type(self):
        """Alias for AlwaysUseClearType"""
        return self.AlwaysUseClearType

    @always_use_clear_type.setter
    def always_use_clear_type(self, value):
        """Alias for AlwaysUseClearType.setter"""
        self.AlwaysUseClearType = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ArbitraryXMLSupportAvailable(self):
        return self.com_object.ArbitraryXMLSupportAvailable

    @property
    def arbitraryxmlsupportavailable(self):
        """Alias for ArbitraryXMLSupportAvailable"""
        return self.ArbitraryXMLSupportAvailable

    @property
    def arbitrary_x_m_l_support_available(self):
        """Alias for ArbitraryXMLSupportAvailable"""
        return self.ArbitraryXMLSupportAvailable

    @property
    def AskToUpdateLinks(self):
        return self.com_object.AskToUpdateLinks

    @AskToUpdateLinks.setter
    def AskToUpdateLinks(self, value):
        self.com_object.AskToUpdateLinks = value

    @property
    def asktoupdatelinks(self):
        """Alias for AskToUpdateLinks"""
        return self.AskToUpdateLinks

    @asktoupdatelinks.setter
    def asktoupdatelinks(self, value):
        """Alias for AskToUpdateLinks.setter"""
        self.AskToUpdateLinks = value

    @property
    def ask_to_update_links(self):
        """Alias for AskToUpdateLinks"""
        return self.AskToUpdateLinks

    @ask_to_update_links.setter
    def ask_to_update_links(self, value):
        """Alias for AskToUpdateLinks.setter"""
        self.AskToUpdateLinks = value

    @property
    def Assistance(self):
        return self.com_object.Assistance

    @property
    def assistance(self):
        """Alias for Assistance"""
        return self.Assistance

    @property
    def AutoCorrect(self):
        return AutoCorrect(self.com_object.AutoCorrect)

    @property
    def autocorrect(self):
        """Alias for AutoCorrect"""
        return self.AutoCorrect

    @property
    def auto_correct(self):
        """Alias for AutoCorrect"""
        return self.AutoCorrect

    @property
    def AutoFormatAsYouTypeReplaceHyperlinks(self):
        return self.com_object.AutoFormatAsYouTypeReplaceHyperlinks

    @AutoFormatAsYouTypeReplaceHyperlinks.setter
    def AutoFormatAsYouTypeReplaceHyperlinks(self, value):
        self.com_object.AutoFormatAsYouTypeReplaceHyperlinks = value

    @property
    def autoformatasyoutypereplacehyperlinks(self):
        """Alias for AutoFormatAsYouTypeReplaceHyperlinks"""
        return self.AutoFormatAsYouTypeReplaceHyperlinks

    @autoformatasyoutypereplacehyperlinks.setter
    def autoformatasyoutypereplacehyperlinks(self, value):
        """Alias for AutoFormatAsYouTypeReplaceHyperlinks.setter"""
        self.AutoFormatAsYouTypeReplaceHyperlinks = value

    @property
    def auto_format_as_you_type_replace_hyperlinks(self):
        """Alias for AutoFormatAsYouTypeReplaceHyperlinks"""
        return self.AutoFormatAsYouTypeReplaceHyperlinks

    @auto_format_as_you_type_replace_hyperlinks.setter
    def auto_format_as_you_type_replace_hyperlinks(self, value):
        """Alias for AutoFormatAsYouTypeReplaceHyperlinks.setter"""
        self.AutoFormatAsYouTypeReplaceHyperlinks = value

    @property
    def AutomationSecurity(self):
        return self.com_object.AutomationSecurity

    @AutomationSecurity.setter
    def AutomationSecurity(self, value):
        self.com_object.AutomationSecurity = value

    @property
    def automationsecurity(self):
        """Alias for AutomationSecurity"""
        return self.AutomationSecurity

    @automationsecurity.setter
    def automationsecurity(self, value):
        """Alias for AutomationSecurity.setter"""
        self.AutomationSecurity = value

    @property
    def automation_security(self):
        """Alias for AutomationSecurity"""
        return self.AutomationSecurity

    @automation_security.setter
    def automation_security(self, value):
        """Alias for AutomationSecurity.setter"""
        self.AutomationSecurity = value

    @property
    def AutoPercentEntry(self):
        return self.com_object.AutoPercentEntry

    @AutoPercentEntry.setter
    def AutoPercentEntry(self, value):
        self.com_object.AutoPercentEntry = value

    @property
    def autopercententry(self):
        """Alias for AutoPercentEntry"""
        return self.AutoPercentEntry

    @autopercententry.setter
    def autopercententry(self, value):
        """Alias for AutoPercentEntry.setter"""
        self.AutoPercentEntry = value

    @property
    def auto_percent_entry(self):
        """Alias for AutoPercentEntry"""
        return self.AutoPercentEntry

    @auto_percent_entry.setter
    def auto_percent_entry(self, value):
        """Alias for AutoPercentEntry.setter"""
        self.AutoPercentEntry = value

    @property
    def AutoRecover(self):
        return AutoRecover(self.com_object.AutoRecover)

    @property
    def autorecover(self):
        """Alias for AutoRecover"""
        return self.AutoRecover

    @property
    def auto_recover(self):
        """Alias for AutoRecover"""
        return self.AutoRecover

    @property
    def Build(self):
        return self.com_object.Build

    @property
    def build(self):
        """Alias for Build"""
        return self.Build

    @property
    def CalculateBeforeSave(self):
        return self.com_object.CalculateBeforeSave

    @CalculateBeforeSave.setter
    def CalculateBeforeSave(self, value):
        self.com_object.CalculateBeforeSave = value

    @property
    def calculatebeforesave(self):
        """Alias for CalculateBeforeSave"""
        return self.CalculateBeforeSave

    @calculatebeforesave.setter
    def calculatebeforesave(self, value):
        """Alias for CalculateBeforeSave.setter"""
        self.CalculateBeforeSave = value

    @property
    def calculate_before_save(self):
        """Alias for CalculateBeforeSave"""
        return self.CalculateBeforeSave

    @calculate_before_save.setter
    def calculate_before_save(self, value):
        """Alias for CalculateBeforeSave.setter"""
        self.CalculateBeforeSave = value

    @property
    def Calculation(self):
        return XlCalculation(self.com_object.Calculation)

    @Calculation.setter
    def Calculation(self, value):
        self.com_object.Calculation = value

    @property
    def calculation(self):
        """Alias for Calculation"""
        return self.Calculation

    @calculation.setter
    def calculation(self, value):
        """Alias for Calculation.setter"""
        self.Calculation = value

    @property
    def CalculationInterruptKey(self):
        return self.com_object.CalculationInterruptKey

    @CalculationInterruptKey.setter
    def CalculationInterruptKey(self, value):
        self.com_object.CalculationInterruptKey = value

    @property
    def calculationinterruptkey(self):
        """Alias for CalculationInterruptKey"""
        return self.CalculationInterruptKey

    @calculationinterruptkey.setter
    def calculationinterruptkey(self, value):
        """Alias for CalculationInterruptKey.setter"""
        self.CalculationInterruptKey = value

    @property
    def calculation_interrupt_key(self):
        """Alias for CalculationInterruptKey"""
        return self.CalculationInterruptKey

    @calculation_interrupt_key.setter
    def calculation_interrupt_key(self, value):
        """Alias for CalculationInterruptKey.setter"""
        self.CalculationInterruptKey = value

    @property
    def CalculationState(self):
        return XlCalculationState(self.com_object.CalculationState)

    @property
    def calculationstate(self):
        """Alias for CalculationState"""
        return self.CalculationState

    @property
    def calculation_state(self):
        """Alias for CalculationState"""
        return self.CalculationState

    @property
    def CalculationVersion(self):
        return self.com_object.CalculationVersion

    @property
    def calculationversion(self):
        """Alias for CalculationVersion"""
        return self.CalculationVersion

    @property
    def calculation_version(self):
        """Alias for CalculationVersion"""
        return self.CalculationVersion

    def Caller(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetCaller"):
            return self.com_object.GetCaller(*arguments)
        else:
            return self.com_object.Caller(*arguments)

    def caller(self, Index=None):
        """Alias for Caller"""
        arguments = [Index]
        return self.Caller(*arguments)

    @property
    def CanPlaySounds(self):
        return self.com_object.CanPlaySounds

    @property
    def canplaysounds(self):
        """Alias for CanPlaySounds"""
        return self.CanPlaySounds

    @property
    def can_play_sounds(self):
        """Alias for CanPlaySounds"""
        return self.CanPlaySounds

    @property
    def CanRecordSounds(self):
        return self.com_object.CanRecordSounds

    @property
    def canrecordsounds(self):
        """Alias for CanRecordSounds"""
        return self.CanRecordSounds

    @property
    def can_record_sounds(self):
        """Alias for CanRecordSounds"""
        return self.CanRecordSounds

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    @property
    def CellDragAndDrop(self):
        return self.com_object.CellDragAndDrop

    @CellDragAndDrop.setter
    def CellDragAndDrop(self, value):
        self.com_object.CellDragAndDrop = value

    @property
    def celldraganddrop(self):
        """Alias for CellDragAndDrop"""
        return self.CellDragAndDrop

    @celldraganddrop.setter
    def celldraganddrop(self, value):
        """Alias for CellDragAndDrop.setter"""
        self.CellDragAndDrop = value

    @property
    def cell_drag_and_drop(self):
        """Alias for CellDragAndDrop"""
        return self.CellDragAndDrop

    @cell_drag_and_drop.setter
    def cell_drag_and_drop(self, value):
        """Alias for CellDragAndDrop.setter"""
        self.CellDragAndDrop = value

    def Cells(self, RowIndex=None, ColumnIndex=None):
        arguments = com_arguments([unwrap(a) for a in [RowIndex, ColumnIndex]])
        if hasattr(self.com_object, "GetCells"):
            return Range(self.com_object.GetCells(*arguments))
        else:
            return Range(self.com_object.Cells(*arguments))

    def cells(self, RowIndex=None, ColumnIndex=None):
        """Alias for Cells"""
        arguments = [RowIndex, ColumnIndex]
        return self.Cells(*arguments)

    @property
    def ChartDataPointTrack(self):
        return self.com_object.ChartDataPointTrack

    @property
    def chartdatapointtrack(self):
        """Alias for ChartDataPointTrack"""
        return self.ChartDataPointTrack

    @property
    def chart_data_point_track(self):
        """Alias for ChartDataPointTrack"""
        return self.ChartDataPointTrack

    @property
    def Charts(self):
        return Sheets(self.com_object.Charts)

    @property
    def charts(self):
        """Alias for Charts"""
        return self.Charts

    def ClipboardFormats(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetClipboardFormats"):
            return self.com_object.GetClipboardFormats(*arguments)
        else:
            return self.com_object.ClipboardFormats(*arguments)

    def clipboardformats(self, Index=None):
        """Alias for ClipboardFormats"""
        arguments = [Index]
        return self.ClipboardFormats(*arguments)

    def clipboard_formats(self, Index=None):
        """Alias for ClipboardFormats"""
        arguments = [Index]
        return self.ClipboardFormats(*arguments)

    @property
    def ClusterConnector(self):
        return self.com_object.ClusterConnector

    @ClusterConnector.setter
    def ClusterConnector(self, value):
        self.com_object.ClusterConnector = value

    @property
    def clusterconnector(self):
        """Alias for ClusterConnector"""
        return self.ClusterConnector

    @clusterconnector.setter
    def clusterconnector(self, value):
        """Alias for ClusterConnector.setter"""
        self.ClusterConnector = value

    @property
    def cluster_connector(self):
        """Alias for ClusterConnector"""
        return self.ClusterConnector

    @cluster_connector.setter
    def cluster_connector(self, value):
        """Alias for ClusterConnector.setter"""
        self.ClusterConnector = value

    @property
    def Columns(self):
        return Range(self.com_object.Columns)

    @property
    def columns(self):
        """Alias for Columns"""
        return self.Columns

    @property
    def COMAddIns(self):
        return self.com_object.COMAddIns

    @property
    def comaddins(self):
        """Alias for COMAddIns"""
        return self.COMAddIns

    @property
    def c_o_m_add_ins(self):
        """Alias for COMAddIns"""
        return self.COMAddIns

    @property
    def CommandBars(self):
        return CommandBars(self.com_object.CommandBars)

    @property
    def commandbars(self):
        """Alias for CommandBars"""
        return self.CommandBars

    @property
    def command_bars(self):
        """Alias for CommandBars"""
        return self.CommandBars

    @property
    def CommandUnderlines(self):
        return XlCommandUnderlines(self.com_object.CommandUnderlines)

    @CommandUnderlines.setter
    def CommandUnderlines(self, value):
        self.com_object.CommandUnderlines = value

    @property
    def commandunderlines(self):
        """Alias for CommandUnderlines"""
        return self.CommandUnderlines

    @commandunderlines.setter
    def commandunderlines(self, value):
        """Alias for CommandUnderlines.setter"""
        self.CommandUnderlines = value

    @property
    def command_underlines(self):
        """Alias for CommandUnderlines"""
        return self.CommandUnderlines

    @command_underlines.setter
    def command_underlines(self, value):
        """Alias for CommandUnderlines.setter"""
        self.CommandUnderlines = value

    @property
    def ConstrainNumeric(self):
        return self.com_object.ConstrainNumeric

    @ConstrainNumeric.setter
    def ConstrainNumeric(self, value):
        self.com_object.ConstrainNumeric = value

    @property
    def constrainnumeric(self):
        """Alias for ConstrainNumeric"""
        return self.ConstrainNumeric

    @constrainnumeric.setter
    def constrainnumeric(self, value):
        """Alias for ConstrainNumeric.setter"""
        self.ConstrainNumeric = value

    @property
    def constrain_numeric(self):
        """Alias for ConstrainNumeric"""
        return self.ConstrainNumeric

    @constrain_numeric.setter
    def constrain_numeric(self, value):
        """Alias for ConstrainNumeric.setter"""
        self.ConstrainNumeric = value

    @property
    def ControlCharacters(self):
        return self.com_object.ControlCharacters

    @ControlCharacters.setter
    def ControlCharacters(self, value):
        self.com_object.ControlCharacters = value

    @property
    def controlcharacters(self):
        """Alias for ControlCharacters"""
        return self.ControlCharacters

    @controlcharacters.setter
    def controlcharacters(self, value):
        """Alias for ControlCharacters.setter"""
        self.ControlCharacters = value

    @property
    def control_characters(self):
        """Alias for ControlCharacters"""
        return self.ControlCharacters

    @control_characters.setter
    def control_characters(self, value):
        """Alias for ControlCharacters.setter"""
        self.ControlCharacters = value

    @property
    def CopyObjectsWithCells(self):
        return self.com_object.CopyObjectsWithCells

    @CopyObjectsWithCells.setter
    def CopyObjectsWithCells(self, value):
        self.com_object.CopyObjectsWithCells = value

    @property
    def copyobjectswithcells(self):
        """Alias for CopyObjectsWithCells"""
        return self.CopyObjectsWithCells

    @copyobjectswithcells.setter
    def copyobjectswithcells(self, value):
        """Alias for CopyObjectsWithCells.setter"""
        self.CopyObjectsWithCells = value

    @property
    def copy_objects_with_cells(self):
        """Alias for CopyObjectsWithCells"""
        return self.CopyObjectsWithCells

    @copy_objects_with_cells.setter
    def copy_objects_with_cells(self, value):
        """Alias for CopyObjectsWithCells.setter"""
        self.CopyObjectsWithCells = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Cursor(self):
        return XlMousePointer(self.com_object.Cursor)

    @Cursor.setter
    def Cursor(self, value):
        self.com_object.Cursor = value

    @property
    def cursor(self):
        """Alias for Cursor"""
        return self.Cursor

    @cursor.setter
    def cursor(self, value):
        """Alias for Cursor.setter"""
        self.Cursor = value

    @property
    def CursorMovement(self):
        return self.com_object.CursorMovement

    @CursorMovement.setter
    def CursorMovement(self, value):
        self.com_object.CursorMovement = value

    @property
    def cursormovement(self):
        """Alias for CursorMovement"""
        return self.CursorMovement

    @cursormovement.setter
    def cursormovement(self, value):
        """Alias for CursorMovement.setter"""
        self.CursorMovement = value

    @property
    def cursor_movement(self):
        """Alias for CursorMovement"""
        return self.CursorMovement

    @cursor_movement.setter
    def cursor_movement(self, value):
        """Alias for CursorMovement.setter"""
        self.CursorMovement = value

    @property
    def CustomListCount(self):
        return self.com_object.CustomListCount

    @property
    def customlistcount(self):
        """Alias for CustomListCount"""
        return self.CustomListCount

    @property
    def custom_list_count(self):
        """Alias for CustomListCount"""
        return self.CustomListCount

    @property
    def CutCopyMode(self):
        return XLCutCopyMode(self.com_object.CutCopyMode)

    @CutCopyMode.setter
    def CutCopyMode(self, value):
        self.com_object.CutCopyMode = value

    @property
    def cutcopymode(self):
        """Alias for CutCopyMode"""
        return self.CutCopyMode

    @cutcopymode.setter
    def cutcopymode(self, value):
        """Alias for CutCopyMode.setter"""
        self.CutCopyMode = value

    @property
    def cut_copy_mode(self):
        """Alias for CutCopyMode"""
        return self.CutCopyMode

    @cut_copy_mode.setter
    def cut_copy_mode(self, value):
        """Alias for CutCopyMode.setter"""
        self.CutCopyMode = value

    @property
    def DataEntryMode(self):
        return self.com_object.DataEntryMode

    @DataEntryMode.setter
    def DataEntryMode(self, value):
        self.com_object.DataEntryMode = value

    @property
    def dataentrymode(self):
        """Alias for DataEntryMode"""
        return self.DataEntryMode

    @dataentrymode.setter
    def dataentrymode(self, value):
        """Alias for DataEntryMode.setter"""
        self.DataEntryMode = value

    @property
    def data_entry_mode(self):
        """Alias for DataEntryMode"""
        return self.DataEntryMode

    @data_entry_mode.setter
    def data_entry_mode(self, value):
        """Alias for DataEntryMode.setter"""
        self.DataEntryMode = value

    @property
    def DDEAppReturnCode(self):
        return self.com_object.DDEAppReturnCode

    @property
    def ddeappreturncode(self):
        """Alias for DDEAppReturnCode"""
        return self.DDEAppReturnCode

    @property
    def d_d_e_app_return_code(self):
        """Alias for DDEAppReturnCode"""
        return self.DDEAppReturnCode

    @property
    def DecimalSeparator(self):
        return self.com_object.DecimalSeparator

    @DecimalSeparator.setter
    def DecimalSeparator(self, value):
        self.com_object.DecimalSeparator = value

    @property
    def decimalseparator(self):
        """Alias for DecimalSeparator"""
        return self.DecimalSeparator

    @decimalseparator.setter
    def decimalseparator(self, value):
        """Alias for DecimalSeparator.setter"""
        self.DecimalSeparator = value

    @property
    def decimal_separator(self):
        """Alias for DecimalSeparator"""
        return self.DecimalSeparator

    @decimal_separator.setter
    def decimal_separator(self, value):
        """Alias for DecimalSeparator.setter"""
        self.DecimalSeparator = value

    @property
    def DefaultFilePath(self):
        return self.com_object.DefaultFilePath

    @DefaultFilePath.setter
    def DefaultFilePath(self, value):
        self.com_object.DefaultFilePath = value

    @property
    def defaultfilepath(self):
        """Alias for DefaultFilePath"""
        return self.DefaultFilePath

    @defaultfilepath.setter
    def defaultfilepath(self, value):
        """Alias for DefaultFilePath.setter"""
        self.DefaultFilePath = value

    @property
    def default_file_path(self):
        """Alias for DefaultFilePath"""
        return self.DefaultFilePath

    @default_file_path.setter
    def default_file_path(self, value):
        """Alias for DefaultFilePath.setter"""
        self.DefaultFilePath = value

    @property
    def DefaultSaveFormat(self):
        return self.com_object.DefaultSaveFormat

    @DefaultSaveFormat.setter
    def DefaultSaveFormat(self, value):
        self.com_object.DefaultSaveFormat = value

    @property
    def defaultsaveformat(self):
        """Alias for DefaultSaveFormat"""
        return self.DefaultSaveFormat

    @defaultsaveformat.setter
    def defaultsaveformat(self, value):
        """Alias for DefaultSaveFormat.setter"""
        self.DefaultSaveFormat = value

    @property
    def default_save_format(self):
        """Alias for DefaultSaveFormat"""
        return self.DefaultSaveFormat

    @default_save_format.setter
    def default_save_format(self, value):
        """Alias for DefaultSaveFormat.setter"""
        self.DefaultSaveFormat = value

    @property
    def DefaultSheetDirection(self):
        return self.com_object.DefaultSheetDirection

    @DefaultSheetDirection.setter
    def DefaultSheetDirection(self, value):
        self.com_object.DefaultSheetDirection = value

    @property
    def defaultsheetdirection(self):
        """Alias for DefaultSheetDirection"""
        return self.DefaultSheetDirection

    @defaultsheetdirection.setter
    def defaultsheetdirection(self, value):
        """Alias for DefaultSheetDirection.setter"""
        self.DefaultSheetDirection = value

    @property
    def default_sheet_direction(self):
        """Alias for DefaultSheetDirection"""
        return self.DefaultSheetDirection

    @default_sheet_direction.setter
    def default_sheet_direction(self, value):
        """Alias for DefaultSheetDirection.setter"""
        self.DefaultSheetDirection = value

    @property
    def DefaultWebOptions(self):
        return DefaultWebOptions(self.com_object.DefaultWebOptions)

    @property
    def defaultweboptions(self):
        """Alias for DefaultWebOptions"""
        return self.DefaultWebOptions

    @property
    def default_web_options(self):
        """Alias for DefaultWebOptions"""
        return self.DefaultWebOptions

    @property
    def DeferAsyncQueries(self):
        return self.com_object.DeferAsyncQueries

    @DeferAsyncQueries.setter
    def DeferAsyncQueries(self, value):
        self.com_object.DeferAsyncQueries = value

    @property
    def deferasyncqueries(self):
        """Alias for DeferAsyncQueries"""
        return self.DeferAsyncQueries

    @deferasyncqueries.setter
    def deferasyncqueries(self, value):
        """Alias for DeferAsyncQueries.setter"""
        self.DeferAsyncQueries = value

    @property
    def defer_async_queries(self):
        """Alias for DeferAsyncQueries"""
        return self.DeferAsyncQueries

    @defer_async_queries.setter
    def defer_async_queries(self, value):
        """Alias for DeferAsyncQueries.setter"""
        self.DeferAsyncQueries = value

    @property
    def Dialogs(self):
        return Dialogs(self.com_object.Dialogs)

    @property
    def dialogs(self):
        """Alias for Dialogs"""
        return self.Dialogs

    @property
    def DisplayAlerts(self):
        return self.com_object.DisplayAlerts

    @DisplayAlerts.setter
    def DisplayAlerts(self, value):
        self.com_object.DisplayAlerts = value

    @property
    def displayalerts(self):
        """Alias for DisplayAlerts"""
        return self.DisplayAlerts

    @displayalerts.setter
    def displayalerts(self, value):
        """Alias for DisplayAlerts.setter"""
        self.DisplayAlerts = value

    @property
    def display_alerts(self):
        """Alias for DisplayAlerts"""
        return self.DisplayAlerts

    @display_alerts.setter
    def display_alerts(self, value):
        """Alias for DisplayAlerts.setter"""
        self.DisplayAlerts = value

    @property
    def DisplayClipboardWindow(self):
        return self.com_object.DisplayClipboardWindow

    @DisplayClipboardWindow.setter
    def DisplayClipboardWindow(self, value):
        self.com_object.DisplayClipboardWindow = value

    @property
    def displayclipboardwindow(self):
        """Alias for DisplayClipboardWindow"""
        return self.DisplayClipboardWindow

    @displayclipboardwindow.setter
    def displayclipboardwindow(self, value):
        """Alias for DisplayClipboardWindow.setter"""
        self.DisplayClipboardWindow = value

    @property
    def display_clipboard_window(self):
        """Alias for DisplayClipboardWindow"""
        return self.DisplayClipboardWindow

    @display_clipboard_window.setter
    def display_clipboard_window(self, value):
        """Alias for DisplayClipboardWindow.setter"""
        self.DisplayClipboardWindow = value

    @property
    def DisplayCommentIndicator(self):
        return XlCommentDisplayMode(self.com_object.DisplayCommentIndicator)

    @DisplayCommentIndicator.setter
    def DisplayCommentIndicator(self, value):
        self.com_object.DisplayCommentIndicator = value

    @property
    def displaycommentindicator(self):
        """Alias for DisplayCommentIndicator"""
        return self.DisplayCommentIndicator

    @displaycommentindicator.setter
    def displaycommentindicator(self, value):
        """Alias for DisplayCommentIndicator.setter"""
        self.DisplayCommentIndicator = value

    @property
    def display_comment_indicator(self):
        """Alias for DisplayCommentIndicator"""
        return self.DisplayCommentIndicator

    @display_comment_indicator.setter
    def display_comment_indicator(self, value):
        """Alias for DisplayCommentIndicator.setter"""
        self.DisplayCommentIndicator = value

    @property
    def DisplayDocumentActionTaskPane(self):
        return self.com_object.DisplayDocumentActionTaskPane

    @DisplayDocumentActionTaskPane.setter
    def DisplayDocumentActionTaskPane(self, value):
        self.com_object.DisplayDocumentActionTaskPane = value

    @property
    def displaydocumentactiontaskpane(self):
        """Alias for DisplayDocumentActionTaskPane"""
        return self.DisplayDocumentActionTaskPane

    @displaydocumentactiontaskpane.setter
    def displaydocumentactiontaskpane(self, value):
        """Alias for DisplayDocumentActionTaskPane.setter"""
        self.DisplayDocumentActionTaskPane = value

    @property
    def display_document_action_task_pane(self):
        """Alias for DisplayDocumentActionTaskPane"""
        return self.DisplayDocumentActionTaskPane

    @display_document_action_task_pane.setter
    def display_document_action_task_pane(self, value):
        """Alias for DisplayDocumentActionTaskPane.setter"""
        self.DisplayDocumentActionTaskPane = value

    @property
    def DisplayDocumentInformationPanel(self):
        return self.com_object.DisplayDocumentInformationPanel

    @DisplayDocumentInformationPanel.setter
    def DisplayDocumentInformationPanel(self, value):
        self.com_object.DisplayDocumentInformationPanel = value

    @property
    def displaydocumentinformationpanel(self):
        """Alias for DisplayDocumentInformationPanel"""
        return self.DisplayDocumentInformationPanel

    @displaydocumentinformationpanel.setter
    def displaydocumentinformationpanel(self, value):
        """Alias for DisplayDocumentInformationPanel.setter"""
        self.DisplayDocumentInformationPanel = value

    @property
    def display_document_information_panel(self):
        """Alias for DisplayDocumentInformationPanel"""
        return self.DisplayDocumentInformationPanel

    @display_document_information_panel.setter
    def display_document_information_panel(self, value):
        """Alias for DisplayDocumentInformationPanel.setter"""
        self.DisplayDocumentInformationPanel = value

    @property
    def DisplayExcel4Menus(self):
        return self.com_object.DisplayExcel4Menus

    @DisplayExcel4Menus.setter
    def DisplayExcel4Menus(self, value):
        self.com_object.DisplayExcel4Menus = value

    @property
    def displayexcel4menus(self):
        """Alias for DisplayExcel4Menus"""
        return self.DisplayExcel4Menus

    @displayexcel4menus.setter
    def displayexcel4menus(self, value):
        """Alias for DisplayExcel4Menus.setter"""
        self.DisplayExcel4Menus = value

    @property
    def display_excel4_menus(self):
        """Alias for DisplayExcel4Menus"""
        return self.DisplayExcel4Menus

    @display_excel4_menus.setter
    def display_excel4_menus(self, value):
        """Alias for DisplayExcel4Menus.setter"""
        self.DisplayExcel4Menus = value

    @property
    def DisplayFormulaAutoComplete(self):
        return self.com_object.DisplayFormulaAutoComplete

    @DisplayFormulaAutoComplete.setter
    def DisplayFormulaAutoComplete(self, value):
        self.com_object.DisplayFormulaAutoComplete = value

    @property
    def displayformulaautocomplete(self):
        """Alias for DisplayFormulaAutoComplete"""
        return self.DisplayFormulaAutoComplete

    @displayformulaautocomplete.setter
    def displayformulaautocomplete(self, value):
        """Alias for DisplayFormulaAutoComplete.setter"""
        self.DisplayFormulaAutoComplete = value

    @property
    def display_formula_auto_complete(self):
        """Alias for DisplayFormulaAutoComplete"""
        return self.DisplayFormulaAutoComplete

    @display_formula_auto_complete.setter
    def display_formula_auto_complete(self, value):
        """Alias for DisplayFormulaAutoComplete.setter"""
        self.DisplayFormulaAutoComplete = value

    @property
    def DisplayFormulaBar(self):
        return self.com_object.DisplayFormulaBar

    @DisplayFormulaBar.setter
    def DisplayFormulaBar(self, value):
        self.com_object.DisplayFormulaBar = value

    @property
    def displayformulabar(self):
        """Alias for DisplayFormulaBar"""
        return self.DisplayFormulaBar

    @displayformulabar.setter
    def displayformulabar(self, value):
        """Alias for DisplayFormulaBar.setter"""
        self.DisplayFormulaBar = value

    @property
    def display_formula_bar(self):
        """Alias for DisplayFormulaBar"""
        return self.DisplayFormulaBar

    @display_formula_bar.setter
    def display_formula_bar(self, value):
        """Alias for DisplayFormulaBar.setter"""
        self.DisplayFormulaBar = value

    @property
    def DisplayFullScreen(self):
        return self.com_object.DisplayFullScreen

    @DisplayFullScreen.setter
    def DisplayFullScreen(self, value):
        self.com_object.DisplayFullScreen = value

    @property
    def displayfullscreen(self):
        """Alias for DisplayFullScreen"""
        return self.DisplayFullScreen

    @displayfullscreen.setter
    def displayfullscreen(self, value):
        """Alias for DisplayFullScreen.setter"""
        self.DisplayFullScreen = value

    @property
    def display_full_screen(self):
        """Alias for DisplayFullScreen"""
        return self.DisplayFullScreen

    @display_full_screen.setter
    def display_full_screen(self, value):
        """Alias for DisplayFullScreen.setter"""
        self.DisplayFullScreen = value

    @property
    def DisplayFunctionToolTips(self):
        return self.com_object.DisplayFunctionToolTips

    @DisplayFunctionToolTips.setter
    def DisplayFunctionToolTips(self, value):
        self.com_object.DisplayFunctionToolTips = value

    @property
    def displayfunctiontooltips(self):
        """Alias for DisplayFunctionToolTips"""
        return self.DisplayFunctionToolTips

    @displayfunctiontooltips.setter
    def displayfunctiontooltips(self, value):
        """Alias for DisplayFunctionToolTips.setter"""
        self.DisplayFunctionToolTips = value

    @property
    def display_function_tool_tips(self):
        """Alias for DisplayFunctionToolTips"""
        return self.DisplayFunctionToolTips

    @display_function_tool_tips.setter
    def display_function_tool_tips(self, value):
        """Alias for DisplayFunctionToolTips.setter"""
        self.DisplayFunctionToolTips = value

    @property
    def DisplayInsertOptions(self):
        return self.com_object.DisplayInsertOptions

    @DisplayInsertOptions.setter
    def DisplayInsertOptions(self, value):
        self.com_object.DisplayInsertOptions = value

    @property
    def displayinsertoptions(self):
        """Alias for DisplayInsertOptions"""
        return self.DisplayInsertOptions

    @displayinsertoptions.setter
    def displayinsertoptions(self, value):
        """Alias for DisplayInsertOptions.setter"""
        self.DisplayInsertOptions = value

    @property
    def display_insert_options(self):
        """Alias for DisplayInsertOptions"""
        return self.DisplayInsertOptions

    @display_insert_options.setter
    def display_insert_options(self, value):
        """Alias for DisplayInsertOptions.setter"""
        self.DisplayInsertOptions = value

    @property
    def DisplayNoteIndicator(self):
        return self.com_object.DisplayNoteIndicator

    @DisplayNoteIndicator.setter
    def DisplayNoteIndicator(self, value):
        self.com_object.DisplayNoteIndicator = value

    @property
    def displaynoteindicator(self):
        """Alias for DisplayNoteIndicator"""
        return self.DisplayNoteIndicator

    @displaynoteindicator.setter
    def displaynoteindicator(self, value):
        """Alias for DisplayNoteIndicator.setter"""
        self.DisplayNoteIndicator = value

    @property
    def display_note_indicator(self):
        """Alias for DisplayNoteIndicator"""
        return self.DisplayNoteIndicator

    @display_note_indicator.setter
    def display_note_indicator(self, value):
        """Alias for DisplayNoteIndicator.setter"""
        self.DisplayNoteIndicator = value

    @property
    def DisplayPasteOptions(self):
        return self.com_object.DisplayPasteOptions

    @DisplayPasteOptions.setter
    def DisplayPasteOptions(self, value):
        self.com_object.DisplayPasteOptions = value

    @property
    def displaypasteoptions(self):
        """Alias for DisplayPasteOptions"""
        return self.DisplayPasteOptions

    @displaypasteoptions.setter
    def displaypasteoptions(self, value):
        """Alias for DisplayPasteOptions.setter"""
        self.DisplayPasteOptions = value

    @property
    def display_paste_options(self):
        """Alias for DisplayPasteOptions"""
        return self.DisplayPasteOptions

    @display_paste_options.setter
    def display_paste_options(self, value):
        """Alias for DisplayPasteOptions.setter"""
        self.DisplayPasteOptions = value

    @property
    def DisplayRecentFiles(self):
        return self.com_object.DisplayRecentFiles

    @DisplayRecentFiles.setter
    def DisplayRecentFiles(self, value):
        self.com_object.DisplayRecentFiles = value

    @property
    def displayrecentfiles(self):
        """Alias for DisplayRecentFiles"""
        return self.DisplayRecentFiles

    @displayrecentfiles.setter
    def displayrecentfiles(self, value):
        """Alias for DisplayRecentFiles.setter"""
        self.DisplayRecentFiles = value

    @property
    def display_recent_files(self):
        """Alias for DisplayRecentFiles"""
        return self.DisplayRecentFiles

    @display_recent_files.setter
    def display_recent_files(self, value):
        """Alias for DisplayRecentFiles.setter"""
        self.DisplayRecentFiles = value

    @property
    def DisplayScrollBars(self):
        return self.com_object.DisplayScrollBars

    @DisplayScrollBars.setter
    def DisplayScrollBars(self, value):
        self.com_object.DisplayScrollBars = value

    @property
    def displayscrollbars(self):
        """Alias for DisplayScrollBars"""
        return self.DisplayScrollBars

    @displayscrollbars.setter
    def displayscrollbars(self, value):
        """Alias for DisplayScrollBars.setter"""
        self.DisplayScrollBars = value

    @property
    def display_scroll_bars(self):
        """Alias for DisplayScrollBars"""
        return self.DisplayScrollBars

    @display_scroll_bars.setter
    def display_scroll_bars(self, value):
        """Alias for DisplayScrollBars.setter"""
        self.DisplayScrollBars = value

    @property
    def DisplayStatusBar(self):
        return self.com_object.DisplayStatusBar

    @DisplayStatusBar.setter
    def DisplayStatusBar(self, value):
        self.com_object.DisplayStatusBar = value

    @property
    def displaystatusbar(self):
        """Alias for DisplayStatusBar"""
        return self.DisplayStatusBar

    @displaystatusbar.setter
    def displaystatusbar(self, value):
        """Alias for DisplayStatusBar.setter"""
        self.DisplayStatusBar = value

    @property
    def display_status_bar(self):
        """Alias for DisplayStatusBar"""
        return self.DisplayStatusBar

    @display_status_bar.setter
    def display_status_bar(self, value):
        """Alias for DisplayStatusBar.setter"""
        self.DisplayStatusBar = value

    @property
    def EditDirectlyInCell(self):
        return self.com_object.EditDirectlyInCell

    @EditDirectlyInCell.setter
    def EditDirectlyInCell(self, value):
        self.com_object.EditDirectlyInCell = value

    @property
    def editdirectlyincell(self):
        """Alias for EditDirectlyInCell"""
        return self.EditDirectlyInCell

    @editdirectlyincell.setter
    def editdirectlyincell(self, value):
        """Alias for EditDirectlyInCell.setter"""
        self.EditDirectlyInCell = value

    @property
    def edit_directly_in_cell(self):
        """Alias for EditDirectlyInCell"""
        return self.EditDirectlyInCell

    @edit_directly_in_cell.setter
    def edit_directly_in_cell(self, value):
        """Alias for EditDirectlyInCell.setter"""
        self.EditDirectlyInCell = value

    @property
    def EnableAnimations(self):
        return self.com_object.EnableAnimations

    @property
    def enableanimations(self):
        """Alias for EnableAnimations"""
        return self.EnableAnimations

    @property
    def enable_animations(self):
        """Alias for EnableAnimations"""
        return self.EnableAnimations

    @property
    def EnableAutoComplete(self):
        return self.com_object.EnableAutoComplete

    @EnableAutoComplete.setter
    def EnableAutoComplete(self, value):
        self.com_object.EnableAutoComplete = value

    @property
    def enableautocomplete(self):
        """Alias for EnableAutoComplete"""
        return self.EnableAutoComplete

    @enableautocomplete.setter
    def enableautocomplete(self, value):
        """Alias for EnableAutoComplete.setter"""
        self.EnableAutoComplete = value

    @property
    def enable_auto_complete(self):
        """Alias for EnableAutoComplete"""
        return self.EnableAutoComplete

    @enable_auto_complete.setter
    def enable_auto_complete(self, value):
        """Alias for EnableAutoComplete.setter"""
        self.EnableAutoComplete = value

    @property
    def EnableCancelKey(self):
        return self.com_object.EnableCancelKey

    @EnableCancelKey.setter
    def EnableCancelKey(self, value):
        self.com_object.EnableCancelKey = value

    @property
    def enablecancelkey(self):
        """Alias for EnableCancelKey"""
        return self.EnableCancelKey

    @enablecancelkey.setter
    def enablecancelkey(self, value):
        """Alias for EnableCancelKey.setter"""
        self.EnableCancelKey = value

    @property
    def enable_cancel_key(self):
        """Alias for EnableCancelKey"""
        return self.EnableCancelKey

    @enable_cancel_key.setter
    def enable_cancel_key(self, value):
        """Alias for EnableCancelKey.setter"""
        self.EnableCancelKey = value

    @property
    def EnableCheckFileExtensions(self):
        return self.com_object.EnableCheckFileExtensions

    @EnableCheckFileExtensions.setter
    def EnableCheckFileExtensions(self, value):
        self.com_object.EnableCheckFileExtensions = value

    @property
    def enablecheckfileextensions(self):
        """Alias for EnableCheckFileExtensions"""
        return self.EnableCheckFileExtensions

    @enablecheckfileextensions.setter
    def enablecheckfileextensions(self, value):
        """Alias for EnableCheckFileExtensions.setter"""
        self.EnableCheckFileExtensions = value

    @property
    def enable_check_file_extensions(self):
        """Alias for EnableCheckFileExtensions"""
        return self.EnableCheckFileExtensions

    @enable_check_file_extensions.setter
    def enable_check_file_extensions(self, value):
        """Alias for EnableCheckFileExtensions.setter"""
        self.EnableCheckFileExtensions = value

    @property
    def EnableEvents(self):
        return self.com_object.EnableEvents

    @EnableEvents.setter
    def EnableEvents(self, value):
        self.com_object.EnableEvents = value

    @property
    def enableevents(self):
        """Alias for EnableEvents"""
        return self.EnableEvents

    @enableevents.setter
    def enableevents(self, value):
        """Alias for EnableEvents.setter"""
        self.EnableEvents = value

    @property
    def enable_events(self):
        """Alias for EnableEvents"""
        return self.EnableEvents

    @enable_events.setter
    def enable_events(self, value):
        """Alias for EnableEvents.setter"""
        self.EnableEvents = value

    @property
    def EnableLargeOperationAlert(self):
        return self.com_object.EnableLargeOperationAlert

    @EnableLargeOperationAlert.setter
    def EnableLargeOperationAlert(self, value):
        self.com_object.EnableLargeOperationAlert = value

    @property
    def enablelargeoperationalert(self):
        """Alias for EnableLargeOperationAlert"""
        return self.EnableLargeOperationAlert

    @enablelargeoperationalert.setter
    def enablelargeoperationalert(self, value):
        """Alias for EnableLargeOperationAlert.setter"""
        self.EnableLargeOperationAlert = value

    @property
    def enable_large_operation_alert(self):
        """Alias for EnableLargeOperationAlert"""
        return self.EnableLargeOperationAlert

    @enable_large_operation_alert.setter
    def enable_large_operation_alert(self, value):
        """Alias for EnableLargeOperationAlert.setter"""
        self.EnableLargeOperationAlert = value

    @property
    def EnableLivePreview(self):
        return self.com_object.EnableLivePreview

    @EnableLivePreview.setter
    def EnableLivePreview(self, value):
        self.com_object.EnableLivePreview = value

    @property
    def enablelivepreview(self):
        """Alias for EnableLivePreview"""
        return self.EnableLivePreview

    @enablelivepreview.setter
    def enablelivepreview(self, value):
        """Alias for EnableLivePreview.setter"""
        self.EnableLivePreview = value

    @property
    def enable_live_preview(self):
        """Alias for EnableLivePreview"""
        return self.EnableLivePreview

    @enable_live_preview.setter
    def enable_live_preview(self, value):
        """Alias for EnableLivePreview.setter"""
        self.EnableLivePreview = value

    @property
    def EnableMacroAnimations(self):
        return self.com_object.EnableMacroAnimations

    @EnableMacroAnimations.setter
    def EnableMacroAnimations(self, value):
        self.com_object.EnableMacroAnimations = value

    @property
    def enablemacroanimations(self):
        """Alias for EnableMacroAnimations"""
        return self.EnableMacroAnimations

    @enablemacroanimations.setter
    def enablemacroanimations(self, value):
        """Alias for EnableMacroAnimations.setter"""
        self.EnableMacroAnimations = value

    @property
    def enable_macro_animations(self):
        """Alias for EnableMacroAnimations"""
        return self.EnableMacroAnimations

    @enable_macro_animations.setter
    def enable_macro_animations(self, value):
        """Alias for EnableMacroAnimations.setter"""
        self.EnableMacroAnimations = value

    @property
    def EnableSound(self):
        return self.com_object.EnableSound

    @EnableSound.setter
    def EnableSound(self, value):
        self.com_object.EnableSound = value

    @property
    def enablesound(self):
        """Alias for EnableSound"""
        return self.EnableSound

    @enablesound.setter
    def enablesound(self, value):
        """Alias for EnableSound.setter"""
        self.EnableSound = value

    @property
    def enable_sound(self):
        """Alias for EnableSound"""
        return self.EnableSound

    @enable_sound.setter
    def enable_sound(self, value):
        """Alias for EnableSound.setter"""
        self.EnableSound = value

    @property
    def ErrorCheckingOptions(self):
        return ErrorCheckingOptions(self.com_object.ErrorCheckingOptions)

    @property
    def errorcheckingoptions(self):
        """Alias for ErrorCheckingOptions"""
        return self.ErrorCheckingOptions

    @property
    def error_checking_options(self):
        """Alias for ErrorCheckingOptions"""
        return self.ErrorCheckingOptions

    @property
    def Excel4IntlMacroSheets(self):
        return Sheets(self.com_object.Excel4IntlMacroSheets)

    @property
    def excel4intlmacrosheets(self):
        """Alias for Excel4IntlMacroSheets"""
        return self.Excel4IntlMacroSheets

    @property
    def excel4_intl_macro_sheets(self):
        """Alias for Excel4IntlMacroSheets"""
        return self.Excel4IntlMacroSheets

    @property
    def Excel4MacroSheets(self):
        return Sheets(self.com_object.Excel4MacroSheets)

    @property
    def excel4macrosheets(self):
        """Alias for Excel4MacroSheets"""
        return self.Excel4MacroSheets

    @property
    def excel4_macro_sheets(self):
        """Alias for Excel4MacroSheets"""
        return self.Excel4MacroSheets

    @property
    def ExtendList(self):
        return self.com_object.ExtendList

    @ExtendList.setter
    def ExtendList(self, value):
        self.com_object.ExtendList = value

    @property
    def extendlist(self):
        """Alias for ExtendList"""
        return self.ExtendList

    @extendlist.setter
    def extendlist(self, value):
        """Alias for ExtendList.setter"""
        self.ExtendList = value

    @property
    def extend_list(self):
        """Alias for ExtendList"""
        return self.ExtendList

    @extend_list.setter
    def extend_list(self, value):
        """Alias for ExtendList.setter"""
        self.ExtendList = value

    @property
    def FeatureInstall(self):
        return self.com_object.FeatureInstall

    @FeatureInstall.setter
    def FeatureInstall(self, value):
        self.com_object.FeatureInstall = value

    @property
    def featureinstall(self):
        """Alias for FeatureInstall"""
        return self.FeatureInstall

    @featureinstall.setter
    def featureinstall(self, value):
        """Alias for FeatureInstall.setter"""
        self.FeatureInstall = value

    @property
    def feature_install(self):
        """Alias for FeatureInstall"""
        return self.FeatureInstall

    @feature_install.setter
    def feature_install(self, value):
        """Alias for FeatureInstall.setter"""
        self.FeatureInstall = value

    def FileConverters(self, Index1=None, Index2=None):
        arguments = com_arguments([unwrap(a) for a in [Index1, Index2]])
        if hasattr(self.com_object, "GetFileConverters"):
            return self.com_object.GetFileConverters(*arguments)
        else:
            return self.com_object.FileConverters(*arguments)

    def fileconverters(self, Index1=None, Index2=None):
        """Alias for FileConverters"""
        arguments = [Index1, Index2]
        return self.FileConverters(*arguments)

    def file_converters(self, Index1=None, Index2=None):
        """Alias for FileConverters"""
        arguments = [Index1, Index2]
        return self.FileConverters(*arguments)

    def FileDialog(self, fileDialogType=None):
        arguments = com_arguments([unwrap(a) for a in [fileDialogType]])
        if hasattr(self.com_object, "GetFileDialog"):
            return self.com_object.GetFileDialog(*arguments)
        else:
            return self.com_object.FileDialog(*arguments)

    def filedialog(self, fileDialogType=None):
        """Alias for FileDialog"""
        arguments = [fileDialogType]
        return self.FileDialog(*arguments)

    def file_dialog(self, fileDialogType=None):
        """Alias for FileDialog"""
        arguments = [fileDialogType]
        return self.FileDialog(*arguments)

    @property
    def FileExportConverters(self):
        return FileExportConverters(self.com_object.FileExportConverters)

    @property
    def fileexportconverters(self):
        """Alias for FileExportConverters"""
        return self.FileExportConverters

    @property
    def file_export_converters(self):
        """Alias for FileExportConverters"""
        return self.FileExportConverters

    @property
    def FileValidation(self):
        return self.com_object.FileValidation

    @FileValidation.setter
    def FileValidation(self, value):
        self.com_object.FileValidation = value

    @property
    def filevalidation(self):
        """Alias for FileValidation"""
        return self.FileValidation

    @filevalidation.setter
    def filevalidation(self, value):
        """Alias for FileValidation.setter"""
        self.FileValidation = value

    @property
    def file_validation(self):
        """Alias for FileValidation"""
        return self.FileValidation

    @file_validation.setter
    def file_validation(self, value):
        """Alias for FileValidation.setter"""
        self.FileValidation = value

    @property
    def FileValidationPivot(self):
        return self.com_object.FileValidationPivot

    @FileValidationPivot.setter
    def FileValidationPivot(self, value):
        self.com_object.FileValidationPivot = value

    @property
    def filevalidationpivot(self):
        """Alias for FileValidationPivot"""
        return self.FileValidationPivot

    @filevalidationpivot.setter
    def filevalidationpivot(self, value):
        """Alias for FileValidationPivot.setter"""
        self.FileValidationPivot = value

    @property
    def file_validation_pivot(self):
        """Alias for FileValidationPivot"""
        return self.FileValidationPivot

    @file_validation_pivot.setter
    def file_validation_pivot(self, value):
        """Alias for FileValidationPivot.setter"""
        self.FileValidationPivot = value

    @property
    def FindFormat(self):
        return self.com_object.FindFormat

    @property
    def findformat(self):
        """Alias for FindFormat"""
        return self.FindFormat

    @property
    def find_format(self):
        """Alias for FindFormat"""
        return self.FindFormat

    @property
    def FixedDecimal(self):
        return self.com_object.FixedDecimal

    @FixedDecimal.setter
    def FixedDecimal(self, value):
        self.com_object.FixedDecimal = value

    @property
    def fixeddecimal(self):
        """Alias for FixedDecimal"""
        return self.FixedDecimal

    @fixeddecimal.setter
    def fixeddecimal(self, value):
        """Alias for FixedDecimal.setter"""
        self.FixedDecimal = value

    @property
    def fixed_decimal(self):
        """Alias for FixedDecimal"""
        return self.FixedDecimal

    @fixed_decimal.setter
    def fixed_decimal(self, value):
        """Alias for FixedDecimal.setter"""
        self.FixedDecimal = value

    @property
    def FixedDecimalPlaces(self):
        return self.com_object.FixedDecimalPlaces

    @FixedDecimalPlaces.setter
    def FixedDecimalPlaces(self, value):
        self.com_object.FixedDecimalPlaces = value

    @property
    def fixeddecimalplaces(self):
        """Alias for FixedDecimalPlaces"""
        return self.FixedDecimalPlaces

    @fixeddecimalplaces.setter
    def fixeddecimalplaces(self, value):
        """Alias for FixedDecimalPlaces.setter"""
        self.FixedDecimalPlaces = value

    @property
    def fixed_decimal_places(self):
        """Alias for FixedDecimalPlaces"""
        return self.FixedDecimalPlaces

    @fixed_decimal_places.setter
    def fixed_decimal_places(self, value):
        """Alias for FixedDecimalPlaces.setter"""
        self.FixedDecimalPlaces = value

    @property
    def FlashFill(self):
        return self.com_object.FlashFill

    @FlashFill.setter
    def FlashFill(self, value):
        self.com_object.FlashFill = value

    @property
    def flashfill(self):
        """Alias for FlashFill"""
        return self.FlashFill

    @flashfill.setter
    def flashfill(self, value):
        """Alias for FlashFill.setter"""
        self.FlashFill = value

    @property
    def flash_fill(self):
        """Alias for FlashFill"""
        return self.FlashFill

    @flash_fill.setter
    def flash_fill(self, value):
        """Alias for FlashFill.setter"""
        self.FlashFill = value

    @property
    def FlashFillMode(self):
        return self.com_object.FlashFillMode

    @FlashFillMode.setter
    def FlashFillMode(self, value):
        self.com_object.FlashFillMode = value

    @property
    def flashfillmode(self):
        """Alias for FlashFillMode"""
        return self.FlashFillMode

    @flashfillmode.setter
    def flashfillmode(self, value):
        """Alias for FlashFillMode.setter"""
        self.FlashFillMode = value

    @property
    def flash_fill_mode(self):
        """Alias for FlashFillMode"""
        return self.FlashFillMode

    @flash_fill_mode.setter
    def flash_fill_mode(self, value):
        """Alias for FlashFillMode.setter"""
        self.FlashFillMode = value

    @property
    def FormulaBarHeight(self):
        return self.com_object.FormulaBarHeight

    @FormulaBarHeight.setter
    def FormulaBarHeight(self, value):
        self.com_object.FormulaBarHeight = value

    @property
    def formulabarheight(self):
        """Alias for FormulaBarHeight"""
        return self.FormulaBarHeight

    @formulabarheight.setter
    def formulabarheight(self, value):
        """Alias for FormulaBarHeight.setter"""
        self.FormulaBarHeight = value

    @property
    def formula_bar_height(self):
        """Alias for FormulaBarHeight"""
        return self.FormulaBarHeight

    @formula_bar_height.setter
    def formula_bar_height(self, value):
        """Alias for FormulaBarHeight.setter"""
        self.FormulaBarHeight = value

    @property
    def GenerateGetPivotData(self):
        return self.com_object.GenerateGetPivotData

    @GenerateGetPivotData.setter
    def GenerateGetPivotData(self, value):
        self.com_object.GenerateGetPivotData = value

    @property
    def generategetpivotdata(self):
        """Alias for GenerateGetPivotData"""
        return self.GenerateGetPivotData

    @generategetpivotdata.setter
    def generategetpivotdata(self, value):
        """Alias for GenerateGetPivotData.setter"""
        self.GenerateGetPivotData = value

    @property
    def generate_get_pivot_data(self):
        """Alias for GenerateGetPivotData"""
        return self.GenerateGetPivotData

    @generate_get_pivot_data.setter
    def generate_get_pivot_data(self, value):
        """Alias for GenerateGetPivotData.setter"""
        self.GenerateGetPivotData = value

    @property
    def GenerateTableRefs(self):
        return self.com_object.GenerateTableRefs

    @GenerateTableRefs.setter
    def GenerateTableRefs(self, value):
        self.com_object.GenerateTableRefs = value

    @property
    def generatetablerefs(self):
        """Alias for GenerateTableRefs"""
        return self.GenerateTableRefs

    @generatetablerefs.setter
    def generatetablerefs(self, value):
        """Alias for GenerateTableRefs.setter"""
        self.GenerateTableRefs = value

    @property
    def generate_table_refs(self):
        """Alias for GenerateTableRefs"""
        return self.GenerateTableRefs

    @generate_table_refs.setter
    def generate_table_refs(self, value):
        """Alias for GenerateTableRefs.setter"""
        self.GenerateTableRefs = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HighQualityModeForGraphics(self):
        return self.com_object.HighQualityModeForGraphics

    @HighQualityModeForGraphics.setter
    def HighQualityModeForGraphics(self, value):
        self.com_object.HighQualityModeForGraphics = value

    @property
    def highqualitymodeforgraphics(self):
        """Alias for HighQualityModeForGraphics"""
        return self.HighQualityModeForGraphics

    @highqualitymodeforgraphics.setter
    def highqualitymodeforgraphics(self, value):
        """Alias for HighQualityModeForGraphics.setter"""
        self.HighQualityModeForGraphics = value

    @property
    def high_quality_mode_for_graphics(self):
        """Alias for HighQualityModeForGraphics"""
        return self.HighQualityModeForGraphics

    @high_quality_mode_for_graphics.setter
    def high_quality_mode_for_graphics(self, value):
        """Alias for HighQualityModeForGraphics.setter"""
        self.HighQualityModeForGraphics = value

    @property
    def Hinstance(self):
        return Application(self.com_object.Hinstance)

    @property
    def hinstance(self):
        """Alias for Hinstance"""
        return self.Hinstance

    @property
    def HinstancePtr(self):
        return Application(self.com_object.HinstancePtr)

    @property
    def hinstanceptr(self):
        """Alias for HinstancePtr"""
        return self.HinstancePtr

    @property
    def hinstance_ptr(self):
        """Alias for HinstancePtr"""
        return self.HinstancePtr

    @property
    def hWnd(self):
        return self.com_object.hWnd

    @property
    def hwnd(self):
        """Alias for hWnd"""
        return self.hWnd

    @property
    def h_wnd(self):
        """Alias for hWnd"""
        return self.hWnd

    @property
    def IgnoreRemoteRequests(self):
        return self.com_object.IgnoreRemoteRequests

    @IgnoreRemoteRequests.setter
    def IgnoreRemoteRequests(self, value):
        self.com_object.IgnoreRemoteRequests = value

    @property
    def ignoreremoterequests(self):
        """Alias for IgnoreRemoteRequests"""
        return self.IgnoreRemoteRequests

    @ignoreremoterequests.setter
    def ignoreremoterequests(self, value):
        """Alias for IgnoreRemoteRequests.setter"""
        self.IgnoreRemoteRequests = value

    @property
    def ignore_remote_requests(self):
        """Alias for IgnoreRemoteRequests"""
        return self.IgnoreRemoteRequests

    @ignore_remote_requests.setter
    def ignore_remote_requests(self, value):
        """Alias for IgnoreRemoteRequests.setter"""
        self.IgnoreRemoteRequests = value

    @property
    def Interactive(self):
        return self.com_object.Interactive

    @Interactive.setter
    def Interactive(self, value):
        self.com_object.Interactive = value

    @property
    def interactive(self):
        """Alias for Interactive"""
        return self.Interactive

    @interactive.setter
    def interactive(self, value):
        """Alias for Interactive.setter"""
        self.Interactive = value

    @property
    def IsSandboxed(self):
        return self.com_object.IsSandboxed

    @property
    def issandboxed(self):
        """Alias for IsSandboxed"""
        return self.IsSandboxed

    @property
    def is_sandboxed(self):
        """Alias for IsSandboxed"""
        return self.IsSandboxed

    @property
    def Iteration(self):
        return self.com_object.Iteration

    @Iteration.setter
    def Iteration(self, value):
        self.com_object.Iteration = value

    @property
    def iteration(self):
        """Alias for Iteration"""
        return self.Iteration

    @iteration.setter
    def iteration(self, value):
        """Alias for Iteration.setter"""
        self.Iteration = value

    @property
    def LanguageSettings(self):
        return self.com_object.LanguageSettings

    @property
    def languagesettings(self):
        """Alias for LanguageSettings"""
        return self.LanguageSettings

    @property
    def language_settings(self):
        """Alias for LanguageSettings"""
        return self.LanguageSettings

    @property
    def LargeOperationCellThousandCount(self):
        return self.com_object.LargeOperationCellThousandCount

    @LargeOperationCellThousandCount.setter
    def LargeOperationCellThousandCount(self, value):
        self.com_object.LargeOperationCellThousandCount = value

    @property
    def largeoperationcellthousandcount(self):
        """Alias for LargeOperationCellThousandCount"""
        return self.LargeOperationCellThousandCount

    @largeoperationcellthousandcount.setter
    def largeoperationcellthousandcount(self, value):
        """Alias for LargeOperationCellThousandCount.setter"""
        self.LargeOperationCellThousandCount = value

    @property
    def large_operation_cell_thousand_count(self):
        """Alias for LargeOperationCellThousandCount"""
        return self.LargeOperationCellThousandCount

    @large_operation_cell_thousand_count.setter
    def large_operation_cell_thousand_count(self, value):
        """Alias for LargeOperationCellThousandCount.setter"""
        self.LargeOperationCellThousandCount = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def LibraryPath(self):
        return self.com_object.LibraryPath

    @property
    def librarypath(self):
        """Alias for LibraryPath"""
        return self.LibraryPath

    @property
    def library_path(self):
        """Alias for LibraryPath"""
        return self.LibraryPath

    @property
    def MailSession(self):
        return self.com_object.MailSession

    @property
    def mailsession(self):
        """Alias for MailSession"""
        return self.MailSession

    @property
    def mail_session(self):
        """Alias for MailSession"""
        return self.MailSession

    @property
    def MailSystem(self):
        return XlMailSystem(self.com_object.MailSystem)

    @property
    def mailsystem(self):
        """Alias for MailSystem"""
        return self.MailSystem

    @property
    def mail_system(self):
        """Alias for MailSystem"""
        return self.MailSystem

    @property
    def MapPaperSize(self):
        return self.com_object.MapPaperSize

    @MapPaperSize.setter
    def MapPaperSize(self, value):
        self.com_object.MapPaperSize = value

    @property
    def mappapersize(self):
        """Alias for MapPaperSize"""
        return self.MapPaperSize

    @mappapersize.setter
    def mappapersize(self, value):
        """Alias for MapPaperSize.setter"""
        self.MapPaperSize = value

    @property
    def map_paper_size(self):
        """Alias for MapPaperSize"""
        return self.MapPaperSize

    @map_paper_size.setter
    def map_paper_size(self, value):
        """Alias for MapPaperSize.setter"""
        self.MapPaperSize = value

    @property
    def MathCoprocessorAvailable(self):
        return self.com_object.MathCoprocessorAvailable

    @property
    def mathcoprocessoravailable(self):
        """Alias for MathCoprocessorAvailable"""
        return self.MathCoprocessorAvailable

    @property
    def math_coprocessor_available(self):
        """Alias for MathCoprocessorAvailable"""
        return self.MathCoprocessorAvailable

    @property
    def MaxChange(self):
        return self.com_object.MaxChange

    @MaxChange.setter
    def MaxChange(self, value):
        self.com_object.MaxChange = value

    @property
    def maxchange(self):
        """Alias for MaxChange"""
        return self.MaxChange

    @maxchange.setter
    def maxchange(self, value):
        """Alias for MaxChange.setter"""
        self.MaxChange = value

    @property
    def max_change(self):
        """Alias for MaxChange"""
        return self.MaxChange

    @max_change.setter
    def max_change(self, value):
        """Alias for MaxChange.setter"""
        self.MaxChange = value

    @property
    def MaxIterations(self):
        return self.com_object.MaxIterations

    @MaxIterations.setter
    def MaxIterations(self, value):
        self.com_object.MaxIterations = value

    @property
    def maxiterations(self):
        """Alias for MaxIterations"""
        return self.MaxIterations

    @maxiterations.setter
    def maxiterations(self, value):
        """Alias for MaxIterations.setter"""
        self.MaxIterations = value

    @property
    def max_iterations(self):
        """Alias for MaxIterations"""
        return self.MaxIterations

    @max_iterations.setter
    def max_iterations(self, value):
        """Alias for MaxIterations.setter"""
        self.MaxIterations = value

    @property
    def MeasurementUnit(self):
        return self.com_object.MeasurementUnit

    @MeasurementUnit.setter
    def MeasurementUnit(self, value):
        self.com_object.MeasurementUnit = value

    @property
    def measurementunit(self):
        """Alias for MeasurementUnit"""
        return self.MeasurementUnit

    @measurementunit.setter
    def measurementunit(self, value):
        """Alias for MeasurementUnit.setter"""
        self.MeasurementUnit = value

    @property
    def measurement_unit(self):
        """Alias for MeasurementUnit"""
        return self.MeasurementUnit

    @measurement_unit.setter
    def measurement_unit(self, value):
        """Alias for MeasurementUnit.setter"""
        self.MeasurementUnit = value

    @property
    def MergeInstances(self):
        return self.com_object.MergeInstances

    @MergeInstances.setter
    def MergeInstances(self, value):
        self.com_object.MergeInstances = value

    @property
    def mergeinstances(self):
        """Alias for MergeInstances"""
        return self.MergeInstances

    @mergeinstances.setter
    def mergeinstances(self, value):
        """Alias for MergeInstances.setter"""
        self.MergeInstances = value

    @property
    def merge_instances(self):
        """Alias for MergeInstances"""
        return self.MergeInstances

    @merge_instances.setter
    def merge_instances(self, value):
        """Alias for MergeInstances.setter"""
        self.MergeInstances = value

    @property
    def MouseAvailable(self):
        return self.com_object.MouseAvailable

    @property
    def mouseavailable(self):
        """Alias for MouseAvailable"""
        return self.MouseAvailable

    @property
    def mouse_available(self):
        """Alias for MouseAvailable"""
        return self.MouseAvailable

    @property
    def MoveAfterReturn(self):
        return self.com_object.MoveAfterReturn

    @MoveAfterReturn.setter
    def MoveAfterReturn(self, value):
        self.com_object.MoveAfterReturn = value

    @property
    def moveafterreturn(self):
        """Alias for MoveAfterReturn"""
        return self.MoveAfterReturn

    @moveafterreturn.setter
    def moveafterreturn(self, value):
        """Alias for MoveAfterReturn.setter"""
        self.MoveAfterReturn = value

    @property
    def move_after_return(self):
        """Alias for MoveAfterReturn"""
        return self.MoveAfterReturn

    @move_after_return.setter
    def move_after_return(self, value):
        """Alias for MoveAfterReturn.setter"""
        self.MoveAfterReturn = value

    @property
    def MoveAfterReturnDirection(self):
        return XlDirection(self.com_object.MoveAfterReturnDirection)

    @MoveAfterReturnDirection.setter
    def MoveAfterReturnDirection(self, value):
        self.com_object.MoveAfterReturnDirection = value

    @property
    def moveafterreturndirection(self):
        """Alias for MoveAfterReturnDirection"""
        return self.MoveAfterReturnDirection

    @moveafterreturndirection.setter
    def moveafterreturndirection(self, value):
        """Alias for MoveAfterReturnDirection.setter"""
        self.MoveAfterReturnDirection = value

    @property
    def move_after_return_direction(self):
        """Alias for MoveAfterReturnDirection"""
        return self.MoveAfterReturnDirection

    @move_after_return_direction.setter
    def move_after_return_direction(self, value):
        """Alias for MoveAfterReturnDirection.setter"""
        self.MoveAfterReturnDirection = value

    @property
    def MultiThreadedCalculation(self):
        return MultiThreadedCalculation(self.com_object.MultiThreadedCalculation)

    @property
    def multithreadedcalculation(self):
        """Alias for MultiThreadedCalculation"""
        return self.MultiThreadedCalculation

    @property
    def multi_threaded_calculation(self):
        """Alias for MultiThreadedCalculation"""
        return self.MultiThreadedCalculation

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Names(self):
        return Names(self.com_object.Names)

    @property
    def names(self):
        """Alias for Names"""
        return self.Names

    @property
    def NetworkTemplatesPath(self):
        return self.com_object.NetworkTemplatesPath

    @property
    def networktemplatespath(self):
        """Alias for NetworkTemplatesPath"""
        return self.NetworkTemplatesPath

    @property
    def network_templates_path(self):
        """Alias for NetworkTemplatesPath"""
        return self.NetworkTemplatesPath

    @property
    def NewWorkbook(self):
        return self.com_object.NewWorkbook

    @property
    def newworkbook(self):
        """Alias for NewWorkbook"""
        return self.NewWorkbook

    @property
    def new_workbook(self):
        """Alias for NewWorkbook"""
        return self.NewWorkbook

    @property
    def ODBCErrors(self):
        return ODBCErrors(self.com_object.ODBCErrors)

    @property
    def odbcerrors(self):
        """Alias for ODBCErrors"""
        return self.ODBCErrors

    @property
    def o_d_b_c_errors(self):
        """Alias for ODBCErrors"""
        return self.ODBCErrors

    @property
    def ODBCTimeout(self):
        return self.com_object.ODBCTimeout

    @ODBCTimeout.setter
    def ODBCTimeout(self, value):
        self.com_object.ODBCTimeout = value

    @property
    def odbctimeout(self):
        """Alias for ODBCTimeout"""
        return self.ODBCTimeout

    @odbctimeout.setter
    def odbctimeout(self, value):
        """Alias for ODBCTimeout.setter"""
        self.ODBCTimeout = value

    @property
    def o_d_b_c_timeout(self):
        """Alias for ODBCTimeout"""
        return self.ODBCTimeout

    @o_d_b_c_timeout.setter
    def o_d_b_c_timeout(self, value):
        """Alias for ODBCTimeout.setter"""
        self.ODBCTimeout = value

    @property
    def OLEDBErrors(self):
        return OLEDBErrors(self.com_object.OLEDBErrors)

    @property
    def oledberrors(self):
        """Alias for OLEDBErrors"""
        return self.OLEDBErrors

    @property
    def o_l_e_d_b_errors(self):
        """Alias for OLEDBErrors"""
        return self.OLEDBErrors

    @property
    def OnWindow(self):
        return self.com_object.OnWindow

    @OnWindow.setter
    def OnWindow(self, value):
        self.com_object.OnWindow = value

    @property
    def onwindow(self):
        """Alias for OnWindow"""
        return self.OnWindow

    @onwindow.setter
    def onwindow(self, value):
        """Alias for OnWindow.setter"""
        self.OnWindow = value

    @property
    def on_window(self):
        """Alias for OnWindow"""
        return self.OnWindow

    @on_window.setter
    def on_window(self, value):
        """Alias for OnWindow.setter"""
        self.OnWindow = value

    @property
    def OperatingSystem(self):
        return self.com_object.OperatingSystem

    @property
    def operatingsystem(self):
        """Alias for OperatingSystem"""
        return self.OperatingSystem

    @property
    def operating_system(self):
        """Alias for OperatingSystem"""
        return self.OperatingSystem

    @property
    def OrganizationName(self):
        return self.com_object.OrganizationName

    @property
    def organizationname(self):
        """Alias for OrganizationName"""
        return self.OrganizationName

    @property
    def organization_name(self):
        """Alias for OrganizationName"""
        return self.OrganizationName

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Path(self):
        return self.com_object.Path

    @property
    def path(self):
        """Alias for Path"""
        return self.Path

    @property
    def PathSeparator(self):
        return self.com_object.PathSeparator

    @property
    def pathseparator(self):
        """Alias for PathSeparator"""
        return self.PathSeparator

    @property
    def path_separator(self):
        """Alias for PathSeparator"""
        return self.PathSeparator

    @property
    def PivotTableSelection(self):
        return self.com_object.PivotTableSelection

    @PivotTableSelection.setter
    def PivotTableSelection(self, value):
        self.com_object.PivotTableSelection = value

    @property
    def pivottableselection(self):
        """Alias for PivotTableSelection"""
        return self.PivotTableSelection

    @pivottableselection.setter
    def pivottableselection(self, value):
        """Alias for PivotTableSelection.setter"""
        self.PivotTableSelection = value

    @property
    def pivot_table_selection(self):
        """Alias for PivotTableSelection"""
        return self.PivotTableSelection

    @pivot_table_selection.setter
    def pivot_table_selection(self, value):
        """Alias for PivotTableSelection.setter"""
        self.PivotTableSelection = value

    def PreviousSelections(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetPreviousSelections"):
            return Range(self.com_object.GetPreviousSelections(*arguments))
        else:
            return Range(self.com_object.PreviousSelections(*arguments))

    def previousselections(self, Index=None):
        """Alias for PreviousSelections"""
        arguments = [Index]
        return self.PreviousSelections(*arguments)

    def previous_selections(self, Index=None):
        """Alias for PreviousSelections"""
        arguments = [Index]
        return self.PreviousSelections(*arguments)

    @property
    def PrintCommunication(self):
        return self.com_object.PrintCommunication

    @PrintCommunication.setter
    def PrintCommunication(self, value):
        self.com_object.PrintCommunication = value

    @property
    def printcommunication(self):
        """Alias for PrintCommunication"""
        return self.PrintCommunication

    @printcommunication.setter
    def printcommunication(self, value):
        """Alias for PrintCommunication.setter"""
        self.PrintCommunication = value

    @property
    def print_communication(self):
        """Alias for PrintCommunication"""
        return self.PrintCommunication

    @print_communication.setter
    def print_communication(self, value):
        """Alias for PrintCommunication.setter"""
        self.PrintCommunication = value

    @property
    def ProductCode(self):
        return self.com_object.ProductCode

    @property
    def productcode(self):
        """Alias for ProductCode"""
        return self.ProductCode

    @property
    def product_code(self):
        """Alias for ProductCode"""
        return self.ProductCode

    @property
    def PromptForSummaryInfo(self):
        return self.com_object.PromptForSummaryInfo

    @PromptForSummaryInfo.setter
    def PromptForSummaryInfo(self, value):
        self.com_object.PromptForSummaryInfo = value

    @property
    def promptforsummaryinfo(self):
        """Alias for PromptForSummaryInfo"""
        return self.PromptForSummaryInfo

    @promptforsummaryinfo.setter
    def promptforsummaryinfo(self, value):
        """Alias for PromptForSummaryInfo.setter"""
        self.PromptForSummaryInfo = value

    @property
    def prompt_for_summary_info(self):
        """Alias for PromptForSummaryInfo"""
        return self.PromptForSummaryInfo

    @prompt_for_summary_info.setter
    def prompt_for_summary_info(self, value):
        """Alias for PromptForSummaryInfo.setter"""
        self.PromptForSummaryInfo = value

    @property
    def ProtectedViewWindows(self):
        return ProtectedViewWindows(self.com_object.ProtectedViewWindows)

    @property
    def protectedviewwindows(self):
        """Alias for ProtectedViewWindows"""
        return self.ProtectedViewWindows

    @property
    def protected_view_windows(self):
        """Alias for ProtectedViewWindows"""
        return self.ProtectedViewWindows

    @property
    def QuickAnalysis(self):
        return QuickAnalysis(self.com_object.QuickAnalysis)

    @property
    def quickanalysis(self):
        """Alias for QuickAnalysis"""
        return self.QuickAnalysis

    @property
    def quick_analysis(self):
        """Alias for QuickAnalysis"""
        return self.QuickAnalysis

    def Range(self, Cell1=None, Cell2=None):
        arguments = com_arguments([unwrap(a) for a in [Cell1, Cell2]])
        if hasattr(self.com_object, "GetRange"):
            return Range(self.com_object.GetRange(*arguments))
        else:
            return Range(self.com_object.Range(*arguments))

    def range(self, Cell1=None, Cell2=None):
        """Alias for Range"""
        arguments = [Cell1, Cell2]
        return self.Range(*arguments)

    @property
    def Ready(self):
        return self.com_object.Ready

    @property
    def ready(self):
        """Alias for Ready"""
        return self.Ready

    @property
    def RecentFiles(self):
        return RecentFiles(self.com_object.RecentFiles)

    @property
    def recentfiles(self):
        """Alias for RecentFiles"""
        return self.RecentFiles

    @property
    def recent_files(self):
        """Alias for RecentFiles"""
        return self.RecentFiles

    @property
    def RecordRelative(self):
        return self.com_object.RecordRelative

    @property
    def recordrelative(self):
        """Alias for RecordRelative"""
        return self.RecordRelative

    @property
    def record_relative(self):
        """Alias for RecordRelative"""
        return self.RecordRelative

    @property
    def ReferenceStyle(self):
        return XlReferenceStyle(self.com_object.ReferenceStyle)

    @ReferenceStyle.setter
    def ReferenceStyle(self, value):
        self.com_object.ReferenceStyle = value

    @property
    def referencestyle(self):
        """Alias for ReferenceStyle"""
        return self.ReferenceStyle

    @referencestyle.setter
    def referencestyle(self, value):
        """Alias for ReferenceStyle.setter"""
        self.ReferenceStyle = value

    @property
    def reference_style(self):
        """Alias for ReferenceStyle"""
        return self.ReferenceStyle

    @reference_style.setter
    def reference_style(self, value):
        """Alias for ReferenceStyle.setter"""
        self.ReferenceStyle = value

    def RegisteredFunctions(self, Index1=None, Index2=None):
        arguments = com_arguments([unwrap(a) for a in [Index1, Index2]])
        if hasattr(self.com_object, "GetRegisteredFunctions"):
            return self.com_object.GetRegisteredFunctions(*arguments)
        else:
            return self.com_object.RegisteredFunctions(*arguments)

    def registeredfunctions(self, Index1=None, Index2=None):
        """Alias for RegisteredFunctions"""
        arguments = [Index1, Index2]
        return self.RegisteredFunctions(*arguments)

    def registered_functions(self, Index1=None, Index2=None):
        """Alias for RegisteredFunctions"""
        arguments = [Index1, Index2]
        return self.RegisteredFunctions(*arguments)

    @property
    def ReplaceFormat(self):
        return self.com_object.ReplaceFormat

    @property
    def replaceformat(self):
        """Alias for ReplaceFormat"""
        return self.ReplaceFormat

    @property
    def replace_format(self):
        """Alias for ReplaceFormat"""
        return self.ReplaceFormat

    @property
    def RollZoom(self):
        return self.com_object.RollZoom

    @RollZoom.setter
    def RollZoom(self, value):
        self.com_object.RollZoom = value

    @property
    def rollzoom(self):
        """Alias for RollZoom"""
        return self.RollZoom

    @rollzoom.setter
    def rollzoom(self, value):
        """Alias for RollZoom.setter"""
        self.RollZoom = value

    @property
    def roll_zoom(self):
        """Alias for RollZoom"""
        return self.RollZoom

    @roll_zoom.setter
    def roll_zoom(self, value):
        """Alias for RollZoom.setter"""
        self.RollZoom = value

    @property
    def Rows(self):
        return Range(self.com_object.Rows)

    @property
    def rows(self):
        """Alias for Rows"""
        return self.Rows

    @property
    def RTD(self):
        return RTD(self.com_object.RTD)

    @property
    def rtd(self):
        """Alias for RTD"""
        return self.RTD

    @property
    def r_t_d(self):
        """Alias for RTD"""
        return self.RTD

    @property
    def ScreenUpdating(self):
        return self.com_object.ScreenUpdating

    @ScreenUpdating.setter
    def ScreenUpdating(self, value):
        self.com_object.ScreenUpdating = value

    @property
    def screenupdating(self):
        """Alias for ScreenUpdating"""
        return self.ScreenUpdating

    @screenupdating.setter
    def screenupdating(self, value):
        """Alias for ScreenUpdating.setter"""
        self.ScreenUpdating = value

    @property
    def screen_updating(self):
        """Alias for ScreenUpdating"""
        return self.ScreenUpdating

    @screen_updating.setter
    def screen_updating(self, value):
        """Alias for ScreenUpdating.setter"""
        self.ScreenUpdating = value

    @property
    def Selection(self):
        return self.com_object.Selection

    @property
    def selection(self):
        """Alias for Selection"""
        return self.Selection

    @property
    def SensitivityLabelPolicy(self):
        return Application(self.com_object.SensitivityLabelPolicy)

    @property
    def sensitivitylabelpolicy(self):
        """Alias for SensitivityLabelPolicy"""
        return self.SensitivityLabelPolicy

    @property
    def sensitivity_label_policy(self):
        """Alias for SensitivityLabelPolicy"""
        return self.SensitivityLabelPolicy

    @property
    def Sheets(self):
        return Sheets(self.com_object.Sheets)

    @property
    def sheets(self):
        """Alias for Sheets"""
        return self.Sheets

    @property
    def SheetsInNewWorkbook(self):
        return self.com_object.SheetsInNewWorkbook

    @SheetsInNewWorkbook.setter
    def SheetsInNewWorkbook(self, value):
        self.com_object.SheetsInNewWorkbook = value

    @property
    def sheetsinnewworkbook(self):
        """Alias for SheetsInNewWorkbook"""
        return self.SheetsInNewWorkbook

    @sheetsinnewworkbook.setter
    def sheetsinnewworkbook(self, value):
        """Alias for SheetsInNewWorkbook.setter"""
        self.SheetsInNewWorkbook = value

    @property
    def sheets_in_new_workbook(self):
        """Alias for SheetsInNewWorkbook"""
        return self.SheetsInNewWorkbook

    @sheets_in_new_workbook.setter
    def sheets_in_new_workbook(self, value):
        """Alias for SheetsInNewWorkbook.setter"""
        self.SheetsInNewWorkbook = value

    @property
    def ShowChartTipNames(self):
        return self.com_object.ShowChartTipNames

    @ShowChartTipNames.setter
    def ShowChartTipNames(self, value):
        self.com_object.ShowChartTipNames = value

    @property
    def showcharttipnames(self):
        """Alias for ShowChartTipNames"""
        return self.ShowChartTipNames

    @showcharttipnames.setter
    def showcharttipnames(self, value):
        """Alias for ShowChartTipNames.setter"""
        self.ShowChartTipNames = value

    @property
    def show_chart_tip_names(self):
        """Alias for ShowChartTipNames"""
        return self.ShowChartTipNames

    @show_chart_tip_names.setter
    def show_chart_tip_names(self, value):
        """Alias for ShowChartTipNames.setter"""
        self.ShowChartTipNames = value

    @property
    def ShowChartTipValues(self):
        return self.com_object.ShowChartTipValues

    @ShowChartTipValues.setter
    def ShowChartTipValues(self, value):
        self.com_object.ShowChartTipValues = value

    @property
    def showcharttipvalues(self):
        """Alias for ShowChartTipValues"""
        return self.ShowChartTipValues

    @showcharttipvalues.setter
    def showcharttipvalues(self, value):
        """Alias for ShowChartTipValues.setter"""
        self.ShowChartTipValues = value

    @property
    def show_chart_tip_values(self):
        """Alias for ShowChartTipValues"""
        return self.ShowChartTipValues

    @show_chart_tip_values.setter
    def show_chart_tip_values(self, value):
        """Alias for ShowChartTipValues.setter"""
        self.ShowChartTipValues = value

    @property
    def ShowDevTools(self):
        return self.com_object.ShowDevTools

    @ShowDevTools.setter
    def ShowDevTools(self, value):
        self.com_object.ShowDevTools = value

    @property
    def showdevtools(self):
        """Alias for ShowDevTools"""
        return self.ShowDevTools

    @showdevtools.setter
    def showdevtools(self, value):
        """Alias for ShowDevTools.setter"""
        self.ShowDevTools = value

    @property
    def show_dev_tools(self):
        """Alias for ShowDevTools"""
        return self.ShowDevTools

    @show_dev_tools.setter
    def show_dev_tools(self, value):
        """Alias for ShowDevTools.setter"""
        self.ShowDevTools = value

    @property
    def ShowMenuFloaties(self):
        return self.com_object.ShowMenuFloaties

    @ShowMenuFloaties.setter
    def ShowMenuFloaties(self, value):
        self.com_object.ShowMenuFloaties = value

    @property
    def showmenufloaties(self):
        """Alias for ShowMenuFloaties"""
        return self.ShowMenuFloaties

    @showmenufloaties.setter
    def showmenufloaties(self, value):
        """Alias for ShowMenuFloaties.setter"""
        self.ShowMenuFloaties = value

    @property
    def show_menu_floaties(self):
        """Alias for ShowMenuFloaties"""
        return self.ShowMenuFloaties

    @show_menu_floaties.setter
    def show_menu_floaties(self, value):
        """Alias for ShowMenuFloaties.setter"""
        self.ShowMenuFloaties = value

    @property
    def ShowQuickAnalysis(self):
        return self.com_object.ShowQuickAnalysis

    @property
    def showquickanalysis(self):
        """Alias for ShowQuickAnalysis"""
        return self.ShowQuickAnalysis

    @property
    def show_quick_analysis(self):
        """Alias for ShowQuickAnalysis"""
        return self.ShowQuickAnalysis

    @property
    def ShowSelectionFloaties(self):
        return self.com_object.ShowSelectionFloaties

    @ShowSelectionFloaties.setter
    def ShowSelectionFloaties(self, value):
        self.com_object.ShowSelectionFloaties = value

    @property
    def showselectionfloaties(self):
        """Alias for ShowSelectionFloaties"""
        return self.ShowSelectionFloaties

    @showselectionfloaties.setter
    def showselectionfloaties(self, value):
        """Alias for ShowSelectionFloaties.setter"""
        self.ShowSelectionFloaties = value

    @property
    def show_selection_floaties(self):
        """Alias for ShowSelectionFloaties"""
        return self.ShowSelectionFloaties

    @show_selection_floaties.setter
    def show_selection_floaties(self, value):
        """Alias for ShowSelectionFloaties.setter"""
        self.ShowSelectionFloaties = value

    @property
    def ShowStartupDialog(self):
        return self.com_object.ShowStartupDialog

    @ShowStartupDialog.setter
    def ShowStartupDialog(self, value):
        self.com_object.ShowStartupDialog = value

    @property
    def showstartupdialog(self):
        """Alias for ShowStartupDialog"""
        return self.ShowStartupDialog

    @showstartupdialog.setter
    def showstartupdialog(self, value):
        """Alias for ShowStartupDialog.setter"""
        self.ShowStartupDialog = value

    @property
    def show_startup_dialog(self):
        """Alias for ShowStartupDialog"""
        return self.ShowStartupDialog

    @show_startup_dialog.setter
    def show_startup_dialog(self, value):
        """Alias for ShowStartupDialog.setter"""
        self.ShowStartupDialog = value

    @property
    def ShowToolTips(self):
        return self.com_object.ShowToolTips

    @ShowToolTips.setter
    def ShowToolTips(self, value):
        self.com_object.ShowToolTips = value

    @property
    def showtooltips(self):
        """Alias for ShowToolTips"""
        return self.ShowToolTips

    @showtooltips.setter
    def showtooltips(self, value):
        """Alias for ShowToolTips.setter"""
        self.ShowToolTips = value

    @property
    def show_tool_tips(self):
        """Alias for ShowToolTips"""
        return self.ShowToolTips

    @show_tool_tips.setter
    def show_tool_tips(self, value):
        """Alias for ShowToolTips.setter"""
        self.ShowToolTips = value

    @property
    def SmartArtColors(self):
        return self.com_object.SmartArtColors

    @property
    def smartartcolors(self):
        """Alias for SmartArtColors"""
        return self.SmartArtColors

    @property
    def smart_art_colors(self):
        """Alias for SmartArtColors"""
        return self.SmartArtColors

    @property
    def SmartArtLayouts(self):
        return self.com_object.SmartArtLayouts

    @property
    def smartartlayouts(self):
        """Alias for SmartArtLayouts"""
        return self.SmartArtLayouts

    @property
    def smart_art_layouts(self):
        """Alias for SmartArtLayouts"""
        return self.SmartArtLayouts

    @property
    def SmartArtQuickStyles(self):
        return self.com_object.SmartArtQuickStyles

    @property
    def smartartquickstyles(self):
        """Alias for SmartArtQuickStyles"""
        return self.SmartArtQuickStyles

    @property
    def smart_art_quick_styles(self):
        """Alias for SmartArtQuickStyles"""
        return self.SmartArtQuickStyles

    @property
    def Speech(self):
        return Speech(self.com_object.Speech)

    @property
    def speech(self):
        """Alias for Speech"""
        return self.Speech

    @property
    def SpellingOptions(self):
        return SpellingOptions(self.com_object.SpellingOptions)

    @property
    def spellingoptions(self):
        """Alias for SpellingOptions"""
        return self.SpellingOptions

    @property
    def spelling_options(self):
        """Alias for SpellingOptions"""
        return self.SpellingOptions

    @property
    def StandardFont(self):
        return self.com_object.StandardFont

    @StandardFont.setter
    def StandardFont(self, value):
        self.com_object.StandardFont = value

    @property
    def standardfont(self):
        """Alias for StandardFont"""
        return self.StandardFont

    @standardfont.setter
    def standardfont(self, value):
        """Alias for StandardFont.setter"""
        self.StandardFont = value

    @property
    def standard_font(self):
        """Alias for StandardFont"""
        return self.StandardFont

    @standard_font.setter
    def standard_font(self, value):
        """Alias for StandardFont.setter"""
        self.StandardFont = value

    @property
    def StandardFontSize(self):
        return self.com_object.StandardFontSize

    @StandardFontSize.setter
    def StandardFontSize(self, value):
        self.com_object.StandardFontSize = value

    @property
    def standardfontsize(self):
        """Alias for StandardFontSize"""
        return self.StandardFontSize

    @standardfontsize.setter
    def standardfontsize(self, value):
        """Alias for StandardFontSize.setter"""
        self.StandardFontSize = value

    @property
    def standard_font_size(self):
        """Alias for StandardFontSize"""
        return self.StandardFontSize

    @standard_font_size.setter
    def standard_font_size(self, value):
        """Alias for StandardFontSize.setter"""
        self.StandardFontSize = value

    @property
    def StartupPath(self):
        return self.com_object.StartupPath

    @property
    def startuppath(self):
        """Alias for StartupPath"""
        return self.StartupPath

    @property
    def startup_path(self):
        """Alias for StartupPath"""
        return self.StartupPath

    @property
    def StatusBar(self):
        return self.com_object.StatusBar

    @StatusBar.setter
    def StatusBar(self, value):
        self.com_object.StatusBar = value

    @property
    def statusbar(self):
        """Alias for StatusBar"""
        return self.StatusBar

    @statusbar.setter
    def statusbar(self, value):
        """Alias for StatusBar.setter"""
        self.StatusBar = value

    @property
    def status_bar(self):
        """Alias for StatusBar"""
        return self.StatusBar

    @status_bar.setter
    def status_bar(self, value):
        """Alias for StatusBar.setter"""
        self.StatusBar = value

    @property
    def TemplatesPath(self):
        return self.com_object.TemplatesPath

    @property
    def templatespath(self):
        """Alias for TemplatesPath"""
        return self.TemplatesPath

    @property
    def templates_path(self):
        """Alias for TemplatesPath"""
        return self.TemplatesPath

    @property
    def ThisCell(self):
        return Range(self.com_object.ThisCell)

    @property
    def thiscell(self):
        """Alias for ThisCell"""
        return self.ThisCell

    @property
    def this_cell(self):
        """Alias for ThisCell"""
        return self.ThisCell

    @property
    def ThisWorkbook(self):
        return Workbook(self.com_object.ThisWorkbook)

    @property
    def thisworkbook(self):
        """Alias for ThisWorkbook"""
        return self.ThisWorkbook

    @property
    def this_workbook(self):
        """Alias for ThisWorkbook"""
        return self.ThisWorkbook

    @property
    def ThousandsSeparator(self):
        return self.com_object.ThousandsSeparator

    @ThousandsSeparator.setter
    def ThousandsSeparator(self, value):
        self.com_object.ThousandsSeparator = value

    @property
    def thousandsseparator(self):
        """Alias for ThousandsSeparator"""
        return self.ThousandsSeparator

    @thousandsseparator.setter
    def thousandsseparator(self, value):
        """Alias for ThousandsSeparator.setter"""
        self.ThousandsSeparator = value

    @property
    def thousands_separator(self):
        """Alias for ThousandsSeparator"""
        return self.ThousandsSeparator

    @thousands_separator.setter
    def thousands_separator(self, value):
        """Alias for ThousandsSeparator.setter"""
        self.ThousandsSeparator = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TransitionMenuKey(self):
        return self.com_object.TransitionMenuKey

    @TransitionMenuKey.setter
    def TransitionMenuKey(self, value):
        self.com_object.TransitionMenuKey = value

    @property
    def transitionmenukey(self):
        """Alias for TransitionMenuKey"""
        return self.TransitionMenuKey

    @transitionmenukey.setter
    def transitionmenukey(self, value):
        """Alias for TransitionMenuKey.setter"""
        self.TransitionMenuKey = value

    @property
    def transition_menu_key(self):
        """Alias for TransitionMenuKey"""
        return self.TransitionMenuKey

    @transition_menu_key.setter
    def transition_menu_key(self, value):
        """Alias for TransitionMenuKey.setter"""
        self.TransitionMenuKey = value

    @property
    def TransitionMenuKeyAction(self):
        return self.com_object.TransitionMenuKeyAction

    @TransitionMenuKeyAction.setter
    def TransitionMenuKeyAction(self, value):
        self.com_object.TransitionMenuKeyAction = value

    @property
    def transitionmenukeyaction(self):
        """Alias for TransitionMenuKeyAction"""
        return self.TransitionMenuKeyAction

    @transitionmenukeyaction.setter
    def transitionmenukeyaction(self, value):
        """Alias for TransitionMenuKeyAction.setter"""
        self.TransitionMenuKeyAction = value

    @property
    def transition_menu_key_action(self):
        """Alias for TransitionMenuKeyAction"""
        return self.TransitionMenuKeyAction

    @transition_menu_key_action.setter
    def transition_menu_key_action(self, value):
        """Alias for TransitionMenuKeyAction.setter"""
        self.TransitionMenuKeyAction = value

    @property
    def TransitionNavigKeys(self):
        return self.com_object.TransitionNavigKeys

    @TransitionNavigKeys.setter
    def TransitionNavigKeys(self, value):
        self.com_object.TransitionNavigKeys = value

    @property
    def transitionnavigkeys(self):
        """Alias for TransitionNavigKeys"""
        return self.TransitionNavigKeys

    @transitionnavigkeys.setter
    def transitionnavigkeys(self, value):
        """Alias for TransitionNavigKeys.setter"""
        self.TransitionNavigKeys = value

    @property
    def transition_navig_keys(self):
        """Alias for TransitionNavigKeys"""
        return self.TransitionNavigKeys

    @transition_navig_keys.setter
    def transition_navig_keys(self, value):
        """Alias for TransitionNavigKeys.setter"""
        self.TransitionNavigKeys = value

    @property
    def UsableHeight(self):
        return self.com_object.UsableHeight

    @property
    def usableheight(self):
        """Alias for UsableHeight"""
        return self.UsableHeight

    @property
    def usable_height(self):
        """Alias for UsableHeight"""
        return self.UsableHeight

    @property
    def UsableWidth(self):
        return self.com_object.UsableWidth

    @property
    def usablewidth(self):
        """Alias for UsableWidth"""
        return self.UsableWidth

    @property
    def usable_width(self):
        """Alias for UsableWidth"""
        return self.UsableWidth

    @property
    def UseClusterConnector(self):
        return self.com_object.UseClusterConnector

    @UseClusterConnector.setter
    def UseClusterConnector(self, value):
        self.com_object.UseClusterConnector = value

    @property
    def useclusterconnector(self):
        """Alias for UseClusterConnector"""
        return self.UseClusterConnector

    @useclusterconnector.setter
    def useclusterconnector(self, value):
        """Alias for UseClusterConnector.setter"""
        self.UseClusterConnector = value

    @property
    def use_cluster_connector(self):
        """Alias for UseClusterConnector"""
        return self.UseClusterConnector

    @use_cluster_connector.setter
    def use_cluster_connector(self, value):
        """Alias for UseClusterConnector.setter"""
        self.UseClusterConnector = value

    @property
    def UsedObjects(self):
        return UsedObjects(self.com_object.UsedObjects)

    @property
    def usedobjects(self):
        """Alias for UsedObjects"""
        return self.UsedObjects

    @property
    def used_objects(self):
        """Alias for UsedObjects"""
        return self.UsedObjects

    @property
    def UserControl(self):
        return self.com_object.UserControl

    @UserControl.setter
    def UserControl(self, value):
        self.com_object.UserControl = value

    @property
    def usercontrol(self):
        """Alias for UserControl"""
        return self.UserControl

    @usercontrol.setter
    def usercontrol(self, value):
        """Alias for UserControl.setter"""
        self.UserControl = value

    @property
    def user_control(self):
        """Alias for UserControl"""
        return self.UserControl

    @user_control.setter
    def user_control(self, value):
        """Alias for UserControl.setter"""
        self.UserControl = value

    @property
    def UserLibraryPath(self):
        return self.com_object.UserLibraryPath

    @property
    def userlibrarypath(self):
        """Alias for UserLibraryPath"""
        return self.UserLibraryPath

    @property
    def user_library_path(self):
        """Alias for UserLibraryPath"""
        return self.UserLibraryPath

    @property
    def UserName(self):
        return self.com_object.UserName

    @UserName.setter
    def UserName(self, value):
        self.com_object.UserName = value

    @property
    def username(self):
        """Alias for UserName"""
        return self.UserName

    @username.setter
    def username(self, value):
        """Alias for UserName.setter"""
        self.UserName = value

    @property
    def user_name(self):
        """Alias for UserName"""
        return self.UserName

    @user_name.setter
    def user_name(self, value):
        """Alias for UserName.setter"""
        self.UserName = value

    @property
    def UseSystemSeparators(self):
        return self.com_object.UseSystemSeparators

    @UseSystemSeparators.setter
    def UseSystemSeparators(self, value):
        self.com_object.UseSystemSeparators = value

    @property
    def usesystemseparators(self):
        """Alias for UseSystemSeparators"""
        return self.UseSystemSeparators

    @usesystemseparators.setter
    def usesystemseparators(self, value):
        """Alias for UseSystemSeparators.setter"""
        self.UseSystemSeparators = value

    @property
    def use_system_separators(self):
        """Alias for UseSystemSeparators"""
        return self.UseSystemSeparators

    @use_system_separators.setter
    def use_system_separators(self, value):
        """Alias for UseSystemSeparators.setter"""
        self.UseSystemSeparators = value

    @property
    def Value(self):
        return self.com_object.Value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @property
    def VBE(self):
        return self.com_object.VBE

    @property
    def vbe(self):
        """Alias for VBE"""
        return self.VBE

    @property
    def v_b_e(self):
        """Alias for VBE"""
        return self.VBE

    @property
    def Version(self):
        return self.com_object.Version

    @property
    def version(self):
        """Alias for Version"""
        return self.Version

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def WarnOnFunctionNameConflict(self):
        return self.com_object.WarnOnFunctionNameConflict

    @WarnOnFunctionNameConflict.setter
    def WarnOnFunctionNameConflict(self, value):
        self.com_object.WarnOnFunctionNameConflict = value

    @property
    def warnonfunctionnameconflict(self):
        """Alias for WarnOnFunctionNameConflict"""
        return self.WarnOnFunctionNameConflict

    @warnonfunctionnameconflict.setter
    def warnonfunctionnameconflict(self, value):
        """Alias for WarnOnFunctionNameConflict.setter"""
        self.WarnOnFunctionNameConflict = value

    @property
    def warn_on_function_name_conflict(self):
        """Alias for WarnOnFunctionNameConflict"""
        return self.WarnOnFunctionNameConflict

    @warn_on_function_name_conflict.setter
    def warn_on_function_name_conflict(self, value):
        """Alias for WarnOnFunctionNameConflict.setter"""
        self.WarnOnFunctionNameConflict = value

    @property
    def Watches(self):
        return Watches(self.com_object.Watches)

    @property
    def watches(self):
        """Alias for Watches"""
        return self.Watches

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def Windows(self):
        return Windows(self.com_object.Windows)

    @property
    def windows(self):
        """Alias for Windows"""
        return self.Windows

    @property
    def WindowsForPens(self):
        return self.com_object.WindowsForPens

    @property
    def windowsforpens(self):
        """Alias for WindowsForPens"""
        return self.WindowsForPens

    @property
    def windows_for_pens(self):
        """Alias for WindowsForPens"""
        return self.WindowsForPens

    @property
    def WindowState(self):
        return XlWindowState(self.com_object.WindowState)

    @WindowState.setter
    def WindowState(self, value):
        self.com_object.WindowState = value

    @property
    def windowstate(self):
        """Alias for WindowState"""
        return self.WindowState

    @windowstate.setter
    def windowstate(self, value):
        """Alias for WindowState.setter"""
        self.WindowState = value

    @property
    def window_state(self):
        """Alias for WindowState"""
        return self.WindowState

    @window_state.setter
    def window_state(self, value):
        """Alias for WindowState.setter"""
        self.WindowState = value

    @property
    def Workbooks(self):
        return Workbooks(self.com_object.Workbooks)

    @property
    def workbooks(self):
        """Alias for Workbooks"""
        return self.Workbooks

    @property
    def WorksheetFunction(self):
        return WorksheetFunction(self.com_object.WorksheetFunction)

    @property
    def worksheetfunction(self):
        """Alias for WorksheetFunction"""
        return self.WorksheetFunction

    @property
    def worksheet_function(self):
        """Alias for WorksheetFunction"""
        return self.WorksheetFunction

    @property
    def Worksheets(self):
        return self.com_object.Worksheets

    @property
    def worksheets(self):
        """Alias for Worksheets"""
        return self.Worksheets

    def ActivateMicrosoftApp(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.ActivateMicrosoftApp(*arguments)

    def activatemicrosoftapp(self, Index=None):
        """Alias for ActivateMicrosoftApp"""
        arguments = [Index]
        return self.ActivateMicrosoftApp(*arguments)

    def activate_microsoft_app(self, Index=None):
        """Alias for ActivateMicrosoftApp"""
        arguments = [Index]
        return self.ActivateMicrosoftApp(*arguments)

    def AddCustomList(self, ListArray=None, ByRow=None):
        arguments = com_arguments([unwrap(a) for a in [ListArray, ByRow]])
        self.com_object.AddCustomList(*arguments)

    def addcustomlist(self, ListArray=None, ByRow=None):
        """Alias for AddCustomList"""
        arguments = [ListArray, ByRow]
        return self.AddCustomList(*arguments)

    def add_custom_list(self, ListArray=None, ByRow=None):
        """Alias for AddCustomList"""
        arguments = [ListArray, ByRow]
        return self.AddCustomList(*arguments)

    def Calculate(self):
        self.com_object.Calculate()

    def calculate(self):
        """Alias for Calculate"""
        return self.Calculate()

    def CalculateFull(self):
        self.com_object.CalculateFull()

    def calculatefull(self):
        """Alias for CalculateFull"""
        return self.CalculateFull()

    def calculate_full(self):
        """Alias for CalculateFull"""
        return self.CalculateFull()

    def CalculateFullRebuild(self):
        self.com_object.CalculateFullRebuild()

    def calculatefullrebuild(self):
        """Alias for CalculateFullRebuild"""
        return self.CalculateFullRebuild()

    def calculate_full_rebuild(self):
        """Alias for CalculateFullRebuild"""
        return self.CalculateFullRebuild()

    def CalculateUntilAsyncQueriesDone(self):
        self.com_object.CalculateUntilAsyncQueriesDone()

    def calculateuntilasyncqueriesdone(self):
        """Alias for CalculateUntilAsyncQueriesDone"""
        return self.CalculateUntilAsyncQueriesDone()

    def calculate_until_async_queries_done(self):
        """Alias for CalculateUntilAsyncQueriesDone"""
        return self.CalculateUntilAsyncQueriesDone()

    def CentimetersToPoints(self, Centimeters=None):
        arguments = com_arguments([unwrap(a) for a in [Centimeters]])
        return self.com_object.CentimetersToPoints(*arguments)

    def centimeterstopoints(self, Centimeters=None):
        """Alias for CentimetersToPoints"""
        arguments = [Centimeters]
        return self.CentimetersToPoints(*arguments)

    def centimeters_to_points(self, Centimeters=None):
        """Alias for CentimetersToPoints"""
        arguments = [Centimeters]
        return self.CentimetersToPoints(*arguments)

    def CheckAbort(self, KeepAbort=None):
        arguments = com_arguments([unwrap(a) for a in [KeepAbort]])
        self.com_object.CheckAbort(*arguments)

    def checkabort(self, KeepAbort=None):
        """Alias for CheckAbort"""
        arguments = [KeepAbort]
        return self.CheckAbort(*arguments)

    def check_abort(self, KeepAbort=None):
        """Alias for CheckAbort"""
        arguments = [KeepAbort]
        return self.CheckAbort(*arguments)

    def CheckSpelling(self, Word=None, CustomDictionary=None, IgnoreUppercase=None):
        arguments = com_arguments([unwrap(a) for a in [Word, CustomDictionary, IgnoreUppercase]])
        return self.com_object.CheckSpelling(*arguments)

    def checkspelling(self, Word=None, CustomDictionary=None, IgnoreUppercase=None):
        """Alias for CheckSpelling"""
        arguments = [Word, CustomDictionary, IgnoreUppercase]
        return self.CheckSpelling(*arguments)

    def check_spelling(self, Word=None, CustomDictionary=None, IgnoreUppercase=None):
        """Alias for CheckSpelling"""
        arguments = [Word, CustomDictionary, IgnoreUppercase]
        return self.CheckSpelling(*arguments)

    def ConvertFormula(self, Formula=None, FromReferenceStyle=None, ToReferenceStyle=None, ToAbsolute=None, RelativeTo=None):
        arguments = com_arguments([unwrap(a) for a in [Formula, FromReferenceStyle, ToReferenceStyle, ToAbsolute, RelativeTo]])
        return self.com_object.ConvertFormula(*arguments)

    def convertformula(self, Formula=None, FromReferenceStyle=None, ToReferenceStyle=None, ToAbsolute=None, RelativeTo=None):
        """Alias for ConvertFormula"""
        arguments = [Formula, FromReferenceStyle, ToReferenceStyle, ToAbsolute, RelativeTo]
        return self.ConvertFormula(*arguments)

    def convert_formula(self, Formula=None, FromReferenceStyle=None, ToReferenceStyle=None, ToAbsolute=None, RelativeTo=None):
        """Alias for ConvertFormula"""
        arguments = [Formula, FromReferenceStyle, ToReferenceStyle, ToAbsolute, RelativeTo]
        return self.ConvertFormula(*arguments)

    def DDEExecute(self, Channel=None, String=None):
        arguments = com_arguments([unwrap(a) for a in [Channel, String]])
        self.com_object.DDEExecute(*arguments)

    def ddeexecute(self, Channel=None, String=None):
        """Alias for DDEExecute"""
        arguments = [Channel, String]
        return self.DDEExecute(*arguments)

    def d_d_e_execute(self, Channel=None, String=None):
        """Alias for DDEExecute"""
        arguments = [Channel, String]
        return self.DDEExecute(*arguments)

    def DDEInitiate(self, App=None, Topic=None):
        arguments = com_arguments([unwrap(a) for a in [App, Topic]])
        return self.com_object.DDEInitiate(*arguments)

    def ddeinitiate(self, App=None, Topic=None):
        """Alias for DDEInitiate"""
        arguments = [App, Topic]
        return self.DDEInitiate(*arguments)

    def d_d_e_initiate(self, App=None, Topic=None):
        """Alias for DDEInitiate"""
        arguments = [App, Topic]
        return self.DDEInitiate(*arguments)

    def DDEPoke(self, Channel=None, Item=None, Data=None):
        arguments = com_arguments([unwrap(a) for a in [Channel, Item, Data]])
        self.com_object.DDEPoke(*arguments)

    def ddepoke(self, Channel=None, Item=None, Data=None):
        """Alias for DDEPoke"""
        arguments = [Channel, Item, Data]
        return self.DDEPoke(*arguments)

    def d_d_e_poke(self, Channel=None, Item=None, Data=None):
        """Alias for DDEPoke"""
        arguments = [Channel, Item, Data]
        return self.DDEPoke(*arguments)

    def DDERequest(self, Channel=None, Item=None):
        arguments = com_arguments([unwrap(a) for a in [Channel, Item]])
        return self.com_object.DDERequest(*arguments)

    def dderequest(self, Channel=None, Item=None):
        """Alias for DDERequest"""
        arguments = [Channel, Item]
        return self.DDERequest(*arguments)

    def d_d_e_request(self, Channel=None, Item=None):
        """Alias for DDERequest"""
        arguments = [Channel, Item]
        return self.DDERequest(*arguments)

    def DDETerminate(self, Channel=None):
        arguments = com_arguments([unwrap(a) for a in [Channel]])
        self.com_object.DDETerminate(*arguments)

    def ddeterminate(self, Channel=None):
        """Alias for DDETerminate"""
        arguments = [Channel]
        return self.DDETerminate(*arguments)

    def d_d_e_terminate(self, Channel=None):
        """Alias for DDETerminate"""
        arguments = [Channel]
        return self.DDETerminate(*arguments)

    def DeleteCustomList(self, ListNum=None):
        arguments = com_arguments([unwrap(a) for a in [ListNum]])
        self.com_object.DeleteCustomList(*arguments)

    def deletecustomlist(self, ListNum=None):
        """Alias for DeleteCustomList"""
        arguments = [ListNum]
        return self.DeleteCustomList(*arguments)

    def delete_custom_list(self, ListNum=None):
        """Alias for DeleteCustomList"""
        arguments = [ListNum]
        return self.DeleteCustomList(*arguments)

    def DisplayXMLSourcePane(self, XmlMap=None):
        arguments = com_arguments([unwrap(a) for a in [XmlMap]])
        self.com_object.DisplayXMLSourcePane(*arguments)

    def displayxmlsourcepane(self, XmlMap=None):
        """Alias for DisplayXMLSourcePane"""
        arguments = [XmlMap]
        return self.DisplayXMLSourcePane(*arguments)

    def display_x_m_l_source_pane(self, XmlMap=None):
        """Alias for DisplayXMLSourcePane"""
        arguments = [XmlMap]
        return self.DisplayXMLSourcePane(*arguments)

    def DoubleClick(self):
        self.com_object.DoubleClick()

    def doubleclick(self):
        """Alias for DoubleClick"""
        return self.DoubleClick()

    def double_click(self):
        """Alias for DoubleClick"""
        return self.DoubleClick()

    def Evaluate(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        return self.com_object.Evaluate(*arguments)

    def evaluate(self, Name=None):
        """Alias for Evaluate"""
        arguments = [Name]
        return self.Evaluate(*arguments)

    def ExecuteExcel4Macro(self, String=None):
        arguments = com_arguments([unwrap(a) for a in [String]])
        return self.com_object.ExecuteExcel4Macro(*arguments)

    def executeexcel4macro(self, String=None):
        """Alias for ExecuteExcel4Macro"""
        arguments = [String]
        return self.ExecuteExcel4Macro(*arguments)

    def execute_excel4_macro(self, String=None):
        """Alias for ExecuteExcel4Macro"""
        arguments = [String]
        return self.ExecuteExcel4Macro(*arguments)

    def FindFile(self):
        return self.com_object.FindFile()

    def findfile(self):
        """Alias for FindFile"""
        return self.FindFile()

    def find_file(self):
        """Alias for FindFile"""
        return self.FindFile()

    def GetCustomListContents(self, ListNum=None):
        arguments = com_arguments([unwrap(a) for a in [ListNum]])
        return self.com_object.GetCustomListContents(*arguments)

    def getcustomlistcontents(self, ListNum=None):
        """Alias for GetCustomListContents"""
        arguments = [ListNum]
        return self.GetCustomListContents(*arguments)

    def get_custom_list_contents(self, ListNum=None):
        """Alias for GetCustomListContents"""
        arguments = [ListNum]
        return self.GetCustomListContents(*arguments)

    def GetCustomListNum(self, ListArray=None):
        arguments = com_arguments([unwrap(a) for a in [ListArray]])
        return self.com_object.GetCustomListNum(*arguments)

    def getcustomlistnum(self, ListArray=None):
        """Alias for GetCustomListNum"""
        arguments = [ListArray]
        return self.GetCustomListNum(*arguments)

    def get_custom_list_num(self, ListArray=None):
        """Alias for GetCustomListNum"""
        arguments = [ListArray]
        return self.GetCustomListNum(*arguments)

    def GetOpenFilename(self, FileFilter=None, FilterIndex=None, Title=None, ButtonText=None, MultiSelect=None):
        arguments = com_arguments([unwrap(a) for a in [FileFilter, FilterIndex, Title, ButtonText, MultiSelect]])
        return self.com_object.GetOpenFilename(*arguments)

    def getopenfilename(self, FileFilter=None, FilterIndex=None, Title=None, ButtonText=None, MultiSelect=None):
        """Alias for GetOpenFilename"""
        arguments = [FileFilter, FilterIndex, Title, ButtonText, MultiSelect]
        return self.GetOpenFilename(*arguments)

    def get_open_filename(self, FileFilter=None, FilterIndex=None, Title=None, ButtonText=None, MultiSelect=None):
        """Alias for GetOpenFilename"""
        arguments = [FileFilter, FilterIndex, Title, ButtonText, MultiSelect]
        return self.GetOpenFilename(*arguments)

    def GetPhonetic(self, Text=None):
        arguments = com_arguments([unwrap(a) for a in [Text]])
        return self.com_object.GetPhonetic(*arguments)

    def getphonetic(self, Text=None):
        """Alias for GetPhonetic"""
        arguments = [Text]
        return self.GetPhonetic(*arguments)

    def get_phonetic(self, Text=None):
        """Alias for GetPhonetic"""
        arguments = [Text]
        return self.GetPhonetic(*arguments)

    def GetSaveAsFilename(self, InitialFilename=None, FileFilter=None, FilterIndex=None, Title=None, ButtonText=None):
        arguments = com_arguments([unwrap(a) for a in [InitialFilename, FileFilter, FilterIndex, Title, ButtonText]])
        return self.com_object.GetSaveAsFilename(*arguments)

    def getsaveasfilename(self, InitialFilename=None, FileFilter=None, FilterIndex=None, Title=None, ButtonText=None):
        """Alias for GetSaveAsFilename"""
        arguments = [InitialFilename, FileFilter, FilterIndex, Title, ButtonText]
        return self.GetSaveAsFilename(*arguments)

    def get_save_as_filename(self, InitialFilename=None, FileFilter=None, FilterIndex=None, Title=None, ButtonText=None):
        """Alias for GetSaveAsFilename"""
        arguments = [InitialFilename, FileFilter, FilterIndex, Title, ButtonText]
        return self.GetSaveAsFilename(*arguments)

    def Goto(self, Reference=None, Scroll=None):
        arguments = com_arguments([unwrap(a) for a in [Reference, Scroll]])
        self.com_object.Goto(*arguments)

    def goto(self, Reference=None, Scroll=None):
        """Alias for Goto"""
        arguments = [Reference, Scroll]
        return self.Goto(*arguments)

    def Help(self, HelpFile=None, HelpContextID=None):
        arguments = com_arguments([unwrap(a) for a in [HelpFile, HelpContextID]])
        self.com_object.Help(*arguments)

    def help(self, HelpFile=None, HelpContextID=None):
        """Alias for Help"""
        arguments = [HelpFile, HelpContextID]
        return self.Help(*arguments)

    def InchesToPoints(self, Inches=None):
        arguments = com_arguments([unwrap(a) for a in [Inches]])
        return self.com_object.InchesToPoints(*arguments)

    def inchestopoints(self, Inches=None):
        """Alias for InchesToPoints"""
        arguments = [Inches]
        return self.InchesToPoints(*arguments)

    def inches_to_points(self, Inches=None):
        """Alias for InchesToPoints"""
        arguments = [Inches]
        return self.InchesToPoints(*arguments)

    def InputBox(self, Prompt=None, Title=None, Default=None, Left=None, Top=None, HelpFile=None, HelpContextID=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Prompt, Title, Default, Left, Top, HelpFile, HelpContextID, Type]])
        return self.com_object.InputBox(*arguments)

    def inputbox(self, Prompt=None, Title=None, Default=None, Left=None, Top=None, HelpFile=None, HelpContextID=None, Type=None):
        """Alias for InputBox"""
        arguments = [Prompt, Title, Default, Left, Top, HelpFile, HelpContextID, Type]
        return self.InputBox(*arguments)

    def input_box(self, Prompt=None, Title=None, Default=None, Left=None, Top=None, HelpFile=None, HelpContextID=None, Type=None):
        """Alias for InputBox"""
        arguments = [Prompt, Title, Default, Left, Top, HelpFile, HelpContextID, Type]
        return self.InputBox(*arguments)

    def Intersect(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return Range(self.com_object.Intersect(*arguments))

    def intersect(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Intersect"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Intersect(*arguments)

    def MacroOptions(self, Macro=None, Description=None, HasMenu=None, MenuText=None, HasShortcutKey=None, ShortcutKey=None, Category=None, StatusBar=None, HelpContextID=None, HelpFile=None, ArgumentDescriptions=None):
        arguments = com_arguments([unwrap(a) for a in [Macro, Description, HasMenu, MenuText, HasShortcutKey, ShortcutKey, Category, StatusBar, HelpContextID, HelpFile, ArgumentDescriptions]])
        self.com_object.MacroOptions(*arguments)

    def macrooptions(self, Macro=None, Description=None, HasMenu=None, MenuText=None, HasShortcutKey=None, ShortcutKey=None, Category=None, StatusBar=None, HelpContextID=None, HelpFile=None, ArgumentDescriptions=None):
        """Alias for MacroOptions"""
        arguments = [Macro, Description, HasMenu, MenuText, HasShortcutKey, ShortcutKey, Category, StatusBar, HelpContextID, HelpFile, ArgumentDescriptions]
        return self.MacroOptions(*arguments)

    def macro_options(self, Macro=None, Description=None, HasMenu=None, MenuText=None, HasShortcutKey=None, ShortcutKey=None, Category=None, StatusBar=None, HelpContextID=None, HelpFile=None, ArgumentDescriptions=None):
        """Alias for MacroOptions"""
        arguments = [Macro, Description, HasMenu, MenuText, HasShortcutKey, ShortcutKey, Category, StatusBar, HelpContextID, HelpFile, ArgumentDescriptions]
        return self.MacroOptions(*arguments)

    def MailLogoff(self):
        self.com_object.MailLogoff()

    def maillogoff(self):
        """Alias for MailLogoff"""
        return self.MailLogoff()

    def mail_logoff(self):
        """Alias for MailLogoff"""
        return self.MailLogoff()

    def MailLogon(self, Name=None, Password=None, DownloadNewMail=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Password, DownloadNewMail]])
        self.com_object.MailLogon(*arguments)

    def maillogon(self, Name=None, Password=None, DownloadNewMail=None):
        """Alias for MailLogon"""
        arguments = [Name, Password, DownloadNewMail]
        return self.MailLogon(*arguments)

    def mail_logon(self, Name=None, Password=None, DownloadNewMail=None):
        """Alias for MailLogon"""
        arguments = [Name, Password, DownloadNewMail]
        return self.MailLogon(*arguments)

    def NextLetter(self):
        return Workbook(self.com_object.NextLetter())

    def nextletter(self):
        """Alias for NextLetter"""
        return self.NextLetter()

    def next_letter(self):
        """Alias for NextLetter"""
        return self.NextLetter()

    def OnKey(self, Key=None, Procedure=None):
        arguments = com_arguments([unwrap(a) for a in [Key, Procedure]])
        self.com_object.OnKey(*arguments)

    def onkey(self, Key=None, Procedure=None):
        """Alias for OnKey"""
        arguments = [Key, Procedure]
        return self.OnKey(*arguments)

    def on_key(self, Key=None, Procedure=None):
        """Alias for OnKey"""
        arguments = [Key, Procedure]
        return self.OnKey(*arguments)

    def OnRepeat(self, Text=None, Procedure=None):
        arguments = com_arguments([unwrap(a) for a in [Text, Procedure]])
        self.com_object.OnRepeat(*arguments)

    def onrepeat(self, Text=None, Procedure=None):
        """Alias for OnRepeat"""
        arguments = [Text, Procedure]
        return self.OnRepeat(*arguments)

    def on_repeat(self, Text=None, Procedure=None):
        """Alias for OnRepeat"""
        arguments = [Text, Procedure]
        return self.OnRepeat(*arguments)

    def OnTime(self, EarliestTime=None, Procedure=None, LatestTime=None, Schedule=None):
        arguments = com_arguments([unwrap(a) for a in [EarliestTime, Procedure, LatestTime, Schedule]])
        self.com_object.OnTime(*arguments)

    def ontime(self, EarliestTime=None, Procedure=None, LatestTime=None, Schedule=None):
        """Alias for OnTime"""
        arguments = [EarliestTime, Procedure, LatestTime, Schedule]
        return self.OnTime(*arguments)

    def on_time(self, EarliestTime=None, Procedure=None, LatestTime=None, Schedule=None):
        """Alias for OnTime"""
        arguments = [EarliestTime, Procedure, LatestTime, Schedule]
        return self.OnTime(*arguments)

    def OnUndo(self, Text=None, Procedure=None):
        arguments = com_arguments([unwrap(a) for a in [Text, Procedure]])
        self.com_object.OnUndo(*arguments)

    def onundo(self, Text=None, Procedure=None):
        """Alias for OnUndo"""
        arguments = [Text, Procedure]
        return self.OnUndo(*arguments)

    def on_undo(self, Text=None, Procedure=None):
        """Alias for OnUndo"""
        arguments = [Text, Procedure]
        return self.OnUndo(*arguments)

    def Quit(self):
        self.com_object.Quit()

    def quit(self):
        """Alias for Quit"""
        return self.Quit()

    def RecordMacro(self, BasicCode=None, XlmCode=None):
        arguments = com_arguments([unwrap(a) for a in [BasicCode, XlmCode]])
        self.com_object.RecordMacro(*arguments)

    def recordmacro(self, BasicCode=None, XlmCode=None):
        """Alias for RecordMacro"""
        arguments = [BasicCode, XlmCode]
        return self.RecordMacro(*arguments)

    def record_macro(self, BasicCode=None, XlmCode=None):
        """Alias for RecordMacro"""
        arguments = [BasicCode, XlmCode]
        return self.RecordMacro(*arguments)

    def RegisterXLL(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        return self.com_object.RegisterXLL(*arguments)

    def registerxll(self, FileName=None):
        """Alias for RegisterXLL"""
        arguments = [FileName]
        return self.RegisterXLL(*arguments)

    def register_x_l_l(self, FileName=None):
        """Alias for RegisterXLL"""
        arguments = [FileName]
        return self.RegisterXLL(*arguments)

    def Repeat(self):
        self.com_object.Repeat()

    def repeat(self):
        """Alias for Repeat"""
        return self.Repeat()

    def Run(self, Macro=None, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Macro, Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Run(*arguments)

    def run(self, Macro=None, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Run"""
        arguments = [Macro, Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Run(*arguments)

    def SaveWorkspace(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        self.com_object.SaveWorkspace(*arguments)

    def saveworkspace(self, FileName=None):
        """Alias for SaveWorkspace"""
        arguments = [FileName]
        return self.SaveWorkspace(*arguments)

    def save_workspace(self, FileName=None):
        """Alias for SaveWorkspace"""
        arguments = [FileName]
        return self.SaveWorkspace(*arguments)

    def SendKeys(self, Keys=None, Wait=None):
        arguments = com_arguments([unwrap(a) for a in [Keys, Wait]])
        self.com_object.SendKeys(*arguments)

    def sendkeys(self, Keys=None, Wait=None):
        """Alias for SendKeys"""
        arguments = [Keys, Wait]
        return self.SendKeys(*arguments)

    def send_keys(self, Keys=None, Wait=None):
        """Alias for SendKeys"""
        arguments = [Keys, Wait]
        return self.SendKeys(*arguments)

    def SharePointVersion(self, bstrUrl=None):
        arguments = com_arguments([unwrap(a) for a in [bstrUrl]])
        return self.com_object.SharePointVersion(*arguments)

    def sharepointversion(self, bstrUrl=None):
        """Alias for SharePointVersion"""
        arguments = [bstrUrl]
        return self.SharePointVersion(*arguments)

    def share_point_version(self, bstrUrl=None):
        """Alias for SharePointVersion"""
        arguments = [bstrUrl]
        return self.SharePointVersion(*arguments)

    def Undo(self):
        self.com_object.Undo()

    def undo(self):
        """Alias for Undo"""
        return self.Undo()

    def Union(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return Range(self.com_object.Union(*arguments))

    def union(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Union"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Union(*arguments)

    def Volatile(self, Volatile=None):
        arguments = com_arguments([unwrap(a) for a in [Volatile]])
        self.com_object.Volatile(*arguments)

    def volatile(self, Volatile=None):
        """Alias for Volatile"""
        arguments = [Volatile]
        return self.Volatile(*arguments)

    def Wait(self, Time=None):
        arguments = com_arguments([unwrap(a) for a in [Time]])
        return self.com_object.Wait(*arguments)

    def wait(self, Time=None):
        """Alias for Wait"""
        arguments = [Time]
        return self.Wait(*arguments)


class Areas:

    def __init__(self, areas=None):
        self.com_object= areas

    def __call__(self, item):
        return Area(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class Author:

    def __init__(self, author=None):
        self.com_object= author

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ProviderID(self):
        return self.com_object.ProviderID

    @property
    def providerid(self):
        """Alias for ProviderID"""
        return self.ProviderID

    @property
    def provider_i_d(self):
        """Alias for ProviderID"""
        return self.ProviderID

    @property
    def UserID(self):
        return self.com_object.UserID

    @property
    def userid(self):
        """Alias for UserID"""
        return self.UserID

    @property
    def user_i_d(self):
        """Alias for UserID"""
        return self.UserID


class AutoCorrect:

    def __init__(self, autocorrect=None):
        self.com_object= autocorrect

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoExpandListRange(self):
        return self.com_object.AutoExpandListRange

    @AutoExpandListRange.setter
    def AutoExpandListRange(self, value):
        self.com_object.AutoExpandListRange = value

    @property
    def autoexpandlistrange(self):
        """Alias for AutoExpandListRange"""
        return self.AutoExpandListRange

    @autoexpandlistrange.setter
    def autoexpandlistrange(self, value):
        """Alias for AutoExpandListRange.setter"""
        self.AutoExpandListRange = value

    @property
    def auto_expand_list_range(self):
        """Alias for AutoExpandListRange"""
        return self.AutoExpandListRange

    @auto_expand_list_range.setter
    def auto_expand_list_range(self, value):
        """Alias for AutoExpandListRange.setter"""
        self.AutoExpandListRange = value

    @property
    def AutoFillFormulasInLists(self):
        return self.com_object.AutoFillFormulasInLists

    @AutoFillFormulasInLists.setter
    def AutoFillFormulasInLists(self, value):
        self.com_object.AutoFillFormulasInLists = value

    @property
    def autofillformulasinlists(self):
        """Alias for AutoFillFormulasInLists"""
        return self.AutoFillFormulasInLists

    @autofillformulasinlists.setter
    def autofillformulasinlists(self, value):
        """Alias for AutoFillFormulasInLists.setter"""
        self.AutoFillFormulasInLists = value

    @property
    def auto_fill_formulas_in_lists(self):
        """Alias for AutoFillFormulasInLists"""
        return self.AutoFillFormulasInLists

    @auto_fill_formulas_in_lists.setter
    def auto_fill_formulas_in_lists(self, value):
        """Alias for AutoFillFormulasInLists.setter"""
        self.AutoFillFormulasInLists = value

    @property
    def CapitalizeNamesOfDays(self):
        return self.com_object.CapitalizeNamesOfDays

    @CapitalizeNamesOfDays.setter
    def CapitalizeNamesOfDays(self, value):
        self.com_object.CapitalizeNamesOfDays = value

    @property
    def capitalizenamesofdays(self):
        """Alias for CapitalizeNamesOfDays"""
        return self.CapitalizeNamesOfDays

    @capitalizenamesofdays.setter
    def capitalizenamesofdays(self, value):
        """Alias for CapitalizeNamesOfDays.setter"""
        self.CapitalizeNamesOfDays = value

    @property
    def capitalize_names_of_days(self):
        """Alias for CapitalizeNamesOfDays"""
        return self.CapitalizeNamesOfDays

    @capitalize_names_of_days.setter
    def capitalize_names_of_days(self, value):
        """Alias for CapitalizeNamesOfDays.setter"""
        self.CapitalizeNamesOfDays = value

    @property
    def CorrectCapsLock(self):
        return self.com_object.CorrectCapsLock

    @CorrectCapsLock.setter
    def CorrectCapsLock(self, value):
        self.com_object.CorrectCapsLock = value

    @property
    def correctcapslock(self):
        """Alias for CorrectCapsLock"""
        return self.CorrectCapsLock

    @correctcapslock.setter
    def correctcapslock(self, value):
        """Alias for CorrectCapsLock.setter"""
        self.CorrectCapsLock = value

    @property
    def correct_caps_lock(self):
        """Alias for CorrectCapsLock"""
        return self.CorrectCapsLock

    @correct_caps_lock.setter
    def correct_caps_lock(self, value):
        """Alias for CorrectCapsLock.setter"""
        self.CorrectCapsLock = value

    @property
    def CorrectSentenceCap(self):
        return self.com_object.CorrectSentenceCap

    @CorrectSentenceCap.setter
    def CorrectSentenceCap(self, value):
        self.com_object.CorrectSentenceCap = value

    @property
    def correctsentencecap(self):
        """Alias for CorrectSentenceCap"""
        return self.CorrectSentenceCap

    @correctsentencecap.setter
    def correctsentencecap(self, value):
        """Alias for CorrectSentenceCap.setter"""
        self.CorrectSentenceCap = value

    @property
    def correct_sentence_cap(self):
        """Alias for CorrectSentenceCap"""
        return self.CorrectSentenceCap

    @correct_sentence_cap.setter
    def correct_sentence_cap(self, value):
        """Alias for CorrectSentenceCap.setter"""
        self.CorrectSentenceCap = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DisplayAutoCorrectOptions(self):
        return self.com_object.DisplayAutoCorrectOptions

    @DisplayAutoCorrectOptions.setter
    def DisplayAutoCorrectOptions(self, value):
        self.com_object.DisplayAutoCorrectOptions = value

    @property
    def displayautocorrectoptions(self):
        """Alias for DisplayAutoCorrectOptions"""
        return self.DisplayAutoCorrectOptions

    @displayautocorrectoptions.setter
    def displayautocorrectoptions(self, value):
        """Alias for DisplayAutoCorrectOptions.setter"""
        self.DisplayAutoCorrectOptions = value

    @property
    def display_auto_correct_options(self):
        """Alias for DisplayAutoCorrectOptions"""
        return self.DisplayAutoCorrectOptions

    @display_auto_correct_options.setter
    def display_auto_correct_options(self, value):
        """Alias for DisplayAutoCorrectOptions.setter"""
        self.DisplayAutoCorrectOptions = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def ReplacementList(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetReplacementList"):
            return self.com_object.GetReplacementList(*arguments)
        else:
            return self.com_object.ReplacementList(*arguments)

    def replacementlist(self, Index=None):
        """Alias for ReplacementList"""
        arguments = [Index]
        return self.ReplacementList(*arguments)

    def replacement_list(self, Index=None):
        """Alias for ReplacementList"""
        arguments = [Index]
        return self.ReplacementList(*arguments)

    @property
    def ReplaceText(self):
        return self.com_object.ReplaceText

    @ReplaceText.setter
    def ReplaceText(self, value):
        self.com_object.ReplaceText = value

    @property
    def replacetext(self):
        """Alias for ReplaceText"""
        return self.ReplaceText

    @replacetext.setter
    def replacetext(self, value):
        """Alias for ReplaceText.setter"""
        self.ReplaceText = value

    @property
    def replace_text(self):
        """Alias for ReplaceText"""
        return self.ReplaceText

    @replace_text.setter
    def replace_text(self, value):
        """Alias for ReplaceText.setter"""
        self.ReplaceText = value

    @property
    def TwoInitialCapitals(self):
        return self.com_object.TwoInitialCapitals

    @TwoInitialCapitals.setter
    def TwoInitialCapitals(self, value):
        self.com_object.TwoInitialCapitals = value

    @property
    def twoinitialcapitals(self):
        """Alias for TwoInitialCapitals"""
        return self.TwoInitialCapitals

    @twoinitialcapitals.setter
    def twoinitialcapitals(self, value):
        """Alias for TwoInitialCapitals.setter"""
        self.TwoInitialCapitals = value

    @property
    def two_initial_capitals(self):
        """Alias for TwoInitialCapitals"""
        return self.TwoInitialCapitals

    @two_initial_capitals.setter
    def two_initial_capitals(self, value):
        """Alias for TwoInitialCapitals.setter"""
        self.TwoInitialCapitals = value

    def AddReplacement(self, What=None, Replacement=None):
        arguments = com_arguments([unwrap(a) for a in [What, Replacement]])
        return self.com_object.AddReplacement(*arguments)

    def addreplacement(self, What=None, Replacement=None):
        """Alias for AddReplacement"""
        arguments = [What, Replacement]
        return self.AddReplacement(*arguments)

    def add_replacement(self, What=None, Replacement=None):
        """Alias for AddReplacement"""
        arguments = [What, Replacement]
        return self.AddReplacement(*arguments)

    def DeleteReplacement(self, What=None):
        arguments = com_arguments([unwrap(a) for a in [What]])
        return self.com_object.DeleteReplacement(*arguments)

    def deletereplacement(self, What=None):
        """Alias for DeleteReplacement"""
        arguments = [What]
        return self.DeleteReplacement(*arguments)

    def delete_replacement(self, What=None):
        """Alias for DeleteReplacement"""
        arguments = [What]
        return self.DeleteReplacement(*arguments)


class AutoFilter:

    def __init__(self, autofilter=None):
        self.com_object= autofilter

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def FilterMode(self):
        return self.com_object.FilterMode

    @property
    def filtermode(self):
        """Alias for FilterMode"""
        return self.FilterMode

    @property
    def filter_mode(self):
        """Alias for FilterMode"""
        return self.FilterMode

    @property
    def Filters(self):
        return Filters(self.com_object.Filters)

    @property
    def filters(self):
        """Alias for Filters"""
        return self.Filters

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def Sort(self):
        return self.com_object.Sort

    @property
    def sort(self):
        """Alias for Sort"""
        return self.Sort

    def ApplyFilter(self):
        self.com_object.ApplyFilter()

    def applyfilter(self):
        """Alias for ApplyFilter"""
        return self.ApplyFilter()

    def apply_filter(self):
        """Alias for ApplyFilter"""
        return self.ApplyFilter()

    def ShowAllData(self):
        self.com_object.ShowAllData()

    def showalldata(self):
        """Alias for ShowAllData"""
        return self.ShowAllData()

    def show_all_data(self):
        """Alias for ShowAllData"""
        return self.ShowAllData()


class AutoRecover:

    def __init__(self, autorecover=None):
        self.com_object= autorecover

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Path(self):
        return self.com_object.Path

    @Path.setter
    def Path(self, value):
        self.com_object.Path = value

    @property
    def path(self):
        """Alias for Path"""
        return self.Path

    @path.setter
    def path(self, value):
        """Alias for Path.setter"""
        self.Path = value

    @property
    def Time(self):
        return self.com_object.Time

    @Time.setter
    def Time(self, value):
        self.com_object.Time = value

    @property
    def time(self):
        """Alias for Time"""
        return self.Time

    @time.setter
    def time(self, value):
        """Alias for Time.setter"""
        self.Time = value


class Axes:

    def __init__(self, axes=None):
        self.com_object= axes

    def __call__(self, item):
        return Axe(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Type=None, AxisGroup=None):
        arguments = com_arguments([unwrap(a) for a in [Type, AxisGroup]])
        return Axis(self.com_object.Item(*arguments))

    def item(self, Type=None, AxisGroup=None):
        """Alias for Item"""
        arguments = [Type, AxisGroup]
        return self.Item(*arguments)


class Axis:

    def __init__(self, axis=None):
        self.com_object= axis

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AxisBetweenCategories(self):
        return self.com_object.AxisBetweenCategories

    @AxisBetweenCategories.setter
    def AxisBetweenCategories(self, value):
        self.com_object.AxisBetweenCategories = value

    @property
    def axisbetweencategories(self):
        """Alias for AxisBetweenCategories"""
        return self.AxisBetweenCategories

    @axisbetweencategories.setter
    def axisbetweencategories(self, value):
        """Alias for AxisBetweenCategories.setter"""
        self.AxisBetweenCategories = value

    @property
    def axis_between_categories(self):
        """Alias for AxisBetweenCategories"""
        return self.AxisBetweenCategories

    @axis_between_categories.setter
    def axis_between_categories(self, value):
        """Alias for AxisBetweenCategories.setter"""
        self.AxisBetweenCategories = value

    @property
    def AxisGroup(self):
        return self.com_object.AxisGroup

    @property
    def axisgroup(self):
        """Alias for AxisGroup"""
        return self.AxisGroup

    @property
    def axis_group(self):
        """Alias for AxisGroup"""
        return self.AxisGroup

    @property
    def AxisTitle(self):
        return AxisTitle(self.com_object.AxisTitle)

    @property
    def axistitle(self):
        """Alias for AxisTitle"""
        return self.AxisTitle

    @property
    def axis_title(self):
        """Alias for AxisTitle"""
        return self.AxisTitle

    @property
    def BaseUnit(self):
        return XlTimeUnit(self.com_object.BaseUnit)

    @BaseUnit.setter
    def BaseUnit(self, value):
        self.com_object.BaseUnit = value

    @property
    def baseunit(self):
        """Alias for BaseUnit"""
        return self.BaseUnit

    @baseunit.setter
    def baseunit(self, value):
        """Alias for BaseUnit.setter"""
        self.BaseUnit = value

    @property
    def base_unit(self):
        """Alias for BaseUnit"""
        return self.BaseUnit

    @base_unit.setter
    def base_unit(self, value):
        """Alias for BaseUnit.setter"""
        self.BaseUnit = value

    @property
    def BaseUnitIsAuto(self):
        return self.com_object.BaseUnitIsAuto

    @BaseUnitIsAuto.setter
    def BaseUnitIsAuto(self, value):
        self.com_object.BaseUnitIsAuto = value

    @property
    def baseunitisauto(self):
        """Alias for BaseUnitIsAuto"""
        return self.BaseUnitIsAuto

    @baseunitisauto.setter
    def baseunitisauto(self, value):
        """Alias for BaseUnitIsAuto.setter"""
        self.BaseUnitIsAuto = value

    @property
    def base_unit_is_auto(self):
        """Alias for BaseUnitIsAuto"""
        return self.BaseUnitIsAuto

    @base_unit_is_auto.setter
    def base_unit_is_auto(self, value):
        """Alias for BaseUnitIsAuto.setter"""
        self.BaseUnitIsAuto = value

    @property
    def Border(self):
        return Border(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def CategoryNames(self):
        return Range(self.com_object.CategoryNames)

    @CategoryNames.setter
    def CategoryNames(self, value):
        self.com_object.CategoryNames = value

    @property
    def categorynames(self):
        """Alias for CategoryNames"""
        return self.CategoryNames

    @categorynames.setter
    def categorynames(self, value):
        """Alias for CategoryNames.setter"""
        self.CategoryNames = value

    @property
    def category_names(self):
        """Alias for CategoryNames"""
        return self.CategoryNames

    @category_names.setter
    def category_names(self, value):
        """Alias for CategoryNames.setter"""
        self.CategoryNames = value

    @property
    def CategoryType(self):
        return XlCategoryType(self.com_object.CategoryType)

    @CategoryType.setter
    def CategoryType(self, value):
        self.com_object.CategoryType = value

    @property
    def categorytype(self):
        """Alias for CategoryType"""
        return self.CategoryType

    @categorytype.setter
    def categorytype(self, value):
        """Alias for CategoryType.setter"""
        self.CategoryType = value

    @property
    def category_type(self):
        """Alias for CategoryType"""
        return self.CategoryType

    @category_type.setter
    def category_type(self, value):
        """Alias for CategoryType.setter"""
        self.CategoryType = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Crosses(self):
        return self.com_object.Crosses

    @Crosses.setter
    def Crosses(self, value):
        self.com_object.Crosses = value

    @property
    def crosses(self):
        """Alias for Crosses"""
        return self.Crosses

    @crosses.setter
    def crosses(self, value):
        """Alias for Crosses.setter"""
        self.Crosses = value

    @property
    def CrossesAt(self):
        return self.com_object.CrossesAt

    @CrossesAt.setter
    def CrossesAt(self, value):
        self.com_object.CrossesAt = value

    @property
    def crossesat(self):
        """Alias for CrossesAt"""
        return self.CrossesAt

    @crossesat.setter
    def crossesat(self, value):
        """Alias for CrossesAt.setter"""
        self.CrossesAt = value

    @property
    def crosses_at(self):
        """Alias for CrossesAt"""
        return self.CrossesAt

    @crosses_at.setter
    def crosses_at(self, value):
        """Alias for CrossesAt.setter"""
        self.CrossesAt = value

    @property
    def DisplayUnit(self):
        return XlDisplayUnit(self.com_object.DisplayUnit)

    @DisplayUnit.setter
    def DisplayUnit(self, value):
        self.com_object.DisplayUnit = value

    @property
    def displayunit(self):
        """Alias for DisplayUnit"""
        return self.DisplayUnit

    @displayunit.setter
    def displayunit(self, value):
        """Alias for DisplayUnit.setter"""
        self.DisplayUnit = value

    @property
    def display_unit(self):
        """Alias for DisplayUnit"""
        return self.DisplayUnit

    @display_unit.setter
    def display_unit(self, value):
        """Alias for DisplayUnit.setter"""
        self.DisplayUnit = value

    @property
    def DisplayUnitCustom(self):
        return self.com_object.DisplayUnitCustom

    @DisplayUnitCustom.setter
    def DisplayUnitCustom(self, value):
        self.com_object.DisplayUnitCustom = value

    @property
    def displayunitcustom(self):
        """Alias for DisplayUnitCustom"""
        return self.DisplayUnitCustom

    @displayunitcustom.setter
    def displayunitcustom(self, value):
        """Alias for DisplayUnitCustom.setter"""
        self.DisplayUnitCustom = value

    @property
    def display_unit_custom(self):
        """Alias for DisplayUnitCustom"""
        return self.DisplayUnitCustom

    @display_unit_custom.setter
    def display_unit_custom(self, value):
        """Alias for DisplayUnitCustom.setter"""
        self.DisplayUnitCustom = value

    @property
    def DisplayUnitLabel(self):
        return DisplayUnitLabel(self.com_object.DisplayUnitLabel)

    @property
    def displayunitlabel(self):
        """Alias for DisplayUnitLabel"""
        return self.DisplayUnitLabel

    @property
    def display_unit_label(self):
        """Alias for DisplayUnitLabel"""
        return self.DisplayUnitLabel

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def HasDisplayUnitLabel(self):
        return self.com_object.HasDisplayUnitLabel

    @HasDisplayUnitLabel.setter
    def HasDisplayUnitLabel(self, value):
        self.com_object.HasDisplayUnitLabel = value

    @property
    def hasdisplayunitlabel(self):
        """Alias for HasDisplayUnitLabel"""
        return self.HasDisplayUnitLabel

    @hasdisplayunitlabel.setter
    def hasdisplayunitlabel(self, value):
        """Alias for HasDisplayUnitLabel.setter"""
        self.HasDisplayUnitLabel = value

    @property
    def has_display_unit_label(self):
        """Alias for HasDisplayUnitLabel"""
        return self.HasDisplayUnitLabel

    @has_display_unit_label.setter
    def has_display_unit_label(self, value):
        """Alias for HasDisplayUnitLabel.setter"""
        self.HasDisplayUnitLabel = value

    @property
    def HasMajorGridlines(self):
        return self.com_object.HasMajorGridlines

    @HasMajorGridlines.setter
    def HasMajorGridlines(self, value):
        self.com_object.HasMajorGridlines = value

    @property
    def hasmajorgridlines(self):
        """Alias for HasMajorGridlines"""
        return self.HasMajorGridlines

    @hasmajorgridlines.setter
    def hasmajorgridlines(self, value):
        """Alias for HasMajorGridlines.setter"""
        self.HasMajorGridlines = value

    @property
    def has_major_gridlines(self):
        """Alias for HasMajorGridlines"""
        return self.HasMajorGridlines

    @has_major_gridlines.setter
    def has_major_gridlines(self, value):
        """Alias for HasMajorGridlines.setter"""
        self.HasMajorGridlines = value

    @property
    def HasMinorGridlines(self):
        return self.com_object.HasMinorGridlines

    @HasMinorGridlines.setter
    def HasMinorGridlines(self, value):
        self.com_object.HasMinorGridlines = value

    @property
    def hasminorgridlines(self):
        """Alias for HasMinorGridlines"""
        return self.HasMinorGridlines

    @hasminorgridlines.setter
    def hasminorgridlines(self, value):
        """Alias for HasMinorGridlines.setter"""
        self.HasMinorGridlines = value

    @property
    def has_minor_gridlines(self):
        """Alias for HasMinorGridlines"""
        return self.HasMinorGridlines

    @has_minor_gridlines.setter
    def has_minor_gridlines(self, value):
        """Alias for HasMinorGridlines.setter"""
        self.HasMinorGridlines = value

    @property
    def HasTitle(self):
        return self.com_object.HasTitle

    @HasTitle.setter
    def HasTitle(self, value):
        self.com_object.HasTitle = value

    @property
    def hastitle(self):
        """Alias for HasTitle"""
        return self.HasTitle

    @hastitle.setter
    def hastitle(self, value):
        """Alias for HasTitle.setter"""
        self.HasTitle = value

    @property
    def has_title(self):
        """Alias for HasTitle"""
        return self.HasTitle

    @has_title.setter
    def has_title(self, value):
        """Alias for HasTitle.setter"""
        self.HasTitle = value

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def Left(self):
        return self.com_object.Left

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @property
    def LogBase(self):
        return self.com_object.LogBase

    @LogBase.setter
    def LogBase(self, value):
        self.com_object.LogBase = value

    @property
    def logbase(self):
        """Alias for LogBase"""
        return self.LogBase

    @logbase.setter
    def logbase(self, value):
        """Alias for LogBase.setter"""
        self.LogBase = value

    @property
    def log_base(self):
        """Alias for LogBase"""
        return self.LogBase

    @log_base.setter
    def log_base(self, value):
        """Alias for LogBase.setter"""
        self.LogBase = value

    @property
    def MajorGridlines(self):
        return Gridlines(self.com_object.MajorGridlines)

    @property
    def majorgridlines(self):
        """Alias for MajorGridlines"""
        return self.MajorGridlines

    @property
    def major_gridlines(self):
        """Alias for MajorGridlines"""
        return self.MajorGridlines

    @property
    def MajorTickMark(self):
        return XlTickMark(self.com_object.MajorTickMark)

    @MajorTickMark.setter
    def MajorTickMark(self, value):
        self.com_object.MajorTickMark = value

    @property
    def majortickmark(self):
        """Alias for MajorTickMark"""
        return self.MajorTickMark

    @majortickmark.setter
    def majortickmark(self, value):
        """Alias for MajorTickMark.setter"""
        self.MajorTickMark = value

    @property
    def major_tick_mark(self):
        """Alias for MajorTickMark"""
        return self.MajorTickMark

    @major_tick_mark.setter
    def major_tick_mark(self, value):
        """Alias for MajorTickMark.setter"""
        self.MajorTickMark = value

    @property
    def MajorUnit(self):
        return self.com_object.MajorUnit

    @MajorUnit.setter
    def MajorUnit(self, value):
        self.com_object.MajorUnit = value

    @property
    def majorunit(self):
        """Alias for MajorUnit"""
        return self.MajorUnit

    @majorunit.setter
    def majorunit(self, value):
        """Alias for MajorUnit.setter"""
        self.MajorUnit = value

    @property
    def major_unit(self):
        """Alias for MajorUnit"""
        return self.MajorUnit

    @major_unit.setter
    def major_unit(self, value):
        """Alias for MajorUnit.setter"""
        self.MajorUnit = value

    @property
    def MajorUnitIsAuto(self):
        return self.com_object.MajorUnitIsAuto

    @MajorUnitIsAuto.setter
    def MajorUnitIsAuto(self, value):
        self.com_object.MajorUnitIsAuto = value

    @property
    def majorunitisauto(self):
        """Alias for MajorUnitIsAuto"""
        return self.MajorUnitIsAuto

    @majorunitisauto.setter
    def majorunitisauto(self, value):
        """Alias for MajorUnitIsAuto.setter"""
        self.MajorUnitIsAuto = value

    @property
    def major_unit_is_auto(self):
        """Alias for MajorUnitIsAuto"""
        return self.MajorUnitIsAuto

    @major_unit_is_auto.setter
    def major_unit_is_auto(self, value):
        """Alias for MajorUnitIsAuto.setter"""
        self.MajorUnitIsAuto = value

    @property
    def MajorUnitScale(self):
        return CategoryType(self.com_object.MajorUnitScale)

    @MajorUnitScale.setter
    def MajorUnitScale(self, value):
        self.com_object.MajorUnitScale = value

    @property
    def majorunitscale(self):
        """Alias for MajorUnitScale"""
        return self.MajorUnitScale

    @majorunitscale.setter
    def majorunitscale(self, value):
        """Alias for MajorUnitScale.setter"""
        self.MajorUnitScale = value

    @property
    def major_unit_scale(self):
        """Alias for MajorUnitScale"""
        return self.MajorUnitScale

    @major_unit_scale.setter
    def major_unit_scale(self, value):
        """Alias for MajorUnitScale.setter"""
        self.MajorUnitScale = value

    @property
    def MaximumScale(self):
        return self.com_object.MaximumScale

    @MaximumScale.setter
    def MaximumScale(self, value):
        self.com_object.MaximumScale = value

    @property
    def maximumscale(self):
        """Alias for MaximumScale"""
        return self.MaximumScale

    @maximumscale.setter
    def maximumscale(self, value):
        """Alias for MaximumScale.setter"""
        self.MaximumScale = value

    @property
    def maximum_scale(self):
        """Alias for MaximumScale"""
        return self.MaximumScale

    @maximum_scale.setter
    def maximum_scale(self, value):
        """Alias for MaximumScale.setter"""
        self.MaximumScale = value

    @property
    def MaximumScaleIsAuto(self):
        return self.com_object.MaximumScaleIsAuto

    @MaximumScaleIsAuto.setter
    def MaximumScaleIsAuto(self, value):
        self.com_object.MaximumScaleIsAuto = value

    @property
    def maximumscaleisauto(self):
        """Alias for MaximumScaleIsAuto"""
        return self.MaximumScaleIsAuto

    @maximumscaleisauto.setter
    def maximumscaleisauto(self, value):
        """Alias for MaximumScaleIsAuto.setter"""
        self.MaximumScaleIsAuto = value

    @property
    def maximum_scale_is_auto(self):
        """Alias for MaximumScaleIsAuto"""
        return self.MaximumScaleIsAuto

    @maximum_scale_is_auto.setter
    def maximum_scale_is_auto(self, value):
        """Alias for MaximumScaleIsAuto.setter"""
        self.MaximumScaleIsAuto = value

    @property
    def MinimumScale(self):
        return self.com_object.MinimumScale

    @MinimumScale.setter
    def MinimumScale(self, value):
        self.com_object.MinimumScale = value

    @property
    def minimumscale(self):
        """Alias for MinimumScale"""
        return self.MinimumScale

    @minimumscale.setter
    def minimumscale(self, value):
        """Alias for MinimumScale.setter"""
        self.MinimumScale = value

    @property
    def minimum_scale(self):
        """Alias for MinimumScale"""
        return self.MinimumScale

    @minimum_scale.setter
    def minimum_scale(self, value):
        """Alias for MinimumScale.setter"""
        self.MinimumScale = value

    @property
    def MinimumScaleIsAuto(self):
        return self.com_object.MinimumScaleIsAuto

    @MinimumScaleIsAuto.setter
    def MinimumScaleIsAuto(self, value):
        self.com_object.MinimumScaleIsAuto = value

    @property
    def minimumscaleisauto(self):
        """Alias for MinimumScaleIsAuto"""
        return self.MinimumScaleIsAuto

    @minimumscaleisauto.setter
    def minimumscaleisauto(self, value):
        """Alias for MinimumScaleIsAuto.setter"""
        self.MinimumScaleIsAuto = value

    @property
    def minimum_scale_is_auto(self):
        """Alias for MinimumScaleIsAuto"""
        return self.MinimumScaleIsAuto

    @minimum_scale_is_auto.setter
    def minimum_scale_is_auto(self, value):
        """Alias for MinimumScaleIsAuto.setter"""
        self.MinimumScaleIsAuto = value

    @property
    def MinorGridlines(self):
        return Gridlines(self.com_object.MinorGridlines)

    @property
    def minorgridlines(self):
        """Alias for MinorGridlines"""
        return self.MinorGridlines

    @property
    def minor_gridlines(self):
        """Alias for MinorGridlines"""
        return self.MinorGridlines

    @property
    def MinorTickMark(self):
        return XlTickMark(self.com_object.MinorTickMark)

    @MinorTickMark.setter
    def MinorTickMark(self, value):
        self.com_object.MinorTickMark = value

    @property
    def minortickmark(self):
        """Alias for MinorTickMark"""
        return self.MinorTickMark

    @minortickmark.setter
    def minortickmark(self, value):
        """Alias for MinorTickMark.setter"""
        self.MinorTickMark = value

    @property
    def minor_tick_mark(self):
        """Alias for MinorTickMark"""
        return self.MinorTickMark

    @minor_tick_mark.setter
    def minor_tick_mark(self, value):
        """Alias for MinorTickMark.setter"""
        self.MinorTickMark = value

    @property
    def MinorUnit(self):
        return self.com_object.MinorUnit

    @MinorUnit.setter
    def MinorUnit(self, value):
        self.com_object.MinorUnit = value

    @property
    def minorunit(self):
        """Alias for MinorUnit"""
        return self.MinorUnit

    @minorunit.setter
    def minorunit(self, value):
        """Alias for MinorUnit.setter"""
        self.MinorUnit = value

    @property
    def minor_unit(self):
        """Alias for MinorUnit"""
        return self.MinorUnit

    @minor_unit.setter
    def minor_unit(self, value):
        """Alias for MinorUnit.setter"""
        self.MinorUnit = value

    @property
    def MinorUnitIsAuto(self):
        return self.com_object.MinorUnitIsAuto

    @MinorUnitIsAuto.setter
    def MinorUnitIsAuto(self, value):
        self.com_object.MinorUnitIsAuto = value

    @property
    def minorunitisauto(self):
        """Alias for MinorUnitIsAuto"""
        return self.MinorUnitIsAuto

    @minorunitisauto.setter
    def minorunitisauto(self, value):
        """Alias for MinorUnitIsAuto.setter"""
        self.MinorUnitIsAuto = value

    @property
    def minor_unit_is_auto(self):
        """Alias for MinorUnitIsAuto"""
        return self.MinorUnitIsAuto

    @minor_unit_is_auto.setter
    def minor_unit_is_auto(self, value):
        """Alias for MinorUnitIsAuto.setter"""
        self.MinorUnitIsAuto = value

    @property
    def MinorUnitScale(self):
        return CategoryType(self.com_object.MinorUnitScale)

    @MinorUnitScale.setter
    def MinorUnitScale(self, value):
        self.com_object.MinorUnitScale = value

    @property
    def minorunitscale(self):
        """Alias for MinorUnitScale"""
        return self.MinorUnitScale

    @minorunitscale.setter
    def minorunitscale(self, value):
        """Alias for MinorUnitScale.setter"""
        self.MinorUnitScale = value

    @property
    def minor_unit_scale(self):
        """Alias for MinorUnitScale"""
        return self.MinorUnitScale

    @minor_unit_scale.setter
    def minor_unit_scale(self, value):
        """Alias for MinorUnitScale.setter"""
        self.MinorUnitScale = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ReversePlotOrder(self):
        return self.com_object.ReversePlotOrder

    @ReversePlotOrder.setter
    def ReversePlotOrder(self, value):
        self.com_object.ReversePlotOrder = value

    @property
    def reverseplotorder(self):
        """Alias for ReversePlotOrder"""
        return self.ReversePlotOrder

    @reverseplotorder.setter
    def reverseplotorder(self, value):
        """Alias for ReversePlotOrder.setter"""
        self.ReversePlotOrder = value

    @property
    def reverse_plot_order(self):
        """Alias for ReversePlotOrder"""
        return self.ReversePlotOrder

    @reverse_plot_order.setter
    def reverse_plot_order(self, value):
        """Alias for ReversePlotOrder.setter"""
        self.ReversePlotOrder = value

    @property
    def ScaleType(self):
        return XlScaleType(self.com_object.ScaleType)

    @ScaleType.setter
    def ScaleType(self, value):
        self.com_object.ScaleType = value

    @property
    def scaletype(self):
        """Alias for ScaleType"""
        return self.ScaleType

    @scaletype.setter
    def scaletype(self, value):
        """Alias for ScaleType.setter"""
        self.ScaleType = value

    @property
    def scale_type(self):
        """Alias for ScaleType"""
        return self.ScaleType

    @scale_type.setter
    def scale_type(self, value):
        """Alias for ScaleType.setter"""
        self.ScaleType = value

    @property
    def TickLabelPosition(self):
        return self.com_object.TickLabelPosition

    @TickLabelPosition.setter
    def TickLabelPosition(self, value):
        self.com_object.TickLabelPosition = value

    @property
    def ticklabelposition(self):
        """Alias for TickLabelPosition"""
        return self.TickLabelPosition

    @ticklabelposition.setter
    def ticklabelposition(self, value):
        """Alias for TickLabelPosition.setter"""
        self.TickLabelPosition = value

    @property
    def tick_label_position(self):
        """Alias for TickLabelPosition"""
        return self.TickLabelPosition

    @tick_label_position.setter
    def tick_label_position(self, value):
        """Alias for TickLabelPosition.setter"""
        self.TickLabelPosition = value

    @property
    def TickLabels(self):
        return TickLabels(self.com_object.TickLabels)

    @property
    def ticklabels(self):
        """Alias for TickLabels"""
        return self.TickLabels

    @property
    def tick_labels(self):
        """Alias for TickLabels"""
        return self.TickLabels

    @property
    def TickLabelSpacing(self):
        return self.com_object.TickLabelSpacing

    @TickLabelSpacing.setter
    def TickLabelSpacing(self, value):
        self.com_object.TickLabelSpacing = value

    @property
    def ticklabelspacing(self):
        """Alias for TickLabelSpacing"""
        return self.TickLabelSpacing

    @ticklabelspacing.setter
    def ticklabelspacing(self, value):
        """Alias for TickLabelSpacing.setter"""
        self.TickLabelSpacing = value

    @property
    def tick_label_spacing(self):
        """Alias for TickLabelSpacing"""
        return self.TickLabelSpacing

    @tick_label_spacing.setter
    def tick_label_spacing(self, value):
        """Alias for TickLabelSpacing.setter"""
        self.TickLabelSpacing = value

    @property
    def TickLabelSpacingIsAuto(self):
        return self.com_object.TickLabelSpacingIsAuto

    @TickLabelSpacingIsAuto.setter
    def TickLabelSpacingIsAuto(self, value):
        self.com_object.TickLabelSpacingIsAuto = value

    @property
    def ticklabelspacingisauto(self):
        """Alias for TickLabelSpacingIsAuto"""
        return self.TickLabelSpacingIsAuto

    @ticklabelspacingisauto.setter
    def ticklabelspacingisauto(self, value):
        """Alias for TickLabelSpacingIsAuto.setter"""
        self.TickLabelSpacingIsAuto = value

    @property
    def tick_label_spacing_is_auto(self):
        """Alias for TickLabelSpacingIsAuto"""
        return self.TickLabelSpacingIsAuto

    @tick_label_spacing_is_auto.setter
    def tick_label_spacing_is_auto(self, value):
        """Alias for TickLabelSpacingIsAuto.setter"""
        self.TickLabelSpacingIsAuto = value

    @property
    def TickMarkSpacing(self):
        return self.com_object.TickMarkSpacing

    @TickMarkSpacing.setter
    def TickMarkSpacing(self, value):
        self.com_object.TickMarkSpacing = value

    @property
    def tickmarkspacing(self):
        """Alias for TickMarkSpacing"""
        return self.TickMarkSpacing

    @tickmarkspacing.setter
    def tickmarkspacing(self, value):
        """Alias for TickMarkSpacing.setter"""
        self.TickMarkSpacing = value

    @property
    def tick_mark_spacing(self):
        """Alias for TickMarkSpacing"""
        return self.TickMarkSpacing

    @tick_mark_spacing.setter
    def tick_mark_spacing(self, value):
        """Alias for TickMarkSpacing.setter"""
        self.TickMarkSpacing = value

    @property
    def Top(self):
        return self.com_object.Top

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @property
    def Type(self):
        return XlAxisType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        return self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class AxisTitle:

    def __init__(self, axistitle=None):
        self.com_object= axistitle

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    def Characters(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        if hasattr(self.com_object, "GetCharacters"):
            return Characters(self.com_object.GetCharacters(*arguments))
        else:
            return Characters(self.com_object.Characters(*arguments))

    def characters(self, Start=None, Length=None):
        """Alias for Characters"""
        arguments = [Start, Length]
        return self.Characters(*arguments)

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def FormulaLocal(self):
        return self.com_object.FormulaLocal

    @FormulaLocal.setter
    def FormulaLocal(self, value):
        self.com_object.FormulaLocal = value

    @property
    def formulalocal(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formulalocal.setter
    def formulalocal(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def formula_local(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formula_local.setter
    def formula_local(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def FormulaR1C1(self):
        return self.com_object.FormulaR1C1

    @FormulaR1C1.setter
    def FormulaR1C1(self, value):
        self.com_object.FormulaR1C1 = value

    @property
    def formular1c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formular1c1.setter
    def formular1c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def formula_r1_c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formula_r1_c1.setter
    def formula_r1_c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def FormulaR1C1Local(self):
        return self.com_object.FormulaR1C1Local

    @FormulaR1C1Local.setter
    def FormulaR1C1Local(self, value):
        self.com_object.FormulaR1C1Local = value

    @property
    def formular1c1local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formular1c1local.setter
    def formular1c1local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def formula_r1_c1_local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formula_r1_c1_local.setter
    def formula_r1_c1_local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def HorizontalAlignment(self):
        return self.com_object.HorizontalAlignment

    @HorizontalAlignment.setter
    def HorizontalAlignment(self, value):
        self.com_object.HorizontalAlignment = value

    @property
    def horizontalalignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontalalignment.setter
    def horizontalalignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def horizontal_alignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def IncludeInLayout(self):
        return self.com_object.IncludeInLayout

    @IncludeInLayout.setter
    def IncludeInLayout(self, value):
        self.com_object.IncludeInLayout = value

    @property
    def includeinlayout(self):
        """Alias for IncludeInLayout"""
        return self.IncludeInLayout

    @includeinlayout.setter
    def includeinlayout(self, value):
        """Alias for IncludeInLayout.setter"""
        self.IncludeInLayout = value

    @property
    def include_in_layout(self):
        """Alias for IncludeInLayout"""
        return self.IncludeInLayout

    @include_in_layout.setter
    def include_in_layout(self, value):
        """Alias for IncludeInLayout.setter"""
        self.IncludeInLayout = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return XlChartElementPosition(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def ReadingOrder(self):
        return self.com_object.ReadingOrder

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def VerticalAlignment(self):
        return self.com_object.VerticalAlignment

    @VerticalAlignment.setter
    def VerticalAlignment(self, value):
        self.com_object.VerticalAlignment = value

    @property
    def verticalalignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @verticalalignment.setter
    def verticalalignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def vertical_alignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @vertical_alignment.setter
    def vertical_alignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        return self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Border:

    def __init__(self, border=None):
        self.com_object= border

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Color(self):
        return RGB(self.com_object.Color)

    @Color.setter
    def Color(self, value):
        self.com_object.Color = value

    @property
    def color(self):
        """Alias for Color"""
        return self.Color

    @color.setter
    def color(self, value):
        """Alias for Color.setter"""
        self.Color = value

    @property
    def ColorIndex(self):
        return self.com_object.ColorIndex

    @ColorIndex.setter
    def ColorIndex(self, value):
        self.com_object.ColorIndex = value

    @property
    def colorindex(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @colorindex.setter
    def colorindex(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def color_index(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @color_index.setter
    def color_index(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def LineStyle(self):
        return XlLineStyle(self.com_object.LineStyle)

    @LineStyle.setter
    def LineStyle(self, value):
        self.com_object.LineStyle = value

    @property
    def linestyle(self):
        """Alias for LineStyle"""
        return self.LineStyle

    @linestyle.setter
    def linestyle(self, value):
        """Alias for LineStyle.setter"""
        self.LineStyle = value

    @property
    def line_style(self):
        """Alias for LineStyle"""
        return self.LineStyle

    @line_style.setter
    def line_style(self, value):
        """Alias for LineStyle.setter"""
        self.LineStyle = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ThemeColor(self):
        return self.com_object.ThemeColor

    @ThemeColor.setter
    def ThemeColor(self, value):
        self.com_object.ThemeColor = value

    @property
    def themecolor(self):
        """Alias for ThemeColor"""
        return self.ThemeColor

    @themecolor.setter
    def themecolor(self, value):
        """Alias for ThemeColor.setter"""
        self.ThemeColor = value

    @property
    def theme_color(self):
        """Alias for ThemeColor"""
        return self.ThemeColor

    @theme_color.setter
    def theme_color(self, value):
        """Alias for ThemeColor.setter"""
        self.ThemeColor = value

    @property
    def TintAndShade(self):
        return self.com_object.TintAndShade

    @TintAndShade.setter
    def TintAndShade(self, value):
        self.com_object.TintAndShade = value

    @property
    def tintandshade(self):
        """Alias for TintAndShade"""
        return self.TintAndShade

    @tintandshade.setter
    def tintandshade(self, value):
        """Alias for TintAndShade.setter"""
        self.TintAndShade = value

    @property
    def tint_and_shade(self):
        """Alias for TintAndShade"""
        return self.TintAndShade

    @tint_and_shade.setter
    def tint_and_shade(self, value):
        """Alias for TintAndShade.setter"""
        self.TintAndShade = value

    @property
    def Weight(self):
        return XlBorderWeight(self.com_object.Weight)

    @Weight.setter
    def Weight(self, value):
        self.com_object.Weight = value

    @property
    def weight(self):
        """Alias for Weight"""
        return self.Weight

    @weight.setter
    def weight(self, value):
        """Alias for Weight.setter"""
        self.Weight = value


class Borders:

    def __init__(self, borders=None):
        self.com_object= borders

    def __call__(self, item):
        return Border(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Color(self):
        return RGB(self.com_object.Color)

    @Color.setter
    def Color(self, value):
        self.com_object.Color = value

    @property
    def color(self):
        """Alias for Color"""
        return self.Color

    @color.setter
    def color(self, value):
        """Alias for Color.setter"""
        self.Color = value

    @property
    def ColorIndex(self):
        return self.com_object.ColorIndex

    @ColorIndex.setter
    def ColorIndex(self, value):
        self.com_object.ColorIndex = value

    @property
    def colorindex(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @colorindex.setter
    def colorindex(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def color_index(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @color_index.setter
    def color_index(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return Border(self.com_object.GetItem(*arguments))
        else:
            return Border(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def LineStyle(self):
        return XlLineStyle(self.com_object.LineStyle)

    @LineStyle.setter
    def LineStyle(self, value):
        self.com_object.LineStyle = value

    @property
    def linestyle(self):
        """Alias for LineStyle"""
        return self.LineStyle

    @linestyle.setter
    def linestyle(self, value):
        """Alias for LineStyle.setter"""
        self.LineStyle = value

    @property
    def line_style(self):
        """Alias for LineStyle"""
        return self.LineStyle

    @line_style.setter
    def line_style(self, value):
        """Alias for LineStyle.setter"""
        self.LineStyle = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ThemeColor(self):
        return self.com_object.ThemeColor

    @ThemeColor.setter
    def ThemeColor(self, value):
        self.com_object.ThemeColor = value

    @property
    def themecolor(self):
        """Alias for ThemeColor"""
        return self.ThemeColor

    @themecolor.setter
    def themecolor(self, value):
        """Alias for ThemeColor.setter"""
        self.ThemeColor = value

    @property
    def theme_color(self):
        """Alias for ThemeColor"""
        return self.ThemeColor

    @theme_color.setter
    def theme_color(self, value):
        """Alias for ThemeColor.setter"""
        self.ThemeColor = value

    @property
    def TintAndShade(self):
        return self.com_object.TintAndShade

    @TintAndShade.setter
    def TintAndShade(self, value):
        self.com_object.TintAndShade = value

    @property
    def tintandshade(self):
        """Alias for TintAndShade"""
        return self.TintAndShade

    @tintandshade.setter
    def tintandshade(self, value):
        """Alias for TintAndShade.setter"""
        self.TintAndShade = value

    @property
    def tint_and_shade(self):
        """Alias for TintAndShade"""
        return self.TintAndShade

    @tint_and_shade.setter
    def tint_and_shade(self, value):
        """Alias for TintAndShade.setter"""
        self.TintAndShade = value

    @property
    def Value(self):
        return self.com_object.Value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @property
    def Weight(self):
        return XlBorderWeight(self.com_object.Weight)

    @Weight.setter
    def Weight(self, value):
        self.com_object.Weight = value

    @property
    def weight(self):
        """Alias for Weight"""
        return self.Weight

    @weight.setter
    def weight(self, value):
        """Alias for Weight.setter"""
        self.Weight = value


class CalculatedFields:

    def __init__(self, calculatedfields=None):
        self.com_object= calculatedfields

    def __call__(self, item):
        return CalculatedField(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, Formula=None, UseStandardFormula=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Formula, UseStandardFormula]])
        return PivotField(self.com_object.Add(*arguments))

    def add(self, Name=None, Formula=None, UseStandardFormula=None):
        """Alias for Add"""
        arguments = [Name, Formula, UseStandardFormula]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return PivotField(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class CalculatedItems:

    def __init__(self, calculateditems=None):
        self.com_object= calculateditems

    def __call__(self, item):
        return CalculatedItem(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, Formula=None, UseStandardFormula=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Formula, UseStandardFormula]])
        return PivotItem(self.com_object.Add(*arguments))

    def add(self, Name=None, Formula=None, UseStandardFormula=None):
        """Alias for Add"""
        arguments = [Name, Formula, UseStandardFormula]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return PivotItem(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class CalculatedMember:

    def __init__(self, calculatedmember=None):
        self.com_object= calculatedmember

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DisplayFolder(self):
        return self.com_object.DisplayFolder

    @property
    def displayfolder(self):
        """Alias for DisplayFolder"""
        return self.DisplayFolder

    @property
    def display_folder(self):
        """Alias for DisplayFolder"""
        return self.DisplayFolder

    @property
    def Dynamic(self):
        return self.com_object.Dynamic

    @property
    def dynamic(self):
        """Alias for Dynamic"""
        return self.Dynamic

    @property
    def FlattenHierarchies(self):
        return self.com_object.FlattenHierarchies

    @FlattenHierarchies.setter
    def FlattenHierarchies(self, value):
        self.com_object.FlattenHierarchies = value

    @property
    def flattenhierarchies(self):
        """Alias for FlattenHierarchies"""
        return self.FlattenHierarchies

    @flattenhierarchies.setter
    def flattenhierarchies(self, value):
        """Alias for FlattenHierarchies.setter"""
        self.FlattenHierarchies = value

    @property
    def flatten_hierarchies(self):
        """Alias for FlattenHierarchies"""
        return self.FlattenHierarchies

    @flatten_hierarchies.setter
    def flatten_hierarchies(self, value):
        """Alias for FlattenHierarchies.setter"""
        self.FlattenHierarchies = value

    @property
    def Formula(self):
        return self.com_object.Formula

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @property
    def HierarchizeDistinct(self):
        return self.com_object.HierarchizeDistinct

    @HierarchizeDistinct.setter
    def HierarchizeDistinct(self, value):
        self.com_object.HierarchizeDistinct = value

    @property
    def hierarchizedistinct(self):
        """Alias for HierarchizeDistinct"""
        return self.HierarchizeDistinct

    @hierarchizedistinct.setter
    def hierarchizedistinct(self, value):
        """Alias for HierarchizeDistinct.setter"""
        self.HierarchizeDistinct = value

    @property
    def hierarchize_distinct(self):
        """Alias for HierarchizeDistinct"""
        return self.HierarchizeDistinct

    @hierarchize_distinct.setter
    def hierarchize_distinct(self, value):
        """Alias for HierarchizeDistinct.setter"""
        self.HierarchizeDistinct = value

    @property
    def IsValid(self):
        return self.com_object.IsValid

    @property
    def isvalid(self):
        """Alias for IsValid"""
        return self.IsValid

    @property
    def is_valid(self):
        """Alias for IsValid"""
        return self.IsValid

    @property
    def MeasureGroup(self):
        return self.com_object.MeasureGroup

    @property
    def measuregroup(self):
        """Alias for MeasureGroup"""
        return self.MeasureGroup

    @property
    def measure_group(self):
        """Alias for MeasureGroup"""
        return self.MeasureGroup

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NumberFormat(self):
        return XlCalcMemNumberFormatType(self.com_object.NumberFormat)

    @property
    def numberformat(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @property
    def number_format(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ParentHierarchy(self):
        return self.com_object.ParentHierarchy

    @property
    def parenthierarchy(self):
        """Alias for ParentHierarchy"""
        return self.ParentHierarchy

    @property
    def parent_hierarchy(self):
        """Alias for ParentHierarchy"""
        return self.ParentHierarchy

    @property
    def ParentMember(self):
        return self.com_object.ParentMember

    @property
    def parentmember(self):
        """Alias for ParentMember"""
        return self.ParentMember

    @property
    def parent_member(self):
        """Alias for ParentMember"""
        return self.ParentMember

    @property
    def SolveOrder(self):
        return self.com_object.SolveOrder

    @property
    def solveorder(self):
        """Alias for SolveOrder"""
        return self.SolveOrder

    @property
    def solve_order(self):
        """Alias for SolveOrder"""
        return self.SolveOrder

    @property
    def SourceName(self):
        return self.com_object.SourceName

    @property
    def sourcename(self):
        """Alias for SourceName"""
        return self.SourceName

    @property
    def source_name(self):
        """Alias for SourceName"""
        return self.SourceName

    @property
    def Type(self):
        return XlCalculatedMemberType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class CalculatedMembers:

    def __init__(self, calculatedmembers=None):
        self.com_object= calculatedmembers

    def __call__(self, item):
        return CalculatedMember(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, Formula=None, SolveOrder=None, Type=None, Dynamic=None, DisplayFolder=None, HierarchizeDistinct=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Formula, SolveOrder, Type, Dynamic, DisplayFolder, HierarchizeDistinct]])
        return CalculatedMember(self.com_object.Add(*arguments))

    def add(self, Name=None, Formula=None, SolveOrder=None, Type=None, Dynamic=None, DisplayFolder=None, HierarchizeDistinct=None):
        """Alias for Add"""
        arguments = [Name, Formula, SolveOrder, Type, Dynamic, DisplayFolder, HierarchizeDistinct]
        return self.Add(*arguments)

    def AddCalculatedMember(self, Name=None, Formula=None, SolveOrder=None, Type=None, DisplayFolder=None, MeasureGroup=None, ParentHierarchy=None, ParentMember=None, NumberFormat=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Formula, SolveOrder, Type, DisplayFolder, MeasureGroup, ParentHierarchy, ParentMember, NumberFormat]])
        return CALCULATEDMEMBER(self.com_object.AddCalculatedMember(*arguments))

    def addcalculatedmember(self, Name=None, Formula=None, SolveOrder=None, Type=None, DisplayFolder=None, MeasureGroup=None, ParentHierarchy=None, ParentMember=None, NumberFormat=None):
        """Alias for AddCalculatedMember"""
        arguments = [Name, Formula, SolveOrder, Type, DisplayFolder, MeasureGroup, ParentHierarchy, ParentMember, NumberFormat]
        return self.AddCalculatedMember(*arguments)

    def add_calculated_member(self, Name=None, Formula=None, SolveOrder=None, Type=None, DisplayFolder=None, MeasureGroup=None, ParentHierarchy=None, ParentMember=None, NumberFormat=None):
        """Alias for AddCalculatedMember"""
        arguments = [Name, Formula, SolveOrder, Type, DisplayFolder, MeasureGroup, ParentHierarchy, ParentMember, NumberFormat]
        return self.AddCalculatedMember(*arguments)


class CalloutFormat:

    def __init__(self, calloutformat=None):
        self.com_object= calloutformat

    @property
    def Accent(self):
        return self.com_object.Accent

    @Accent.setter
    def Accent(self, value):
        self.com_object.Accent = value

    @property
    def accent(self):
        """Alias for Accent"""
        return self.Accent

    @accent.setter
    def accent(self, value):
        """Alias for Accent.setter"""
        self.Accent = value

    @property
    def Angle(self):
        return self.com_object.Angle

    @Angle.setter
    def Angle(self, value):
        self.com_object.Angle = value

    @property
    def angle(self):
        """Alias for Angle"""
        return self.Angle

    @angle.setter
    def angle(self, value):
        """Alias for Angle.setter"""
        self.Angle = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoAttach(self):
        return self.com_object.AutoAttach

    @AutoAttach.setter
    def AutoAttach(self, value):
        self.com_object.AutoAttach = value

    @property
    def autoattach(self):
        """Alias for AutoAttach"""
        return self.AutoAttach

    @autoattach.setter
    def autoattach(self, value):
        """Alias for AutoAttach.setter"""
        self.AutoAttach = value

    @property
    def auto_attach(self):
        """Alias for AutoAttach"""
        return self.AutoAttach

    @auto_attach.setter
    def auto_attach(self, value):
        """Alias for AutoAttach.setter"""
        self.AutoAttach = value

    @property
    def AutoLength(self):
        return self.com_object.AutoLength

    @AutoLength.setter
    def AutoLength(self, value):
        self.com_object.AutoLength = value

    @property
    def autolength(self):
        """Alias for AutoLength"""
        return self.AutoLength

    @autolength.setter
    def autolength(self, value):
        """Alias for AutoLength.setter"""
        self.AutoLength = value

    @property
    def auto_length(self):
        """Alias for AutoLength"""
        return self.AutoLength

    @auto_length.setter
    def auto_length(self, value):
        """Alias for AutoLength.setter"""
        self.AutoLength = value

    @property
    def Border(self):
        return self.com_object.Border

    @Border.setter
    def Border(self, value):
        self.com_object.Border = value

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @border.setter
    def border(self, value):
        """Alias for Border.setter"""
        self.Border = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Drop(self):
        return self.com_object.Drop

    @property
    def drop(self):
        """Alias for Drop"""
        return self.Drop

    @property
    def DropType(self):
        return self.com_object.DropType

    @property
    def droptype(self):
        """Alias for DropType"""
        return self.DropType

    @property
    def drop_type(self):
        """Alias for DropType"""
        return self.DropType

    @property
    def Gap(self):
        return self.com_object.Gap

    @Gap.setter
    def Gap(self, value):
        self.com_object.Gap = value

    @property
    def gap(self):
        """Alias for Gap"""
        return self.Gap

    @gap.setter
    def gap(self, value):
        """Alias for Gap.setter"""
        self.Gap = value

    @property
    def Length(self):
        return self.com_object.Length

    @property
    def length(self):
        """Alias for Length"""
        return self.Length

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    def AutomaticLength(self):
        self.com_object.AutomaticLength()

    def automaticlength(self):
        """Alias for AutomaticLength"""
        return self.AutomaticLength()

    def automatic_length(self):
        """Alias for AutomaticLength"""
        return self.AutomaticLength()

    def CustomDrop(self, Drop=None):
        arguments = com_arguments([unwrap(a) for a in [Drop]])
        self.com_object.CustomDrop(*arguments)

    def customdrop(self, Drop=None):
        """Alias for CustomDrop"""
        arguments = [Drop]
        return self.CustomDrop(*arguments)

    def custom_drop(self, Drop=None):
        """Alias for CustomDrop"""
        arguments = [Drop]
        return self.CustomDrop(*arguments)

    def CustomLength(self, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Length]])
        self.com_object.CustomLength(*arguments)

    def customlength(self, Length=None):
        """Alias for CustomLength"""
        arguments = [Length]
        return self.CustomLength(*arguments)

    def custom_length(self, Length=None):
        """Alias for CustomLength"""
        arguments = [Length]
        return self.CustomLength(*arguments)

    def PresetDrop(self, DropType=None):
        arguments = com_arguments([unwrap(a) for a in [DropType]])
        self.com_object.PresetDrop(*arguments)

    def presetdrop(self, DropType=None):
        """Alias for PresetDrop"""
        arguments = [DropType]
        return self.PresetDrop(*arguments)

    def preset_drop(self, DropType=None):
        """Alias for PresetDrop"""
        arguments = [DropType]
        return self.PresetDrop(*arguments)


class CategoryCollection:

    def __init__(self, categorycollection=None):
        self.com_object= categorycollection

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ChartCategory(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class CellFormat:

    def __init__(self, cellformat=None):
        self.com_object= cellformat

    @property
    def AddIndent(self):
        return self.com_object.AddIndent

    @AddIndent.setter
    def AddIndent(self, value):
        self.com_object.AddIndent = value

    @property
    def addindent(self):
        """Alias for AddIndent"""
        return self.AddIndent

    @addindent.setter
    def addindent(self, value):
        """Alias for AddIndent.setter"""
        self.AddIndent = value

    @property
    def add_indent(self):
        """Alias for AddIndent"""
        return self.AddIndent

    @add_indent.setter
    def add_indent(self, value):
        """Alias for AddIndent.setter"""
        self.AddIndent = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @Borders.setter
    def Borders(self, value):
        self.com_object.Borders = value

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @borders.setter
    def borders(self, value):
        """Alias for Borders.setter"""
        self.Borders = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def FormulaHidden(self):
        return self.com_object.FormulaHidden

    @FormulaHidden.setter
    def FormulaHidden(self, value):
        self.com_object.FormulaHidden = value

    @property
    def formulahidden(self):
        """Alias for FormulaHidden"""
        return self.FormulaHidden

    @formulahidden.setter
    def formulahidden(self, value):
        """Alias for FormulaHidden.setter"""
        self.FormulaHidden = value

    @property
    def formula_hidden(self):
        """Alias for FormulaHidden"""
        return self.FormulaHidden

    @formula_hidden.setter
    def formula_hidden(self, value):
        """Alias for FormulaHidden.setter"""
        self.FormulaHidden = value

    @property
    def HorizontalAlignment(self):
        return self.com_object.HorizontalAlignment

    @HorizontalAlignment.setter
    def HorizontalAlignment(self, value):
        self.com_object.HorizontalAlignment = value

    @property
    def horizontalalignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontalalignment.setter
    def horizontalalignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def horizontal_alignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def IndentLevel(self):
        return self.com_object.IndentLevel

    @IndentLevel.setter
    def IndentLevel(self, value):
        self.com_object.IndentLevel = value

    @property
    def indentlevel(self):
        """Alias for IndentLevel"""
        return self.IndentLevel

    @indentlevel.setter
    def indentlevel(self, value):
        """Alias for IndentLevel.setter"""
        self.IndentLevel = value

    @property
    def indent_level(self):
        """Alias for IndentLevel"""
        return self.IndentLevel

    @indent_level.setter
    def indent_level(self, value):
        """Alias for IndentLevel.setter"""
        self.IndentLevel = value

    @property
    def Interior(self):
        return Interior(self.com_object.Interior)

    @property
    def interior(self):
        """Alias for Interior"""
        return self.Interior

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def MergeCells(self):
        return self.com_object.MergeCells

    @MergeCells.setter
    def MergeCells(self, value):
        self.com_object.MergeCells = value

    @property
    def mergecells(self):
        """Alias for MergeCells"""
        return self.MergeCells

    @mergecells.setter
    def mergecells(self, value):
        """Alias for MergeCells.setter"""
        self.MergeCells = value

    @property
    def merge_cells(self):
        """Alias for MergeCells"""
        return self.MergeCells

    @merge_cells.setter
    def merge_cells(self, value):
        """Alias for MergeCells.setter"""
        self.MergeCells = value

    @property
    def NumberFormat(self):
        return self.com_object.NumberFormat

    @NumberFormat.setter
    def NumberFormat(self, value):
        self.com_object.NumberFormat = value

    @property
    def numberformat(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @numberformat.setter
    def numberformat(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def number_format(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @number_format.setter
    def number_format(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def NumberFormatLocal(self):
        return self.com_object.NumberFormatLocal

    @NumberFormatLocal.setter
    def NumberFormatLocal(self, value):
        self.com_object.NumberFormatLocal = value

    @property
    def numberformatlocal(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @numberformatlocal.setter
    def numberformatlocal(self, value):
        """Alias for NumberFormatLocal.setter"""
        self.NumberFormatLocal = value

    @property
    def number_format_local(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @number_format_local.setter
    def number_format_local(self, value):
        """Alias for NumberFormatLocal.setter"""
        self.NumberFormatLocal = value

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ShrinkToFit(self):
        return self.com_object.ShrinkToFit

    @ShrinkToFit.setter
    def ShrinkToFit(self, value):
        self.com_object.ShrinkToFit = value

    @property
    def shrinktofit(self):
        """Alias for ShrinkToFit"""
        return self.ShrinkToFit

    @shrinktofit.setter
    def shrinktofit(self, value):
        """Alias for ShrinkToFit.setter"""
        self.ShrinkToFit = value

    @property
    def shrink_to_fit(self):
        """Alias for ShrinkToFit"""
        return self.ShrinkToFit

    @shrink_to_fit.setter
    def shrink_to_fit(self, value):
        """Alias for ShrinkToFit.setter"""
        self.ShrinkToFit = value

    @property
    def VerticalAlignment(self):
        return self.com_object.VerticalAlignment

    @VerticalAlignment.setter
    def VerticalAlignment(self, value):
        self.com_object.VerticalAlignment = value

    @property
    def verticalalignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @verticalalignment.setter
    def verticalalignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def vertical_alignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @vertical_alignment.setter
    def vertical_alignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def WrapText(self):
        return self.com_object.WrapText

    @WrapText.setter
    def WrapText(self, value):
        self.com_object.WrapText = value

    @property
    def wraptext(self):
        """Alias for WrapText"""
        return self.WrapText

    @wraptext.setter
    def wraptext(self, value):
        """Alias for WrapText.setter"""
        self.WrapText = value

    @property
    def wrap_text(self):
        """Alias for WrapText"""
        return self.WrapText

    @wrap_text.setter
    def wrap_text(self, value):
        """Alias for WrapText.setter"""
        self.WrapText = value

    def Clear(self):
        self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()


class Characters:

    def __init__(self, characters=None):
        self.com_object= characters

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Caption(self):
        return self.com_object.Caption

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PhoneticCharacters(self):
        return Characters(self.com_object.PhoneticCharacters)

    @PhoneticCharacters.setter
    def PhoneticCharacters(self, value):
        self.com_object.PhoneticCharacters = value

    @property
    def phoneticcharacters(self):
        """Alias for PhoneticCharacters"""
        return self.PhoneticCharacters

    @phoneticcharacters.setter
    def phoneticcharacters(self, value):
        """Alias for PhoneticCharacters.setter"""
        self.PhoneticCharacters = value

    @property
    def phonetic_characters(self):
        """Alias for PhoneticCharacters"""
        return self.PhoneticCharacters

    @phonetic_characters.setter
    def phonetic_characters(self, value):
        """Alias for PhoneticCharacters.setter"""
        self.PhoneticCharacters = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Insert(self, String=None):
        arguments = com_arguments([unwrap(a) for a in [String]])
        return self.com_object.Insert(*arguments)

    def insert(self, String=None):
        """Alias for Insert"""
        arguments = [String]
        return self.Insert(*arguments)


class Chart:

    def __init__(self, chart=None):
        self.com_object= chart

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoScaling(self):
        return self.com_object.AutoScaling

    @AutoScaling.setter
    def AutoScaling(self, value):
        self.com_object.AutoScaling = value

    @property
    def autoscaling(self):
        """Alias for AutoScaling"""
        return self.AutoScaling

    @autoscaling.setter
    def autoscaling(self, value):
        """Alias for AutoScaling.setter"""
        self.AutoScaling = value

    @property
    def auto_scaling(self):
        """Alias for AutoScaling"""
        return self.AutoScaling

    @auto_scaling.setter
    def auto_scaling(self, value):
        """Alias for AutoScaling.setter"""
        self.AutoScaling = value

    @property
    def BackWall(self):
        return Walls(self.com_object.BackWall)

    @property
    def backwall(self):
        """Alias for BackWall"""
        return self.BackWall

    @property
    def back_wall(self):
        """Alias for BackWall"""
        return self.BackWall

    @property
    def BarShape(self):
        return XlBarShape(self.com_object.BarShape)

    @BarShape.setter
    def BarShape(self, value):
        self.com_object.BarShape = value

    @property
    def barshape(self):
        """Alias for BarShape"""
        return self.BarShape

    @barshape.setter
    def barshape(self, value):
        """Alias for BarShape.setter"""
        self.BarShape = value

    @property
    def bar_shape(self):
        """Alias for BarShape"""
        return self.BarShape

    @bar_shape.setter
    def bar_shape(self, value):
        """Alias for BarShape.setter"""
        self.BarShape = value

    @property
    def CategoryLabelLevel(self):
        return XlCategoryLabelLevel(self.com_object.CategoryLabelLevel)

    @CategoryLabelLevel.setter
    def CategoryLabelLevel(self, value):
        self.com_object.CategoryLabelLevel = value

    @property
    def categorylabellevel(self):
        """Alias for CategoryLabelLevel"""
        return self.CategoryLabelLevel

    @categorylabellevel.setter
    def categorylabellevel(self, value):
        """Alias for CategoryLabelLevel.setter"""
        self.CategoryLabelLevel = value

    @property
    def category_label_level(self):
        """Alias for CategoryLabelLevel"""
        return self.CategoryLabelLevel

    @category_label_level.setter
    def category_label_level(self, value):
        """Alias for CategoryLabelLevel.setter"""
        self.CategoryLabelLevel = value

    @property
    def ChartArea(self):
        return ChartArea(self.com_object.ChartArea)

    @property
    def chartarea(self):
        """Alias for ChartArea"""
        return self.ChartArea

    @property
    def chart_area(self):
        """Alias for ChartArea"""
        return self.ChartArea

    @property
    def ChartColor(self):
        return self.com_object.ChartColor

    @ChartColor.setter
    def ChartColor(self, value):
        self.com_object.ChartColor = value

    @property
    def chartcolor(self):
        """Alias for ChartColor"""
        return self.ChartColor

    @chartcolor.setter
    def chartcolor(self, value):
        """Alias for ChartColor.setter"""
        self.ChartColor = value

    @property
    def chart_color(self):
        """Alias for ChartColor"""
        return self.ChartColor

    @chart_color.setter
    def chart_color(self, value):
        """Alias for ChartColor.setter"""
        self.ChartColor = value

    @property
    def ChartStyle(self):
        return self.com_object.ChartStyle

    @ChartStyle.setter
    def ChartStyle(self, value):
        self.com_object.ChartStyle = value

    @property
    def chartstyle(self):
        """Alias for ChartStyle"""
        return self.ChartStyle

    @chartstyle.setter
    def chartstyle(self, value):
        """Alias for ChartStyle.setter"""
        self.ChartStyle = value

    @property
    def chart_style(self):
        """Alias for ChartStyle"""
        return self.ChartStyle

    @chart_style.setter
    def chart_style(self, value):
        """Alias for ChartStyle.setter"""
        self.ChartStyle = value

    @property
    def ChartTitle(self):
        return ChartTitle(self.com_object.ChartTitle)

    @property
    def charttitle(self):
        """Alias for ChartTitle"""
        return self.ChartTitle

    @property
    def chart_title(self):
        """Alias for ChartTitle"""
        return self.ChartTitle

    @property
    def ChartType(self):
        return XlChartType(self.com_object.ChartType)

    @ChartType.setter
    def ChartType(self, value):
        self.com_object.ChartType = value

    @property
    def charttype(self):
        """Alias for ChartType"""
        return self.ChartType

    @charttype.setter
    def charttype(self, value):
        """Alias for ChartType.setter"""
        self.ChartType = value

    @property
    def chart_type(self):
        """Alias for ChartType"""
        return self.ChartType

    @chart_type.setter
    def chart_type(self, value):
        """Alias for ChartType.setter"""
        self.ChartType = value

    @property
    def CodeName(self):
        return self.com_object.CodeName

    @property
    def codename(self):
        """Alias for CodeName"""
        return self.CodeName

    @property
    def code_name(self):
        """Alias for CodeName"""
        return self.CodeName

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DataTable(self):
        return DataTable(self.com_object.DataTable)

    @property
    def datatable(self):
        """Alias for DataTable"""
        return self.DataTable

    @property
    def data_table(self):
        """Alias for DataTable"""
        return self.DataTable

    @property
    def DepthPercent(self):
        return self.com_object.DepthPercent

    @DepthPercent.setter
    def DepthPercent(self, value):
        self.com_object.DepthPercent = value

    @property
    def depthpercent(self):
        """Alias for DepthPercent"""
        return self.DepthPercent

    @depthpercent.setter
    def depthpercent(self, value):
        """Alias for DepthPercent.setter"""
        self.DepthPercent = value

    @property
    def depth_percent(self):
        """Alias for DepthPercent"""
        return self.DepthPercent

    @depth_percent.setter
    def depth_percent(self, value):
        """Alias for DepthPercent.setter"""
        self.DepthPercent = value

    @property
    def DisplayBlanksAs(self):
        return XlDisplayBlanksAs(self.com_object.DisplayBlanksAs)

    @DisplayBlanksAs.setter
    def DisplayBlanksAs(self, value):
        self.com_object.DisplayBlanksAs = value

    @property
    def displayblanksas(self):
        """Alias for DisplayBlanksAs"""
        return self.DisplayBlanksAs

    @displayblanksas.setter
    def displayblanksas(self, value):
        """Alias for DisplayBlanksAs.setter"""
        self.DisplayBlanksAs = value

    @property
    def display_blanks_as(self):
        """Alias for DisplayBlanksAs"""
        return self.DisplayBlanksAs

    @display_blanks_as.setter
    def display_blanks_as(self, value):
        """Alias for DisplayBlanksAs.setter"""
        self.DisplayBlanksAs = value

    @property
    def Elevation(self):
        return self.com_object.Elevation

    @Elevation.setter
    def Elevation(self, value):
        self.com_object.Elevation = value

    @property
    def elevation(self):
        """Alias for Elevation"""
        return self.Elevation

    @elevation.setter
    def elevation(self, value):
        """Alias for Elevation.setter"""
        self.Elevation = value

    @property
    def Floor(self):
        return Floor(self.com_object.Floor)

    @property
    def floor(self):
        """Alias for Floor"""
        return self.Floor

    @property
    def GapDepth(self):
        return self.com_object.GapDepth

    @GapDepth.setter
    def GapDepth(self, value):
        self.com_object.GapDepth = value

    @property
    def gapdepth(self):
        """Alias for GapDepth"""
        return self.GapDepth

    @gapdepth.setter
    def gapdepth(self, value):
        """Alias for GapDepth.setter"""
        self.GapDepth = value

    @property
    def gap_depth(self):
        """Alias for GapDepth"""
        return self.GapDepth

    @gap_depth.setter
    def gap_depth(self, value):
        """Alias for GapDepth.setter"""
        self.GapDepth = value

    @property
    def HasAxis(self):
        return self.com_object.HasAxis

    @HasAxis.setter
    def HasAxis(self, value):
        self.com_object.HasAxis = value

    @property
    def hasaxis(self):
        """Alias for HasAxis"""
        return self.HasAxis

    @hasaxis.setter
    def hasaxis(self, value):
        """Alias for HasAxis.setter"""
        self.HasAxis = value

    @property
    def has_axis(self):
        """Alias for HasAxis"""
        return self.HasAxis

    @has_axis.setter
    def has_axis(self, value):
        """Alias for HasAxis.setter"""
        self.HasAxis = value

    @property
    def HasDataTable(self):
        return self.com_object.HasDataTable

    @HasDataTable.setter
    def HasDataTable(self, value):
        self.com_object.HasDataTable = value

    @property
    def hasdatatable(self):
        """Alias for HasDataTable"""
        return self.HasDataTable

    @hasdatatable.setter
    def hasdatatable(self, value):
        """Alias for HasDataTable.setter"""
        self.HasDataTable = value

    @property
    def has_data_table(self):
        """Alias for HasDataTable"""
        return self.HasDataTable

    @has_data_table.setter
    def has_data_table(self, value):
        """Alias for HasDataTable.setter"""
        self.HasDataTable = value

    @property
    def HasLegend(self):
        return self.com_object.HasLegend

    @HasLegend.setter
    def HasLegend(self, value):
        self.com_object.HasLegend = value

    @property
    def haslegend(self):
        """Alias for HasLegend"""
        return self.HasLegend

    @haslegend.setter
    def haslegend(self, value):
        """Alias for HasLegend.setter"""
        self.HasLegend = value

    @property
    def has_legend(self):
        """Alias for HasLegend"""
        return self.HasLegend

    @has_legend.setter
    def has_legend(self, value):
        """Alias for HasLegend.setter"""
        self.HasLegend = value

    @property
    def HasTitle(self):
        return self.com_object.HasTitle

    @HasTitle.setter
    def HasTitle(self, value):
        self.com_object.HasTitle = value

    @property
    def hastitle(self):
        """Alias for HasTitle"""
        return self.HasTitle

    @hastitle.setter
    def hastitle(self, value):
        """Alias for HasTitle.setter"""
        self.HasTitle = value

    @property
    def has_title(self):
        """Alias for HasTitle"""
        return self.HasTitle

    @has_title.setter
    def has_title(self, value):
        """Alias for HasTitle.setter"""
        self.HasTitle = value

    @property
    def HeightPercent(self):
        return self.com_object.HeightPercent

    @HeightPercent.setter
    def HeightPercent(self, value):
        self.com_object.HeightPercent = value

    @property
    def heightpercent(self):
        """Alias for HeightPercent"""
        return self.HeightPercent

    @heightpercent.setter
    def heightpercent(self, value):
        """Alias for HeightPercent.setter"""
        self.HeightPercent = value

    @property
    def height_percent(self):
        """Alias for HeightPercent"""
        return self.HeightPercent

    @height_percent.setter
    def height_percent(self, value):
        """Alias for HeightPercent.setter"""
        self.HeightPercent = value

    @property
    def Hyperlinks(self):
        return Hyperlinks(self.com_object.Hyperlinks)

    @property
    def hyperlinks(self):
        """Alias for Hyperlinks"""
        return self.Hyperlinks

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Legend(self):
        return Legend(self.com_object.Legend)

    @property
    def legend(self):
        """Alias for Legend"""
        return self.Legend

    @property
    def MailEnvelope(self):
        return self.com_object.MailEnvelope

    @property
    def mailenvelope(self):
        """Alias for MailEnvelope"""
        return self.MailEnvelope

    @property
    def mail_envelope(self):
        """Alias for MailEnvelope"""
        return self.MailEnvelope

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Next(self):
        return Worksheet(self.com_object.Next)

    @property
    def next(self):
        """Alias for Next"""
        return self.Next

    @property
    def PageSetup(self):
        return PageSetup(self.com_object.PageSetup)

    @property
    def pagesetup(self):
        """Alias for PageSetup"""
        return self.PageSetup

    @property
    def page_setup(self):
        """Alias for PageSetup"""
        return self.PageSetup

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Perspective(self):
        return self.com_object.Perspective

    @Perspective.setter
    def Perspective(self, value):
        self.com_object.Perspective = value

    @property
    def perspective(self):
        """Alias for Perspective"""
        return self.Perspective

    @perspective.setter
    def perspective(self, value):
        """Alias for Perspective.setter"""
        self.Perspective = value

    @property
    def PivotLayout(self):
        return PivotLayout(self.com_object.PivotLayout)

    @property
    def pivotlayout(self):
        """Alias for PivotLayout"""
        return self.PivotLayout

    @property
    def pivot_layout(self):
        """Alias for PivotLayout"""
        return self.PivotLayout

    @property
    def PlotArea(self):
        return PlotArea(self.com_object.PlotArea)

    @property
    def plotarea(self):
        """Alias for PlotArea"""
        return self.PlotArea

    @property
    def plot_area(self):
        """Alias for PlotArea"""
        return self.PlotArea

    @property
    def PlotBy(self):
        return XlRowCol(self.com_object.PlotBy)

    @PlotBy.setter
    def PlotBy(self, value):
        self.com_object.PlotBy = value

    @property
    def plotby(self):
        """Alias for PlotBy"""
        return self.PlotBy

    @plotby.setter
    def plotby(self, value):
        """Alias for PlotBy.setter"""
        self.PlotBy = value

    @property
    def plot_by(self):
        """Alias for PlotBy"""
        return self.PlotBy

    @plot_by.setter
    def plot_by(self, value):
        """Alias for PlotBy.setter"""
        self.PlotBy = value

    @property
    def PlotVisibleOnly(self):
        return self.com_object.PlotVisibleOnly

    @PlotVisibleOnly.setter
    def PlotVisibleOnly(self, value):
        self.com_object.PlotVisibleOnly = value

    @property
    def plotvisibleonly(self):
        """Alias for PlotVisibleOnly"""
        return self.PlotVisibleOnly

    @plotvisibleonly.setter
    def plotvisibleonly(self, value):
        """Alias for PlotVisibleOnly.setter"""
        self.PlotVisibleOnly = value

    @property
    def plot_visible_only(self):
        """Alias for PlotVisibleOnly"""
        return self.PlotVisibleOnly

    @plot_visible_only.setter
    def plot_visible_only(self, value):
        """Alias for PlotVisibleOnly.setter"""
        self.PlotVisibleOnly = value

    @property
    def Previous(self):
        return Worksheet(self.com_object.Previous)

    @property
    def previous(self):
        """Alias for Previous"""
        return self.Previous

    @property
    def PrintedCommentPages(self):
        return self.com_object.PrintedCommentPages

    @property
    def printedcommentpages(self):
        """Alias for PrintedCommentPages"""
        return self.PrintedCommentPages

    @property
    def printed_comment_pages(self):
        """Alias for PrintedCommentPages"""
        return self.PrintedCommentPages

    @property
    def ProtectContents(self):
        return self.com_object.ProtectContents

    @property
    def protectcontents(self):
        """Alias for ProtectContents"""
        return self.ProtectContents

    @property
    def protect_contents(self):
        """Alias for ProtectContents"""
        return self.ProtectContents

    @property
    def ProtectData(self):
        return self.com_object.ProtectData

    @ProtectData.setter
    def ProtectData(self, value):
        self.com_object.ProtectData = value

    @property
    def protectdata(self):
        """Alias for ProtectData"""
        return self.ProtectData

    @protectdata.setter
    def protectdata(self, value):
        """Alias for ProtectData.setter"""
        self.ProtectData = value

    @property
    def protect_data(self):
        """Alias for ProtectData"""
        return self.ProtectData

    @protect_data.setter
    def protect_data(self, value):
        """Alias for ProtectData.setter"""
        self.ProtectData = value

    @property
    def ProtectDrawingObjects(self):
        return self.com_object.ProtectDrawingObjects

    @property
    def protectdrawingobjects(self):
        """Alias for ProtectDrawingObjects"""
        return self.ProtectDrawingObjects

    @property
    def protect_drawing_objects(self):
        """Alias for ProtectDrawingObjects"""
        return self.ProtectDrawingObjects

    @property
    def ProtectFormatting(self):
        return self.com_object.ProtectFormatting

    @ProtectFormatting.setter
    def ProtectFormatting(self, value):
        self.com_object.ProtectFormatting = value

    @property
    def protectformatting(self):
        """Alias for ProtectFormatting"""
        return self.ProtectFormatting

    @protectformatting.setter
    def protectformatting(self, value):
        """Alias for ProtectFormatting.setter"""
        self.ProtectFormatting = value

    @property
    def protect_formatting(self):
        """Alias for ProtectFormatting"""
        return self.ProtectFormatting

    @protect_formatting.setter
    def protect_formatting(self, value):
        """Alias for ProtectFormatting.setter"""
        self.ProtectFormatting = value

    @property
    def ProtectionMode(self):
        return self.com_object.ProtectionMode

    @property
    def protectionmode(self):
        """Alias for ProtectionMode"""
        return self.ProtectionMode

    @property
    def protection_mode(self):
        """Alias for ProtectionMode"""
        return self.ProtectionMode

    @property
    def ProtectSelection(self):
        return self.com_object.ProtectSelection

    @ProtectSelection.setter
    def ProtectSelection(self, value):
        self.com_object.ProtectSelection = value

    @property
    def protectselection(self):
        """Alias for ProtectSelection"""
        return self.ProtectSelection

    @protectselection.setter
    def protectselection(self, value):
        """Alias for ProtectSelection.setter"""
        self.ProtectSelection = value

    @property
    def protect_selection(self):
        """Alias for ProtectSelection"""
        return self.ProtectSelection

    @protect_selection.setter
    def protect_selection(self, value):
        """Alias for ProtectSelection.setter"""
        self.ProtectSelection = value

    @property
    def RightAngleAxes(self):
        return self.com_object.RightAngleAxes

    @RightAngleAxes.setter
    def RightAngleAxes(self, value):
        self.com_object.RightAngleAxes = value

    @property
    def rightangleaxes(self):
        """Alias for RightAngleAxes"""
        return self.RightAngleAxes

    @rightangleaxes.setter
    def rightangleaxes(self, value):
        """Alias for RightAngleAxes.setter"""
        self.RightAngleAxes = value

    @property
    def right_angle_axes(self):
        """Alias for RightAngleAxes"""
        return self.RightAngleAxes

    @right_angle_axes.setter
    def right_angle_axes(self, value):
        """Alias for RightAngleAxes.setter"""
        self.RightAngleAxes = value

    @property
    def Rotation(self):
        return self.com_object.Rotation

    @Rotation.setter
    def Rotation(self, value):
        self.com_object.Rotation = value

    @property
    def rotation(self):
        """Alias for Rotation"""
        return self.Rotation

    @rotation.setter
    def rotation(self, value):
        """Alias for Rotation.setter"""
        self.Rotation = value

    @property
    def SeriesNameLevel(self):
        return XlSeriesNameLevel(self.com_object.SeriesNameLevel)

    @SeriesNameLevel.setter
    def SeriesNameLevel(self, value):
        self.com_object.SeriesNameLevel = value

    @property
    def seriesnamelevel(self):
        """Alias for SeriesNameLevel"""
        return self.SeriesNameLevel

    @seriesnamelevel.setter
    def seriesnamelevel(self, value):
        """Alias for SeriesNameLevel.setter"""
        self.SeriesNameLevel = value

    @property
    def series_name_level(self):
        """Alias for SeriesNameLevel"""
        return self.SeriesNameLevel

    @series_name_level.setter
    def series_name_level(self, value):
        """Alias for SeriesNameLevel.setter"""
        self.SeriesNameLevel = value

    @property
    def Shapes(self):
        return Shapes(self.com_object.Shapes)

    @property
    def shapes(self):
        """Alias for Shapes"""
        return self.Shapes

    @property
    def ShowAllFieldButtons(self):
        return self.com_object.ShowAllFieldButtons

    @ShowAllFieldButtons.setter
    def ShowAllFieldButtons(self, value):
        self.com_object.ShowAllFieldButtons = value

    @property
    def showallfieldbuttons(self):
        """Alias for ShowAllFieldButtons"""
        return self.ShowAllFieldButtons

    @showallfieldbuttons.setter
    def showallfieldbuttons(self, value):
        """Alias for ShowAllFieldButtons.setter"""
        self.ShowAllFieldButtons = value

    @property
    def show_all_field_buttons(self):
        """Alias for ShowAllFieldButtons"""
        return self.ShowAllFieldButtons

    @show_all_field_buttons.setter
    def show_all_field_buttons(self, value):
        """Alias for ShowAllFieldButtons.setter"""
        self.ShowAllFieldButtons = value

    @property
    def ShowAxisFieldButtons(self):
        return self.com_object.ShowAxisFieldButtons

    @ShowAxisFieldButtons.setter
    def ShowAxisFieldButtons(self, value):
        self.com_object.ShowAxisFieldButtons = value

    @property
    def showaxisfieldbuttons(self):
        """Alias for ShowAxisFieldButtons"""
        return self.ShowAxisFieldButtons

    @showaxisfieldbuttons.setter
    def showaxisfieldbuttons(self, value):
        """Alias for ShowAxisFieldButtons.setter"""
        self.ShowAxisFieldButtons = value

    @property
    def show_axis_field_buttons(self):
        """Alias for ShowAxisFieldButtons"""
        return self.ShowAxisFieldButtons

    @show_axis_field_buttons.setter
    def show_axis_field_buttons(self, value):
        """Alias for ShowAxisFieldButtons.setter"""
        self.ShowAxisFieldButtons = value

    @property
    def ShowDataLabelsOverMaximum(self):
        return self.com_object.ShowDataLabelsOverMaximum

    @ShowDataLabelsOverMaximum.setter
    def ShowDataLabelsOverMaximum(self, value):
        self.com_object.ShowDataLabelsOverMaximum = value

    @property
    def showdatalabelsovermaximum(self):
        """Alias for ShowDataLabelsOverMaximum"""
        return self.ShowDataLabelsOverMaximum

    @showdatalabelsovermaximum.setter
    def showdatalabelsovermaximum(self, value):
        """Alias for ShowDataLabelsOverMaximum.setter"""
        self.ShowDataLabelsOverMaximum = value

    @property
    def show_data_labels_over_maximum(self):
        """Alias for ShowDataLabelsOverMaximum"""
        return self.ShowDataLabelsOverMaximum

    @show_data_labels_over_maximum.setter
    def show_data_labels_over_maximum(self, value):
        """Alias for ShowDataLabelsOverMaximum.setter"""
        self.ShowDataLabelsOverMaximum = value

    @property
    def ShowExpandCollapseEntireFieldButtons(self):
        return self.com_object.ShowExpandCollapseEntireFieldButtons

    @ShowExpandCollapseEntireFieldButtons.setter
    def ShowExpandCollapseEntireFieldButtons(self, value):
        self.com_object.ShowExpandCollapseEntireFieldButtons = value

    @property
    def showexpandcollapseentirefieldbuttons(self):
        """Alias for ShowExpandCollapseEntireFieldButtons"""
        return self.ShowExpandCollapseEntireFieldButtons

    @showexpandcollapseentirefieldbuttons.setter
    def showexpandcollapseentirefieldbuttons(self, value):
        """Alias for ShowExpandCollapseEntireFieldButtons.setter"""
        self.ShowExpandCollapseEntireFieldButtons = value

    @property
    def show_expand_collapse_entire_field_buttons(self):
        """Alias for ShowExpandCollapseEntireFieldButtons"""
        return self.ShowExpandCollapseEntireFieldButtons

    @show_expand_collapse_entire_field_buttons.setter
    def show_expand_collapse_entire_field_buttons(self, value):
        """Alias for ShowExpandCollapseEntireFieldButtons.setter"""
        self.ShowExpandCollapseEntireFieldButtons = value

    @property
    def ShowLegendFieldButtons(self):
        return self.com_object.ShowLegendFieldButtons

    @ShowLegendFieldButtons.setter
    def ShowLegendFieldButtons(self, value):
        self.com_object.ShowLegendFieldButtons = value

    @property
    def showlegendfieldbuttons(self):
        """Alias for ShowLegendFieldButtons"""
        return self.ShowLegendFieldButtons

    @showlegendfieldbuttons.setter
    def showlegendfieldbuttons(self, value):
        """Alias for ShowLegendFieldButtons.setter"""
        self.ShowLegendFieldButtons = value

    @property
    def show_legend_field_buttons(self):
        """Alias for ShowLegendFieldButtons"""
        return self.ShowLegendFieldButtons

    @show_legend_field_buttons.setter
    def show_legend_field_buttons(self, value):
        """Alias for ShowLegendFieldButtons.setter"""
        self.ShowLegendFieldButtons = value

    @property
    def ShowReportFilterFieldButtons(self):
        return self.com_object.ShowReportFilterFieldButtons

    @ShowReportFilterFieldButtons.setter
    def ShowReportFilterFieldButtons(self, value):
        self.com_object.ShowReportFilterFieldButtons = value

    @property
    def showreportfilterfieldbuttons(self):
        """Alias for ShowReportFilterFieldButtons"""
        return self.ShowReportFilterFieldButtons

    @showreportfilterfieldbuttons.setter
    def showreportfilterfieldbuttons(self, value):
        """Alias for ShowReportFilterFieldButtons.setter"""
        self.ShowReportFilterFieldButtons = value

    @property
    def show_report_filter_field_buttons(self):
        """Alias for ShowReportFilterFieldButtons"""
        return self.ShowReportFilterFieldButtons

    @show_report_filter_field_buttons.setter
    def show_report_filter_field_buttons(self, value):
        """Alias for ShowReportFilterFieldButtons.setter"""
        self.ShowReportFilterFieldButtons = value

    @property
    def ShowValueFieldButtons(self):
        return self.com_object.ShowValueFieldButtons

    @ShowValueFieldButtons.setter
    def ShowValueFieldButtons(self, value):
        self.com_object.ShowValueFieldButtons = value

    @property
    def showvaluefieldbuttons(self):
        """Alias for ShowValueFieldButtons"""
        return self.ShowValueFieldButtons

    @showvaluefieldbuttons.setter
    def showvaluefieldbuttons(self, value):
        """Alias for ShowValueFieldButtons.setter"""
        self.ShowValueFieldButtons = value

    @property
    def show_value_field_buttons(self):
        """Alias for ShowValueFieldButtons"""
        return self.ShowValueFieldButtons

    @show_value_field_buttons.setter
    def show_value_field_buttons(self, value):
        """Alias for ShowValueFieldButtons.setter"""
        self.ShowValueFieldButtons = value

    @property
    def SideWall(self):
        return Walls(self.com_object.SideWall)

    @property
    def sidewall(self):
        """Alias for SideWall"""
        return self.SideWall

    @property
    def side_wall(self):
        """Alias for SideWall"""
        return self.SideWall

    @property
    def Tab(self):
        return Tab(self.com_object.Tab)

    @property
    def tab(self):
        """Alias for Tab"""
        return self.Tab

    @property
    def Visible(self):
        return XlSheetVisibility(self.com_object.Visible)

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Walls(self):
        return Walls(self.com_object.Walls)

    @property
    def walls(self):
        """Alias for Walls"""
        return self.Walls

    def Activate(self):
        self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()

    def ApplyChartTemplate(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        self.com_object.ApplyChartTemplate(*arguments)

    def applycharttemplate(self, FileName=None):
        """Alias for ApplyChartTemplate"""
        arguments = [FileName]
        return self.ApplyChartTemplate(*arguments)

    def apply_chart_template(self, FileName=None):
        """Alias for ApplyChartTemplate"""
        arguments = [FileName]
        return self.ApplyChartTemplate(*arguments)

    def ApplyDataLabels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        arguments = com_arguments([unwrap(a) for a in [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]])
        self.com_object.ApplyDataLabels(*arguments)

    def applydatalabels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        """Alias for ApplyDataLabels"""
        arguments = [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]
        return self.ApplyDataLabels(*arguments)

    def apply_data_labels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        """Alias for ApplyDataLabels"""
        arguments = [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]
        return self.ApplyDataLabels(*arguments)

    def ApplyLayout(self, Layout=None, ChartType=None):
        arguments = com_arguments([unwrap(a) for a in [Layout, ChartType]])
        self.com_object.ApplyLayout(*arguments)

    def applylayout(self, Layout=None, ChartType=None):
        """Alias for ApplyLayout"""
        arguments = [Layout, ChartType]
        return self.ApplyLayout(*arguments)

    def apply_layout(self, Layout=None, ChartType=None):
        """Alias for ApplyLayout"""
        arguments = [Layout, ChartType]
        return self.ApplyLayout(*arguments)

    def Axes(self, Type=None, AxisGroup=None):
        arguments = com_arguments([unwrap(a) for a in [Type, AxisGroup]])
        return self.com_object.Axes(*arguments)

    def axes(self, Type=None, AxisGroup=None):
        """Alias for Axes"""
        arguments = [Type, AxisGroup]
        return self.Axes(*arguments)

    def ChartGroups(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.ChartGroups(*arguments)

    def chartgroups(self, Index=None):
        """Alias for ChartGroups"""
        arguments = [Index]
        return self.ChartGroups(*arguments)

    def chart_groups(self, Index=None):
        """Alias for ChartGroups"""
        arguments = [Index]
        return self.ChartGroups(*arguments)

    def ChartObjects(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.ChartObjects(*arguments)

    def chartobjects(self, Index=None):
        """Alias for ChartObjects"""
        arguments = [Index]
        return self.ChartObjects(*arguments)

    def chart_objects(self, Index=None):
        """Alias for ChartObjects"""
        arguments = [Index]
        return self.ChartObjects(*arguments)

    def ChartWizard(self, Source=None, Gallery=None, Format=None, PlotBy=None, CategoryLabels=None, SeriesLabels=None, HasLegend=None, Title=None, CategoryTitle=None, ValueTitle=None, ExtraTitle=None):
        arguments = com_arguments([unwrap(a) for a in [Source, Gallery, Format, PlotBy, CategoryLabels, SeriesLabels, HasLegend, Title, CategoryTitle, ValueTitle, ExtraTitle]])
        self.com_object.ChartWizard(*arguments)

    def chartwizard(self, Source=None, Gallery=None, Format=None, PlotBy=None, CategoryLabels=None, SeriesLabels=None, HasLegend=None, Title=None, CategoryTitle=None, ValueTitle=None, ExtraTitle=None):
        """Alias for ChartWizard"""
        arguments = [Source, Gallery, Format, PlotBy, CategoryLabels, SeriesLabels, HasLegend, Title, CategoryTitle, ValueTitle, ExtraTitle]
        return self.ChartWizard(*arguments)

    def chart_wizard(self, Source=None, Gallery=None, Format=None, PlotBy=None, CategoryLabels=None, SeriesLabels=None, HasLegend=None, Title=None, CategoryTitle=None, ValueTitle=None, ExtraTitle=None):
        """Alias for ChartWizard"""
        arguments = [Source, Gallery, Format, PlotBy, CategoryLabels, SeriesLabels, HasLegend, Title, CategoryTitle, ValueTitle, ExtraTitle]
        return self.ChartWizard(*arguments)

    def CheckSpelling(self, CustomDictionary=None, IgnoreUppercase=None, AlwaysSuggest=None, SpellLang=None):
        arguments = com_arguments([unwrap(a) for a in [CustomDictionary, IgnoreUppercase, AlwaysSuggest, SpellLang]])
        self.com_object.CheckSpelling(*arguments)

    def checkspelling(self, CustomDictionary=None, IgnoreUppercase=None, AlwaysSuggest=None, SpellLang=None):
        """Alias for CheckSpelling"""
        arguments = [CustomDictionary, IgnoreUppercase, AlwaysSuggest, SpellLang]
        return self.CheckSpelling(*arguments)

    def check_spelling(self, CustomDictionary=None, IgnoreUppercase=None, AlwaysSuggest=None, SpellLang=None):
        """Alias for CheckSpelling"""
        arguments = [CustomDictionary, IgnoreUppercase, AlwaysSuggest, SpellLang]
        return self.CheckSpelling(*arguments)

    def ClearToMatchColorStyle(self):
        return self.com_object.ClearToMatchColorStyle()

    def cleartomatchcolorstyle(self):
        """Alias for ClearToMatchColorStyle"""
        return self.ClearToMatchColorStyle()

    def clear_to_match_color_style(self):
        """Alias for ClearToMatchColorStyle"""
        return self.ClearToMatchColorStyle()

    def ClearToMatchStyle(self):
        self.com_object.ClearToMatchStyle()

    def cleartomatchstyle(self):
        """Alias for ClearToMatchStyle"""
        return self.ClearToMatchStyle()

    def clear_to_match_style(self):
        """Alias for ClearToMatchStyle"""
        return self.ClearToMatchStyle()

    def Copy(self, Before=None, After=None):
        arguments = com_arguments([unwrap(a) for a in [Before, After]])
        self.com_object.Copy(*arguments)

    def copy(self, Before=None, After=None):
        """Alias for Copy"""
        arguments = [Before, After]
        return self.Copy(*arguments)

    def CopyPicture(self, Appearance=None, Format=None, Size=None):
        arguments = com_arguments([unwrap(a) for a in [Appearance, Format, Size]])
        self.com_object.CopyPicture(*arguments)

    def copypicture(self, Appearance=None, Format=None, Size=None):
        """Alias for CopyPicture"""
        arguments = [Appearance, Format, Size]
        return self.CopyPicture(*arguments)

    def copy_picture(self, Appearance=None, Format=None, Size=None):
        """Alias for CopyPicture"""
        arguments = [Appearance, Format, Size]
        return self.CopyPicture(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Evaluate(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        return self.com_object.Evaluate(*arguments)

    def evaluate(self, Name=None):
        """Alias for Evaluate"""
        arguments = [Name]
        return self.Evaluate(*arguments)

    def Export(self, FileName=None, FilterName=None, Interactive=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, FilterName, Interactive]])
        return self.com_object.Export(*arguments)

    def export(self, FileName=None, FilterName=None, Interactive=None):
        """Alias for Export"""
        arguments = [FileName, FilterName, Interactive]
        return self.Export(*arguments)

    def ExportAsFixedFormat(self, Type=None, FileName=None, Quality=None, IncludeDocProperties=None, IgnorePrintAreas=None, From=None, To=None, OpenAfterPublish=None, FixedFormatExtClassPtr=None):
        arguments = com_arguments([unwrap(a) for a in [Type, FileName, Quality, IncludeDocProperties, IgnorePrintAreas, From, To, OpenAfterPublish, FixedFormatExtClassPtr]])
        self.com_object.ExportAsFixedFormat(*arguments)

    def exportasfixedformat(self, Type=None, FileName=None, Quality=None, IncludeDocProperties=None, IgnorePrintAreas=None, From=None, To=None, OpenAfterPublish=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat"""
        arguments = [Type, FileName, Quality, IncludeDocProperties, IgnorePrintAreas, From, To, OpenAfterPublish, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat(*arguments)

    def export_as_fixed_format(self, Type=None, FileName=None, Quality=None, IncludeDocProperties=None, IgnorePrintAreas=None, From=None, To=None, OpenAfterPublish=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat"""
        arguments = [Type, FileName, Quality, IncludeDocProperties, IgnorePrintAreas, From, To, OpenAfterPublish, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat(*arguments)

    def FullSeriesCollection(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return FullSeriesCollection(self.com_object.FullSeriesCollection(*arguments))

    def fullseriescollection(self, Index=None):
        """Alias for FullSeriesCollection"""
        arguments = [Index]
        return self.FullSeriesCollection(*arguments)

    def full_series_collection(self, Index=None):
        """Alias for FullSeriesCollection"""
        arguments = [Index]
        return self.FullSeriesCollection(*arguments)

    def GetChartElement(self, x=None, y=None, ElementID=None, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [x, y, ElementID, Arg1, Arg2]])
        self.com_object.GetChartElement(*arguments)

    def getchartelement(self, x=None, y=None, ElementID=None, Arg1=None, Arg2=None):
        """Alias for GetChartElement"""
        arguments = [x, y, ElementID, Arg1, Arg2]
        return self.GetChartElement(*arguments)

    def get_chart_element(self, x=None, y=None, ElementID=None, Arg1=None, Arg2=None):
        """Alias for GetChartElement"""
        arguments = [x, y, ElementID, Arg1, Arg2]
        return self.GetChartElement(*arguments)

    def Location(self, Where=None, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Where, Name]])
        return self.com_object.Location(*arguments)

    def location(self, Where=None, Name=None):
        """Alias for Location"""
        arguments = [Where, Name]
        return self.Location(*arguments)

    def Move(self, Before=None, After=None):
        arguments = com_arguments([unwrap(a) for a in [Before, After]])
        self.com_object.Move(*arguments)

    def move(self, Before=None, After=None):
        """Alias for Move"""
        arguments = [Before, After]
        return self.Move(*arguments)

    def OLEObjects(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.OLEObjects(*arguments)

    def oleobjects(self, Index=None):
        """Alias for OLEObjects"""
        arguments = [Index]
        return self.OLEObjects(*arguments)

    def o_l_e_objects(self, Index=None):
        """Alias for OLEObjects"""
        arguments = [Index]
        return self.OLEObjects(*arguments)

    def Paste(self, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Type]])
        self.com_object.Paste(*arguments)

    def paste(self, Type=None):
        """Alias for Paste"""
        arguments = [Type]
        return self.Paste(*arguments)

    def PrintOut(self, From=None, To=None, Copies=None, Preview=None, ActivePrinter=None, PrintToFile=None, Collate=None, PrToFileName=None, IgnorePrintAreas=None):
        arguments = com_arguments([unwrap(a) for a in [From, To, Copies, Preview, ActivePrinter, PrintToFile, Collate, PrToFileName, IgnorePrintAreas]])
        return self.com_object.PrintOut(*arguments)

    def printout(self, From=None, To=None, Copies=None, Preview=None, ActivePrinter=None, PrintToFile=None, Collate=None, PrToFileName=None, IgnorePrintAreas=None):
        """Alias for PrintOut"""
        arguments = [From, To, Copies, Preview, ActivePrinter, PrintToFile, Collate, PrToFileName, IgnorePrintAreas]
        return self.PrintOut(*arguments)

    def print_out(self, From=None, To=None, Copies=None, Preview=None, ActivePrinter=None, PrintToFile=None, Collate=None, PrToFileName=None, IgnorePrintAreas=None):
        """Alias for PrintOut"""
        arguments = [From, To, Copies, Preview, ActivePrinter, PrintToFile, Collate, PrToFileName, IgnorePrintAreas]
        return self.PrintOut(*arguments)

    def PrintPreview(self, EnableChanges=None):
        arguments = com_arguments([unwrap(a) for a in [EnableChanges]])
        self.com_object.PrintPreview(*arguments)

    def printpreview(self, EnableChanges=None):
        """Alias for PrintPreview"""
        arguments = [EnableChanges]
        return self.PrintPreview(*arguments)

    def print_preview(self, EnableChanges=None):
        """Alias for PrintPreview"""
        arguments = [EnableChanges]
        return self.PrintPreview(*arguments)

    def Protect(self, Password=None, DrawingObjects=None, Contents=None, Scenarios=None, UserInterfaceOnly=None):
        arguments = com_arguments([unwrap(a) for a in [Password, DrawingObjects, Contents, Scenarios, UserInterfaceOnly]])
        self.com_object.Protect(*arguments)

    def protect(self, Password=None, DrawingObjects=None, Contents=None, Scenarios=None, UserInterfaceOnly=None):
        """Alias for Protect"""
        arguments = [Password, DrawingObjects, Contents, Scenarios, UserInterfaceOnly]
        return self.Protect(*arguments)

    def Refresh(self):
        self.com_object.Refresh()

    def refresh(self):
        """Alias for Refresh"""
        return self.Refresh()

    def SaveAs(self, FileName=None, FileFormat=None, Password=None, WriteResPassword=None, ReadOnlyRecommended=None, CreateBackup=None, AddToMru=None, TextCodepage=None, TextVisualLayout=None, Local=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, FileFormat, Password, WriteResPassword, ReadOnlyRecommended, CreateBackup, AddToMru, TextCodepage, TextVisualLayout, Local]])
        self.com_object.SaveAs(*arguments)

    def saveas(self, FileName=None, FileFormat=None, Password=None, WriteResPassword=None, ReadOnlyRecommended=None, CreateBackup=None, AddToMru=None, TextCodepage=None, TextVisualLayout=None, Local=None):
        """Alias for SaveAs"""
        arguments = [FileName, FileFormat, Password, WriteResPassword, ReadOnlyRecommended, CreateBackup, AddToMru, TextCodepage, TextVisualLayout, Local]
        return self.SaveAs(*arguments)

    def save_as(self, FileName=None, FileFormat=None, Password=None, WriteResPassword=None, ReadOnlyRecommended=None, CreateBackup=None, AddToMru=None, TextCodepage=None, TextVisualLayout=None, Local=None):
        """Alias for SaveAs"""
        arguments = [FileName, FileFormat, Password, WriteResPassword, ReadOnlyRecommended, CreateBackup, AddToMru, TextCodepage, TextVisualLayout, Local]
        return self.SaveAs(*arguments)

    def SaveChartTemplate(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        self.com_object.SaveChartTemplate(*arguments)

    def savecharttemplate(self, FileName=None):
        """Alias for SaveChartTemplate"""
        arguments = [FileName]
        return self.SaveChartTemplate(*arguments)

    def save_chart_template(self, FileName=None):
        """Alias for SaveChartTemplate"""
        arguments = [FileName]
        return self.SaveChartTemplate(*arguments)

    def Select(self, Replace=None):
        arguments = com_arguments([unwrap(a) for a in [Replace]])
        self.com_object.Select(*arguments)

    def select(self, Replace=None):
        """Alias for Select"""
        arguments = [Replace]
        return self.Select(*arguments)

    def SeriesCollection(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.SeriesCollection(*arguments)

    def seriescollection(self, Index=None):
        """Alias for SeriesCollection"""
        arguments = [Index]
        return self.SeriesCollection(*arguments)

    def series_collection(self, Index=None):
        """Alias for SeriesCollection"""
        arguments = [Index]
        return self.SeriesCollection(*arguments)

    def SetBackgroundPicture(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        self.com_object.SetBackgroundPicture(*arguments)

    def setbackgroundpicture(self, FileName=None):
        """Alias for SetBackgroundPicture"""
        arguments = [FileName]
        return self.SetBackgroundPicture(*arguments)

    def set_background_picture(self, FileName=None):
        """Alias for SetBackgroundPicture"""
        arguments = [FileName]
        return self.SetBackgroundPicture(*arguments)

    def SetDefaultChart(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        self.com_object.SetDefaultChart(*arguments)

    def setdefaultchart(self, Name=None):
        """Alias for SetDefaultChart"""
        arguments = [Name]
        return self.SetDefaultChart(*arguments)

    def set_default_chart(self, Name=None):
        """Alias for SetDefaultChart"""
        arguments = [Name]
        return self.SetDefaultChart(*arguments)

    def SetElement(self, Element=None):
        arguments = com_arguments([unwrap(a) for a in [Element]])
        return self.com_object.SetElement(*arguments)

    def setelement(self, Element=None):
        """Alias for SetElement"""
        arguments = [Element]
        return self.SetElement(*arguments)

    def set_element(self, Element=None):
        """Alias for SetElement"""
        arguments = [Element]
        return self.SetElement(*arguments)

    def SetSourceData(self, Source=None, PlotBy=None):
        arguments = com_arguments([unwrap(a) for a in [Source, PlotBy]])
        self.com_object.SetSourceData(*arguments)

    def setsourcedata(self, Source=None, PlotBy=None):
        """Alias for SetSourceData"""
        arguments = [Source, PlotBy]
        return self.SetSourceData(*arguments)

    def set_source_data(self, Source=None, PlotBy=None):
        """Alias for SetSourceData"""
        arguments = [Source, PlotBy]
        return self.SetSourceData(*arguments)

    def Unprotect(self, Password=None):
        arguments = com_arguments([unwrap(a) for a in [Password]])
        self.com_object.Unprotect(*arguments)

    def unprotect(self, Password=None):
        """Alias for Unprotect"""
        arguments = [Password]
        return self.Unprotect(*arguments)


class ChartArea:

    def __init__(self, chartarea=None):
        self.com_object= chartarea

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RoundedCorners(self):
        return self.com_object.RoundedCorners

    @RoundedCorners.setter
    def RoundedCorners(self, value):
        self.com_object.RoundedCorners = value

    @property
    def roundedcorners(self):
        """Alias for RoundedCorners"""
        return self.RoundedCorners

    @roundedcorners.setter
    def roundedcorners(self, value):
        """Alias for RoundedCorners.setter"""
        self.RoundedCorners = value

    @property
    def rounded_corners(self):
        """Alias for RoundedCorners"""
        return self.RoundedCorners

    @rounded_corners.setter
    def rounded_corners(self, value):
        """Alias for RoundedCorners.setter"""
        self.RoundedCorners = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Top(self):
        return self.com_object.Top

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Clear(self):
        return self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()

    def ClearContents(self):
        return self.com_object.ClearContents()

    def clearcontents(self):
        """Alias for ClearContents"""
        return self.ClearContents()

    def clear_contents(self):
        """Alias for ClearContents"""
        return self.ClearContents()

    def ClearFormats(self):
        return self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Copy(self):
        return self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Select(self):
        return self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class ChartCategory:

    def __init__(self, chartcategory=None):
        self.com_object= chartcategory

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def IsFiltered(self):
        return self.com_object.IsFiltered

    @property
    def isfiltered(self):
        """Alias for IsFiltered"""
        return self.IsFiltered

    @property
    def is_filtered(self):
        """Alias for IsFiltered"""
        return self.IsFiltered

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class ChartColorFormat:

    def __init__(self, chartcolorformat=None):
        self.com_object= chartcolorformat


class ChartFillFormat:

    def __init__(self, chartfillformat=None):
        self.com_object= chartfillformat


class ChartFormat:

    def __init__(self, chartformat=None):
        self.com_object= chartformat

    @property
    def Adjustments(self):
        return Adjustments(self.com_object.Adjustments)

    @property
    def adjustments(self):
        """Alias for Adjustments"""
        return self.Adjustments

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoShapeType(self):
        return self.com_object.AutoShapeType

    @property
    def autoshapetype(self):
        """Alias for AutoShapeType"""
        return self.AutoShapeType

    @property
    def auto_shape_type(self):
        """Alias for AutoShapeType"""
        return self.AutoShapeType

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Fill(self):
        return FillFormat(self.com_object.Fill)

    @property
    def fill(self):
        """Alias for Fill"""
        return self.Fill

    @property
    def Glow(self):
        return self.com_object.Glow

    @property
    def glow(self):
        """Alias for Glow"""
        return self.Glow

    @property
    def Line(self):
        return LineFormat(self.com_object.Line)

    @property
    def line(self):
        """Alias for Line"""
        return self.Line

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PictureFormat(self):
        return PictureFormat(self.com_object.PictureFormat)

    @property
    def pictureformat(self):
        """Alias for PictureFormat"""
        return self.PictureFormat

    @property
    def picture_format(self):
        """Alias for PictureFormat"""
        return self.PictureFormat

    @property
    def Shadow(self):
        return ShadowFormat(self.com_object.Shadow)

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @property
    def SoftEdge(self):
        return self.com_object.SoftEdge

    @property
    def softedge(self):
        """Alias for SoftEdge"""
        return self.SoftEdge

    @property
    def soft_edge(self):
        """Alias for SoftEdge"""
        return self.SoftEdge

    @property
    def TextFrame2(self):
        return TextFrame2(self.com_object.TextFrame2)

    @property
    def textframe2(self):
        """Alias for TextFrame2"""
        return self.TextFrame2

    @property
    def text_frame2(self):
        """Alias for TextFrame2"""
        return self.TextFrame2

    @property
    def ThreeD(self):
        return ThreeDFormat(self.com_object.ThreeD)

    @property
    def threed(self):
        """Alias for ThreeD"""
        return self.ThreeD

    @property
    def three_d(self):
        """Alias for ThreeD"""
        return self.ThreeD


class ChartGroup:

    def __init__(self, chartgroup=None):
        self.com_object= chartgroup

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AxisGroup(self):
        return self.com_object.AxisGroup

    @AxisGroup.setter
    def AxisGroup(self, value):
        self.com_object.AxisGroup = value

    @property
    def axisgroup(self):
        """Alias for AxisGroup"""
        return self.AxisGroup

    @axisgroup.setter
    def axisgroup(self, value):
        """Alias for AxisGroup.setter"""
        self.AxisGroup = value

    @property
    def axis_group(self):
        """Alias for AxisGroup"""
        return self.AxisGroup

    @axis_group.setter
    def axis_group(self, value):
        """Alias for AxisGroup.setter"""
        self.AxisGroup = value

    @property
    def BinsCountValue(self):
        return self.com_object.BinsCountValue

    @BinsCountValue.setter
    def BinsCountValue(self, value):
        self.com_object.BinsCountValue = value

    @property
    def binscountvalue(self):
        """Alias for BinsCountValue"""
        return self.BinsCountValue

    @binscountvalue.setter
    def binscountvalue(self, value):
        """Alias for BinsCountValue.setter"""
        self.BinsCountValue = value

    @property
    def bins_count_value(self):
        """Alias for BinsCountValue"""
        return self.BinsCountValue

    @bins_count_value.setter
    def bins_count_value(self, value):
        """Alias for BinsCountValue.setter"""
        self.BinsCountValue = value

    @property
    def BinsOverflowEnabled(self):
        return self.com_object.BinsOverflowEnabled

    @BinsOverflowEnabled.setter
    def BinsOverflowEnabled(self, value):
        self.com_object.BinsOverflowEnabled = value

    @property
    def binsoverflowenabled(self):
        """Alias for BinsOverflowEnabled"""
        return self.BinsOverflowEnabled

    @binsoverflowenabled.setter
    def binsoverflowenabled(self, value):
        """Alias for BinsOverflowEnabled.setter"""
        self.BinsOverflowEnabled = value

    @property
    def bins_overflow_enabled(self):
        """Alias for BinsOverflowEnabled"""
        return self.BinsOverflowEnabled

    @bins_overflow_enabled.setter
    def bins_overflow_enabled(self, value):
        """Alias for BinsOverflowEnabled.setter"""
        self.BinsOverflowEnabled = value

    @property
    def BinsOverflowValue(self):
        return self.com_object.BinsOverflowValue

    @BinsOverflowValue.setter
    def BinsOverflowValue(self, value):
        self.com_object.BinsOverflowValue = value

    @property
    def binsoverflowvalue(self):
        """Alias for BinsOverflowValue"""
        return self.BinsOverflowValue

    @binsoverflowvalue.setter
    def binsoverflowvalue(self, value):
        """Alias for BinsOverflowValue.setter"""
        self.BinsOverflowValue = value

    @property
    def bins_overflow_value(self):
        """Alias for BinsOverflowValue"""
        return self.BinsOverflowValue

    @bins_overflow_value.setter
    def bins_overflow_value(self, value):
        """Alias for BinsOverflowValue.setter"""
        self.BinsOverflowValue = value

    @property
    def BinsType(self):
        return self.com_object.BinsType

    @BinsType.setter
    def BinsType(self, value):
        self.com_object.BinsType = value

    @property
    def binstype(self):
        """Alias for BinsType"""
        return self.BinsType

    @binstype.setter
    def binstype(self, value):
        """Alias for BinsType.setter"""
        self.BinsType = value

    @property
    def bins_type(self):
        """Alias for BinsType"""
        return self.BinsType

    @bins_type.setter
    def bins_type(self, value):
        """Alias for BinsType.setter"""
        self.BinsType = value

    @property
    def BinsUnderflowEnabled(self):
        return self.com_object.BinsUnderflowEnabled

    @BinsUnderflowEnabled.setter
    def BinsUnderflowEnabled(self, value):
        self.com_object.BinsUnderflowEnabled = value

    @property
    def binsunderflowenabled(self):
        """Alias for BinsUnderflowEnabled"""
        return self.BinsUnderflowEnabled

    @binsunderflowenabled.setter
    def binsunderflowenabled(self, value):
        """Alias for BinsUnderflowEnabled.setter"""
        self.BinsUnderflowEnabled = value

    @property
    def bins_underflow_enabled(self):
        """Alias for BinsUnderflowEnabled"""
        return self.BinsUnderflowEnabled

    @bins_underflow_enabled.setter
    def bins_underflow_enabled(self, value):
        """Alias for BinsUnderflowEnabled.setter"""
        self.BinsUnderflowEnabled = value

    @property
    def BinsUnderflowValue(self):
        return self.com_object.BinsUnderflowValue

    @BinsUnderflowValue.setter
    def BinsUnderflowValue(self, value):
        self.com_object.BinsUnderflowValue = value

    @property
    def binsunderflowvalue(self):
        """Alias for BinsUnderflowValue"""
        return self.BinsUnderflowValue

    @binsunderflowvalue.setter
    def binsunderflowvalue(self, value):
        """Alias for BinsUnderflowValue.setter"""
        self.BinsUnderflowValue = value

    @property
    def bins_underflow_value(self):
        """Alias for BinsUnderflowValue"""
        return self.BinsUnderflowValue

    @bins_underflow_value.setter
    def bins_underflow_value(self, value):
        """Alias for BinsUnderflowValue.setter"""
        self.BinsUnderflowValue = value

    @property
    def BinWidthValue(self):
        return self.com_object.BinWidthValue

    @BinWidthValue.setter
    def BinWidthValue(self, value):
        self.com_object.BinWidthValue = value

    @property
    def binwidthvalue(self):
        """Alias for BinWidthValue"""
        return self.BinWidthValue

    @binwidthvalue.setter
    def binwidthvalue(self, value):
        """Alias for BinWidthValue.setter"""
        self.BinWidthValue = value

    @property
    def bin_width_value(self):
        """Alias for BinWidthValue"""
        return self.BinWidthValue

    @bin_width_value.setter
    def bin_width_value(self, value):
        """Alias for BinWidthValue.setter"""
        self.BinWidthValue = value

    @property
    def BubbleScale(self):
        return self.com_object.BubbleScale

    @BubbleScale.setter
    def BubbleScale(self, value):
        self.com_object.BubbleScale = value

    @property
    def bubblescale(self):
        """Alias for BubbleScale"""
        return self.BubbleScale

    @bubblescale.setter
    def bubblescale(self, value):
        """Alias for BubbleScale.setter"""
        self.BubbleScale = value

    @property
    def bubble_scale(self):
        """Alias for BubbleScale"""
        return self.BubbleScale

    @bubble_scale.setter
    def bubble_scale(self, value):
        """Alias for BubbleScale.setter"""
        self.BubbleScale = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DoughnutHoleSize(self):
        return self.com_object.DoughnutHoleSize

    @DoughnutHoleSize.setter
    def DoughnutHoleSize(self, value):
        self.com_object.DoughnutHoleSize = value

    @property
    def doughnutholesize(self):
        """Alias for DoughnutHoleSize"""
        return self.DoughnutHoleSize

    @doughnutholesize.setter
    def doughnutholesize(self, value):
        """Alias for DoughnutHoleSize.setter"""
        self.DoughnutHoleSize = value

    @property
    def doughnut_hole_size(self):
        """Alias for DoughnutHoleSize"""
        return self.DoughnutHoleSize

    @doughnut_hole_size.setter
    def doughnut_hole_size(self, value):
        """Alias for DoughnutHoleSize.setter"""
        self.DoughnutHoleSize = value

    @property
    def DownBars(self):
        return DownBars(self.com_object.DownBars)

    @property
    def downbars(self):
        """Alias for DownBars"""
        return self.DownBars

    @property
    def down_bars(self):
        """Alias for DownBars"""
        return self.DownBars

    @property
    def DropLines(self):
        return DropLines(self.com_object.DropLines)

    @property
    def droplines(self):
        """Alias for DropLines"""
        return self.DropLines

    @property
    def drop_lines(self):
        """Alias for DropLines"""
        return self.DropLines

    @property
    def FirstSliceAngle(self):
        return self.com_object.FirstSliceAngle

    @FirstSliceAngle.setter
    def FirstSliceAngle(self, value):
        self.com_object.FirstSliceAngle = value

    @property
    def firstsliceangle(self):
        """Alias for FirstSliceAngle"""
        return self.FirstSliceAngle

    @firstsliceangle.setter
    def firstsliceangle(self, value):
        """Alias for FirstSliceAngle.setter"""
        self.FirstSliceAngle = value

    @property
    def first_slice_angle(self):
        """Alias for FirstSliceAngle"""
        return self.FirstSliceAngle

    @first_slice_angle.setter
    def first_slice_angle(self, value):
        """Alias for FirstSliceAngle.setter"""
        self.FirstSliceAngle = value

    @property
    def GapWidth(self):
        return self.com_object.GapWidth

    @GapWidth.setter
    def GapWidth(self, value):
        self.com_object.GapWidth = value

    @property
    def gapwidth(self):
        """Alias for GapWidth"""
        return self.GapWidth

    @gapwidth.setter
    def gapwidth(self, value):
        """Alias for GapWidth.setter"""
        self.GapWidth = value

    @property
    def gap_width(self):
        """Alias for GapWidth"""
        return self.GapWidth

    @gap_width.setter
    def gap_width(self, value):
        """Alias for GapWidth.setter"""
        self.GapWidth = value

    @property
    def Has3DShading(self):
        return ChartGroup(self.com_object.Has3DShading)

    @Has3DShading.setter
    def Has3DShading(self, value):
        self.com_object.Has3DShading = value

    @property
    def has3dshading(self):
        """Alias for Has3DShading"""
        return self.Has3DShading

    @has3dshading.setter
    def has3dshading(self, value):
        """Alias for Has3DShading.setter"""
        self.Has3DShading = value

    @property
    def has3_d_shading(self):
        """Alias for Has3DShading"""
        return self.Has3DShading

    @has3_d_shading.setter
    def has3_d_shading(self, value):
        """Alias for Has3DShading.setter"""
        self.Has3DShading = value

    @property
    def HasDropLines(self):
        return self.com_object.HasDropLines

    @HasDropLines.setter
    def HasDropLines(self, value):
        self.com_object.HasDropLines = value

    @property
    def hasdroplines(self):
        """Alias for HasDropLines"""
        return self.HasDropLines

    @hasdroplines.setter
    def hasdroplines(self, value):
        """Alias for HasDropLines.setter"""
        self.HasDropLines = value

    @property
    def has_drop_lines(self):
        """Alias for HasDropLines"""
        return self.HasDropLines

    @has_drop_lines.setter
    def has_drop_lines(self, value):
        """Alias for HasDropLines.setter"""
        self.HasDropLines = value

    @property
    def HasHiLoLines(self):
        return self.com_object.HasHiLoLines

    @HasHiLoLines.setter
    def HasHiLoLines(self, value):
        self.com_object.HasHiLoLines = value

    @property
    def hashilolines(self):
        """Alias for HasHiLoLines"""
        return self.HasHiLoLines

    @hashilolines.setter
    def hashilolines(self, value):
        """Alias for HasHiLoLines.setter"""
        self.HasHiLoLines = value

    @property
    def has_hi_lo_lines(self):
        """Alias for HasHiLoLines"""
        return self.HasHiLoLines

    @has_hi_lo_lines.setter
    def has_hi_lo_lines(self, value):
        """Alias for HasHiLoLines.setter"""
        self.HasHiLoLines = value

    @property
    def HasRadarAxisLabels(self):
        return self.com_object.HasRadarAxisLabels

    @HasRadarAxisLabels.setter
    def HasRadarAxisLabels(self, value):
        self.com_object.HasRadarAxisLabels = value

    @property
    def hasradaraxislabels(self):
        """Alias for HasRadarAxisLabels"""
        return self.HasRadarAxisLabels

    @hasradaraxislabels.setter
    def hasradaraxislabels(self, value):
        """Alias for HasRadarAxisLabels.setter"""
        self.HasRadarAxisLabels = value

    @property
    def has_radar_axis_labels(self):
        """Alias for HasRadarAxisLabels"""
        return self.HasRadarAxisLabels

    @has_radar_axis_labels.setter
    def has_radar_axis_labels(self, value):
        """Alias for HasRadarAxisLabels.setter"""
        self.HasRadarAxisLabels = value

    @property
    def HasSeriesLines(self):
        return self.com_object.HasSeriesLines

    @HasSeriesLines.setter
    def HasSeriesLines(self, value):
        self.com_object.HasSeriesLines = value

    @property
    def hasserieslines(self):
        """Alias for HasSeriesLines"""
        return self.HasSeriesLines

    @hasserieslines.setter
    def hasserieslines(self, value):
        """Alias for HasSeriesLines.setter"""
        self.HasSeriesLines = value

    @property
    def has_series_lines(self):
        """Alias for HasSeriesLines"""
        return self.HasSeriesLines

    @has_series_lines.setter
    def has_series_lines(self, value):
        """Alias for HasSeriesLines.setter"""
        self.HasSeriesLines = value

    @property
    def HasUpDownBars(self):
        return self.com_object.HasUpDownBars

    @HasUpDownBars.setter
    def HasUpDownBars(self, value):
        self.com_object.HasUpDownBars = value

    @property
    def hasupdownbars(self):
        """Alias for HasUpDownBars"""
        return self.HasUpDownBars

    @hasupdownbars.setter
    def hasupdownbars(self, value):
        """Alias for HasUpDownBars.setter"""
        self.HasUpDownBars = value

    @property
    def has_up_down_bars(self):
        """Alias for HasUpDownBars"""
        return self.HasUpDownBars

    @has_up_down_bars.setter
    def has_up_down_bars(self, value):
        """Alias for HasUpDownBars.setter"""
        self.HasUpDownBars = value

    @property
    def HiLoLines(self):
        return HiLoLines(self.com_object.HiLoLines)

    @property
    def hilolines(self):
        """Alias for HiLoLines"""
        return self.HiLoLines

    @property
    def hi_lo_lines(self):
        """Alias for HiLoLines"""
        return self.HiLoLines

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Overlap(self):
        return self.com_object.Overlap

    @Overlap.setter
    def Overlap(self, value):
        self.com_object.Overlap = value

    @property
    def overlap(self):
        """Alias for Overlap"""
        return self.Overlap

    @overlap.setter
    def overlap(self, value):
        """Alias for Overlap.setter"""
        self.Overlap = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RadarAxisLabels(self):
        return TickLabels(self.com_object.RadarAxisLabels)

    @property
    def radaraxislabels(self):
        """Alias for RadarAxisLabels"""
        return self.RadarAxisLabels

    @property
    def radar_axis_labels(self):
        """Alias for RadarAxisLabels"""
        return self.RadarAxisLabels

    @property
    def SecondPlotSize(self):
        return self.com_object.SecondPlotSize

    @SecondPlotSize.setter
    def SecondPlotSize(self, value):
        self.com_object.SecondPlotSize = value

    @property
    def secondplotsize(self):
        """Alias for SecondPlotSize"""
        return self.SecondPlotSize

    @secondplotsize.setter
    def secondplotsize(self, value):
        """Alias for SecondPlotSize.setter"""
        self.SecondPlotSize = value

    @property
    def second_plot_size(self):
        """Alias for SecondPlotSize"""
        return self.SecondPlotSize

    @second_plot_size.setter
    def second_plot_size(self, value):
        """Alias for SecondPlotSize.setter"""
        self.SecondPlotSize = value

    @property
    def SeriesLines(self):
        return SeriesLines(self.com_object.SeriesLines)

    @property
    def serieslines(self):
        """Alias for SeriesLines"""
        return self.SeriesLines

    @property
    def series_lines(self):
        """Alias for SeriesLines"""
        return self.SeriesLines

    @property
    def ShowNegativeBubbles(self):
        return self.com_object.ShowNegativeBubbles

    @ShowNegativeBubbles.setter
    def ShowNegativeBubbles(self, value):
        self.com_object.ShowNegativeBubbles = value

    @property
    def shownegativebubbles(self):
        """Alias for ShowNegativeBubbles"""
        return self.ShowNegativeBubbles

    @shownegativebubbles.setter
    def shownegativebubbles(self, value):
        """Alias for ShowNegativeBubbles.setter"""
        self.ShowNegativeBubbles = value

    @property
    def show_negative_bubbles(self):
        """Alias for ShowNegativeBubbles"""
        return self.ShowNegativeBubbles

    @show_negative_bubbles.setter
    def show_negative_bubbles(self, value):
        """Alias for ShowNegativeBubbles.setter"""
        self.ShowNegativeBubbles = value

    @property
    def SizeRepresents(self):
        return XlSizeRepresents(self.com_object.SizeRepresents)

    @SizeRepresents.setter
    def SizeRepresents(self, value):
        self.com_object.SizeRepresents = value

    @property
    def sizerepresents(self):
        """Alias for SizeRepresents"""
        return self.SizeRepresents

    @sizerepresents.setter
    def sizerepresents(self, value):
        """Alias for SizeRepresents.setter"""
        self.SizeRepresents = value

    @property
    def size_represents(self):
        """Alias for SizeRepresents"""
        return self.SizeRepresents

    @size_represents.setter
    def size_represents(self, value):
        """Alias for SizeRepresents.setter"""
        self.SizeRepresents = value

    @property
    def SplitType(self):
        return XlChartSplitType(self.com_object.SplitType)

    @SplitType.setter
    def SplitType(self, value):
        self.com_object.SplitType = value

    @property
    def splittype(self):
        """Alias for SplitType"""
        return self.SplitType

    @splittype.setter
    def splittype(self, value):
        """Alias for SplitType.setter"""
        self.SplitType = value

    @property
    def split_type(self):
        """Alias for SplitType"""
        return self.SplitType

    @split_type.setter
    def split_type(self, value):
        """Alias for SplitType.setter"""
        self.SplitType = value

    @property
    def SplitValue(self):
        return self.com_object.SplitValue

    @SplitValue.setter
    def SplitValue(self, value):
        self.com_object.SplitValue = value

    @property
    def splitvalue(self):
        """Alias for SplitValue"""
        return self.SplitValue

    @splitvalue.setter
    def splitvalue(self, value):
        """Alias for SplitValue.setter"""
        self.SplitValue = value

    @property
    def split_value(self):
        """Alias for SplitValue"""
        return self.SplitValue

    @split_value.setter
    def split_value(self, value):
        """Alias for SplitValue.setter"""
        self.SplitValue = value

    @property
    def UpBars(self):
        return UpBars(self.com_object.UpBars)

    @property
    def upbars(self):
        """Alias for UpBars"""
        return self.UpBars

    @property
    def up_bars(self):
        """Alias for UpBars"""
        return self.UpBars

    @property
    def VaryByCategories(self):
        return self.com_object.VaryByCategories

    @VaryByCategories.setter
    def VaryByCategories(self, value):
        self.com_object.VaryByCategories = value

    @property
    def varybycategories(self):
        """Alias for VaryByCategories"""
        return self.VaryByCategories

    @varybycategories.setter
    def varybycategories(self, value):
        """Alias for VaryByCategories.setter"""
        self.VaryByCategories = value

    @property
    def vary_by_categories(self):
        """Alias for VaryByCategories"""
        return self.VaryByCategories

    @vary_by_categories.setter
    def vary_by_categories(self, value):
        """Alias for VaryByCategories.setter"""
        self.VaryByCategories = value

    def CategoryCollection(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.CategoryCollection(*arguments)

    def categorycollection(self, Index=None):
        """Alias for CategoryCollection"""
        arguments = [Index]
        return self.CategoryCollection(*arguments)

    def category_collection(self, Index=None):
        """Alias for CategoryCollection"""
        arguments = [Index]
        return self.CategoryCollection(*arguments)

    def FullCategoryCollection(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.FullCategoryCollection(*arguments)

    def fullcategorycollection(self, Index=None):
        """Alias for FullCategoryCollection"""
        arguments = [Index]
        return self.FullCategoryCollection(*arguments)

    def full_category_collection(self, Index=None):
        """Alias for FullCategoryCollection"""
        arguments = [Index]
        return self.FullCategoryCollection(*arguments)

    def SeriesCollection(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.SeriesCollection(*arguments)

    def seriescollection(self, Index=None):
        """Alias for SeriesCollection"""
        arguments = [Index]
        return self.SeriesCollection(*arguments)

    def series_collection(self, Index=None):
        """Alias for SeriesCollection"""
        arguments = [Index]
        return self.SeriesCollection(*arguments)


class ChartGroups:

    def __init__(self, chartgroups=None):
        self.com_object= chartgroups

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ChartGroup(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ChartObject:

    def __init__(self, chartobject=None):
        self.com_object= chartobject

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BottomRightCell(self):
        return Range(self.com_object.BottomRightCell)

    @property
    def bottomrightcell(self):
        """Alias for BottomRightCell"""
        return self.BottomRightCell

    @property
    def bottom_right_cell(self):
        """Alias for BottomRightCell"""
        return self.BottomRightCell

    @property
    def Chart(self):
        return Chart(self.com_object.Chart)

    @property
    def chart(self):
        """Alias for Chart"""
        return self.Chart

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Placement(self):
        return XlPlacement(self.com_object.Placement)

    @Placement.setter
    def Placement(self, value):
        self.com_object.Placement = value

    @property
    def placement(self):
        """Alias for Placement"""
        return self.Placement

    @placement.setter
    def placement(self, value):
        """Alias for Placement.setter"""
        self.Placement = value

    @property
    def PrintObject(self):
        return self.com_object.PrintObject

    @PrintObject.setter
    def PrintObject(self, value):
        self.com_object.PrintObject = value

    @property
    def printobject(self):
        """Alias for PrintObject"""
        return self.PrintObject

    @printobject.setter
    def printobject(self, value):
        """Alias for PrintObject.setter"""
        self.PrintObject = value

    @property
    def print_object(self):
        """Alias for PrintObject"""
        return self.PrintObject

    @print_object.setter
    def print_object(self, value):
        """Alias for PrintObject.setter"""
        self.PrintObject = value

    @property
    def ProtectChartObject(self):
        return self.com_object.ProtectChartObject

    @ProtectChartObject.setter
    def ProtectChartObject(self, value):
        self.com_object.ProtectChartObject = value

    @property
    def protectchartobject(self):
        """Alias for ProtectChartObject"""
        return self.ProtectChartObject

    @protectchartobject.setter
    def protectchartobject(self, value):
        """Alias for ProtectChartObject.setter"""
        self.ProtectChartObject = value

    @property
    def protect_chart_object(self):
        """Alias for ProtectChartObject"""
        return self.ProtectChartObject

    @protect_chart_object.setter
    def protect_chart_object(self, value):
        """Alias for ProtectChartObject.setter"""
        self.ProtectChartObject = value

    @property
    def RoundedCorners(self):
        return self.com_object.RoundedCorners

    @RoundedCorners.setter
    def RoundedCorners(self, value):
        self.com_object.RoundedCorners = value

    @property
    def roundedcorners(self):
        """Alias for RoundedCorners"""
        return self.RoundedCorners

    @roundedcorners.setter
    def roundedcorners(self, value):
        """Alias for RoundedCorners.setter"""
        self.RoundedCorners = value

    @property
    def rounded_corners(self):
        """Alias for RoundedCorners"""
        return self.RoundedCorners

    @rounded_corners.setter
    def rounded_corners(self, value):
        """Alias for RoundedCorners.setter"""
        self.RoundedCorners = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def ShapeRange(self):
        return ShapeRange(self.com_object.ShapeRange)

    @property
    def shaperange(self):
        """Alias for ShapeRange"""
        return self.ShapeRange

    @property
    def shape_range(self):
        """Alias for ShapeRange"""
        return self.ShapeRange

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TopLeftCell(self):
        return Range(self.com_object.TopLeftCell)

    @property
    def topleftcell(self):
        """Alias for TopLeftCell"""
        return self.TopLeftCell

    @property
    def top_left_cell(self):
        """Alias for TopLeftCell"""
        return self.TopLeftCell

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def ZOrder(self):
        return self.com_object.ZOrder

    @property
    def zorder(self):
        """Alias for ZOrder"""
        return self.ZOrder

    @property
    def z_order(self):
        """Alias for ZOrder"""
        return self.ZOrder

    def Activate(self):
        return self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()

    def BringToFront(self):
        return self.com_object.BringToFront()

    def bringtofront(self):
        """Alias for BringToFront"""
        return self.BringToFront()

    def bring_to_front(self):
        """Alias for BringToFront"""
        return self.BringToFront()

    def Copy(self):
        return self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def CopyPicture(self, Appearance=None, Format=None):
        arguments = com_arguments([unwrap(a) for a in [Appearance, Format]])
        return self.com_object.CopyPicture(*arguments)

    def copypicture(self, Appearance=None, Format=None):
        """Alias for CopyPicture"""
        arguments = [Appearance, Format]
        return self.CopyPicture(*arguments)

    def copy_picture(self, Appearance=None, Format=None):
        """Alias for CopyPicture"""
        arguments = [Appearance, Format]
        return self.CopyPicture(*arguments)

    def Cut(self):
        return self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Duplicate(self):
        return self.com_object.Duplicate()

    def duplicate(self):
        """Alias for Duplicate"""
        return self.Duplicate()

    def Select(self, Replace=None):
        arguments = com_arguments([unwrap(a) for a in [Replace]])
        return self.com_object.Select(*arguments)

    def select(self, Replace=None):
        """Alias for Select"""
        arguments = [Replace]
        return self.Select(*arguments)

    def SendToBack(self):
        return self.com_object.SendToBack()

    def sendtoback(self):
        """Alias for SendToBack"""
        return self.SendToBack()

    def send_to_back(self):
        """Alias for SendToBack"""
        return self.SendToBack()


class ChartObjects:

    def __init__(self, chartobjects=None):
        self.com_object= chartobjects

    def __call__(self, item):
        return ChartObject(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Placement(self):
        return XlPlacement(self.com_object.Placement)

    @Placement.setter
    def Placement(self, value):
        self.com_object.Placement = value

    @property
    def placement(self):
        """Alias for Placement"""
        return self.Placement

    @placement.setter
    def placement(self, value):
        """Alias for Placement.setter"""
        self.Placement = value

    @property
    def PrintObject(self):
        return self.com_object.PrintObject

    @PrintObject.setter
    def PrintObject(self, value):
        self.com_object.PrintObject = value

    @property
    def printobject(self):
        """Alias for PrintObject"""
        return self.PrintObject

    @printobject.setter
    def printobject(self, value):
        """Alias for PrintObject.setter"""
        self.PrintObject = value

    @property
    def print_object(self):
        """Alias for PrintObject"""
        return self.PrintObject

    @print_object.setter
    def print_object(self, value):
        """Alias for PrintObject.setter"""
        self.PrintObject = value

    @property
    def ProtectChartObject(self):
        return self.com_object.ProtectChartObject

    @ProtectChartObject.setter
    def ProtectChartObject(self, value):
        self.com_object.ProtectChartObject = value

    @property
    def protectchartobject(self):
        """Alias for ProtectChartObject"""
        return self.ProtectChartObject

    @protectchartobject.setter
    def protectchartobject(self, value):
        """Alias for ProtectChartObject.setter"""
        self.ProtectChartObject = value

    @property
    def protect_chart_object(self):
        """Alias for ProtectChartObject"""
        return self.ProtectChartObject

    @protect_chart_object.setter
    def protect_chart_object(self, value):
        """Alias for ProtectChartObject.setter"""
        self.ProtectChartObject = value

    @property
    def ShapeRange(self):
        return ShapeRange(self.com_object.ShapeRange)

    @property
    def shaperange(self):
        """Alias for ShapeRange"""
        return self.ShapeRange

    @property
    def shape_range(self):
        """Alias for ShapeRange"""
        return self.ShapeRange

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Add(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        return ChartObject(self.com_object.Add(*arguments))

    def add(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Add"""
        arguments = [Left, Top, Width, Height]
        return self.Add(*arguments)

    def Copy(self):
        return self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def CopyPicture(self, Appearance=None, Format=None):
        arguments = com_arguments([unwrap(a) for a in [Appearance, Format]])
        return self.com_object.CopyPicture(*arguments)

    def copypicture(self, Appearance=None, Format=None):
        """Alias for CopyPicture"""
        arguments = [Appearance, Format]
        return self.CopyPicture(*arguments)

    def copy_picture(self, Appearance=None, Format=None):
        """Alias for CopyPicture"""
        arguments = [Appearance, Format]
        return self.CopyPicture(*arguments)

    def Cut(self):
        return self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Duplicate(self):
        return self.com_object.Duplicate()

    def duplicate(self):
        """Alias for Duplicate"""
        return self.Duplicate()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Select(self, Replace=None):
        arguments = com_arguments([unwrap(a) for a in [Replace]])
        return self.com_object.Select(*arguments)

    def select(self, Replace=None):
        """Alias for Select"""
        arguments = [Replace]
        return self.Select(*arguments)


class Charts:

    def __init__(self, charts=None):
        self.com_object= charts

    def __call__(self, item):
        return Chart(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def HPageBreaks(self):
        return HPageBreaks(self.com_object.HPageBreaks)

    @property
    def hpagebreaks(self):
        """Alias for HPageBreaks"""
        return self.HPageBreaks

    @property
    def h_page_breaks(self):
        """Alias for HPageBreaks"""
        return self.HPageBreaks

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def VPageBreaks(self):
        return VPageBreaks(self.com_object.VPageBreaks)

    @property
    def vpagebreaks(self):
        """Alias for VPageBreaks"""
        return self.VPageBreaks

    @property
    def v_page_breaks(self):
        """Alias for VPageBreaks"""
        return self.VPageBreaks

    def Add2(self, Before=None, After=None, Count=None, NewLayout=None):
        arguments = com_arguments([unwrap(a) for a in [Before, After, Count, NewLayout]])
        return CHART(self.com_object.Add2(*arguments))

    def add2(self, Before=None, After=None, Count=None, NewLayout=None):
        """Alias for Add2"""
        arguments = [Before, After, Count, NewLayout]
        return self.Add2(*arguments)

    def Copy(self, Before=None, After=None):
        arguments = com_arguments([unwrap(a) for a in [Before, After]])
        self.com_object.Copy(*arguments)

    def copy(self, Before=None, After=None):
        """Alias for Copy"""
        arguments = [Before, After]
        return self.Copy(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Move(self, Before=None, After=None):
        arguments = com_arguments([unwrap(a) for a in [Before, After]])
        self.com_object.Move(*arguments)

    def move(self, Before=None, After=None):
        """Alias for Move"""
        arguments = [Before, After]
        return self.Move(*arguments)

    def PrintOut(self, From=None, To=None, Copies=None, Preview=None, ActivePrinter=None, PrintToFile=None, Collate=None, PrToFileName=None, IgnorePrintAreas=None):
        arguments = com_arguments([unwrap(a) for a in [From, To, Copies, Preview, ActivePrinter, PrintToFile, Collate, PrToFileName, IgnorePrintAreas]])
        return self.com_object.PrintOut(*arguments)

    def printout(self, From=None, To=None, Copies=None, Preview=None, ActivePrinter=None, PrintToFile=None, Collate=None, PrToFileName=None, IgnorePrintAreas=None):
        """Alias for PrintOut"""
        arguments = [From, To, Copies, Preview, ActivePrinter, PrintToFile, Collate, PrToFileName, IgnorePrintAreas]
        return self.PrintOut(*arguments)

    def print_out(self, From=None, To=None, Copies=None, Preview=None, ActivePrinter=None, PrintToFile=None, Collate=None, PrToFileName=None, IgnorePrintAreas=None):
        """Alias for PrintOut"""
        arguments = [From, To, Copies, Preview, ActivePrinter, PrintToFile, Collate, PrToFileName, IgnorePrintAreas]
        return self.PrintOut(*arguments)

    def PrintPreview(self, EnableChanges=None):
        arguments = com_arguments([unwrap(a) for a in [EnableChanges]])
        self.com_object.PrintPreview(*arguments)

    def printpreview(self, EnableChanges=None):
        """Alias for PrintPreview"""
        arguments = [EnableChanges]
        return self.PrintPreview(*arguments)

    def print_preview(self, EnableChanges=None):
        """Alias for PrintPreview"""
        arguments = [EnableChanges]
        return self.PrintPreview(*arguments)

    def Select(self, Replace=None):
        arguments = com_arguments([unwrap(a) for a in [Replace]])
        self.com_object.Select(*arguments)

    def select(self, Replace=None):
        """Alias for Select"""
        arguments = [Replace]
        return self.Select(*arguments)


class ChartTitle:

    def __init__(self, charttitle=None):
        self.com_object= charttitle

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    def Characters(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        if hasattr(self.com_object, "GetCharacters"):
            return Characters(self.com_object.GetCharacters(*arguments))
        else:
            return Characters(self.com_object.Characters(*arguments))

    def characters(self, Start=None, Length=None):
        """Alias for Characters"""
        arguments = [Start, Length]
        return self.Characters(*arguments)

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def FormulaLocal(self):
        return self.com_object.FormulaLocal

    @FormulaLocal.setter
    def FormulaLocal(self, value):
        self.com_object.FormulaLocal = value

    @property
    def formulalocal(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formulalocal.setter
    def formulalocal(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def formula_local(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formula_local.setter
    def formula_local(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def FormulaR1C1(self):
        return self.com_object.FormulaR1C1

    @FormulaR1C1.setter
    def FormulaR1C1(self, value):
        self.com_object.FormulaR1C1 = value

    @property
    def formular1c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formular1c1.setter
    def formular1c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def formula_r1_c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formula_r1_c1.setter
    def formula_r1_c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def FormulaR1C1Local(self):
        return self.com_object.FormulaR1C1Local

    @FormulaR1C1Local.setter
    def FormulaR1C1Local(self, value):
        self.com_object.FormulaR1C1Local = value

    @property
    def formular1c1local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formular1c1local.setter
    def formular1c1local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def formula_r1_c1_local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formula_r1_c1_local.setter
    def formula_r1_c1_local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def HorizontalAlignment(self):
        return self.com_object.HorizontalAlignment

    @HorizontalAlignment.setter
    def HorizontalAlignment(self, value):
        self.com_object.HorizontalAlignment = value

    @property
    def horizontalalignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontalalignment.setter
    def horizontalalignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def horizontal_alignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def IncludeInLayout(self):
        return self.com_object.IncludeInLayout

    @IncludeInLayout.setter
    def IncludeInLayout(self, value):
        self.com_object.IncludeInLayout = value

    @property
    def includeinlayout(self):
        """Alias for IncludeInLayout"""
        return self.IncludeInLayout

    @includeinlayout.setter
    def includeinlayout(self, value):
        """Alias for IncludeInLayout.setter"""
        self.IncludeInLayout = value

    @property
    def include_in_layout(self):
        """Alias for IncludeInLayout"""
        return self.IncludeInLayout

    @include_in_layout.setter
    def include_in_layout(self, value):
        """Alias for IncludeInLayout.setter"""
        self.IncludeInLayout = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return XlChartElementPosition(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def ReadingOrder(self):
        return self.com_object.ReadingOrder

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def VerticalAlignment(self):
        return self.com_object.VerticalAlignment

    @VerticalAlignment.setter
    def VerticalAlignment(self, value):
        self.com_object.VerticalAlignment = value

    @property
    def verticalalignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @verticalalignment.setter
    def verticalalignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def vertical_alignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @vertical_alignment.setter
    def vertical_alignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        return self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class ChartView:

    def __init__(self, chartview=None):
        self.com_object= chartview

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Sheet(self):
        return ChartView(self.com_object.Sheet)

    @property
    def sheet(self):
        """Alias for Sheet"""
        return self.Sheet


class ColorFormat:

    def __init__(self, colorformat=None):
        self.com_object= colorformat

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Brightness(self):
        return self.com_object.Brightness

    @Brightness.setter
    def Brightness(self, value):
        self.com_object.Brightness = value

    @property
    def brightness(self):
        """Alias for Brightness"""
        return self.Brightness

    @brightness.setter
    def brightness(self, value):
        """Alias for Brightness.setter"""
        self.Brightness = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ObjectThemeColor(self):
        return self.com_object.ObjectThemeColor

    @ObjectThemeColor.setter
    def ObjectThemeColor(self, value):
        self.com_object.ObjectThemeColor = value

    @property
    def objectthemecolor(self):
        """Alias for ObjectThemeColor"""
        return self.ObjectThemeColor

    @objectthemecolor.setter
    def objectthemecolor(self, value):
        """Alias for ObjectThemeColor.setter"""
        self.ObjectThemeColor = value

    @property
    def object_theme_color(self):
        """Alias for ObjectThemeColor"""
        return self.ObjectThemeColor

    @object_theme_color.setter
    def object_theme_color(self, value):
        """Alias for ObjectThemeColor.setter"""
        self.ObjectThemeColor = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RGB(self):
        return self.com_object.RGB

    @RGB.setter
    def RGB(self, value):
        self.com_object.RGB = value

    @property
    def rgb(self):
        """Alias for RGB"""
        return self.RGB

    @rgb.setter
    def rgb(self, value):
        """Alias for RGB.setter"""
        self.RGB = value

    @property
    def r_g_b(self):
        """Alias for RGB"""
        return self.RGB

    @r_g_b.setter
    def r_g_b(self, value):
        """Alias for RGB.setter"""
        self.RGB = value

    @property
    def SchemeColor(self):
        return self.com_object.SchemeColor

    @SchemeColor.setter
    def SchemeColor(self, value):
        self.com_object.SchemeColor = value

    @property
    def schemecolor(self):
        """Alias for SchemeColor"""
        return self.SchemeColor

    @schemecolor.setter
    def schemecolor(self, value):
        """Alias for SchemeColor.setter"""
        self.SchemeColor = value

    @property
    def scheme_color(self):
        """Alias for SchemeColor"""
        return self.SchemeColor

    @scheme_color.setter
    def scheme_color(self, value):
        """Alias for SchemeColor.setter"""
        self.SchemeColor = value

    @property
    def TintAndShade(self):
        return self.com_object.TintAndShade

    @TintAndShade.setter
    def TintAndShade(self, value):
        self.com_object.TintAndShade = value

    @property
    def tintandshade(self):
        """Alias for TintAndShade"""
        return self.TintAndShade

    @tintandshade.setter
    def tintandshade(self, value):
        """Alias for TintAndShade.setter"""
        self.TintAndShade = value

    @property
    def tint_and_shade(self):
        """Alias for TintAndShade"""
        return self.TintAndShade

    @tint_and_shade.setter
    def tint_and_shade(self, value):
        """Alias for TintAndShade.setter"""
        self.TintAndShade = value

    @property
    def Type(self):
        return self.com_object.Type

    @property
    def type(self):
        """Alias for Type"""
        return self.Type


class ColorScale:

    def __init__(self, colorscale=None):
        self.com_object= colorscale

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AppliesTo(self):
        return Range(self.com_object.AppliesTo)

    @property
    def appliesto(self):
        """Alias for AppliesTo"""
        return self.AppliesTo

    @property
    def applies_to(self):
        """Alias for AppliesTo"""
        return self.AppliesTo

    @property
    def ColorScaleCriteria(self):
        return ColorScaleCriteria(self.com_object.ColorScaleCriteria)

    @property
    def colorscalecriteria(self):
        """Alias for ColorScaleCriteria"""
        return self.ColorScaleCriteria

    @property
    def color_scale_criteria(self):
        """Alias for ColorScaleCriteria"""
        return self.ColorScaleCriteria

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Priority(self):
        return self.com_object.Priority

    @Priority.setter
    def Priority(self, value):
        self.com_object.Priority = value

    @property
    def priority(self):
        """Alias for Priority"""
        return self.Priority

    @priority.setter
    def priority(self, value):
        """Alias for Priority.setter"""
        self.Priority = value

    @property
    def PTCondition(self):
        return self.com_object.PTCondition

    @property
    def ptcondition(self):
        """Alias for PTCondition"""
        return self.PTCondition

    @property
    def p_t_condition(self):
        """Alias for PTCondition"""
        return self.PTCondition

    @property
    def ScopeType(self):
        return XlPivotConditionScope(self.com_object.ScopeType)

    @ScopeType.setter
    def ScopeType(self, value):
        self.com_object.ScopeType = value

    @property
    def scopetype(self):
        """Alias for ScopeType"""
        return self.ScopeType

    @scopetype.setter
    def scopetype(self, value):
        """Alias for ScopeType.setter"""
        self.ScopeType = value

    @property
    def scope_type(self):
        """Alias for ScopeType"""
        return self.ScopeType

    @scope_type.setter
    def scope_type(self, value):
        """Alias for ScopeType.setter"""
        self.ScopeType = value

    @property
    def StopIfTrue(self):
        return self.com_object.StopIfTrue

    @StopIfTrue.setter
    def StopIfTrue(self, value):
        self.com_object.StopIfTrue = value

    @property
    def stopiftrue(self):
        """Alias for StopIfTrue"""
        return self.StopIfTrue

    @stopiftrue.setter
    def stopiftrue(self, value):
        """Alias for StopIfTrue.setter"""
        self.StopIfTrue = value

    @property
    def stop_if_true(self):
        """Alias for StopIfTrue"""
        return self.StopIfTrue

    @stop_if_true.setter
    def stop_if_true(self, value):
        """Alias for StopIfTrue.setter"""
        self.StopIfTrue = value

    @property
    def Type(self):
        return XlFormatConditionType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def ModifyAppliesToRange(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        self.com_object.ModifyAppliesToRange(*arguments)

    def modifyappliestorange(self, Range=None):
        """Alias for ModifyAppliesToRange"""
        arguments = [Range]
        return self.ModifyAppliesToRange(*arguments)

    def modify_applies_to_range(self, Range=None):
        """Alias for ModifyAppliesToRange"""
        arguments = [Range]
        return self.ModifyAppliesToRange(*arguments)

    def SetFirstPriority(self):
        self.com_object.SetFirstPriority()

    def setfirstpriority(self):
        """Alias for SetFirstPriority"""
        return self.SetFirstPriority()

    def set_first_priority(self):
        """Alias for SetFirstPriority"""
        return self.SetFirstPriority()

    def SetLastPriority(self):
        self.com_object.SetLastPriority()

    def setlastpriority(self):
        """Alias for SetLastPriority"""
        return self.SetLastPriority()

    def set_last_priority(self):
        """Alias for SetLastPriority"""
        return self.SetLastPriority()


class ColorScaleCriteria:

    def __init__(self, colorscalecriteria=None):
        self.com_object= colorscalecriteria

    def __call__(self, item):
        return ColorScaleCriteria(self.com_object(item))

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return ColorScaleCriterion(self.com_object.GetItem(*arguments))
        else:
            return ColorScaleCriterion(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ColorScaleCriterion:

    def __init__(self, colorscalecriterion=None):
        self.com_object= colorscalecriterion

    @property
    def FormatColor(self):
        return FormatColor(self.com_object.FormatColor)

    @property
    def formatcolor(self):
        """Alias for FormatColor"""
        return self.FormatColor

    @property
    def format_color(self):
        """Alias for FormatColor"""
        return self.FormatColor

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Type(self):
        return XlConditionValueTypes(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value


class ColorStop:

    def __init__(self, colorstop=None):
        self.com_object= colorstop

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Color(self):
        return self.com_object.Color

    @Color.setter
    def Color(self, value):
        self.com_object.Color = value

    @property
    def color(self):
        """Alias for Color"""
        return self.Color

    @color.setter
    def color(self, value):
        """Alias for Color.setter"""
        self.Color = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return ColorStop(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def ThemeColor(self):
        return self.com_object.ThemeColor

    @ThemeColor.setter
    def ThemeColor(self, value):
        self.com_object.ThemeColor = value

    @property
    def themecolor(self):
        """Alias for ThemeColor"""
        return self.ThemeColor

    @themecolor.setter
    def themecolor(self, value):
        """Alias for ThemeColor.setter"""
        self.ThemeColor = value

    @property
    def theme_color(self):
        """Alias for ThemeColor"""
        return self.ThemeColor

    @theme_color.setter
    def theme_color(self, value):
        """Alias for ThemeColor.setter"""
        self.ThemeColor = value

    @property
    def TintAndShade(self):
        return self.com_object.TintAndShade

    @TintAndShade.setter
    def TintAndShade(self, value):
        self.com_object.TintAndShade = value

    @property
    def tintandshade(self):
        """Alias for TintAndShade"""
        return self.TintAndShade

    @tintandshade.setter
    def tintandshade(self, value):
        """Alias for TintAndShade.setter"""
        self.TintAndShade = value

    @property
    def tint_and_shade(self):
        """Alias for TintAndShade"""
        return self.TintAndShade

    @tint_and_shade.setter
    def tint_and_shade(self, value):
        """Alias for TintAndShade.setter"""
        self.TintAndShade = value

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class ColorStops:

    def __init__(self, colorstops=None):
        self.com_object= colorstops

    def __call__(self, item):
        return ColorStop(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @Count.setter
    def Count(self, value):
        self.com_object.Count = value

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @count.setter
    def count(self, value):
        """Alias for Count.setter"""
        self.Count = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Position=None):
        arguments = com_arguments([unwrap(a) for a in [Position]])
        return ColorStop(self.com_object.Add(*arguments))

    def add(self, Position=None):
        """Alias for Add"""
        arguments = [Position]
        return self.Add(*arguments)

    def Clear(self):
        return self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ColorStops(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Comment:

    def __init__(self, comment=None):
        self.com_object= comment

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Author(self):
        return self.com_object.Author

    @property
    def author(self):
        """Alias for Author"""
        return self.Author

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Shape(self):
        return Shape(self.com_object.Shape)

    @property
    def shape(self):
        """Alias for Shape"""
        return self.Shape

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Next(self):
        return Comment(self.com_object.Next())

    def next(self):
        """Alias for Next"""
        return self.Next()

    def Previous(self):
        return Comment(self.com_object.Previous())

    def previous(self):
        """Alias for Previous"""
        return self.Previous()

    def Text(self, Text=None, Start=None, Overwrite=None):
        arguments = com_arguments([unwrap(a) for a in [Text, Start, Overwrite]])
        return self.com_object.Text(*arguments)

    def text(self, Text=None, Start=None, Overwrite=None):
        """Alias for Text"""
        arguments = [Text, Start, Overwrite]
        return self.Text(*arguments)


class Comments:

    def __init__(self, comments=None):
        self.com_object= comments

    def __call__(self, item):
        return Comment(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Comment(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class CommentsThreaded:

    def __init__(self, commentsthreaded=None):
        self.com_object= commentsthreaded

    def __call__(self, item):
        return CommentsThreaded(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return CommentThreaded(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class CommentThreaded:

    def __init__(self, commentthreaded=None):
        self.com_object= commentthreaded

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Author(self):
        return Author(self.com_object.Author)

    @property
    def author(self):
        """Alias for Author"""
        return self.Author

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Date(self):
        return self.com_object.Date

    @property
    def date(self):
        """Alias for Date"""
        return self.Date

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Replies(self):
        return self.com_object.Replies

    @property
    def replies(self):
        """Alias for Replies"""
        return self.Replies

    def AddReply(self, Text=None):
        arguments = com_arguments([unwrap(a) for a in [Text]])
        return CommentThreaded(self.com_object.AddReply(*arguments))

    def addreply(self, Text=None):
        """Alias for AddReply"""
        arguments = [Text]
        return self.AddReply(*arguments)

    def add_reply(self, Text=None):
        """Alias for AddReply"""
        arguments = [Text]
        return self.AddReply(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Next(self):
        return CommentThreaded(self.com_object.Next())

    def next(self):
        """Alias for Next"""
        return self.Next()

    def Previous(self):
        return CommentThreaded(self.com_object.Previous())

    def previous(self):
        """Alias for Previous"""
        return self.Previous()

    def Text(self, Text=None, Start=None, Overwrite=None):
        arguments = com_arguments([unwrap(a) for a in [Text, Start, Overwrite]])
        return self.com_object.Text(*arguments)

    def text(self, Text=None, Start=None, Overwrite=None):
        """Alias for Text"""
        arguments = [Text, Start, Overwrite]
        return self.Text(*arguments)


class ConditionValue:

    def __init__(self, conditionvalue=None):
        self.com_object= conditionvalue

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Type(self):
        return XlConditionValueTypes(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    def Modify(self, NewType=None, NewValue=None):
        arguments = com_arguments([unwrap(a) for a in [NewType, NewValue]])
        self.com_object.Modify(*arguments)

    def modify(self, NewType=None, NewValue=None):
        """Alias for Modify"""
        arguments = [NewType, NewValue]
        return self.Modify(*arguments)


class Connections:

    def __init__(self, connections=None):
        self.com_object= connections

    def __call__(self, item):
        return Connection(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, Description=None, ConnectionString=None, CommandText=None, lCmdtype=None, CreateModelConnection=None, ImportRelationships=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Description, ConnectionString, CommandText, lCmdtype, CreateModelConnection, ImportRelationships]])
        return WorkbookConnection(self.com_object.Add(*arguments))

    def add(self, Name=None, Description=None, ConnectionString=None, CommandText=None, lCmdtype=None, CreateModelConnection=None, ImportRelationships=None):
        """Alias for Add"""
        arguments = [Name, Description, ConnectionString, CommandText, lCmdtype, CreateModelConnection, ImportRelationships]
        return self.Add(*arguments)

    def AddFromFile(self, FileName=None, CreateModelConnection=None, ImportRelationships=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, CreateModelConnection, ImportRelationships]])
        return WorkbookConnection(self.com_object.AddFromFile(*arguments))

    def addfromfile(self, FileName=None, CreateModelConnection=None, ImportRelationships=None):
        """Alias for AddFromFile"""
        arguments = [FileName, CreateModelConnection, ImportRelationships]
        return self.AddFromFile(*arguments)

    def add_from_file(self, FileName=None, CreateModelConnection=None, ImportRelationships=None):
        """Alias for AddFromFile"""
        arguments = [FileName, CreateModelConnection, ImportRelationships]
        return self.AddFromFile(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return WorkbookConnection(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ConnectorFormat:

    def __init__(self, connectorformat=None):
        self.com_object= connectorformat

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BeginConnected(self):
        return self.com_object.BeginConnected

    @property
    def beginconnected(self):
        """Alias for BeginConnected"""
        return self.BeginConnected

    @property
    def begin_connected(self):
        """Alias for BeginConnected"""
        return self.BeginConnected

    @property
    def BeginConnectedShape(self):
        return Shape(self.com_object.BeginConnectedShape)

    @property
    def beginconnectedshape(self):
        """Alias for BeginConnectedShape"""
        return self.BeginConnectedShape

    @property
    def begin_connected_shape(self):
        """Alias for BeginConnectedShape"""
        return self.BeginConnectedShape

    @property
    def BeginConnectionSite(self):
        return self.com_object.BeginConnectionSite

    @property
    def beginconnectionsite(self):
        """Alias for BeginConnectionSite"""
        return self.BeginConnectionSite

    @property
    def begin_connection_site(self):
        """Alias for BeginConnectionSite"""
        return self.BeginConnectionSite

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def EndConnected(self):
        return self.com_object.EndConnected

    @property
    def endconnected(self):
        """Alias for EndConnected"""
        return self.EndConnected

    @property
    def end_connected(self):
        """Alias for EndConnected"""
        return self.EndConnected

    @property
    def EndConnectedShape(self):
        return Shape(self.com_object.EndConnectedShape)

    @property
    def endconnectedshape(self):
        """Alias for EndConnectedShape"""
        return self.EndConnectedShape

    @property
    def end_connected_shape(self):
        """Alias for EndConnectedShape"""
        return self.EndConnectedShape

    @property
    def EndConnectionSite(self):
        return self.com_object.EndConnectionSite

    @property
    def endconnectionsite(self):
        """Alias for EndConnectionSite"""
        return self.EndConnectionSite

    @property
    def end_connection_site(self):
        """Alias for EndConnectionSite"""
        return self.EndConnectionSite

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    def BeginConnect(self, ConnectedShape=None, ConnectionSite=None):
        arguments = com_arguments([unwrap(a) for a in [ConnectedShape, ConnectionSite]])
        self.com_object.BeginConnect(*arguments)

    def beginconnect(self, ConnectedShape=None, ConnectionSite=None):
        """Alias for BeginConnect"""
        arguments = [ConnectedShape, ConnectionSite]
        return self.BeginConnect(*arguments)

    def begin_connect(self, ConnectedShape=None, ConnectionSite=None):
        """Alias for BeginConnect"""
        arguments = [ConnectedShape, ConnectionSite]
        return self.BeginConnect(*arguments)

    def BeginDisconnect(self):
        self.com_object.BeginDisconnect()

    def begindisconnect(self):
        """Alias for BeginDisconnect"""
        return self.BeginDisconnect()

    def begin_disconnect(self):
        """Alias for BeginDisconnect"""
        return self.BeginDisconnect()

    def EndConnect(self, ConnectedShape=None, ConnectionSite=None):
        arguments = com_arguments([unwrap(a) for a in [ConnectedShape, ConnectionSite]])
        self.com_object.EndConnect(*arguments)

    def endconnect(self, ConnectedShape=None, ConnectionSite=None):
        """Alias for EndConnect"""
        arguments = [ConnectedShape, ConnectionSite]
        return self.EndConnect(*arguments)

    def end_connect(self, ConnectedShape=None, ConnectionSite=None):
        """Alias for EndConnect"""
        arguments = [ConnectedShape, ConnectionSite]
        return self.EndConnect(*arguments)

    def EndDisconnect(self):
        self.com_object.EndDisconnect()

    def enddisconnect(self):
        """Alias for EndDisconnect"""
        return self.EndDisconnect()

    def end_disconnect(self):
        """Alias for EndDisconnect"""
        return self.EndDisconnect()


# Constants enumeration
xl3DBar = -4099
xl3DEffects1 = 13
xl3DEffects2 = 14
xl3DSurface = -4103
xlAbove = 0
xlAccounting1 = 4
xlAccounting2 = 5
xlAccounting4 = 17
xlAdd = 2
xlAll = -4104
xlAccounting3 = 6
xlAllExceptBorders = 7
xlAutomatic = -4105
xlBar = 2
xlBelow = 1
xlBidi = -5000
xlBidiCalendar = 3
xlBoth = 1
xlBottom = -4107
xlCascade = 7
xlCenter = -4108
xlCenterAcrossSelection = 7
xlChart4 = 2
xlChartSeries = 17
xlChartShort = 6
xlChartTitles = 18
xlChecker = 9
xlCircle = 8
xlClassic1 = 1
xlClassic2 = 2
xlClassic3 = 3
xlClosed = 3
xlColor1 = 7
xlColor2 = 8
xlColor3 = 9
xlColumn = 3
xlCombination = -4111
xlComplete = 4
xlConstants = 2
xlContents = 2
xlContext = -5002
xlCorner = 2
xlCrissCross = 16
xlCross = 4
xlCustom = -4114
xlDebugCodePane = 13
xlDefaultAutoFormat = -1
xlDesktop = 9
xlDiamond = 2
xlDirect = 1
xlDistributed = -4117
xlDivide = 5
xlDoubleAccounting = 5
xlDoubleClosed = 5
xlDoubleOpen = 4
xlDoubleQuote = 1
xlDrawingObject = 14
xlEntireChart = 20
xlExcelMenus = 1
xlExtended = 3
xlFill = 5
xlFirst = 0
xlFixedValue = 1
xlFloating = 5
xlFormats = -4122
xlFormula = 5
xlFullScript = 1
xlGeneral = 1
xlGray16 = 17
xlGray25 = -4124
xlGray50 = -4125
xlGray75 = -4126
xlGray8 = 18
xlGregorian = 2
xlGrid = 15
xlGridline = 22
xlHigh = -4127
xlHindiNumerals = 3
xlIcons = 1
xlImmediatePane = 12
xlInside = 2
xlInteger = 2
xlJustify = -4130
xlLast = 1
xlLastCell = 11
xlLatin = -5001
xlLeft = -4131
xlLeftToRight = 2
xlLightDown = 13
xlLightHorizontal = 11
xlLightUp = 14
xlLightVertical = 12
xlList1 = 10
xlList2 = 11
xlList3 = 12
xlLocalFormat1 = 15
xlLocalFormat2 = 16
xlLogicalCursor = 1
xlLong = 3
xlLotusHelp = 2
xlLow = -4134
xlLTR = -5003
xlMacrosheetCell = 7
xlManual = -4135
xlMaximum = 2
xlMinimum = 4
xlMinusValues = 3
xlMixed = 2
xlMixedAuthorizedScript = 4
xlMixedScript = 3
xlModule = -4141
xlMultiply = 4
xlNarrow = 1
xlNextToAxis = 4
xlNoDocuments = 3
xlNone = -4142
xlNotes = -4144
xlOff = -4146
xlOn = 1
xlOpaque = 3
xlOpen = 2
xlOutside = 3
xlPartial = 3
xlPartialScript = 2
xlPercent = 2
xlPlus = 9
xlPlusValues = 2
xlReference = 4
xlRight = -4152
xlRTL = -5004
xlScale = 3
xlSemiautomatic = 2
xlSemiGray75 = 10
xlShort = 1
xlShowLabel = 4
xlShowLabelAndPercent = 5
xlShowPercent = 3
xlShowValue = 2
xlSimple = -4154
xlSingle = 2
xlSingleAccounting = 4
xlSingleQuote = 2
xlSolid = 1
xlSquare = 1
xlStar = 5
xlStError = 4
xlStrict = 2
xlSubtract = 3
xlSystem = 1
xlTextBox = 16
xlTiled = 1
xlTitleBar = 8
xlToolbar = 1
xlToolbarButton = 2
xlTop = -4160
xlTopToBottom = 1
xlTransparent = 2
xlTriangle = 3
xlVeryHidden = 2
xlVisible = 12
xlVisualCursor = 2
xlWatchPane = 11
xlWide = 3
xlWorkbookTab = 6
xlWorksheet4 = 1
xlWorksheetCell = 3
xlWorksheetShort = 5

class ControlFormat:

    def __init__(self, controlformat=None):
        self.com_object= controlformat

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DropDownLines(self):
        return self.com_object.DropDownLines

    @DropDownLines.setter
    def DropDownLines(self, value):
        self.com_object.DropDownLines = value

    @property
    def dropdownlines(self):
        """Alias for DropDownLines"""
        return self.DropDownLines

    @dropdownlines.setter
    def dropdownlines(self, value):
        """Alias for DropDownLines.setter"""
        self.DropDownLines = value

    @property
    def drop_down_lines(self):
        """Alias for DropDownLines"""
        return self.DropDownLines

    @drop_down_lines.setter
    def drop_down_lines(self, value):
        """Alias for DropDownLines.setter"""
        self.DropDownLines = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def LargeChange(self):
        return self.com_object.LargeChange

    @LargeChange.setter
    def LargeChange(self, value):
        self.com_object.LargeChange = value

    @property
    def largechange(self):
        """Alias for LargeChange"""
        return self.LargeChange

    @largechange.setter
    def largechange(self, value):
        """Alias for LargeChange.setter"""
        self.LargeChange = value

    @property
    def large_change(self):
        """Alias for LargeChange"""
        return self.LargeChange

    @large_change.setter
    def large_change(self, value):
        """Alias for LargeChange.setter"""
        self.LargeChange = value

    @property
    def LinkedCell(self):
        return self.com_object.LinkedCell

    @LinkedCell.setter
    def LinkedCell(self, value):
        self.com_object.LinkedCell = value

    @property
    def linkedcell(self):
        """Alias for LinkedCell"""
        return self.LinkedCell

    @linkedcell.setter
    def linkedcell(self, value):
        """Alias for LinkedCell.setter"""
        self.LinkedCell = value

    @property
    def linked_cell(self):
        """Alias for LinkedCell"""
        return self.LinkedCell

    @linked_cell.setter
    def linked_cell(self, value):
        """Alias for LinkedCell.setter"""
        self.LinkedCell = value

    @property
    def ListCount(self):
        return self.com_object.ListCount

    @property
    def listcount(self):
        """Alias for ListCount"""
        return self.ListCount

    @property
    def list_count(self):
        """Alias for ListCount"""
        return self.ListCount

    @property
    def ListFillRange(self):
        return self.com_object.ListFillRange

    @ListFillRange.setter
    def ListFillRange(self, value):
        self.com_object.ListFillRange = value

    @property
    def listfillrange(self):
        """Alias for ListFillRange"""
        return self.ListFillRange

    @listfillrange.setter
    def listfillrange(self, value):
        """Alias for ListFillRange.setter"""
        self.ListFillRange = value

    @property
    def list_fill_range(self):
        """Alias for ListFillRange"""
        return self.ListFillRange

    @list_fill_range.setter
    def list_fill_range(self, value):
        """Alias for ListFillRange.setter"""
        self.ListFillRange = value

    @property
    def ListIndex(self):
        return self.com_object.ListIndex

    @ListIndex.setter
    def ListIndex(self, value):
        self.com_object.ListIndex = value

    @property
    def listindex(self):
        """Alias for ListIndex"""
        return self.ListIndex

    @listindex.setter
    def listindex(self, value):
        """Alias for ListIndex.setter"""
        self.ListIndex = value

    @property
    def list_index(self):
        """Alias for ListIndex"""
        return self.ListIndex

    @list_index.setter
    def list_index(self, value):
        """Alias for ListIndex.setter"""
        self.ListIndex = value

    @property
    def LockedText(self):
        return self.com_object.LockedText

    @LockedText.setter
    def LockedText(self, value):
        self.com_object.LockedText = value

    @property
    def lockedtext(self):
        """Alias for LockedText"""
        return self.LockedText

    @lockedtext.setter
    def lockedtext(self, value):
        """Alias for LockedText.setter"""
        self.LockedText = value

    @property
    def locked_text(self):
        """Alias for LockedText"""
        return self.LockedText

    @locked_text.setter
    def locked_text(self, value):
        """Alias for LockedText.setter"""
        self.LockedText = value

    @property
    def Max(self):
        return self.com_object.Max

    @Max.setter
    def Max(self, value):
        self.com_object.Max = value

    @property
    def max(self):
        """Alias for Max"""
        return self.Max

    @max.setter
    def max(self, value):
        """Alias for Max.setter"""
        self.Max = value

    @property
    def Min(self):
        return self.com_object.Min

    @Min.setter
    def Min(self, value):
        self.com_object.Min = value

    @property
    def min(self):
        """Alias for Min"""
        return self.Min

    @min.setter
    def min(self, value):
        """Alias for Min.setter"""
        self.Min = value

    @property
    def MultiSelect(self):
        return self.com_object.MultiSelect

    @MultiSelect.setter
    def MultiSelect(self, value):
        self.com_object.MultiSelect = value

    @property
    def multiselect(self):
        """Alias for MultiSelect"""
        return self.MultiSelect

    @multiselect.setter
    def multiselect(self, value):
        """Alias for MultiSelect.setter"""
        self.MultiSelect = value

    @property
    def multi_select(self):
        """Alias for MultiSelect"""
        return self.MultiSelect

    @multi_select.setter
    def multi_select(self, value):
        """Alias for MultiSelect.setter"""
        self.MultiSelect = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PrintObject(self):
        return self.com_object.PrintObject

    @PrintObject.setter
    def PrintObject(self, value):
        self.com_object.PrintObject = value

    @property
    def printobject(self):
        """Alias for PrintObject"""
        return self.PrintObject

    @printobject.setter
    def printobject(self, value):
        """Alias for PrintObject.setter"""
        self.PrintObject = value

    @property
    def print_object(self):
        """Alias for PrintObject"""
        return self.PrintObject

    @print_object.setter
    def print_object(self, value):
        """Alias for PrintObject.setter"""
        self.PrintObject = value

    @property
    def SmallChange(self):
        return self.com_object.SmallChange

    @SmallChange.setter
    def SmallChange(self, value):
        self.com_object.SmallChange = value

    @property
    def smallchange(self):
        """Alias for SmallChange"""
        return self.SmallChange

    @smallchange.setter
    def smallchange(self, value):
        """Alias for SmallChange.setter"""
        self.SmallChange = value

    @property
    def small_change(self):
        """Alias for SmallChange"""
        return self.SmallChange

    @small_change.setter
    def small_change(self, value):
        """Alias for SmallChange.setter"""
        self.SmallChange = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    def AddItem(self, Text=None, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Text, Index]])
        self.com_object.AddItem(*arguments)

    def additem(self, Text=None, Index=None):
        """Alias for AddItem"""
        arguments = [Text, Index]
        return self.AddItem(*arguments)

    def add_item(self, Text=None, Index=None):
        """Alias for AddItem"""
        arguments = [Text, Index]
        return self.AddItem(*arguments)

    def List(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.List(*arguments)

    def list(self, Index=None):
        """Alias for List"""
        arguments = [Index]
        return self.List(*arguments)

    def RemoveAllItems(self):
        self.com_object.RemoveAllItems()

    def removeallitems(self):
        """Alias for RemoveAllItems"""
        return self.RemoveAllItems()

    def remove_all_items(self):
        """Alias for RemoveAllItems"""
        return self.RemoveAllItems()

    def RemoveItem(self, Index=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [Index, Count]])
        self.com_object.RemoveItem(*arguments)

    def removeitem(self, Index=None, Count=None):
        """Alias for RemoveItem"""
        arguments = [Index, Count]
        return self.RemoveItem(*arguments)

    def remove_item(self, Index=None, Count=None):
        """Alias for RemoveItem"""
        arguments = [Index, Count]
        return self.RemoveItem(*arguments)


class CubeField:

    def __init__(self, cubefield=None):
        self.com_object= cubefield

    @property
    def AllItemsVisible(self):
        return self.com_object.AllItemsVisible

    @property
    def allitemsvisible(self):
        """Alias for AllItemsVisible"""
        return self.AllItemsVisible

    @property
    def all_items_visible(self):
        """Alias for AllItemsVisible"""
        return self.AllItemsVisible

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Caption(self):
        return self.com_object.Caption

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def CubeFieldSubType(self):
        return self.com_object.CubeFieldSubType

    @property
    def cubefieldsubtype(self):
        """Alias for CubeFieldSubType"""
        return self.CubeFieldSubType

    @property
    def cube_field_sub_type(self):
        """Alias for CubeFieldSubType"""
        return self.CubeFieldSubType

    @property
    def CubeFieldType(self):
        return self.com_object.CubeFieldType

    @property
    def cubefieldtype(self):
        """Alias for CubeFieldType"""
        return self.CubeFieldType

    @property
    def cube_field_type(self):
        """Alias for CubeFieldType"""
        return self.CubeFieldType

    @property
    def CurrentPageName(self):
        return self.com_object.CurrentPageName

    @CurrentPageName.setter
    def CurrentPageName(self, value):
        self.com_object.CurrentPageName = value

    @property
    def currentpagename(self):
        """Alias for CurrentPageName"""
        return self.CurrentPageName

    @currentpagename.setter
    def currentpagename(self, value):
        """Alias for CurrentPageName.setter"""
        self.CurrentPageName = value

    @property
    def current_page_name(self):
        """Alias for CurrentPageName"""
        return self.CurrentPageName

    @current_page_name.setter
    def current_page_name(self, value):
        """Alias for CurrentPageName.setter"""
        self.CurrentPageName = value

    @property
    def DragToColumn(self):
        return self.com_object.DragToColumn

    @DragToColumn.setter
    def DragToColumn(self, value):
        self.com_object.DragToColumn = value

    @property
    def dragtocolumn(self):
        """Alias for DragToColumn"""
        return self.DragToColumn

    @dragtocolumn.setter
    def dragtocolumn(self, value):
        """Alias for DragToColumn.setter"""
        self.DragToColumn = value

    @property
    def drag_to_column(self):
        """Alias for DragToColumn"""
        return self.DragToColumn

    @drag_to_column.setter
    def drag_to_column(self, value):
        """Alias for DragToColumn.setter"""
        self.DragToColumn = value

    @property
    def DragToData(self):
        return self.com_object.DragToData

    @DragToData.setter
    def DragToData(self, value):
        self.com_object.DragToData = value

    @property
    def dragtodata(self):
        """Alias for DragToData"""
        return self.DragToData

    @dragtodata.setter
    def dragtodata(self, value):
        """Alias for DragToData.setter"""
        self.DragToData = value

    @property
    def drag_to_data(self):
        """Alias for DragToData"""
        return self.DragToData

    @drag_to_data.setter
    def drag_to_data(self, value):
        """Alias for DragToData.setter"""
        self.DragToData = value

    @property
    def DragToHide(self):
        return self.com_object.DragToHide

    @DragToHide.setter
    def DragToHide(self, value):
        self.com_object.DragToHide = value

    @property
    def dragtohide(self):
        """Alias for DragToHide"""
        return self.DragToHide

    @dragtohide.setter
    def dragtohide(self, value):
        """Alias for DragToHide.setter"""
        self.DragToHide = value

    @property
    def drag_to_hide(self):
        """Alias for DragToHide"""
        return self.DragToHide

    @drag_to_hide.setter
    def drag_to_hide(self, value):
        """Alias for DragToHide.setter"""
        self.DragToHide = value

    @property
    def DragToPage(self):
        return self.com_object.DragToPage

    @DragToPage.setter
    def DragToPage(self, value):
        self.com_object.DragToPage = value

    @property
    def dragtopage(self):
        """Alias for DragToPage"""
        return self.DragToPage

    @dragtopage.setter
    def dragtopage(self, value):
        """Alias for DragToPage.setter"""
        self.DragToPage = value

    @property
    def drag_to_page(self):
        """Alias for DragToPage"""
        return self.DragToPage

    @drag_to_page.setter
    def drag_to_page(self, value):
        """Alias for DragToPage.setter"""
        self.DragToPage = value

    @property
    def DragToRow(self):
        return self.com_object.DragToRow

    @DragToRow.setter
    def DragToRow(self, value):
        self.com_object.DragToRow = value

    @property
    def dragtorow(self):
        """Alias for DragToRow"""
        return self.DragToRow

    @dragtorow.setter
    def dragtorow(self, value):
        """Alias for DragToRow.setter"""
        self.DragToRow = value

    @property
    def drag_to_row(self):
        """Alias for DragToRow"""
        return self.DragToRow

    @drag_to_row.setter
    def drag_to_row(self, value):
        """Alias for DragToRow.setter"""
        self.DragToRow = value

    @property
    def EnableMultiplePageItems(self):
        return self.com_object.EnableMultiplePageItems

    @EnableMultiplePageItems.setter
    def EnableMultiplePageItems(self, value):
        self.com_object.EnableMultiplePageItems = value

    @property
    def enablemultiplepageitems(self):
        """Alias for EnableMultiplePageItems"""
        return self.EnableMultiplePageItems

    @enablemultiplepageitems.setter
    def enablemultiplepageitems(self, value):
        """Alias for EnableMultiplePageItems.setter"""
        self.EnableMultiplePageItems = value

    @property
    def enable_multiple_page_items(self):
        """Alias for EnableMultiplePageItems"""
        return self.EnableMultiplePageItems

    @enable_multiple_page_items.setter
    def enable_multiple_page_items(self, value):
        """Alias for EnableMultiplePageItems.setter"""
        self.EnableMultiplePageItems = value

    @property
    def FlattenHierarchies(self):
        return self.com_object.FlattenHierarchies

    @FlattenHierarchies.setter
    def FlattenHierarchies(self, value):
        self.com_object.FlattenHierarchies = value

    @property
    def flattenhierarchies(self):
        """Alias for FlattenHierarchies"""
        return self.FlattenHierarchies

    @flattenhierarchies.setter
    def flattenhierarchies(self, value):
        """Alias for FlattenHierarchies.setter"""
        self.FlattenHierarchies = value

    @property
    def flatten_hierarchies(self):
        """Alias for FlattenHierarchies"""
        return self.FlattenHierarchies

    @flatten_hierarchies.setter
    def flatten_hierarchies(self, value):
        """Alias for FlattenHierarchies.setter"""
        self.FlattenHierarchies = value

    @property
    def HasMemberProperties(self):
        return self.com_object.HasMemberProperties

    @property
    def hasmemberproperties(self):
        """Alias for HasMemberProperties"""
        return self.HasMemberProperties

    @property
    def has_member_properties(self):
        """Alias for HasMemberProperties"""
        return self.HasMemberProperties

    @property
    def HierarchizeDistinct(self):
        return self.com_object.HierarchizeDistinct

    @HierarchizeDistinct.setter
    def HierarchizeDistinct(self, value):
        self.com_object.HierarchizeDistinct = value

    @property
    def hierarchizedistinct(self):
        """Alias for HierarchizeDistinct"""
        return self.HierarchizeDistinct

    @hierarchizedistinct.setter
    def hierarchizedistinct(self, value):
        """Alias for HierarchizeDistinct.setter"""
        self.HierarchizeDistinct = value

    @property
    def hierarchize_distinct(self):
        """Alias for HierarchizeDistinct"""
        return self.HierarchizeDistinct

    @hierarchize_distinct.setter
    def hierarchize_distinct(self, value):
        """Alias for HierarchizeDistinct.setter"""
        self.HierarchizeDistinct = value

    @property
    def IncludeNewItemsInFilter(self):
        return self.com_object.IncludeNewItemsInFilter

    @IncludeNewItemsInFilter.setter
    def IncludeNewItemsInFilter(self, value):
        self.com_object.IncludeNewItemsInFilter = value

    @property
    def includenewitemsinfilter(self):
        """Alias for IncludeNewItemsInFilter"""
        return self.IncludeNewItemsInFilter

    @includenewitemsinfilter.setter
    def includenewitemsinfilter(self, value):
        """Alias for IncludeNewItemsInFilter.setter"""
        self.IncludeNewItemsInFilter = value

    @property
    def include_new_items_in_filter(self):
        """Alias for IncludeNewItemsInFilter"""
        return self.IncludeNewItemsInFilter

    @include_new_items_in_filter.setter
    def include_new_items_in_filter(self, value):
        """Alias for IncludeNewItemsInFilter.setter"""
        self.IncludeNewItemsInFilter = value

    @property
    def IsDate(self):
        return self.com_object.IsDate

    @property
    def isdate(self):
        """Alias for IsDate"""
        return self.IsDate

    @property
    def is_date(self):
        """Alias for IsDate"""
        return self.IsDate

    @property
    def LayoutForm(self):
        return XlLayoutFormType(self.com_object.LayoutForm)

    @LayoutForm.setter
    def LayoutForm(self, value):
        self.com_object.LayoutForm = value

    @property
    def layoutform(self):
        """Alias for LayoutForm"""
        return self.LayoutForm

    @layoutform.setter
    def layoutform(self, value):
        """Alias for LayoutForm.setter"""
        self.LayoutForm = value

    @property
    def layout_form(self):
        """Alias for LayoutForm"""
        return self.LayoutForm

    @layout_form.setter
    def layout_form(self, value):
        """Alias for LayoutForm.setter"""
        self.LayoutForm = value

    @property
    def LayoutSubtotalLocation(self):
        return XlSubtotalLocationType(self.com_object.LayoutSubtotalLocation)

    @LayoutSubtotalLocation.setter
    def LayoutSubtotalLocation(self, value):
        self.com_object.LayoutSubtotalLocation = value

    @property
    def layoutsubtotallocation(self):
        """Alias for LayoutSubtotalLocation"""
        return self.LayoutSubtotalLocation

    @layoutsubtotallocation.setter
    def layoutsubtotallocation(self, value):
        """Alias for LayoutSubtotalLocation.setter"""
        self.LayoutSubtotalLocation = value

    @property
    def layout_subtotal_location(self):
        """Alias for LayoutSubtotalLocation"""
        return self.LayoutSubtotalLocation

    @layout_subtotal_location.setter
    def layout_subtotal_location(self, value):
        """Alias for LayoutSubtotalLocation.setter"""
        self.LayoutSubtotalLocation = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Orientation(self):
        return XlPivotFieldOrientation(self.com_object.Orientation)

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PivotFields(self):
        return PivotFields(self.com_object.PivotFields)

    @property
    def pivotfields(self):
        """Alias for PivotFields"""
        return self.PivotFields

    @property
    def pivot_fields(self):
        """Alias for PivotFields"""
        return self.PivotFields

    @property
    def Position(self):
        return self.com_object.Position

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def ShowInFieldList(self):
        return self.com_object.ShowInFieldList

    @ShowInFieldList.setter
    def ShowInFieldList(self, value):
        self.com_object.ShowInFieldList = value

    @property
    def showinfieldlist(self):
        """Alias for ShowInFieldList"""
        return self.ShowInFieldList

    @showinfieldlist.setter
    def showinfieldlist(self, value):
        """Alias for ShowInFieldList.setter"""
        self.ShowInFieldList = value

    @property
    def show_in_field_list(self):
        """Alias for ShowInFieldList"""
        return self.ShowInFieldList

    @show_in_field_list.setter
    def show_in_field_list(self, value):
        """Alias for ShowInFieldList.setter"""
        self.ShowInFieldList = value

    @property
    def TreeviewControl(self):
        return TreeviewControl(self.com_object.TreeviewControl)

    @property
    def treeviewcontrol(self):
        """Alias for TreeviewControl"""
        return self.TreeviewControl

    @property
    def treeview_control(self):
        """Alias for TreeviewControl"""
        return self.TreeviewControl

    @property
    def Value(self):
        return self.com_object.Value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    def AddMemberPropertyField(self, Property=None, PropertyOrder=None, PropertyDisplayedIn=None):
        arguments = com_arguments([unwrap(a) for a in [Property, PropertyOrder, PropertyDisplayedIn]])
        self.com_object.AddMemberPropertyField(*arguments)

    def addmemberpropertyfield(self, Property=None, PropertyOrder=None, PropertyDisplayedIn=None):
        """Alias for AddMemberPropertyField"""
        arguments = [Property, PropertyOrder, PropertyDisplayedIn]
        return self.AddMemberPropertyField(*arguments)

    def add_member_property_field(self, Property=None, PropertyOrder=None, PropertyDisplayedIn=None):
        """Alias for AddMemberPropertyField"""
        arguments = [Property, PropertyOrder, PropertyDisplayedIn]
        return self.AddMemberPropertyField(*arguments)

    def AutoGroup(self, Orientation=None, Position=None):
        arguments = com_arguments([unwrap(a) for a in [Orientation, Position]])
        self.com_object.AutoGroup(*arguments)

    def autogroup(self, Orientation=None, Position=None):
        """Alias for AutoGroup"""
        arguments = [Orientation, Position]
        return self.AutoGroup(*arguments)

    def auto_group(self, Orientation=None, Position=None):
        """Alias for AutoGroup"""
        arguments = [Orientation, Position]
        return self.AutoGroup(*arguments)

    def ClearManualFilter(self):
        self.com_object.ClearManualFilter()

    def clearmanualfilter(self):
        """Alias for ClearManualFilter"""
        return self.ClearManualFilter()

    def clear_manual_filter(self):
        """Alias for ClearManualFilter"""
        return self.ClearManualFilter()

    def CreatePivotFields(self):
        self.com_object.CreatePivotFields()

    def createpivotfields(self):
        """Alias for CreatePivotFields"""
        return self.CreatePivotFields()

    def create_pivot_fields(self):
        """Alias for CreatePivotFields"""
        return self.CreatePivotFields()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class CubeFields:

    def __init__(self, cubefields=None):
        self.com_object= cubefields

    def __call__(self, item):
        return CubeField(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def AddSet(self, Name=None, Caption=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Caption]])
        return CubeField(self.com_object.AddSet(*arguments))

    def addset(self, Name=None, Caption=None):
        """Alias for AddSet"""
        arguments = [Name, Caption]
        return self.AddSet(*arguments)

    def add_set(self, Name=None, Caption=None):
        """Alias for AddSet"""
        arguments = [Name, Caption]
        return self.AddSet(*arguments)

    def GetMeasure(self, AttributeHierarchy=None, Function=None, Caption=None):
        arguments = com_arguments([unwrap(a) for a in [AttributeHierarchy, Function, Caption]])
        return CUBEFIELD(self.com_object.GetMeasure(*arguments))

    def getmeasure(self, AttributeHierarchy=None, Function=None, Caption=None):
        """Alias for GetMeasure"""
        arguments = [AttributeHierarchy, Function, Caption]
        return self.GetMeasure(*arguments)

    def get_measure(self, AttributeHierarchy=None, Function=None, Caption=None):
        """Alias for GetMeasure"""
        arguments = [AttributeHierarchy, Function, Caption]
        return self.GetMeasure(*arguments)


class CustomProperties:

    def __init__(self, customproperties=None):
        self.com_object= customproperties

    def __call__(self, item):
        return CustomPropertie(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, Value=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Value]])
        return CustomProperty(self.com_object.Add(*arguments))

    def add(self, Name=None, Value=None):
        """Alias for Add"""
        arguments = [Name, Value]
        return self.Add(*arguments)


class CustomProperty:

    def __init__(self, customproperty=None):
        self.com_object= customproperty

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Value(self):
        return self.com_object.Value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class CustomView:

    def __init__(self, customview=None):
        self.com_object= customview

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PrintSettings(self):
        return self.com_object.PrintSettings

    @property
    def printsettings(self):
        """Alias for PrintSettings"""
        return self.PrintSettings

    @property
    def print_settings(self):
        """Alias for PrintSettings"""
        return self.PrintSettings

    @property
    def RowColSettings(self):
        return self.com_object.RowColSettings

    @property
    def rowcolsettings(self):
        """Alias for RowColSettings"""
        return self.RowColSettings

    @property
    def row_col_settings(self):
        """Alias for RowColSettings"""
        return self.RowColSettings

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Show(self):
        self.com_object.Show()

    def show(self):
        """Alias for Show"""
        return self.Show()


class CustomViews:

    def __init__(self, customviews=None):
        self.com_object= customviews

    def __call__(self, item):
        return CustomView(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, ViewName=None, PrintSettings=None, RowColSettings=None):
        arguments = com_arguments([unwrap(a) for a in [ViewName, PrintSettings, RowColSettings]])
        return CustomView(self.com_object.Add(*arguments))

    def add(self, ViewName=None, PrintSettings=None, RowColSettings=None):
        """Alias for Add"""
        arguments = [ViewName, PrintSettings, RowColSettings]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return CustomView(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Databar:

    def __init__(self, databar=None):
        self.com_object= databar

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AppliesTo(self):
        return Range(self.com_object.AppliesTo)

    @property
    def appliesto(self):
        """Alias for AppliesTo"""
        return self.AppliesTo

    @property
    def applies_to(self):
        """Alias for AppliesTo"""
        return self.AppliesTo

    @property
    def AxisColor(self):
        return self.com_object.AxisColor

    @property
    def axiscolor(self):
        """Alias for AxisColor"""
        return self.AxisColor

    @property
    def axis_color(self):
        """Alias for AxisColor"""
        return self.AxisColor

    @property
    def AxisPosition(self):
        return self.com_object.AxisPosition

    @AxisPosition.setter
    def AxisPosition(self, value):
        self.com_object.AxisPosition = value

    @property
    def axisposition(self):
        """Alias for AxisPosition"""
        return self.AxisPosition

    @axisposition.setter
    def axisposition(self, value):
        """Alias for AxisPosition.setter"""
        self.AxisPosition = value

    @property
    def axis_position(self):
        """Alias for AxisPosition"""
        return self.AxisPosition

    @axis_position.setter
    def axis_position(self, value):
        """Alias for AxisPosition.setter"""
        self.AxisPosition = value

    @property
    def BarBorder(self):
        return self.com_object.BarBorder

    @property
    def barborder(self):
        """Alias for BarBorder"""
        return self.BarBorder

    @property
    def bar_border(self):
        """Alias for BarBorder"""
        return self.BarBorder

    @property
    def BarColor(self):
        return FormatColor(self.com_object.BarColor)

    @property
    def barcolor(self):
        """Alias for BarColor"""
        return self.BarColor

    @property
    def bar_color(self):
        """Alias for BarColor"""
        return self.BarColor

    @property
    def BarFillType(self):
        return self.com_object.BarFillType

    @BarFillType.setter
    def BarFillType(self, value):
        self.com_object.BarFillType = value

    @property
    def barfilltype(self):
        """Alias for BarFillType"""
        return self.BarFillType

    @barfilltype.setter
    def barfilltype(self, value):
        """Alias for BarFillType.setter"""
        self.BarFillType = value

    @property
    def bar_fill_type(self):
        """Alias for BarFillType"""
        return self.BarFillType

    @bar_fill_type.setter
    def bar_fill_type(self, value):
        """Alias for BarFillType.setter"""
        self.BarFillType = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Direction(self):
        return self.com_object.Direction

    @Direction.setter
    def Direction(self, value):
        self.com_object.Direction = value

    @property
    def direction(self):
        """Alias for Direction"""
        return self.Direction

    @direction.setter
    def direction(self, value):
        """Alias for Direction.setter"""
        self.Direction = value

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def MaxPoint(self):
        return ConditionValue(self.com_object.MaxPoint)

    @property
    def maxpoint(self):
        """Alias for MaxPoint"""
        return self.MaxPoint

    @property
    def max_point(self):
        """Alias for MaxPoint"""
        return self.MaxPoint

    @property
    def MinPoint(self):
        return ConditionValue(self.com_object.MinPoint)

    @property
    def minpoint(self):
        """Alias for MinPoint"""
        return self.MinPoint

    @property
    def min_point(self):
        """Alias for MinPoint"""
        return self.MinPoint

    @property
    def NegativeBarFormat(self):
        return NegativeBarFormat(self.com_object.NegativeBarFormat)

    @property
    def negativebarformat(self):
        """Alias for NegativeBarFormat"""
        return self.NegativeBarFormat

    @property
    def negative_bar_format(self):
        """Alias for NegativeBarFormat"""
        return self.NegativeBarFormat

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PercentMax(self):
        return self.com_object.PercentMax

    @PercentMax.setter
    def PercentMax(self, value):
        self.com_object.PercentMax = value

    @property
    def percentmax(self):
        """Alias for PercentMax"""
        return self.PercentMax

    @percentmax.setter
    def percentmax(self, value):
        """Alias for PercentMax.setter"""
        self.PercentMax = value

    @property
    def percent_max(self):
        """Alias for PercentMax"""
        return self.PercentMax

    @percent_max.setter
    def percent_max(self, value):
        """Alias for PercentMax.setter"""
        self.PercentMax = value

    @property
    def PercentMin(self):
        return self.com_object.PercentMin

    @PercentMin.setter
    def PercentMin(self, value):
        self.com_object.PercentMin = value

    @property
    def percentmin(self):
        """Alias for PercentMin"""
        return self.PercentMin

    @percentmin.setter
    def percentmin(self, value):
        """Alias for PercentMin.setter"""
        self.PercentMin = value

    @property
    def percent_min(self):
        """Alias for PercentMin"""
        return self.PercentMin

    @percent_min.setter
    def percent_min(self, value):
        """Alias for PercentMin.setter"""
        self.PercentMin = value

    @property
    def Priority(self):
        return self.com_object.Priority

    @Priority.setter
    def Priority(self, value):
        self.com_object.Priority = value

    @property
    def priority(self):
        """Alias for Priority"""
        return self.Priority

    @priority.setter
    def priority(self, value):
        """Alias for Priority.setter"""
        self.Priority = value

    @property
    def PTCondition(self):
        return self.com_object.PTCondition

    @property
    def ptcondition(self):
        """Alias for PTCondition"""
        return self.PTCondition

    @property
    def p_t_condition(self):
        """Alias for PTCondition"""
        return self.PTCondition

    @property
    def ScopeType(self):
        return XlPivotConditionScope(self.com_object.ScopeType)

    @ScopeType.setter
    def ScopeType(self, value):
        self.com_object.ScopeType = value

    @property
    def scopetype(self):
        """Alias for ScopeType"""
        return self.ScopeType

    @scopetype.setter
    def scopetype(self, value):
        """Alias for ScopeType.setter"""
        self.ScopeType = value

    @property
    def scope_type(self):
        """Alias for ScopeType"""
        return self.ScopeType

    @scope_type.setter
    def scope_type(self, value):
        """Alias for ScopeType.setter"""
        self.ScopeType = value

    @property
    def ShowValue(self):
        return self.com_object.ShowValue

    @ShowValue.setter
    def ShowValue(self, value):
        self.com_object.ShowValue = value

    @property
    def showvalue(self):
        """Alias for ShowValue"""
        return self.ShowValue

    @showvalue.setter
    def showvalue(self, value):
        """Alias for ShowValue.setter"""
        self.ShowValue = value

    @property
    def show_value(self):
        """Alias for ShowValue"""
        return self.ShowValue

    @show_value.setter
    def show_value(self, value):
        """Alias for ShowValue.setter"""
        self.ShowValue = value

    @property
    def StopIfTrue(self):
        return self.com_object.StopIfTrue

    @StopIfTrue.setter
    def StopIfTrue(self, value):
        self.com_object.StopIfTrue = value

    @property
    def stopiftrue(self):
        """Alias for StopIfTrue"""
        return self.StopIfTrue

    @stopiftrue.setter
    def stopiftrue(self, value):
        """Alias for StopIfTrue.setter"""
        self.StopIfTrue = value

    @property
    def stop_if_true(self):
        """Alias for StopIfTrue"""
        return self.StopIfTrue

    @stop_if_true.setter
    def stop_if_true(self, value):
        """Alias for StopIfTrue.setter"""
        self.StopIfTrue = value

    @property
    def Type(self):
        return XlFormatConditionType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def ModifyAppliesToRange(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        self.com_object.ModifyAppliesToRange(*arguments)

    def modifyappliestorange(self, Range=None):
        """Alias for ModifyAppliesToRange"""
        arguments = [Range]
        return self.ModifyAppliesToRange(*arguments)

    def modify_applies_to_range(self, Range=None):
        """Alias for ModifyAppliesToRange"""
        arguments = [Range]
        return self.ModifyAppliesToRange(*arguments)

    def SetFirstPriority(self):
        self.com_object.SetFirstPriority()

    def setfirstpriority(self):
        """Alias for SetFirstPriority"""
        return self.SetFirstPriority()

    def set_first_priority(self):
        """Alias for SetFirstPriority"""
        return self.SetFirstPriority()

    def SetLastPriority(self):
        self.com_object.SetLastPriority()

    def setlastpriority(self):
        """Alias for SetLastPriority"""
        return self.SetLastPriority()

    def set_last_priority(self):
        """Alias for SetLastPriority"""
        return self.SetLastPriority()


class DataBarBorder:

    def __init__(self, databarborder=None):
        self.com_object= databarborder

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Color(self):
        return self.com_object.Color

    @property
    def color(self):
        """Alias for Color"""
        return self.Color

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value


class DataFeedConnection:

    def __init__(self, datafeedconnection=None):
        self.com_object= datafeedconnection

    @property
    def AlwaysUseConnectionFile(self):
        return self.com_object.AlwaysUseConnectionFile

    @AlwaysUseConnectionFile.setter
    def AlwaysUseConnectionFile(self, value):
        self.com_object.AlwaysUseConnectionFile = value

    @property
    def alwaysuseconnectionfile(self):
        """Alias for AlwaysUseConnectionFile"""
        return self.AlwaysUseConnectionFile

    @alwaysuseconnectionfile.setter
    def alwaysuseconnectionfile(self, value):
        """Alias for AlwaysUseConnectionFile.setter"""
        self.AlwaysUseConnectionFile = value

    @property
    def always_use_connection_file(self):
        """Alias for AlwaysUseConnectionFile"""
        return self.AlwaysUseConnectionFile

    @always_use_connection_file.setter
    def always_use_connection_file(self, value):
        """Alias for AlwaysUseConnectionFile.setter"""
        self.AlwaysUseConnectionFile = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def CommandText(self):
        return self.com_object.CommandText

    @CommandText.setter
    def CommandText(self, value):
        self.com_object.CommandText = value

    @property
    def commandtext(self):
        """Alias for CommandText"""
        return self.CommandText

    @commandtext.setter
    def commandtext(self, value):
        """Alias for CommandText.setter"""
        self.CommandText = value

    @property
    def command_text(self):
        """Alias for CommandText"""
        return self.CommandText

    @command_text.setter
    def command_text(self, value):
        """Alias for CommandText.setter"""
        self.CommandText = value

    @property
    def CommandType(self):
        return self.com_object.CommandType

    @CommandType.setter
    def CommandType(self, value):
        self.com_object.CommandType = value

    @property
    def commandtype(self):
        """Alias for CommandType"""
        return self.CommandType

    @commandtype.setter
    def commandtype(self, value):
        """Alias for CommandType.setter"""
        self.CommandType = value

    @property
    def command_type(self):
        """Alias for CommandType"""
        return self.CommandType

    @command_type.setter
    def command_type(self, value):
        """Alias for CommandType.setter"""
        self.CommandType = value

    @property
    def Connection(self):
        return self.com_object.Connection

    @Connection.setter
    def Connection(self, value):
        self.com_object.Connection = value

    @property
    def connection(self):
        """Alias for Connection"""
        return self.Connection

    @connection.setter
    def connection(self, value):
        """Alias for Connection.setter"""
        self.Connection = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def EnableRefresh(self):
        return self.com_object.EnableRefresh

    @EnableRefresh.setter
    def EnableRefresh(self, value):
        self.com_object.EnableRefresh = value

    @property
    def enablerefresh(self):
        """Alias for EnableRefresh"""
        return self.EnableRefresh

    @enablerefresh.setter
    def enablerefresh(self, value):
        """Alias for EnableRefresh.setter"""
        self.EnableRefresh = value

    @property
    def enable_refresh(self):
        """Alias for EnableRefresh"""
        return self.EnableRefresh

    @enable_refresh.setter
    def enable_refresh(self, value):
        """Alias for EnableRefresh.setter"""
        self.EnableRefresh = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RefreshDate(self):
        return self.com_object.RefreshDate

    @property
    def refreshdate(self):
        """Alias for RefreshDate"""
        return self.RefreshDate

    @property
    def refresh_date(self):
        """Alias for RefreshDate"""
        return self.RefreshDate

    @property
    def Refreshing(self):
        return self.com_object.Refreshing

    @Refreshing.setter
    def Refreshing(self, value):
        self.com_object.Refreshing = value

    @property
    def refreshing(self):
        """Alias for Refreshing"""
        return self.Refreshing

    @refreshing.setter
    def refreshing(self, value):
        """Alias for Refreshing.setter"""
        self.Refreshing = value

    @property
    def RefreshOnFileOpen(self):
        return self.com_object.RefreshOnFileOpen

    @property
    def refreshonfileopen(self):
        """Alias for RefreshOnFileOpen"""
        return self.RefreshOnFileOpen

    @property
    def refresh_on_file_open(self):
        """Alias for RefreshOnFileOpen"""
        return self.RefreshOnFileOpen

    @property
    def RefreshPeriod(self):
        return self.com_object.RefreshPeriod

    @RefreshPeriod.setter
    def RefreshPeriod(self, value):
        self.com_object.RefreshPeriod = value

    @property
    def refreshperiod(self):
        """Alias for RefreshPeriod"""
        return self.RefreshPeriod

    @refreshperiod.setter
    def refreshperiod(self, value):
        """Alias for RefreshPeriod.setter"""
        self.RefreshPeriod = value

    @property
    def refresh_period(self):
        """Alias for RefreshPeriod"""
        return self.RefreshPeriod

    @refresh_period.setter
    def refresh_period(self, value):
        """Alias for RefreshPeriod.setter"""
        self.RefreshPeriod = value

    @property
    def SavePassword(self):
        return self.com_object.SavePassword

    @property
    def savepassword(self):
        """Alias for SavePassword"""
        return self.SavePassword

    @property
    def save_password(self):
        """Alias for SavePassword"""
        return self.SavePassword

    @property
    def ServerCredentialsMethod(self):
        return XlCredentialsMethod(self.com_object.ServerCredentialsMethod)

    @ServerCredentialsMethod.setter
    def ServerCredentialsMethod(self, value):
        self.com_object.ServerCredentialsMethod = value

    @property
    def servercredentialsmethod(self):
        """Alias for ServerCredentialsMethod"""
        return self.ServerCredentialsMethod

    @servercredentialsmethod.setter
    def servercredentialsmethod(self, value):
        """Alias for ServerCredentialsMethod.setter"""
        self.ServerCredentialsMethod = value

    @property
    def server_credentials_method(self):
        """Alias for ServerCredentialsMethod"""
        return self.ServerCredentialsMethod

    @server_credentials_method.setter
    def server_credentials_method(self, value):
        """Alias for ServerCredentialsMethod.setter"""
        self.ServerCredentialsMethod = value

    @property
    def SourceConnectionFile(self):
        return self.com_object.SourceConnectionFile

    @SourceConnectionFile.setter
    def SourceConnectionFile(self, value):
        self.com_object.SourceConnectionFile = value

    @property
    def sourceconnectionfile(self):
        """Alias for SourceConnectionFile"""
        return self.SourceConnectionFile

    @sourceconnectionfile.setter
    def sourceconnectionfile(self, value):
        """Alias for SourceConnectionFile.setter"""
        self.SourceConnectionFile = value

    @property
    def source_connection_file(self):
        """Alias for SourceConnectionFile"""
        return self.SourceConnectionFile

    @source_connection_file.setter
    def source_connection_file(self, value):
        """Alias for SourceConnectionFile.setter"""
        self.SourceConnectionFile = value

    @property
    def SourceDataFile(self):
        return self.com_object.SourceDataFile

    @SourceDataFile.setter
    def SourceDataFile(self, value):
        self.com_object.SourceDataFile = value

    @property
    def sourcedatafile(self):
        """Alias for SourceDataFile"""
        return self.SourceDataFile

    @sourcedatafile.setter
    def sourcedatafile(self, value):
        """Alias for SourceDataFile.setter"""
        self.SourceDataFile = value

    @property
    def source_data_file(self):
        """Alias for SourceDataFile"""
        return self.SourceDataFile

    @source_data_file.setter
    def source_data_file(self, value):
        """Alias for SourceDataFile.setter"""
        self.SourceDataFile = value

    def CancelRefresh(self):
        return self.com_object.CancelRefresh()

    def cancelrefresh(self):
        """Alias for CancelRefresh"""
        return self.CancelRefresh()

    def cancel_refresh(self):
        """Alias for CancelRefresh"""
        return self.CancelRefresh()

    def Refresh(self):
        return self.com_object.Refresh()

    def refresh(self):
        """Alias for Refresh"""
        return self.Refresh()

    def SaveAsODC(self, ODCFileName=None, Description=None, Keywords=None):
        arguments = com_arguments([unwrap(a) for a in [ODCFileName, Description, Keywords]])
        return self.com_object.SaveAsODC(*arguments)

    def saveasodc(self, ODCFileName=None, Description=None, Keywords=None):
        """Alias for SaveAsODC"""
        arguments = [ODCFileName, Description, Keywords]
        return self.SaveAsODC(*arguments)

    def save_as_o_d_c(self, ODCFileName=None, Description=None, Keywords=None):
        """Alias for SaveAsODC"""
        arguments = [ODCFileName, Description, Keywords]
        return self.SaveAsODC(*arguments)


class DataLabel:

    def __init__(self, datalabel=None):
        self.com_object= datalabel

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoText(self):
        return self.com_object.AutoText

    @AutoText.setter
    def AutoText(self, value):
        self.com_object.AutoText = value

    @property
    def autotext(self):
        """Alias for AutoText"""
        return self.AutoText

    @autotext.setter
    def autotext(self, value):
        """Alias for AutoText.setter"""
        self.AutoText = value

    @property
    def auto_text(self):
        """Alias for AutoText"""
        return self.AutoText

    @auto_text.setter
    def auto_text(self, value):
        """Alias for AutoText.setter"""
        self.AutoText = value

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    def Characters(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        if hasattr(self.com_object, "GetCharacters"):
            return Characters(self.com_object.GetCharacters(*arguments))
        else:
            return Characters(self.com_object.Characters(*arguments))

    def characters(self, Start=None, Length=None):
        """Alias for Characters"""
        arguments = [Start, Length]
        return self.Characters(*arguments)

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def FormulaLocal(self):
        return self.com_object.FormulaLocal

    @FormulaLocal.setter
    def FormulaLocal(self, value):
        self.com_object.FormulaLocal = value

    @property
    def formulalocal(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formulalocal.setter
    def formulalocal(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def formula_local(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formula_local.setter
    def formula_local(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def FormulaR1C1(self):
        return self.com_object.FormulaR1C1

    @FormulaR1C1.setter
    def FormulaR1C1(self, value):
        self.com_object.FormulaR1C1 = value

    @property
    def formular1c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formular1c1.setter
    def formular1c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def formula_r1_c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formula_r1_c1.setter
    def formula_r1_c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def FormulaR1C1Local(self):
        return self.com_object.FormulaR1C1Local

    @FormulaR1C1Local.setter
    def FormulaR1C1Local(self, value):
        self.com_object.FormulaR1C1Local = value

    @property
    def formular1c1local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formular1c1local.setter
    def formular1c1local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def formula_r1_c1_local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formula_r1_c1_local.setter
    def formula_r1_c1_local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HorizontalAlignment(self):
        return self.com_object.HorizontalAlignment

    @HorizontalAlignment.setter
    def HorizontalAlignment(self, value):
        self.com_object.HorizontalAlignment = value

    @property
    def horizontalalignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontalalignment.setter
    def horizontalalignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def horizontal_alignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NumberFormat(self):
        return self.com_object.NumberFormat

    @NumberFormat.setter
    def NumberFormat(self, value):
        self.com_object.NumberFormat = value

    @property
    def numberformat(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @numberformat.setter
    def numberformat(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def number_format(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @number_format.setter
    def number_format(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def NumberFormatLinked(self):
        return self.com_object.NumberFormatLinked

    @NumberFormatLinked.setter
    def NumberFormatLinked(self, value):
        self.com_object.NumberFormatLinked = value

    @property
    def numberformatlinked(self):
        """Alias for NumberFormatLinked"""
        return self.NumberFormatLinked

    @numberformatlinked.setter
    def numberformatlinked(self, value):
        """Alias for NumberFormatLinked.setter"""
        self.NumberFormatLinked = value

    @property
    def number_format_linked(self):
        """Alias for NumberFormatLinked"""
        return self.NumberFormatLinked

    @number_format_linked.setter
    def number_format_linked(self, value):
        """Alias for NumberFormatLinked.setter"""
        self.NumberFormatLinked = value

    @property
    def NumberFormatLocal(self):
        return self.com_object.NumberFormatLocal

    @NumberFormatLocal.setter
    def NumberFormatLocal(self, value):
        self.com_object.NumberFormatLocal = value

    @property
    def numberformatlocal(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @numberformatlocal.setter
    def numberformatlocal(self, value):
        """Alias for NumberFormatLocal.setter"""
        self.NumberFormatLocal = value

    @property
    def number_format_local(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @number_format_local.setter
    def number_format_local(self, value):
        """Alias for NumberFormatLocal.setter"""
        self.NumberFormatLocal = value

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return XlDataLabelPosition(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def ReadingOrder(self):
        return self.com_object.ReadingOrder

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def Separator(self):
        return self.com_object.Separator

    @Separator.setter
    def Separator(self, value):
        self.com_object.Separator = value

    @property
    def separator(self):
        """Alias for Separator"""
        return self.Separator

    @separator.setter
    def separator(self, value):
        """Alias for Separator.setter"""
        self.Separator = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def ShowBubbleSize(self):
        return self.com_object.ShowBubbleSize

    @ShowBubbleSize.setter
    def ShowBubbleSize(self, value):
        self.com_object.ShowBubbleSize = value

    @property
    def showbubblesize(self):
        """Alias for ShowBubbleSize"""
        return self.ShowBubbleSize

    @showbubblesize.setter
    def showbubblesize(self, value):
        """Alias for ShowBubbleSize.setter"""
        self.ShowBubbleSize = value

    @property
    def show_bubble_size(self):
        """Alias for ShowBubbleSize"""
        return self.ShowBubbleSize

    @show_bubble_size.setter
    def show_bubble_size(self, value):
        """Alias for ShowBubbleSize.setter"""
        self.ShowBubbleSize = value

    @property
    def ShowCategoryName(self):
        return self.com_object.ShowCategoryName

    @ShowCategoryName.setter
    def ShowCategoryName(self, value):
        self.com_object.ShowCategoryName = value

    @property
    def showcategoryname(self):
        """Alias for ShowCategoryName"""
        return self.ShowCategoryName

    @showcategoryname.setter
    def showcategoryname(self, value):
        """Alias for ShowCategoryName.setter"""
        self.ShowCategoryName = value

    @property
    def show_category_name(self):
        """Alias for ShowCategoryName"""
        return self.ShowCategoryName

    @show_category_name.setter
    def show_category_name(self, value):
        """Alias for ShowCategoryName.setter"""
        self.ShowCategoryName = value

    @property
    def ShowLegendKey(self):
        return self.com_object.ShowLegendKey

    @ShowLegendKey.setter
    def ShowLegendKey(self, value):
        self.com_object.ShowLegendKey = value

    @property
    def showlegendkey(self):
        """Alias for ShowLegendKey"""
        return self.ShowLegendKey

    @showlegendkey.setter
    def showlegendkey(self, value):
        """Alias for ShowLegendKey.setter"""
        self.ShowLegendKey = value

    @property
    def show_legend_key(self):
        """Alias for ShowLegendKey"""
        return self.ShowLegendKey

    @show_legend_key.setter
    def show_legend_key(self, value):
        """Alias for ShowLegendKey.setter"""
        self.ShowLegendKey = value

    @property
    def ShowPercentage(self):
        return self.com_object.ShowPercentage

    @ShowPercentage.setter
    def ShowPercentage(self, value):
        self.com_object.ShowPercentage = value

    @property
    def showpercentage(self):
        """Alias for ShowPercentage"""
        return self.ShowPercentage

    @showpercentage.setter
    def showpercentage(self, value):
        """Alias for ShowPercentage.setter"""
        self.ShowPercentage = value

    @property
    def show_percentage(self):
        """Alias for ShowPercentage"""
        return self.ShowPercentage

    @show_percentage.setter
    def show_percentage(self, value):
        """Alias for ShowPercentage.setter"""
        self.ShowPercentage = value

    @property
    def ShowRange(self):
        return self.com_object.ShowRange

    @ShowRange.setter
    def ShowRange(self, value):
        self.com_object.ShowRange = value

    @property
    def showrange(self):
        """Alias for ShowRange"""
        return self.ShowRange

    @showrange.setter
    def showrange(self, value):
        """Alias for ShowRange.setter"""
        self.ShowRange = value

    @property
    def show_range(self):
        """Alias for ShowRange"""
        return self.ShowRange

    @show_range.setter
    def show_range(self, value):
        """Alias for ShowRange.setter"""
        self.ShowRange = value

    @property
    def ShowSeriesName(self):
        return self.com_object.ShowSeriesName

    @ShowSeriesName.setter
    def ShowSeriesName(self, value):
        self.com_object.ShowSeriesName = value

    @property
    def showseriesname(self):
        """Alias for ShowSeriesName"""
        return self.ShowSeriesName

    @showseriesname.setter
    def showseriesname(self, value):
        """Alias for ShowSeriesName.setter"""
        self.ShowSeriesName = value

    @property
    def show_series_name(self):
        """Alias for ShowSeriesName"""
        return self.ShowSeriesName

    @show_series_name.setter
    def show_series_name(self, value):
        """Alias for ShowSeriesName.setter"""
        self.ShowSeriesName = value

    @property
    def ShowValue(self):
        return self.com_object.ShowValue

    @ShowValue.setter
    def ShowValue(self, value):
        self.com_object.ShowValue = value

    @property
    def showvalue(self):
        """Alias for ShowValue"""
        return self.ShowValue

    @showvalue.setter
    def showvalue(self, value):
        """Alias for ShowValue.setter"""
        self.ShowValue = value

    @property
    def show_value(self):
        """Alias for ShowValue"""
        return self.ShowValue

    @show_value.setter
    def show_value(self, value):
        """Alias for ShowValue.setter"""
        self.ShowValue = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def VerticalAlignment(self):
        return self.com_object.VerticalAlignment

    @VerticalAlignment.setter
    def VerticalAlignment(self, value):
        self.com_object.VerticalAlignment = value

    @property
    def verticalalignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @verticalalignment.setter
    def verticalalignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def vertical_alignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @vertical_alignment.setter
    def vertical_alignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        return self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class DataLabels:

    def __init__(self, datalabels=None):
        self.com_object= datalabels

    def __call__(self, item):
        return DataLabel(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoText(self):
        return self.com_object.AutoText

    @AutoText.setter
    def AutoText(self, value):
        self.com_object.AutoText = value

    @property
    def autotext(self):
        """Alias for AutoText"""
        return self.AutoText

    @autotext.setter
    def autotext(self, value):
        """Alias for AutoText.setter"""
        self.AutoText = value

    @property
    def auto_text(self):
        """Alias for AutoText"""
        return self.AutoText

    @auto_text.setter
    def auto_text(self, value):
        """Alias for AutoText.setter"""
        self.AutoText = value

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def HorizontalAlignment(self):
        return self.com_object.HorizontalAlignment

    @HorizontalAlignment.setter
    def HorizontalAlignment(self, value):
        self.com_object.HorizontalAlignment = value

    @property
    def horizontalalignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontalalignment.setter
    def horizontalalignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def horizontal_alignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NumberFormat(self):
        return self.com_object.NumberFormat

    @NumberFormat.setter
    def NumberFormat(self, value):
        self.com_object.NumberFormat = value

    @property
    def numberformat(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @numberformat.setter
    def numberformat(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def number_format(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @number_format.setter
    def number_format(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def NumberFormatLinked(self):
        return self.com_object.NumberFormatLinked

    @NumberFormatLinked.setter
    def NumberFormatLinked(self, value):
        self.com_object.NumberFormatLinked = value

    @property
    def numberformatlinked(self):
        """Alias for NumberFormatLinked"""
        return self.NumberFormatLinked

    @numberformatlinked.setter
    def numberformatlinked(self, value):
        """Alias for NumberFormatLinked.setter"""
        self.NumberFormatLinked = value

    @property
    def number_format_linked(self):
        """Alias for NumberFormatLinked"""
        return self.NumberFormatLinked

    @number_format_linked.setter
    def number_format_linked(self, value):
        """Alias for NumberFormatLinked.setter"""
        self.NumberFormatLinked = value

    @property
    def NumberFormatLocal(self):
        return self.com_object.NumberFormatLocal

    @NumberFormatLocal.setter
    def NumberFormatLocal(self, value):
        self.com_object.NumberFormatLocal = value

    @property
    def numberformatlocal(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @numberformatlocal.setter
    def numberformatlocal(self, value):
        """Alias for NumberFormatLocal.setter"""
        self.NumberFormatLocal = value

    @property
    def number_format_local(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @number_format_local.setter
    def number_format_local(self, value):
        """Alias for NumberFormatLocal.setter"""
        self.NumberFormatLocal = value

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return XlDataLabelPosition(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def ReadingOrder(self):
        return self.com_object.ReadingOrder

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def Separator(self):
        return self.com_object.Separator

    @Separator.setter
    def Separator(self, value):
        self.com_object.Separator = value

    @property
    def separator(self):
        """Alias for Separator"""
        return self.Separator

    @separator.setter
    def separator(self, value):
        """Alias for Separator.setter"""
        self.Separator = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def ShowBubbleSize(self):
        return self.com_object.ShowBubbleSize

    @ShowBubbleSize.setter
    def ShowBubbleSize(self, value):
        self.com_object.ShowBubbleSize = value

    @property
    def showbubblesize(self):
        """Alias for ShowBubbleSize"""
        return self.ShowBubbleSize

    @showbubblesize.setter
    def showbubblesize(self, value):
        """Alias for ShowBubbleSize.setter"""
        self.ShowBubbleSize = value

    @property
    def show_bubble_size(self):
        """Alias for ShowBubbleSize"""
        return self.ShowBubbleSize

    @show_bubble_size.setter
    def show_bubble_size(self, value):
        """Alias for ShowBubbleSize.setter"""
        self.ShowBubbleSize = value

    @property
    def ShowCategoryName(self):
        return self.com_object.ShowCategoryName

    @ShowCategoryName.setter
    def ShowCategoryName(self, value):
        self.com_object.ShowCategoryName = value

    @property
    def showcategoryname(self):
        """Alias for ShowCategoryName"""
        return self.ShowCategoryName

    @showcategoryname.setter
    def showcategoryname(self, value):
        """Alias for ShowCategoryName.setter"""
        self.ShowCategoryName = value

    @property
    def show_category_name(self):
        """Alias for ShowCategoryName"""
        return self.ShowCategoryName

    @show_category_name.setter
    def show_category_name(self, value):
        """Alias for ShowCategoryName.setter"""
        self.ShowCategoryName = value

    @property
    def ShowLegendKey(self):
        return self.com_object.ShowLegendKey

    @ShowLegendKey.setter
    def ShowLegendKey(self, value):
        self.com_object.ShowLegendKey = value

    @property
    def showlegendkey(self):
        """Alias for ShowLegendKey"""
        return self.ShowLegendKey

    @showlegendkey.setter
    def showlegendkey(self, value):
        """Alias for ShowLegendKey.setter"""
        self.ShowLegendKey = value

    @property
    def show_legend_key(self):
        """Alias for ShowLegendKey"""
        return self.ShowLegendKey

    @show_legend_key.setter
    def show_legend_key(self, value):
        """Alias for ShowLegendKey.setter"""
        self.ShowLegendKey = value

    @property
    def ShowPercentage(self):
        return self.com_object.ShowPercentage

    @ShowPercentage.setter
    def ShowPercentage(self, value):
        self.com_object.ShowPercentage = value

    @property
    def showpercentage(self):
        """Alias for ShowPercentage"""
        return self.ShowPercentage

    @showpercentage.setter
    def showpercentage(self, value):
        """Alias for ShowPercentage.setter"""
        self.ShowPercentage = value

    @property
    def show_percentage(self):
        """Alias for ShowPercentage"""
        return self.ShowPercentage

    @show_percentage.setter
    def show_percentage(self, value):
        """Alias for ShowPercentage.setter"""
        self.ShowPercentage = value

    @property
    def ShowRange(self):
        return self.com_object.ShowRange

    @ShowRange.setter
    def ShowRange(self, value):
        self.com_object.ShowRange = value

    @property
    def showrange(self):
        """Alias for ShowRange"""
        return self.ShowRange

    @showrange.setter
    def showrange(self, value):
        """Alias for ShowRange.setter"""
        self.ShowRange = value

    @property
    def show_range(self):
        """Alias for ShowRange"""
        return self.ShowRange

    @show_range.setter
    def show_range(self, value):
        """Alias for ShowRange.setter"""
        self.ShowRange = value

    @property
    def ShowSeriesName(self):
        return self.com_object.ShowSeriesName

    @ShowSeriesName.setter
    def ShowSeriesName(self, value):
        self.com_object.ShowSeriesName = value

    @property
    def showseriesname(self):
        """Alias for ShowSeriesName"""
        return self.ShowSeriesName

    @showseriesname.setter
    def showseriesname(self, value):
        """Alias for ShowSeriesName.setter"""
        self.ShowSeriesName = value

    @property
    def show_series_name(self):
        """Alias for ShowSeriesName"""
        return self.ShowSeriesName

    @show_series_name.setter
    def show_series_name(self, value):
        """Alias for ShowSeriesName.setter"""
        self.ShowSeriesName = value

    @property
    def ShowValue(self):
        return self.com_object.ShowValue

    @ShowValue.setter
    def ShowValue(self, value):
        self.com_object.ShowValue = value

    @property
    def showvalue(self):
        """Alias for ShowValue"""
        return self.ShowValue

    @showvalue.setter
    def showvalue(self, value):
        """Alias for ShowValue.setter"""
        self.ShowValue = value

    @property
    def show_value(self):
        """Alias for ShowValue"""
        return self.ShowValue

    @show_value.setter
    def show_value(self, value):
        """Alias for ShowValue.setter"""
        self.ShowValue = value

    @property
    def VerticalAlignment(self):
        return self.com_object.VerticalAlignment

    @VerticalAlignment.setter
    def VerticalAlignment(self, value):
        self.com_object.VerticalAlignment = value

    @property
    def verticalalignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @verticalalignment.setter
    def verticalalignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def vertical_alignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @vertical_alignment.setter
    def vertical_alignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return DataLabel(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Propagate(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Propagate(*arguments)

    def propagate(self, Index=None):
        """Alias for Propagate"""
        arguments = [Index]
        return self.Propagate(*arguments)

    def Select(self):
        return self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class DataTable:

    def __init__(self, datatable=None):
        self.com_object= datatable

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Border(self):
        return Border(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def HasBorderHorizontal(self):
        return self.com_object.HasBorderHorizontal

    @HasBorderHorizontal.setter
    def HasBorderHorizontal(self, value):
        self.com_object.HasBorderHorizontal = value

    @property
    def hasborderhorizontal(self):
        """Alias for HasBorderHorizontal"""
        return self.HasBorderHorizontal

    @hasborderhorizontal.setter
    def hasborderhorizontal(self, value):
        """Alias for HasBorderHorizontal.setter"""
        self.HasBorderHorizontal = value

    @property
    def has_border_horizontal(self):
        """Alias for HasBorderHorizontal"""
        return self.HasBorderHorizontal

    @has_border_horizontal.setter
    def has_border_horizontal(self, value):
        """Alias for HasBorderHorizontal.setter"""
        self.HasBorderHorizontal = value

    @property
    def HasBorderOutline(self):
        return self.com_object.HasBorderOutline

    @HasBorderOutline.setter
    def HasBorderOutline(self, value):
        self.com_object.HasBorderOutline = value

    @property
    def hasborderoutline(self):
        """Alias for HasBorderOutline"""
        return self.HasBorderOutline

    @hasborderoutline.setter
    def hasborderoutline(self, value):
        """Alias for HasBorderOutline.setter"""
        self.HasBorderOutline = value

    @property
    def has_border_outline(self):
        """Alias for HasBorderOutline"""
        return self.HasBorderOutline

    @has_border_outline.setter
    def has_border_outline(self, value):
        """Alias for HasBorderOutline.setter"""
        self.HasBorderOutline = value

    @property
    def HasBorderVertical(self):
        return self.com_object.HasBorderVertical

    @HasBorderVertical.setter
    def HasBorderVertical(self, value):
        self.com_object.HasBorderVertical = value

    @property
    def hasbordervertical(self):
        """Alias for HasBorderVertical"""
        return self.HasBorderVertical

    @hasbordervertical.setter
    def hasbordervertical(self, value):
        """Alias for HasBorderVertical.setter"""
        self.HasBorderVertical = value

    @property
    def has_border_vertical(self):
        """Alias for HasBorderVertical"""
        return self.HasBorderVertical

    @has_border_vertical.setter
    def has_border_vertical(self, value):
        """Alias for HasBorderVertical.setter"""
        self.HasBorderVertical = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ShowLegendKey(self):
        return self.com_object.ShowLegendKey

    @ShowLegendKey.setter
    def ShowLegendKey(self, value):
        self.com_object.ShowLegendKey = value

    @property
    def showlegendkey(self):
        """Alias for ShowLegendKey"""
        return self.ShowLegendKey

    @showlegendkey.setter
    def showlegendkey(self, value):
        """Alias for ShowLegendKey.setter"""
        self.ShowLegendKey = value

    @property
    def show_legend_key(self):
        """Alias for ShowLegendKey"""
        return self.ShowLegendKey

    @show_legend_key.setter
    def show_legend_key(self, value):
        """Alias for ShowLegendKey.setter"""
        self.ShowLegendKey = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class DefaultWebOptions:

    def __init__(self, defaultweboptions=None):
        self.com_object= defaultweboptions

    @property
    def AllowPNG(self):
        return self.com_object.AllowPNG

    @AllowPNG.setter
    def AllowPNG(self, value):
        self.com_object.AllowPNG = value

    @property
    def allowpng(self):
        """Alias for AllowPNG"""
        return self.AllowPNG

    @allowpng.setter
    def allowpng(self, value):
        """Alias for AllowPNG.setter"""
        self.AllowPNG = value

    @property
    def allow_p_n_g(self):
        """Alias for AllowPNG"""
        return self.AllowPNG

    @allow_p_n_g.setter
    def allow_p_n_g(self, value):
        """Alias for AllowPNG.setter"""
        self.AllowPNG = value

    @property
    def AlwaysSaveInDefaultEncoding(self):
        return self.com_object.AlwaysSaveInDefaultEncoding

    @AlwaysSaveInDefaultEncoding.setter
    def AlwaysSaveInDefaultEncoding(self, value):
        self.com_object.AlwaysSaveInDefaultEncoding = value

    @property
    def alwayssaveindefaultencoding(self):
        """Alias for AlwaysSaveInDefaultEncoding"""
        return self.AlwaysSaveInDefaultEncoding

    @alwayssaveindefaultencoding.setter
    def alwayssaveindefaultencoding(self, value):
        """Alias for AlwaysSaveInDefaultEncoding.setter"""
        self.AlwaysSaveInDefaultEncoding = value

    @property
    def always_save_in_default_encoding(self):
        """Alias for AlwaysSaveInDefaultEncoding"""
        return self.AlwaysSaveInDefaultEncoding

    @always_save_in_default_encoding.setter
    def always_save_in_default_encoding(self, value):
        """Alias for AlwaysSaveInDefaultEncoding.setter"""
        self.AlwaysSaveInDefaultEncoding = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def CheckIfOfficeIsHTMLEditor(self):
        return self.com_object.CheckIfOfficeIsHTMLEditor

    @CheckIfOfficeIsHTMLEditor.setter
    def CheckIfOfficeIsHTMLEditor(self, value):
        self.com_object.CheckIfOfficeIsHTMLEditor = value

    @property
    def checkifofficeishtmleditor(self):
        """Alias for CheckIfOfficeIsHTMLEditor"""
        return self.CheckIfOfficeIsHTMLEditor

    @checkifofficeishtmleditor.setter
    def checkifofficeishtmleditor(self, value):
        """Alias for CheckIfOfficeIsHTMLEditor.setter"""
        self.CheckIfOfficeIsHTMLEditor = value

    @property
    def check_if_office_is_h_t_m_l_editor(self):
        """Alias for CheckIfOfficeIsHTMLEditor"""
        return self.CheckIfOfficeIsHTMLEditor

    @check_if_office_is_h_t_m_l_editor.setter
    def check_if_office_is_h_t_m_l_editor(self, value):
        """Alias for CheckIfOfficeIsHTMLEditor.setter"""
        self.CheckIfOfficeIsHTMLEditor = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DownloadComponents(self):
        return self.com_object.DownloadComponents

    @DownloadComponents.setter
    def DownloadComponents(self, value):
        self.com_object.DownloadComponents = value

    @property
    def downloadcomponents(self):
        """Alias for DownloadComponents"""
        return self.DownloadComponents

    @downloadcomponents.setter
    def downloadcomponents(self, value):
        """Alias for DownloadComponents.setter"""
        self.DownloadComponents = value

    @property
    def download_components(self):
        """Alias for DownloadComponents"""
        return self.DownloadComponents

    @download_components.setter
    def download_components(self, value):
        """Alias for DownloadComponents.setter"""
        self.DownloadComponents = value

    @property
    def Encoding(self):
        return self.com_object.Encoding

    @Encoding.setter
    def Encoding(self, value):
        self.com_object.Encoding = value

    @property
    def encoding(self):
        """Alias for Encoding"""
        return self.Encoding

    @encoding.setter
    def encoding(self, value):
        """Alias for Encoding.setter"""
        self.Encoding = value

    @property
    def FolderSuffix(self):
        return self.com_object.FolderSuffix

    @property
    def foldersuffix(self):
        """Alias for FolderSuffix"""
        return self.FolderSuffix

    @property
    def folder_suffix(self):
        """Alias for FolderSuffix"""
        return self.FolderSuffix

    @property
    def Fonts(self):
        return self.com_object.Fonts

    @property
    def fonts(self):
        """Alias for Fonts"""
        return self.Fonts

    @property
    def LoadPictures(self):
        return self.com_object.LoadPictures

    @LoadPictures.setter
    def LoadPictures(self, value):
        self.com_object.LoadPictures = value

    @property
    def loadpictures(self):
        """Alias for LoadPictures"""
        return self.LoadPictures

    @loadpictures.setter
    def loadpictures(self, value):
        """Alias for LoadPictures.setter"""
        self.LoadPictures = value

    @property
    def load_pictures(self):
        """Alias for LoadPictures"""
        return self.LoadPictures

    @load_pictures.setter
    def load_pictures(self, value):
        """Alias for LoadPictures.setter"""
        self.LoadPictures = value

    @property
    def LocationOfComponents(self):
        return self.com_object.LocationOfComponents

    @LocationOfComponents.setter
    def LocationOfComponents(self, value):
        self.com_object.LocationOfComponents = value

    @property
    def locationofcomponents(self):
        """Alias for LocationOfComponents"""
        return self.LocationOfComponents

    @locationofcomponents.setter
    def locationofcomponents(self, value):
        """Alias for LocationOfComponents.setter"""
        self.LocationOfComponents = value

    @property
    def location_of_components(self):
        """Alias for LocationOfComponents"""
        return self.LocationOfComponents

    @location_of_components.setter
    def location_of_components(self, value):
        """Alias for LocationOfComponents.setter"""
        self.LocationOfComponents = value

    @property
    def OrganizeInFolder(self):
        return self.com_object.OrganizeInFolder

    @OrganizeInFolder.setter
    def OrganizeInFolder(self, value):
        self.com_object.OrganizeInFolder = value

    @property
    def organizeinfolder(self):
        """Alias for OrganizeInFolder"""
        return self.OrganizeInFolder

    @organizeinfolder.setter
    def organizeinfolder(self, value):
        """Alias for OrganizeInFolder.setter"""
        self.OrganizeInFolder = value

    @property
    def organize_in_folder(self):
        """Alias for OrganizeInFolder"""
        return self.OrganizeInFolder

    @organize_in_folder.setter
    def organize_in_folder(self, value):
        """Alias for OrganizeInFolder.setter"""
        self.OrganizeInFolder = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PixelsPerInch(self):
        return self.com_object.PixelsPerInch

    @PixelsPerInch.setter
    def PixelsPerInch(self, value):
        self.com_object.PixelsPerInch = value

    @property
    def pixelsperinch(self):
        """Alias for PixelsPerInch"""
        return self.PixelsPerInch

    @pixelsperinch.setter
    def pixelsperinch(self, value):
        """Alias for PixelsPerInch.setter"""
        self.PixelsPerInch = value

    @property
    def pixels_per_inch(self):
        """Alias for PixelsPerInch"""
        return self.PixelsPerInch

    @pixels_per_inch.setter
    def pixels_per_inch(self, value):
        """Alias for PixelsPerInch.setter"""
        self.PixelsPerInch = value

    @property
    def RelyOnCSS(self):
        return self.com_object.RelyOnCSS

    @RelyOnCSS.setter
    def RelyOnCSS(self, value):
        self.com_object.RelyOnCSS = value

    @property
    def relyoncss(self):
        """Alias for RelyOnCSS"""
        return self.RelyOnCSS

    @relyoncss.setter
    def relyoncss(self, value):
        """Alias for RelyOnCSS.setter"""
        self.RelyOnCSS = value

    @property
    def rely_on_c_s_s(self):
        """Alias for RelyOnCSS"""
        return self.RelyOnCSS

    @rely_on_c_s_s.setter
    def rely_on_c_s_s(self, value):
        """Alias for RelyOnCSS.setter"""
        self.RelyOnCSS = value

    @property
    def RelyOnVML(self):
        return self.com_object.RelyOnVML

    @RelyOnVML.setter
    def RelyOnVML(self, value):
        self.com_object.RelyOnVML = value

    @property
    def relyonvml(self):
        """Alias for RelyOnVML"""
        return self.RelyOnVML

    @relyonvml.setter
    def relyonvml(self, value):
        """Alias for RelyOnVML.setter"""
        self.RelyOnVML = value

    @property
    def rely_on_v_m_l(self):
        """Alias for RelyOnVML"""
        return self.RelyOnVML

    @rely_on_v_m_l.setter
    def rely_on_v_m_l(self, value):
        """Alias for RelyOnVML.setter"""
        self.RelyOnVML = value

    @property
    def SaveHiddenData(self):
        return self.com_object.SaveHiddenData

    @SaveHiddenData.setter
    def SaveHiddenData(self, value):
        self.com_object.SaveHiddenData = value

    @property
    def savehiddendata(self):
        """Alias for SaveHiddenData"""
        return self.SaveHiddenData

    @savehiddendata.setter
    def savehiddendata(self, value):
        """Alias for SaveHiddenData.setter"""
        self.SaveHiddenData = value

    @property
    def save_hidden_data(self):
        """Alias for SaveHiddenData"""
        return self.SaveHiddenData

    @save_hidden_data.setter
    def save_hidden_data(self, value):
        """Alias for SaveHiddenData.setter"""
        self.SaveHiddenData = value

    @property
    def SaveNewWebPagesAsWebArchives(self):
        return self.com_object.SaveNewWebPagesAsWebArchives

    @SaveNewWebPagesAsWebArchives.setter
    def SaveNewWebPagesAsWebArchives(self, value):
        self.com_object.SaveNewWebPagesAsWebArchives = value

    @property
    def savenewwebpagesaswebarchives(self):
        """Alias for SaveNewWebPagesAsWebArchives"""
        return self.SaveNewWebPagesAsWebArchives

    @savenewwebpagesaswebarchives.setter
    def savenewwebpagesaswebarchives(self, value):
        """Alias for SaveNewWebPagesAsWebArchives.setter"""
        self.SaveNewWebPagesAsWebArchives = value

    @property
    def save_new_web_pages_as_web_archives(self):
        """Alias for SaveNewWebPagesAsWebArchives"""
        return self.SaveNewWebPagesAsWebArchives

    @save_new_web_pages_as_web_archives.setter
    def save_new_web_pages_as_web_archives(self, value):
        """Alias for SaveNewWebPagesAsWebArchives.setter"""
        self.SaveNewWebPagesAsWebArchives = value

    @property
    def ScreenSize(self):
        return self.com_object.ScreenSize

    @ScreenSize.setter
    def ScreenSize(self, value):
        self.com_object.ScreenSize = value

    @property
    def screensize(self):
        """Alias for ScreenSize"""
        return self.ScreenSize

    @screensize.setter
    def screensize(self, value):
        """Alias for ScreenSize.setter"""
        self.ScreenSize = value

    @property
    def screen_size(self):
        """Alias for ScreenSize"""
        return self.ScreenSize

    @screen_size.setter
    def screen_size(self, value):
        """Alias for ScreenSize.setter"""
        self.ScreenSize = value

    @property
    def TargetBrowser(self):
        return self.com_object.TargetBrowser

    @TargetBrowser.setter
    def TargetBrowser(self, value):
        self.com_object.TargetBrowser = value

    @property
    def targetbrowser(self):
        """Alias for TargetBrowser"""
        return self.TargetBrowser

    @targetbrowser.setter
    def targetbrowser(self, value):
        """Alias for TargetBrowser.setter"""
        self.TargetBrowser = value

    @property
    def target_browser(self):
        """Alias for TargetBrowser"""
        return self.TargetBrowser

    @target_browser.setter
    def target_browser(self, value):
        """Alias for TargetBrowser.setter"""
        self.TargetBrowser = value

    @property
    def UpdateLinksOnSave(self):
        return self.com_object.UpdateLinksOnSave

    @UpdateLinksOnSave.setter
    def UpdateLinksOnSave(self, value):
        self.com_object.UpdateLinksOnSave = value

    @property
    def updatelinksonsave(self):
        """Alias for UpdateLinksOnSave"""
        return self.UpdateLinksOnSave

    @updatelinksonsave.setter
    def updatelinksonsave(self, value):
        """Alias for UpdateLinksOnSave.setter"""
        self.UpdateLinksOnSave = value

    @property
    def update_links_on_save(self):
        """Alias for UpdateLinksOnSave"""
        return self.UpdateLinksOnSave

    @update_links_on_save.setter
    def update_links_on_save(self, value):
        """Alias for UpdateLinksOnSave.setter"""
        self.UpdateLinksOnSave = value

    @property
    def UseLongFileNames(self):
        return self.com_object.UseLongFileNames

    @UseLongFileNames.setter
    def UseLongFileNames(self, value):
        self.com_object.UseLongFileNames = value

    @property
    def uselongfilenames(self):
        """Alias for UseLongFileNames"""
        return self.UseLongFileNames

    @uselongfilenames.setter
    def uselongfilenames(self, value):
        """Alias for UseLongFileNames.setter"""
        self.UseLongFileNames = value

    @property
    def use_long_file_names(self):
        """Alias for UseLongFileNames"""
        return self.UseLongFileNames

    @use_long_file_names.setter
    def use_long_file_names(self, value):
        """Alias for UseLongFileNames.setter"""
        self.UseLongFileNames = value


class Dialog:

    def __init__(self, dialog=None):
        self.com_object= dialog

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Show(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Show(*arguments)

    def show(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Show"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Show(*arguments)


class Dialogs:

    def __init__(self, dialogs=None):
        self.com_object= dialogs

    def __call__(self, item):
        return Dialog(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class DialogSheetView:

    def __init__(self, dialogsheetview=None):
        self.com_object= dialogsheetview

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Sheet(self):
        return DialogSheetView(self.com_object.Sheet)

    @property
    def sheet(self):
        """Alias for Sheet"""
        return self.Sheet


class DisplayFormat:

    def __init__(self, displayformat=None):
        self.com_object= displayformat

    @property
    def AddIndent(self):
        return Range(self.com_object.AddIndent)

    @property
    def addindent(self):
        """Alias for AddIndent"""
        return self.AddIndent

    @property
    def add_indent(self):
        """Alias for AddIndent"""
        return self.AddIndent

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    def Characters(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        if hasattr(self.com_object, "GetCharacters"):
            return Characters(self.com_object.GetCharacters(*arguments))
        else:
            return Characters(self.com_object.Characters(*arguments))

    def characters(self, Start=None, Length=None):
        """Alias for Characters"""
        arguments = [Start, Length]
        return self.Characters(*arguments)

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def FormulaHidden(self):
        return Range(self.com_object.FormulaHidden)

    @property
    def formulahidden(self):
        """Alias for FormulaHidden"""
        return self.FormulaHidden

    @property
    def formula_hidden(self):
        """Alias for FormulaHidden"""
        return self.FormulaHidden

    @property
    def HorizontalAlignment(self):
        return Range(self.com_object.HorizontalAlignment)

    @property
    def horizontalalignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @property
    def horizontal_alignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @property
    def IndentLevel(self):
        return Range(self.com_object.IndentLevel)

    @property
    def indentlevel(self):
        """Alias for IndentLevel"""
        return self.IndentLevel

    @property
    def indent_level(self):
        """Alias for IndentLevel"""
        return self.IndentLevel

    @property
    def Interior(self):
        return Interior(self.com_object.Interior)

    @property
    def interior(self):
        """Alias for Interior"""
        return self.Interior

    @property
    def Locked(self):
        return Range(self.com_object.Locked)

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @property
    def MergeCells(self):
        return Range(self.com_object.MergeCells)

    @property
    def mergecells(self):
        """Alias for MergeCells"""
        return self.MergeCells

    @property
    def merge_cells(self):
        """Alias for MergeCells"""
        return self.MergeCells

    @property
    def NumberFormat(self):
        return Range(self.com_object.NumberFormat)

    @property
    def numberformat(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @property
    def number_format(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @property
    def NumberFormatLocal(self):
        return Range(self.com_object.NumberFormatLocal)

    @property
    def numberformatlocal(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @property
    def number_format_local(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @property
    def Orientation(self):
        return Range(self.com_object.Orientation)

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ReadingOrder(self):
        return Range(self.com_object.ReadingOrder)

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @property
    def ShrinkToFit(self):
        return Range(self.com_object.ShrinkToFit)

    @property
    def shrinktofit(self):
        """Alias for ShrinkToFit"""
        return self.ShrinkToFit

    @property
    def shrink_to_fit(self):
        """Alias for ShrinkToFit"""
        return self.ShrinkToFit

    @property
    def Style(self):
        return Style(self.com_object.Style)

    @property
    def style(self):
        """Alias for Style"""
        return self.Style

    @property
    def VerticalAlignment(self):
        return Range(self.com_object.VerticalAlignment)

    @property
    def verticalalignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @property
    def vertical_alignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @property
    def WrapText(self):
        return Range(self.com_object.WrapText)

    @property
    def wraptext(self):
        """Alias for WrapText"""
        return self.WrapText

    @property
    def wrap_text(self):
        """Alias for WrapText"""
        return self.WrapText


class DisplayUnitLabel:

    def __init__(self, displayunitlabel=None):
        self.com_object= displayunitlabel

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    def Characters(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        if hasattr(self.com_object, "GetCharacters"):
            return Characters(self.com_object.GetCharacters(*arguments))
        else:
            return Characters(self.com_object.Characters(*arguments))

    def characters(self, Start=None, Length=None):
        """Alias for Characters"""
        arguments = [Start, Length]
        return self.Characters(*arguments)

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def FormulaLocal(self):
        return self.com_object.FormulaLocal

    @FormulaLocal.setter
    def FormulaLocal(self, value):
        self.com_object.FormulaLocal = value

    @property
    def formulalocal(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formulalocal.setter
    def formulalocal(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def formula_local(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formula_local.setter
    def formula_local(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def FormulaR1C1(self):
        return self.com_object.FormulaR1C1

    @FormulaR1C1.setter
    def FormulaR1C1(self, value):
        self.com_object.FormulaR1C1 = value

    @property
    def formular1c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formular1c1.setter
    def formular1c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def formula_r1_c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formula_r1_c1.setter
    def formula_r1_c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def FormulaR1C1Local(self):
        return self.com_object.FormulaR1C1Local

    @FormulaR1C1Local.setter
    def FormulaR1C1Local(self, value):
        self.com_object.FormulaR1C1Local = value

    @property
    def formular1c1local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formular1c1local.setter
    def formular1c1local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def formula_r1_c1_local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formula_r1_c1_local.setter
    def formula_r1_c1_local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def HorizontalAlignment(self):
        return self.com_object.HorizontalAlignment

    @HorizontalAlignment.setter
    def HorizontalAlignment(self, value):
        self.com_object.HorizontalAlignment = value

    @property
    def horizontalalignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontalalignment.setter
    def horizontalalignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def horizontal_alignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return XlChartElementPosition(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def ReadingOrder(self):
        return self.com_object.ReadingOrder

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def VerticalAlignment(self):
        return self.com_object.VerticalAlignment

    @VerticalAlignment.setter
    def VerticalAlignment(self, value):
        self.com_object.VerticalAlignment = value

    @property
    def verticalalignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @verticalalignment.setter
    def verticalalignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def vertical_alignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @vertical_alignment.setter
    def vertical_alignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        return self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class DownBars:

    def __init__(self, downbars=None):
        self.com_object= downbars

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        return self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class DropLines:

    def __init__(self, droplines=None):
        self.com_object= droplines

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Border(self):
        return Border(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        return self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Error:

    def __init__(self, error=None):
        self.com_object= error

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Ignore(self):
        return self.com_object.Ignore

    @Ignore.setter
    def Ignore(self, value):
        self.com_object.Ignore = value

    @property
    def ignore(self):
        """Alias for Ignore"""
        return self.Ignore

    @ignore.setter
    def ignore(self, value):
        """Alias for Ignore.setter"""
        self.Ignore = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Value(self):
        return self.com_object.Value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value


class ErrorBars:

    def __init__(self, errorbars=None):
        self.com_object= errorbars

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Border(self):
        return Border(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def EndStyle(self):
        return XlEndStyleCap(self.com_object.EndStyle)

    @EndStyle.setter
    def EndStyle(self, value):
        self.com_object.EndStyle = value

    @property
    def endstyle(self):
        """Alias for EndStyle"""
        return self.EndStyle

    @endstyle.setter
    def endstyle(self, value):
        """Alias for EndStyle.setter"""
        self.EndStyle = value

    @property
    def end_style(self):
        """Alias for EndStyle"""
        return self.EndStyle

    @end_style.setter
    def end_style(self, value):
        """Alias for EndStyle.setter"""
        self.EndStyle = value

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def ClearFormats(self):
        return self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        return self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class ErrorCheckingOptions:

    def __init__(self, errorcheckingoptions=None):
        self.com_object= errorcheckingoptions

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BackgroundChecking(self):
        return self.com_object.BackgroundChecking

    @BackgroundChecking.setter
    def BackgroundChecking(self, value):
        self.com_object.BackgroundChecking = value

    @property
    def backgroundchecking(self):
        """Alias for BackgroundChecking"""
        return self.BackgroundChecking

    @backgroundchecking.setter
    def backgroundchecking(self, value):
        """Alias for BackgroundChecking.setter"""
        self.BackgroundChecking = value

    @property
    def background_checking(self):
        """Alias for BackgroundChecking"""
        return self.BackgroundChecking

    @background_checking.setter
    def background_checking(self, value):
        """Alias for BackgroundChecking.setter"""
        self.BackgroundChecking = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def EmptyCellReferences(self):
        return self.com_object.EmptyCellReferences

    @EmptyCellReferences.setter
    def EmptyCellReferences(self, value):
        self.com_object.EmptyCellReferences = value

    @property
    def emptycellreferences(self):
        """Alias for EmptyCellReferences"""
        return self.EmptyCellReferences

    @emptycellreferences.setter
    def emptycellreferences(self, value):
        """Alias for EmptyCellReferences.setter"""
        self.EmptyCellReferences = value

    @property
    def empty_cell_references(self):
        """Alias for EmptyCellReferences"""
        return self.EmptyCellReferences

    @empty_cell_references.setter
    def empty_cell_references(self, value):
        """Alias for EmptyCellReferences.setter"""
        self.EmptyCellReferences = value

    @property
    def EvaluateToError(self):
        return self.com_object.EvaluateToError

    @EvaluateToError.setter
    def EvaluateToError(self, value):
        self.com_object.EvaluateToError = value

    @property
    def evaluatetoerror(self):
        """Alias for EvaluateToError"""
        return self.EvaluateToError

    @evaluatetoerror.setter
    def evaluatetoerror(self, value):
        """Alias for EvaluateToError.setter"""
        self.EvaluateToError = value

    @property
    def evaluate_to_error(self):
        """Alias for EvaluateToError"""
        return self.EvaluateToError

    @evaluate_to_error.setter
    def evaluate_to_error(self, value):
        """Alias for EvaluateToError.setter"""
        self.EvaluateToError = value

    @property
    def InconsistentFormula(self):
        return self.com_object.InconsistentFormula

    @InconsistentFormula.setter
    def InconsistentFormula(self, value):
        self.com_object.InconsistentFormula = value

    @property
    def inconsistentformula(self):
        """Alias for InconsistentFormula"""
        return self.InconsistentFormula

    @inconsistentformula.setter
    def inconsistentformula(self, value):
        """Alias for InconsistentFormula.setter"""
        self.InconsistentFormula = value

    @property
    def inconsistent_formula(self):
        """Alias for InconsistentFormula"""
        return self.InconsistentFormula

    @inconsistent_formula.setter
    def inconsistent_formula(self, value):
        """Alias for InconsistentFormula.setter"""
        self.InconsistentFormula = value

    @property
    def InconsistentTableFormula(self):
        return self.com_object.InconsistentTableFormula

    @InconsistentTableFormula.setter
    def InconsistentTableFormula(self, value):
        self.com_object.InconsistentTableFormula = value

    @property
    def inconsistenttableformula(self):
        """Alias for InconsistentTableFormula"""
        return self.InconsistentTableFormula

    @inconsistenttableformula.setter
    def inconsistenttableformula(self, value):
        """Alias for InconsistentTableFormula.setter"""
        self.InconsistentTableFormula = value

    @property
    def inconsistent_table_formula(self):
        """Alias for InconsistentTableFormula"""
        return self.InconsistentTableFormula

    @inconsistent_table_formula.setter
    def inconsistent_table_formula(self, value):
        """Alias for InconsistentTableFormula.setter"""
        self.InconsistentTableFormula = value

    @property
    def IndicatorColorIndex(self):
        return XlColorIndex(self.com_object.IndicatorColorIndex)

    @IndicatorColorIndex.setter
    def IndicatorColorIndex(self, value):
        self.com_object.IndicatorColorIndex = value

    @property
    def indicatorcolorindex(self):
        """Alias for IndicatorColorIndex"""
        return self.IndicatorColorIndex

    @indicatorcolorindex.setter
    def indicatorcolorindex(self, value):
        """Alias for IndicatorColorIndex.setter"""
        self.IndicatorColorIndex = value

    @property
    def indicator_color_index(self):
        """Alias for IndicatorColorIndex"""
        return self.IndicatorColorIndex

    @indicator_color_index.setter
    def indicator_color_index(self, value):
        """Alias for IndicatorColorIndex.setter"""
        self.IndicatorColorIndex = value

    @property
    def ListDataValidation(self):
        return self.com_object.ListDataValidation

    @ListDataValidation.setter
    def ListDataValidation(self, value):
        self.com_object.ListDataValidation = value

    @property
    def listdatavalidation(self):
        """Alias for ListDataValidation"""
        return self.ListDataValidation

    @listdatavalidation.setter
    def listdatavalidation(self, value):
        """Alias for ListDataValidation.setter"""
        self.ListDataValidation = value

    @property
    def list_data_validation(self):
        """Alias for ListDataValidation"""
        return self.ListDataValidation

    @list_data_validation.setter
    def list_data_validation(self, value):
        """Alias for ListDataValidation.setter"""
        self.ListDataValidation = value

    @property
    def NumberAsText(self):
        return self.com_object.NumberAsText

    @NumberAsText.setter
    def NumberAsText(self, value):
        self.com_object.NumberAsText = value

    @property
    def numberastext(self):
        """Alias for NumberAsText"""
        return self.NumberAsText

    @numberastext.setter
    def numberastext(self, value):
        """Alias for NumberAsText.setter"""
        self.NumberAsText = value

    @property
    def number_as_text(self):
        """Alias for NumberAsText"""
        return self.NumberAsText

    @number_as_text.setter
    def number_as_text(self, value):
        """Alias for NumberAsText.setter"""
        self.NumberAsText = value

    @property
    def OmittedCells(self):
        return self.com_object.OmittedCells

    @OmittedCells.setter
    def OmittedCells(self, value):
        self.com_object.OmittedCells = value

    @property
    def omittedcells(self):
        """Alias for OmittedCells"""
        return self.OmittedCells

    @omittedcells.setter
    def omittedcells(self, value):
        """Alias for OmittedCells.setter"""
        self.OmittedCells = value

    @property
    def omitted_cells(self):
        """Alias for OmittedCells"""
        return self.OmittedCells

    @omitted_cells.setter
    def omitted_cells(self, value):
        """Alias for OmittedCells.setter"""
        self.OmittedCells = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def TextDate(self):
        return self.com_object.TextDate

    @TextDate.setter
    def TextDate(self, value):
        self.com_object.TextDate = value

    @property
    def textdate(self):
        """Alias for TextDate"""
        return self.TextDate

    @textdate.setter
    def textdate(self, value):
        """Alias for TextDate.setter"""
        self.TextDate = value

    @property
    def text_date(self):
        """Alias for TextDate"""
        return self.TextDate

    @text_date.setter
    def text_date(self, value):
        """Alias for TextDate.setter"""
        self.TextDate = value

    @property
    def UnlockedFormulaCells(self):
        return self.com_object.UnlockedFormulaCells

    @UnlockedFormulaCells.setter
    def UnlockedFormulaCells(self, value):
        self.com_object.UnlockedFormulaCells = value

    @property
    def unlockedformulacells(self):
        """Alias for UnlockedFormulaCells"""
        return self.UnlockedFormulaCells

    @unlockedformulacells.setter
    def unlockedformulacells(self, value):
        """Alias for UnlockedFormulaCells.setter"""
        self.UnlockedFormulaCells = value

    @property
    def unlocked_formula_cells(self):
        """Alias for UnlockedFormulaCells"""
        return self.UnlockedFormulaCells

    @unlocked_formula_cells.setter
    def unlocked_formula_cells(self, value):
        """Alias for UnlockedFormulaCells.setter"""
        self.UnlockedFormulaCells = value


class Errors:

    def __init__(self, errors=None):
        self.com_object= errors

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return Error(self.com_object.GetItem(*arguments))
        else:
            return Error(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class FileExportConverter:

    def __init__(self, fileexportconverter=None):
        self.com_object= fileexportconverter

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Description(self):
        return self.com_object.Description

    @property
    def description(self):
        """Alias for Description"""
        return self.Description

    @property
    def Extensions(self):
        return FileExportConverter(self.com_object.Extensions)

    @property
    def extensions(self):
        """Alias for Extensions"""
        return self.Extensions

    @property
    def FileFormat(self):
        return FileExportConverter(self.com_object.FileFormat)

    @property
    def fileformat(self):
        """Alias for FileFormat"""
        return self.FileFormat

    @property
    def file_format(self):
        """Alias for FileFormat"""
        return self.FileFormat

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class FileExportConverters:

    def __init__(self, fileexportconverters=None):
        self.com_object= fileexportconverters

    def __call__(self, item):
        return FileExportConverter(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return FileExportConverter(self.com_object.GetItem(*arguments))
        else:
            return FileExportConverter(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class FillFormat:

    def __init__(self, fillformat=None):
        self.com_object= fillformat

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BackColor(self):
        return ColorFormat(self.com_object.BackColor)

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ForeColor(self):
        return ColorFormat(self.com_object.ForeColor)

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def GradientAngle(self):
        return self.com_object.GradientAngle

    @GradientAngle.setter
    def GradientAngle(self, value):
        self.com_object.GradientAngle = value

    @property
    def gradientangle(self):
        """Alias for GradientAngle"""
        return self.GradientAngle

    @gradientangle.setter
    def gradientangle(self, value):
        """Alias for GradientAngle.setter"""
        self.GradientAngle = value

    @property
    def gradient_angle(self):
        """Alias for GradientAngle"""
        return self.GradientAngle

    @gradient_angle.setter
    def gradient_angle(self, value):
        """Alias for GradientAngle.setter"""
        self.GradientAngle = value

    @property
    def GradientColorType(self):
        return self.com_object.GradientColorType

    @property
    def gradientcolortype(self):
        """Alias for GradientColorType"""
        return self.GradientColorType

    @property
    def gradient_color_type(self):
        """Alias for GradientColorType"""
        return self.GradientColorType

    @property
    def GradientDegree(self):
        return self.com_object.GradientDegree

    @property
    def gradientdegree(self):
        """Alias for GradientDegree"""
        return self.GradientDegree

    @property
    def gradient_degree(self):
        """Alias for GradientDegree"""
        return self.GradientDegree

    @property
    def GradientStops(self):
        return self.com_object.GradientStops

    @property
    def gradientstops(self):
        """Alias for GradientStops"""
        return self.GradientStops

    @property
    def gradient_stops(self):
        """Alias for GradientStops"""
        return self.GradientStops

    @property
    def GradientStyle(self):
        return self.com_object.GradientStyle

    @property
    def gradientstyle(self):
        """Alias for GradientStyle"""
        return self.GradientStyle

    @property
    def gradient_style(self):
        """Alias for GradientStyle"""
        return self.GradientStyle

    @property
    def GradientVariant(self):
        return self.com_object.GradientVariant

    @property
    def gradientvariant(self):
        """Alias for GradientVariant"""
        return self.GradientVariant

    @property
    def gradient_variant(self):
        """Alias for GradientVariant"""
        return self.GradientVariant

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Pattern(self):
        return self.com_object.Pattern

    @Pattern.setter
    def Pattern(self, value):
        self.com_object.Pattern = value

    @property
    def pattern(self):
        """Alias for Pattern"""
        return self.Pattern

    @pattern.setter
    def pattern(self, value):
        """Alias for Pattern.setter"""
        self.Pattern = value

    @property
    def PictureEffects(self):
        return self.com_object.PictureEffects

    @property
    def pictureeffects(self):
        """Alias for PictureEffects"""
        return self.PictureEffects

    @property
    def picture_effects(self):
        """Alias for PictureEffects"""
        return self.PictureEffects

    @property
    def PresetGradientType(self):
        return self.com_object.PresetGradientType

    @property
    def presetgradienttype(self):
        """Alias for PresetGradientType"""
        return self.PresetGradientType

    @property
    def preset_gradient_type(self):
        """Alias for PresetGradientType"""
        return self.PresetGradientType

    @property
    def PresetTexture(self):
        return self.com_object.PresetTexture

    @property
    def presettexture(self):
        """Alias for PresetTexture"""
        return self.PresetTexture

    @property
    def preset_texture(self):
        """Alias for PresetTexture"""
        return self.PresetTexture

    @property
    def RotateWithObject(self):
        return self.com_object.RotateWithObject

    @RotateWithObject.setter
    def RotateWithObject(self, value):
        self.com_object.RotateWithObject = value

    @property
    def rotatewithobject(self):
        """Alias for RotateWithObject"""
        return self.RotateWithObject

    @rotatewithobject.setter
    def rotatewithobject(self, value):
        """Alias for RotateWithObject.setter"""
        self.RotateWithObject = value

    @property
    def rotate_with_object(self):
        """Alias for RotateWithObject"""
        return self.RotateWithObject

    @rotate_with_object.setter
    def rotate_with_object(self, value):
        """Alias for RotateWithObject.setter"""
        self.RotateWithObject = value

    @property
    def TextureAlignment(self):
        return self.com_object.TextureAlignment

    @TextureAlignment.setter
    def TextureAlignment(self, value):
        self.com_object.TextureAlignment = value

    @property
    def texturealignment(self):
        """Alias for TextureAlignment"""
        return self.TextureAlignment

    @texturealignment.setter
    def texturealignment(self, value):
        """Alias for TextureAlignment.setter"""
        self.TextureAlignment = value

    @property
    def texture_alignment(self):
        """Alias for TextureAlignment"""
        return self.TextureAlignment

    @texture_alignment.setter
    def texture_alignment(self, value):
        """Alias for TextureAlignment.setter"""
        self.TextureAlignment = value

    @property
    def TextureHorizontalScale(self):
        return self.com_object.TextureHorizontalScale

    @TextureHorizontalScale.setter
    def TextureHorizontalScale(self, value):
        self.com_object.TextureHorizontalScale = value

    @property
    def texturehorizontalscale(self):
        """Alias for TextureHorizontalScale"""
        return self.TextureHorizontalScale

    @texturehorizontalscale.setter
    def texturehorizontalscale(self, value):
        """Alias for TextureHorizontalScale.setter"""
        self.TextureHorizontalScale = value

    @property
    def texture_horizontal_scale(self):
        """Alias for TextureHorizontalScale"""
        return self.TextureHorizontalScale

    @texture_horizontal_scale.setter
    def texture_horizontal_scale(self, value):
        """Alias for TextureHorizontalScale.setter"""
        self.TextureHorizontalScale = value

    @property
    def TextureName(self):
        return self.com_object.TextureName

    @property
    def texturename(self):
        """Alias for TextureName"""
        return self.TextureName

    @property
    def texture_name(self):
        """Alias for TextureName"""
        return self.TextureName

    @property
    def TextureOffsetX(self):
        return self.com_object.TextureOffsetX

    @TextureOffsetX.setter
    def TextureOffsetX(self, value):
        self.com_object.TextureOffsetX = value

    @property
    def textureoffsetx(self):
        """Alias for TextureOffsetX"""
        return self.TextureOffsetX

    @textureoffsetx.setter
    def textureoffsetx(self, value):
        """Alias for TextureOffsetX.setter"""
        self.TextureOffsetX = value

    @property
    def texture_offset_x(self):
        """Alias for TextureOffsetX"""
        return self.TextureOffsetX

    @texture_offset_x.setter
    def texture_offset_x(self, value):
        """Alias for TextureOffsetX.setter"""
        self.TextureOffsetX = value

    @property
    def TextureOffsetY(self):
        return self.com_object.TextureOffsetY

    @TextureOffsetY.setter
    def TextureOffsetY(self, value):
        self.com_object.TextureOffsetY = value

    @property
    def textureoffsety(self):
        """Alias for TextureOffsetY"""
        return self.TextureOffsetY

    @textureoffsety.setter
    def textureoffsety(self, value):
        """Alias for TextureOffsetY.setter"""
        self.TextureOffsetY = value

    @property
    def texture_offset_y(self):
        """Alias for TextureOffsetY"""
        return self.TextureOffsetY

    @texture_offset_y.setter
    def texture_offset_y(self, value):
        """Alias for TextureOffsetY.setter"""
        self.TextureOffsetY = value

    @property
    def TextureTile(self):
        return self.com_object.TextureTile

    @TextureTile.setter
    def TextureTile(self, value):
        self.com_object.TextureTile = value

    @property
    def texturetile(self):
        """Alias for TextureTile"""
        return self.TextureTile

    @texturetile.setter
    def texturetile(self, value):
        """Alias for TextureTile.setter"""
        self.TextureTile = value

    @property
    def texture_tile(self):
        """Alias for TextureTile"""
        return self.TextureTile

    @texture_tile.setter
    def texture_tile(self, value):
        """Alias for TextureTile.setter"""
        self.TextureTile = value

    @property
    def TextureType(self):
        return self.com_object.TextureType

    @property
    def texturetype(self):
        """Alias for TextureType"""
        return self.TextureType

    @property
    def texture_type(self):
        """Alias for TextureType"""
        return self.TextureType

    @property
    def TextureVerticalScale(self):
        return self.com_object.TextureVerticalScale

    @TextureVerticalScale.setter
    def TextureVerticalScale(self, value):
        self.com_object.TextureVerticalScale = value

    @property
    def textureverticalscale(self):
        """Alias for TextureVerticalScale"""
        return self.TextureVerticalScale

    @textureverticalscale.setter
    def textureverticalscale(self, value):
        """Alias for TextureVerticalScale.setter"""
        self.TextureVerticalScale = value

    @property
    def texture_vertical_scale(self):
        """Alias for TextureVerticalScale"""
        return self.TextureVerticalScale

    @texture_vertical_scale.setter
    def texture_vertical_scale(self, value):
        """Alias for TextureVerticalScale.setter"""
        self.TextureVerticalScale = value

    @property
    def Transparency(self):
        return self.com_object.Transparency

    @Transparency.setter
    def Transparency(self, value):
        self.com_object.Transparency = value

    @property
    def transparency(self):
        """Alias for Transparency"""
        return self.Transparency

    @transparency.setter
    def transparency(self, value):
        """Alias for Transparency.setter"""
        self.Transparency = value

    @property
    def Type(self):
        return self.com_object.Type

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    def OneColorGradient(self, Style=None, Variant=None, Degree=None):
        arguments = com_arguments([unwrap(a) for a in [Style, Variant, Degree]])
        self.com_object.OneColorGradient(*arguments)

    def onecolorgradient(self, Style=None, Variant=None, Degree=None):
        """Alias for OneColorGradient"""
        arguments = [Style, Variant, Degree]
        return self.OneColorGradient(*arguments)

    def one_color_gradient(self, Style=None, Variant=None, Degree=None):
        """Alias for OneColorGradient"""
        arguments = [Style, Variant, Degree]
        return self.OneColorGradient(*arguments)

    def Patterned(self, Pattern=None):
        arguments = com_arguments([unwrap(a) for a in [Pattern]])
        self.com_object.Patterned(*arguments)

    def patterned(self, Pattern=None):
        """Alias for Patterned"""
        arguments = [Pattern]
        return self.Patterned(*arguments)

    def PresetGradient(self, Style=None, Variant=None, PresetGradientType=None):
        arguments = com_arguments([unwrap(a) for a in [Style, Variant, PresetGradientType]])
        self.com_object.PresetGradient(*arguments)

    def presetgradient(self, Style=None, Variant=None, PresetGradientType=None):
        """Alias for PresetGradient"""
        arguments = [Style, Variant, PresetGradientType]
        return self.PresetGradient(*arguments)

    def preset_gradient(self, Style=None, Variant=None, PresetGradientType=None):
        """Alias for PresetGradient"""
        arguments = [Style, Variant, PresetGradientType]
        return self.PresetGradient(*arguments)

    def PresetTextured(self, PresetTexture=None):
        arguments = com_arguments([unwrap(a) for a in [PresetTexture]])
        self.com_object.PresetTextured(*arguments)

    def presettextured(self, PresetTexture=None):
        """Alias for PresetTextured"""
        arguments = [PresetTexture]
        return self.PresetTextured(*arguments)

    def preset_textured(self, PresetTexture=None):
        """Alias for PresetTextured"""
        arguments = [PresetTexture]
        return self.PresetTextured(*arguments)

    def Solid(self):
        self.com_object.Solid()

    def solid(self):
        """Alias for Solid"""
        return self.Solid()

    def TwoColorGradient(self, Style=None, Variant=None):
        arguments = com_arguments([unwrap(a) for a in [Style, Variant]])
        self.com_object.TwoColorGradient(*arguments)

    def twocolorgradient(self, Style=None, Variant=None):
        """Alias for TwoColorGradient"""
        arguments = [Style, Variant]
        return self.TwoColorGradient(*arguments)

    def two_color_gradient(self, Style=None, Variant=None):
        """Alias for TwoColorGradient"""
        arguments = [Style, Variant]
        return self.TwoColorGradient(*arguments)

    def UserPicture(self, PictureFile=None):
        arguments = com_arguments([unwrap(a) for a in [PictureFile]])
        self.com_object.UserPicture(*arguments)

    def userpicture(self, PictureFile=None):
        """Alias for UserPicture"""
        arguments = [PictureFile]
        return self.UserPicture(*arguments)

    def user_picture(self, PictureFile=None):
        """Alias for UserPicture"""
        arguments = [PictureFile]
        return self.UserPicture(*arguments)

    def UserTextured(self, TextureFile=None):
        arguments = com_arguments([unwrap(a) for a in [TextureFile]])
        self.com_object.UserTextured(*arguments)

    def usertextured(self, TextureFile=None):
        """Alias for UserTextured"""
        arguments = [TextureFile]
        return self.UserTextured(*arguments)

    def user_textured(self, TextureFile=None):
        """Alias for UserTextured"""
        arguments = [TextureFile]
        return self.UserTextured(*arguments)


class Filter:

    def __init__(self, filter=None):
        self.com_object= filter

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Criteria1(self):
        return self.com_object.Criteria1

    @property
    def criteria1(self):
        """Alias for Criteria1"""
        return self.Criteria1

    @property
    def Criteria2(self):
        return self.com_object.Criteria2

    @property
    def criteria2(self):
        """Alias for Criteria2"""
        return self.Criteria2

    @property
    def On(self):
        return self.com_object.On

    @property
    def on(self):
        """Alias for On"""
        return self.On

    @property
    def Operator(self):
        return XlAutoFilterOperator(self.com_object.Operator)

    @property
    def operator(self):
        """Alias for Operator"""
        return self.Operator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class Filters:

    def __init__(self, filters=None):
        self.com_object= filters

    def __call__(self, item):
        return Filter(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class Floor:

    def __init__(self, floor=None):
        self.com_object= floor

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PictureType(self):
        return self.com_object.PictureType

    @PictureType.setter
    def PictureType(self, value):
        self.com_object.PictureType = value

    @property
    def picturetype(self):
        """Alias for PictureType"""
        return self.PictureType

    @picturetype.setter
    def picturetype(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def picture_type(self):
        """Alias for PictureType"""
        return self.PictureType

    @picture_type.setter
    def picture_type(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def Thickness(self):
        return self.com_object.Thickness

    @Thickness.setter
    def Thickness(self, value):
        self.com_object.Thickness = value

    @property
    def thickness(self):
        """Alias for Thickness"""
        return self.Thickness

    @thickness.setter
    def thickness(self, value):
        """Alias for Thickness.setter"""
        self.Thickness = value

    def ClearFormats(self):
        return self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Paste(self):
        self.com_object.Paste()

    def paste(self):
        """Alias for Paste"""
        return self.Paste()

    def Select(self):
        return self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Font:

    def __init__(self, font=None):
        self.com_object= font

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Background(self):
        return XlBackground(self.com_object.Background)

    @Background.setter
    def Background(self, value):
        self.com_object.Background = value

    @property
    def background(self):
        """Alias for Background"""
        return self.Background

    @background.setter
    def background(self, value):
        """Alias for Background.setter"""
        self.Background = value

    @property
    def Bold(self):
        return self.com_object.Bold

    @Bold.setter
    def Bold(self, value):
        self.com_object.Bold = value

    @property
    def bold(self):
        """Alias for Bold"""
        return self.Bold

    @bold.setter
    def bold(self, value):
        """Alias for Bold.setter"""
        self.Bold = value

    @property
    def Color(self):
        return RGB(self.com_object.Color)

    @Color.setter
    def Color(self, value):
        self.com_object.Color = value

    @property
    def color(self):
        """Alias for Color"""
        return self.Color

    @color.setter
    def color(self, value):
        """Alias for Color.setter"""
        self.Color = value

    @property
    def ColorIndex(self):
        return self.com_object.ColorIndex

    @ColorIndex.setter
    def ColorIndex(self, value):
        self.com_object.ColorIndex = value

    @property
    def colorindex(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @colorindex.setter
    def colorindex(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def color_index(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @color_index.setter
    def color_index(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def FontStyle(self):
        return self.com_object.FontStyle

    @FontStyle.setter
    def FontStyle(self, value):
        self.com_object.FontStyle = value

    @property
    def fontstyle(self):
        """Alias for FontStyle"""
        return self.FontStyle

    @fontstyle.setter
    def fontstyle(self, value):
        """Alias for FontStyle.setter"""
        self.FontStyle = value

    @property
    def font_style(self):
        """Alias for FontStyle"""
        return self.FontStyle

    @font_style.setter
    def font_style(self, value):
        """Alias for FontStyle.setter"""
        self.FontStyle = value

    @property
    def Italic(self):
        return self.com_object.Italic

    @Italic.setter
    def Italic(self, value):
        self.com_object.Italic = value

    @property
    def italic(self):
        """Alias for Italic"""
        return self.Italic

    @italic.setter
    def italic(self, value):
        """Alias for Italic.setter"""
        self.Italic = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Size(self):
        return self.com_object.Size

    @Size.setter
    def Size(self, value):
        self.com_object.Size = value

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @size.setter
    def size(self, value):
        """Alias for Size.setter"""
        self.Size = value

    @property
    def Strikethrough(self):
        return self.com_object.Strikethrough

    @Strikethrough.setter
    def Strikethrough(self, value):
        self.com_object.Strikethrough = value

    @property
    def strikethrough(self):
        """Alias for Strikethrough"""
        return self.Strikethrough

    @strikethrough.setter
    def strikethrough(self, value):
        """Alias for Strikethrough.setter"""
        self.Strikethrough = value

    @property
    def Subscript(self):
        return self.com_object.Subscript

    @Subscript.setter
    def Subscript(self, value):
        self.com_object.Subscript = value

    @property
    def subscript(self):
        """Alias for Subscript"""
        return self.Subscript

    @subscript.setter
    def subscript(self, value):
        """Alias for Subscript.setter"""
        self.Subscript = value

    @property
    def Superscript(self):
        return self.com_object.Superscript

    @Superscript.setter
    def Superscript(self, value):
        self.com_object.Superscript = value

    @property
    def superscript(self):
        """Alias for Superscript"""
        return self.Superscript

    @superscript.setter
    def superscript(self, value):
        """Alias for Superscript.setter"""
        self.Superscript = value

    @property
    def ThemeColor(self):
        return self.com_object.ThemeColor

    @ThemeColor.setter
    def ThemeColor(self, value):
        self.com_object.ThemeColor = value

    @property
    def themecolor(self):
        """Alias for ThemeColor"""
        return self.ThemeColor

    @themecolor.setter
    def themecolor(self, value):
        """Alias for ThemeColor.setter"""
        self.ThemeColor = value

    @property
    def theme_color(self):
        """Alias for ThemeColor"""
        return self.ThemeColor

    @theme_color.setter
    def theme_color(self, value):
        """Alias for ThemeColor.setter"""
        self.ThemeColor = value

    @property
    def ThemeFont(self):
        return XlThemeFont(self.com_object.ThemeFont)

    @ThemeFont.setter
    def ThemeFont(self, value):
        self.com_object.ThemeFont = value

    @property
    def themefont(self):
        """Alias for ThemeFont"""
        return self.ThemeFont

    @themefont.setter
    def themefont(self, value):
        """Alias for ThemeFont.setter"""
        self.ThemeFont = value

    @property
    def theme_font(self):
        """Alias for ThemeFont"""
        return self.ThemeFont

    @theme_font.setter
    def theme_font(self, value):
        """Alias for ThemeFont.setter"""
        self.ThemeFont = value

    @property
    def TintAndShade(self):
        return self.com_object.TintAndShade

    @TintAndShade.setter
    def TintAndShade(self, value):
        self.com_object.TintAndShade = value

    @property
    def tintandshade(self):
        """Alias for TintAndShade"""
        return self.TintAndShade

    @tintandshade.setter
    def tintandshade(self, value):
        """Alias for TintAndShade.setter"""
        self.TintAndShade = value

    @property
    def tint_and_shade(self):
        """Alias for TintAndShade"""
        return self.TintAndShade

    @tint_and_shade.setter
    def tint_and_shade(self, value):
        """Alias for TintAndShade.setter"""
        self.TintAndShade = value

    @property
    def Underline(self):
        return self.com_object.Underline

    @Underline.setter
    def Underline(self, value):
        self.com_object.Underline = value

    @property
    def underline(self):
        """Alias for Underline"""
        return self.Underline

    @underline.setter
    def underline(self, value):
        """Alias for Underline.setter"""
        self.Underline = value


class FormatColor:

    def __init__(self, formatcolor=None):
        self.com_object= formatcolor

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Color(self):
        return self.com_object.Color

    @Color.setter
    def Color(self, value):
        self.com_object.Color = value

    @property
    def color(self):
        """Alias for Color"""
        return self.Color

    @color.setter
    def color(self, value):
        """Alias for Color.setter"""
        self.Color = value

    @property
    def ColorIndex(self):
        return XlColorIndex(self.com_object.ColorIndex)

    @ColorIndex.setter
    def ColorIndex(self, value):
        self.com_object.ColorIndex = value

    @property
    def colorindex(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @colorindex.setter
    def colorindex(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def color_index(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @color_index.setter
    def color_index(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ThemeColor(self):
        return XlThemeColor(self.com_object.ThemeColor)

    @ThemeColor.setter
    def ThemeColor(self, value):
        self.com_object.ThemeColor = value

    @property
    def themecolor(self):
        """Alias for ThemeColor"""
        return self.ThemeColor

    @themecolor.setter
    def themecolor(self, value):
        """Alias for ThemeColor.setter"""
        self.ThemeColor = value

    @property
    def theme_color(self):
        """Alias for ThemeColor"""
        return self.ThemeColor

    @theme_color.setter
    def theme_color(self, value):
        """Alias for ThemeColor.setter"""
        self.ThemeColor = value

    @property
    def TintAndShade(self):
        return self.com_object.TintAndShade

    @TintAndShade.setter
    def TintAndShade(self, value):
        self.com_object.TintAndShade = value

    @property
    def tintandshade(self):
        """Alias for TintAndShade"""
        return self.TintAndShade

    @tintandshade.setter
    def tintandshade(self, value):
        """Alias for TintAndShade.setter"""
        self.TintAndShade = value

    @property
    def tint_and_shade(self):
        """Alias for TintAndShade"""
        return self.TintAndShade

    @tint_and_shade.setter
    def tint_and_shade(self, value):
        """Alias for TintAndShade.setter"""
        self.TintAndShade = value


class FormatCondition:

    def __init__(self, formatcondition=None):
        self.com_object= formatcondition

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AppliesTo(self):
        return Range(self.com_object.AppliesTo)

    @property
    def appliesto(self):
        """Alias for AppliesTo"""
        return self.AppliesTo

    @property
    def applies_to(self):
        """Alias for AppliesTo"""
        return self.AppliesTo

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DateOperator(self):
        return self.com_object.DateOperator

    @DateOperator.setter
    def DateOperator(self, value):
        self.com_object.DateOperator = value

    @property
    def dateoperator(self):
        """Alias for DateOperator"""
        return self.DateOperator

    @dateoperator.setter
    def dateoperator(self, value):
        """Alias for DateOperator.setter"""
        self.DateOperator = value

    @property
    def date_operator(self):
        """Alias for DateOperator"""
        return self.DateOperator

    @date_operator.setter
    def date_operator(self, value):
        """Alias for DateOperator.setter"""
        self.DateOperator = value

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def Formula1(self):
        return self.com_object.Formula1

    @property
    def formula1(self):
        """Alias for Formula1"""
        return self.Formula1

    @property
    def Formula2(self):
        return self.com_object.Formula2

    @property
    def formula2(self):
        """Alias for Formula2"""
        return self.Formula2

    @property
    def Interior(self):
        return Interior(self.com_object.Interior)

    @property
    def interior(self):
        """Alias for Interior"""
        return self.Interior

    @property
    def NumberFormat(self):
        return self.com_object.NumberFormat

    @NumberFormat.setter
    def NumberFormat(self, value):
        self.com_object.NumberFormat = value

    @property
    def numberformat(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @numberformat.setter
    def numberformat(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def number_format(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @number_format.setter
    def number_format(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def Operator(self):
        return self.com_object.Operator

    @property
    def operator(self):
        """Alias for Operator"""
        return self.Operator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Priority(self):
        return self.com_object.Priority

    @Priority.setter
    def Priority(self, value):
        self.com_object.Priority = value

    @property
    def priority(self):
        """Alias for Priority"""
        return self.Priority

    @priority.setter
    def priority(self, value):
        """Alias for Priority.setter"""
        self.Priority = value

    @property
    def PTCondition(self):
        return self.com_object.PTCondition

    @property
    def ptcondition(self):
        """Alias for PTCondition"""
        return self.PTCondition

    @property
    def p_t_condition(self):
        """Alias for PTCondition"""
        return self.PTCondition

    @property
    def ScopeType(self):
        return XlPivotConditionScope(self.com_object.ScopeType)

    @ScopeType.setter
    def ScopeType(self, value):
        self.com_object.ScopeType = value

    @property
    def scopetype(self):
        """Alias for ScopeType"""
        return self.ScopeType

    @scopetype.setter
    def scopetype(self, value):
        """Alias for ScopeType.setter"""
        self.ScopeType = value

    @property
    def scope_type(self):
        """Alias for ScopeType"""
        return self.ScopeType

    @scope_type.setter
    def scope_type(self, value):
        """Alias for ScopeType.setter"""
        self.ScopeType = value

    @property
    def StopIfTrue(self):
        return self.com_object.StopIfTrue

    @StopIfTrue.setter
    def StopIfTrue(self, value):
        self.com_object.StopIfTrue = value

    @property
    def stopiftrue(self):
        """Alias for StopIfTrue"""
        return self.StopIfTrue

    @stopiftrue.setter
    def stopiftrue(self, value):
        """Alias for StopIfTrue.setter"""
        self.StopIfTrue = value

    @property
    def stop_if_true(self):
        """Alias for StopIfTrue"""
        return self.StopIfTrue

    @stop_if_true.setter
    def stop_if_true(self, value):
        """Alias for StopIfTrue.setter"""
        self.StopIfTrue = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def TextOperator(self):
        return XlContainsOperator(self.com_object.TextOperator)

    @TextOperator.setter
    def TextOperator(self, value):
        self.com_object.TextOperator = value

    @property
    def textoperator(self):
        """Alias for TextOperator"""
        return self.TextOperator

    @textoperator.setter
    def textoperator(self, value):
        """Alias for TextOperator.setter"""
        self.TextOperator = value

    @property
    def text_operator(self):
        """Alias for TextOperator"""
        return self.TextOperator

    @text_operator.setter
    def text_operator(self, value):
        """Alias for TextOperator.setter"""
        self.TextOperator = value

    @property
    def Type(self):
        return XlFormatConditionType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Modify(self, Type=None, Operator=None, Formula1=None, Formula2=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Operator, Formula1, Formula2]])
        self.com_object.Modify(*arguments)

    def modify(self, Type=None, Operator=None, Formula1=None, Formula2=None):
        """Alias for Modify"""
        arguments = [Type, Operator, Formula1, Formula2]
        return self.Modify(*arguments)

    def ModifyAppliesToRange(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        self.com_object.ModifyAppliesToRange(*arguments)

    def modifyappliestorange(self, Range=None):
        """Alias for ModifyAppliesToRange"""
        arguments = [Range]
        return self.ModifyAppliesToRange(*arguments)

    def modify_applies_to_range(self, Range=None):
        """Alias for ModifyAppliesToRange"""
        arguments = [Range]
        return self.ModifyAppliesToRange(*arguments)

    def SetFirstPriority(self):
        self.com_object.SetFirstPriority()

    def setfirstpriority(self):
        """Alias for SetFirstPriority"""
        return self.SetFirstPriority()

    def set_first_priority(self):
        """Alias for SetFirstPriority"""
        return self.SetFirstPriority()

    def SetLastPriority(self):
        self.com_object.SetLastPriority()

    def setlastpriority(self):
        """Alias for SetLastPriority"""
        return self.SetLastPriority()

    def set_last_priority(self):
        """Alias for SetLastPriority"""
        return self.SetLastPriority()


class FormatConditions:

    def __init__(self, formatconditions=None):
        self.com_object= formatconditions

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Type=None, Operator=None, Formula1=None, Formula2=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Operator, Formula1, Formula2]])
        return FormatCondition(self.com_object.Add(*arguments))

    def add(self, Type=None, Operator=None, Formula1=None, Formula2=None):
        """Alias for Add"""
        arguments = [Type, Operator, Formula1, Formula2]
        return self.Add(*arguments)

    def AddAboveAverage(self):
        return AboveAverage(self.com_object.AddAboveAverage())

    def addaboveaverage(self):
        """Alias for AddAboveAverage"""
        return self.AddAboveAverage()

    def add_above_average(self):
        """Alias for AddAboveAverage"""
        return self.AddAboveAverage()

    def AddColorScale(self, ColorScaleType=None):
        arguments = com_arguments([unwrap(a) for a in [ColorScaleType]])
        return ColorScale(self.com_object.AddColorScale(*arguments))

    def addcolorscale(self, ColorScaleType=None):
        """Alias for AddColorScale"""
        arguments = [ColorScaleType]
        return self.AddColorScale(*arguments)

    def add_color_scale(self, ColorScaleType=None):
        """Alias for AddColorScale"""
        arguments = [ColorScaleType]
        return self.AddColorScale(*arguments)

    def AddDatabar(self):
        return Databar(self.com_object.AddDatabar())

    def adddatabar(self):
        """Alias for AddDatabar"""
        return self.AddDatabar()

    def add_databar(self):
        """Alias for AddDatabar"""
        return self.AddDatabar()

    def AddIconSetCondition(self):
        return IconSetCondition(self.com_object.AddIconSetCondition())

    def addiconsetcondition(self):
        """Alias for AddIconSetCondition"""
        return self.AddIconSetCondition()

    def add_icon_set_condition(self):
        """Alias for AddIconSetCondition"""
        return self.AddIconSetCondition()

    def AddTop10(self):
        return Top10(self.com_object.AddTop10())

    def addtop10(self):
        """Alias for AddTop10"""
        return self.AddTop10()

    def add_top10(self):
        """Alias for AddTop10"""
        return self.AddTop10()

    def AddUniqueValues(self):
        return UniqueValues(self.com_object.AddUniqueValues())

    def adduniquevalues(self):
        """Alias for AddUniqueValues"""
        return self.AddUniqueValues()

    def add_unique_values(self):
        """Alias for AddUniqueValues"""
        return self.AddUniqueValues()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class FreeformBuilder:

    def __init__(self, freeformbuilder=None):
        self.com_object= freeformbuilder

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def AddNodes(self, SegmentType=None, EditingType=None, X1=None, Y1=None, X2=None, Y2=None, X3=None, Y3=None):
        arguments = com_arguments([unwrap(a) for a in [SegmentType, EditingType, X1, Y1, X2, Y2, X3, Y3]])
        self.com_object.AddNodes(*arguments)

    def addnodes(self, SegmentType=None, EditingType=None, X1=None, Y1=None, X2=None, Y2=None, X3=None, Y3=None):
        """Alias for AddNodes"""
        arguments = [SegmentType, EditingType, X1, Y1, X2, Y2, X3, Y3]
        return self.AddNodes(*arguments)

    def add_nodes(self, SegmentType=None, EditingType=None, X1=None, Y1=None, X2=None, Y2=None, X3=None, Y3=None):
        """Alias for AddNodes"""
        arguments = [SegmentType, EditingType, X1, Y1, X2, Y2, X3, Y3]
        return self.AddNodes(*arguments)

    def ConvertToShape(self):
        return Shape(self.com_object.ConvertToShape())

    def converttoshape(self):
        """Alias for ConvertToShape"""
        return self.ConvertToShape()

    def convert_to_shape(self):
        """Alias for ConvertToShape"""
        return self.ConvertToShape()


class FullSeriesCollection:

    def __init__(self, fullseriescollection=None):
        self.com_object= fullseriescollection

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return Series(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Series(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Graphic:

    def __init__(self, graphic=None):
        self.com_object= graphic

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Brightness(self):
        return self.com_object.Brightness

    @Brightness.setter
    def Brightness(self, value):
        self.com_object.Brightness = value

    @property
    def brightness(self):
        """Alias for Brightness"""
        return self.Brightness

    @brightness.setter
    def brightness(self, value):
        """Alias for Brightness.setter"""
        self.Brightness = value

    @property
    def ColorType(self):
        return self.com_object.ColorType

    @ColorType.setter
    def ColorType(self, value):
        self.com_object.ColorType = value

    @property
    def colortype(self):
        """Alias for ColorType"""
        return self.ColorType

    @colortype.setter
    def colortype(self, value):
        """Alias for ColorType.setter"""
        self.ColorType = value

    @property
    def color_type(self):
        """Alias for ColorType"""
        return self.ColorType

    @color_type.setter
    def color_type(self, value):
        """Alias for ColorType.setter"""
        self.ColorType = value

    @property
    def Contrast(self):
        return self.com_object.Contrast

    @Contrast.setter
    def Contrast(self, value):
        self.com_object.Contrast = value

    @property
    def contrast(self):
        """Alias for Contrast"""
        return self.Contrast

    @contrast.setter
    def contrast(self, value):
        """Alias for Contrast.setter"""
        self.Contrast = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def CropBottom(self):
        return self.com_object.CropBottom

    @CropBottom.setter
    def CropBottom(self, value):
        self.com_object.CropBottom = value

    @property
    def cropbottom(self):
        """Alias for CropBottom"""
        return self.CropBottom

    @cropbottom.setter
    def cropbottom(self, value):
        """Alias for CropBottom.setter"""
        self.CropBottom = value

    @property
    def crop_bottom(self):
        """Alias for CropBottom"""
        return self.CropBottom

    @crop_bottom.setter
    def crop_bottom(self, value):
        """Alias for CropBottom.setter"""
        self.CropBottom = value

    @property
    def CropLeft(self):
        return self.com_object.CropLeft

    @CropLeft.setter
    def CropLeft(self, value):
        self.com_object.CropLeft = value

    @property
    def cropleft(self):
        """Alias for CropLeft"""
        return self.CropLeft

    @cropleft.setter
    def cropleft(self, value):
        """Alias for CropLeft.setter"""
        self.CropLeft = value

    @property
    def crop_left(self):
        """Alias for CropLeft"""
        return self.CropLeft

    @crop_left.setter
    def crop_left(self, value):
        """Alias for CropLeft.setter"""
        self.CropLeft = value

    @property
    def CropRight(self):
        return self.com_object.CropRight

    @CropRight.setter
    def CropRight(self, value):
        self.com_object.CropRight = value

    @property
    def cropright(self):
        """Alias for CropRight"""
        return self.CropRight

    @cropright.setter
    def cropright(self, value):
        """Alias for CropRight.setter"""
        self.CropRight = value

    @property
    def crop_right(self):
        """Alias for CropRight"""
        return self.CropRight

    @crop_right.setter
    def crop_right(self, value):
        """Alias for CropRight.setter"""
        self.CropRight = value

    @property
    def CropTop(self):
        return self.com_object.CropTop

    @CropTop.setter
    def CropTop(self, value):
        self.com_object.CropTop = value

    @property
    def croptop(self):
        """Alias for CropTop"""
        return self.CropTop

    @croptop.setter
    def croptop(self, value):
        """Alias for CropTop.setter"""
        self.CropTop = value

    @property
    def crop_top(self):
        """Alias for CropTop"""
        return self.CropTop

    @crop_top.setter
    def crop_top(self, value):
        """Alias for CropTop.setter"""
        self.CropTop = value

    @property
    def Filename(self):
        return self.com_object.Filename

    @Filename.setter
    def Filename(self, value):
        self.com_object.Filename = value

    @property
    def filename(self):
        """Alias for Filename"""
        return self.Filename

    @filename.setter
    def filename(self, value):
        """Alias for Filename.setter"""
        self.Filename = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def LockAspectRatio(self):
        return self.com_object.LockAspectRatio

    @LockAspectRatio.setter
    def LockAspectRatio(self, value):
        self.com_object.LockAspectRatio = value

    @property
    def lockaspectratio(self):
        """Alias for LockAspectRatio"""
        return self.LockAspectRatio

    @lockaspectratio.setter
    def lockaspectratio(self, value):
        """Alias for LockAspectRatio.setter"""
        self.LockAspectRatio = value

    @property
    def lock_aspect_ratio(self):
        """Alias for LockAspectRatio"""
        return self.LockAspectRatio

    @lock_aspect_ratio.setter
    def lock_aspect_ratio(self, value):
        """Alias for LockAspectRatio.setter"""
        self.LockAspectRatio = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value


class Gridlines:

    def __init__(self, gridlines=None):
        self.com_object= gridlines

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Border(self):
        return Border(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        return self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class GroupShapes:

    def __init__(self, groupshapes=None):
        self.com_object= groupshapes

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Range(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetRange"):
            return ShapeRange(self.com_object.GetRange(*arguments))
        else:
            return ShapeRange(self.com_object.Range(*arguments))

    def range(self, Index=None):
        """Alias for Range"""
        arguments = [Index]
        return self.Range(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Shape(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class HeaderFooter:

    def __init__(self, headerfooter=None):
        self.com_object= headerfooter

    @property
    def Picture(self):
        return self.com_object.Picture

    @property
    def picture(self):
        """Alias for Picture"""
        return self.Picture

    @property
    def Text(self):
        return Text(self.com_object.Text)

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value


class HiLoLines:

    def __init__(self, hilolines=None):
        self.com_object= hilolines

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Border(self):
        return Border(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        return self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class HPageBreak:

    def __init__(self, hpagebreak=None):
        self.com_object= hpagebreak

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Extent(self):
        return XlPageBreakExtent(self.com_object.Extent)

    @property
    def extent(self):
        """Alias for Extent"""
        return self.Extent

    @property
    def Location(self):
        return Range(self.com_object.Location)

    @Location.setter
    def Location(self, value):
        self.com_object.Location = value

    @property
    def location(self):
        """Alias for Location"""
        return self.Location

    @location.setter
    def location(self, value):
        """Alias for Location.setter"""
        self.Location = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Type(self):
        return XlPageBreak(self.com_object.Type)

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def DragOff(self, Direction=None, RegionIndex=None):
        arguments = com_arguments([unwrap(a) for a in [Direction, RegionIndex]])
        self.com_object.DragOff(*arguments)

    def dragoff(self, Direction=None, RegionIndex=None):
        """Alias for DragOff"""
        arguments = [Direction, RegionIndex]
        return self.DragOff(*arguments)

    def drag_off(self, Direction=None, RegionIndex=None):
        """Alias for DragOff"""
        arguments = [Direction, RegionIndex]
        return self.DragOff(*arguments)


class HPageBreaks:

    def __init__(self, hpagebreaks=None):
        self.com_object= hpagebreaks

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Before=None):
        arguments = com_arguments([unwrap(a) for a in [Before]])
        return HPageBreak(self.com_object.Add(*arguments))

    def add(self, Before=None):
        """Alias for Add"""
        arguments = [Before]
        return self.Add(*arguments)


class Hyperlink:

    def __init__(self, hyperlink=None):
        self.com_object= hyperlink

    @property
    def Address(self):
        return self.com_object.Address

    @Address.setter
    def Address(self, value):
        self.com_object.Address = value

    @property
    def address(self):
        """Alias for Address"""
        return self.Address

    @address.setter
    def address(self, value):
        """Alias for Address.setter"""
        self.Address = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def EmailSubject(self):
        return self.com_object.EmailSubject

    @EmailSubject.setter
    def EmailSubject(self, value):
        self.com_object.EmailSubject = value

    @property
    def emailsubject(self):
        """Alias for EmailSubject"""
        return self.EmailSubject

    @emailsubject.setter
    def emailsubject(self, value):
        """Alias for EmailSubject.setter"""
        self.EmailSubject = value

    @property
    def email_subject(self):
        """Alias for EmailSubject"""
        return self.EmailSubject

    @email_subject.setter
    def email_subject(self, value):
        """Alias for EmailSubject.setter"""
        self.EmailSubject = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def ScreenTip(self):
        return self.com_object.ScreenTip

    @ScreenTip.setter
    def ScreenTip(self, value):
        self.com_object.ScreenTip = value

    @property
    def screentip(self):
        """Alias for ScreenTip"""
        return self.ScreenTip

    @screentip.setter
    def screentip(self, value):
        """Alias for ScreenTip.setter"""
        self.ScreenTip = value

    @property
    def screen_tip(self):
        """Alias for ScreenTip"""
        return self.ScreenTip

    @screen_tip.setter
    def screen_tip(self, value):
        """Alias for ScreenTip.setter"""
        self.ScreenTip = value

    @property
    def Shape(self):
        return Shape(self.com_object.Shape)

    @property
    def shape(self):
        """Alias for Shape"""
        return self.Shape

    @property
    def SubAddress(self):
        return self.com_object.SubAddress

    @SubAddress.setter
    def SubAddress(self, value):
        self.com_object.SubAddress = value

    @property
    def subaddress(self):
        """Alias for SubAddress"""
        return self.SubAddress

    @subaddress.setter
    def subaddress(self, value):
        """Alias for SubAddress.setter"""
        self.SubAddress = value

    @property
    def sub_address(self):
        """Alias for SubAddress"""
        return self.SubAddress

    @sub_address.setter
    def sub_address(self, value):
        """Alias for SubAddress.setter"""
        self.SubAddress = value

    @property
    def TextToDisplay(self):
        return self.com_object.TextToDisplay

    @TextToDisplay.setter
    def TextToDisplay(self, value):
        self.com_object.TextToDisplay = value

    @property
    def texttodisplay(self):
        """Alias for TextToDisplay"""
        return self.TextToDisplay

    @texttodisplay.setter
    def texttodisplay(self, value):
        """Alias for TextToDisplay.setter"""
        self.TextToDisplay = value

    @property
    def text_to_display(self):
        """Alias for TextToDisplay"""
        return self.TextToDisplay

    @text_to_display.setter
    def text_to_display(self, value):
        """Alias for TextToDisplay.setter"""
        self.TextToDisplay = value

    @property
    def Type(self):
        return self.com_object.Type

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def AddToFavorites(self):
        self.com_object.AddToFavorites()

    def addtofavorites(self):
        """Alias for AddToFavorites"""
        return self.AddToFavorites()

    def add_to_favorites(self):
        """Alias for AddToFavorites"""
        return self.AddToFavorites()

    def CreateNewDocument(self, FileName=None, EditNow=None, Overwrite=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, EditNow, Overwrite]])
        self.com_object.CreateNewDocument(*arguments)

    def createnewdocument(self, FileName=None, EditNow=None, Overwrite=None):
        """Alias for CreateNewDocument"""
        arguments = [FileName, EditNow, Overwrite]
        return self.CreateNewDocument(*arguments)

    def create_new_document(self, FileName=None, EditNow=None, Overwrite=None):
        """Alias for CreateNewDocument"""
        arguments = [FileName, EditNow, Overwrite]
        return self.CreateNewDocument(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Follow(self, NewWindow=None, AddHistory=None, ExtraInfo=None, Method=None, HeaderInfo=None):
        arguments = com_arguments([unwrap(a) for a in [NewWindow, AddHistory, ExtraInfo, Method, HeaderInfo]])
        self.com_object.Follow(*arguments)

    def follow(self, NewWindow=None, AddHistory=None, ExtraInfo=None, Method=None, HeaderInfo=None):
        """Alias for Follow"""
        arguments = [NewWindow, AddHistory, ExtraInfo, Method, HeaderInfo]
        return self.Follow(*arguments)


class Hyperlinks:

    def __init__(self, hyperlinks=None):
        self.com_object= hyperlinks

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Anchor=None, Address=None, SubAddress=None, ScreenTip=None, TextToDisplay=None):
        arguments = com_arguments([unwrap(a) for a in [Anchor, Address, SubAddress, ScreenTip, TextToDisplay]])
        return Hyperlink(self.com_object.Add(*arguments))

    def add(self, Anchor=None, Address=None, SubAddress=None, ScreenTip=None, TextToDisplay=None):
        """Alias for Add"""
        arguments = [Anchor, Address, SubAddress, ScreenTip, TextToDisplay]
        return self.Add(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class Icon:

    def __init__(self, icon=None):
        self.com_object= icon

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return IconSet(self.com_object.Index)

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class IconCriteria:

    def __init__(self, iconcriteria=None):
        self.com_object= iconcriteria

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return IconCriterion(self.com_object.GetItem(*arguments))
        else:
            return IconCriterion(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class IconCriterion:

    def __init__(self, iconcriterion=None):
        self.com_object= iconcriterion

    @property
    def Icon(self):
        return self.com_object.Icon

    @Icon.setter
    def Icon(self, value):
        self.com_object.Icon = value

    @property
    def icon(self):
        """Alias for Icon"""
        return self.Icon

    @icon.setter
    def icon(self, value):
        """Alias for Icon.setter"""
        self.Icon = value

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Operator(self):
        return XlFormatConditionOperator(self.com_object.Operator)

    @Operator.setter
    def Operator(self, value):
        self.com_object.Operator = value

    @property
    def operator(self):
        """Alias for Operator"""
        return self.Operator

    @operator.setter
    def operator(self, value):
        """Alias for Operator.setter"""
        self.Operator = value

    @property
    def Type(self):
        return XlConditionValueTypes(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value


class IconSet:

    def __init__(self, iconset=None):
        self.com_object= iconset

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ID(self):
        return XlIconSet(self.com_object.ID)

    @property
    def id(self):
        """Alias for ID"""
        return self.ID

    @property
    def i_d(self):
        """Alias for ID"""
        return self.ID

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return Icon(self.com_object.GetItem(*arguments))
        else:
            return Icon(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class IconSetCondition:

    def __init__(self, iconsetcondition=None):
        self.com_object= iconsetcondition

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AppliesTo(self):
        return Range(self.com_object.AppliesTo)

    @property
    def appliesto(self):
        """Alias for AppliesTo"""
        return self.AppliesTo

    @property
    def applies_to(self):
        """Alias for AppliesTo"""
        return self.AppliesTo

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def IconCriteria(self):
        return IconCriteria(self.com_object.IconCriteria)

    @property
    def iconcriteria(self):
        """Alias for IconCriteria"""
        return self.IconCriteria

    @property
    def icon_criteria(self):
        """Alias for IconCriteria"""
        return self.IconCriteria

    @property
    def IconSet(self):
        return IconSets(self.com_object.IconSet)

    @IconSet.setter
    def IconSet(self, value):
        self.com_object.IconSet = value

    @property
    def iconset(self):
        """Alias for IconSet"""
        return self.IconSet

    @iconset.setter
    def iconset(self, value):
        """Alias for IconSet.setter"""
        self.IconSet = value

    @property
    def icon_set(self):
        """Alias for IconSet"""
        return self.IconSet

    @icon_set.setter
    def icon_set(self, value):
        """Alias for IconSet.setter"""
        self.IconSet = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PercentileValues(self):
        return self.com_object.PercentileValues

    @PercentileValues.setter
    def PercentileValues(self, value):
        self.com_object.PercentileValues = value

    @property
    def percentilevalues(self):
        """Alias for PercentileValues"""
        return self.PercentileValues

    @percentilevalues.setter
    def percentilevalues(self, value):
        """Alias for PercentileValues.setter"""
        self.PercentileValues = value

    @property
    def percentile_values(self):
        """Alias for PercentileValues"""
        return self.PercentileValues

    @percentile_values.setter
    def percentile_values(self, value):
        """Alias for PercentileValues.setter"""
        self.PercentileValues = value

    @property
    def Priority(self):
        return self.com_object.Priority

    @Priority.setter
    def Priority(self, value):
        self.com_object.Priority = value

    @property
    def priority(self):
        """Alias for Priority"""
        return self.Priority

    @priority.setter
    def priority(self, value):
        """Alias for Priority.setter"""
        self.Priority = value

    @property
    def PTCondition(self):
        return self.com_object.PTCondition

    @property
    def ptcondition(self):
        """Alias for PTCondition"""
        return self.PTCondition

    @property
    def p_t_condition(self):
        """Alias for PTCondition"""
        return self.PTCondition

    @property
    def ReverseOrder(self):
        return self.com_object.ReverseOrder

    @ReverseOrder.setter
    def ReverseOrder(self, value):
        self.com_object.ReverseOrder = value

    @property
    def reverseorder(self):
        """Alias for ReverseOrder"""
        return self.ReverseOrder

    @reverseorder.setter
    def reverseorder(self, value):
        """Alias for ReverseOrder.setter"""
        self.ReverseOrder = value

    @property
    def reverse_order(self):
        """Alias for ReverseOrder"""
        return self.ReverseOrder

    @reverse_order.setter
    def reverse_order(self, value):
        """Alias for ReverseOrder.setter"""
        self.ReverseOrder = value

    @property
    def ScopeType(self):
        return XlPivotConditionScope(self.com_object.ScopeType)

    @ScopeType.setter
    def ScopeType(self, value):
        self.com_object.ScopeType = value

    @property
    def scopetype(self):
        """Alias for ScopeType"""
        return self.ScopeType

    @scopetype.setter
    def scopetype(self, value):
        """Alias for ScopeType.setter"""
        self.ScopeType = value

    @property
    def scope_type(self):
        """Alias for ScopeType"""
        return self.ScopeType

    @scope_type.setter
    def scope_type(self, value):
        """Alias for ScopeType.setter"""
        self.ScopeType = value

    @property
    def ShowIconOnly(self):
        return self.com_object.ShowIconOnly

    @ShowIconOnly.setter
    def ShowIconOnly(self, value):
        self.com_object.ShowIconOnly = value

    @property
    def showicononly(self):
        """Alias for ShowIconOnly"""
        return self.ShowIconOnly

    @showicononly.setter
    def showicononly(self, value):
        """Alias for ShowIconOnly.setter"""
        self.ShowIconOnly = value

    @property
    def show_icon_only(self):
        """Alias for ShowIconOnly"""
        return self.ShowIconOnly

    @show_icon_only.setter
    def show_icon_only(self, value):
        """Alias for ShowIconOnly.setter"""
        self.ShowIconOnly = value

    @property
    def StopIfTrue(self):
        return self.com_object.StopIfTrue

    @StopIfTrue.setter
    def StopIfTrue(self, value):
        self.com_object.StopIfTrue = value

    @property
    def stopiftrue(self):
        """Alias for StopIfTrue"""
        return self.StopIfTrue

    @stopiftrue.setter
    def stopiftrue(self, value):
        """Alias for StopIfTrue.setter"""
        self.StopIfTrue = value

    @property
    def stop_if_true(self):
        """Alias for StopIfTrue"""
        return self.StopIfTrue

    @stop_if_true.setter
    def stop_if_true(self, value):
        """Alias for StopIfTrue.setter"""
        self.StopIfTrue = value

    @property
    def Type(self):
        return XlFormatConditionType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def ModifyAppliesToRange(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        self.com_object.ModifyAppliesToRange(*arguments)

    def modifyappliestorange(self, Range=None):
        """Alias for ModifyAppliesToRange"""
        arguments = [Range]
        return self.ModifyAppliesToRange(*arguments)

    def modify_applies_to_range(self, Range=None):
        """Alias for ModifyAppliesToRange"""
        arguments = [Range]
        return self.ModifyAppliesToRange(*arguments)

    def SetFirstPriority(self):
        self.com_object.SetFirstPriority()

    def setfirstpriority(self):
        """Alias for SetFirstPriority"""
        return self.SetFirstPriority()

    def set_first_priority(self):
        """Alias for SetFirstPriority"""
        return self.SetFirstPriority()

    def SetLastPriority(self):
        self.com_object.SetLastPriority()

    def setlastpriority(self):
        """Alias for SetLastPriority"""
        return self.SetLastPriority()

    def set_last_priority(self):
        """Alias for SetLastPriority"""
        return self.SetLastPriority()


class IconSets:

    def __init__(self, iconsets=None):
        self.com_object= iconsets

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return IconSet(self.com_object.GetItem(*arguments))
        else:
            return IconSet(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class Interior:

    def __init__(self, interior=None):
        self.com_object= interior

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Color(self):
        return RGB(self.com_object.Color)

    @Color.setter
    def Color(self, value):
        self.com_object.Color = value

    @property
    def color(self):
        """Alias for Color"""
        return self.Color

    @color.setter
    def color(self, value):
        """Alias for Color.setter"""
        self.Color = value

    @property
    def ColorIndex(self):
        return self.com_object.ColorIndex

    @ColorIndex.setter
    def ColorIndex(self, value):
        self.com_object.ColorIndex = value

    @property
    def colorindex(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @colorindex.setter
    def colorindex(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def color_index(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @color_index.setter
    def color_index(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Gradient(self):
        return self.com_object.Gradient

    @Gradient.setter
    def Gradient(self, value):
        self.com_object.Gradient = value

    @property
    def gradient(self):
        """Alias for Gradient"""
        return self.Gradient

    @gradient.setter
    def gradient(self, value):
        """Alias for Gradient.setter"""
        self.Gradient = value

    @property
    def InvertIfNegative(self):
        return self.com_object.InvertIfNegative

    @InvertIfNegative.setter
    def InvertIfNegative(self, value):
        self.com_object.InvertIfNegative = value

    @property
    def invertifnegative(self):
        """Alias for InvertIfNegative"""
        return self.InvertIfNegative

    @invertifnegative.setter
    def invertifnegative(self, value):
        """Alias for InvertIfNegative.setter"""
        self.InvertIfNegative = value

    @property
    def invert_if_negative(self):
        """Alias for InvertIfNegative"""
        return self.InvertIfNegative

    @invert_if_negative.setter
    def invert_if_negative(self, value):
        """Alias for InvertIfNegative.setter"""
        self.InvertIfNegative = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Pattern(self):
        return XlPattern(self.com_object.Pattern)

    @Pattern.setter
    def Pattern(self, value):
        self.com_object.Pattern = value

    @property
    def pattern(self):
        """Alias for Pattern"""
        return self.Pattern

    @pattern.setter
    def pattern(self, value):
        """Alias for Pattern.setter"""
        self.Pattern = value

    @property
    def PatternColor(self):
        return RGB(self.com_object.PatternColor)

    @PatternColor.setter
    def PatternColor(self, value):
        self.com_object.PatternColor = value

    @property
    def patterncolor(self):
        """Alias for PatternColor"""
        return self.PatternColor

    @patterncolor.setter
    def patterncolor(self, value):
        """Alias for PatternColor.setter"""
        self.PatternColor = value

    @property
    def pattern_color(self):
        """Alias for PatternColor"""
        return self.PatternColor

    @pattern_color.setter
    def pattern_color(self, value):
        """Alias for PatternColor.setter"""
        self.PatternColor = value

    @property
    def PatternColorIndex(self):
        return XlColorIndex(self.com_object.PatternColorIndex)

    @PatternColorIndex.setter
    def PatternColorIndex(self, value):
        self.com_object.PatternColorIndex = value

    @property
    def patterncolorindex(self):
        """Alias for PatternColorIndex"""
        return self.PatternColorIndex

    @patterncolorindex.setter
    def patterncolorindex(self, value):
        """Alias for PatternColorIndex.setter"""
        self.PatternColorIndex = value

    @property
    def pattern_color_index(self):
        """Alias for PatternColorIndex"""
        return self.PatternColorIndex

    @pattern_color_index.setter
    def pattern_color_index(self, value):
        """Alias for PatternColorIndex.setter"""
        self.PatternColorIndex = value

    @property
    def PatternThemeColor(self):
        return Interior(self.com_object.PatternThemeColor)

    @PatternThemeColor.setter
    def PatternThemeColor(self, value):
        self.com_object.PatternThemeColor = value

    @property
    def patternthemecolor(self):
        """Alias for PatternThemeColor"""
        return self.PatternThemeColor

    @patternthemecolor.setter
    def patternthemecolor(self, value):
        """Alias for PatternThemeColor.setter"""
        self.PatternThemeColor = value

    @property
    def pattern_theme_color(self):
        """Alias for PatternThemeColor"""
        return self.PatternThemeColor

    @pattern_theme_color.setter
    def pattern_theme_color(self, value):
        """Alias for PatternThemeColor.setter"""
        self.PatternThemeColor = value

    @property
    def PatternTintAndShade(self):
        return Interior(self.com_object.PatternTintAndShade)

    @PatternTintAndShade.setter
    def PatternTintAndShade(self, value):
        self.com_object.PatternTintAndShade = value

    @property
    def patterntintandshade(self):
        """Alias for PatternTintAndShade"""
        return self.PatternTintAndShade

    @patterntintandshade.setter
    def patterntintandshade(self, value):
        """Alias for PatternTintAndShade.setter"""
        self.PatternTintAndShade = value

    @property
    def pattern_tint_and_shade(self):
        """Alias for PatternTintAndShade"""
        return self.PatternTintAndShade

    @pattern_tint_and_shade.setter
    def pattern_tint_and_shade(self, value):
        """Alias for PatternTintAndShade.setter"""
        self.PatternTintAndShade = value

    @property
    def ThemeColor(self):
        return XlThemeColor(self.com_object.ThemeColor)

    @ThemeColor.setter
    def ThemeColor(self, value):
        self.com_object.ThemeColor = value

    @property
    def themecolor(self):
        """Alias for ThemeColor"""
        return self.ThemeColor

    @themecolor.setter
    def themecolor(self, value):
        """Alias for ThemeColor.setter"""
        self.ThemeColor = value

    @property
    def theme_color(self):
        """Alias for ThemeColor"""
        return self.ThemeColor

    @theme_color.setter
    def theme_color(self, value):
        """Alias for ThemeColor.setter"""
        self.ThemeColor = value

    @property
    def TintAndShade(self):
        return self.com_object.TintAndShade

    @TintAndShade.setter
    def TintAndShade(self, value):
        self.com_object.TintAndShade = value

    @property
    def tintandshade(self):
        """Alias for TintAndShade"""
        return self.TintAndShade

    @tintandshade.setter
    def tintandshade(self, value):
        """Alias for TintAndShade.setter"""
        self.TintAndShade = value

    @property
    def tint_and_shade(self):
        """Alias for TintAndShade"""
        return self.TintAndShade

    @tint_and_shade.setter
    def tint_and_shade(self, value):
        """Alias for TintAndShade.setter"""
        self.TintAndShade = value


class IRtdServer:

    def __init__(self, irtdserver=None):
        self.com_object= irtdserver

    def ConnectData(self, TopicID=None, Strings=None, GetNewValues=None):
        arguments = com_arguments([unwrap(a) for a in [TopicID, Strings, GetNewValues]])
        return self.com_object.ConnectData(*arguments)

    def connectdata(self, TopicID=None, Strings=None, GetNewValues=None):
        """Alias for ConnectData"""
        arguments = [TopicID, Strings, GetNewValues]
        return self.ConnectData(*arguments)

    def connect_data(self, TopicID=None, Strings=None, GetNewValues=None):
        """Alias for ConnectData"""
        arguments = [TopicID, Strings, GetNewValues]
        return self.ConnectData(*arguments)

    def DisconnectData(self, TopicID=None):
        arguments = com_arguments([unwrap(a) for a in [TopicID]])
        self.com_object.DisconnectData(*arguments)

    def disconnectdata(self, TopicID=None):
        """Alias for DisconnectData"""
        arguments = [TopicID]
        return self.DisconnectData(*arguments)

    def disconnect_data(self, TopicID=None):
        """Alias for DisconnectData"""
        arguments = [TopicID]
        return self.DisconnectData(*arguments)

    def Heartbeat(self):
        return self.com_object.Heartbeat()

    def heartbeat(self):
        """Alias for Heartbeat"""
        return self.Heartbeat()

    def RefreshData(self, TopicCount=None):
        arguments = com_arguments([unwrap(a) for a in [TopicCount]])
        return self.com_object.RefreshData(*arguments)

    def refreshdata(self, TopicCount=None):
        """Alias for RefreshData"""
        arguments = [TopicCount]
        return self.RefreshData(*arguments)

    def refresh_data(self, TopicCount=None):
        """Alias for RefreshData"""
        arguments = [TopicCount]
        return self.RefreshData(*arguments)

    def ServerStart(self, CallbackObject=None):
        arguments = com_arguments([unwrap(a) for a in [CallbackObject]])
        return self.com_object.ServerStart(*arguments)

    def serverstart(self, CallbackObject=None):
        """Alias for ServerStart"""
        arguments = [CallbackObject]
        return self.ServerStart(*arguments)

    def server_start(self, CallbackObject=None):
        """Alias for ServerStart"""
        arguments = [CallbackObject]
        return self.ServerStart(*arguments)

    def ServerTerminate(self):
        self.com_object.ServerTerminate()

    def serverterminate(self):
        """Alias for ServerTerminate"""
        return self.ServerTerminate()

    def server_terminate(self):
        """Alias for ServerTerminate"""
        return self.ServerTerminate()


class IRTDUpdateEvent:

    def __init__(self, irtdupdateevent=None):
        self.com_object= irtdupdateevent

    @property
    def HeartbeatInterval(self):
        return self.com_object.HeartbeatInterval

    @HeartbeatInterval.setter
    def HeartbeatInterval(self, value):
        self.com_object.HeartbeatInterval = value

    @property
    def heartbeatinterval(self):
        """Alias for HeartbeatInterval"""
        return self.HeartbeatInterval

    @heartbeatinterval.setter
    def heartbeatinterval(self, value):
        """Alias for HeartbeatInterval.setter"""
        self.HeartbeatInterval = value

    @property
    def heartbeat_interval(self):
        """Alias for HeartbeatInterval"""
        return self.HeartbeatInterval

    @heartbeat_interval.setter
    def heartbeat_interval(self, value):
        """Alias for HeartbeatInterval.setter"""
        self.HeartbeatInterval = value

    def Disconnect(self):
        self.com_object.Disconnect()

    def disconnect(self):
        """Alias for Disconnect"""
        return self.Disconnect()

    def UpdateNotify(self):
        self.com_object.UpdateNotify()

    def updatenotify(self):
        """Alias for UpdateNotify"""
        return self.UpdateNotify()

    def update_notify(self):
        """Alias for UpdateNotify"""
        return self.UpdateNotify()


class LeaderLines:

    def __init__(self, leaderlines=None):
        self.com_object= leaderlines

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Border(self):
        return Border(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Legend:

    def __init__(self, legend=None):
        self.com_object= legend

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def IncludeInLayout(self):
        return self.com_object.IncludeInLayout

    @IncludeInLayout.setter
    def IncludeInLayout(self, value):
        self.com_object.IncludeInLayout = value

    @property
    def includeinlayout(self):
        """Alias for IncludeInLayout"""
        return self.IncludeInLayout

    @includeinlayout.setter
    def includeinlayout(self, value):
        """Alias for IncludeInLayout.setter"""
        self.IncludeInLayout = value

    @property
    def include_in_layout(self):
        """Alias for IncludeInLayout"""
        return self.IncludeInLayout

    @include_in_layout.setter
    def include_in_layout(self, value):
        """Alias for IncludeInLayout.setter"""
        self.IncludeInLayout = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return XlLegendPosition(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Clear(self):
        return self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def LegendEntries(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.LegendEntries(*arguments)

    def legendentries(self, Index=None):
        """Alias for LegendEntries"""
        arguments = [Index]
        return self.LegendEntries(*arguments)

    def legend_entries(self, Index=None):
        """Alias for LegendEntries"""
        arguments = [Index]
        return self.LegendEntries(*arguments)

    def Select(self):
        return self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class LegendEntries:

    def __init__(self, legendentries=None):
        self.com_object= legendentries

    def __call__(self, item):
        return LegendEntrie(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return LegendEntry(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class LegendEntry:

    def __init__(self, legendentry=None):
        self.com_object= legendentry

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Left(self):
        return self.com_object.Left

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @property
    def LegendKey(self):
        return LegendKey(self.com_object.LegendKey)

    @property
    def legendkey(self):
        """Alias for LegendKey"""
        return self.LegendKey

    @property
    def legend_key(self):
        """Alias for LegendKey"""
        return self.LegendKey

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Top(self):
        return self.com_object.Top

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        return self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class LegendKey:

    def __init__(self, legendkey=None):
        self.com_object= legendkey

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def InvertIfNegative(self):
        return self.com_object.InvertIfNegative

    @InvertIfNegative.setter
    def InvertIfNegative(self, value):
        self.com_object.InvertIfNegative = value

    @property
    def invertifnegative(self):
        """Alias for InvertIfNegative"""
        return self.InvertIfNegative

    @invertifnegative.setter
    def invertifnegative(self, value):
        """Alias for InvertIfNegative.setter"""
        self.InvertIfNegative = value

    @property
    def invert_if_negative(self):
        """Alias for InvertIfNegative"""
        return self.InvertIfNegative

    @invert_if_negative.setter
    def invert_if_negative(self, value):
        """Alias for InvertIfNegative.setter"""
        self.InvertIfNegative = value

    @property
    def Left(self):
        return self.com_object.Left

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @property
    def MarkerBackgroundColor(self):
        return self.com_object.MarkerBackgroundColor

    @MarkerBackgroundColor.setter
    def MarkerBackgroundColor(self, value):
        self.com_object.MarkerBackgroundColor = value

    @property
    def markerbackgroundcolor(self):
        """Alias for MarkerBackgroundColor"""
        return self.MarkerBackgroundColor

    @markerbackgroundcolor.setter
    def markerbackgroundcolor(self, value):
        """Alias for MarkerBackgroundColor.setter"""
        self.MarkerBackgroundColor = value

    @property
    def marker_background_color(self):
        """Alias for MarkerBackgroundColor"""
        return self.MarkerBackgroundColor

    @marker_background_color.setter
    def marker_background_color(self, value):
        """Alias for MarkerBackgroundColor.setter"""
        self.MarkerBackgroundColor = value

    @property
    def MarkerBackgroundColorIndex(self):
        return XlColorIndex(self.com_object.MarkerBackgroundColorIndex)

    @MarkerBackgroundColorIndex.setter
    def MarkerBackgroundColorIndex(self, value):
        self.com_object.MarkerBackgroundColorIndex = value

    @property
    def markerbackgroundcolorindex(self):
        """Alias for MarkerBackgroundColorIndex"""
        return self.MarkerBackgroundColorIndex

    @markerbackgroundcolorindex.setter
    def markerbackgroundcolorindex(self, value):
        """Alias for MarkerBackgroundColorIndex.setter"""
        self.MarkerBackgroundColorIndex = value

    @property
    def marker_background_color_index(self):
        """Alias for MarkerBackgroundColorIndex"""
        return self.MarkerBackgroundColorIndex

    @marker_background_color_index.setter
    def marker_background_color_index(self, value):
        """Alias for MarkerBackgroundColorIndex.setter"""
        self.MarkerBackgroundColorIndex = value

    @property
    def MarkerForegroundColor(self):
        return self.com_object.MarkerForegroundColor

    @MarkerForegroundColor.setter
    def MarkerForegroundColor(self, value):
        self.com_object.MarkerForegroundColor = value

    @property
    def markerforegroundcolor(self):
        """Alias for MarkerForegroundColor"""
        return self.MarkerForegroundColor

    @markerforegroundcolor.setter
    def markerforegroundcolor(self, value):
        """Alias for MarkerForegroundColor.setter"""
        self.MarkerForegroundColor = value

    @property
    def marker_foreground_color(self):
        """Alias for MarkerForegroundColor"""
        return self.MarkerForegroundColor

    @marker_foreground_color.setter
    def marker_foreground_color(self, value):
        """Alias for MarkerForegroundColor.setter"""
        self.MarkerForegroundColor = value

    @property
    def MarkerForegroundColorIndex(self):
        return XlColorIndex(self.com_object.MarkerForegroundColorIndex)

    @MarkerForegroundColorIndex.setter
    def MarkerForegroundColorIndex(self, value):
        self.com_object.MarkerForegroundColorIndex = value

    @property
    def markerforegroundcolorindex(self):
        """Alias for MarkerForegroundColorIndex"""
        return self.MarkerForegroundColorIndex

    @markerforegroundcolorindex.setter
    def markerforegroundcolorindex(self, value):
        """Alias for MarkerForegroundColorIndex.setter"""
        self.MarkerForegroundColorIndex = value

    @property
    def marker_foreground_color_index(self):
        """Alias for MarkerForegroundColorIndex"""
        return self.MarkerForegroundColorIndex

    @marker_foreground_color_index.setter
    def marker_foreground_color_index(self, value):
        """Alias for MarkerForegroundColorIndex.setter"""
        self.MarkerForegroundColorIndex = value

    @property
    def MarkerSize(self):
        return self.com_object.MarkerSize

    @MarkerSize.setter
    def MarkerSize(self, value):
        self.com_object.MarkerSize = value

    @property
    def markersize(self):
        """Alias for MarkerSize"""
        return self.MarkerSize

    @markersize.setter
    def markersize(self, value):
        """Alias for MarkerSize.setter"""
        self.MarkerSize = value

    @property
    def marker_size(self):
        """Alias for MarkerSize"""
        return self.MarkerSize

    @marker_size.setter
    def marker_size(self, value):
        """Alias for MarkerSize.setter"""
        self.MarkerSize = value

    @property
    def MarkerStyle(self):
        return XlMarkerStyle(self.com_object.MarkerStyle)

    @MarkerStyle.setter
    def MarkerStyle(self, value):
        self.com_object.MarkerStyle = value

    @property
    def markerstyle(self):
        """Alias for MarkerStyle"""
        return self.MarkerStyle

    @markerstyle.setter
    def markerstyle(self, value):
        """Alias for MarkerStyle.setter"""
        self.MarkerStyle = value

    @property
    def marker_style(self):
        """Alias for MarkerStyle"""
        return self.MarkerStyle

    @marker_style.setter
    def marker_style(self, value):
        """Alias for MarkerStyle.setter"""
        self.MarkerStyle = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PictureType(self):
        return XlChartPictureType(self.com_object.PictureType)

    @PictureType.setter
    def PictureType(self, value):
        self.com_object.PictureType = value

    @property
    def picturetype(self):
        """Alias for PictureType"""
        return self.PictureType

    @picturetype.setter
    def picturetype(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def picture_type(self):
        """Alias for PictureType"""
        return self.PictureType

    @picture_type.setter
    def picture_type(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def PictureUnit2(self):
        return PictureType(self.com_object.PictureUnit2)

    @PictureUnit2.setter
    def PictureUnit2(self, value):
        self.com_object.PictureUnit2 = value

    @property
    def pictureunit2(self):
        """Alias for PictureUnit2"""
        return self.PictureUnit2

    @pictureunit2.setter
    def pictureunit2(self, value):
        """Alias for PictureUnit2.setter"""
        self.PictureUnit2 = value

    @property
    def picture_unit2(self):
        """Alias for PictureUnit2"""
        return self.PictureUnit2

    @picture_unit2.setter
    def picture_unit2(self, value):
        """Alias for PictureUnit2.setter"""
        self.PictureUnit2 = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Smooth(self):
        return self.com_object.Smooth

    @Smooth.setter
    def Smooth(self, value):
        self.com_object.Smooth = value

    @property
    def smooth(self):
        """Alias for Smooth"""
        return self.Smooth

    @smooth.setter
    def smooth(self, value):
        """Alias for Smooth.setter"""
        self.Smooth = value

    @property
    def Top(self):
        return self.com_object.Top

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    def ClearFormats(self):
        return self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class LinearGradient:

    def __init__(self, lineargradient=None):
        self.com_object= lineargradient

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ColorStops(self):
        return ColorStops(self.com_object.ColorStops)

    @property
    def colorstops(self):
        """Alias for ColorStops"""
        return self.ColorStops

    @property
    def color_stops(self):
        """Alias for ColorStops"""
        return self.ColorStops

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Degree(self):
        return self.com_object.Degree

    @Degree.setter
    def Degree(self, value):
        self.com_object.Degree = value

    @property
    def degree(self):
        """Alias for Degree"""
        return self.Degree

    @degree.setter
    def degree(self, value):
        """Alias for Degree.setter"""
        self.Degree = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class LineFormat:

    def __init__(self, lineformat=None):
        self.com_object= lineformat

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BackColor(self):
        return ColorFormat(self.com_object.BackColor)

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BeginArrowheadLength(self):
        return self.com_object.BeginArrowheadLength

    @BeginArrowheadLength.setter
    def BeginArrowheadLength(self, value):
        self.com_object.BeginArrowheadLength = value

    @property
    def beginarrowheadlength(self):
        """Alias for BeginArrowheadLength"""
        return self.BeginArrowheadLength

    @beginarrowheadlength.setter
    def beginarrowheadlength(self, value):
        """Alias for BeginArrowheadLength.setter"""
        self.BeginArrowheadLength = value

    @property
    def begin_arrowhead_length(self):
        """Alias for BeginArrowheadLength"""
        return self.BeginArrowheadLength

    @begin_arrowhead_length.setter
    def begin_arrowhead_length(self, value):
        """Alias for BeginArrowheadLength.setter"""
        self.BeginArrowheadLength = value

    @property
    def BeginArrowheadStyle(self):
        return self.com_object.BeginArrowheadStyle

    @BeginArrowheadStyle.setter
    def BeginArrowheadStyle(self, value):
        self.com_object.BeginArrowheadStyle = value

    @property
    def beginarrowheadstyle(self):
        """Alias for BeginArrowheadStyle"""
        return self.BeginArrowheadStyle

    @beginarrowheadstyle.setter
    def beginarrowheadstyle(self, value):
        """Alias for BeginArrowheadStyle.setter"""
        self.BeginArrowheadStyle = value

    @property
    def begin_arrowhead_style(self):
        """Alias for BeginArrowheadStyle"""
        return self.BeginArrowheadStyle

    @begin_arrowhead_style.setter
    def begin_arrowhead_style(self, value):
        """Alias for BeginArrowheadStyle.setter"""
        self.BeginArrowheadStyle = value

    @property
    def BeginArrowheadWidth(self):
        return self.com_object.BeginArrowheadWidth

    @BeginArrowheadWidth.setter
    def BeginArrowheadWidth(self, value):
        self.com_object.BeginArrowheadWidth = value

    @property
    def beginarrowheadwidth(self):
        """Alias for BeginArrowheadWidth"""
        return self.BeginArrowheadWidth

    @beginarrowheadwidth.setter
    def beginarrowheadwidth(self, value):
        """Alias for BeginArrowheadWidth.setter"""
        self.BeginArrowheadWidth = value

    @property
    def begin_arrowhead_width(self):
        """Alias for BeginArrowheadWidth"""
        return self.BeginArrowheadWidth

    @begin_arrowhead_width.setter
    def begin_arrowhead_width(self, value):
        """Alias for BeginArrowheadWidth.setter"""
        self.BeginArrowheadWidth = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DashStyle(self):
        return self.com_object.DashStyle

    @DashStyle.setter
    def DashStyle(self, value):
        self.com_object.DashStyle = value

    @property
    def dashstyle(self):
        """Alias for DashStyle"""
        return self.DashStyle

    @dashstyle.setter
    def dashstyle(self, value):
        """Alias for DashStyle.setter"""
        self.DashStyle = value

    @property
    def dash_style(self):
        """Alias for DashStyle"""
        return self.DashStyle

    @dash_style.setter
    def dash_style(self, value):
        """Alias for DashStyle.setter"""
        self.DashStyle = value

    @property
    def EndArrowheadLength(self):
        return self.com_object.EndArrowheadLength

    @EndArrowheadLength.setter
    def EndArrowheadLength(self, value):
        self.com_object.EndArrowheadLength = value

    @property
    def endarrowheadlength(self):
        """Alias for EndArrowheadLength"""
        return self.EndArrowheadLength

    @endarrowheadlength.setter
    def endarrowheadlength(self, value):
        """Alias for EndArrowheadLength.setter"""
        self.EndArrowheadLength = value

    @property
    def end_arrowhead_length(self):
        """Alias for EndArrowheadLength"""
        return self.EndArrowheadLength

    @end_arrowhead_length.setter
    def end_arrowhead_length(self, value):
        """Alias for EndArrowheadLength.setter"""
        self.EndArrowheadLength = value

    @property
    def EndArrowheadStyle(self):
        return self.com_object.EndArrowheadStyle

    @EndArrowheadStyle.setter
    def EndArrowheadStyle(self, value):
        self.com_object.EndArrowheadStyle = value

    @property
    def endarrowheadstyle(self):
        """Alias for EndArrowheadStyle"""
        return self.EndArrowheadStyle

    @endarrowheadstyle.setter
    def endarrowheadstyle(self, value):
        """Alias for EndArrowheadStyle.setter"""
        self.EndArrowheadStyle = value

    @property
    def end_arrowhead_style(self):
        """Alias for EndArrowheadStyle"""
        return self.EndArrowheadStyle

    @end_arrowhead_style.setter
    def end_arrowhead_style(self, value):
        """Alias for EndArrowheadStyle.setter"""
        self.EndArrowheadStyle = value

    @property
    def EndArrowheadWidth(self):
        return self.com_object.EndArrowheadWidth

    @EndArrowheadWidth.setter
    def EndArrowheadWidth(self, value):
        self.com_object.EndArrowheadWidth = value

    @property
    def endarrowheadwidth(self):
        """Alias for EndArrowheadWidth"""
        return self.EndArrowheadWidth

    @endarrowheadwidth.setter
    def endarrowheadwidth(self, value):
        """Alias for EndArrowheadWidth.setter"""
        self.EndArrowheadWidth = value

    @property
    def end_arrowhead_width(self):
        """Alias for EndArrowheadWidth"""
        return self.EndArrowheadWidth

    @end_arrowhead_width.setter
    def end_arrowhead_width(self, value):
        """Alias for EndArrowheadWidth.setter"""
        self.EndArrowheadWidth = value

    @property
    def ForeColor(self):
        return ColorFormat(self.com_object.ForeColor)

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def InsetPen(self):
        return self.com_object.InsetPen

    @InsetPen.setter
    def InsetPen(self, value):
        self.com_object.InsetPen = value

    @property
    def insetpen(self):
        """Alias for InsetPen"""
        return self.InsetPen

    @insetpen.setter
    def insetpen(self, value):
        """Alias for InsetPen.setter"""
        self.InsetPen = value

    @property
    def inset_pen(self):
        """Alias for InsetPen"""
        return self.InsetPen

    @inset_pen.setter
    def inset_pen(self, value):
        """Alias for InsetPen.setter"""
        self.InsetPen = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Pattern(self):
        return self.com_object.Pattern

    @Pattern.setter
    def Pattern(self, value):
        self.com_object.Pattern = value

    @property
    def pattern(self):
        """Alias for Pattern"""
        return self.Pattern

    @pattern.setter
    def pattern(self, value):
        """Alias for Pattern.setter"""
        self.Pattern = value

    @property
    def Style(self):
        return self.com_object.Style

    @Style.setter
    def Style(self, value):
        self.com_object.Style = value

    @property
    def style(self):
        """Alias for Style"""
        return self.Style

    @style.setter
    def style(self, value):
        """Alias for Style.setter"""
        self.Style = value

    @property
    def Transparency(self):
        return self.com_object.Transparency

    @Transparency.setter
    def Transparency(self, value):
        self.com_object.Transparency = value

    @property
    def transparency(self):
        """Alias for Transparency"""
        return self.Transparency

    @transparency.setter
    def transparency(self, value):
        """Alias for Transparency.setter"""
        self.Transparency = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Weight(self):
        return self.com_object.Weight

    @Weight.setter
    def Weight(self, value):
        self.com_object.Weight = value

    @property
    def weight(self):
        """Alias for Weight"""
        return self.Weight

    @weight.setter
    def weight(self, value):
        """Alias for Weight.setter"""
        self.Weight = value


class LinkFormat:

    def __init__(self, linkformat=None):
        self.com_object= linkformat

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoUpdate(self):
        return self.com_object.AutoUpdate

    @property
    def autoupdate(self):
        """Alias for AutoUpdate"""
        return self.AutoUpdate

    @property
    def auto_update(self):
        """Alias for AutoUpdate"""
        return self.AutoUpdate

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Update(self):
        self.com_object.Update()

    def update(self):
        """Alias for Update"""
        return self.Update()


class ListColumn:

    def __init__(self, listcolumn=None):
        self.com_object= listcolumn

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DataBodyRange(self):
        return Range(self.com_object.DataBodyRange)

    @property
    def databodyrange(self):
        """Alias for DataBodyRange"""
        return self.DataBodyRange

    @property
    def data_body_range(self):
        """Alias for DataBodyRange"""
        return self.DataBodyRange

    @property
    def Index(self):
        return ListColumns(self.com_object.Index)

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def Total(self):
        return ListColumn(self.com_object.Total)

    @property
    def total(self):
        """Alias for Total"""
        return self.Total

    @property
    def TotalsCalculation(self):
        return self.com_object.TotalsCalculation

    @TotalsCalculation.setter
    def TotalsCalculation(self, value):
        self.com_object.TotalsCalculation = value

    @property
    def totalscalculation(self):
        """Alias for TotalsCalculation"""
        return self.TotalsCalculation

    @totalscalculation.setter
    def totalscalculation(self, value):
        """Alias for TotalsCalculation.setter"""
        self.TotalsCalculation = value

    @property
    def totals_calculation(self):
        """Alias for TotalsCalculation"""
        return self.TotalsCalculation

    @totals_calculation.setter
    def totals_calculation(self, value):
        """Alias for TotalsCalculation.setter"""
        self.TotalsCalculation = value

    @property
    def XPath(self):
        return XPath(self.com_object.XPath)

    @property
    def xpath(self):
        """Alias for XPath"""
        return self.XPath

    @property
    def x_path(self):
        """Alias for XPath"""
        return self.XPath

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class ListColumns:

    def __init__(self, listcolumns=None):
        self.com_object= listcolumns

    def __call__(self, item):
        return ListColumn(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Position=None):
        arguments = com_arguments([unwrap(a) for a in [Position]])
        return ListColumn(self.com_object.Add(*arguments))

    def add(self, Position=None):
        """Alias for Add"""
        arguments = [Position]
        return self.Add(*arguments)


class ListDataFormat:

    def __init__(self, listdataformat=None):
        self.com_object= listdataformat

    @property
    def AllowFillIn(self):
        return self.com_object.AllowFillIn

    @property
    def allowfillin(self):
        """Alias for AllowFillIn"""
        return self.AllowFillIn

    @property
    def allow_fill_in(self):
        """Alias for AllowFillIn"""
        return self.AllowFillIn

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Choices(self):
        return self.com_object.Choices

    @property
    def choices(self):
        """Alias for Choices"""
        return self.Choices

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DecimalPlaces(self):
        return ListColumn(self.com_object.DecimalPlaces)

    @property
    def decimalplaces(self):
        """Alias for DecimalPlaces"""
        return self.DecimalPlaces

    @property
    def decimal_places(self):
        """Alias for DecimalPlaces"""
        return self.DecimalPlaces

    @property
    def DefaultValue(self):
        return self.com_object.DefaultValue

    @property
    def defaultvalue(self):
        """Alias for DefaultValue"""
        return self.DefaultValue

    @property
    def default_value(self):
        """Alias for DefaultValue"""
        return self.DefaultValue

    @property
    def IsPercent(self):
        return ListColumn(self.com_object.IsPercent)

    @property
    def ispercent(self):
        """Alias for IsPercent"""
        return self.IsPercent

    @property
    def is_percent(self):
        """Alias for IsPercent"""
        return self.IsPercent

    @property
    def lcid(self):
        return ListColumn(self.com_object.lcid)

    @property
    def MaxCharacters(self):
        return ListColumn(self.com_object.MaxCharacters)

    @property
    def maxcharacters(self):
        """Alias for MaxCharacters"""
        return self.MaxCharacters

    @property
    def max_characters(self):
        """Alias for MaxCharacters"""
        return self.MaxCharacters

    @property
    def MaxNumber(self):
        return self.com_object.MaxNumber

    @property
    def maxnumber(self):
        """Alias for MaxNumber"""
        return self.MaxNumber

    @property
    def max_number(self):
        """Alias for MaxNumber"""
        return self.MaxNumber

    @property
    def MinNumber(self):
        return self.com_object.MinNumber

    @property
    def minnumber(self):
        """Alias for MinNumber"""
        return self.MinNumber

    @property
    def min_number(self):
        """Alias for MinNumber"""
        return self.MinNumber

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ReadOnly(self):
        return self.com_object.ReadOnly

    @property
    def readonly(self):
        """Alias for ReadOnly"""
        return self.ReadOnly

    @property
    def read_only(self):
        """Alias for ReadOnly"""
        return self.ReadOnly

    @property
    def Required(self):
        return self.com_object.Required

    @property
    def required(self):
        """Alias for Required"""
        return self.Required

    @property
    def Type(self):
        return XlListDataType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type


class ListObject:

    def __init__(self, listobject=None):
        self.com_object= listobject

    @property
    def Active(self):
        return self.com_object.Active

    @property
    def active(self):
        """Alias for Active"""
        return self.Active

    @property
    def AlternativeText(self):
        return self.com_object.AlternativeText

    @AlternativeText.setter
    def AlternativeText(self, value):
        self.com_object.AlternativeText = value

    @property
    def alternativetext(self):
        """Alias for AlternativeText"""
        return self.AlternativeText

    @alternativetext.setter
    def alternativetext(self, value):
        """Alias for AlternativeText.setter"""
        self.AlternativeText = value

    @property
    def alternative_text(self):
        """Alias for AlternativeText"""
        return self.AlternativeText

    @alternative_text.setter
    def alternative_text(self, value):
        """Alias for AlternativeText.setter"""
        self.AlternativeText = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoFilter(self):
        return self.com_object.AutoFilter

    @property
    def autofilter(self):
        """Alias for AutoFilter"""
        return self.AutoFilter

    @property
    def auto_filter(self):
        """Alias for AutoFilter"""
        return self.AutoFilter

    @property
    def Comment(self):
        return self.com_object.Comment

    @Comment.setter
    def Comment(self, value):
        self.com_object.Comment = value

    @property
    def comment(self):
        """Alias for Comment"""
        return self.Comment

    @comment.setter
    def comment(self, value):
        """Alias for Comment.setter"""
        self.Comment = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DataBodyRange(self):
        return Range(self.com_object.DataBodyRange)

    @property
    def databodyrange(self):
        """Alias for DataBodyRange"""
        return self.DataBodyRange

    @property
    def data_body_range(self):
        """Alias for DataBodyRange"""
        return self.DataBodyRange

    @property
    def DisplayName(self):
        return ListObject(self.com_object.DisplayName)

    @DisplayName.setter
    def DisplayName(self, value):
        self.com_object.DisplayName = value

    @property
    def displayname(self):
        """Alias for DisplayName"""
        return self.DisplayName

    @displayname.setter
    def displayname(self, value):
        """Alias for DisplayName.setter"""
        self.DisplayName = value

    @property
    def display_name(self):
        """Alias for DisplayName"""
        return self.DisplayName

    @display_name.setter
    def display_name(self, value):
        """Alias for DisplayName.setter"""
        self.DisplayName = value

    @property
    def DisplayRightToLeft(self):
        return self.com_object.DisplayRightToLeft

    @property
    def displayrighttoleft(self):
        """Alias for DisplayRightToLeft"""
        return self.DisplayRightToLeft

    @property
    def display_right_to_left(self):
        """Alias for DisplayRightToLeft"""
        return self.DisplayRightToLeft

    @property
    def HeaderRowRange(self):
        return Range(self.com_object.HeaderRowRange)

    @property
    def headerrowrange(self):
        """Alias for HeaderRowRange"""
        return self.HeaderRowRange

    @property
    def header_row_range(self):
        """Alias for HeaderRowRange"""
        return self.HeaderRowRange

    @property
    def InsertRowRange(self):
        return Range(self.com_object.InsertRowRange)

    @property
    def insertrowrange(self):
        """Alias for InsertRowRange"""
        return self.InsertRowRange

    @property
    def insert_row_range(self):
        """Alias for InsertRowRange"""
        return self.InsertRowRange

    @property
    def ListColumns(self):
        return ListColumns(self.com_object.ListColumns)

    @property
    def listcolumns(self):
        """Alias for ListColumns"""
        return self.ListColumns

    @property
    def list_columns(self):
        """Alias for ListColumns"""
        return self.ListColumns

    @property
    def ListRows(self):
        return ListRows(self.com_object.ListRows)

    @property
    def listrows(self):
        """Alias for ListRows"""
        return self.ListRows

    @property
    def list_rows(self):
        """Alias for ListRows"""
        return self.ListRows

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def QueryTable(self):
        return QueryTable(self.com_object.QueryTable)

    @property
    def querytable(self):
        """Alias for QueryTable"""
        return self.QueryTable

    @property
    def query_table(self):
        """Alias for QueryTable"""
        return self.QueryTable

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def SharePointURL(self):
        return self.com_object.SharePointURL

    @property
    def sharepointurl(self):
        """Alias for SharePointURL"""
        return self.SharePointURL

    @property
    def share_point_u_r_l(self):
        """Alias for SharePointURL"""
        return self.SharePointURL

    @property
    def ShowAutoFilter(self):
        return self.com_object.ShowAutoFilter

    @ShowAutoFilter.setter
    def ShowAutoFilter(self, value):
        self.com_object.ShowAutoFilter = value

    @property
    def showautofilter(self):
        """Alias for ShowAutoFilter"""
        return self.ShowAutoFilter

    @showautofilter.setter
    def showautofilter(self, value):
        """Alias for ShowAutoFilter.setter"""
        self.ShowAutoFilter = value

    @property
    def show_auto_filter(self):
        """Alias for ShowAutoFilter"""
        return self.ShowAutoFilter

    @show_auto_filter.setter
    def show_auto_filter(self, value):
        """Alias for ShowAutoFilter.setter"""
        self.ShowAutoFilter = value

    @property
    def ShowAutoFilterDropDown(self):
        return self.com_object.ShowAutoFilterDropDown

    @ShowAutoFilterDropDown.setter
    def ShowAutoFilterDropDown(self, value):
        self.com_object.ShowAutoFilterDropDown = value

    @property
    def showautofilterdropdown(self):
        """Alias for ShowAutoFilterDropDown"""
        return self.ShowAutoFilterDropDown

    @showautofilterdropdown.setter
    def showautofilterdropdown(self, value):
        """Alias for ShowAutoFilterDropDown.setter"""
        self.ShowAutoFilterDropDown = value

    @property
    def show_auto_filter_drop_down(self):
        """Alias for ShowAutoFilterDropDown"""
        return self.ShowAutoFilterDropDown

    @show_auto_filter_drop_down.setter
    def show_auto_filter_drop_down(self, value):
        """Alias for ShowAutoFilterDropDown.setter"""
        self.ShowAutoFilterDropDown = value

    @property
    def ShowHeaders(self):
        return ListObject(self.com_object.ShowHeaders)

    @ShowHeaders.setter
    def ShowHeaders(self, value):
        self.com_object.ShowHeaders = value

    @property
    def showheaders(self):
        """Alias for ShowHeaders"""
        return self.ShowHeaders

    @showheaders.setter
    def showheaders(self, value):
        """Alias for ShowHeaders.setter"""
        self.ShowHeaders = value

    @property
    def show_headers(self):
        """Alias for ShowHeaders"""
        return self.ShowHeaders

    @show_headers.setter
    def show_headers(self, value):
        """Alias for ShowHeaders.setter"""
        self.ShowHeaders = value

    @property
    def ShowTableStyleColumnStripes(self):
        return ListObject(self.com_object.ShowTableStyleColumnStripes)

    @ShowTableStyleColumnStripes.setter
    def ShowTableStyleColumnStripes(self, value):
        self.com_object.ShowTableStyleColumnStripes = value

    @property
    def showtablestylecolumnstripes(self):
        """Alias for ShowTableStyleColumnStripes"""
        return self.ShowTableStyleColumnStripes

    @showtablestylecolumnstripes.setter
    def showtablestylecolumnstripes(self, value):
        """Alias for ShowTableStyleColumnStripes.setter"""
        self.ShowTableStyleColumnStripes = value

    @property
    def show_table_style_column_stripes(self):
        """Alias for ShowTableStyleColumnStripes"""
        return self.ShowTableStyleColumnStripes

    @show_table_style_column_stripes.setter
    def show_table_style_column_stripes(self, value):
        """Alias for ShowTableStyleColumnStripes.setter"""
        self.ShowTableStyleColumnStripes = value

    @property
    def ShowTableStyleFirstColumn(self):
        return ListObject(self.com_object.ShowTableStyleFirstColumn)

    @ShowTableStyleFirstColumn.setter
    def ShowTableStyleFirstColumn(self, value):
        self.com_object.ShowTableStyleFirstColumn = value

    @property
    def showtablestylefirstcolumn(self):
        """Alias for ShowTableStyleFirstColumn"""
        return self.ShowTableStyleFirstColumn

    @showtablestylefirstcolumn.setter
    def showtablestylefirstcolumn(self, value):
        """Alias for ShowTableStyleFirstColumn.setter"""
        self.ShowTableStyleFirstColumn = value

    @property
    def show_table_style_first_column(self):
        """Alias for ShowTableStyleFirstColumn"""
        return self.ShowTableStyleFirstColumn

    @show_table_style_first_column.setter
    def show_table_style_first_column(self, value):
        """Alias for ShowTableStyleFirstColumn.setter"""
        self.ShowTableStyleFirstColumn = value

    @property
    def ShowTableStyleLastColumn(self):
        return ListObject(self.com_object.ShowTableStyleLastColumn)

    @ShowTableStyleLastColumn.setter
    def ShowTableStyleLastColumn(self, value):
        self.com_object.ShowTableStyleLastColumn = value

    @property
    def showtablestylelastcolumn(self):
        """Alias for ShowTableStyleLastColumn"""
        return self.ShowTableStyleLastColumn

    @showtablestylelastcolumn.setter
    def showtablestylelastcolumn(self, value):
        """Alias for ShowTableStyleLastColumn.setter"""
        self.ShowTableStyleLastColumn = value

    @property
    def show_table_style_last_column(self):
        """Alias for ShowTableStyleLastColumn"""
        return self.ShowTableStyleLastColumn

    @show_table_style_last_column.setter
    def show_table_style_last_column(self, value):
        """Alias for ShowTableStyleLastColumn.setter"""
        self.ShowTableStyleLastColumn = value

    @property
    def ShowTableStyleRowStripes(self):
        return ListObject(self.com_object.ShowTableStyleRowStripes)

    @ShowTableStyleRowStripes.setter
    def ShowTableStyleRowStripes(self, value):
        self.com_object.ShowTableStyleRowStripes = value

    @property
    def showtablestylerowstripes(self):
        """Alias for ShowTableStyleRowStripes"""
        return self.ShowTableStyleRowStripes

    @showtablestylerowstripes.setter
    def showtablestylerowstripes(self, value):
        """Alias for ShowTableStyleRowStripes.setter"""
        self.ShowTableStyleRowStripes = value

    @property
    def show_table_style_row_stripes(self):
        """Alias for ShowTableStyleRowStripes"""
        return self.ShowTableStyleRowStripes

    @show_table_style_row_stripes.setter
    def show_table_style_row_stripes(self, value):
        """Alias for ShowTableStyleRowStripes.setter"""
        self.ShowTableStyleRowStripes = value

    @property
    def ShowTotals(self):
        return self.com_object.ShowTotals

    @ShowTotals.setter
    def ShowTotals(self, value):
        self.com_object.ShowTotals = value

    @property
    def showtotals(self):
        """Alias for ShowTotals"""
        return self.ShowTotals

    @showtotals.setter
    def showtotals(self, value):
        """Alias for ShowTotals.setter"""
        self.ShowTotals = value

    @property
    def show_totals(self):
        """Alias for ShowTotals"""
        return self.ShowTotals

    @show_totals.setter
    def show_totals(self, value):
        """Alias for ShowTotals.setter"""
        self.ShowTotals = value

    @property
    def Slicers(self):
        return ListObject(self.com_object.Slicers)

    @property
    def slicers(self):
        """Alias for Slicers"""
        return self.Slicers

    @property
    def Sort(self):
        return self.com_object.Sort

    @property
    def sort(self):
        """Alias for Sort"""
        return self.Sort

    @property
    def SourceType(self):
        return XlListObjectSourceType(self.com_object.SourceType)

    @property
    def sourcetype(self):
        """Alias for SourceType"""
        return self.SourceType

    @property
    def source_type(self):
        """Alias for SourceType"""
        return self.SourceType

    @property
    def Summary(self):
        return self.com_object.Summary

    @Summary.setter
    def Summary(self, value):
        self.com_object.Summary = value

    @property
    def summary(self):
        """Alias for Summary"""
        return self.Summary

    @summary.setter
    def summary(self, value):
        """Alias for Summary.setter"""
        self.Summary = value

    @property
    def TableObject(self):
        return TableObject(self.com_object.TableObject)

    @property
    def tableobject(self):
        """Alias for TableObject"""
        return self.TableObject

    @property
    def table_object(self):
        """Alias for TableObject"""
        return self.TableObject

    @property
    def TableStyle(self):
        return self.com_object.TableStyle

    @TableStyle.setter
    def TableStyle(self, value):
        self.com_object.TableStyle = value

    @property
    def tablestyle(self):
        """Alias for TableStyle"""
        return self.TableStyle

    @tablestyle.setter
    def tablestyle(self, value):
        """Alias for TableStyle.setter"""
        self.TableStyle = value

    @property
    def table_style(self):
        """Alias for TableStyle"""
        return self.TableStyle

    @table_style.setter
    def table_style(self, value):
        """Alias for TableStyle.setter"""
        self.TableStyle = value

    @property
    def TotalsRowRange(self):
        return Range(self.com_object.TotalsRowRange)

    @property
    def totalsrowrange(self):
        """Alias for TotalsRowRange"""
        return self.TotalsRowRange

    @property
    def totals_row_range(self):
        """Alias for TotalsRowRange"""
        return self.TotalsRowRange

    @property
    def XmlMap(self):
        return XmlMap(self.com_object.XmlMap)

    @property
    def xmlmap(self):
        """Alias for XmlMap"""
        return self.XmlMap

    @property
    def xml_map(self):
        """Alias for XmlMap"""
        return self.XmlMap

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def ExportToVisio(self):
        self.com_object.ExportToVisio()

    def exporttovisio(self):
        """Alias for ExportToVisio"""
        return self.ExportToVisio()

    def export_to_visio(self):
        """Alias for ExportToVisio"""
        return self.ExportToVisio()

    def Publish(self, Target=None, LinkSource=None):
        arguments = com_arguments([unwrap(a) for a in [Target, LinkSource]])
        return self.com_object.Publish(*arguments)

    def publish(self, Target=None, LinkSource=None):
        """Alias for Publish"""
        arguments = [Target, LinkSource]
        return self.Publish(*arguments)

    def Refresh(self):
        self.com_object.Refresh()

    def refresh(self):
        """Alias for Refresh"""
        return self.Refresh()

    def Resize(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        self.com_object.Resize(*arguments)

    def resize(self, Range=None):
        """Alias for Resize"""
        arguments = [Range]
        return self.Resize(*arguments)

    def Unlink(self):
        self.com_object.Unlink()

    def unlink(self):
        """Alias for Unlink"""
        return self.Unlink()

    def Unlist(self):
        self.com_object.Unlist()

    def unlist(self):
        """Alias for Unlist"""
        return self.Unlist()


class ListObjects:

    def __init__(self, listobjects=None):
        self.com_object= listobjects

    def __call__(self, item):
        return ListObject(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, SourceType=None, Source=None, LinkSource=None, XlListObjectHasHeaders=None, Destination=None, TableStyleName=None):
        arguments = com_arguments([unwrap(a) for a in [SourceType, Source, LinkSource, XlListObjectHasHeaders, Destination, TableStyleName]])
        return ListObject(self.com_object.Add(*arguments))

    def add(self, SourceType=None, Source=None, LinkSource=None, XlListObjectHasHeaders=None, Destination=None, TableStyleName=None):
        """Alias for Add"""
        arguments = [SourceType, Source, LinkSource, XlListObjectHasHeaders, Destination, TableStyleName]
        return self.Add(*arguments)


class ListRow:

    def __init__(self, listrow=None):
        self.com_object= listrow

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return ListRows(self.com_object.Index)

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class ListRows:

    def __init__(self, listrows=None):
        self.com_object= listrows

    def __call__(self, item):
        return ListRow(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Position=None, AlwaysInsert=None):
        arguments = com_arguments([unwrap(a) for a in [Position, AlwaysInsert]])
        return ListRow(self.com_object.Add(*arguments))

    def add(self, Position=None, AlwaysInsert=None):
        """Alias for Add"""
        arguments = [Position, AlwaysInsert]
        return self.Add(*arguments)


class Mailer:

    def __init__(self, mailer=None):
        self.com_object= mailer

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BCCRecipients(self):
        return self.com_object.BCCRecipients

    @property
    def bccrecipients(self):
        """Alias for BCCRecipients"""
        return self.BCCRecipients

    @property
    def b_c_c_recipients(self):
        """Alias for BCCRecipients"""
        return self.BCCRecipients

    @property
    def CCRecipients(self):
        return self.com_object.CCRecipients

    @property
    def ccrecipients(self):
        """Alias for CCRecipients"""
        return self.CCRecipients

    @property
    def c_c_recipients(self):
        """Alias for CCRecipients"""
        return self.CCRecipients

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Enclosures(self):
        return self.com_object.Enclosures

    @property
    def enclosures(self):
        """Alias for Enclosures"""
        return self.Enclosures

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Received(self):
        return self.com_object.Received

    @property
    def received(self):
        """Alias for Received"""
        return self.Received

    @property
    def SendDateTime(self):
        return self.com_object.SendDateTime

    @property
    def senddatetime(self):
        """Alias for SendDateTime"""
        return self.SendDateTime

    @property
    def send_date_time(self):
        """Alias for SendDateTime"""
        return self.SendDateTime

    @property
    def Sender(self):
        return self.com_object.Sender

    @property
    def sender(self):
        """Alias for Sender"""
        return self.Sender

    @property
    def Subject(self):
        return self.com_object.Subject

    @Subject.setter
    def Subject(self, value):
        self.com_object.Subject = value

    @property
    def subject(self):
        """Alias for Subject"""
        return self.Subject

    @subject.setter
    def subject(self, value):
        """Alias for Subject.setter"""
        self.Subject = value

    @property
    def ToRecipients(self):
        return self.com_object.ToRecipients

    @property
    def torecipients(self):
        """Alias for ToRecipients"""
        return self.ToRecipients

    @property
    def to_recipients(self):
        """Alias for ToRecipients"""
        return self.ToRecipients

    @property
    def WhichAddress(self):
        return self.com_object.WhichAddress

    @property
    def whichaddress(self):
        """Alias for WhichAddress"""
        return self.WhichAddress

    @property
    def which_address(self):
        """Alias for WhichAddress"""
        return self.WhichAddress


class Model3DFormat:

    def __init__(self, model3dformat=None):
        self.com_object= model3dformat

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoFit(self):
        return self.com_object.AutoFit

    @AutoFit.setter
    def AutoFit(self, value):
        self.com_object.AutoFit = value

    @property
    def autofit(self):
        """Alias for AutoFit"""
        return self.AutoFit

    @autofit.setter
    def autofit(self, value):
        """Alias for AutoFit.setter"""
        self.AutoFit = value

    @property
    def auto_fit(self):
        """Alias for AutoFit"""
        return self.AutoFit

    @auto_fit.setter
    def auto_fit(self, value):
        """Alias for AutoFit.setter"""
        self.AutoFit = value

    @property
    def CameraPositionX(self):
        return self.com_object.CameraPositionX

    @CameraPositionX.setter
    def CameraPositionX(self, value):
        self.com_object.CameraPositionX = value

    @property
    def camerapositionx(self):
        """Alias for CameraPositionX"""
        return self.CameraPositionX

    @camerapositionx.setter
    def camerapositionx(self, value):
        """Alias for CameraPositionX.setter"""
        self.CameraPositionX = value

    @property
    def camera_position_x(self):
        """Alias for CameraPositionX"""
        return self.CameraPositionX

    @camera_position_x.setter
    def camera_position_x(self, value):
        """Alias for CameraPositionX.setter"""
        self.CameraPositionX = value

    @property
    def CameraPositionY(self):
        return self.com_object.CameraPositionY

    @CameraPositionY.setter
    def CameraPositionY(self, value):
        self.com_object.CameraPositionY = value

    @property
    def camerapositiony(self):
        """Alias for CameraPositionY"""
        return self.CameraPositionY

    @camerapositiony.setter
    def camerapositiony(self, value):
        """Alias for CameraPositionY.setter"""
        self.CameraPositionY = value

    @property
    def camera_position_y(self):
        """Alias for CameraPositionY"""
        return self.CameraPositionY

    @camera_position_y.setter
    def camera_position_y(self, value):
        """Alias for CameraPositionY.setter"""
        self.CameraPositionY = value

    @property
    def CameraPositionZ(self):
        return self.com_object.CameraPositionZ

    @CameraPositionZ.setter
    def CameraPositionZ(self, value):
        self.com_object.CameraPositionZ = value

    @property
    def camerapositionz(self):
        """Alias for CameraPositionZ"""
        return self.CameraPositionZ

    @camerapositionz.setter
    def camerapositionz(self, value):
        """Alias for CameraPositionZ.setter"""
        self.CameraPositionZ = value

    @property
    def camera_position_z(self):
        """Alias for CameraPositionZ"""
        return self.CameraPositionZ

    @camera_position_z.setter
    def camera_position_z(self, value):
        """Alias for CameraPositionZ.setter"""
        self.CameraPositionZ = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def FieldOfView(self):
        return self.com_object.FieldOfView

    @FieldOfView.setter
    def FieldOfView(self, value):
        self.com_object.FieldOfView = value

    @property
    def fieldofview(self):
        """Alias for FieldOfView"""
        return self.FieldOfView

    @fieldofview.setter
    def fieldofview(self, value):
        """Alias for FieldOfView.setter"""
        self.FieldOfView = value

    @property
    def field_of_view(self):
        """Alias for FieldOfView"""
        return self.FieldOfView

    @field_of_view.setter
    def field_of_view(self, value):
        """Alias for FieldOfView.setter"""
        self.FieldOfView = value

    @property
    def LookAtPointX(self):
        return self.com_object.LookAtPointX

    @LookAtPointX.setter
    def LookAtPointX(self, value):
        self.com_object.LookAtPointX = value

    @property
    def lookatpointx(self):
        """Alias for LookAtPointX"""
        return self.LookAtPointX

    @lookatpointx.setter
    def lookatpointx(self, value):
        """Alias for LookAtPointX.setter"""
        self.LookAtPointX = value

    @property
    def look_at_point_x(self):
        """Alias for LookAtPointX"""
        return self.LookAtPointX

    @look_at_point_x.setter
    def look_at_point_x(self, value):
        """Alias for LookAtPointX.setter"""
        self.LookAtPointX = value

    @property
    def LookAtPointY(self):
        return self.com_object.LookAtPointY

    @LookAtPointY.setter
    def LookAtPointY(self, value):
        self.com_object.LookAtPointY = value

    @property
    def lookatpointy(self):
        """Alias for LookAtPointY"""
        return self.LookAtPointY

    @lookatpointy.setter
    def lookatpointy(self, value):
        """Alias for LookAtPointY.setter"""
        self.LookAtPointY = value

    @property
    def look_at_point_y(self):
        """Alias for LookAtPointY"""
        return self.LookAtPointY

    @look_at_point_y.setter
    def look_at_point_y(self, value):
        """Alias for LookAtPointY.setter"""
        self.LookAtPointY = value

    @property
    def LookAtPointZ(self):
        return self.com_object.LookAtPointZ

    @LookAtPointZ.setter
    def LookAtPointZ(self, value):
        self.com_object.LookAtPointZ = value

    @property
    def lookatpointz(self):
        """Alias for LookAtPointZ"""
        return self.LookAtPointZ

    @lookatpointz.setter
    def lookatpointz(self, value):
        """Alias for LookAtPointZ.setter"""
        self.LookAtPointZ = value

    @property
    def look_at_point_z(self):
        """Alias for LookAtPointZ"""
        return self.LookAtPointZ

    @look_at_point_z.setter
    def look_at_point_z(self, value):
        """Alias for LookAtPointZ.setter"""
        self.LookAtPointZ = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RotationX(self):
        return self.com_object.RotationX

    @RotationX.setter
    def RotationX(self, value):
        self.com_object.RotationX = value

    @property
    def rotationx(self):
        """Alias for RotationX"""
        return self.RotationX

    @rotationx.setter
    def rotationx(self, value):
        """Alias for RotationX.setter"""
        self.RotationX = value

    @property
    def rotation_x(self):
        """Alias for RotationX"""
        return self.RotationX

    @rotation_x.setter
    def rotation_x(self, value):
        """Alias for RotationX.setter"""
        self.RotationX = value

    @property
    def RotationY(self):
        return self.com_object.RotationY

    @RotationY.setter
    def RotationY(self, value):
        self.com_object.RotationY = value

    @property
    def rotationy(self):
        """Alias for RotationY"""
        return self.RotationY

    @rotationy.setter
    def rotationy(self, value):
        """Alias for RotationY.setter"""
        self.RotationY = value

    @property
    def rotation_y(self):
        """Alias for RotationY"""
        return self.RotationY

    @rotation_y.setter
    def rotation_y(self, value):
        """Alias for RotationY.setter"""
        self.RotationY = value

    @property
    def RotationZ(self):
        return self.com_object.RotationZ

    @RotationZ.setter
    def RotationZ(self, value):
        self.com_object.RotationZ = value

    @property
    def rotationz(self):
        """Alias for RotationZ"""
        return self.RotationZ

    @rotationz.setter
    def rotationz(self, value):
        """Alias for RotationZ.setter"""
        self.RotationZ = value

    @property
    def rotation_z(self):
        """Alias for RotationZ"""
        return self.RotationZ

    @rotation_z.setter
    def rotation_z(self, value):
        """Alias for RotationZ.setter"""
        self.RotationZ = value

    def IncrementRotationX(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotationX(*arguments)

    def incrementrotationx(self, Increment=None):
        """Alias for IncrementRotationX"""
        arguments = [Increment]
        return self.IncrementRotationX(*arguments)

    def increment_rotation_x(self, Increment=None):
        """Alias for IncrementRotationX"""
        arguments = [Increment]
        return self.IncrementRotationX(*arguments)

    def IncrementRotationY(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotationY(*arguments)

    def incrementrotationy(self, Increment=None):
        """Alias for IncrementRotationY"""
        arguments = [Increment]
        return self.IncrementRotationY(*arguments)

    def increment_rotation_y(self, Increment=None):
        """Alias for IncrementRotationY"""
        arguments = [Increment]
        return self.IncrementRotationY(*arguments)

    def IncrementRotationZ(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotationZ(*arguments)

    def incrementrotationz(self, Increment=None):
        """Alias for IncrementRotationZ"""
        arguments = [Increment]
        return self.IncrementRotationZ(*arguments)

    def increment_rotation_z(self, Increment=None):
        """Alias for IncrementRotationZ"""
        arguments = [Increment]
        return self.IncrementRotationZ(*arguments)

    def ResetModel(self, ResetSize=None):
        arguments = com_arguments([unwrap(a) for a in [ResetSize]])
        self.com_object.ResetModel(*arguments)

    def resetmodel(self, ResetSize=None):
        """Alias for ResetModel"""
        arguments = [ResetSize]
        return self.ResetModel(*arguments)

    def reset_model(self, ResetSize=None):
        """Alias for ResetModel"""
        arguments = [ResetSize]
        return self.ResetModel(*arguments)


class ModelChanges:

    def __init__(self, modelchanges=None):
        self.com_object= modelchanges

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ColumnsAdded(self):
        return ModelColumnNames(self.com_object.ColumnsAdded)

    @property
    def columnsadded(self):
        """Alias for ColumnsAdded"""
        return self.ColumnsAdded

    @property
    def columns_added(self):
        """Alias for ColumnsAdded"""
        return self.ColumnsAdded

    @property
    def ColumnsChanged(self):
        return ModelColumnChanges(self.com_object.ColumnsChanged)

    @property
    def columnschanged(self):
        """Alias for ColumnsChanged"""
        return self.ColumnsChanged

    @property
    def columns_changed(self):
        """Alias for ColumnsChanged"""
        return self.ColumnsChanged

    @property
    def ColumnsDeleted(self):
        return ModelColumnNames(self.com_object.ColumnsDeleted)

    @property
    def columnsdeleted(self):
        """Alias for ColumnsDeleted"""
        return self.ColumnsDeleted

    @property
    def columns_deleted(self):
        """Alias for ColumnsDeleted"""
        return self.ColumnsDeleted

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def MeasuresAdded(self):
        return ModelMeasureNames(self.com_object.MeasuresAdded)

    @property
    def measuresadded(self):
        """Alias for MeasuresAdded"""
        return self.MeasuresAdded

    @property
    def measures_added(self):
        """Alias for MeasuresAdded"""
        return self.MeasuresAdded

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RelationshipChange(self):
        return self.com_object.RelationshipChange

    @property
    def relationshipchange(self):
        """Alias for RelationshipChange"""
        return self.RelationshipChange

    @property
    def relationship_change(self):
        """Alias for RelationshipChange"""
        return self.RelationshipChange

    @property
    def Source(self):
        return self.com_object.Source

    @property
    def source(self):
        """Alias for Source"""
        return self.Source

    @property
    def TableNamesChanged(self):
        return ModelTableNameChanges(self.com_object.TableNamesChanged)

    @property
    def tablenameschanged(self):
        """Alias for TableNamesChanged"""
        return self.TableNamesChanged

    @property
    def table_names_changed(self):
        """Alias for TableNamesChanged"""
        return self.TableNamesChanged

    @property
    def TablesAdded(self):
        return ModelTableNames(self.com_object.TablesAdded)

    @property
    def tablesadded(self):
        """Alias for TablesAdded"""
        return self.TablesAdded

    @property
    def tables_added(self):
        """Alias for TablesAdded"""
        return self.TablesAdded

    @property
    def TablesDeleted(self):
        return ModelTableNames(self.com_object.TablesDeleted)

    @property
    def tablesdeleted(self):
        """Alias for TablesDeleted"""
        return self.TablesDeleted

    @property
    def tables_deleted(self):
        """Alias for TablesDeleted"""
        return self.TablesDeleted

    @property
    def TablesModified(self):
        return ModelTableNames(self.com_object.TablesModified)

    @property
    def tablesmodified(self):
        """Alias for TablesModified"""
        return self.TablesModified

    @property
    def tables_modified(self):
        """Alias for TablesModified"""
        return self.TablesModified

    @property
    def UnknownChange(self):
        return self.com_object.UnknownChange

    @property
    def unknownchange(self):
        """Alias for UnknownChange"""
        return self.UnknownChange

    @property
    def unknown_change(self):
        """Alias for UnknownChange"""
        return self.UnknownChange


class ModelColumnChange:

    def __init__(self, modelcolumnchange=None):
        self.com_object= modelcolumnchange

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ColumnName(self):
        return self.com_object.ColumnName

    @property
    def columnname(self):
        """Alias for ColumnName"""
        return self.ColumnName

    @property
    def column_name(self):
        """Alias for ColumnName"""
        return self.ColumnName

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def TableName(self):
        return self.com_object.TableName

    @property
    def tablename(self):
        """Alias for TableName"""
        return self.TableName

    @property
    def table_name(self):
        """Alias for TableName"""
        return self.TableName


class ModelColumnChanges:

    def __init__(self, modelcolumnchanges=None):
        self.com_object= modelcolumnchanges

    def __call__(self, item):
        return ModelColumnChange(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return ModelColumnChange(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ModelColumnChange(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ModelColumnName:

    def __init__(self, modelcolumnname=None):
        self.com_object= modelcolumnname

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ColumnName(self):
        return self.com_object.ColumnName

    @property
    def columnname(self):
        """Alias for ColumnName"""
        return self.ColumnName

    @property
    def column_name(self):
        """Alias for ColumnName"""
        return self.ColumnName

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def TableName(self):
        return self.com_object.TableName

    @property
    def tablename(self):
        """Alias for TableName"""
        return self.TableName

    @property
    def table_name(self):
        """Alias for TableName"""
        return self.TableName


class ModelColumnNames:

    def __init__(self, modelcolumnnames=None):
        self.com_object= modelcolumnnames

    def __call__(self, item):
        return ModelColumnName(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return ModelColumnName(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ModelColumnName(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ModelConnection:

    def __init__(self, modelconnection=None):
        self.com_object= modelconnection

    @property
    def ADOConnection(self):
        return self.com_object.ADOConnection

    @property
    def adoconnection(self):
        """Alias for ADOConnection"""
        return self.ADOConnection

    @property
    def a_d_o_connection(self):
        """Alias for ADOConnection"""
        return self.ADOConnection

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def CalculatedMembers(self):
        return CalculatedMembers(self.com_object.CalculatedMembers)

    @property
    def calculatedmembers(self):
        """Alias for CalculatedMembers"""
        return self.CalculatedMembers

    @property
    def calculated_members(self):
        """Alias for CalculatedMembers"""
        return self.CalculatedMembers

    @property
    def CommandText(self):
        return self.com_object.CommandText

    @CommandText.setter
    def CommandText(self, value):
        self.com_object.CommandText = value

    @property
    def commandtext(self):
        """Alias for CommandText"""
        return self.CommandText

    @commandtext.setter
    def commandtext(self, value):
        """Alias for CommandText.setter"""
        self.CommandText = value

    @property
    def command_text(self):
        """Alias for CommandText"""
        return self.CommandText

    @command_text.setter
    def command_text(self, value):
        """Alias for CommandText.setter"""
        self.CommandText = value

    @property
    def CommandType(self):
        return XlCmdType(self.com_object.CommandType)

    @CommandType.setter
    def CommandType(self, value):
        self.com_object.CommandType = value

    @property
    def commandtype(self):
        """Alias for CommandType"""
        return self.CommandType

    @commandtype.setter
    def commandtype(self, value):
        """Alias for CommandType.setter"""
        self.CommandType = value

    @property
    def command_type(self):
        """Alias for CommandType"""
        return self.CommandType

    @command_type.setter
    def command_type(self, value):
        """Alias for CommandType.setter"""
        self.CommandType = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class ModelFormatBoolean:

    def __init__(self, modelformatboolean=None):
        self.com_object= modelformatboolean

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class ModelFormatCurrency:

    def __init__(self, modelformatcurrency=None):
        self.com_object= modelformatcurrency

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DecimalPlaces(self):
        return self.com_object.DecimalPlaces

    @DecimalPlaces.setter
    def DecimalPlaces(self, value):
        self.com_object.DecimalPlaces = value

    @property
    def decimalplaces(self):
        """Alias for DecimalPlaces"""
        return self.DecimalPlaces

    @decimalplaces.setter
    def decimalplaces(self, value):
        """Alias for DecimalPlaces.setter"""
        self.DecimalPlaces = value

    @property
    def decimal_places(self):
        """Alias for DecimalPlaces"""
        return self.DecimalPlaces

    @decimal_places.setter
    def decimal_places(self, value):
        """Alias for DecimalPlaces.setter"""
        self.DecimalPlaces = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Symbol(self):
        return self.com_object.Symbol

    @Symbol.setter
    def Symbol(self, value):
        self.com_object.Symbol = value

    @property
    def symbol(self):
        """Alias for Symbol"""
        return self.Symbol

    @symbol.setter
    def symbol(self, value):
        """Alias for Symbol.setter"""
        self.Symbol = value


class ModelFormatDate:

    def __init__(self, modelformatdate=None):
        self.com_object= modelformatdate

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def FormatString(self):
        return self.com_object.FormatString

    @FormatString.setter
    def FormatString(self, value):
        self.com_object.FormatString = value

    @property
    def formatstring(self):
        """Alias for FormatString"""
        return self.FormatString

    @formatstring.setter
    def formatstring(self, value):
        """Alias for FormatString.setter"""
        self.FormatString = value

    @property
    def format_string(self):
        """Alias for FormatString"""
        return self.FormatString

    @format_string.setter
    def format_string(self, value):
        """Alias for FormatString.setter"""
        self.FormatString = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class ModelFormatDecimalNumber:

    def __init__(self, modelformatdecimalnumber=None):
        self.com_object= modelformatdecimalnumber

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DecimalPlaces(self):
        return self.com_object.DecimalPlaces

    @DecimalPlaces.setter
    def DecimalPlaces(self, value):
        self.com_object.DecimalPlaces = value

    @property
    def decimalplaces(self):
        """Alias for DecimalPlaces"""
        return self.DecimalPlaces

    @decimalplaces.setter
    def decimalplaces(self, value):
        """Alias for DecimalPlaces.setter"""
        self.DecimalPlaces = value

    @property
    def decimal_places(self):
        """Alias for DecimalPlaces"""
        return self.DecimalPlaces

    @decimal_places.setter
    def decimal_places(self, value):
        """Alias for DecimalPlaces.setter"""
        self.DecimalPlaces = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def UseThousandSeparator(self):
        return self.com_object.UseThousandSeparator

    @UseThousandSeparator.setter
    def UseThousandSeparator(self, value):
        self.com_object.UseThousandSeparator = value

    @property
    def usethousandseparator(self):
        """Alias for UseThousandSeparator"""
        return self.UseThousandSeparator

    @usethousandseparator.setter
    def usethousandseparator(self, value):
        """Alias for UseThousandSeparator.setter"""
        self.UseThousandSeparator = value

    @property
    def use_thousand_separator(self):
        """Alias for UseThousandSeparator"""
        return self.UseThousandSeparator

    @use_thousand_separator.setter
    def use_thousand_separator(self, value):
        """Alias for UseThousandSeparator.setter"""
        self.UseThousandSeparator = value


class ModelFormatGeneral:

    def __init__(self, modelformatgeneral=None):
        self.com_object= modelformatgeneral

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class ModelFormatPercentageNumber:

    def __init__(self, modelformatpercentagenumber=None):
        self.com_object= modelformatpercentagenumber

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DecimalPlaces(self):
        return self.com_object.DecimalPlaces

    @DecimalPlaces.setter
    def DecimalPlaces(self, value):
        self.com_object.DecimalPlaces = value

    @property
    def decimalplaces(self):
        """Alias for DecimalPlaces"""
        return self.DecimalPlaces

    @decimalplaces.setter
    def decimalplaces(self, value):
        """Alias for DecimalPlaces.setter"""
        self.DecimalPlaces = value

    @property
    def decimal_places(self):
        """Alias for DecimalPlaces"""
        return self.DecimalPlaces

    @decimal_places.setter
    def decimal_places(self, value):
        """Alias for DecimalPlaces.setter"""
        self.DecimalPlaces = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def UseThousandSeparator(self):
        return self.com_object.UseThousandSeparator

    @UseThousandSeparator.setter
    def UseThousandSeparator(self, value):
        self.com_object.UseThousandSeparator = value

    @property
    def usethousandseparator(self):
        """Alias for UseThousandSeparator"""
        return self.UseThousandSeparator

    @usethousandseparator.setter
    def usethousandseparator(self, value):
        """Alias for UseThousandSeparator.setter"""
        self.UseThousandSeparator = value

    @property
    def use_thousand_separator(self):
        """Alias for UseThousandSeparator"""
        return self.UseThousandSeparator

    @use_thousand_separator.setter
    def use_thousand_separator(self, value):
        """Alias for UseThousandSeparator.setter"""
        self.UseThousandSeparator = value


class ModelFormatScientificNumber:

    def __init__(self, modelformatscientificnumber=None):
        self.com_object= modelformatscientificnumber

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DecimalPlaces(self):
        return self.com_object.DecimalPlaces

    @DecimalPlaces.setter
    def DecimalPlaces(self, value):
        self.com_object.DecimalPlaces = value

    @property
    def decimalplaces(self):
        """Alias for DecimalPlaces"""
        return self.DecimalPlaces

    @decimalplaces.setter
    def decimalplaces(self, value):
        """Alias for DecimalPlaces.setter"""
        self.DecimalPlaces = value

    @property
    def decimal_places(self):
        """Alias for DecimalPlaces"""
        return self.DecimalPlaces

    @decimal_places.setter
    def decimal_places(self, value):
        """Alias for DecimalPlaces.setter"""
        self.DecimalPlaces = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class ModelFormatWholeNumber:

    def __init__(self, modelformatwholenumber=None):
        self.com_object= modelformatwholenumber

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def UseThousandSeparator(self):
        return self.com_object.UseThousandSeparator

    @UseThousandSeparator.setter
    def UseThousandSeparator(self, value):
        self.com_object.UseThousandSeparator = value

    @property
    def usethousandseparator(self):
        """Alias for UseThousandSeparator"""
        return self.UseThousandSeparator

    @usethousandseparator.setter
    def usethousandseparator(self, value):
        """Alias for UseThousandSeparator.setter"""
        self.UseThousandSeparator = value

    @property
    def use_thousand_separator(self):
        """Alias for UseThousandSeparator"""
        return self.UseThousandSeparator

    @use_thousand_separator.setter
    def use_thousand_separator(self, value):
        """Alias for UseThousandSeparator.setter"""
        self.UseThousandSeparator = value


class ModelMeasure:

    def __init__(self, modelmeasure=None):
        self.com_object= modelmeasure

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AssociatedTable(self):
        return self.com_object.AssociatedTable

    @AssociatedTable.setter
    def AssociatedTable(self, value):
        self.com_object.AssociatedTable = value

    @property
    def associatedtable(self):
        """Alias for AssociatedTable"""
        return self.AssociatedTable

    @associatedtable.setter
    def associatedtable(self, value):
        """Alias for AssociatedTable.setter"""
        self.AssociatedTable = value

    @property
    def associated_table(self):
        """Alias for AssociatedTable"""
        return self.AssociatedTable

    @associated_table.setter
    def associated_table(self, value):
        """Alias for AssociatedTable.setter"""
        self.AssociatedTable = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Description(self):
        return self.com_object.Description

    @Description.setter
    def Description(self, value):
        self.com_object.Description = value

    @property
    def description(self):
        """Alias for Description"""
        return self.Description

    @description.setter
    def description(self, value):
        """Alias for Description.setter"""
        self.Description = value

    @property
    def FormatInformation(self):
        return self.com_object.FormatInformation

    @FormatInformation.setter
    def FormatInformation(self, value):
        self.com_object.FormatInformation = value

    @property
    def formatinformation(self):
        """Alias for FormatInformation"""
        return self.FormatInformation

    @formatinformation.setter
    def formatinformation(self, value):
        """Alias for FormatInformation.setter"""
        self.FormatInformation = value

    @property
    def format_information(self):
        """Alias for FormatInformation"""
        return self.FormatInformation

    @format_information.setter
    def format_information(self, value):
        """Alias for FormatInformation.setter"""
        self.FormatInformation = value

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class ModelMeasureName:

    def __init__(self, modelmeasurename=None):
        self.com_object= modelmeasurename

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def MeasureName(self):
        return self.com_object.MeasureName

    @property
    def measurename(self):
        """Alias for MeasureName"""
        return self.MeasureName

    @property
    def measure_name(self):
        """Alias for MeasureName"""
        return self.MeasureName

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def TableName(self):
        return self.com_object.TableName

    @property
    def tablename(self):
        """Alias for TableName"""
        return self.TableName

    @property
    def table_name(self):
        """Alias for TableName"""
        return self.TableName


class ModelMeasureNames:

    def __init__(self, modelmeasurenames=None):
        self.com_object= modelmeasurenames

    def __call__(self, item):
        return ModelMeasureName(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return ModelMeasureName(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ModelMeasureName(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ModelMeasures:

    def __init__(self, modelmeasures=None):
        self.com_object= modelmeasures

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, MeasureName=None, AssociatedTable=None, Formula=None, FormatInformation=None, Description=None):
        arguments = com_arguments([unwrap(a) for a in [MeasureName, AssociatedTable, Formula, FormatInformation, Description]])
        return ModelMeasure(self.com_object.Add(*arguments))

    def add(self, MeasureName=None, AssociatedTable=None, Formula=None, FormatInformation=None, Description=None):
        """Alias for Add"""
        arguments = [MeasureName, AssociatedTable, Formula, FormatInformation, Description]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ModelMeasure(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ModelRelationship:

    def __init__(self, modelrelationship=None):
        self.com_object= modelrelationship

    @property
    def Active(self):
        return self.com_object.Active

    @Active.setter
    def Active(self, value):
        self.com_object.Active = value

    @property
    def active(self):
        """Alias for Active"""
        return self.Active

    @active.setter
    def active(self, value):
        """Alias for Active.setter"""
        self.Active = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ForeignKeyColumn(self):
        return self.com_object.ForeignKeyColumn

    @property
    def foreignkeycolumn(self):
        """Alias for ForeignKeyColumn"""
        return self.ForeignKeyColumn

    @property
    def foreign_key_column(self):
        """Alias for ForeignKeyColumn"""
        return self.ForeignKeyColumn

    @property
    def ForeignKeyTable(self):
        return self.com_object.ForeignKeyTable

    @property
    def foreignkeytable(self):
        """Alias for ForeignKeyTable"""
        return self.ForeignKeyTable

    @property
    def foreign_key_table(self):
        """Alias for ForeignKeyTable"""
        return self.ForeignKeyTable

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PrimaryKeyColumn(self):
        return self.com_object.PrimaryKeyColumn

    @property
    def primarykeycolumn(self):
        """Alias for PrimaryKeyColumn"""
        return self.PrimaryKeyColumn

    @property
    def primary_key_column(self):
        """Alias for PrimaryKeyColumn"""
        return self.PrimaryKeyColumn

    @property
    def PrimaryKeyTable(self):
        return self.com_object.PrimaryKeyTable

    @property
    def primarykeytable(self):
        """Alias for PrimaryKeyTable"""
        return self.PrimaryKeyTable

    @property
    def primary_key_table(self):
        """Alias for PrimaryKeyTable"""
        return self.PrimaryKeyTable

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class ModelRelationships:

    def __init__(self, modelrelationships=None):
        self.com_object= modelrelationships

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return ModelRelationship(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, ForeignKeyColumn=None, PrimaryKeyColumn=None):
        arguments = com_arguments([unwrap(a) for a in [ForeignKeyColumn, PrimaryKeyColumn]])
        return MODELRELATIONSHIP(self.com_object.Add(*arguments))

    def add(self, ForeignKeyColumn=None, PrimaryKeyColumn=None):
        """Alias for Add"""
        arguments = [ForeignKeyColumn, PrimaryKeyColumn]
        return self.Add(*arguments)

    def DetectRelationships(self, PivotTable=None):
        arguments = com_arguments([unwrap(a) for a in [PivotTable]])
        return self.com_object.DetectRelationships(*arguments)

    def detectrelationships(self, PivotTable=None):
        """Alias for DetectRelationships"""
        arguments = [PivotTable]
        return self.DetectRelationships(*arguments)

    def detect_relationships(self, PivotTable=None):
        """Alias for DetectRelationships"""
        arguments = [PivotTable]
        return self.DetectRelationships(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ModelRelationship(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ModelTable:

    def __init__(self, modeltable=None):
        self.com_object= modeltable

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ModelTableColumns(self):
        return self.com_object.ModelTableColumns

    @property
    def modeltablecolumns(self):
        """Alias for ModelTableColumns"""
        return self.ModelTableColumns

    @property
    def model_table_columns(self):
        """Alias for ModelTableColumns"""
        return self.ModelTableColumns

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RecordCount(self):
        return self.com_object.RecordCount

    @property
    def recordcount(self):
        """Alias for RecordCount"""
        return self.RecordCount

    @property
    def record_count(self):
        """Alias for RecordCount"""
        return self.RecordCount

    @property
    def SourceName(self):
        return self.com_object.SourceName

    @property
    def sourcename(self):
        """Alias for SourceName"""
        return self.SourceName

    @property
    def source_name(self):
        """Alias for SourceName"""
        return self.SourceName

    @property
    def SourceWorkbookConnection(self):
        return self.com_object.SourceWorkbookConnection

    @property
    def sourceworkbookconnection(self):
        """Alias for SourceWorkbookConnection"""
        return self.SourceWorkbookConnection

    @property
    def source_workbook_connection(self):
        """Alias for SourceWorkbookConnection"""
        return self.SourceWorkbookConnection

    def Refresh(self):
        return self.com_object.Refresh()

    def refresh(self):
        """Alias for Refresh"""
        return self.Refresh()


class ModelTableColumn:

    def __init__(self, modeltablecolumn=None):
        self.com_object= modeltablecolumn

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DataType(self):
        return XlParameterDataType(self.com_object.DataType)

    @property
    def datatype(self):
        """Alias for DataType"""
        return self.DataType

    @property
    def data_type(self):
        """Alias for DataType"""
        return self.DataType

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class ModelTableColumns:

    def __init__(self, modeltablecolumns=None):
        self.com_object= modeltablecolumns

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return ModelTableColumn(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return MODELTABLECOLUMN(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ModelTableNameChange:

    def __init__(self, modeltablenamechange=None):
        self.com_object= modeltablenamechange

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def TableNameNew(self):
        return self.com_object.TableNameNew

    @property
    def tablenamenew(self):
        """Alias for TableNameNew"""
        return self.TableNameNew

    @property
    def table_name_new(self):
        """Alias for TableNameNew"""
        return self.TableNameNew

    @property
    def TableNameOld(self):
        return self.com_object.TableNameOld

    @property
    def tablenameold(self):
        """Alias for TableNameOld"""
        return self.TableNameOld

    @property
    def table_name_old(self):
        """Alias for TableNameOld"""
        return self.TableNameOld


class ModelTableNameChanges:

    def __init__(self, modeltablenamechanges=None):
        self.com_object= modeltablenamechanges

    def __call__(self, item):
        return ModelTableNameChange(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return ModelTableNameChange(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return MODELTABLENAMECHANGE(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ModelTableNames:

    def __init__(self, modeltablenames=None):
        self.com_object= modeltablenames

    def __call__(self, item):
        return ModelTableName(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ModelTables:

    def __init__(self, modeltables=None):
        self.com_object= modeltables

    def __call__(self, item):
        return ModelTable(self.com_object(item))

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return ModelTable(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return MODELTABLE(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ModuleView:

    def __init__(self, moduleview=None):
        self.com_object= moduleview

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Sheet(self):
        return self.com_object.Sheet

    @property
    def sheet(self):
        """Alias for Sheet"""
        return self.Sheet


class MultiThreadedCalculation:

    def __init__(self, multithreadedcalculation=None):
        self.com_object= multithreadedcalculation

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ThreadCount(self):
        return self.com_object.ThreadCount

    @property
    def threadcount(self):
        """Alias for ThreadCount"""
        return self.ThreadCount

    @property
    def thread_count(self):
        """Alias for ThreadCount"""
        return self.ThreadCount

    @property
    def ThreadMode(self):
        return XlThreadMode(self.com_object.ThreadMode)

    @ThreadMode.setter
    def ThreadMode(self, value):
        self.com_object.ThreadMode = value

    @property
    def threadmode(self):
        """Alias for ThreadMode"""
        return self.ThreadMode

    @threadmode.setter
    def threadmode(self, value):
        """Alias for ThreadMode.setter"""
        self.ThreadMode = value

    @property
    def thread_mode(self):
        """Alias for ThreadMode"""
        return self.ThreadMode

    @thread_mode.setter
    def thread_mode(self, value):
        """Alias for ThreadMode.setter"""
        self.ThreadMode = value


class Names:

    def __init__(self, names=None):
        self.com_object= names

    def __call__(self, item):
        return Name(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, RefersTo=None, Visible=None, MacroType=None, ShortcutKey=None, Category=None, NameLocal=None, RefersToLocal=None, CategoryLocal=None, RefersToR1C1=None, RefersToR1C1Local=None):
        arguments = com_arguments([unwrap(a) for a in [Name, RefersTo, Visible, MacroType, ShortcutKey, Category, NameLocal, RefersToLocal, CategoryLocal, RefersToR1C1, RefersToR1C1Local]])
        return Name(self.com_object.Add(*arguments))

    def add(self, Name=None, RefersTo=None, Visible=None, MacroType=None, ShortcutKey=None, Category=None, NameLocal=None, RefersToLocal=None, CategoryLocal=None, RefersToR1C1=None, RefersToR1C1Local=None):
        """Alias for Add"""
        arguments = [Name, RefersTo, Visible, MacroType, ShortcutKey, Category, NameLocal, RefersToLocal, CategoryLocal, RefersToR1C1, RefersToR1C1Local]
        return self.Add(*arguments)

    def Item(self, Index=None, IndexLocal=None, RefersTo=None):
        arguments = com_arguments([unwrap(a) for a in [Index, IndexLocal, RefersTo]])
        return Name(self.com_object.Item(*arguments))

    def item(self, Index=None, IndexLocal=None, RefersTo=None):
        """Alias for Item"""
        arguments = [Index, IndexLocal, RefersTo]
        return self.Item(*arguments)


class NegativeBarFormat:

    def __init__(self, negativebarformat=None):
        self.com_object= negativebarformat

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BorderColor(self):
        return FormatColor(self.com_object.BorderColor)

    @property
    def bordercolor(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @property
    def border_color(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @property
    def BorderColorType(self):
        return self.com_object.BorderColorType

    @BorderColorType.setter
    def BorderColorType(self, value):
        self.com_object.BorderColorType = value

    @property
    def bordercolortype(self):
        """Alias for BorderColorType"""
        return self.BorderColorType

    @bordercolortype.setter
    def bordercolortype(self, value):
        """Alias for BorderColorType.setter"""
        self.BorderColorType = value

    @property
    def border_color_type(self):
        """Alias for BorderColorType"""
        return self.BorderColorType

    @border_color_type.setter
    def border_color_type(self, value):
        """Alias for BorderColorType.setter"""
        self.BorderColorType = value

    @property
    def Color(self):
        return FormatColor(self.com_object.Color)

    @property
    def color(self):
        """Alias for Color"""
        return self.Color

    @property
    def ColorType(self):
        return self.com_object.ColorType

    @ColorType.setter
    def ColorType(self, value):
        self.com_object.ColorType = value

    @property
    def colortype(self):
        """Alias for ColorType"""
        return self.ColorType

    @colortype.setter
    def colortype(self, value):
        """Alias for ColorType.setter"""
        self.ColorType = value

    @property
    def color_type(self):
        """Alias for ColorType"""
        return self.ColorType

    @color_type.setter
    def color_type(self, value):
        """Alias for ColorType.setter"""
        self.ColorType = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class ODBCConnection:

    def __init__(self, odbcconnection=None):
        self.com_object= odbcconnection

    @property
    def AlwaysUseConnectionFile(self):
        return self.com_object.AlwaysUseConnectionFile

    @AlwaysUseConnectionFile.setter
    def AlwaysUseConnectionFile(self, value):
        self.com_object.AlwaysUseConnectionFile = value

    @property
    def alwaysuseconnectionfile(self):
        """Alias for AlwaysUseConnectionFile"""
        return self.AlwaysUseConnectionFile

    @alwaysuseconnectionfile.setter
    def alwaysuseconnectionfile(self, value):
        """Alias for AlwaysUseConnectionFile.setter"""
        self.AlwaysUseConnectionFile = value

    @property
    def always_use_connection_file(self):
        """Alias for AlwaysUseConnectionFile"""
        return self.AlwaysUseConnectionFile

    @always_use_connection_file.setter
    def always_use_connection_file(self, value):
        """Alias for AlwaysUseConnectionFile.setter"""
        self.AlwaysUseConnectionFile = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BackgroundQuery(self):
        return self.com_object.BackgroundQuery

    @BackgroundQuery.setter
    def BackgroundQuery(self, value):
        self.com_object.BackgroundQuery = value

    @property
    def backgroundquery(self):
        """Alias for BackgroundQuery"""
        return self.BackgroundQuery

    @backgroundquery.setter
    def backgroundquery(self, value):
        """Alias for BackgroundQuery.setter"""
        self.BackgroundQuery = value

    @property
    def background_query(self):
        """Alias for BackgroundQuery"""
        return self.BackgroundQuery

    @background_query.setter
    def background_query(self, value):
        """Alias for BackgroundQuery.setter"""
        self.BackgroundQuery = value

    @property
    def CommandText(self):
        return self.com_object.CommandText

    @CommandText.setter
    def CommandText(self, value):
        self.com_object.CommandText = value

    @property
    def commandtext(self):
        """Alias for CommandText"""
        return self.CommandText

    @commandtext.setter
    def commandtext(self, value):
        """Alias for CommandText.setter"""
        self.CommandText = value

    @property
    def command_text(self):
        """Alias for CommandText"""
        return self.CommandText

    @command_text.setter
    def command_text(self, value):
        """Alias for CommandText.setter"""
        self.CommandText = value

    @property
    def CommandType(self):
        return XlCmdType(self.com_object.CommandType)

    @CommandType.setter
    def CommandType(self, value):
        self.com_object.CommandType = value

    @property
    def commandtype(self):
        """Alias for CommandType"""
        return self.CommandType

    @commandtype.setter
    def commandtype(self, value):
        """Alias for CommandType.setter"""
        self.CommandType = value

    @property
    def command_type(self):
        """Alias for CommandType"""
        return self.CommandType

    @command_type.setter
    def command_type(self, value):
        """Alias for CommandType.setter"""
        self.CommandType = value

    @property
    def Connection(self):
        return self.com_object.Connection

    @Connection.setter
    def Connection(self, value):
        self.com_object.Connection = value

    @property
    def connection(self):
        """Alias for Connection"""
        return self.Connection

    @connection.setter
    def connection(self, value):
        """Alias for Connection.setter"""
        self.Connection = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def EnableRefresh(self):
        return self.com_object.EnableRefresh

    @EnableRefresh.setter
    def EnableRefresh(self, value):
        self.com_object.EnableRefresh = value

    @property
    def enablerefresh(self):
        """Alias for EnableRefresh"""
        return self.EnableRefresh

    @enablerefresh.setter
    def enablerefresh(self, value):
        """Alias for EnableRefresh.setter"""
        self.EnableRefresh = value

    @property
    def enable_refresh(self):
        """Alias for EnableRefresh"""
        return self.EnableRefresh

    @enable_refresh.setter
    def enable_refresh(self, value):
        """Alias for EnableRefresh.setter"""
        self.EnableRefresh = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RefreshDate(self):
        return self.com_object.RefreshDate

    @property
    def refreshdate(self):
        """Alias for RefreshDate"""
        return self.RefreshDate

    @property
    def refresh_date(self):
        """Alias for RefreshDate"""
        return self.RefreshDate

    @property
    def Refreshing(self):
        return self.com_object.Refreshing

    @Refreshing.setter
    def Refreshing(self, value):
        self.com_object.Refreshing = value

    @property
    def refreshing(self):
        """Alias for Refreshing"""
        return self.Refreshing

    @refreshing.setter
    def refreshing(self, value):
        """Alias for Refreshing.setter"""
        self.Refreshing = value

    @property
    def RefreshOnFileOpen(self):
        return self.com_object.RefreshOnFileOpen

    @RefreshOnFileOpen.setter
    def RefreshOnFileOpen(self, value):
        self.com_object.RefreshOnFileOpen = value

    @property
    def refreshonfileopen(self):
        """Alias for RefreshOnFileOpen"""
        return self.RefreshOnFileOpen

    @refreshonfileopen.setter
    def refreshonfileopen(self, value):
        """Alias for RefreshOnFileOpen.setter"""
        self.RefreshOnFileOpen = value

    @property
    def refresh_on_file_open(self):
        """Alias for RefreshOnFileOpen"""
        return self.RefreshOnFileOpen

    @refresh_on_file_open.setter
    def refresh_on_file_open(self, value):
        """Alias for RefreshOnFileOpen.setter"""
        self.RefreshOnFileOpen = value

    @property
    def RefreshPeriod(self):
        return self.com_object.RefreshPeriod

    @RefreshPeriod.setter
    def RefreshPeriod(self, value):
        self.com_object.RefreshPeriod = value

    @property
    def refreshperiod(self):
        """Alias for RefreshPeriod"""
        return self.RefreshPeriod

    @refreshperiod.setter
    def refreshperiod(self, value):
        """Alias for RefreshPeriod.setter"""
        self.RefreshPeriod = value

    @property
    def refresh_period(self):
        """Alias for RefreshPeriod"""
        return self.RefreshPeriod

    @refresh_period.setter
    def refresh_period(self, value):
        """Alias for RefreshPeriod.setter"""
        self.RefreshPeriod = value

    @property
    def RobustConnect(self):
        return XlRobustConnect(self.com_object.RobustConnect)

    @RobustConnect.setter
    def RobustConnect(self, value):
        self.com_object.RobustConnect = value

    @property
    def robustconnect(self):
        """Alias for RobustConnect"""
        return self.RobustConnect

    @robustconnect.setter
    def robustconnect(self, value):
        """Alias for RobustConnect.setter"""
        self.RobustConnect = value

    @property
    def robust_connect(self):
        """Alias for RobustConnect"""
        return self.RobustConnect

    @robust_connect.setter
    def robust_connect(self, value):
        """Alias for RobustConnect.setter"""
        self.RobustConnect = value

    @property
    def SavePassword(self):
        return self.com_object.SavePassword

    @SavePassword.setter
    def SavePassword(self, value):
        self.com_object.SavePassword = value

    @property
    def savepassword(self):
        """Alias for SavePassword"""
        return self.SavePassword

    @savepassword.setter
    def savepassword(self, value):
        """Alias for SavePassword.setter"""
        self.SavePassword = value

    @property
    def save_password(self):
        """Alias for SavePassword"""
        return self.SavePassword

    @save_password.setter
    def save_password(self, value):
        """Alias for SavePassword.setter"""
        self.SavePassword = value

    @property
    def ServerCredentialsMethod(self):
        return XlCredentialsMethod(self.com_object.ServerCredentialsMethod)

    @ServerCredentialsMethod.setter
    def ServerCredentialsMethod(self, value):
        self.com_object.ServerCredentialsMethod = value

    @property
    def servercredentialsmethod(self):
        """Alias for ServerCredentialsMethod"""
        return self.ServerCredentialsMethod

    @servercredentialsmethod.setter
    def servercredentialsmethod(self, value):
        """Alias for ServerCredentialsMethod.setter"""
        self.ServerCredentialsMethod = value

    @property
    def server_credentials_method(self):
        """Alias for ServerCredentialsMethod"""
        return self.ServerCredentialsMethod

    @server_credentials_method.setter
    def server_credentials_method(self, value):
        """Alias for ServerCredentialsMethod.setter"""
        self.ServerCredentialsMethod = value

    @property
    def ServerSSOApplicationID(self):
        return self.com_object.ServerSSOApplicationID

    @ServerSSOApplicationID.setter
    def ServerSSOApplicationID(self, value):
        self.com_object.ServerSSOApplicationID = value

    @property
    def serverssoapplicationid(self):
        """Alias for ServerSSOApplicationID"""
        return self.ServerSSOApplicationID

    @serverssoapplicationid.setter
    def serverssoapplicationid(self, value):
        """Alias for ServerSSOApplicationID.setter"""
        self.ServerSSOApplicationID = value

    @property
    def server_s_s_o_application_i_d(self):
        """Alias for ServerSSOApplicationID"""
        return self.ServerSSOApplicationID

    @server_s_s_o_application_i_d.setter
    def server_s_s_o_application_i_d(self, value):
        """Alias for ServerSSOApplicationID.setter"""
        self.ServerSSOApplicationID = value

    @property
    def SourceConnectionFile(self):
        return self.com_object.SourceConnectionFile

    @SourceConnectionFile.setter
    def SourceConnectionFile(self, value):
        self.com_object.SourceConnectionFile = value

    @property
    def sourceconnectionfile(self):
        """Alias for SourceConnectionFile"""
        return self.SourceConnectionFile

    @sourceconnectionfile.setter
    def sourceconnectionfile(self, value):
        """Alias for SourceConnectionFile.setter"""
        self.SourceConnectionFile = value

    @property
    def source_connection_file(self):
        """Alias for SourceConnectionFile"""
        return self.SourceConnectionFile

    @source_connection_file.setter
    def source_connection_file(self, value):
        """Alias for SourceConnectionFile.setter"""
        self.SourceConnectionFile = value

    @property
    def SourceData(self):
        return self.com_object.SourceData

    @SourceData.setter
    def SourceData(self, value):
        self.com_object.SourceData = value

    @property
    def sourcedata(self):
        """Alias for SourceData"""
        return self.SourceData

    @sourcedata.setter
    def sourcedata(self, value):
        """Alias for SourceData.setter"""
        self.SourceData = value

    @property
    def source_data(self):
        """Alias for SourceData"""
        return self.SourceData

    @source_data.setter
    def source_data(self, value):
        """Alias for SourceData.setter"""
        self.SourceData = value

    @property
    def SourceDataFile(self):
        return self.com_object.SourceDataFile

    @SourceDataFile.setter
    def SourceDataFile(self, value):
        self.com_object.SourceDataFile = value

    @property
    def sourcedatafile(self):
        """Alias for SourceDataFile"""
        return self.SourceDataFile

    @sourcedatafile.setter
    def sourcedatafile(self, value):
        """Alias for SourceDataFile.setter"""
        self.SourceDataFile = value

    @property
    def source_data_file(self):
        """Alias for SourceDataFile"""
        return self.SourceDataFile

    @source_data_file.setter
    def source_data_file(self, value):
        """Alias for SourceDataFile.setter"""
        self.SourceDataFile = value

    def CancelRefresh(self):
        self.com_object.CancelRefresh()

    def cancelrefresh(self):
        """Alias for CancelRefresh"""
        return self.CancelRefresh()

    def cancel_refresh(self):
        """Alias for CancelRefresh"""
        return self.CancelRefresh()

    def Refresh(self):
        self.com_object.Refresh()

    def refresh(self):
        """Alias for Refresh"""
        return self.Refresh()

    def SaveAsODC(self, ODCFileName=None, Description=None, Keywords=None):
        arguments = com_arguments([unwrap(a) for a in [ODCFileName, Description, Keywords]])
        return self.com_object.SaveAsODC(*arguments)

    def saveasodc(self, ODCFileName=None, Description=None, Keywords=None):
        """Alias for SaveAsODC"""
        arguments = [ODCFileName, Description, Keywords]
        return self.SaveAsODC(*arguments)

    def save_as_o_d_c(self, ODCFileName=None, Description=None, Keywords=None):
        """Alias for SaveAsODC"""
        arguments = [ODCFileName, Description, Keywords]
        return self.SaveAsODC(*arguments)


class ODBCError:

    def __init__(self, odbcerror=None):
        self.com_object= odbcerror

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ErrorString(self):
        return self.com_object.ErrorString

    @property
    def errorstring(self):
        """Alias for ErrorString"""
        return self.ErrorString

    @property
    def error_string(self):
        """Alias for ErrorString"""
        return self.ErrorString

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SqlState(self):
        return self.com_object.SqlState

    @property
    def sqlstate(self):
        """Alias for SqlState"""
        return self.SqlState

    @property
    def sql_state(self):
        """Alias for SqlState"""
        return self.SqlState


class ODBCErrors:

    def __init__(self, odbcerrors=None):
        self.com_object= odbcerrors

    def __call__(self, item):
        return ODBCError(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ODBCError(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class OLEDBConnection:

    def __init__(self, oledbconnection=None):
        self.com_object= oledbconnection

    @property
    def ADOConnection(self):
        return self.com_object.ADOConnection

    @property
    def adoconnection(self):
        """Alias for ADOConnection"""
        return self.ADOConnection

    @property
    def a_d_o_connection(self):
        """Alias for ADOConnection"""
        return self.ADOConnection

    @property
    def AlwaysUseConnectionFile(self):
        return self.com_object.AlwaysUseConnectionFile

    @AlwaysUseConnectionFile.setter
    def AlwaysUseConnectionFile(self, value):
        self.com_object.AlwaysUseConnectionFile = value

    @property
    def alwaysuseconnectionfile(self):
        """Alias for AlwaysUseConnectionFile"""
        return self.AlwaysUseConnectionFile

    @alwaysuseconnectionfile.setter
    def alwaysuseconnectionfile(self, value):
        """Alias for AlwaysUseConnectionFile.setter"""
        self.AlwaysUseConnectionFile = value

    @property
    def always_use_connection_file(self):
        """Alias for AlwaysUseConnectionFile"""
        return self.AlwaysUseConnectionFile

    @always_use_connection_file.setter
    def always_use_connection_file(self, value):
        """Alias for AlwaysUseConnectionFile.setter"""
        self.AlwaysUseConnectionFile = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BackgroundQuery(self):
        return self.com_object.BackgroundQuery

    @BackgroundQuery.setter
    def BackgroundQuery(self, value):
        self.com_object.BackgroundQuery = value

    @property
    def backgroundquery(self):
        """Alias for BackgroundQuery"""
        return self.BackgroundQuery

    @backgroundquery.setter
    def backgroundquery(self, value):
        """Alias for BackgroundQuery.setter"""
        self.BackgroundQuery = value

    @property
    def background_query(self):
        """Alias for BackgroundQuery"""
        return self.BackgroundQuery

    @background_query.setter
    def background_query(self, value):
        """Alias for BackgroundQuery.setter"""
        self.BackgroundQuery = value

    @property
    def CalculatedMembers(self):
        return CalculatedMembers(self.com_object.CalculatedMembers)

    @property
    def calculatedmembers(self):
        """Alias for CalculatedMembers"""
        return self.CalculatedMembers

    @property
    def calculated_members(self):
        """Alias for CalculatedMembers"""
        return self.CalculatedMembers

    @property
    def CommandText(self):
        return self.com_object.CommandText

    @CommandText.setter
    def CommandText(self, value):
        self.com_object.CommandText = value

    @property
    def commandtext(self):
        """Alias for CommandText"""
        return self.CommandText

    @commandtext.setter
    def commandtext(self, value):
        """Alias for CommandText.setter"""
        self.CommandText = value

    @property
    def command_text(self):
        """Alias for CommandText"""
        return self.CommandText

    @command_text.setter
    def command_text(self, value):
        """Alias for CommandText.setter"""
        self.CommandText = value

    @property
    def CommandType(self):
        return XlCmdType(self.com_object.CommandType)

    @CommandType.setter
    def CommandType(self, value):
        self.com_object.CommandType = value

    @property
    def commandtype(self):
        """Alias for CommandType"""
        return self.CommandType

    @commandtype.setter
    def commandtype(self, value):
        """Alias for CommandType.setter"""
        self.CommandType = value

    @property
    def command_type(self):
        """Alias for CommandType"""
        return self.CommandType

    @command_type.setter
    def command_type(self, value):
        """Alias for CommandType.setter"""
        self.CommandType = value

    @property
    def Connection(self):
        return self.com_object.Connection

    @Connection.setter
    def Connection(self, value):
        self.com_object.Connection = value

    @property
    def connection(self):
        """Alias for Connection"""
        return self.Connection

    @connection.setter
    def connection(self, value):
        """Alias for Connection.setter"""
        self.Connection = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def EnableRefresh(self):
        return self.com_object.EnableRefresh

    @EnableRefresh.setter
    def EnableRefresh(self, value):
        self.com_object.EnableRefresh = value

    @property
    def enablerefresh(self):
        """Alias for EnableRefresh"""
        return self.EnableRefresh

    @enablerefresh.setter
    def enablerefresh(self, value):
        """Alias for EnableRefresh.setter"""
        self.EnableRefresh = value

    @property
    def enable_refresh(self):
        """Alias for EnableRefresh"""
        return self.EnableRefresh

    @enable_refresh.setter
    def enable_refresh(self, value):
        """Alias for EnableRefresh.setter"""
        self.EnableRefresh = value

    @property
    def IsConnected(self):
        return self.com_object.IsConnected

    @property
    def isconnected(self):
        """Alias for IsConnected"""
        return self.IsConnected

    @property
    def is_connected(self):
        """Alias for IsConnected"""
        return self.IsConnected

    @property
    def LocalConnection(self):
        return self.com_object.LocalConnection

    @LocalConnection.setter
    def LocalConnection(self, value):
        self.com_object.LocalConnection = value

    @property
    def localconnection(self):
        """Alias for LocalConnection"""
        return self.LocalConnection

    @localconnection.setter
    def localconnection(self, value):
        """Alias for LocalConnection.setter"""
        self.LocalConnection = value

    @property
    def local_connection(self):
        """Alias for LocalConnection"""
        return self.LocalConnection

    @local_connection.setter
    def local_connection(self, value):
        """Alias for LocalConnection.setter"""
        self.LocalConnection = value

    @property
    def LocaleID(self):
        return self.com_object.LocaleID

    @LocaleID.setter
    def LocaleID(self, value):
        self.com_object.LocaleID = value

    @property
    def localeid(self):
        """Alias for LocaleID"""
        return self.LocaleID

    @localeid.setter
    def localeid(self, value):
        """Alias for LocaleID.setter"""
        self.LocaleID = value

    @property
    def locale_i_d(self):
        """Alias for LocaleID"""
        return self.LocaleID

    @locale_i_d.setter
    def locale_i_d(self, value):
        """Alias for LocaleID.setter"""
        self.LocaleID = value

    @property
    def MaintainConnection(self):
        return self.com_object.MaintainConnection

    @MaintainConnection.setter
    def MaintainConnection(self, value):
        self.com_object.MaintainConnection = value

    @property
    def maintainconnection(self):
        """Alias for MaintainConnection"""
        return self.MaintainConnection

    @maintainconnection.setter
    def maintainconnection(self, value):
        """Alias for MaintainConnection.setter"""
        self.MaintainConnection = value

    @property
    def maintain_connection(self):
        """Alias for MaintainConnection"""
        return self.MaintainConnection

    @maintain_connection.setter
    def maintain_connection(self, value):
        """Alias for MaintainConnection.setter"""
        self.MaintainConnection = value

    @property
    def MaxDrillthroughRecords(self):
        return self.com_object.MaxDrillthroughRecords

    @MaxDrillthroughRecords.setter
    def MaxDrillthroughRecords(self, value):
        self.com_object.MaxDrillthroughRecords = value

    @property
    def maxdrillthroughrecords(self):
        """Alias for MaxDrillthroughRecords"""
        return self.MaxDrillthroughRecords

    @maxdrillthroughrecords.setter
    def maxdrillthroughrecords(self, value):
        """Alias for MaxDrillthroughRecords.setter"""
        self.MaxDrillthroughRecords = value

    @property
    def max_drillthrough_records(self):
        """Alias for MaxDrillthroughRecords"""
        return self.MaxDrillthroughRecords

    @max_drillthrough_records.setter
    def max_drillthrough_records(self, value):
        """Alias for MaxDrillthroughRecords.setter"""
        self.MaxDrillthroughRecords = value

    @property
    def OLAP(self):
        return self.com_object.OLAP

    @property
    def olap(self):
        """Alias for OLAP"""
        return self.OLAP

    @property
    def o_l_a_p(self):
        """Alias for OLAP"""
        return self.OLAP

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RefreshDate(self):
        return self.com_object.RefreshDate

    @property
    def refreshdate(self):
        """Alias for RefreshDate"""
        return self.RefreshDate

    @property
    def refresh_date(self):
        """Alias for RefreshDate"""
        return self.RefreshDate

    @property
    def Refreshing(self):
        return self.com_object.Refreshing

    @Refreshing.setter
    def Refreshing(self, value):
        self.com_object.Refreshing = value

    @property
    def refreshing(self):
        """Alias for Refreshing"""
        return self.Refreshing

    @refreshing.setter
    def refreshing(self, value):
        """Alias for Refreshing.setter"""
        self.Refreshing = value

    @property
    def RefreshOnFileOpen(self):
        return self.com_object.RefreshOnFileOpen

    @RefreshOnFileOpen.setter
    def RefreshOnFileOpen(self, value):
        self.com_object.RefreshOnFileOpen = value

    @property
    def refreshonfileopen(self):
        """Alias for RefreshOnFileOpen"""
        return self.RefreshOnFileOpen

    @refreshonfileopen.setter
    def refreshonfileopen(self, value):
        """Alias for RefreshOnFileOpen.setter"""
        self.RefreshOnFileOpen = value

    @property
    def refresh_on_file_open(self):
        """Alias for RefreshOnFileOpen"""
        return self.RefreshOnFileOpen

    @refresh_on_file_open.setter
    def refresh_on_file_open(self, value):
        """Alias for RefreshOnFileOpen.setter"""
        self.RefreshOnFileOpen = value

    @property
    def RefreshPeriod(self):
        return self.com_object.RefreshPeriod

    @RefreshPeriod.setter
    def RefreshPeriod(self, value):
        self.com_object.RefreshPeriod = value

    @property
    def refreshperiod(self):
        """Alias for RefreshPeriod"""
        return self.RefreshPeriod

    @refreshperiod.setter
    def refreshperiod(self, value):
        """Alias for RefreshPeriod.setter"""
        self.RefreshPeriod = value

    @property
    def refresh_period(self):
        """Alias for RefreshPeriod"""
        return self.RefreshPeriod

    @refresh_period.setter
    def refresh_period(self, value):
        """Alias for RefreshPeriod.setter"""
        self.RefreshPeriod = value

    @property
    def RetrieveInOfficeUILang(self):
        return self.com_object.RetrieveInOfficeUILang

    @RetrieveInOfficeUILang.setter
    def RetrieveInOfficeUILang(self, value):
        self.com_object.RetrieveInOfficeUILang = value

    @property
    def retrieveinofficeuilang(self):
        """Alias for RetrieveInOfficeUILang"""
        return self.RetrieveInOfficeUILang

    @retrieveinofficeuilang.setter
    def retrieveinofficeuilang(self, value):
        """Alias for RetrieveInOfficeUILang.setter"""
        self.RetrieveInOfficeUILang = value

    @property
    def retrieve_in_office_u_i_lang(self):
        """Alias for RetrieveInOfficeUILang"""
        return self.RetrieveInOfficeUILang

    @retrieve_in_office_u_i_lang.setter
    def retrieve_in_office_u_i_lang(self, value):
        """Alias for RetrieveInOfficeUILang.setter"""
        self.RetrieveInOfficeUILang = value

    @property
    def RobustConnect(self):
        return XlRobustConnect(self.com_object.RobustConnect)

    @RobustConnect.setter
    def RobustConnect(self, value):
        self.com_object.RobustConnect = value

    @property
    def robustconnect(self):
        """Alias for RobustConnect"""
        return self.RobustConnect

    @robustconnect.setter
    def robustconnect(self, value):
        """Alias for RobustConnect.setter"""
        self.RobustConnect = value

    @property
    def robust_connect(self):
        """Alias for RobustConnect"""
        return self.RobustConnect

    @robust_connect.setter
    def robust_connect(self, value):
        """Alias for RobustConnect.setter"""
        self.RobustConnect = value

    @property
    def SavePassword(self):
        return self.com_object.SavePassword

    @SavePassword.setter
    def SavePassword(self, value):
        self.com_object.SavePassword = value

    @property
    def savepassword(self):
        """Alias for SavePassword"""
        return self.SavePassword

    @savepassword.setter
    def savepassword(self, value):
        """Alias for SavePassword.setter"""
        self.SavePassword = value

    @property
    def save_password(self):
        """Alias for SavePassword"""
        return self.SavePassword

    @save_password.setter
    def save_password(self, value):
        """Alias for SavePassword.setter"""
        self.SavePassword = value

    @property
    def ServerCredentialsMethod(self):
        return XlCredentialsMethod(self.com_object.ServerCredentialsMethod)

    @ServerCredentialsMethod.setter
    def ServerCredentialsMethod(self, value):
        self.com_object.ServerCredentialsMethod = value

    @property
    def servercredentialsmethod(self):
        """Alias for ServerCredentialsMethod"""
        return self.ServerCredentialsMethod

    @servercredentialsmethod.setter
    def servercredentialsmethod(self, value):
        """Alias for ServerCredentialsMethod.setter"""
        self.ServerCredentialsMethod = value

    @property
    def server_credentials_method(self):
        """Alias for ServerCredentialsMethod"""
        return self.ServerCredentialsMethod

    @server_credentials_method.setter
    def server_credentials_method(self, value):
        """Alias for ServerCredentialsMethod.setter"""
        self.ServerCredentialsMethod = value

    @property
    def ServerFillColor(self):
        return self.com_object.ServerFillColor

    @ServerFillColor.setter
    def ServerFillColor(self, value):
        self.com_object.ServerFillColor = value

    @property
    def serverfillcolor(self):
        """Alias for ServerFillColor"""
        return self.ServerFillColor

    @serverfillcolor.setter
    def serverfillcolor(self, value):
        """Alias for ServerFillColor.setter"""
        self.ServerFillColor = value

    @property
    def server_fill_color(self):
        """Alias for ServerFillColor"""
        return self.ServerFillColor

    @server_fill_color.setter
    def server_fill_color(self, value):
        """Alias for ServerFillColor.setter"""
        self.ServerFillColor = value

    @property
    def ServerFontStyle(self):
        return self.com_object.ServerFontStyle

    @ServerFontStyle.setter
    def ServerFontStyle(self, value):
        self.com_object.ServerFontStyle = value

    @property
    def serverfontstyle(self):
        """Alias for ServerFontStyle"""
        return self.ServerFontStyle

    @serverfontstyle.setter
    def serverfontstyle(self, value):
        """Alias for ServerFontStyle.setter"""
        self.ServerFontStyle = value

    @property
    def server_font_style(self):
        """Alias for ServerFontStyle"""
        return self.ServerFontStyle

    @server_font_style.setter
    def server_font_style(self, value):
        """Alias for ServerFontStyle.setter"""
        self.ServerFontStyle = value

    @property
    def ServerNumberFormat(self):
        return self.com_object.ServerNumberFormat

    @ServerNumberFormat.setter
    def ServerNumberFormat(self, value):
        self.com_object.ServerNumberFormat = value

    @property
    def servernumberformat(self):
        """Alias for ServerNumberFormat"""
        return self.ServerNumberFormat

    @servernumberformat.setter
    def servernumberformat(self, value):
        """Alias for ServerNumberFormat.setter"""
        self.ServerNumberFormat = value

    @property
    def server_number_format(self):
        """Alias for ServerNumberFormat"""
        return self.ServerNumberFormat

    @server_number_format.setter
    def server_number_format(self, value):
        """Alias for ServerNumberFormat.setter"""
        self.ServerNumberFormat = value

    @property
    def ServerSSOApplicationID(self):
        return self.com_object.ServerSSOApplicationID

    @ServerSSOApplicationID.setter
    def ServerSSOApplicationID(self, value):
        self.com_object.ServerSSOApplicationID = value

    @property
    def serverssoapplicationid(self):
        """Alias for ServerSSOApplicationID"""
        return self.ServerSSOApplicationID

    @serverssoapplicationid.setter
    def serverssoapplicationid(self, value):
        """Alias for ServerSSOApplicationID.setter"""
        self.ServerSSOApplicationID = value

    @property
    def server_s_s_o_application_i_d(self):
        """Alias for ServerSSOApplicationID"""
        return self.ServerSSOApplicationID

    @server_s_s_o_application_i_d.setter
    def server_s_s_o_application_i_d(self, value):
        """Alias for ServerSSOApplicationID.setter"""
        self.ServerSSOApplicationID = value

    @property
    def ServerTextColor(self):
        return self.com_object.ServerTextColor

    @ServerTextColor.setter
    def ServerTextColor(self, value):
        self.com_object.ServerTextColor = value

    @property
    def servertextcolor(self):
        """Alias for ServerTextColor"""
        return self.ServerTextColor

    @servertextcolor.setter
    def servertextcolor(self, value):
        """Alias for ServerTextColor.setter"""
        self.ServerTextColor = value

    @property
    def server_text_color(self):
        """Alias for ServerTextColor"""
        return self.ServerTextColor

    @server_text_color.setter
    def server_text_color(self, value):
        """Alias for ServerTextColor.setter"""
        self.ServerTextColor = value

    @property
    def SourceConnectionFile(self):
        return self.com_object.SourceConnectionFile

    @SourceConnectionFile.setter
    def SourceConnectionFile(self, value):
        self.com_object.SourceConnectionFile = value

    @property
    def sourceconnectionfile(self):
        """Alias for SourceConnectionFile"""
        return self.SourceConnectionFile

    @sourceconnectionfile.setter
    def sourceconnectionfile(self, value):
        """Alias for SourceConnectionFile.setter"""
        self.SourceConnectionFile = value

    @property
    def source_connection_file(self):
        """Alias for SourceConnectionFile"""
        return self.SourceConnectionFile

    @source_connection_file.setter
    def source_connection_file(self, value):
        """Alias for SourceConnectionFile.setter"""
        self.SourceConnectionFile = value

    @property
    def SourceDataFile(self):
        return self.com_object.SourceDataFile

    @SourceDataFile.setter
    def SourceDataFile(self, value):
        self.com_object.SourceDataFile = value

    @property
    def sourcedatafile(self):
        """Alias for SourceDataFile"""
        return self.SourceDataFile

    @sourcedatafile.setter
    def sourcedatafile(self, value):
        """Alias for SourceDataFile.setter"""
        self.SourceDataFile = value

    @property
    def source_data_file(self):
        """Alias for SourceDataFile"""
        return self.SourceDataFile

    @source_data_file.setter
    def source_data_file(self, value):
        """Alias for SourceDataFile.setter"""
        self.SourceDataFile = value

    @property
    def UseLocalConnection(self):
        return self.com_object.UseLocalConnection

    @UseLocalConnection.setter
    def UseLocalConnection(self, value):
        self.com_object.UseLocalConnection = value

    @property
    def uselocalconnection(self):
        """Alias for UseLocalConnection"""
        return self.UseLocalConnection

    @uselocalconnection.setter
    def uselocalconnection(self, value):
        """Alias for UseLocalConnection.setter"""
        self.UseLocalConnection = value

    @property
    def use_local_connection(self):
        """Alias for UseLocalConnection"""
        return self.UseLocalConnection

    @use_local_connection.setter
    def use_local_connection(self, value):
        """Alias for UseLocalConnection.setter"""
        self.UseLocalConnection = value

    def CancelRefresh(self):
        self.com_object.CancelRefresh()

    def cancelrefresh(self):
        """Alias for CancelRefresh"""
        return self.CancelRefresh()

    def cancel_refresh(self):
        """Alias for CancelRefresh"""
        return self.CancelRefresh()

    def MakeConnection(self):
        return self.com_object.MakeConnection()

    def makeconnection(self):
        """Alias for MakeConnection"""
        return self.MakeConnection()

    def make_connection(self):
        """Alias for MakeConnection"""
        return self.MakeConnection()

    def Reconnect(self):
        self.com_object.Reconnect()

    def reconnect(self):
        """Alias for Reconnect"""
        return self.Reconnect()

    def Refresh(self):
        self.com_object.Refresh()

    def refresh(self):
        """Alias for Refresh"""
        return self.Refresh()

    def SaveAsODC(self, ODCFileName=None, Description=None, Keywords=None):
        arguments = com_arguments([unwrap(a) for a in [ODCFileName, Description, Keywords]])
        self.com_object.SaveAsODC(*arguments)

    def saveasodc(self, ODCFileName=None, Description=None, Keywords=None):
        """Alias for SaveAsODC"""
        arguments = [ODCFileName, Description, Keywords]
        return self.SaveAsODC(*arguments)

    def save_as_o_d_c(self, ODCFileName=None, Description=None, Keywords=None):
        """Alias for SaveAsODC"""
        arguments = [ODCFileName, Description, Keywords]
        return self.SaveAsODC(*arguments)


class OLEDBError:

    def __init__(self, oledberror=None):
        self.com_object= oledberror

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ErrorString(self):
        return self.com_object.ErrorString

    @property
    def errorstring(self):
        """Alias for ErrorString"""
        return self.ErrorString

    @property
    def error_string(self):
        """Alias for ErrorString"""
        return self.ErrorString

    @property
    def Native(self):
        return self.com_object.Native

    @property
    def native(self):
        """Alias for Native"""
        return self.Native

    @property
    def Number(self):
        return self.com_object.Number

    @property
    def number(self):
        """Alias for Number"""
        return self.Number

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SqlState(self):
        return self.com_object.SqlState

    @property
    def sqlstate(self):
        """Alias for SqlState"""
        return self.SqlState

    @property
    def sql_state(self):
        """Alias for SqlState"""
        return self.SqlState

    @property
    def Stage(self):
        return self.com_object.Stage

    @property
    def stage(self):
        """Alias for Stage"""
        return self.Stage


class OLEDBErrors:

    def __init__(self, oledberrors=None):
        self.com_object= oledberrors

    def __call__(self, item):
        return OLEDBError(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return OLEDBError(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class OLEFormat:

    def __init__(self, oleformat=None):
        self.com_object= oleformat

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Object(self):
        return self.com_object.Object

    @property
    def object(self):
        """Alias for Object"""
        return self.Object

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def progID(self):
        return self.com_object.progID

    @property
    def progid(self):
        """Alias for progID"""
        return self.progID

    @property
    def prog_i_d(self):
        """Alias for progID"""
        return self.progID

    def Activate(self):
        self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()

    def Verb(self, Verb=None):
        arguments = com_arguments([unwrap(a) for a in [Verb]])
        self.com_object.Verb(*arguments)

    def verb(self, Verb=None):
        """Alias for Verb"""
        arguments = [Verb]
        return self.Verb(*arguments)


class OLEObject:

    def __init__(self, oleobject=None):
        self.com_object= oleobject

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoLoad(self):
        return self.com_object.AutoLoad

    @AutoLoad.setter
    def AutoLoad(self, value):
        self.com_object.AutoLoad = value

    @property
    def autoload(self):
        """Alias for AutoLoad"""
        return self.AutoLoad

    @autoload.setter
    def autoload(self, value):
        """Alias for AutoLoad.setter"""
        self.AutoLoad = value

    @property
    def auto_load(self):
        """Alias for AutoLoad"""
        return self.AutoLoad

    @auto_load.setter
    def auto_load(self, value):
        """Alias for AutoLoad.setter"""
        self.AutoLoad = value

    @property
    def AutoUpdate(self):
        return self.com_object.AutoUpdate

    @property
    def autoupdate(self):
        """Alias for AutoUpdate"""
        return self.AutoUpdate

    @property
    def auto_update(self):
        """Alias for AutoUpdate"""
        return self.AutoUpdate

    @property
    def Border(self):
        return Border(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def BottomRightCell(self):
        return Range(self.com_object.BottomRightCell)

    @property
    def bottomrightcell(self):
        """Alias for BottomRightCell"""
        return self.BottomRightCell

    @property
    def bottom_right_cell(self):
        """Alias for BottomRightCell"""
        return self.BottomRightCell

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Interior(self):
        return Interior(self.com_object.Interior)

    @property
    def interior(self):
        """Alias for Interior"""
        return self.Interior

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def LinkedCell(self):
        return self.com_object.LinkedCell

    @LinkedCell.setter
    def LinkedCell(self, value):
        self.com_object.LinkedCell = value

    @property
    def linkedcell(self):
        """Alias for LinkedCell"""
        return self.LinkedCell

    @linkedcell.setter
    def linkedcell(self, value):
        """Alias for LinkedCell.setter"""
        self.LinkedCell = value

    @property
    def linked_cell(self):
        """Alias for LinkedCell"""
        return self.LinkedCell

    @linked_cell.setter
    def linked_cell(self, value):
        """Alias for LinkedCell.setter"""
        self.LinkedCell = value

    @property
    def ListFillRange(self):
        return self.com_object.ListFillRange

    @ListFillRange.setter
    def ListFillRange(self, value):
        self.com_object.ListFillRange = value

    @property
    def listfillrange(self):
        """Alias for ListFillRange"""
        return self.ListFillRange

    @listfillrange.setter
    def listfillrange(self, value):
        """Alias for ListFillRange.setter"""
        self.ListFillRange = value

    @property
    def list_fill_range(self):
        """Alias for ListFillRange"""
        return self.ListFillRange

    @list_fill_range.setter
    def list_fill_range(self, value):
        """Alias for ListFillRange.setter"""
        self.ListFillRange = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Object(self):
        return self.com_object.Object

    @property
    def object(self):
        """Alias for Object"""
        return self.Object

    @property
    def OLEType(self):
        return XlOLEType(self.com_object.OLEType)

    @property
    def oletype(self):
        """Alias for OLEType"""
        return self.OLEType

    @property
    def o_l_e_type(self):
        """Alias for OLEType"""
        return self.OLEType

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Placement(self):
        return XlPlacement(self.com_object.Placement)

    @Placement.setter
    def Placement(self, value):
        self.com_object.Placement = value

    @property
    def placement(self):
        """Alias for Placement"""
        return self.Placement

    @placement.setter
    def placement(self, value):
        """Alias for Placement.setter"""
        self.Placement = value

    @property
    def PrintObject(self):
        return self.com_object.PrintObject

    @PrintObject.setter
    def PrintObject(self, value):
        self.com_object.PrintObject = value

    @property
    def printobject(self):
        """Alias for PrintObject"""
        return self.PrintObject

    @printobject.setter
    def printobject(self, value):
        """Alias for PrintObject.setter"""
        self.PrintObject = value

    @property
    def print_object(self):
        """Alias for PrintObject"""
        return self.PrintObject

    @print_object.setter
    def print_object(self, value):
        """Alias for PrintObject.setter"""
        self.PrintObject = value

    @property
    def progID(self):
        return self.com_object.progID

    @property
    def progid(self):
        """Alias for progID"""
        return self.progID

    @property
    def prog_i_d(self):
        """Alias for progID"""
        return self.progID

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def ShapeRange(self):
        return ShapeRange(self.com_object.ShapeRange)

    @property
    def shaperange(self):
        """Alias for ShapeRange"""
        return self.ShapeRange

    @property
    def shape_range(self):
        """Alias for ShapeRange"""
        return self.ShapeRange

    @property
    def SourceName(self):
        return self.com_object.SourceName

    @SourceName.setter
    def SourceName(self, value):
        self.com_object.SourceName = value

    @property
    def sourcename(self):
        """Alias for SourceName"""
        return self.SourceName

    @sourcename.setter
    def sourcename(self, value):
        """Alias for SourceName.setter"""
        self.SourceName = value

    @property
    def source_name(self):
        """Alias for SourceName"""
        return self.SourceName

    @source_name.setter
    def source_name(self, value):
        """Alias for SourceName.setter"""
        self.SourceName = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TopLeftCell(self):
        return Range(self.com_object.TopLeftCell)

    @property
    def topleftcell(self):
        """Alias for TopLeftCell"""
        return self.TopLeftCell

    @property
    def top_left_cell(self):
        """Alias for TopLeftCell"""
        return self.TopLeftCell

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def ZOrder(self):
        return self.com_object.ZOrder

    @property
    def zorder(self):
        """Alias for ZOrder"""
        return self.ZOrder

    @property
    def z_order(self):
        """Alias for ZOrder"""
        return self.ZOrder

    def Activate(self):
        return self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()

    def BringToFront(self):
        return self.com_object.BringToFront()

    def bringtofront(self):
        """Alias for BringToFront"""
        return self.BringToFront()

    def bring_to_front(self):
        """Alias for BringToFront"""
        return self.BringToFront()

    def Copy(self):
        return self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def CopyPicture(self, Appearance=None, Format=None):
        arguments = com_arguments([unwrap(a) for a in [Appearance, Format]])
        return self.com_object.CopyPicture(*arguments)

    def copypicture(self, Appearance=None, Format=None):
        """Alias for CopyPicture"""
        arguments = [Appearance, Format]
        return self.CopyPicture(*arguments)

    def copy_picture(self, Appearance=None, Format=None):
        """Alias for CopyPicture"""
        arguments = [Appearance, Format]
        return self.CopyPicture(*arguments)

    def Cut(self):
        return self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Duplicate(self):
        return self.com_object.Duplicate()

    def duplicate(self):
        """Alias for Duplicate"""
        return self.Duplicate()

    def Select(self, Replace=None):
        arguments = com_arguments([unwrap(a) for a in [Replace]])
        return self.com_object.Select(*arguments)

    def select(self, Replace=None):
        """Alias for Select"""
        arguments = [Replace]
        return self.Select(*arguments)

    def SendToBack(self):
        return self.com_object.SendToBack()

    def sendtoback(self):
        """Alias for SendToBack"""
        return self.SendToBack()

    def send_to_back(self):
        """Alias for SendToBack"""
        return self.SendToBack()

    def Update(self):
        return self.com_object.Update()

    def update(self):
        """Alias for Update"""
        return self.Update()

    def Verb(self, Verb=None):
        arguments = com_arguments([unwrap(a) for a in [Verb]])
        return self.com_object.Verb(*arguments)

    def verb(self, Verb=None):
        """Alias for Verb"""
        arguments = [Verb]
        return self.Verb(*arguments)


class OLEObjects:

    def __init__(self, oleobjects=None):
        self.com_object= oleobjects

    def __call__(self, item):
        return OLEObject(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoLoad(self):
        return self.com_object.AutoLoad

    @AutoLoad.setter
    def AutoLoad(self, value):
        self.com_object.AutoLoad = value

    @property
    def autoload(self):
        """Alias for AutoLoad"""
        return self.AutoLoad

    @autoload.setter
    def autoload(self, value):
        """Alias for AutoLoad.setter"""
        self.AutoLoad = value

    @property
    def auto_load(self):
        """Alias for AutoLoad"""
        return self.AutoLoad

    @auto_load.setter
    def auto_load(self, value):
        """Alias for AutoLoad.setter"""
        self.AutoLoad = value

    @property
    def Border(self):
        return Border(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def Interior(self):
        return Interior(self.com_object.Interior)

    @property
    def interior(self):
        """Alias for Interior"""
        return self.Interior

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Placement(self):
        return XlPlacement(self.com_object.Placement)

    @Placement.setter
    def Placement(self, value):
        self.com_object.Placement = value

    @property
    def placement(self):
        """Alias for Placement"""
        return self.Placement

    @placement.setter
    def placement(self, value):
        """Alias for Placement.setter"""
        self.Placement = value

    @property
    def PrintObject(self):
        return self.com_object.PrintObject

    @PrintObject.setter
    def PrintObject(self, value):
        self.com_object.PrintObject = value

    @property
    def printobject(self):
        """Alias for PrintObject"""
        return self.PrintObject

    @printobject.setter
    def printobject(self, value):
        """Alias for PrintObject.setter"""
        self.PrintObject = value

    @property
    def print_object(self):
        """Alias for PrintObject"""
        return self.PrintObject

    @print_object.setter
    def print_object(self, value):
        """Alias for PrintObject.setter"""
        self.PrintObject = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def ShapeRange(self):
        return ShapeRange(self.com_object.ShapeRange)

    @property
    def shaperange(self):
        """Alias for ShapeRange"""
        return self.ShapeRange

    @property
    def shape_range(self):
        """Alias for ShapeRange"""
        return self.ShapeRange

    @property
    def SourceName(self):
        return self.com_object.SourceName

    @SourceName.setter
    def SourceName(self, value):
        self.com_object.SourceName = value

    @property
    def sourcename(self):
        """Alias for SourceName"""
        return self.SourceName

    @sourcename.setter
    def sourcename(self, value):
        """Alias for SourceName.setter"""
        self.SourceName = value

    @property
    def source_name(self):
        """Alias for SourceName"""
        return self.SourceName

    @source_name.setter
    def source_name(self, value):
        """Alias for SourceName.setter"""
        self.SourceName = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def ZOrder(self):
        return self.com_object.ZOrder

    @property
    def zorder(self):
        """Alias for ZOrder"""
        return self.ZOrder

    @property
    def z_order(self):
        """Alias for ZOrder"""
        return self.ZOrder

    def Add(self, ClassType=None, FileName=None, Link=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [ClassType, FileName, Link, DisplayAsIcon, IconFileName, IconIndex, IconLabel, Left, Top, Width, Height]])
        return OLEObject(self.com_object.Add(*arguments))

    def add(self, ClassType=None, FileName=None, Link=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for Add"""
        arguments = [ClassType, FileName, Link, DisplayAsIcon, IconFileName, IconIndex, IconLabel, Left, Top, Width, Height]
        return self.Add(*arguments)

    def BringToFront(self):
        return self.com_object.BringToFront()

    def bringtofront(self):
        """Alias for BringToFront"""
        return self.BringToFront()

    def bring_to_front(self):
        """Alias for BringToFront"""
        return self.BringToFront()

    def Copy(self):
        return self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def CopyPicture(self, Appearance=None, Format=None):
        arguments = com_arguments([unwrap(a) for a in [Appearance, Format]])
        return self.com_object.CopyPicture(*arguments)

    def copypicture(self, Appearance=None, Format=None):
        """Alias for CopyPicture"""
        arguments = [Appearance, Format]
        return self.CopyPicture(*arguments)

    def copy_picture(self, Appearance=None, Format=None):
        """Alias for CopyPicture"""
        arguments = [Appearance, Format]
        return self.CopyPicture(*arguments)

    def Cut(self):
        return self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Duplicate(self):
        return self.com_object.Duplicate()

    def duplicate(self):
        """Alias for Duplicate"""
        return self.Duplicate()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Select(self, Replace=None):
        arguments = com_arguments([unwrap(a) for a in [Replace]])
        return self.com_object.Select(*arguments)

    def select(self, Replace=None):
        """Alias for Select"""
        arguments = [Replace]
        return self.Select(*arguments)

    def SendToBack(self):
        return self.com_object.SendToBack()

    def sendtoback(self):
        """Alias for SendToBack"""
        return self.SendToBack()

    def send_to_back(self):
        """Alias for SendToBack"""
        return self.SendToBack()


class Outline:

    def __init__(self, outline=None):
        self.com_object= outline

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutomaticStyles(self):
        return self.com_object.AutomaticStyles

    @AutomaticStyles.setter
    def AutomaticStyles(self, value):
        self.com_object.AutomaticStyles = value

    @property
    def automaticstyles(self):
        """Alias for AutomaticStyles"""
        return self.AutomaticStyles

    @automaticstyles.setter
    def automaticstyles(self, value):
        """Alias for AutomaticStyles.setter"""
        self.AutomaticStyles = value

    @property
    def automatic_styles(self):
        """Alias for AutomaticStyles"""
        return self.AutomaticStyles

    @automatic_styles.setter
    def automatic_styles(self, value):
        """Alias for AutomaticStyles.setter"""
        self.AutomaticStyles = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SummaryColumn(self):
        return XlSummaryColumn(self.com_object.SummaryColumn)

    @SummaryColumn.setter
    def SummaryColumn(self, value):
        self.com_object.SummaryColumn = value

    @property
    def summarycolumn(self):
        """Alias for SummaryColumn"""
        return self.SummaryColumn

    @summarycolumn.setter
    def summarycolumn(self, value):
        """Alias for SummaryColumn.setter"""
        self.SummaryColumn = value

    @property
    def summary_column(self):
        """Alias for SummaryColumn"""
        return self.SummaryColumn

    @summary_column.setter
    def summary_column(self, value):
        """Alias for SummaryColumn.setter"""
        self.SummaryColumn = value

    @property
    def SummaryRow(self):
        return XlSummaryRow(self.com_object.SummaryRow)

    @SummaryRow.setter
    def SummaryRow(self, value):
        self.com_object.SummaryRow = value

    @property
    def summaryrow(self):
        """Alias for SummaryRow"""
        return self.SummaryRow

    @summaryrow.setter
    def summaryrow(self, value):
        """Alias for SummaryRow.setter"""
        self.SummaryRow = value

    @property
    def summary_row(self):
        """Alias for SummaryRow"""
        return self.SummaryRow

    @summary_row.setter
    def summary_row(self, value):
        """Alias for SummaryRow.setter"""
        self.SummaryRow = value

    def ShowLevels(self, RowLevels=None, ColumnLevels=None):
        arguments = com_arguments([unwrap(a) for a in [RowLevels, ColumnLevels]])
        return self.com_object.ShowLevels(*arguments)

    def showlevels(self, RowLevels=None, ColumnLevels=None):
        """Alias for ShowLevels"""
        arguments = [RowLevels, ColumnLevels]
        return self.ShowLevels(*arguments)

    def show_levels(self, RowLevels=None, ColumnLevels=None):
        """Alias for ShowLevels"""
        arguments = [RowLevels, ColumnLevels]
        return self.ShowLevels(*arguments)


class Page:

    def __init__(self, page=None):
        self.com_object= page

    @property
    def CenterFooter(self):
        return self.com_object.CenterFooter

    @property
    def centerfooter(self):
        """Alias for CenterFooter"""
        return self.CenterFooter

    @property
    def center_footer(self):
        """Alias for CenterFooter"""
        return self.CenterFooter

    @property
    def CenterHeader(self):
        return self.com_object.CenterHeader

    @property
    def centerheader(self):
        """Alias for CenterHeader"""
        return self.CenterHeader

    @property
    def center_header(self):
        """Alias for CenterHeader"""
        return self.CenterHeader

    @property
    def LeftFooter(self):
        return self.com_object.LeftFooter

    @property
    def leftfooter(self):
        """Alias for LeftFooter"""
        return self.LeftFooter

    @property
    def left_footer(self):
        """Alias for LeftFooter"""
        return self.LeftFooter

    @property
    def LeftHeader(self):
        return self.com_object.LeftHeader

    @property
    def leftheader(self):
        """Alias for LeftHeader"""
        return self.LeftHeader

    @property
    def left_header(self):
        """Alias for LeftHeader"""
        return self.LeftHeader

    @property
    def RightFooter(self):
        return self.com_object.RightFooter

    @property
    def rightfooter(self):
        """Alias for RightFooter"""
        return self.RightFooter

    @property
    def right_footer(self):
        """Alias for RightFooter"""
        return self.RightFooter

    @property
    def RightHeader(self):
        return self.com_object.RightHeader

    @property
    def rightheader(self):
        """Alias for RightHeader"""
        return self.RightHeader

    @property
    def right_header(self):
        """Alias for RightHeader"""
        return self.RightHeader


class Pages:

    def __init__(self, pages=None):
        self.com_object= pages

    def __call__(self, item):
        return Page(self.com_object(item))

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return Page(self.com_object.GetItem(*arguments))
        else:
            return Page(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class PageSetup:

    def __init__(self, pagesetup=None):
        self.com_object= pagesetup

    @property
    def AlignMarginsHeaderFooter(self):
        return self.com_object.AlignMarginsHeaderFooter

    @AlignMarginsHeaderFooter.setter
    def AlignMarginsHeaderFooter(self, value):
        self.com_object.AlignMarginsHeaderFooter = value

    @property
    def alignmarginsheaderfooter(self):
        """Alias for AlignMarginsHeaderFooter"""
        return self.AlignMarginsHeaderFooter

    @alignmarginsheaderfooter.setter
    def alignmarginsheaderfooter(self, value):
        """Alias for AlignMarginsHeaderFooter.setter"""
        self.AlignMarginsHeaderFooter = value

    @property
    def align_margins_header_footer(self):
        """Alias for AlignMarginsHeaderFooter"""
        return self.AlignMarginsHeaderFooter

    @align_margins_header_footer.setter
    def align_margins_header_footer(self, value):
        """Alias for AlignMarginsHeaderFooter.setter"""
        self.AlignMarginsHeaderFooter = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BlackAndWhite(self):
        return self.com_object.BlackAndWhite

    @BlackAndWhite.setter
    def BlackAndWhite(self, value):
        self.com_object.BlackAndWhite = value

    @property
    def blackandwhite(self):
        """Alias for BlackAndWhite"""
        return self.BlackAndWhite

    @blackandwhite.setter
    def blackandwhite(self, value):
        """Alias for BlackAndWhite.setter"""
        self.BlackAndWhite = value

    @property
    def black_and_white(self):
        """Alias for BlackAndWhite"""
        return self.BlackAndWhite

    @black_and_white.setter
    def black_and_white(self, value):
        """Alias for BlackAndWhite.setter"""
        self.BlackAndWhite = value

    @property
    def BottomMargin(self):
        return self.com_object.BottomMargin

    @BottomMargin.setter
    def BottomMargin(self, value):
        self.com_object.BottomMargin = value

    @property
    def bottommargin(self):
        """Alias for BottomMargin"""
        return self.BottomMargin

    @bottommargin.setter
    def bottommargin(self, value):
        """Alias for BottomMargin.setter"""
        self.BottomMargin = value

    @property
    def bottom_margin(self):
        """Alias for BottomMargin"""
        return self.BottomMargin

    @bottom_margin.setter
    def bottom_margin(self, value):
        """Alias for BottomMargin.setter"""
        self.BottomMargin = value

    @property
    def CenterFooter(self):
        return self.com_object.CenterFooter

    @CenterFooter.setter
    def CenterFooter(self, value):
        self.com_object.CenterFooter = value

    @property
    def centerfooter(self):
        """Alias for CenterFooter"""
        return self.CenterFooter

    @centerfooter.setter
    def centerfooter(self, value):
        """Alias for CenterFooter.setter"""
        self.CenterFooter = value

    @property
    def center_footer(self):
        """Alias for CenterFooter"""
        return self.CenterFooter

    @center_footer.setter
    def center_footer(self, value):
        """Alias for CenterFooter.setter"""
        self.CenterFooter = value

    @property
    def CenterFooterPicture(self):
        return Graphic(self.com_object.CenterFooterPicture)

    @property
    def centerfooterpicture(self):
        """Alias for CenterFooterPicture"""
        return self.CenterFooterPicture

    @property
    def center_footer_picture(self):
        """Alias for CenterFooterPicture"""
        return self.CenterFooterPicture

    @property
    def CenterHeader(self):
        return self.com_object.CenterHeader

    @CenterHeader.setter
    def CenterHeader(self, value):
        self.com_object.CenterHeader = value

    @property
    def centerheader(self):
        """Alias for CenterHeader"""
        return self.CenterHeader

    @centerheader.setter
    def centerheader(self, value):
        """Alias for CenterHeader.setter"""
        self.CenterHeader = value

    @property
    def center_header(self):
        """Alias for CenterHeader"""
        return self.CenterHeader

    @center_header.setter
    def center_header(self, value):
        """Alias for CenterHeader.setter"""
        self.CenterHeader = value

    @property
    def CenterHeaderPicture(self):
        return Graphic(self.com_object.CenterHeaderPicture)

    @property
    def centerheaderpicture(self):
        """Alias for CenterHeaderPicture"""
        return self.CenterHeaderPicture

    @property
    def center_header_picture(self):
        """Alias for CenterHeaderPicture"""
        return self.CenterHeaderPicture

    @property
    def CenterHorizontally(self):
        return self.com_object.CenterHorizontally

    @CenterHorizontally.setter
    def CenterHorizontally(self, value):
        self.com_object.CenterHorizontally = value

    @property
    def centerhorizontally(self):
        """Alias for CenterHorizontally"""
        return self.CenterHorizontally

    @centerhorizontally.setter
    def centerhorizontally(self, value):
        """Alias for CenterHorizontally.setter"""
        self.CenterHorizontally = value

    @property
    def center_horizontally(self):
        """Alias for CenterHorizontally"""
        return self.CenterHorizontally

    @center_horizontally.setter
    def center_horizontally(self, value):
        """Alias for CenterHorizontally.setter"""
        self.CenterHorizontally = value

    @property
    def CenterVertically(self):
        return self.com_object.CenterVertically

    @CenterVertically.setter
    def CenterVertically(self, value):
        self.com_object.CenterVertically = value

    @property
    def centervertically(self):
        """Alias for CenterVertically"""
        return self.CenterVertically

    @centervertically.setter
    def centervertically(self, value):
        """Alias for CenterVertically.setter"""
        self.CenterVertically = value

    @property
    def center_vertically(self):
        """Alias for CenterVertically"""
        return self.CenterVertically

    @center_vertically.setter
    def center_vertically(self, value):
        """Alias for CenterVertically.setter"""
        self.CenterVertically = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DifferentFirstPageHeaderFooter(self):
        return self.com_object.DifferentFirstPageHeaderFooter

    @DifferentFirstPageHeaderFooter.setter
    def DifferentFirstPageHeaderFooter(self, value):
        self.com_object.DifferentFirstPageHeaderFooter = value

    @property
    def differentfirstpageheaderfooter(self):
        """Alias for DifferentFirstPageHeaderFooter"""
        return self.DifferentFirstPageHeaderFooter

    @differentfirstpageheaderfooter.setter
    def differentfirstpageheaderfooter(self, value):
        """Alias for DifferentFirstPageHeaderFooter.setter"""
        self.DifferentFirstPageHeaderFooter = value

    @property
    def different_first_page_header_footer(self):
        """Alias for DifferentFirstPageHeaderFooter"""
        return self.DifferentFirstPageHeaderFooter

    @different_first_page_header_footer.setter
    def different_first_page_header_footer(self, value):
        """Alias for DifferentFirstPageHeaderFooter.setter"""
        self.DifferentFirstPageHeaderFooter = value

    @property
    def Draft(self):
        return self.com_object.Draft

    @Draft.setter
    def Draft(self, value):
        self.com_object.Draft = value

    @property
    def draft(self):
        """Alias for Draft"""
        return self.Draft

    @draft.setter
    def draft(self, value):
        """Alias for Draft.setter"""
        self.Draft = value

    @property
    def EvenPage(self):
        return self.com_object.EvenPage

    @EvenPage.setter
    def EvenPage(self, value):
        self.com_object.EvenPage = value

    @property
    def evenpage(self):
        """Alias for EvenPage"""
        return self.EvenPage

    @evenpage.setter
    def evenpage(self, value):
        """Alias for EvenPage.setter"""
        self.EvenPage = value

    @property
    def even_page(self):
        """Alias for EvenPage"""
        return self.EvenPage

    @even_page.setter
    def even_page(self, value):
        """Alias for EvenPage.setter"""
        self.EvenPage = value

    @property
    def FirstPage(self):
        return self.com_object.FirstPage

    @FirstPage.setter
    def FirstPage(self, value):
        self.com_object.FirstPage = value

    @property
    def firstpage(self):
        """Alias for FirstPage"""
        return self.FirstPage

    @firstpage.setter
    def firstpage(self, value):
        """Alias for FirstPage.setter"""
        self.FirstPage = value

    @property
    def first_page(self):
        """Alias for FirstPage"""
        return self.FirstPage

    @first_page.setter
    def first_page(self, value):
        """Alias for FirstPage.setter"""
        self.FirstPage = value

    @property
    def FirstPageNumber(self):
        return self.com_object.FirstPageNumber

    @FirstPageNumber.setter
    def FirstPageNumber(self, value):
        self.com_object.FirstPageNumber = value

    @property
    def firstpagenumber(self):
        """Alias for FirstPageNumber"""
        return self.FirstPageNumber

    @firstpagenumber.setter
    def firstpagenumber(self, value):
        """Alias for FirstPageNumber.setter"""
        self.FirstPageNumber = value

    @property
    def first_page_number(self):
        """Alias for FirstPageNumber"""
        return self.FirstPageNumber

    @first_page_number.setter
    def first_page_number(self, value):
        """Alias for FirstPageNumber.setter"""
        self.FirstPageNumber = value

    @property
    def FitToPagesTall(self):
        return self.com_object.FitToPagesTall

    @FitToPagesTall.setter
    def FitToPagesTall(self, value):
        self.com_object.FitToPagesTall = value

    @property
    def fittopagestall(self):
        """Alias for FitToPagesTall"""
        return self.FitToPagesTall

    @fittopagestall.setter
    def fittopagestall(self, value):
        """Alias for FitToPagesTall.setter"""
        self.FitToPagesTall = value

    @property
    def fit_to_pages_tall(self):
        """Alias for FitToPagesTall"""
        return self.FitToPagesTall

    @fit_to_pages_tall.setter
    def fit_to_pages_tall(self, value):
        """Alias for FitToPagesTall.setter"""
        self.FitToPagesTall = value

    @property
    def FitToPagesWide(self):
        return self.com_object.FitToPagesWide

    @FitToPagesWide.setter
    def FitToPagesWide(self, value):
        self.com_object.FitToPagesWide = value

    @property
    def fittopageswide(self):
        """Alias for FitToPagesWide"""
        return self.FitToPagesWide

    @fittopageswide.setter
    def fittopageswide(self, value):
        """Alias for FitToPagesWide.setter"""
        self.FitToPagesWide = value

    @property
    def fit_to_pages_wide(self):
        """Alias for FitToPagesWide"""
        return self.FitToPagesWide

    @fit_to_pages_wide.setter
    def fit_to_pages_wide(self, value):
        """Alias for FitToPagesWide.setter"""
        self.FitToPagesWide = value

    @property
    def FooterMargin(self):
        return self.com_object.FooterMargin

    @FooterMargin.setter
    def FooterMargin(self, value):
        self.com_object.FooterMargin = value

    @property
    def footermargin(self):
        """Alias for FooterMargin"""
        return self.FooterMargin

    @footermargin.setter
    def footermargin(self, value):
        """Alias for FooterMargin.setter"""
        self.FooterMargin = value

    @property
    def footer_margin(self):
        """Alias for FooterMargin"""
        return self.FooterMargin

    @footer_margin.setter
    def footer_margin(self, value):
        """Alias for FooterMargin.setter"""
        self.FooterMargin = value

    @property
    def HeaderMargin(self):
        return self.com_object.HeaderMargin

    @HeaderMargin.setter
    def HeaderMargin(self, value):
        self.com_object.HeaderMargin = value

    @property
    def headermargin(self):
        """Alias for HeaderMargin"""
        return self.HeaderMargin

    @headermargin.setter
    def headermargin(self, value):
        """Alias for HeaderMargin.setter"""
        self.HeaderMargin = value

    @property
    def header_margin(self):
        """Alias for HeaderMargin"""
        return self.HeaderMargin

    @header_margin.setter
    def header_margin(self, value):
        """Alias for HeaderMargin.setter"""
        self.HeaderMargin = value

    @property
    def LeftFooter(self):
        return self.com_object.LeftFooter

    @LeftFooter.setter
    def LeftFooter(self, value):
        self.com_object.LeftFooter = value

    @property
    def leftfooter(self):
        """Alias for LeftFooter"""
        return self.LeftFooter

    @leftfooter.setter
    def leftfooter(self, value):
        """Alias for LeftFooter.setter"""
        self.LeftFooter = value

    @property
    def left_footer(self):
        """Alias for LeftFooter"""
        return self.LeftFooter

    @left_footer.setter
    def left_footer(self, value):
        """Alias for LeftFooter.setter"""
        self.LeftFooter = value

    @property
    def LeftFooterPicture(self):
        return Graphic(self.com_object.LeftFooterPicture)

    @property
    def leftfooterpicture(self):
        """Alias for LeftFooterPicture"""
        return self.LeftFooterPicture

    @property
    def left_footer_picture(self):
        """Alias for LeftFooterPicture"""
        return self.LeftFooterPicture

    @property
    def LeftHeader(self):
        return self.com_object.LeftHeader

    @LeftHeader.setter
    def LeftHeader(self, value):
        self.com_object.LeftHeader = value

    @property
    def leftheader(self):
        """Alias for LeftHeader"""
        return self.LeftHeader

    @leftheader.setter
    def leftheader(self, value):
        """Alias for LeftHeader.setter"""
        self.LeftHeader = value

    @property
    def left_header(self):
        """Alias for LeftHeader"""
        return self.LeftHeader

    @left_header.setter
    def left_header(self, value):
        """Alias for LeftHeader.setter"""
        self.LeftHeader = value

    @property
    def LeftHeaderPicture(self):
        return Graphic(self.com_object.LeftHeaderPicture)

    @property
    def leftheaderpicture(self):
        """Alias for LeftHeaderPicture"""
        return self.LeftHeaderPicture

    @property
    def left_header_picture(self):
        """Alias for LeftHeaderPicture"""
        return self.LeftHeaderPicture

    @property
    def LeftMargin(self):
        return self.com_object.LeftMargin

    @LeftMargin.setter
    def LeftMargin(self, value):
        self.com_object.LeftMargin = value

    @property
    def leftmargin(self):
        """Alias for LeftMargin"""
        return self.LeftMargin

    @leftmargin.setter
    def leftmargin(self, value):
        """Alias for LeftMargin.setter"""
        self.LeftMargin = value

    @property
    def left_margin(self):
        """Alias for LeftMargin"""
        return self.LeftMargin

    @left_margin.setter
    def left_margin(self, value):
        """Alias for LeftMargin.setter"""
        self.LeftMargin = value

    @property
    def OddAndEvenPagesHeaderFooter(self):
        return self.com_object.OddAndEvenPagesHeaderFooter

    @OddAndEvenPagesHeaderFooter.setter
    def OddAndEvenPagesHeaderFooter(self, value):
        self.com_object.OddAndEvenPagesHeaderFooter = value

    @property
    def oddandevenpagesheaderfooter(self):
        """Alias for OddAndEvenPagesHeaderFooter"""
        return self.OddAndEvenPagesHeaderFooter

    @oddandevenpagesheaderfooter.setter
    def oddandevenpagesheaderfooter(self, value):
        """Alias for OddAndEvenPagesHeaderFooter.setter"""
        self.OddAndEvenPagesHeaderFooter = value

    @property
    def odd_and_even_pages_header_footer(self):
        """Alias for OddAndEvenPagesHeaderFooter"""
        return self.OddAndEvenPagesHeaderFooter

    @odd_and_even_pages_header_footer.setter
    def odd_and_even_pages_header_footer(self, value):
        """Alias for OddAndEvenPagesHeaderFooter.setter"""
        self.OddAndEvenPagesHeaderFooter = value

    @property
    def Order(self):
        return XlOrder(self.com_object.Order)

    @Order.setter
    def Order(self, value):
        self.com_object.Order = value

    @property
    def order(self):
        """Alias for Order"""
        return self.Order

    @order.setter
    def order(self, value):
        """Alias for Order.setter"""
        self.Order = value

    @property
    def Orientation(self):
        return XlPageOrientation(self.com_object.Orientation)

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Pages(self):
        return Pages(self.com_object.Pages)

    @Pages.setter
    def Pages(self, value):
        self.com_object.Pages = value

    @property
    def pages(self):
        """Alias for Pages"""
        return self.Pages

    @pages.setter
    def pages(self, value):
        """Alias for Pages.setter"""
        self.Pages = value

    @property
    def PaperSize(self):
        return XlPaperSize(self.com_object.PaperSize)

    @PaperSize.setter
    def PaperSize(self, value):
        self.com_object.PaperSize = value

    @property
    def papersize(self):
        """Alias for PaperSize"""
        return self.PaperSize

    @papersize.setter
    def papersize(self, value):
        """Alias for PaperSize.setter"""
        self.PaperSize = value

    @property
    def paper_size(self):
        """Alias for PaperSize"""
        return self.PaperSize

    @paper_size.setter
    def paper_size(self, value):
        """Alias for PaperSize.setter"""
        self.PaperSize = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PrintArea(self):
        return self.com_object.PrintArea

    @PrintArea.setter
    def PrintArea(self, value):
        self.com_object.PrintArea = value

    @property
    def printarea(self):
        """Alias for PrintArea"""
        return self.PrintArea

    @printarea.setter
    def printarea(self, value):
        """Alias for PrintArea.setter"""
        self.PrintArea = value

    @property
    def print_area(self):
        """Alias for PrintArea"""
        return self.PrintArea

    @print_area.setter
    def print_area(self, value):
        """Alias for PrintArea.setter"""
        self.PrintArea = value

    @property
    def PrintComments(self):
        return XlPrintLocation(self.com_object.PrintComments)

    @PrintComments.setter
    def PrintComments(self, value):
        self.com_object.PrintComments = value

    @property
    def printcomments(self):
        """Alias for PrintComments"""
        return self.PrintComments

    @printcomments.setter
    def printcomments(self, value):
        """Alias for PrintComments.setter"""
        self.PrintComments = value

    @property
    def print_comments(self):
        """Alias for PrintComments"""
        return self.PrintComments

    @print_comments.setter
    def print_comments(self, value):
        """Alias for PrintComments.setter"""
        self.PrintComments = value

    @property
    def PrintErrors(self):
        return self.com_object.PrintErrors

    @PrintErrors.setter
    def PrintErrors(self, value):
        self.com_object.PrintErrors = value

    @property
    def printerrors(self):
        """Alias for PrintErrors"""
        return self.PrintErrors

    @printerrors.setter
    def printerrors(self, value):
        """Alias for PrintErrors.setter"""
        self.PrintErrors = value

    @property
    def print_errors(self):
        """Alias for PrintErrors"""
        return self.PrintErrors

    @print_errors.setter
    def print_errors(self, value):
        """Alias for PrintErrors.setter"""
        self.PrintErrors = value

    @property
    def PrintGridlines(self):
        return self.com_object.PrintGridlines

    @PrintGridlines.setter
    def PrintGridlines(self, value):
        self.com_object.PrintGridlines = value

    @property
    def printgridlines(self):
        """Alias for PrintGridlines"""
        return self.PrintGridlines

    @printgridlines.setter
    def printgridlines(self, value):
        """Alias for PrintGridlines.setter"""
        self.PrintGridlines = value

    @property
    def print_gridlines(self):
        """Alias for PrintGridlines"""
        return self.PrintGridlines

    @print_gridlines.setter
    def print_gridlines(self, value):
        """Alias for PrintGridlines.setter"""
        self.PrintGridlines = value

    @property
    def PrintHeadings(self):
        return self.com_object.PrintHeadings

    @PrintHeadings.setter
    def PrintHeadings(self, value):
        self.com_object.PrintHeadings = value

    @property
    def printheadings(self):
        """Alias for PrintHeadings"""
        return self.PrintHeadings

    @printheadings.setter
    def printheadings(self, value):
        """Alias for PrintHeadings.setter"""
        self.PrintHeadings = value

    @property
    def print_headings(self):
        """Alias for PrintHeadings"""
        return self.PrintHeadings

    @print_headings.setter
    def print_headings(self, value):
        """Alias for PrintHeadings.setter"""
        self.PrintHeadings = value

    @property
    def PrintNotes(self):
        return self.com_object.PrintNotes

    @PrintNotes.setter
    def PrintNotes(self, value):
        self.com_object.PrintNotes = value

    @property
    def printnotes(self):
        """Alias for PrintNotes"""
        return self.PrintNotes

    @printnotes.setter
    def printnotes(self, value):
        """Alias for PrintNotes.setter"""
        self.PrintNotes = value

    @property
    def print_notes(self):
        """Alias for PrintNotes"""
        return self.PrintNotes

    @print_notes.setter
    def print_notes(self, value):
        """Alias for PrintNotes.setter"""
        self.PrintNotes = value

    @property
    def PrintQuality(self):
        return self.com_object.PrintQuality

    @PrintQuality.setter
    def PrintQuality(self, value):
        self.com_object.PrintQuality = value

    @property
    def printquality(self):
        """Alias for PrintQuality"""
        return self.PrintQuality

    @printquality.setter
    def printquality(self, value):
        """Alias for PrintQuality.setter"""
        self.PrintQuality = value

    @property
    def print_quality(self):
        """Alias for PrintQuality"""
        return self.PrintQuality

    @print_quality.setter
    def print_quality(self, value):
        """Alias for PrintQuality.setter"""
        self.PrintQuality = value

    @property
    def PrintTitleColumns(self):
        return self.com_object.PrintTitleColumns

    @PrintTitleColumns.setter
    def PrintTitleColumns(self, value):
        self.com_object.PrintTitleColumns = value

    @property
    def printtitlecolumns(self):
        """Alias for PrintTitleColumns"""
        return self.PrintTitleColumns

    @printtitlecolumns.setter
    def printtitlecolumns(self, value):
        """Alias for PrintTitleColumns.setter"""
        self.PrintTitleColumns = value

    @property
    def print_title_columns(self):
        """Alias for PrintTitleColumns"""
        return self.PrintTitleColumns

    @print_title_columns.setter
    def print_title_columns(self, value):
        """Alias for PrintTitleColumns.setter"""
        self.PrintTitleColumns = value

    @property
    def PrintTitleRows(self):
        return self.com_object.PrintTitleRows

    @PrintTitleRows.setter
    def PrintTitleRows(self, value):
        self.com_object.PrintTitleRows = value

    @property
    def printtitlerows(self):
        """Alias for PrintTitleRows"""
        return self.PrintTitleRows

    @printtitlerows.setter
    def printtitlerows(self, value):
        """Alias for PrintTitleRows.setter"""
        self.PrintTitleRows = value

    @property
    def print_title_rows(self):
        """Alias for PrintTitleRows"""
        return self.PrintTitleRows

    @print_title_rows.setter
    def print_title_rows(self, value):
        """Alias for PrintTitleRows.setter"""
        self.PrintTitleRows = value

    @property
    def RightFooter(self):
        return self.com_object.RightFooter

    @RightFooter.setter
    def RightFooter(self, value):
        self.com_object.RightFooter = value

    @property
    def rightfooter(self):
        """Alias for RightFooter"""
        return self.RightFooter

    @rightfooter.setter
    def rightfooter(self, value):
        """Alias for RightFooter.setter"""
        self.RightFooter = value

    @property
    def right_footer(self):
        """Alias for RightFooter"""
        return self.RightFooter

    @right_footer.setter
    def right_footer(self, value):
        """Alias for RightFooter.setter"""
        self.RightFooter = value

    @property
    def RightFooterPicture(self):
        return Graphic(self.com_object.RightFooterPicture)

    @property
    def rightfooterpicture(self):
        """Alias for RightFooterPicture"""
        return self.RightFooterPicture

    @property
    def right_footer_picture(self):
        """Alias for RightFooterPicture"""
        return self.RightFooterPicture

    @property
    def RightHeader(self):
        return self.com_object.RightHeader

    @RightHeader.setter
    def RightHeader(self, value):
        self.com_object.RightHeader = value

    @property
    def rightheader(self):
        """Alias for RightHeader"""
        return self.RightHeader

    @rightheader.setter
    def rightheader(self, value):
        """Alias for RightHeader.setter"""
        self.RightHeader = value

    @property
    def right_header(self):
        """Alias for RightHeader"""
        return self.RightHeader

    @right_header.setter
    def right_header(self, value):
        """Alias for RightHeader.setter"""
        self.RightHeader = value

    @property
    def RightHeaderPicture(self):
        return Graphic(self.com_object.RightHeaderPicture)

    @property
    def rightheaderpicture(self):
        """Alias for RightHeaderPicture"""
        return self.RightHeaderPicture

    @property
    def right_header_picture(self):
        """Alias for RightHeaderPicture"""
        return self.RightHeaderPicture

    @property
    def RightMargin(self):
        return self.com_object.RightMargin

    @RightMargin.setter
    def RightMargin(self, value):
        self.com_object.RightMargin = value

    @property
    def rightmargin(self):
        """Alias for RightMargin"""
        return self.RightMargin

    @rightmargin.setter
    def rightmargin(self, value):
        """Alias for RightMargin.setter"""
        self.RightMargin = value

    @property
    def right_margin(self):
        """Alias for RightMargin"""
        return self.RightMargin

    @right_margin.setter
    def right_margin(self, value):
        """Alias for RightMargin.setter"""
        self.RightMargin = value

    @property
    def ScaleWithDocHeaderFooter(self):
        return self.com_object.ScaleWithDocHeaderFooter

    @ScaleWithDocHeaderFooter.setter
    def ScaleWithDocHeaderFooter(self, value):
        self.com_object.ScaleWithDocHeaderFooter = value

    @property
    def scalewithdocheaderfooter(self):
        """Alias for ScaleWithDocHeaderFooter"""
        return self.ScaleWithDocHeaderFooter

    @scalewithdocheaderfooter.setter
    def scalewithdocheaderfooter(self, value):
        """Alias for ScaleWithDocHeaderFooter.setter"""
        self.ScaleWithDocHeaderFooter = value

    @property
    def scale_with_doc_header_footer(self):
        """Alias for ScaleWithDocHeaderFooter"""
        return self.ScaleWithDocHeaderFooter

    @scale_with_doc_header_footer.setter
    def scale_with_doc_header_footer(self, value):
        """Alias for ScaleWithDocHeaderFooter.setter"""
        self.ScaleWithDocHeaderFooter = value

    @property
    def TopMargin(self):
        return self.com_object.TopMargin

    @TopMargin.setter
    def TopMargin(self, value):
        self.com_object.TopMargin = value

    @property
    def topmargin(self):
        """Alias for TopMargin"""
        return self.TopMargin

    @topmargin.setter
    def topmargin(self, value):
        """Alias for TopMargin.setter"""
        self.TopMargin = value

    @property
    def top_margin(self):
        """Alias for TopMargin"""
        return self.TopMargin

    @top_margin.setter
    def top_margin(self, value):
        """Alias for TopMargin.setter"""
        self.TopMargin = value

    @property
    def Zoom(self):
        return self.com_object.Zoom

    @Zoom.setter
    def Zoom(self, value):
        self.com_object.Zoom = value

    @property
    def zoom(self):
        """Alias for Zoom"""
        return self.Zoom

    @zoom.setter
    def zoom(self, value):
        """Alias for Zoom.setter"""
        self.Zoom = value


class Pane:

    def __init__(self, pane=None):
        self.com_object= pane

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ScrollColumn(self):
        return self.com_object.ScrollColumn

    @ScrollColumn.setter
    def ScrollColumn(self, value):
        self.com_object.ScrollColumn = value

    @property
    def scrollcolumn(self):
        """Alias for ScrollColumn"""
        return self.ScrollColumn

    @scrollcolumn.setter
    def scrollcolumn(self, value):
        """Alias for ScrollColumn.setter"""
        self.ScrollColumn = value

    @property
    def scroll_column(self):
        """Alias for ScrollColumn"""
        return self.ScrollColumn

    @scroll_column.setter
    def scroll_column(self, value):
        """Alias for ScrollColumn.setter"""
        self.ScrollColumn = value

    @property
    def ScrollRow(self):
        return self.com_object.ScrollRow

    @ScrollRow.setter
    def ScrollRow(self, value):
        self.com_object.ScrollRow = value

    @property
    def scrollrow(self):
        """Alias for ScrollRow"""
        return self.ScrollRow

    @scrollrow.setter
    def scrollrow(self, value):
        """Alias for ScrollRow.setter"""
        self.ScrollRow = value

    @property
    def scroll_row(self):
        """Alias for ScrollRow"""
        return self.ScrollRow

    @scroll_row.setter
    def scroll_row(self, value):
        """Alias for ScrollRow.setter"""
        self.ScrollRow = value

    @property
    def VisibleRange(self):
        return Range(self.com_object.VisibleRange)

    @property
    def visiblerange(self):
        """Alias for VisibleRange"""
        return self.VisibleRange

    @property
    def visible_range(self):
        """Alias for VisibleRange"""
        return self.VisibleRange

    def Activate(self):
        return self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()

    def LargeScroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        arguments = com_arguments([unwrap(a) for a in [Down, Up, ToRight, ToLeft]])
        return self.com_object.LargeScroll(*arguments)

    def largescroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        """Alias for LargeScroll"""
        arguments = [Down, Up, ToRight, ToLeft]
        return self.LargeScroll(*arguments)

    def large_scroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        """Alias for LargeScroll"""
        arguments = [Down, Up, ToRight, ToLeft]
        return self.LargeScroll(*arguments)

    def PointsToScreenPixelsX(self, Points=None):
        arguments = com_arguments([unwrap(a) for a in [Points]])
        return self.com_object.PointsToScreenPixelsX(*arguments)

    def pointstoscreenpixelsx(self, Points=None):
        """Alias for PointsToScreenPixelsX"""
        arguments = [Points]
        return self.PointsToScreenPixelsX(*arguments)

    def points_to_screen_pixels_x(self, Points=None):
        """Alias for PointsToScreenPixelsX"""
        arguments = [Points]
        return self.PointsToScreenPixelsX(*arguments)

    def PointsToScreenPixelsY(self, Points=None):
        arguments = com_arguments([unwrap(a) for a in [Points]])
        return self.com_object.PointsToScreenPixelsY(*arguments)

    def pointstoscreenpixelsy(self, Points=None):
        """Alias for PointsToScreenPixelsY"""
        arguments = [Points]
        return self.PointsToScreenPixelsY(*arguments)

    def points_to_screen_pixels_y(self, Points=None):
        """Alias for PointsToScreenPixelsY"""
        arguments = [Points]
        return self.PointsToScreenPixelsY(*arguments)

    def ScrollIntoView(self, Left=None, Top=None, Width=None, Height=None, Start=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height, Start]])
        self.com_object.ScrollIntoView(*arguments)

    def scrollintoview(self, Left=None, Top=None, Width=None, Height=None, Start=None):
        """Alias for ScrollIntoView"""
        arguments = [Left, Top, Width, Height, Start]
        return self.ScrollIntoView(*arguments)

    def scroll_into_view(self, Left=None, Top=None, Width=None, Height=None, Start=None):
        """Alias for ScrollIntoView"""
        arguments = [Left, Top, Width, Height, Start]
        return self.ScrollIntoView(*arguments)

    def SmallScroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        arguments = com_arguments([unwrap(a) for a in [Down, Up, ToRight, ToLeft]])
        return self.com_object.SmallScroll(*arguments)

    def smallscroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        """Alias for SmallScroll"""
        arguments = [Down, Up, ToRight, ToLeft]
        return self.SmallScroll(*arguments)

    def small_scroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        """Alias for SmallScroll"""
        arguments = [Down, Up, ToRight, ToLeft]
        return self.SmallScroll(*arguments)


class Panes:

    def __init__(self, panes=None):
        self.com_object= panes

    def __call__(self, item):
        return Pane(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class Parameter:

    def __init__(self, parameter=None):
        self.com_object= parameter

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DataType(self):
        return XlParameterDataType(self.com_object.DataType)

    @DataType.setter
    def DataType(self, value):
        self.com_object.DataType = value

    @property
    def datatype(self):
        """Alias for DataType"""
        return self.DataType

    @datatype.setter
    def datatype(self, value):
        """Alias for DataType.setter"""
        self.DataType = value

    @property
    def data_type(self):
        """Alias for DataType"""
        return self.DataType

    @data_type.setter
    def data_type(self, value):
        """Alias for DataType.setter"""
        self.DataType = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PromptString(self):
        return self.com_object.PromptString

    @property
    def promptstring(self):
        """Alias for PromptString"""
        return self.PromptString

    @property
    def prompt_string(self):
        """Alias for PromptString"""
        return self.PromptString

    @property
    def RefreshOnChange(self):
        return self.com_object.RefreshOnChange

    @RefreshOnChange.setter
    def RefreshOnChange(self, value):
        self.com_object.RefreshOnChange = value

    @property
    def refreshonchange(self):
        """Alias for RefreshOnChange"""
        return self.RefreshOnChange

    @refreshonchange.setter
    def refreshonchange(self, value):
        """Alias for RefreshOnChange.setter"""
        self.RefreshOnChange = value

    @property
    def refresh_on_change(self):
        """Alias for RefreshOnChange"""
        return self.RefreshOnChange

    @refresh_on_change.setter
    def refresh_on_change(self, value):
        """Alias for RefreshOnChange.setter"""
        self.RefreshOnChange = value

    @property
    def SourceRange(self):
        return Range(self.com_object.SourceRange)

    @property
    def sourcerange(self):
        """Alias for SourceRange"""
        return self.SourceRange

    @property
    def source_range(self):
        """Alias for SourceRange"""
        return self.SourceRange

    @property
    def Type(self):
        return XlParameterType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def Value(self):
        return self.com_object.Value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    def SetParam(self, Type=None, Value=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Value]])
        self.com_object.SetParam(*arguments)

    def setparam(self, Type=None, Value=None):
        """Alias for SetParam"""
        arguments = [Type, Value]
        return self.SetParam(*arguments)

    def set_param(self, Type=None, Value=None):
        """Alias for SetParam"""
        arguments = [Type, Value]
        return self.SetParam(*arguments)


class Parameters:

    def __init__(self, parameters=None):
        self.com_object= parameters

    def __call__(self, item):
        return Parameter(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, iDataType=None):
        arguments = com_arguments([unwrap(a) for a in [Name, iDataType]])
        return Parameter(self.com_object.Add(*arguments))

    def add(self, Name=None, iDataType=None):
        """Alias for Add"""
        arguments = [Name, iDataType]
        return self.Add(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Parameter(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class Phonetic:

    def __init__(self, phonetic=None):
        self.com_object= phonetic

    @property
    def Alignment(self):
        return self.com_object.Alignment

    @Alignment.setter
    def Alignment(self, value):
        self.com_object.Alignment = value

    @property
    def alignment(self):
        """Alias for Alignment"""
        return self.Alignment

    @alignment.setter
    def alignment(self, value):
        """Alias for Alignment.setter"""
        self.Alignment = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def CharacterType(self):
        return XlPhoneticCharacterType(self.com_object.CharacterType)

    @CharacterType.setter
    def CharacterType(self, value):
        self.com_object.CharacterType = value

    @property
    def charactertype(self):
        """Alias for CharacterType"""
        return self.CharacterType

    @charactertype.setter
    def charactertype(self, value):
        """Alias for CharacterType.setter"""
        self.CharacterType = value

    @property
    def character_type(self):
        """Alias for CharacterType"""
        return self.CharacterType

    @character_type.setter
    def character_type(self, value):
        """Alias for CharacterType.setter"""
        self.CharacterType = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value


class Phonetics:

    def __init__(self, phonetics=None):
        self.com_object= phonetics

    def __call__(self, item):
        return Phonetic(self.com_object(item))

    @property
    def Alignment(self):
        return self.com_object.Alignment

    @Alignment.setter
    def Alignment(self, value):
        self.com_object.Alignment = value

    @property
    def alignment(self):
        """Alias for Alignment"""
        return self.Alignment

    @alignment.setter
    def alignment(self, value):
        """Alias for Alignment.setter"""
        self.Alignment = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def CharacterType(self):
        return XlPhoneticCharacterType(self.com_object.CharacterType)

    @CharacterType.setter
    def CharacterType(self, value):
        self.com_object.CharacterType = value

    @property
    def charactertype(self):
        """Alias for CharacterType"""
        return self.CharacterType

    @charactertype.setter
    def charactertype(self, value):
        """Alias for CharacterType.setter"""
        self.CharacterType = value

    @property
    def character_type(self):
        """Alias for CharacterType"""
        return self.CharacterType

    @character_type.setter
    def character_type(self, value):
        """Alias for CharacterType.setter"""
        self.CharacterType = value

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Length(self):
        return self.com_object.Length

    @property
    def length(self):
        """Alias for Length"""
        return self.Length

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Start(self):
        return self.com_object.Start

    @property
    def start(self):
        """Alias for Start"""
        return self.Start

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    def Add(self, Start=None, Length=None, Text=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length, Text]])
        self.com_object.Add(*arguments)

    def add(self, Start=None, Length=None, Text=None):
        """Alias for Add"""
        arguments = [Start, Length, Text]
        return self.Add(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class PictureFormat:

    def __init__(self, pictureformat=None):
        self.com_object= pictureformat

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Brightness(self):
        return self.com_object.Brightness

    @Brightness.setter
    def Brightness(self, value):
        self.com_object.Brightness = value

    @property
    def brightness(self):
        """Alias for Brightness"""
        return self.Brightness

    @brightness.setter
    def brightness(self, value):
        """Alias for Brightness.setter"""
        self.Brightness = value

    @property
    def ColorType(self):
        return self.com_object.ColorType

    @ColorType.setter
    def ColorType(self, value):
        self.com_object.ColorType = value

    @property
    def colortype(self):
        """Alias for ColorType"""
        return self.ColorType

    @colortype.setter
    def colortype(self, value):
        """Alias for ColorType.setter"""
        self.ColorType = value

    @property
    def color_type(self):
        """Alias for ColorType"""
        return self.ColorType

    @color_type.setter
    def color_type(self, value):
        """Alias for ColorType.setter"""
        self.ColorType = value

    @property
    def Contrast(self):
        return self.com_object.Contrast

    @Contrast.setter
    def Contrast(self, value):
        self.com_object.Contrast = value

    @property
    def contrast(self):
        """Alias for Contrast"""
        return self.Contrast

    @contrast.setter
    def contrast(self, value):
        """Alias for Contrast.setter"""
        self.Contrast = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Crop(self):
        return self.com_object.Crop

    @property
    def crop(self):
        """Alias for Crop"""
        return self.Crop

    @property
    def CropBottom(self):
        return self.com_object.CropBottom

    @CropBottom.setter
    def CropBottom(self, value):
        self.com_object.CropBottom = value

    @property
    def cropbottom(self):
        """Alias for CropBottom"""
        return self.CropBottom

    @cropbottom.setter
    def cropbottom(self, value):
        """Alias for CropBottom.setter"""
        self.CropBottom = value

    @property
    def crop_bottom(self):
        """Alias for CropBottom"""
        return self.CropBottom

    @crop_bottom.setter
    def crop_bottom(self, value):
        """Alias for CropBottom.setter"""
        self.CropBottom = value

    @property
    def CropLeft(self):
        return self.com_object.CropLeft

    @CropLeft.setter
    def CropLeft(self, value):
        self.com_object.CropLeft = value

    @property
    def cropleft(self):
        """Alias for CropLeft"""
        return self.CropLeft

    @cropleft.setter
    def cropleft(self, value):
        """Alias for CropLeft.setter"""
        self.CropLeft = value

    @property
    def crop_left(self):
        """Alias for CropLeft"""
        return self.CropLeft

    @crop_left.setter
    def crop_left(self, value):
        """Alias for CropLeft.setter"""
        self.CropLeft = value

    @property
    def CropRight(self):
        return self.com_object.CropRight

    @CropRight.setter
    def CropRight(self, value):
        self.com_object.CropRight = value

    @property
    def cropright(self):
        """Alias for CropRight"""
        return self.CropRight

    @cropright.setter
    def cropright(self, value):
        """Alias for CropRight.setter"""
        self.CropRight = value

    @property
    def crop_right(self):
        """Alias for CropRight"""
        return self.CropRight

    @crop_right.setter
    def crop_right(self, value):
        """Alias for CropRight.setter"""
        self.CropRight = value

    @property
    def CropTop(self):
        return self.com_object.CropTop

    @CropTop.setter
    def CropTop(self, value):
        self.com_object.CropTop = value

    @property
    def croptop(self):
        """Alias for CropTop"""
        return self.CropTop

    @croptop.setter
    def croptop(self, value):
        """Alias for CropTop.setter"""
        self.CropTop = value

    @property
    def crop_top(self):
        """Alias for CropTop"""
        return self.CropTop

    @crop_top.setter
    def crop_top(self, value):
        """Alias for CropTop.setter"""
        self.CropTop = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def TransparencyColor(self):
        return self.com_object.TransparencyColor

    @TransparencyColor.setter
    def TransparencyColor(self, value):
        self.com_object.TransparencyColor = value

    @property
    def transparencycolor(self):
        """Alias for TransparencyColor"""
        return self.TransparencyColor

    @transparencycolor.setter
    def transparencycolor(self, value):
        """Alias for TransparencyColor.setter"""
        self.TransparencyColor = value

    @property
    def transparency_color(self):
        """Alias for TransparencyColor"""
        return self.TransparencyColor

    @transparency_color.setter
    def transparency_color(self, value):
        """Alias for TransparencyColor.setter"""
        self.TransparencyColor = value

    @property
    def TransparentBackground(self):
        return self.com_object.TransparentBackground

    @TransparentBackground.setter
    def TransparentBackground(self, value):
        self.com_object.TransparentBackground = value

    @property
    def transparentbackground(self):
        """Alias for TransparentBackground"""
        return self.TransparentBackground

    @transparentbackground.setter
    def transparentbackground(self, value):
        """Alias for TransparentBackground.setter"""
        self.TransparentBackground = value

    @property
    def transparent_background(self):
        """Alias for TransparentBackground"""
        return self.TransparentBackground

    @transparent_background.setter
    def transparent_background(self, value):
        """Alias for TransparentBackground.setter"""
        self.TransparentBackground = value

    def IncrementBrightness(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementBrightness(*arguments)

    def incrementbrightness(self, Increment=None):
        """Alias for IncrementBrightness"""
        arguments = [Increment]
        return self.IncrementBrightness(*arguments)

    def increment_brightness(self, Increment=None):
        """Alias for IncrementBrightness"""
        arguments = [Increment]
        return self.IncrementBrightness(*arguments)

    def IncrementContrast(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementContrast(*arguments)

    def incrementcontrast(self, Increment=None):
        """Alias for IncrementContrast"""
        arguments = [Increment]
        return self.IncrementContrast(*arguments)

    def increment_contrast(self, Increment=None):
        """Alias for IncrementContrast"""
        arguments = [Increment]
        return self.IncrementContrast(*arguments)


class PivotAxis:

    def __init__(self, pivotaxis=None):
        self.com_object= pivotaxis

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return PivotAxis(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PivotLines(self):
        return PivotLines(self.com_object.PivotLines)

    @property
    def pivotlines(self):
        """Alias for PivotLines"""
        return self.PivotLines

    @property
    def pivot_lines(self):
        """Alias for PivotLines"""
        return self.PivotLines


class PivotCache:

    def __init__(self, pivotcache=None):
        self.com_object= pivotcache

    @property
    def ADOConnection(self):
        return self.com_object.ADOConnection

    @property
    def adoconnection(self):
        """Alias for ADOConnection"""
        return self.ADOConnection

    @property
    def a_d_o_connection(self):
        """Alias for ADOConnection"""
        return self.ADOConnection

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BackgroundQuery(self):
        return self.com_object.BackgroundQuery

    @BackgroundQuery.setter
    def BackgroundQuery(self, value):
        self.com_object.BackgroundQuery = value

    @property
    def backgroundquery(self):
        """Alias for BackgroundQuery"""
        return self.BackgroundQuery

    @backgroundquery.setter
    def backgroundquery(self, value):
        """Alias for BackgroundQuery.setter"""
        self.BackgroundQuery = value

    @property
    def background_query(self):
        """Alias for BackgroundQuery"""
        return self.BackgroundQuery

    @background_query.setter
    def background_query(self, value):
        """Alias for BackgroundQuery.setter"""
        self.BackgroundQuery = value

    @property
    def CommandText(self):
        return self.com_object.CommandText

    @CommandText.setter
    def CommandText(self, value):
        self.com_object.CommandText = value

    @property
    def commandtext(self):
        """Alias for CommandText"""
        return self.CommandText

    @commandtext.setter
    def commandtext(self, value):
        """Alias for CommandText.setter"""
        self.CommandText = value

    @property
    def command_text(self):
        """Alias for CommandText"""
        return self.CommandText

    @command_text.setter
    def command_text(self, value):
        """Alias for CommandText.setter"""
        self.CommandText = value

    @property
    def CommandType(self):
        return XlCmdType(self.com_object.CommandType)

    @CommandType.setter
    def CommandType(self, value):
        self.com_object.CommandType = value

    @property
    def commandtype(self):
        """Alias for CommandType"""
        return self.CommandType

    @commandtype.setter
    def commandtype(self, value):
        """Alias for CommandType.setter"""
        self.CommandType = value

    @property
    def command_type(self):
        """Alias for CommandType"""
        return self.CommandType

    @command_type.setter
    def command_type(self, value):
        """Alias for CommandType.setter"""
        self.CommandType = value

    @property
    def Connection(self):
        return self.com_object.Connection

    @Connection.setter
    def Connection(self, value):
        self.com_object.Connection = value

    @property
    def connection(self):
        """Alias for Connection"""
        return self.Connection

    @connection.setter
    def connection(self, value):
        """Alias for Connection.setter"""
        self.Connection = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def EnableRefresh(self):
        return self.com_object.EnableRefresh

    @EnableRefresh.setter
    def EnableRefresh(self, value):
        self.com_object.EnableRefresh = value

    @property
    def enablerefresh(self):
        """Alias for EnableRefresh"""
        return self.EnableRefresh

    @enablerefresh.setter
    def enablerefresh(self, value):
        """Alias for EnableRefresh.setter"""
        self.EnableRefresh = value

    @property
    def enable_refresh(self):
        """Alias for EnableRefresh"""
        return self.EnableRefresh

    @enable_refresh.setter
    def enable_refresh(self, value):
        """Alias for EnableRefresh.setter"""
        self.EnableRefresh = value

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def IsConnected(self):
        return self.com_object.IsConnected

    @property
    def isconnected(self):
        """Alias for IsConnected"""
        return self.IsConnected

    @property
    def is_connected(self):
        """Alias for IsConnected"""
        return self.IsConnected

    @property
    def LocalConnection(self):
        return self.com_object.LocalConnection

    @LocalConnection.setter
    def LocalConnection(self, value):
        self.com_object.LocalConnection = value

    @property
    def localconnection(self):
        """Alias for LocalConnection"""
        return self.LocalConnection

    @localconnection.setter
    def localconnection(self, value):
        """Alias for LocalConnection.setter"""
        self.LocalConnection = value

    @property
    def local_connection(self):
        """Alias for LocalConnection"""
        return self.LocalConnection

    @local_connection.setter
    def local_connection(self, value):
        """Alias for LocalConnection.setter"""
        self.LocalConnection = value

    @property
    def MaintainConnection(self):
        return self.com_object.MaintainConnection

    @MaintainConnection.setter
    def MaintainConnection(self, value):
        self.com_object.MaintainConnection = value

    @property
    def maintainconnection(self):
        """Alias for MaintainConnection"""
        return self.MaintainConnection

    @maintainconnection.setter
    def maintainconnection(self, value):
        """Alias for MaintainConnection.setter"""
        self.MaintainConnection = value

    @property
    def maintain_connection(self):
        """Alias for MaintainConnection"""
        return self.MaintainConnection

    @maintain_connection.setter
    def maintain_connection(self, value):
        """Alias for MaintainConnection.setter"""
        self.MaintainConnection = value

    @property
    def MemoryUsed(self):
        return self.com_object.MemoryUsed

    @property
    def memoryused(self):
        """Alias for MemoryUsed"""
        return self.MemoryUsed

    @property
    def memory_used(self):
        """Alias for MemoryUsed"""
        return self.MemoryUsed

    @property
    def MissingItemsLimit(self):
        return XlPivotTableMissingItems(self.com_object.MissingItemsLimit)

    @MissingItemsLimit.setter
    def MissingItemsLimit(self, value):
        self.com_object.MissingItemsLimit = value

    @property
    def missingitemslimit(self):
        """Alias for MissingItemsLimit"""
        return self.MissingItemsLimit

    @missingitemslimit.setter
    def missingitemslimit(self, value):
        """Alias for MissingItemsLimit.setter"""
        self.MissingItemsLimit = value

    @property
    def missing_items_limit(self):
        """Alias for MissingItemsLimit"""
        return self.MissingItemsLimit

    @missing_items_limit.setter
    def missing_items_limit(self, value):
        """Alias for MissingItemsLimit.setter"""
        self.MissingItemsLimit = value

    @property
    def OLAP(self):
        return self.com_object.OLAP

    @property
    def olap(self):
        """Alias for OLAP"""
        return self.OLAP

    @property
    def o_l_a_p(self):
        """Alias for OLAP"""
        return self.OLAP

    @property
    def OptimizeCache(self):
        return self.com_object.OptimizeCache

    @OptimizeCache.setter
    def OptimizeCache(self, value):
        self.com_object.OptimizeCache = value

    @property
    def optimizecache(self):
        """Alias for OptimizeCache"""
        return self.OptimizeCache

    @optimizecache.setter
    def optimizecache(self, value):
        """Alias for OptimizeCache.setter"""
        self.OptimizeCache = value

    @property
    def optimize_cache(self):
        """Alias for OptimizeCache"""
        return self.OptimizeCache

    @optimize_cache.setter
    def optimize_cache(self, value):
        """Alias for OptimizeCache.setter"""
        self.OptimizeCache = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def QueryType(self):
        return self.com_object.QueryType

    @property
    def querytype(self):
        """Alias for QueryType"""
        return self.QueryType

    @property
    def query_type(self):
        """Alias for QueryType"""
        return self.QueryType

    @property
    def RecordCount(self):
        return self.com_object.RecordCount

    @property
    def recordcount(self):
        """Alias for RecordCount"""
        return self.RecordCount

    @property
    def record_count(self):
        """Alias for RecordCount"""
        return self.RecordCount

    @property
    def Recordset(self):
        return self.com_object.Recordset

    @Recordset.setter
    def Recordset(self, value):
        self.com_object.Recordset = value

    @property
    def recordset(self):
        """Alias for Recordset"""
        return self.Recordset

    @recordset.setter
    def recordset(self, value):
        """Alias for Recordset.setter"""
        self.Recordset = value

    @property
    def RefreshDate(self):
        return self.com_object.RefreshDate

    @property
    def refreshdate(self):
        """Alias for RefreshDate"""
        return self.RefreshDate

    @property
    def refresh_date(self):
        """Alias for RefreshDate"""
        return self.RefreshDate

    @property
    def RefreshName(self):
        return self.com_object.RefreshName

    @property
    def refreshname(self):
        """Alias for RefreshName"""
        return self.RefreshName

    @property
    def refresh_name(self):
        """Alias for RefreshName"""
        return self.RefreshName

    @property
    def RefreshOnFileOpen(self):
        return self.com_object.RefreshOnFileOpen

    @RefreshOnFileOpen.setter
    def RefreshOnFileOpen(self, value):
        self.com_object.RefreshOnFileOpen = value

    @property
    def refreshonfileopen(self):
        """Alias for RefreshOnFileOpen"""
        return self.RefreshOnFileOpen

    @refreshonfileopen.setter
    def refreshonfileopen(self, value):
        """Alias for RefreshOnFileOpen.setter"""
        self.RefreshOnFileOpen = value

    @property
    def refresh_on_file_open(self):
        """Alias for RefreshOnFileOpen"""
        return self.RefreshOnFileOpen

    @refresh_on_file_open.setter
    def refresh_on_file_open(self, value):
        """Alias for RefreshOnFileOpen.setter"""
        self.RefreshOnFileOpen = value

    @property
    def RefreshPeriod(self):
        return self.com_object.RefreshPeriod

    @RefreshPeriod.setter
    def RefreshPeriod(self, value):
        self.com_object.RefreshPeriod = value

    @property
    def refreshperiod(self):
        """Alias for RefreshPeriod"""
        return self.RefreshPeriod

    @refreshperiod.setter
    def refreshperiod(self, value):
        """Alias for RefreshPeriod.setter"""
        self.RefreshPeriod = value

    @property
    def refresh_period(self):
        """Alias for RefreshPeriod"""
        return self.RefreshPeriod

    @refresh_period.setter
    def refresh_period(self, value):
        """Alias for RefreshPeriod.setter"""
        self.RefreshPeriod = value

    @property
    def RobustConnect(self):
        return XlRobustConnect(self.com_object.RobustConnect)

    @RobustConnect.setter
    def RobustConnect(self, value):
        self.com_object.RobustConnect = value

    @property
    def robustconnect(self):
        """Alias for RobustConnect"""
        return self.RobustConnect

    @robustconnect.setter
    def robustconnect(self, value):
        """Alias for RobustConnect.setter"""
        self.RobustConnect = value

    @property
    def robust_connect(self):
        """Alias for RobustConnect"""
        return self.RobustConnect

    @robust_connect.setter
    def robust_connect(self, value):
        """Alias for RobustConnect.setter"""
        self.RobustConnect = value

    @property
    def SavePassword(self):
        return self.com_object.SavePassword

    @SavePassword.setter
    def SavePassword(self, value):
        self.com_object.SavePassword = value

    @property
    def savepassword(self):
        """Alias for SavePassword"""
        return self.SavePassword

    @savepassword.setter
    def savepassword(self, value):
        """Alias for SavePassword.setter"""
        self.SavePassword = value

    @property
    def save_password(self):
        """Alias for SavePassword"""
        return self.SavePassword

    @save_password.setter
    def save_password(self, value):
        """Alias for SavePassword.setter"""
        self.SavePassword = value

    @property
    def SourceConnectionFile(self):
        return self.com_object.SourceConnectionFile

    @SourceConnectionFile.setter
    def SourceConnectionFile(self, value):
        self.com_object.SourceConnectionFile = value

    @property
    def sourceconnectionfile(self):
        """Alias for SourceConnectionFile"""
        return self.SourceConnectionFile

    @sourceconnectionfile.setter
    def sourceconnectionfile(self, value):
        """Alias for SourceConnectionFile.setter"""
        self.SourceConnectionFile = value

    @property
    def source_connection_file(self):
        """Alias for SourceConnectionFile"""
        return self.SourceConnectionFile

    @source_connection_file.setter
    def source_connection_file(self, value):
        """Alias for SourceConnectionFile.setter"""
        self.SourceConnectionFile = value

    @property
    def SourceData(self):
        return self.com_object.SourceData

    @SourceData.setter
    def SourceData(self, value):
        self.com_object.SourceData = value

    @property
    def sourcedata(self):
        """Alias for SourceData"""
        return self.SourceData

    @sourcedata.setter
    def sourcedata(self, value):
        """Alias for SourceData.setter"""
        self.SourceData = value

    @property
    def source_data(self):
        """Alias for SourceData"""
        return self.SourceData

    @source_data.setter
    def source_data(self, value):
        """Alias for SourceData.setter"""
        self.SourceData = value

    @property
    def SourceDataFile(self):
        return self.com_object.SourceDataFile

    @property
    def sourcedatafile(self):
        """Alias for SourceDataFile"""
        return self.SourceDataFile

    @property
    def source_data_file(self):
        """Alias for SourceDataFile"""
        return self.SourceDataFile

    @property
    def SourceType(self):
        return XlPivotTableSourceType(self.com_object.SourceType)

    @property
    def sourcetype(self):
        """Alias for SourceType"""
        return self.SourceType

    @property
    def source_type(self):
        """Alias for SourceType"""
        return self.SourceType

    @property
    def UpgradeOnRefresh(self):
        return self.com_object.UpgradeOnRefresh

    @UpgradeOnRefresh.setter
    def UpgradeOnRefresh(self, value):
        self.com_object.UpgradeOnRefresh = value

    @property
    def upgradeonrefresh(self):
        """Alias for UpgradeOnRefresh"""
        return self.UpgradeOnRefresh

    @upgradeonrefresh.setter
    def upgradeonrefresh(self, value):
        """Alias for UpgradeOnRefresh.setter"""
        self.UpgradeOnRefresh = value

    @property
    def upgrade_on_refresh(self):
        """Alias for UpgradeOnRefresh"""
        return self.UpgradeOnRefresh

    @upgrade_on_refresh.setter
    def upgrade_on_refresh(self, value):
        """Alias for UpgradeOnRefresh.setter"""
        self.UpgradeOnRefresh = value

    @property
    def UseLocalConnection(self):
        return self.com_object.UseLocalConnection

    @UseLocalConnection.setter
    def UseLocalConnection(self, value):
        self.com_object.UseLocalConnection = value

    @property
    def uselocalconnection(self):
        """Alias for UseLocalConnection"""
        return self.UseLocalConnection

    @uselocalconnection.setter
    def uselocalconnection(self, value):
        """Alias for UseLocalConnection.setter"""
        self.UseLocalConnection = value

    @property
    def use_local_connection(self):
        """Alias for UseLocalConnection"""
        return self.UseLocalConnection

    @use_local_connection.setter
    def use_local_connection(self, value):
        """Alias for UseLocalConnection.setter"""
        self.UseLocalConnection = value

    @property
    def Version(self):
        return XlPivotTableVersionList(self.com_object.Version)

    @property
    def version(self):
        """Alias for Version"""
        return self.Version

    @property
    def WorkbookConnection(self):
        return self.com_object.WorkbookConnection

    @property
    def workbookconnection(self):
        """Alias for WorkbookConnection"""
        return self.WorkbookConnection

    @property
    def workbook_connection(self):
        """Alias for WorkbookConnection"""
        return self.WorkbookConnection

    def CreatePivotChart(self, ChartDestination=None, XlChartType=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [ChartDestination, XlChartType, Left, Top, Width, Height]])
        return Shape(self.com_object.CreatePivotChart(*arguments))

    def createpivotchart(self, ChartDestination=None, XlChartType=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for CreatePivotChart"""
        arguments = [ChartDestination, XlChartType, Left, Top, Width, Height]
        return self.CreatePivotChart(*arguments)

    def create_pivot_chart(self, ChartDestination=None, XlChartType=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for CreatePivotChart"""
        arguments = [ChartDestination, XlChartType, Left, Top, Width, Height]
        return self.CreatePivotChart(*arguments)

    def CreatePivotTable(self, TableDestination=None, TableName=None, ReadData=None, DefaultVersion=None):
        arguments = com_arguments([unwrap(a) for a in [TableDestination, TableName, ReadData, DefaultVersion]])
        return PivotTable(self.com_object.CreatePivotTable(*arguments))

    def createpivottable(self, TableDestination=None, TableName=None, ReadData=None, DefaultVersion=None):
        """Alias for CreatePivotTable"""
        arguments = [TableDestination, TableName, ReadData, DefaultVersion]
        return self.CreatePivotTable(*arguments)

    def create_pivot_table(self, TableDestination=None, TableName=None, ReadData=None, DefaultVersion=None):
        """Alias for CreatePivotTable"""
        arguments = [TableDestination, TableName, ReadData, DefaultVersion]
        return self.CreatePivotTable(*arguments)

    def MakeConnection(self):
        self.com_object.MakeConnection()

    def makeconnection(self):
        """Alias for MakeConnection"""
        return self.MakeConnection()

    def make_connection(self):
        """Alias for MakeConnection"""
        return self.MakeConnection()

    def Refresh(self):
        self.com_object.Refresh()

    def refresh(self):
        """Alias for Refresh"""
        return self.Refresh()

    def ResetTimer(self):
        self.com_object.ResetTimer()

    def resettimer(self):
        """Alias for ResetTimer"""
        return self.ResetTimer()

    def reset_timer(self):
        """Alias for ResetTimer"""
        return self.ResetTimer()

    def SaveAsODC(self, ODCFileName=None, Description=None, Keywords=None):
        arguments = com_arguments([unwrap(a) for a in [ODCFileName, Description, Keywords]])
        self.com_object.SaveAsODC(*arguments)

    def saveasodc(self, ODCFileName=None, Description=None, Keywords=None):
        """Alias for SaveAsODC"""
        arguments = [ODCFileName, Description, Keywords]
        return self.SaveAsODC(*arguments)

    def save_as_o_d_c(self, ODCFileName=None, Description=None, Keywords=None):
        """Alias for SaveAsODC"""
        arguments = [ODCFileName, Description, Keywords]
        return self.SaveAsODC(*arguments)


class PivotCaches:

    def __init__(self, pivotcaches=None):
        self.com_object= pivotcaches

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Create(self, SourceType=None, SourceData=None, Version=None):
        arguments = com_arguments([unwrap(a) for a in [SourceType, SourceData, Version]])
        return PivotCache(self.com_object.Create(*arguments))

    def create(self, SourceType=None, SourceData=None, Version=None):
        """Alias for Create"""
        arguments = [SourceType, SourceData, Version]
        return self.Create(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return PivotCache(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class PivotCell:

    def __init__(self, pivotcell=None):
        self.com_object= pivotcell

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def CellChanged(self):
        return self.com_object.CellChanged

    @property
    def cellchanged(self):
        """Alias for CellChanged"""
        return self.CellChanged

    @property
    def cell_changed(self):
        """Alias for CellChanged"""
        return self.CellChanged

    @property
    def ColumnItems(self):
        return PivotItemList(self.com_object.ColumnItems)

    @property
    def columnitems(self):
        """Alias for ColumnItems"""
        return self.ColumnItems

    @property
    def column_items(self):
        """Alias for ColumnItems"""
        return self.ColumnItems

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def CustomSubtotalFunction(self):
        return XlConsolidationFunction(self.com_object.CustomSubtotalFunction)

    @property
    def customsubtotalfunction(self):
        """Alias for CustomSubtotalFunction"""
        return self.CustomSubtotalFunction

    @property
    def custom_subtotal_function(self):
        """Alias for CustomSubtotalFunction"""
        return self.CustomSubtotalFunction

    @property
    def DataField(self):
        return PivotField(self.com_object.DataField)

    @property
    def datafield(self):
        """Alias for DataField"""
        return self.DataField

    @property
    def data_field(self):
        """Alias for DataField"""
        return self.DataField

    @property
    def DataSourceValue(self):
        return self.com_object.DataSourceValue

    @property
    def datasourcevalue(self):
        """Alias for DataSourceValue"""
        return self.DataSourceValue

    @property
    def data_source_value(self):
        """Alias for DataSourceValue"""
        return self.DataSourceValue

    @property
    def MDX(self):
        return self.com_object.MDX

    @property
    def mdx(self):
        """Alias for MDX"""
        return self.MDX

    @property
    def m_d_x(self):
        """Alias for MDX"""
        return self.MDX

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PivotCellType(self):
        return XlPivotCellType(self.com_object.PivotCellType)

    @property
    def pivotcelltype(self):
        """Alias for PivotCellType"""
        return self.PivotCellType

    @property
    def pivot_cell_type(self):
        """Alias for PivotCellType"""
        return self.PivotCellType

    @property
    def PivotColumnLine(self):
        return PivotLine(self.com_object.PivotColumnLine)

    @property
    def pivotcolumnline(self):
        """Alias for PivotColumnLine"""
        return self.PivotColumnLine

    @property
    def pivot_column_line(self):
        """Alias for PivotColumnLine"""
        return self.PivotColumnLine

    @property
    def PivotField(self):
        return PivotField(self.com_object.PivotField)

    @property
    def pivotfield(self):
        """Alias for PivotField"""
        return self.PivotField

    @property
    def pivot_field(self):
        """Alias for PivotField"""
        return self.PivotField

    @property
    def PivotItem(self):
        return PivotItem(self.com_object.PivotItem)

    @property
    def pivotitem(self):
        """Alias for PivotItem"""
        return self.PivotItem

    @property
    def pivot_item(self):
        """Alias for PivotItem"""
        return self.PivotItem

    @property
    def PivotRowLine(self):
        return PivotLine(self.com_object.PivotRowLine)

    @property
    def pivotrowline(self):
        """Alias for PivotRowLine"""
        return self.PivotRowLine

    @property
    def pivot_row_line(self):
        """Alias for PivotRowLine"""
        return self.PivotRowLine

    @property
    def PivotTable(self):
        return PivotTable(self.com_object.PivotTable)

    @property
    def pivottable(self):
        """Alias for PivotTable"""
        return self.PivotTable

    @property
    def pivot_table(self):
        """Alias for PivotTable"""
        return self.PivotTable

    @property
    def Range(self):
        return Range(self.com_object.Range)

    @property
    def range(self):
        """Alias for Range"""
        return self.Range

    @property
    def RowItems(self):
        return PivotItemList(self.com_object.RowItems)

    @property
    def rowitems(self):
        """Alias for RowItems"""
        return self.RowItems

    @property
    def row_items(self):
        """Alias for RowItems"""
        return self.RowItems

    @property
    def ServerActions(self):
        return self.com_object.ServerActions

    @property
    def serveractions(self):
        """Alias for ServerActions"""
        return self.ServerActions

    @property
    def server_actions(self):
        """Alias for ServerActions"""
        return self.ServerActions

    def AllocateChange(self):
        return self.com_object.AllocateChange()

    def allocatechange(self):
        """Alias for AllocateChange"""
        return self.AllocateChange()

    def allocate_change(self):
        """Alias for AllocateChange"""
        return self.AllocateChange()

    def DiscardChange(self):
        return self.com_object.DiscardChange()

    def discardchange(self):
        """Alias for DiscardChange"""
        return self.DiscardChange()

    def discard_change(self):
        """Alias for DiscardChange"""
        return self.DiscardChange()


class PivotField:

    def __init__(self, pivotfield=None):
        self.com_object= pivotfield

    @property
    def AllItemsVisible(self):
        return self.com_object.AllItemsVisible

    @property
    def allitemsvisible(self):
        """Alias for AllItemsVisible"""
        return self.AllItemsVisible

    @property
    def all_items_visible(self):
        """Alias for AllItemsVisible"""
        return self.AllItemsVisible

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoShowCount(self):
        return self.com_object.AutoShowCount

    @property
    def autoshowcount(self):
        """Alias for AutoShowCount"""
        return self.AutoShowCount

    @property
    def auto_show_count(self):
        """Alias for AutoShowCount"""
        return self.AutoShowCount

    @property
    def AutoShowField(self):
        return self.com_object.AutoShowField

    @property
    def autoshowfield(self):
        """Alias for AutoShowField"""
        return self.AutoShowField

    @property
    def auto_show_field(self):
        """Alias for AutoShowField"""
        return self.AutoShowField

    @property
    def AutoShowRange(self):
        return self.com_object.AutoShowRange

    @property
    def autoshowrange(self):
        """Alias for AutoShowRange"""
        return self.AutoShowRange

    @property
    def auto_show_range(self):
        """Alias for AutoShowRange"""
        return self.AutoShowRange

    @property
    def AutoShowType(self):
        return self.com_object.AutoShowType

    @property
    def autoshowtype(self):
        """Alias for AutoShowType"""
        return self.AutoShowType

    @property
    def auto_show_type(self):
        """Alias for AutoShowType"""
        return self.AutoShowType

    @property
    def AutoSortCustomSubtotal(self):
        return self.com_object.AutoSortCustomSubtotal

    @property
    def autosortcustomsubtotal(self):
        """Alias for AutoSortCustomSubtotal"""
        return self.AutoSortCustomSubtotal

    @property
    def auto_sort_custom_subtotal(self):
        """Alias for AutoSortCustomSubtotal"""
        return self.AutoSortCustomSubtotal

    @property
    def AutoSortField(self):
        return self.com_object.AutoSortField

    @property
    def autosortfield(self):
        """Alias for AutoSortField"""
        return self.AutoSortField

    @property
    def auto_sort_field(self):
        """Alias for AutoSortField"""
        return self.AutoSortField

    @property
    def AutoSortOrder(self):
        return XlSortOrder(self.com_object.AutoSortOrder)

    @property
    def autosortorder(self):
        """Alias for AutoSortOrder"""
        return self.AutoSortOrder

    @property
    def auto_sort_order(self):
        """Alias for AutoSortOrder"""
        return self.AutoSortOrder

    @property
    def AutoSortPivotLine(self):
        return PivotLine(self.com_object.AutoSortPivotLine)

    @property
    def autosortpivotline(self):
        """Alias for AutoSortPivotLine"""
        return self.AutoSortPivotLine

    @property
    def auto_sort_pivot_line(self):
        """Alias for AutoSortPivotLine"""
        return self.AutoSortPivotLine

    @property
    def BaseField(self):
        return self.com_object.BaseField

    @BaseField.setter
    def BaseField(self, value):
        self.com_object.BaseField = value

    @property
    def basefield(self):
        """Alias for BaseField"""
        return self.BaseField

    @basefield.setter
    def basefield(self, value):
        """Alias for BaseField.setter"""
        self.BaseField = value

    @property
    def base_field(self):
        """Alias for BaseField"""
        return self.BaseField

    @base_field.setter
    def base_field(self, value):
        """Alias for BaseField.setter"""
        self.BaseField = value

    @property
    def BaseItem(self):
        return self.com_object.BaseItem

    @BaseItem.setter
    def BaseItem(self, value):
        self.com_object.BaseItem = value

    @property
    def baseitem(self):
        """Alias for BaseItem"""
        return self.BaseItem

    @baseitem.setter
    def baseitem(self, value):
        """Alias for BaseItem.setter"""
        self.BaseItem = value

    @property
    def base_item(self):
        """Alias for BaseItem"""
        return self.BaseItem

    @base_item.setter
    def base_item(self, value):
        """Alias for BaseItem.setter"""
        self.BaseItem = value

    @property
    def Calculation(self):
        return XlPivotFieldCalculation(self.com_object.Calculation)

    @Calculation.setter
    def Calculation(self, value):
        self.com_object.Calculation = value

    @property
    def calculation(self):
        """Alias for Calculation"""
        return self.Calculation

    @calculation.setter
    def calculation(self, value):
        """Alias for Calculation.setter"""
        self.Calculation = value

    @property
    def Caption(self):
        return self.com_object.Caption

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @property
    def ChildField(self):
        return PivotField(self.com_object.ChildField)

    @property
    def childfield(self):
        """Alias for ChildField"""
        return self.ChildField

    @property
    def child_field(self):
        """Alias for ChildField"""
        return self.ChildField

    def ChildItems(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetChildItems"):
            return PivotItem(self.com_object.GetChildItems(*arguments))
        else:
            return PivotItem(self.com_object.ChildItems(*arguments))

    def childitems(self, Index=None):
        """Alias for ChildItems"""
        arguments = [Index]
        return self.ChildItems(*arguments)

    def child_items(self, Index=None):
        """Alias for ChildItems"""
        arguments = [Index]
        return self.ChildItems(*arguments)

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def CubeField(self):
        return CubeField(self.com_object.CubeField)

    @property
    def cubefield(self):
        """Alias for CubeField"""
        return self.CubeField

    @property
    def cube_field(self):
        """Alias for CubeField"""
        return self.CubeField

    @property
    def CurrentPage(self):
        return PivotItem(self.com_object.CurrentPage)

    @CurrentPage.setter
    def CurrentPage(self, value):
        self.com_object.CurrentPage = value

    @property
    def currentpage(self):
        """Alias for CurrentPage"""
        return self.CurrentPage

    @currentpage.setter
    def currentpage(self, value):
        """Alias for CurrentPage.setter"""
        self.CurrentPage = value

    @property
    def current_page(self):
        """Alias for CurrentPage"""
        return self.CurrentPage

    @current_page.setter
    def current_page(self, value):
        """Alias for CurrentPage.setter"""
        self.CurrentPage = value

    @property
    def CurrentPageList(self):
        return self.com_object.CurrentPageList

    @CurrentPageList.setter
    def CurrentPageList(self, value):
        self.com_object.CurrentPageList = value

    @property
    def currentpagelist(self):
        """Alias for CurrentPageList"""
        return self.CurrentPageList

    @currentpagelist.setter
    def currentpagelist(self, value):
        """Alias for CurrentPageList.setter"""
        self.CurrentPageList = value

    @property
    def current_page_list(self):
        """Alias for CurrentPageList"""
        return self.CurrentPageList

    @current_page_list.setter
    def current_page_list(self, value):
        """Alias for CurrentPageList.setter"""
        self.CurrentPageList = value

    @property
    def CurrentPageName(self):
        return self.com_object.CurrentPageName

    @CurrentPageName.setter
    def CurrentPageName(self, value):
        self.com_object.CurrentPageName = value

    @property
    def currentpagename(self):
        """Alias for CurrentPageName"""
        return self.CurrentPageName

    @currentpagename.setter
    def currentpagename(self, value):
        """Alias for CurrentPageName.setter"""
        self.CurrentPageName = value

    @property
    def current_page_name(self):
        """Alias for CurrentPageName"""
        return self.CurrentPageName

    @current_page_name.setter
    def current_page_name(self, value):
        """Alias for CurrentPageName.setter"""
        self.CurrentPageName = value

    @property
    def DatabaseSort(self):
        return self.com_object.DatabaseSort

    @DatabaseSort.setter
    def DatabaseSort(self, value):
        self.com_object.DatabaseSort = value

    @property
    def databasesort(self):
        """Alias for DatabaseSort"""
        return self.DatabaseSort

    @databasesort.setter
    def databasesort(self, value):
        """Alias for DatabaseSort.setter"""
        self.DatabaseSort = value

    @property
    def database_sort(self):
        """Alias for DatabaseSort"""
        return self.DatabaseSort

    @database_sort.setter
    def database_sort(self, value):
        """Alias for DatabaseSort.setter"""
        self.DatabaseSort = value

    @property
    def DataRange(self):
        return Range(self.com_object.DataRange)

    @property
    def datarange(self):
        """Alias for DataRange"""
        return self.DataRange

    @property
    def data_range(self):
        """Alias for DataRange"""
        return self.DataRange

    @property
    def DataType(self):
        return XlPivotFieldDataType(self.com_object.DataType)

    @property
    def datatype(self):
        """Alias for DataType"""
        return self.DataType

    @property
    def data_type(self):
        """Alias for DataType"""
        return self.DataType

    @property
    def DisplayAsCaption(self):
        return self.com_object.DisplayAsCaption

    @property
    def displayascaption(self):
        """Alias for DisplayAsCaption"""
        return self.DisplayAsCaption

    @property
    def display_as_caption(self):
        """Alias for DisplayAsCaption"""
        return self.DisplayAsCaption

    @property
    def DisplayAsTooltip(self):
        return self.com_object.DisplayAsTooltip

    @DisplayAsTooltip.setter
    def DisplayAsTooltip(self, value):
        self.com_object.DisplayAsTooltip = value

    @property
    def displayastooltip(self):
        """Alias for DisplayAsTooltip"""
        return self.DisplayAsTooltip

    @displayastooltip.setter
    def displayastooltip(self, value):
        """Alias for DisplayAsTooltip.setter"""
        self.DisplayAsTooltip = value

    @property
    def display_as_tooltip(self):
        """Alias for DisplayAsTooltip"""
        return self.DisplayAsTooltip

    @display_as_tooltip.setter
    def display_as_tooltip(self, value):
        """Alias for DisplayAsTooltip.setter"""
        self.DisplayAsTooltip = value

    @property
    def DisplayInReport(self):
        return self.com_object.DisplayInReport

    @DisplayInReport.setter
    def DisplayInReport(self, value):
        self.com_object.DisplayInReport = value

    @property
    def displayinreport(self):
        """Alias for DisplayInReport"""
        return self.DisplayInReport

    @displayinreport.setter
    def displayinreport(self, value):
        """Alias for DisplayInReport.setter"""
        self.DisplayInReport = value

    @property
    def display_in_report(self):
        """Alias for DisplayInReport"""
        return self.DisplayInReport

    @display_in_report.setter
    def display_in_report(self, value):
        """Alias for DisplayInReport.setter"""
        self.DisplayInReport = value

    @property
    def DragToColumn(self):
        return self.com_object.DragToColumn

    @DragToColumn.setter
    def DragToColumn(self, value):
        self.com_object.DragToColumn = value

    @property
    def dragtocolumn(self):
        """Alias for DragToColumn"""
        return self.DragToColumn

    @dragtocolumn.setter
    def dragtocolumn(self, value):
        """Alias for DragToColumn.setter"""
        self.DragToColumn = value

    @property
    def drag_to_column(self):
        """Alias for DragToColumn"""
        return self.DragToColumn

    @drag_to_column.setter
    def drag_to_column(self, value):
        """Alias for DragToColumn.setter"""
        self.DragToColumn = value

    @property
    def DragToData(self):
        return self.com_object.DragToData

    @DragToData.setter
    def DragToData(self, value):
        self.com_object.DragToData = value

    @property
    def dragtodata(self):
        """Alias for DragToData"""
        return self.DragToData

    @dragtodata.setter
    def dragtodata(self, value):
        """Alias for DragToData.setter"""
        self.DragToData = value

    @property
    def drag_to_data(self):
        """Alias for DragToData"""
        return self.DragToData

    @drag_to_data.setter
    def drag_to_data(self, value):
        """Alias for DragToData.setter"""
        self.DragToData = value

    @property
    def DragToHide(self):
        return self.com_object.DragToHide

    @DragToHide.setter
    def DragToHide(self, value):
        self.com_object.DragToHide = value

    @property
    def dragtohide(self):
        """Alias for DragToHide"""
        return self.DragToHide

    @dragtohide.setter
    def dragtohide(self, value):
        """Alias for DragToHide.setter"""
        self.DragToHide = value

    @property
    def drag_to_hide(self):
        """Alias for DragToHide"""
        return self.DragToHide

    @drag_to_hide.setter
    def drag_to_hide(self, value):
        """Alias for DragToHide.setter"""
        self.DragToHide = value

    @property
    def DragToPage(self):
        return self.com_object.DragToPage

    @DragToPage.setter
    def DragToPage(self, value):
        self.com_object.DragToPage = value

    @property
    def dragtopage(self):
        """Alias for DragToPage"""
        return self.DragToPage

    @dragtopage.setter
    def dragtopage(self, value):
        """Alias for DragToPage.setter"""
        self.DragToPage = value

    @property
    def drag_to_page(self):
        """Alias for DragToPage"""
        return self.DragToPage

    @drag_to_page.setter
    def drag_to_page(self, value):
        """Alias for DragToPage.setter"""
        self.DragToPage = value

    @property
    def DragToRow(self):
        return self.com_object.DragToRow

    @DragToRow.setter
    def DragToRow(self, value):
        self.com_object.DragToRow = value

    @property
    def dragtorow(self):
        """Alias for DragToRow"""
        return self.DragToRow

    @dragtorow.setter
    def dragtorow(self, value):
        """Alias for DragToRow.setter"""
        self.DragToRow = value

    @property
    def drag_to_row(self):
        """Alias for DragToRow"""
        return self.DragToRow

    @drag_to_row.setter
    def drag_to_row(self, value):
        """Alias for DragToRow.setter"""
        self.DragToRow = value

    @property
    def DrilledDown(self):
        return self.com_object.DrilledDown

    @DrilledDown.setter
    def DrilledDown(self, value):
        self.com_object.DrilledDown = value

    @property
    def drilleddown(self):
        """Alias for DrilledDown"""
        return self.DrilledDown

    @drilleddown.setter
    def drilleddown(self, value):
        """Alias for DrilledDown.setter"""
        self.DrilledDown = value

    @property
    def drilled_down(self):
        """Alias for DrilledDown"""
        return self.DrilledDown

    @drilled_down.setter
    def drilled_down(self, value):
        """Alias for DrilledDown.setter"""
        self.DrilledDown = value

    @property
    def EnableItemSelection(self):
        return self.com_object.EnableItemSelection

    @EnableItemSelection.setter
    def EnableItemSelection(self, value):
        self.com_object.EnableItemSelection = value

    @property
    def enableitemselection(self):
        """Alias for EnableItemSelection"""
        return self.EnableItemSelection

    @enableitemselection.setter
    def enableitemselection(self, value):
        """Alias for EnableItemSelection.setter"""
        self.EnableItemSelection = value

    @property
    def enable_item_selection(self):
        """Alias for EnableItemSelection"""
        return self.EnableItemSelection

    @enable_item_selection.setter
    def enable_item_selection(self, value):
        """Alias for EnableItemSelection.setter"""
        self.EnableItemSelection = value

    @property
    def EnableMultiplePageItems(self):
        return self.com_object.EnableMultiplePageItems

    @EnableMultiplePageItems.setter
    def EnableMultiplePageItems(self, value):
        self.com_object.EnableMultiplePageItems = value

    @property
    def enablemultiplepageitems(self):
        """Alias for EnableMultiplePageItems"""
        return self.EnableMultiplePageItems

    @enablemultiplepageitems.setter
    def enablemultiplepageitems(self, value):
        """Alias for EnableMultiplePageItems.setter"""
        self.EnableMultiplePageItems = value

    @property
    def enable_multiple_page_items(self):
        """Alias for EnableMultiplePageItems"""
        return self.EnableMultiplePageItems

    @enable_multiple_page_items.setter
    def enable_multiple_page_items(self, value):
        """Alias for EnableMultiplePageItems.setter"""
        self.EnableMultiplePageItems = value

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def Function(self):
        return XlConsolidationFunction(self.com_object.Function)

    @Function.setter
    def Function(self, value):
        self.com_object.Function = value

    @property
    def function(self):
        """Alias for Function"""
        return self.Function

    @function.setter
    def function(self, value):
        """Alias for Function.setter"""
        self.Function = value

    @property
    def GroupLevel(self):
        return self.com_object.GroupLevel

    @property
    def grouplevel(self):
        """Alias for GroupLevel"""
        return self.GroupLevel

    @property
    def group_level(self):
        """Alias for GroupLevel"""
        return self.GroupLevel

    @property
    def Hidden(self):
        return self.com_object.Hidden

    @Hidden.setter
    def Hidden(self, value):
        self.com_object.Hidden = value

    @property
    def hidden(self):
        """Alias for Hidden"""
        return self.Hidden

    @hidden.setter
    def hidden(self, value):
        """Alias for Hidden.setter"""
        self.Hidden = value

    def HiddenItems(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetHiddenItems"):
            return PivotItem(self.com_object.GetHiddenItems(*arguments))
        else:
            return PivotItem(self.com_object.HiddenItems(*arguments))

    def hiddenitems(self, Index=None):
        """Alias for HiddenItems"""
        arguments = [Index]
        return self.HiddenItems(*arguments)

    def hidden_items(self, Index=None):
        """Alias for HiddenItems"""
        arguments = [Index]
        return self.HiddenItems(*arguments)

    @property
    def HiddenItemsList(self):
        return self.com_object.HiddenItemsList

    @HiddenItemsList.setter
    def HiddenItemsList(self, value):
        self.com_object.HiddenItemsList = value

    @property
    def hiddenitemslist(self):
        """Alias for HiddenItemsList"""
        return self.HiddenItemsList

    @hiddenitemslist.setter
    def hiddenitemslist(self, value):
        """Alias for HiddenItemsList.setter"""
        self.HiddenItemsList = value

    @property
    def hidden_items_list(self):
        """Alias for HiddenItemsList"""
        return self.HiddenItemsList

    @hidden_items_list.setter
    def hidden_items_list(self, value):
        """Alias for HiddenItemsList.setter"""
        self.HiddenItemsList = value

    @property
    def IncludeNewItemsInFilter(self):
        return self.com_object.IncludeNewItemsInFilter

    @IncludeNewItemsInFilter.setter
    def IncludeNewItemsInFilter(self, value):
        self.com_object.IncludeNewItemsInFilter = value

    @property
    def includenewitemsinfilter(self):
        """Alias for IncludeNewItemsInFilter"""
        return self.IncludeNewItemsInFilter

    @includenewitemsinfilter.setter
    def includenewitemsinfilter(self, value):
        """Alias for IncludeNewItemsInFilter.setter"""
        self.IncludeNewItemsInFilter = value

    @property
    def include_new_items_in_filter(self):
        """Alias for IncludeNewItemsInFilter"""
        return self.IncludeNewItemsInFilter

    @include_new_items_in_filter.setter
    def include_new_items_in_filter(self, value):
        """Alias for IncludeNewItemsInFilter.setter"""
        self.IncludeNewItemsInFilter = value

    @property
    def IsCalculated(self):
        return self.com_object.IsCalculated

    @property
    def iscalculated(self):
        """Alias for IsCalculated"""
        return self.IsCalculated

    @property
    def is_calculated(self):
        """Alias for IsCalculated"""
        return self.IsCalculated

    @property
    def IsMemberProperty(self):
        return self.com_object.IsMemberProperty

    @property
    def ismemberproperty(self):
        """Alias for IsMemberProperty"""
        return self.IsMemberProperty

    @property
    def is_member_property(self):
        """Alias for IsMemberProperty"""
        return self.IsMemberProperty

    @property
    def LabelRange(self):
        return Range(self.com_object.LabelRange)

    @property
    def labelrange(self):
        """Alias for LabelRange"""
        return self.LabelRange

    @property
    def label_range(self):
        """Alias for LabelRange"""
        return self.LabelRange

    @property
    def LayoutBlankLine(self):
        return self.com_object.LayoutBlankLine

    @LayoutBlankLine.setter
    def LayoutBlankLine(self, value):
        self.com_object.LayoutBlankLine = value

    @property
    def layoutblankline(self):
        """Alias for LayoutBlankLine"""
        return self.LayoutBlankLine

    @layoutblankline.setter
    def layoutblankline(self, value):
        """Alias for LayoutBlankLine.setter"""
        self.LayoutBlankLine = value

    @property
    def layout_blank_line(self):
        """Alias for LayoutBlankLine"""
        return self.LayoutBlankLine

    @layout_blank_line.setter
    def layout_blank_line(self, value):
        """Alias for LayoutBlankLine.setter"""
        self.LayoutBlankLine = value

    @property
    def LayoutCompactRow(self):
        return self.com_object.LayoutCompactRow

    @LayoutCompactRow.setter
    def LayoutCompactRow(self, value):
        self.com_object.LayoutCompactRow = value

    @property
    def layoutcompactrow(self):
        """Alias for LayoutCompactRow"""
        return self.LayoutCompactRow

    @layoutcompactrow.setter
    def layoutcompactrow(self, value):
        """Alias for LayoutCompactRow.setter"""
        self.LayoutCompactRow = value

    @property
    def layout_compact_row(self):
        """Alias for LayoutCompactRow"""
        return self.LayoutCompactRow

    @layout_compact_row.setter
    def layout_compact_row(self, value):
        """Alias for LayoutCompactRow.setter"""
        self.LayoutCompactRow = value

    @property
    def LayoutForm(self):
        return XlLayoutFormType(self.com_object.LayoutForm)

    @LayoutForm.setter
    def LayoutForm(self, value):
        self.com_object.LayoutForm = value

    @property
    def layoutform(self):
        """Alias for LayoutForm"""
        return self.LayoutForm

    @layoutform.setter
    def layoutform(self, value):
        """Alias for LayoutForm.setter"""
        self.LayoutForm = value

    @property
    def layout_form(self):
        """Alias for LayoutForm"""
        return self.LayoutForm

    @layout_form.setter
    def layout_form(self, value):
        """Alias for LayoutForm.setter"""
        self.LayoutForm = value

    @property
    def LayoutPageBreak(self):
        return self.com_object.LayoutPageBreak

    @LayoutPageBreak.setter
    def LayoutPageBreak(self, value):
        self.com_object.LayoutPageBreak = value

    @property
    def layoutpagebreak(self):
        """Alias for LayoutPageBreak"""
        return self.LayoutPageBreak

    @layoutpagebreak.setter
    def layoutpagebreak(self, value):
        """Alias for LayoutPageBreak.setter"""
        self.LayoutPageBreak = value

    @property
    def layout_page_break(self):
        """Alias for LayoutPageBreak"""
        return self.LayoutPageBreak

    @layout_page_break.setter
    def layout_page_break(self, value):
        """Alias for LayoutPageBreak.setter"""
        self.LayoutPageBreak = value

    @property
    def LayoutSubtotalLocation(self):
        return XlSubtotalLocationType(self.com_object.LayoutSubtotalLocation)

    @LayoutSubtotalLocation.setter
    def LayoutSubtotalLocation(self, value):
        self.com_object.LayoutSubtotalLocation = value

    @property
    def layoutsubtotallocation(self):
        """Alias for LayoutSubtotalLocation"""
        return self.LayoutSubtotalLocation

    @layoutsubtotallocation.setter
    def layoutsubtotallocation(self, value):
        """Alias for LayoutSubtotalLocation.setter"""
        self.LayoutSubtotalLocation = value

    @property
    def layout_subtotal_location(self):
        """Alias for LayoutSubtotalLocation"""
        return self.LayoutSubtotalLocation

    @layout_subtotal_location.setter
    def layout_subtotal_location(self, value):
        """Alias for LayoutSubtotalLocation.setter"""
        self.LayoutSubtotalLocation = value

    @property
    def MemberPropertyCaption(self):
        return self.com_object.MemberPropertyCaption

    @MemberPropertyCaption.setter
    def MemberPropertyCaption(self, value):
        self.com_object.MemberPropertyCaption = value

    @property
    def memberpropertycaption(self):
        """Alias for MemberPropertyCaption"""
        return self.MemberPropertyCaption

    @memberpropertycaption.setter
    def memberpropertycaption(self, value):
        """Alias for MemberPropertyCaption.setter"""
        self.MemberPropertyCaption = value

    @property
    def member_property_caption(self):
        """Alias for MemberPropertyCaption"""
        return self.MemberPropertyCaption

    @member_property_caption.setter
    def member_property_caption(self, value):
        """Alias for MemberPropertyCaption.setter"""
        self.MemberPropertyCaption = value

    @property
    def MemoryUsed(self):
        return self.com_object.MemoryUsed

    @property
    def memoryused(self):
        """Alias for MemoryUsed"""
        return self.MemoryUsed

    @property
    def memory_used(self):
        """Alias for MemoryUsed"""
        return self.MemoryUsed

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def NumberFormat(self):
        return self.com_object.NumberFormat

    @NumberFormat.setter
    def NumberFormat(self, value):
        self.com_object.NumberFormat = value

    @property
    def numberformat(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @numberformat.setter
    def numberformat(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def number_format(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @number_format.setter
    def number_format(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def Orientation(self):
        return XlPivotFieldOrientation(self.com_object.Orientation)

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ParentField(self):
        return PivotField(self.com_object.ParentField)

    @property
    def parentfield(self):
        """Alias for ParentField"""
        return self.ParentField

    @property
    def parent_field(self):
        """Alias for ParentField"""
        return self.ParentField

    def ParentItems(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetParentItems"):
            return PivotItem(self.com_object.GetParentItems(*arguments))
        else:
            return PivotItem(self.com_object.ParentItems(*arguments))

    def parentitems(self, Index=None):
        """Alias for ParentItems"""
        arguments = [Index]
        return self.ParentItems(*arguments)

    def parent_items(self, Index=None):
        """Alias for ParentItems"""
        arguments = [Index]
        return self.ParentItems(*arguments)

    @property
    def PivotFilters(self):
        return PivotField(self.com_object.PivotFilters)

    @PivotFilters.setter
    def PivotFilters(self, value):
        self.com_object.PivotFilters = value

    @property
    def pivotfilters(self):
        """Alias for PivotFilters"""
        return self.PivotFilters

    @pivotfilters.setter
    def pivotfilters(self, value):
        """Alias for PivotFilters.setter"""
        self.PivotFilters = value

    @property
    def pivot_filters(self):
        """Alias for PivotFilters"""
        return self.PivotFilters

    @pivot_filters.setter
    def pivot_filters(self, value):
        """Alias for PivotFilters.setter"""
        self.PivotFilters = value

    @property
    def Position(self):
        return self.com_object.Position

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def PropertyOrder(self):
        return self.com_object.PropertyOrder

    @PropertyOrder.setter
    def PropertyOrder(self, value):
        self.com_object.PropertyOrder = value

    @property
    def propertyorder(self):
        """Alias for PropertyOrder"""
        return self.PropertyOrder

    @propertyorder.setter
    def propertyorder(self, value):
        """Alias for PropertyOrder.setter"""
        self.PropertyOrder = value

    @property
    def property_order(self):
        """Alias for PropertyOrder"""
        return self.PropertyOrder

    @property_order.setter
    def property_order(self, value):
        """Alias for PropertyOrder.setter"""
        self.PropertyOrder = value

    @property
    def PropertyParentField(self):
        return PivotField(self.com_object.PropertyParentField)

    @property
    def propertyparentfield(self):
        """Alias for PropertyParentField"""
        return self.PropertyParentField

    @property
    def property_parent_field(self):
        """Alias for PropertyParentField"""
        return self.PropertyParentField

    @property
    def RepeatLabels(self):
        return self.com_object.RepeatLabels

    @RepeatLabels.setter
    def RepeatLabels(self, value):
        self.com_object.RepeatLabels = value

    @property
    def repeatlabels(self):
        """Alias for RepeatLabels"""
        return self.RepeatLabels

    @repeatlabels.setter
    def repeatlabels(self, value):
        """Alias for RepeatLabels.setter"""
        self.RepeatLabels = value

    @property
    def repeat_labels(self):
        """Alias for RepeatLabels"""
        return self.RepeatLabels

    @repeat_labels.setter
    def repeat_labels(self, value):
        """Alias for RepeatLabels.setter"""
        self.RepeatLabels = value

    @property
    def ServerBased(self):
        return self.com_object.ServerBased

    @ServerBased.setter
    def ServerBased(self, value):
        self.com_object.ServerBased = value

    @property
    def serverbased(self):
        """Alias for ServerBased"""
        return self.ServerBased

    @serverbased.setter
    def serverbased(self, value):
        """Alias for ServerBased.setter"""
        self.ServerBased = value

    @property
    def server_based(self):
        """Alias for ServerBased"""
        return self.ServerBased

    @server_based.setter
    def server_based(self, value):
        """Alias for ServerBased.setter"""
        self.ServerBased = value

    @property
    def ShowAllItems(self):
        return self.com_object.ShowAllItems

    @ShowAllItems.setter
    def ShowAllItems(self, value):
        self.com_object.ShowAllItems = value

    @property
    def showallitems(self):
        """Alias for ShowAllItems"""
        return self.ShowAllItems

    @showallitems.setter
    def showallitems(self, value):
        """Alias for ShowAllItems.setter"""
        self.ShowAllItems = value

    @property
    def show_all_items(self):
        """Alias for ShowAllItems"""
        return self.ShowAllItems

    @show_all_items.setter
    def show_all_items(self, value):
        """Alias for ShowAllItems.setter"""
        self.ShowAllItems = value

    @property
    def ShowDetail(self):
        return self.com_object.ShowDetail

    @ShowDetail.setter
    def ShowDetail(self, value):
        self.com_object.ShowDetail = value

    @property
    def showdetail(self):
        """Alias for ShowDetail"""
        return self.ShowDetail

    @showdetail.setter
    def showdetail(self, value):
        """Alias for ShowDetail.setter"""
        self.ShowDetail = value

    @property
    def show_detail(self):
        """Alias for ShowDetail"""
        return self.ShowDetail

    @show_detail.setter
    def show_detail(self, value):
        """Alias for ShowDetail.setter"""
        self.ShowDetail = value

    @property
    def ShowingInAxis(self):
        return self.com_object.ShowingInAxis

    @property
    def showinginaxis(self):
        """Alias for ShowingInAxis"""
        return self.ShowingInAxis

    @property
    def showing_in_axis(self):
        """Alias for ShowingInAxis"""
        return self.ShowingInAxis

    @property
    def SourceCaption(self):
        return self.com_object.SourceCaption

    @property
    def sourcecaption(self):
        """Alias for SourceCaption"""
        return self.SourceCaption

    @property
    def source_caption(self):
        """Alias for SourceCaption"""
        return self.SourceCaption

    @property
    def SourceName(self):
        return self.com_object.SourceName

    @property
    def sourcename(self):
        """Alias for SourceName"""
        return self.SourceName

    @property
    def source_name(self):
        """Alias for SourceName"""
        return self.SourceName

    @property
    def StandardFormula(self):
        return self.com_object.StandardFormula

    @StandardFormula.setter
    def StandardFormula(self, value):
        self.com_object.StandardFormula = value

    @property
    def standardformula(self):
        """Alias for StandardFormula"""
        return self.StandardFormula

    @standardformula.setter
    def standardformula(self, value):
        """Alias for StandardFormula.setter"""
        self.StandardFormula = value

    @property
    def standard_formula(self):
        """Alias for StandardFormula"""
        return self.StandardFormula

    @standard_formula.setter
    def standard_formula(self, value):
        """Alias for StandardFormula.setter"""
        self.StandardFormula = value

    @property
    def SubtotalName(self):
        return self.com_object.SubtotalName

    @SubtotalName.setter
    def SubtotalName(self, value):
        self.com_object.SubtotalName = value

    @property
    def subtotalname(self):
        """Alias for SubtotalName"""
        return self.SubtotalName

    @subtotalname.setter
    def subtotalname(self, value):
        """Alias for SubtotalName.setter"""
        self.SubtotalName = value

    @property
    def subtotal_name(self):
        """Alias for SubtotalName"""
        return self.SubtotalName

    @subtotal_name.setter
    def subtotal_name(self, value):
        """Alias for SubtotalName.setter"""
        self.SubtotalName = value

    @property
    def Subtotals(self):
        return self.com_object.Subtotals

    @Subtotals.setter
    def Subtotals(self, value):
        self.com_object.Subtotals = value

    @property
    def subtotals(self):
        """Alias for Subtotals"""
        return self.Subtotals

    @subtotals.setter
    def subtotals(self, value):
        """Alias for Subtotals.setter"""
        self.Subtotals = value

    @property
    def TotalLevels(self):
        return self.com_object.TotalLevels

    @property
    def totallevels(self):
        """Alias for TotalLevels"""
        return self.TotalLevels

    @property
    def total_levels(self):
        """Alias for TotalLevels"""
        return self.TotalLevels

    @property
    def UseMemberPropertyAsCaption(self):
        return self.com_object.UseMemberPropertyAsCaption

    @UseMemberPropertyAsCaption.setter
    def UseMemberPropertyAsCaption(self, value):
        self.com_object.UseMemberPropertyAsCaption = value

    @property
    def usememberpropertyascaption(self):
        """Alias for UseMemberPropertyAsCaption"""
        return self.UseMemberPropertyAsCaption

    @usememberpropertyascaption.setter
    def usememberpropertyascaption(self, value):
        """Alias for UseMemberPropertyAsCaption.setter"""
        self.UseMemberPropertyAsCaption = value

    @property
    def use_member_property_as_caption(self):
        """Alias for UseMemberPropertyAsCaption"""
        return self.UseMemberPropertyAsCaption

    @use_member_property_as_caption.setter
    def use_member_property_as_caption(self, value):
        """Alias for UseMemberPropertyAsCaption.setter"""
        self.UseMemberPropertyAsCaption = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    def VisibleItems(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetVisibleItems"):
            return PivotItem(self.com_object.GetVisibleItems(*arguments))
        else:
            return PivotItem(self.com_object.VisibleItems(*arguments))

    def visibleitems(self, Index=None):
        """Alias for VisibleItems"""
        arguments = [Index]
        return self.VisibleItems(*arguments)

    def visible_items(self, Index=None):
        """Alias for VisibleItems"""
        arguments = [Index]
        return self.VisibleItems(*arguments)

    @property
    def VisibleItemsList(self):
        return self.com_object.VisibleItemsList

    @VisibleItemsList.setter
    def VisibleItemsList(self, value):
        self.com_object.VisibleItemsList = value

    @property
    def visibleitemslist(self):
        """Alias for VisibleItemsList"""
        return self.VisibleItemsList

    @visibleitemslist.setter
    def visibleitemslist(self, value):
        """Alias for VisibleItemsList.setter"""
        self.VisibleItemsList = value

    @property
    def visible_items_list(self):
        """Alias for VisibleItemsList"""
        return self.VisibleItemsList

    @visible_items_list.setter
    def visible_items_list(self, value):
        """Alias for VisibleItemsList.setter"""
        self.VisibleItemsList = value

    def AddPageItem(self, Item=None, ClearList=None):
        arguments = com_arguments([unwrap(a) for a in [Item, ClearList]])
        self.com_object.AddPageItem(*arguments)

    def addpageitem(self, Item=None, ClearList=None):
        """Alias for AddPageItem"""
        arguments = [Item, ClearList]
        return self.AddPageItem(*arguments)

    def add_page_item(self, Item=None, ClearList=None):
        """Alias for AddPageItem"""
        arguments = [Item, ClearList]
        return self.AddPageItem(*arguments)

    def AutoGroup(self):
        self.com_object.AutoGroup()

    def autogroup(self):
        """Alias for AutoGroup"""
        return self.AutoGroup()

    def auto_group(self):
        """Alias for AutoGroup"""
        return self.AutoGroup()

    def AutoShow(self, Type=None, Range=None, Count=None, Field=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Range, Count, Field]])
        self.com_object.AutoShow(*arguments)

    def autoshow(self, Type=None, Range=None, Count=None, Field=None):
        """Alias for AutoShow"""
        arguments = [Type, Range, Count, Field]
        return self.AutoShow(*arguments)

    def auto_show(self, Type=None, Range=None, Count=None, Field=None):
        """Alias for AutoShow"""
        arguments = [Type, Range, Count, Field]
        return self.AutoShow(*arguments)

    def AutoSort(self, Order=None, Field=None, PivotLine=None, CustomSubtotal=None):
        arguments = com_arguments([unwrap(a) for a in [Order, Field, PivotLine, CustomSubtotal]])
        self.com_object.AutoSort(*arguments)

    def autosort(self, Order=None, Field=None, PivotLine=None, CustomSubtotal=None):
        """Alias for AutoSort"""
        arguments = [Order, Field, PivotLine, CustomSubtotal]
        return self.AutoSort(*arguments)

    def auto_sort(self, Order=None, Field=None, PivotLine=None, CustomSubtotal=None):
        """Alias for AutoSort"""
        arguments = [Order, Field, PivotLine, CustomSubtotal]
        return self.AutoSort(*arguments)

    def CalculatedItems(self):
        return CalculatedItems(self.com_object.CalculatedItems())

    def calculateditems(self):
        """Alias for CalculatedItems"""
        return self.CalculatedItems()

    def calculated_items(self):
        """Alias for CalculatedItems"""
        return self.CalculatedItems()

    def ClearAllFilters(self):
        self.com_object.ClearAllFilters()

    def clearallfilters(self):
        """Alias for ClearAllFilters"""
        return self.ClearAllFilters()

    def clear_all_filters(self):
        """Alias for ClearAllFilters"""
        return self.ClearAllFilters()

    def ClearLabelFilters(self):
        self.com_object.ClearLabelFilters()

    def clearlabelfilters(self):
        """Alias for ClearLabelFilters"""
        return self.ClearLabelFilters()

    def clear_label_filters(self):
        """Alias for ClearLabelFilters"""
        return self.ClearLabelFilters()

    def ClearManualFilter(self):
        self.com_object.ClearManualFilter()

    def clearmanualfilter(self):
        """Alias for ClearManualFilter"""
        return self.ClearManualFilter()

    def clear_manual_filter(self):
        """Alias for ClearManualFilter"""
        return self.ClearManualFilter()

    def ClearValueFilters(self):
        self.com_object.ClearValueFilters()

    def clearvaluefilters(self):
        """Alias for ClearValueFilters"""
        return self.ClearValueFilters()

    def clear_value_filters(self):
        """Alias for ClearValueFilters"""
        return self.ClearValueFilters()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def DrillTo(self, PivotFieldName=None):
        arguments = com_arguments([unwrap(a) for a in [PivotFieldName]])
        self.com_object.DrillTo(*arguments)

    def drillto(self, PivotFieldName=None):
        """Alias for DrillTo"""
        arguments = [PivotFieldName]
        return self.DrillTo(*arguments)

    def drill_to(self, PivotFieldName=None):
        """Alias for DrillTo"""
        arguments = [PivotFieldName]
        return self.DrillTo(*arguments)

    def PivotItems(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.PivotItems(*arguments)

    def pivotitems(self, Index=None):
        """Alias for PivotItems"""
        arguments = [Index]
        return self.PivotItems(*arguments)

    def pivot_items(self, Index=None):
        """Alias for PivotItems"""
        arguments = [Index]
        return self.PivotItems(*arguments)


class PivotFields:

    def __init__(self, pivotfields=None):
        self.com_object= pivotfields

    def __call__(self, item):
        return PivotField(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class PivotFilter:

    def __init__(self, pivotfilter=None):
        self.com_object= pivotfilter

    @property
    def Active(self):
        return self.com_object.Active

    @property
    def active(self):
        """Alias for Active"""
        return self.Active

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DataCubeField(self):
        return self.com_object.DataCubeField

    @DataCubeField.setter
    def DataCubeField(self, value):
        self.com_object.DataCubeField = value

    @property
    def datacubefield(self):
        """Alias for DataCubeField"""
        return self.DataCubeField

    @datacubefield.setter
    def datacubefield(self, value):
        """Alias for DataCubeField.setter"""
        self.DataCubeField = value

    @property
    def data_cube_field(self):
        """Alias for DataCubeField"""
        return self.DataCubeField

    @data_cube_field.setter
    def data_cube_field(self, value):
        """Alias for DataCubeField.setter"""
        self.DataCubeField = value

    @property
    def DataField(self):
        return self.com_object.DataField

    @DataField.setter
    def DataField(self, value):
        self.com_object.DataField = value

    @property
    def datafield(self):
        """Alias for DataField"""
        return self.DataField

    @datafield.setter
    def datafield(self, value):
        """Alias for DataField.setter"""
        self.DataField = value

    @property
    def data_field(self):
        """Alias for DataField"""
        return self.DataField

    @data_field.setter
    def data_field(self, value):
        """Alias for DataField.setter"""
        self.DataField = value

    @property
    def Description(self):
        return self.com_object.Description

    @property
    def description(self):
        """Alias for Description"""
        return self.Description

    @property
    def FilterType(self):
        return self.com_object.FilterType

    @property
    def filtertype(self):
        """Alias for FilterType"""
        return self.FilterType

    @property
    def filter_type(self):
        """Alias for FilterType"""
        return self.FilterType

    @property
    def IsMemberPropertyFilter(self):
        return self.com_object.IsMemberPropertyFilter

    @property
    def ismemberpropertyfilter(self):
        """Alias for IsMemberPropertyFilter"""
        return self.IsMemberPropertyFilter

    @property
    def is_member_property_filter(self):
        """Alias for IsMemberPropertyFilter"""
        return self.IsMemberPropertyFilter

    @property
    def MemberPropertyField(self):
        return self.com_object.MemberPropertyField

    @MemberPropertyField.setter
    def MemberPropertyField(self, value):
        self.com_object.MemberPropertyField = value

    @property
    def memberpropertyfield(self):
        """Alias for MemberPropertyField"""
        return self.MemberPropertyField

    @memberpropertyfield.setter
    def memberpropertyfield(self, value):
        """Alias for MemberPropertyField.setter"""
        self.MemberPropertyField = value

    @property
    def member_property_field(self):
        """Alias for MemberPropertyField"""
        return self.MemberPropertyField

    @member_property_field.setter
    def member_property_field(self, value):
        """Alias for MemberPropertyField.setter"""
        self.MemberPropertyField = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Order(self):
        return self.com_object.Order

    @Order.setter
    def Order(self, value):
        self.com_object.Order = value

    @property
    def order(self):
        """Alias for Order"""
        return self.Order

    @order.setter
    def order(self, value):
        """Alias for Order.setter"""
        self.Order = value

    @property
    def Parent(self):
        return PivotFilter(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PivotField(self):
        return self.com_object.PivotField

    @property
    def pivotfield(self):
        """Alias for PivotField"""
        return self.PivotField

    @property
    def pivot_field(self):
        """Alias for PivotField"""
        return self.PivotField

    @property
    def Value1(self):
        return self.com_object.Value1

    @Value1.setter
    def Value1(self, value):
        self.com_object.Value1 = value

    @property
    def value1(self):
        """Alias for Value1"""
        return self.Value1

    @value1.setter
    def value1(self, value):
        """Alias for Value1.setter"""
        self.Value1 = value

    @property
    def Value2(self):
        return self.com_object.Value2

    @Value2.setter
    def Value2(self, value):
        self.com_object.Value2 = value

    @property
    def value2(self):
        """Alias for Value2"""
        return self.Value2

    @value2.setter
    def value2(self, value):
        """Alias for Value2.setter"""
        self.Value2 = value

    @property
    def WholeDayFilter(self):
        return self.com_object.WholeDayFilter

    @WholeDayFilter.setter
    def WholeDayFilter(self, value):
        self.com_object.WholeDayFilter = value

    @property
    def wholedayfilter(self):
        """Alias for WholeDayFilter"""
        return self.WholeDayFilter

    @wholedayfilter.setter
    def wholedayfilter(self, value):
        """Alias for WholeDayFilter.setter"""
        self.WholeDayFilter = value

    @property
    def whole_day_filter(self):
        """Alias for WholeDayFilter"""
        return self.WholeDayFilter

    @whole_day_filter.setter
    def whole_day_filter(self, value):
        """Alias for WholeDayFilter.setter"""
        self.WholeDayFilter = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class PivotFilters:

    def __init__(self, pivotfilters=None):
        self.com_object= pivotfilters

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return PivotFilters(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return PivotFilters(self.com_object.GetItem(*arguments))
        else:
            return PivotFilters(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return PivotFilters(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Type=None, DataField=None, Value1=None, Value2=None, Order=None, Name=None, Description=None, MemberPropertyField=None, WholeDayFilter=None):
        arguments = com_arguments([unwrap(a) for a in [Type, DataField, Value1, Value2, Order, Name, Description, MemberPropertyField, WholeDayFilter]])
        return PivotFilter(self.com_object.Add(*arguments))

    def add(self, Type=None, DataField=None, Value1=None, Value2=None, Order=None, Name=None, Description=None, MemberPropertyField=None, WholeDayFilter=None):
        """Alias for Add"""
        arguments = [Type, DataField, Value1, Value2, Order, Name, Description, MemberPropertyField, WholeDayFilter]
        return self.Add(*arguments)


class PivotFormula:

    def __init__(self, pivotformula=None):
        self.com_object= pivotformula

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def Index(self):
        return PivotFormulas(self.com_object.Index)

    @Index.setter
    def Index(self, value):
        self.com_object.Index = value

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @index.setter
    def index(self, value):
        """Alias for Index.setter"""
        self.Index = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def StandardFormula(self):
        return self.com_object.StandardFormula

    @StandardFormula.setter
    def StandardFormula(self, value):
        self.com_object.StandardFormula = value

    @property
    def standardformula(self):
        """Alias for StandardFormula"""
        return self.StandardFormula

    @standardformula.setter
    def standardformula(self, value):
        """Alias for StandardFormula.setter"""
        self.StandardFormula = value

    @property
    def standard_formula(self):
        """Alias for StandardFormula"""
        return self.StandardFormula

    @standard_formula.setter
    def standard_formula(self, value):
        """Alias for StandardFormula.setter"""
        self.StandardFormula = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class PivotFormulas:

    def __init__(self, pivotformulas=None):
        self.com_object= pivotformulas

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Formula=None, UseStandardFormula=None):
        arguments = com_arguments([unwrap(a) for a in [Formula, UseStandardFormula]])
        return PivotFormula(self.com_object.Add(*arguments))

    def add(self, Formula=None, UseStandardFormula=None):
        """Alias for Add"""
        arguments = [Formula, UseStandardFormula]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return PivotFormula(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class PivotItem:

    def __init__(self, pivotitem=None):
        self.com_object= pivotitem

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Caption(self):
        return self.com_object.Caption

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    def ChildItems(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetChildItems"):
            return PivotItem(self.com_object.GetChildItems(*arguments))
        else:
            return PivotItem(self.com_object.ChildItems(*arguments))

    def childitems(self, Index=None):
        """Alias for ChildItems"""
        arguments = [Index]
        return self.ChildItems(*arguments)

    def child_items(self, Index=None):
        """Alias for ChildItems"""
        arguments = [Index]
        return self.ChildItems(*arguments)

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DataRange(self):
        return Range(self.com_object.DataRange)

    @property
    def datarange(self):
        """Alias for DataRange"""
        return self.DataRange

    @property
    def data_range(self):
        """Alias for DataRange"""
        return self.DataRange

    @property
    def DrilledDown(self):
        return self.com_object.DrilledDown

    @DrilledDown.setter
    def DrilledDown(self, value):
        self.com_object.DrilledDown = value

    @property
    def drilleddown(self):
        """Alias for DrilledDown"""
        return self.DrilledDown

    @drilleddown.setter
    def drilleddown(self, value):
        """Alias for DrilledDown.setter"""
        self.DrilledDown = value

    @property
    def drilled_down(self):
        """Alias for DrilledDown"""
        return self.DrilledDown

    @drilled_down.setter
    def drilled_down(self, value):
        """Alias for DrilledDown.setter"""
        self.DrilledDown = value

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def IsCalculated(self):
        return self.com_object.IsCalculated

    @property
    def iscalculated(self):
        """Alias for IsCalculated"""
        return self.IsCalculated

    @property
    def is_calculated(self):
        """Alias for IsCalculated"""
        return self.IsCalculated

    @property
    def LabelRange(self):
        return Range(self.com_object.LabelRange)

    @property
    def labelrange(self):
        """Alias for LabelRange"""
        return self.LabelRange

    @property
    def label_range(self):
        """Alias for LabelRange"""
        return self.LabelRange

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ParentItem(self):
        return PivotField(self.com_object.ParentItem)

    @property
    def parentitem(self):
        """Alias for ParentItem"""
        return self.ParentItem

    @property
    def parent_item(self):
        """Alias for ParentItem"""
        return self.ParentItem

    @property
    def ParentShowDetail(self):
        return self.com_object.ParentShowDetail

    @property
    def parentshowdetail(self):
        """Alias for ParentShowDetail"""
        return self.ParentShowDetail

    @property
    def parent_show_detail(self):
        """Alias for ParentShowDetail"""
        return self.ParentShowDetail

    @property
    def Position(self):
        return self.com_object.Position

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def RecordCount(self):
        return self.com_object.RecordCount

    @property
    def recordcount(self):
        """Alias for RecordCount"""
        return self.RecordCount

    @property
    def record_count(self):
        """Alias for RecordCount"""
        return self.RecordCount

    @property
    def ShowDetail(self):
        return self.com_object.ShowDetail

    @ShowDetail.setter
    def ShowDetail(self, value):
        self.com_object.ShowDetail = value

    @property
    def showdetail(self):
        """Alias for ShowDetail"""
        return self.ShowDetail

    @showdetail.setter
    def showdetail(self, value):
        """Alias for ShowDetail.setter"""
        self.ShowDetail = value

    @property
    def show_detail(self):
        """Alias for ShowDetail"""
        return self.ShowDetail

    @show_detail.setter
    def show_detail(self, value):
        """Alias for ShowDetail.setter"""
        self.ShowDetail = value

    @property
    def SourceName(self):
        return self.com_object.SourceName

    @property
    def sourcename(self):
        """Alias for SourceName"""
        return self.SourceName

    @property
    def source_name(self):
        """Alias for SourceName"""
        return self.SourceName

    @property
    def SourceNameStandard(self):
        return self.com_object.SourceNameStandard

    @property
    def sourcenamestandard(self):
        """Alias for SourceNameStandard"""
        return self.SourceNameStandard

    @property
    def source_name_standard(self):
        """Alias for SourceNameStandard"""
        return self.SourceNameStandard

    @property
    def StandardFormula(self):
        return self.com_object.StandardFormula

    @StandardFormula.setter
    def StandardFormula(self, value):
        self.com_object.StandardFormula = value

    @property
    def standardformula(self):
        """Alias for StandardFormula"""
        return self.StandardFormula

    @standardformula.setter
    def standardformula(self, value):
        """Alias for StandardFormula.setter"""
        self.StandardFormula = value

    @property
    def standard_formula(self):
        """Alias for StandardFormula"""
        return self.StandardFormula

    @standard_formula.setter
    def standard_formula(self, value):
        """Alias for StandardFormula.setter"""
        self.StandardFormula = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def DrillTo(self, PivotItemName=None):
        arguments = com_arguments([unwrap(a) for a in [PivotItemName]])
        self.com_object.DrillTo(*arguments)

    def drillto(self, PivotItemName=None):
        """Alias for DrillTo"""
        arguments = [PivotItemName]
        return self.DrillTo(*arguments)

    def drill_to(self, PivotItemName=None):
        """Alias for DrillTo"""
        arguments = [PivotItemName]
        return self.DrillTo(*arguments)


class PivotItemList:

    def __init__(self, pivotitemlist=None):
        self.com_object= pivotitemlist

    def __call__(self, item):
        return PivotItemList(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return PivotItem(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class PivotItems:

    def __init__(self, pivotitems=None):
        self.com_object= pivotitems

    def __call__(self, item):
        return PivotItem(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        self.com_object.Add(*arguments)

    def add(self, Name=None):
        """Alias for Add"""
        arguments = [Name]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class PivotLayout:

    def __init__(self, pivotlayout=None):
        self.com_object= pivotlayout

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PivotTable(self):
        return PivotTable(self.com_object.PivotTable)

    @property
    def pivottable(self):
        """Alias for PivotTable"""
        return self.PivotTable

    @property
    def pivot_table(self):
        """Alias for PivotTable"""
        return self.PivotTable


class PivotLine:

    def __init__(self, pivotline=None):
        self.com_object= pivotline

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def LineType(self):
        return XlPivotLineType(self.com_object.LineType)

    @property
    def linetype(self):
        """Alias for LineType"""
        return self.LineType

    @property
    def line_type(self):
        """Alias for LineType"""
        return self.LineType

    @property
    def Parent(self):
        return PivotLine(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PivotLineCells(self):
        return self.com_object.PivotLineCells

    @property
    def pivotlinecells(self):
        """Alias for PivotLineCells"""
        return self.PivotLineCells

    @property
    def pivot_line_cells(self):
        """Alias for PivotLineCells"""
        return self.PivotLineCells

    @property
    def PivotLineCellsFull(self):
        return self.com_object.PivotLineCellsFull

    @property
    def pivotlinecellsfull(self):
        """Alias for PivotLineCellsFull"""
        return self.PivotLineCellsFull

    @property
    def pivot_line_cells_full(self):
        """Alias for PivotLineCellsFull"""
        return self.PivotLineCellsFull

    @property
    def Position(self):
        return PivotLine(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value


class PivotLineCells:

    def __init__(self, pivotlinecells=None):
        self.com_object= pivotlinecells

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return PivotLineCells(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Full(self):
        return self.com_object.Full

    @property
    def full(self):
        """Alias for Full"""
        return self.Full

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return PivotLineCells(self.com_object.GetItem(*arguments))
        else:
            return PivotLineCells(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return PivotLineCells(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class PivotLines:

    def __init__(self, pivotlines=None):
        self.com_object= pivotlines

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return PivotLines(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return PivotLines(self.com_object.GetItem(*arguments))
        else:
            return PivotLines(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return PivotLines(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class PivotTable:

    def __init__(self, pivottable=None):
        self.com_object= pivottable

    @property
    def ActiveFilters(self):
        return self.com_object.ActiveFilters

    @property
    def activefilters(self):
        """Alias for ActiveFilters"""
        return self.ActiveFilters

    @property
    def active_filters(self):
        """Alias for ActiveFilters"""
        return self.ActiveFilters

    @property
    def Allocation(self):
        return self.com_object.Allocation

    @Allocation.setter
    def Allocation(self, value):
        self.com_object.Allocation = value

    @property
    def allocation(self):
        """Alias for Allocation"""
        return self.Allocation

    @allocation.setter
    def allocation(self, value):
        """Alias for Allocation.setter"""
        self.Allocation = value

    @property
    def AllocationMethod(self):
        return self.com_object.AllocationMethod

    @AllocationMethod.setter
    def AllocationMethod(self, value):
        self.com_object.AllocationMethod = value

    @property
    def allocationmethod(self):
        """Alias for AllocationMethod"""
        return self.AllocationMethod

    @allocationmethod.setter
    def allocationmethod(self, value):
        """Alias for AllocationMethod.setter"""
        self.AllocationMethod = value

    @property
    def allocation_method(self):
        """Alias for AllocationMethod"""
        return self.AllocationMethod

    @allocation_method.setter
    def allocation_method(self, value):
        """Alias for AllocationMethod.setter"""
        self.AllocationMethod = value

    @property
    def AllocationValue(self):
        return self.com_object.AllocationValue

    @AllocationValue.setter
    def AllocationValue(self, value):
        self.com_object.AllocationValue = value

    @property
    def allocationvalue(self):
        """Alias for AllocationValue"""
        return self.AllocationValue

    @allocationvalue.setter
    def allocationvalue(self, value):
        """Alias for AllocationValue.setter"""
        self.AllocationValue = value

    @property
    def allocation_value(self):
        """Alias for AllocationValue"""
        return self.AllocationValue

    @allocation_value.setter
    def allocation_value(self, value):
        """Alias for AllocationValue.setter"""
        self.AllocationValue = value

    @property
    def AllocationWeightExpression(self):
        return self.com_object.AllocationWeightExpression

    @AllocationWeightExpression.setter
    def AllocationWeightExpression(self, value):
        self.com_object.AllocationWeightExpression = value

    @property
    def allocationweightexpression(self):
        """Alias for AllocationWeightExpression"""
        return self.AllocationWeightExpression

    @allocationweightexpression.setter
    def allocationweightexpression(self, value):
        """Alias for AllocationWeightExpression.setter"""
        self.AllocationWeightExpression = value

    @property
    def allocation_weight_expression(self):
        """Alias for AllocationWeightExpression"""
        return self.AllocationWeightExpression

    @allocation_weight_expression.setter
    def allocation_weight_expression(self, value):
        """Alias for AllocationWeightExpression.setter"""
        self.AllocationWeightExpression = value

    @property
    def AllowMultipleFilters(self):
        return self.com_object.AllowMultipleFilters

    @AllowMultipleFilters.setter
    def AllowMultipleFilters(self, value):
        self.com_object.AllowMultipleFilters = value

    @property
    def allowmultiplefilters(self):
        """Alias for AllowMultipleFilters"""
        return self.AllowMultipleFilters

    @allowmultiplefilters.setter
    def allowmultiplefilters(self, value):
        """Alias for AllowMultipleFilters.setter"""
        self.AllowMultipleFilters = value

    @property
    def allow_multiple_filters(self):
        """Alias for AllowMultipleFilters"""
        return self.AllowMultipleFilters

    @allow_multiple_filters.setter
    def allow_multiple_filters(self, value):
        """Alias for AllowMultipleFilters.setter"""
        self.AllowMultipleFilters = value

    @property
    def AlternativeText(self):
        return self.com_object.AlternativeText

    @AlternativeText.setter
    def AlternativeText(self, value):
        self.com_object.AlternativeText = value

    @property
    def alternativetext(self):
        """Alias for AlternativeText"""
        return self.AlternativeText

    @alternativetext.setter
    def alternativetext(self, value):
        """Alias for AlternativeText.setter"""
        self.AlternativeText = value

    @property
    def alternative_text(self):
        """Alias for AlternativeText"""
        return self.AlternativeText

    @alternative_text.setter
    def alternative_text(self, value):
        """Alias for AlternativeText.setter"""
        self.AlternativeText = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def CacheIndex(self):
        return self.com_object.CacheIndex

    @CacheIndex.setter
    def CacheIndex(self, value):
        self.com_object.CacheIndex = value

    @property
    def cacheindex(self):
        """Alias for CacheIndex"""
        return self.CacheIndex

    @cacheindex.setter
    def cacheindex(self, value):
        """Alias for CacheIndex.setter"""
        self.CacheIndex = value

    @property
    def cache_index(self):
        """Alias for CacheIndex"""
        return self.CacheIndex

    @cache_index.setter
    def cache_index(self, value):
        """Alias for CacheIndex.setter"""
        self.CacheIndex = value

    @property
    def CalculatedMembers(self):
        return CalculatedMembers(self.com_object.CalculatedMembers)

    @property
    def calculatedmembers(self):
        """Alias for CalculatedMembers"""
        return self.CalculatedMembers

    @property
    def calculated_members(self):
        """Alias for CalculatedMembers"""
        return self.CalculatedMembers

    @property
    def CalculatedMembersInFilters(self):
        return self.com_object.CalculatedMembersInFilters

    @CalculatedMembersInFilters.setter
    def CalculatedMembersInFilters(self, value):
        self.com_object.CalculatedMembersInFilters = value

    @property
    def calculatedmembersinfilters(self):
        """Alias for CalculatedMembersInFilters"""
        return self.CalculatedMembersInFilters

    @calculatedmembersinfilters.setter
    def calculatedmembersinfilters(self, value):
        """Alias for CalculatedMembersInFilters.setter"""
        self.CalculatedMembersInFilters = value

    @property
    def calculated_members_in_filters(self):
        """Alias for CalculatedMembersInFilters"""
        return self.CalculatedMembersInFilters

    @calculated_members_in_filters.setter
    def calculated_members_in_filters(self, value):
        """Alias for CalculatedMembersInFilters.setter"""
        self.CalculatedMembersInFilters = value

    @property
    def ChangeList(self):
        return PivotTableChangeList(self.com_object.ChangeList)

    @property
    def changelist(self):
        """Alias for ChangeList"""
        return self.ChangeList

    @property
    def change_list(self):
        """Alias for ChangeList"""
        return self.ChangeList

    def ColumnFields(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetColumnFields"):
            return PivotField(self.com_object.GetColumnFields(*arguments))
        else:
            return PivotField(self.com_object.ColumnFields(*arguments))

    def columnfields(self, Index=None):
        """Alias for ColumnFields"""
        arguments = [Index]
        return self.ColumnFields(*arguments)

    def column_fields(self, Index=None):
        """Alias for ColumnFields"""
        arguments = [Index]
        return self.ColumnFields(*arguments)

    @property
    def ColumnGrand(self):
        return self.com_object.ColumnGrand

    @ColumnGrand.setter
    def ColumnGrand(self, value):
        self.com_object.ColumnGrand = value

    @property
    def columngrand(self):
        """Alias for ColumnGrand"""
        return self.ColumnGrand

    @columngrand.setter
    def columngrand(self, value):
        """Alias for ColumnGrand.setter"""
        self.ColumnGrand = value

    @property
    def column_grand(self):
        """Alias for ColumnGrand"""
        return self.ColumnGrand

    @column_grand.setter
    def column_grand(self, value):
        """Alias for ColumnGrand.setter"""
        self.ColumnGrand = value

    @property
    def ColumnRange(self):
        return Range(self.com_object.ColumnRange)

    @property
    def columnrange(self):
        """Alias for ColumnRange"""
        return self.ColumnRange

    @property
    def column_range(self):
        """Alias for ColumnRange"""
        return self.ColumnRange

    @property
    def CompactLayoutColumnHeader(self):
        return self.com_object.CompactLayoutColumnHeader

    @CompactLayoutColumnHeader.setter
    def CompactLayoutColumnHeader(self, value):
        self.com_object.CompactLayoutColumnHeader = value

    @property
    def compactlayoutcolumnheader(self):
        """Alias for CompactLayoutColumnHeader"""
        return self.CompactLayoutColumnHeader

    @compactlayoutcolumnheader.setter
    def compactlayoutcolumnheader(self, value):
        """Alias for CompactLayoutColumnHeader.setter"""
        self.CompactLayoutColumnHeader = value

    @property
    def compact_layout_column_header(self):
        """Alias for CompactLayoutColumnHeader"""
        return self.CompactLayoutColumnHeader

    @compact_layout_column_header.setter
    def compact_layout_column_header(self, value):
        """Alias for CompactLayoutColumnHeader.setter"""
        self.CompactLayoutColumnHeader = value

    @property
    def CompactLayoutRowHeader(self):
        return self.com_object.CompactLayoutRowHeader

    @CompactLayoutRowHeader.setter
    def CompactLayoutRowHeader(self, value):
        self.com_object.CompactLayoutRowHeader = value

    @property
    def compactlayoutrowheader(self):
        """Alias for CompactLayoutRowHeader"""
        return self.CompactLayoutRowHeader

    @compactlayoutrowheader.setter
    def compactlayoutrowheader(self, value):
        """Alias for CompactLayoutRowHeader.setter"""
        self.CompactLayoutRowHeader = value

    @property
    def compact_layout_row_header(self):
        """Alias for CompactLayoutRowHeader"""
        return self.CompactLayoutRowHeader

    @compact_layout_row_header.setter
    def compact_layout_row_header(self, value):
        """Alias for CompactLayoutRowHeader.setter"""
        self.CompactLayoutRowHeader = value

    @property
    def CompactRowIndent(self):
        return self.com_object.CompactRowIndent

    @CompactRowIndent.setter
    def CompactRowIndent(self, value):
        self.com_object.CompactRowIndent = value

    @property
    def compactrowindent(self):
        """Alias for CompactRowIndent"""
        return self.CompactRowIndent

    @compactrowindent.setter
    def compactrowindent(self, value):
        """Alias for CompactRowIndent.setter"""
        self.CompactRowIndent = value

    @property
    def compact_row_indent(self):
        """Alias for CompactRowIndent"""
        return self.CompactRowIndent

    @compact_row_indent.setter
    def compact_row_indent(self, value):
        """Alias for CompactRowIndent.setter"""
        self.CompactRowIndent = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def CubeFields(self):
        return CubeFields(self.com_object.CubeFields)

    @property
    def cubefields(self):
        """Alias for CubeFields"""
        return self.CubeFields

    @property
    def cube_fields(self):
        """Alias for CubeFields"""
        return self.CubeFields

    @property
    def DataBodyRange(self):
        return Range(self.com_object.DataBodyRange)

    @property
    def databodyrange(self):
        """Alias for DataBodyRange"""
        return self.DataBodyRange

    @property
    def data_body_range(self):
        """Alias for DataBodyRange"""
        return self.DataBodyRange

    def DataFields(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetDataFields"):
            return PivotField(self.com_object.GetDataFields(*arguments))
        else:
            return PivotField(self.com_object.DataFields(*arguments))

    def datafields(self, Index=None):
        """Alias for DataFields"""
        arguments = [Index]
        return self.DataFields(*arguments)

    def data_fields(self, Index=None):
        """Alias for DataFields"""
        arguments = [Index]
        return self.DataFields(*arguments)

    @property
    def DataLabelRange(self):
        return Range(self.com_object.DataLabelRange)

    @property
    def datalabelrange(self):
        """Alias for DataLabelRange"""
        return self.DataLabelRange

    @property
    def data_label_range(self):
        """Alias for DataLabelRange"""
        return self.DataLabelRange

    @property
    def DataPivotField(self):
        return PivotField(self.com_object.DataPivotField)

    @property
    def datapivotfield(self):
        """Alias for DataPivotField"""
        return self.DataPivotField

    @property
    def data_pivot_field(self):
        """Alias for DataPivotField"""
        return self.DataPivotField

    @property
    def DisplayContextTooltips(self):
        return self.com_object.DisplayContextTooltips

    @DisplayContextTooltips.setter
    def DisplayContextTooltips(self, value):
        self.com_object.DisplayContextTooltips = value

    @property
    def displaycontexttooltips(self):
        """Alias for DisplayContextTooltips"""
        return self.DisplayContextTooltips

    @displaycontexttooltips.setter
    def displaycontexttooltips(self, value):
        """Alias for DisplayContextTooltips.setter"""
        self.DisplayContextTooltips = value

    @property
    def display_context_tooltips(self):
        """Alias for DisplayContextTooltips"""
        return self.DisplayContextTooltips

    @display_context_tooltips.setter
    def display_context_tooltips(self, value):
        """Alias for DisplayContextTooltips.setter"""
        self.DisplayContextTooltips = value

    @property
    def DisplayEmptyColumn(self):
        return self.com_object.DisplayEmptyColumn

    @DisplayEmptyColumn.setter
    def DisplayEmptyColumn(self, value):
        self.com_object.DisplayEmptyColumn = value

    @property
    def displayemptycolumn(self):
        """Alias for DisplayEmptyColumn"""
        return self.DisplayEmptyColumn

    @displayemptycolumn.setter
    def displayemptycolumn(self, value):
        """Alias for DisplayEmptyColumn.setter"""
        self.DisplayEmptyColumn = value

    @property
    def display_empty_column(self):
        """Alias for DisplayEmptyColumn"""
        return self.DisplayEmptyColumn

    @display_empty_column.setter
    def display_empty_column(self, value):
        """Alias for DisplayEmptyColumn.setter"""
        self.DisplayEmptyColumn = value

    @property
    def DisplayEmptyRow(self):
        return self.com_object.DisplayEmptyRow

    @DisplayEmptyRow.setter
    def DisplayEmptyRow(self, value):
        self.com_object.DisplayEmptyRow = value

    @property
    def displayemptyrow(self):
        """Alias for DisplayEmptyRow"""
        return self.DisplayEmptyRow

    @displayemptyrow.setter
    def displayemptyrow(self, value):
        """Alias for DisplayEmptyRow.setter"""
        self.DisplayEmptyRow = value

    @property
    def display_empty_row(self):
        """Alias for DisplayEmptyRow"""
        return self.DisplayEmptyRow

    @display_empty_row.setter
    def display_empty_row(self, value):
        """Alias for DisplayEmptyRow.setter"""
        self.DisplayEmptyRow = value

    @property
    def DisplayErrorString(self):
        return self.com_object.DisplayErrorString

    @DisplayErrorString.setter
    def DisplayErrorString(self, value):
        self.com_object.DisplayErrorString = value

    @property
    def displayerrorstring(self):
        """Alias for DisplayErrorString"""
        return self.DisplayErrorString

    @displayerrorstring.setter
    def displayerrorstring(self, value):
        """Alias for DisplayErrorString.setter"""
        self.DisplayErrorString = value

    @property
    def display_error_string(self):
        """Alias for DisplayErrorString"""
        return self.DisplayErrorString

    @display_error_string.setter
    def display_error_string(self, value):
        """Alias for DisplayErrorString.setter"""
        self.DisplayErrorString = value

    @property
    def DisplayFieldCaptions(self):
        return self.com_object.DisplayFieldCaptions

    @DisplayFieldCaptions.setter
    def DisplayFieldCaptions(self, value):
        self.com_object.DisplayFieldCaptions = value

    @property
    def displayfieldcaptions(self):
        """Alias for DisplayFieldCaptions"""
        return self.DisplayFieldCaptions

    @displayfieldcaptions.setter
    def displayfieldcaptions(self, value):
        """Alias for DisplayFieldCaptions.setter"""
        self.DisplayFieldCaptions = value

    @property
    def display_field_captions(self):
        """Alias for DisplayFieldCaptions"""
        return self.DisplayFieldCaptions

    @display_field_captions.setter
    def display_field_captions(self, value):
        """Alias for DisplayFieldCaptions.setter"""
        self.DisplayFieldCaptions = value

    @property
    def DisplayImmediateItems(self):
        return self.com_object.DisplayImmediateItems

    @DisplayImmediateItems.setter
    def DisplayImmediateItems(self, value):
        self.com_object.DisplayImmediateItems = value

    @property
    def displayimmediateitems(self):
        """Alias for DisplayImmediateItems"""
        return self.DisplayImmediateItems

    @displayimmediateitems.setter
    def displayimmediateitems(self, value):
        """Alias for DisplayImmediateItems.setter"""
        self.DisplayImmediateItems = value

    @property
    def display_immediate_items(self):
        """Alias for DisplayImmediateItems"""
        return self.DisplayImmediateItems

    @display_immediate_items.setter
    def display_immediate_items(self, value):
        """Alias for DisplayImmediateItems.setter"""
        self.DisplayImmediateItems = value

    @property
    def DisplayMemberPropertyTooltips(self):
        return self.com_object.DisplayMemberPropertyTooltips

    @DisplayMemberPropertyTooltips.setter
    def DisplayMemberPropertyTooltips(self, value):
        self.com_object.DisplayMemberPropertyTooltips = value

    @property
    def displaymemberpropertytooltips(self):
        """Alias for DisplayMemberPropertyTooltips"""
        return self.DisplayMemberPropertyTooltips

    @displaymemberpropertytooltips.setter
    def displaymemberpropertytooltips(self, value):
        """Alias for DisplayMemberPropertyTooltips.setter"""
        self.DisplayMemberPropertyTooltips = value

    @property
    def display_member_property_tooltips(self):
        """Alias for DisplayMemberPropertyTooltips"""
        return self.DisplayMemberPropertyTooltips

    @display_member_property_tooltips.setter
    def display_member_property_tooltips(self, value):
        """Alias for DisplayMemberPropertyTooltips.setter"""
        self.DisplayMemberPropertyTooltips = value

    @property
    def DisplayNullString(self):
        return self.com_object.DisplayNullString

    @DisplayNullString.setter
    def DisplayNullString(self, value):
        self.com_object.DisplayNullString = value

    @property
    def displaynullstring(self):
        """Alias for DisplayNullString"""
        return self.DisplayNullString

    @displaynullstring.setter
    def displaynullstring(self, value):
        """Alias for DisplayNullString.setter"""
        self.DisplayNullString = value

    @property
    def display_null_string(self):
        """Alias for DisplayNullString"""
        return self.DisplayNullString

    @display_null_string.setter
    def display_null_string(self, value):
        """Alias for DisplayNullString.setter"""
        self.DisplayNullString = value

    @property
    def EnableDataValueEditing(self):
        return self.com_object.EnableDataValueEditing

    @EnableDataValueEditing.setter
    def EnableDataValueEditing(self, value):
        self.com_object.EnableDataValueEditing = value

    @property
    def enabledatavalueediting(self):
        """Alias for EnableDataValueEditing"""
        return self.EnableDataValueEditing

    @enabledatavalueediting.setter
    def enabledatavalueediting(self, value):
        """Alias for EnableDataValueEditing.setter"""
        self.EnableDataValueEditing = value

    @property
    def enable_data_value_editing(self):
        """Alias for EnableDataValueEditing"""
        return self.EnableDataValueEditing

    @enable_data_value_editing.setter
    def enable_data_value_editing(self, value):
        """Alias for EnableDataValueEditing.setter"""
        self.EnableDataValueEditing = value

    @property
    def EnableDrilldown(self):
        return self.com_object.EnableDrilldown

    @EnableDrilldown.setter
    def EnableDrilldown(self, value):
        self.com_object.EnableDrilldown = value

    @property
    def enabledrilldown(self):
        """Alias for EnableDrilldown"""
        return self.EnableDrilldown

    @enabledrilldown.setter
    def enabledrilldown(self, value):
        """Alias for EnableDrilldown.setter"""
        self.EnableDrilldown = value

    @property
    def enable_drilldown(self):
        """Alias for EnableDrilldown"""
        return self.EnableDrilldown

    @enable_drilldown.setter
    def enable_drilldown(self, value):
        """Alias for EnableDrilldown.setter"""
        self.EnableDrilldown = value

    @property
    def EnableFieldDialog(self):
        return self.com_object.EnableFieldDialog

    @EnableFieldDialog.setter
    def EnableFieldDialog(self, value):
        self.com_object.EnableFieldDialog = value

    @property
    def enablefielddialog(self):
        """Alias for EnableFieldDialog"""
        return self.EnableFieldDialog

    @enablefielddialog.setter
    def enablefielddialog(self, value):
        """Alias for EnableFieldDialog.setter"""
        self.EnableFieldDialog = value

    @property
    def enable_field_dialog(self):
        """Alias for EnableFieldDialog"""
        return self.EnableFieldDialog

    @enable_field_dialog.setter
    def enable_field_dialog(self, value):
        """Alias for EnableFieldDialog.setter"""
        self.EnableFieldDialog = value

    @property
    def EnableFieldList(self):
        return self.com_object.EnableFieldList

    @EnableFieldList.setter
    def EnableFieldList(self, value):
        self.com_object.EnableFieldList = value

    @property
    def enablefieldlist(self):
        """Alias for EnableFieldList"""
        return self.EnableFieldList

    @enablefieldlist.setter
    def enablefieldlist(self, value):
        """Alias for EnableFieldList.setter"""
        self.EnableFieldList = value

    @property
    def enable_field_list(self):
        """Alias for EnableFieldList"""
        return self.EnableFieldList

    @enable_field_list.setter
    def enable_field_list(self, value):
        """Alias for EnableFieldList.setter"""
        self.EnableFieldList = value

    @property
    def EnableWizard(self):
        return self.com_object.EnableWizard

    @EnableWizard.setter
    def EnableWizard(self, value):
        self.com_object.EnableWizard = value

    @property
    def enablewizard(self):
        """Alias for EnableWizard"""
        return self.EnableWizard

    @enablewizard.setter
    def enablewizard(self, value):
        """Alias for EnableWizard.setter"""
        self.EnableWizard = value

    @property
    def enable_wizard(self):
        """Alias for EnableWizard"""
        return self.EnableWizard

    @enable_wizard.setter
    def enable_wizard(self, value):
        """Alias for EnableWizard.setter"""
        self.EnableWizard = value

    @property
    def EnableWriteback(self):
        return self.com_object.EnableWriteback

    @EnableWriteback.setter
    def EnableWriteback(self, value):
        self.com_object.EnableWriteback = value

    @property
    def enablewriteback(self):
        """Alias for EnableWriteback"""
        return self.EnableWriteback

    @enablewriteback.setter
    def enablewriteback(self, value):
        """Alias for EnableWriteback.setter"""
        self.EnableWriteback = value

    @property
    def enable_writeback(self):
        """Alias for EnableWriteback"""
        return self.EnableWriteback

    @enable_writeback.setter
    def enable_writeback(self, value):
        """Alias for EnableWriteback.setter"""
        self.EnableWriteback = value

    @property
    def ErrorString(self):
        return self.com_object.ErrorString

    @ErrorString.setter
    def ErrorString(self, value):
        self.com_object.ErrorString = value

    @property
    def errorstring(self):
        """Alias for ErrorString"""
        return self.ErrorString

    @errorstring.setter
    def errorstring(self, value):
        """Alias for ErrorString.setter"""
        self.ErrorString = value

    @property
    def error_string(self):
        """Alias for ErrorString"""
        return self.ErrorString

    @error_string.setter
    def error_string(self, value):
        """Alias for ErrorString.setter"""
        self.ErrorString = value

    @property
    def FieldListSortAscending(self):
        return self.com_object.FieldListSortAscending

    @FieldListSortAscending.setter
    def FieldListSortAscending(self, value):
        self.com_object.FieldListSortAscending = value

    @property
    def fieldlistsortascending(self):
        """Alias for FieldListSortAscending"""
        return self.FieldListSortAscending

    @fieldlistsortascending.setter
    def fieldlistsortascending(self, value):
        """Alias for FieldListSortAscending.setter"""
        self.FieldListSortAscending = value

    @property
    def field_list_sort_ascending(self):
        """Alias for FieldListSortAscending"""
        return self.FieldListSortAscending

    @field_list_sort_ascending.setter
    def field_list_sort_ascending(self, value):
        """Alias for FieldListSortAscending.setter"""
        self.FieldListSortAscending = value

    @property
    def GrandTotalName(self):
        return self.com_object.GrandTotalName

    @GrandTotalName.setter
    def GrandTotalName(self, value):
        self.com_object.GrandTotalName = value

    @property
    def grandtotalname(self):
        """Alias for GrandTotalName"""
        return self.GrandTotalName

    @grandtotalname.setter
    def grandtotalname(self, value):
        """Alias for GrandTotalName.setter"""
        self.GrandTotalName = value

    @property
    def grand_total_name(self):
        """Alias for GrandTotalName"""
        return self.GrandTotalName

    @grand_total_name.setter
    def grand_total_name(self, value):
        """Alias for GrandTotalName.setter"""
        self.GrandTotalName = value

    @property
    def HasAutoFormat(self):
        return self.com_object.HasAutoFormat

    @HasAutoFormat.setter
    def HasAutoFormat(self, value):
        self.com_object.HasAutoFormat = value

    @property
    def hasautoformat(self):
        """Alias for HasAutoFormat"""
        return self.HasAutoFormat

    @hasautoformat.setter
    def hasautoformat(self, value):
        """Alias for HasAutoFormat.setter"""
        self.HasAutoFormat = value

    @property
    def has_auto_format(self):
        """Alias for HasAutoFormat"""
        return self.HasAutoFormat

    @has_auto_format.setter
    def has_auto_format(self, value):
        """Alias for HasAutoFormat.setter"""
        self.HasAutoFormat = value

    @property
    def Hidden(self):
        return self.com_object.Hidden

    @property
    def hidden(self):
        """Alias for Hidden"""
        return self.Hidden

    def HiddenFields(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetHiddenFields"):
            return PivotField(self.com_object.GetHiddenFields(*arguments))
        else:
            return PivotField(self.com_object.HiddenFields(*arguments))

    def hiddenfields(self, Index=None):
        """Alias for HiddenFields"""
        arguments = [Index]
        return self.HiddenFields(*arguments)

    def hidden_fields(self, Index=None):
        """Alias for HiddenFields"""
        arguments = [Index]
        return self.HiddenFields(*arguments)

    @property
    def InGridDropZones(self):
        return self.com_object.InGridDropZones

    @InGridDropZones.setter
    def InGridDropZones(self, value):
        self.com_object.InGridDropZones = value

    @property
    def ingriddropzones(self):
        """Alias for InGridDropZones"""
        return self.InGridDropZones

    @ingriddropzones.setter
    def ingriddropzones(self, value):
        """Alias for InGridDropZones.setter"""
        self.InGridDropZones = value

    @property
    def in_grid_drop_zones(self):
        """Alias for InGridDropZones"""
        return self.InGridDropZones

    @in_grid_drop_zones.setter
    def in_grid_drop_zones(self, value):
        """Alias for InGridDropZones.setter"""
        self.InGridDropZones = value

    @property
    def InnerDetail(self):
        return self.com_object.InnerDetail

    @InnerDetail.setter
    def InnerDetail(self, value):
        self.com_object.InnerDetail = value

    @property
    def innerdetail(self):
        """Alias for InnerDetail"""
        return self.InnerDetail

    @innerdetail.setter
    def innerdetail(self, value):
        """Alias for InnerDetail.setter"""
        self.InnerDetail = value

    @property
    def inner_detail(self):
        """Alias for InnerDetail"""
        return self.InnerDetail

    @inner_detail.setter
    def inner_detail(self, value):
        """Alias for InnerDetail.setter"""
        self.InnerDetail = value

    @property
    def LayoutRowDefault(self):
        return self.com_object.LayoutRowDefault

    @LayoutRowDefault.setter
    def LayoutRowDefault(self, value):
        self.com_object.LayoutRowDefault = value

    @property
    def layoutrowdefault(self):
        """Alias for LayoutRowDefault"""
        return self.LayoutRowDefault

    @layoutrowdefault.setter
    def layoutrowdefault(self, value):
        """Alias for LayoutRowDefault.setter"""
        self.LayoutRowDefault = value

    @property
    def layout_row_default(self):
        """Alias for LayoutRowDefault"""
        return self.LayoutRowDefault

    @layout_row_default.setter
    def layout_row_default(self, value):
        """Alias for LayoutRowDefault.setter"""
        self.LayoutRowDefault = value

    @property
    def Location(self):
        return self.com_object.Location

    @Location.setter
    def Location(self, value):
        self.com_object.Location = value

    @property
    def location(self):
        """Alias for Location"""
        return self.Location

    @location.setter
    def location(self, value):
        """Alias for Location.setter"""
        self.Location = value

    @property
    def ManualUpdate(self):
        return self.com_object.ManualUpdate

    @ManualUpdate.setter
    def ManualUpdate(self, value):
        self.com_object.ManualUpdate = value

    @property
    def manualupdate(self):
        """Alias for ManualUpdate"""
        return self.ManualUpdate

    @manualupdate.setter
    def manualupdate(self, value):
        """Alias for ManualUpdate.setter"""
        self.ManualUpdate = value

    @property
    def manual_update(self):
        """Alias for ManualUpdate"""
        return self.ManualUpdate

    @manual_update.setter
    def manual_update(self, value):
        """Alias for ManualUpdate.setter"""
        self.ManualUpdate = value

    @property
    def MDX(self):
        return self.com_object.MDX

    @property
    def mdx(self):
        """Alias for MDX"""
        return self.MDX

    @property
    def m_d_x(self):
        """Alias for MDX"""
        return self.MDX

    @property
    def MergeLabels(self):
        return self.com_object.MergeLabels

    @MergeLabels.setter
    def MergeLabels(self, value):
        self.com_object.MergeLabels = value

    @property
    def mergelabels(self):
        """Alias for MergeLabels"""
        return self.MergeLabels

    @mergelabels.setter
    def mergelabels(self, value):
        """Alias for MergeLabels.setter"""
        self.MergeLabels = value

    @property
    def merge_labels(self):
        """Alias for MergeLabels"""
        return self.MergeLabels

    @merge_labels.setter
    def merge_labels(self, value):
        """Alias for MergeLabels.setter"""
        self.MergeLabels = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def NullString(self):
        return self.com_object.NullString

    @NullString.setter
    def NullString(self, value):
        self.com_object.NullString = value

    @property
    def nullstring(self):
        """Alias for NullString"""
        return self.NullString

    @nullstring.setter
    def nullstring(self, value):
        """Alias for NullString.setter"""
        self.NullString = value

    @property
    def null_string(self):
        """Alias for NullString"""
        return self.NullString

    @null_string.setter
    def null_string(self, value):
        """Alias for NullString.setter"""
        self.NullString = value

    @property
    def PageFieldOrder(self):
        return XlOrder(self.com_object.PageFieldOrder)

    @PageFieldOrder.setter
    def PageFieldOrder(self, value):
        self.com_object.PageFieldOrder = value

    @property
    def pagefieldorder(self):
        """Alias for PageFieldOrder"""
        return self.PageFieldOrder

    @pagefieldorder.setter
    def pagefieldorder(self, value):
        """Alias for PageFieldOrder.setter"""
        self.PageFieldOrder = value

    @property
    def page_field_order(self):
        """Alias for PageFieldOrder"""
        return self.PageFieldOrder

    @page_field_order.setter
    def page_field_order(self, value):
        """Alias for PageFieldOrder.setter"""
        self.PageFieldOrder = value

    def PageFields(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetPageFields"):
            return PivotField(self.com_object.GetPageFields(*arguments))
        else:
            return PivotField(self.com_object.PageFields(*arguments))

    def pagefields(self, Index=None):
        """Alias for PageFields"""
        arguments = [Index]
        return self.PageFields(*arguments)

    def page_fields(self, Index=None):
        """Alias for PageFields"""
        arguments = [Index]
        return self.PageFields(*arguments)

    @property
    def PageFieldStyle(self):
        return self.com_object.PageFieldStyle

    @PageFieldStyle.setter
    def PageFieldStyle(self, value):
        self.com_object.PageFieldStyle = value

    @property
    def pagefieldstyle(self):
        """Alias for PageFieldStyle"""
        return self.PageFieldStyle

    @pagefieldstyle.setter
    def pagefieldstyle(self, value):
        """Alias for PageFieldStyle.setter"""
        self.PageFieldStyle = value

    @property
    def page_field_style(self):
        """Alias for PageFieldStyle"""
        return self.PageFieldStyle

    @page_field_style.setter
    def page_field_style(self, value):
        """Alias for PageFieldStyle.setter"""
        self.PageFieldStyle = value

    @property
    def PageFieldWrapCount(self):
        return self.com_object.PageFieldWrapCount

    @PageFieldWrapCount.setter
    def PageFieldWrapCount(self, value):
        self.com_object.PageFieldWrapCount = value

    @property
    def pagefieldwrapcount(self):
        """Alias for PageFieldWrapCount"""
        return self.PageFieldWrapCount

    @pagefieldwrapcount.setter
    def pagefieldwrapcount(self, value):
        """Alias for PageFieldWrapCount.setter"""
        self.PageFieldWrapCount = value

    @property
    def page_field_wrap_count(self):
        """Alias for PageFieldWrapCount"""
        return self.PageFieldWrapCount

    @page_field_wrap_count.setter
    def page_field_wrap_count(self, value):
        """Alias for PageFieldWrapCount.setter"""
        self.PageFieldWrapCount = value

    @property
    def PageRange(self):
        return Range(self.com_object.PageRange)

    @property
    def pagerange(self):
        """Alias for PageRange"""
        return self.PageRange

    @property
    def page_range(self):
        """Alias for PageRange"""
        return self.PageRange

    @property
    def PageRangeCells(self):
        return Range(self.com_object.PageRangeCells)

    @property
    def pagerangecells(self):
        """Alias for PageRangeCells"""
        return self.PageRangeCells

    @property
    def page_range_cells(self):
        """Alias for PageRangeCells"""
        return self.PageRangeCells

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PivotChart(self):
        return Shape(self.com_object.PivotChart)

    @property
    def pivotchart(self):
        """Alias for PivotChart"""
        return self.PivotChart

    @property
    def pivot_chart(self):
        """Alias for PivotChart"""
        return self.PivotChart

    @property
    def PivotColumnAxis(self):
        return PivotAxis(self.com_object.PivotColumnAxis)

    @property
    def pivotcolumnaxis(self):
        """Alias for PivotColumnAxis"""
        return self.PivotColumnAxis

    @property
    def pivot_column_axis(self):
        """Alias for PivotColumnAxis"""
        return self.PivotColumnAxis

    @property
    def PivotFormulas(self):
        return PivotFormulas(self.com_object.PivotFormulas)

    @property
    def pivotformulas(self):
        """Alias for PivotFormulas"""
        return self.PivotFormulas

    @property
    def pivot_formulas(self):
        """Alias for PivotFormulas"""
        return self.PivotFormulas

    @property
    def PivotRowAxis(self):
        return PivotAxis(self.com_object.PivotRowAxis)

    @property
    def pivotrowaxis(self):
        """Alias for PivotRowAxis"""
        return self.PivotRowAxis

    @property
    def pivot_row_axis(self):
        """Alias for PivotRowAxis"""
        return self.PivotRowAxis

    @property
    def PivotSelection(self):
        return self.com_object.PivotSelection

    @PivotSelection.setter
    def PivotSelection(self, value):
        self.com_object.PivotSelection = value

    @property
    def pivotselection(self):
        """Alias for PivotSelection"""
        return self.PivotSelection

    @pivotselection.setter
    def pivotselection(self, value):
        """Alias for PivotSelection.setter"""
        self.PivotSelection = value

    @property
    def pivot_selection(self):
        """Alias for PivotSelection"""
        return self.PivotSelection

    @pivot_selection.setter
    def pivot_selection(self, value):
        """Alias for PivotSelection.setter"""
        self.PivotSelection = value

    @property
    def PivotSelectionStandard(self):
        return self.com_object.PivotSelectionStandard

    @PivotSelectionStandard.setter
    def PivotSelectionStandard(self, value):
        self.com_object.PivotSelectionStandard = value

    @property
    def pivotselectionstandard(self):
        """Alias for PivotSelectionStandard"""
        return self.PivotSelectionStandard

    @pivotselectionstandard.setter
    def pivotselectionstandard(self, value):
        """Alias for PivotSelectionStandard.setter"""
        self.PivotSelectionStandard = value

    @property
    def pivot_selection_standard(self):
        """Alias for PivotSelectionStandard"""
        return self.PivotSelectionStandard

    @pivot_selection_standard.setter
    def pivot_selection_standard(self, value):
        """Alias for PivotSelectionStandard.setter"""
        self.PivotSelectionStandard = value

    @property
    def PreserveFormatting(self):
        return self.com_object.PreserveFormatting

    @property
    def preserveformatting(self):
        """Alias for PreserveFormatting"""
        return self.PreserveFormatting

    @property
    def preserve_formatting(self):
        """Alias for PreserveFormatting"""
        return self.PreserveFormatting

    @property
    def PrintDrillIndicators(self):
        return self.com_object.PrintDrillIndicators

    @PrintDrillIndicators.setter
    def PrintDrillIndicators(self, value):
        self.com_object.PrintDrillIndicators = value

    @property
    def printdrillindicators(self):
        """Alias for PrintDrillIndicators"""
        return self.PrintDrillIndicators

    @printdrillindicators.setter
    def printdrillindicators(self, value):
        """Alias for PrintDrillIndicators.setter"""
        self.PrintDrillIndicators = value

    @property
    def print_drill_indicators(self):
        """Alias for PrintDrillIndicators"""
        return self.PrintDrillIndicators

    @print_drill_indicators.setter
    def print_drill_indicators(self, value):
        """Alias for PrintDrillIndicators.setter"""
        self.PrintDrillIndicators = value

    @property
    def PrintTitles(self):
        return self.com_object.PrintTitles

    @PrintTitles.setter
    def PrintTitles(self, value):
        self.com_object.PrintTitles = value

    @property
    def printtitles(self):
        """Alias for PrintTitles"""
        return self.PrintTitles

    @printtitles.setter
    def printtitles(self, value):
        """Alias for PrintTitles.setter"""
        self.PrintTitles = value

    @property
    def print_titles(self):
        """Alias for PrintTitles"""
        return self.PrintTitles

    @print_titles.setter
    def print_titles(self, value):
        """Alias for PrintTitles.setter"""
        self.PrintTitles = value

    @property
    def RefreshDate(self):
        return self.com_object.RefreshDate

    @property
    def refreshdate(self):
        """Alias for RefreshDate"""
        return self.RefreshDate

    @property
    def refresh_date(self):
        """Alias for RefreshDate"""
        return self.RefreshDate

    @property
    def RefreshName(self):
        return self.com_object.RefreshName

    @property
    def refreshname(self):
        """Alias for RefreshName"""
        return self.RefreshName

    @property
    def refresh_name(self):
        """Alias for RefreshName"""
        return self.RefreshName

    @property
    def RepeatItemsOnEachPrintedPage(self):
        return self.com_object.RepeatItemsOnEachPrintedPage

    @RepeatItemsOnEachPrintedPage.setter
    def RepeatItemsOnEachPrintedPage(self, value):
        self.com_object.RepeatItemsOnEachPrintedPage = value

    @property
    def repeatitemsoneachprintedpage(self):
        """Alias for RepeatItemsOnEachPrintedPage"""
        return self.RepeatItemsOnEachPrintedPage

    @repeatitemsoneachprintedpage.setter
    def repeatitemsoneachprintedpage(self, value):
        """Alias for RepeatItemsOnEachPrintedPage.setter"""
        self.RepeatItemsOnEachPrintedPage = value

    @property
    def repeat_items_on_each_printed_page(self):
        """Alias for RepeatItemsOnEachPrintedPage"""
        return self.RepeatItemsOnEachPrintedPage

    @repeat_items_on_each_printed_page.setter
    def repeat_items_on_each_printed_page(self, value):
        """Alias for RepeatItemsOnEachPrintedPage.setter"""
        self.RepeatItemsOnEachPrintedPage = value

    def RowFields(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetRowFields"):
            return PivotField(self.com_object.GetRowFields(*arguments))
        else:
            return PivotField(self.com_object.RowFields(*arguments))

    def rowfields(self, Index=None):
        """Alias for RowFields"""
        arguments = [Index]
        return self.RowFields(*arguments)

    def row_fields(self, Index=None):
        """Alias for RowFields"""
        arguments = [Index]
        return self.RowFields(*arguments)

    @property
    def RowGrand(self):
        return self.com_object.RowGrand

    @RowGrand.setter
    def RowGrand(self, value):
        self.com_object.RowGrand = value

    @property
    def rowgrand(self):
        """Alias for RowGrand"""
        return self.RowGrand

    @rowgrand.setter
    def rowgrand(self, value):
        """Alias for RowGrand.setter"""
        self.RowGrand = value

    @property
    def row_grand(self):
        """Alias for RowGrand"""
        return self.RowGrand

    @row_grand.setter
    def row_grand(self, value):
        """Alias for RowGrand.setter"""
        self.RowGrand = value

    @property
    def RowRange(self):
        return Range(self.com_object.RowRange)

    @property
    def rowrange(self):
        """Alias for RowRange"""
        return self.RowRange

    @property
    def row_range(self):
        """Alias for RowRange"""
        return self.RowRange

    @property
    def SaveData(self):
        return self.com_object.SaveData

    @SaveData.setter
    def SaveData(self, value):
        self.com_object.SaveData = value

    @property
    def savedata(self):
        """Alias for SaveData"""
        return self.SaveData

    @savedata.setter
    def savedata(self, value):
        """Alias for SaveData.setter"""
        self.SaveData = value

    @property
    def save_data(self):
        """Alias for SaveData"""
        return self.SaveData

    @save_data.setter
    def save_data(self, value):
        """Alias for SaveData.setter"""
        self.SaveData = value

    @property
    def SelectionMode(self):
        return XlPTSelectionMode(self.com_object.SelectionMode)

    @SelectionMode.setter
    def SelectionMode(self, value):
        self.com_object.SelectionMode = value

    @property
    def selectionmode(self):
        """Alias for SelectionMode"""
        return self.SelectionMode

    @selectionmode.setter
    def selectionmode(self, value):
        """Alias for SelectionMode.setter"""
        self.SelectionMode = value

    @property
    def selection_mode(self):
        """Alias for SelectionMode"""
        return self.SelectionMode

    @selection_mode.setter
    def selection_mode(self, value):
        """Alias for SelectionMode.setter"""
        self.SelectionMode = value

    @property
    def ShowDrillIndicators(self):
        return self.com_object.ShowDrillIndicators

    @ShowDrillIndicators.setter
    def ShowDrillIndicators(self, value):
        self.com_object.ShowDrillIndicators = value

    @property
    def showdrillindicators(self):
        """Alias for ShowDrillIndicators"""
        return self.ShowDrillIndicators

    @showdrillindicators.setter
    def showdrillindicators(self, value):
        """Alias for ShowDrillIndicators.setter"""
        self.ShowDrillIndicators = value

    @property
    def show_drill_indicators(self):
        """Alias for ShowDrillIndicators"""
        return self.ShowDrillIndicators

    @show_drill_indicators.setter
    def show_drill_indicators(self, value):
        """Alias for ShowDrillIndicators.setter"""
        self.ShowDrillIndicators = value

    @property
    def ShowPageMultipleItemLabel(self):
        return self.com_object.ShowPageMultipleItemLabel

    @ShowPageMultipleItemLabel.setter
    def ShowPageMultipleItemLabel(self, value):
        self.com_object.ShowPageMultipleItemLabel = value

    @property
    def showpagemultipleitemlabel(self):
        """Alias for ShowPageMultipleItemLabel"""
        return self.ShowPageMultipleItemLabel

    @showpagemultipleitemlabel.setter
    def showpagemultipleitemlabel(self, value):
        """Alias for ShowPageMultipleItemLabel.setter"""
        self.ShowPageMultipleItemLabel = value

    @property
    def show_page_multiple_item_label(self):
        """Alias for ShowPageMultipleItemLabel"""
        return self.ShowPageMultipleItemLabel

    @show_page_multiple_item_label.setter
    def show_page_multiple_item_label(self, value):
        """Alias for ShowPageMultipleItemLabel.setter"""
        self.ShowPageMultipleItemLabel = value

    @property
    def ShowTableStyleColumnHeaders(self):
        return self.com_object.ShowTableStyleColumnHeaders

    @ShowTableStyleColumnHeaders.setter
    def ShowTableStyleColumnHeaders(self, value):
        self.com_object.ShowTableStyleColumnHeaders = value

    @property
    def showtablestylecolumnheaders(self):
        """Alias for ShowTableStyleColumnHeaders"""
        return self.ShowTableStyleColumnHeaders

    @showtablestylecolumnheaders.setter
    def showtablestylecolumnheaders(self, value):
        """Alias for ShowTableStyleColumnHeaders.setter"""
        self.ShowTableStyleColumnHeaders = value

    @property
    def show_table_style_column_headers(self):
        """Alias for ShowTableStyleColumnHeaders"""
        return self.ShowTableStyleColumnHeaders

    @show_table_style_column_headers.setter
    def show_table_style_column_headers(self, value):
        """Alias for ShowTableStyleColumnHeaders.setter"""
        self.ShowTableStyleColumnHeaders = value

    @property
    def ShowTableStyleColumnStripes(self):
        return self.com_object.ShowTableStyleColumnStripes

    @ShowTableStyleColumnStripes.setter
    def ShowTableStyleColumnStripes(self, value):
        self.com_object.ShowTableStyleColumnStripes = value

    @property
    def showtablestylecolumnstripes(self):
        """Alias for ShowTableStyleColumnStripes"""
        return self.ShowTableStyleColumnStripes

    @showtablestylecolumnstripes.setter
    def showtablestylecolumnstripes(self, value):
        """Alias for ShowTableStyleColumnStripes.setter"""
        self.ShowTableStyleColumnStripes = value

    @property
    def show_table_style_column_stripes(self):
        """Alias for ShowTableStyleColumnStripes"""
        return self.ShowTableStyleColumnStripes

    @show_table_style_column_stripes.setter
    def show_table_style_column_stripes(self, value):
        """Alias for ShowTableStyleColumnStripes.setter"""
        self.ShowTableStyleColumnStripes = value

    @property
    def ShowTableStyleLastColumn(self):
        return PivotTable(self.com_object.ShowTableStyleLastColumn)

    @ShowTableStyleLastColumn.setter
    def ShowTableStyleLastColumn(self, value):
        self.com_object.ShowTableStyleLastColumn = value

    @property
    def showtablestylelastcolumn(self):
        """Alias for ShowTableStyleLastColumn"""
        return self.ShowTableStyleLastColumn

    @showtablestylelastcolumn.setter
    def showtablestylelastcolumn(self, value):
        """Alias for ShowTableStyleLastColumn.setter"""
        self.ShowTableStyleLastColumn = value

    @property
    def show_table_style_last_column(self):
        """Alias for ShowTableStyleLastColumn"""
        return self.ShowTableStyleLastColumn

    @show_table_style_last_column.setter
    def show_table_style_last_column(self, value):
        """Alias for ShowTableStyleLastColumn.setter"""
        self.ShowTableStyleLastColumn = value

    @property
    def ShowTableStyleRowHeaders(self):
        return self.com_object.ShowTableStyleRowHeaders

    @ShowTableStyleRowHeaders.setter
    def ShowTableStyleRowHeaders(self, value):
        self.com_object.ShowTableStyleRowHeaders = value

    @property
    def showtablestylerowheaders(self):
        """Alias for ShowTableStyleRowHeaders"""
        return self.ShowTableStyleRowHeaders

    @showtablestylerowheaders.setter
    def showtablestylerowheaders(self, value):
        """Alias for ShowTableStyleRowHeaders.setter"""
        self.ShowTableStyleRowHeaders = value

    @property
    def show_table_style_row_headers(self):
        """Alias for ShowTableStyleRowHeaders"""
        return self.ShowTableStyleRowHeaders

    @show_table_style_row_headers.setter
    def show_table_style_row_headers(self, value):
        """Alias for ShowTableStyleRowHeaders.setter"""
        self.ShowTableStyleRowHeaders = value

    @property
    def ShowTableStyleRowStripes(self):
        return self.com_object.ShowTableStyleRowStripes

    @ShowTableStyleRowStripes.setter
    def ShowTableStyleRowStripes(self, value):
        self.com_object.ShowTableStyleRowStripes = value

    @property
    def showtablestylerowstripes(self):
        """Alias for ShowTableStyleRowStripes"""
        return self.ShowTableStyleRowStripes

    @showtablestylerowstripes.setter
    def showtablestylerowstripes(self, value):
        """Alias for ShowTableStyleRowStripes.setter"""
        self.ShowTableStyleRowStripes = value

    @property
    def show_table_style_row_stripes(self):
        """Alias for ShowTableStyleRowStripes"""
        return self.ShowTableStyleRowStripes

    @show_table_style_row_stripes.setter
    def show_table_style_row_stripes(self, value):
        """Alias for ShowTableStyleRowStripes.setter"""
        self.ShowTableStyleRowStripes = value

    @property
    def ShowValuesRow(self):
        return self.com_object.ShowValuesRow

    @ShowValuesRow.setter
    def ShowValuesRow(self, value):
        self.com_object.ShowValuesRow = value

    @property
    def showvaluesrow(self):
        """Alias for ShowValuesRow"""
        return self.ShowValuesRow

    @showvaluesrow.setter
    def showvaluesrow(self, value):
        """Alias for ShowValuesRow.setter"""
        self.ShowValuesRow = value

    @property
    def show_values_row(self):
        """Alias for ShowValuesRow"""
        return self.ShowValuesRow

    @show_values_row.setter
    def show_values_row(self, value):
        """Alias for ShowValuesRow.setter"""
        self.ShowValuesRow = value

    @property
    def Slicers(self):
        return Slicers(self.com_object.Slicers)

    @property
    def slicers(self):
        """Alias for Slicers"""
        return self.Slicers

    @property
    def SmallGrid(self):
        return self.com_object.SmallGrid

    @SmallGrid.setter
    def SmallGrid(self, value):
        self.com_object.SmallGrid = value

    @property
    def smallgrid(self):
        """Alias for SmallGrid"""
        return self.SmallGrid

    @smallgrid.setter
    def smallgrid(self, value):
        """Alias for SmallGrid.setter"""
        self.SmallGrid = value

    @property
    def small_grid(self):
        """Alias for SmallGrid"""
        return self.SmallGrid

    @small_grid.setter
    def small_grid(self, value):
        """Alias for SmallGrid.setter"""
        self.SmallGrid = value

    @property
    def SortUsingCustomLists(self):
        return self.com_object.SortUsingCustomLists

    @SortUsingCustomLists.setter
    def SortUsingCustomLists(self, value):
        self.com_object.SortUsingCustomLists = value

    @property
    def sortusingcustomlists(self):
        """Alias for SortUsingCustomLists"""
        return self.SortUsingCustomLists

    @sortusingcustomlists.setter
    def sortusingcustomlists(self, value):
        """Alias for SortUsingCustomLists.setter"""
        self.SortUsingCustomLists = value

    @property
    def sort_using_custom_lists(self):
        """Alias for SortUsingCustomLists"""
        return self.SortUsingCustomLists

    @sort_using_custom_lists.setter
    def sort_using_custom_lists(self, value):
        """Alias for SortUsingCustomLists.setter"""
        self.SortUsingCustomLists = value

    @property
    def SourceData(self):
        return self.com_object.SourceData

    @SourceData.setter
    def SourceData(self, value):
        self.com_object.SourceData = value

    @property
    def sourcedata(self):
        """Alias for SourceData"""
        return self.SourceData

    @sourcedata.setter
    def sourcedata(self, value):
        """Alias for SourceData.setter"""
        self.SourceData = value

    @property
    def source_data(self):
        """Alias for SourceData"""
        return self.SourceData

    @source_data.setter
    def source_data(self, value):
        """Alias for SourceData.setter"""
        self.SourceData = value

    @property
    def SubtotalHiddenPageItems(self):
        return self.com_object.SubtotalHiddenPageItems

    @SubtotalHiddenPageItems.setter
    def SubtotalHiddenPageItems(self, value):
        self.com_object.SubtotalHiddenPageItems = value

    @property
    def subtotalhiddenpageitems(self):
        """Alias for SubtotalHiddenPageItems"""
        return self.SubtotalHiddenPageItems

    @subtotalhiddenpageitems.setter
    def subtotalhiddenpageitems(self, value):
        """Alias for SubtotalHiddenPageItems.setter"""
        self.SubtotalHiddenPageItems = value

    @property
    def subtotal_hidden_page_items(self):
        """Alias for SubtotalHiddenPageItems"""
        return self.SubtotalHiddenPageItems

    @subtotal_hidden_page_items.setter
    def subtotal_hidden_page_items(self, value):
        """Alias for SubtotalHiddenPageItems.setter"""
        self.SubtotalHiddenPageItems = value

    @property
    def Summary(self):
        return self.com_object.Summary

    @Summary.setter
    def Summary(self, value):
        self.com_object.Summary = value

    @property
    def summary(self):
        """Alias for Summary"""
        return self.Summary

    @summary.setter
    def summary(self, value):
        """Alias for Summary.setter"""
        self.Summary = value

    @property
    def TableRange1(self):
        return Range(self.com_object.TableRange1)

    @property
    def tablerange1(self):
        """Alias for TableRange1"""
        return self.TableRange1

    @property
    def table_range1(self):
        """Alias for TableRange1"""
        return self.TableRange1

    @property
    def TableRange2(self):
        return Range(self.com_object.TableRange2)

    @property
    def tablerange2(self):
        """Alias for TableRange2"""
        return self.TableRange2

    @property
    def table_range2(self):
        """Alias for TableRange2"""
        return self.TableRange2

    @property
    def TableStyle2(self):
        return self.com_object.TableStyle2

    @TableStyle2.setter
    def TableStyle2(self, value):
        self.com_object.TableStyle2 = value

    @property
    def tablestyle2(self):
        """Alias for TableStyle2"""
        return self.TableStyle2

    @tablestyle2.setter
    def tablestyle2(self, value):
        """Alias for TableStyle2.setter"""
        self.TableStyle2 = value

    @property
    def table_style2(self):
        """Alias for TableStyle2"""
        return self.TableStyle2

    @table_style2.setter
    def table_style2(self, value):
        """Alias for TableStyle2.setter"""
        self.TableStyle2 = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def TotalsAnnotation(self):
        return self.com_object.TotalsAnnotation

    @TotalsAnnotation.setter
    def TotalsAnnotation(self, value):
        self.com_object.TotalsAnnotation = value

    @property
    def totalsannotation(self):
        """Alias for TotalsAnnotation"""
        return self.TotalsAnnotation

    @totalsannotation.setter
    def totalsannotation(self, value):
        """Alias for TotalsAnnotation.setter"""
        self.TotalsAnnotation = value

    @property
    def totals_annotation(self):
        """Alias for TotalsAnnotation"""
        return self.TotalsAnnotation

    @totals_annotation.setter
    def totals_annotation(self, value):
        """Alias for TotalsAnnotation.setter"""
        self.TotalsAnnotation = value

    @property
    def VacatedStyle(self):
        return self.com_object.VacatedStyle

    @VacatedStyle.setter
    def VacatedStyle(self, value):
        self.com_object.VacatedStyle = value

    @property
    def vacatedstyle(self):
        """Alias for VacatedStyle"""
        return self.VacatedStyle

    @vacatedstyle.setter
    def vacatedstyle(self, value):
        """Alias for VacatedStyle.setter"""
        self.VacatedStyle = value

    @property
    def vacated_style(self):
        """Alias for VacatedStyle"""
        return self.VacatedStyle

    @vacated_style.setter
    def vacated_style(self, value):
        """Alias for VacatedStyle.setter"""
        self.VacatedStyle = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    @property
    def Version(self):
        return XlPivotTableVersionList(self.com_object.Version)

    @property
    def version(self):
        """Alias for Version"""
        return self.Version

    @property
    def ViewCalculatedMembers(self):
        return self.com_object.ViewCalculatedMembers

    @ViewCalculatedMembers.setter
    def ViewCalculatedMembers(self, value):
        self.com_object.ViewCalculatedMembers = value

    @property
    def viewcalculatedmembers(self):
        """Alias for ViewCalculatedMembers"""
        return self.ViewCalculatedMembers

    @viewcalculatedmembers.setter
    def viewcalculatedmembers(self, value):
        """Alias for ViewCalculatedMembers.setter"""
        self.ViewCalculatedMembers = value

    @property
    def view_calculated_members(self):
        """Alias for ViewCalculatedMembers"""
        return self.ViewCalculatedMembers

    @view_calculated_members.setter
    def view_calculated_members(self, value):
        """Alias for ViewCalculatedMembers.setter"""
        self.ViewCalculatedMembers = value

    def VisibleFields(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetVisibleFields"):
            return PivotField(self.com_object.GetVisibleFields(*arguments))
        else:
            return PivotField(self.com_object.VisibleFields(*arguments))

    def visiblefields(self, Index=None):
        """Alias for VisibleFields"""
        arguments = [Index]
        return self.VisibleFields(*arguments)

    def visible_fields(self, Index=None):
        """Alias for VisibleFields"""
        arguments = [Index]
        return self.VisibleFields(*arguments)

    @property
    def VisualTotals(self):
        return self.com_object.VisualTotals

    @VisualTotals.setter
    def VisualTotals(self, value):
        self.com_object.VisualTotals = value

    @property
    def visualtotals(self):
        """Alias for VisualTotals"""
        return self.VisualTotals

    @visualtotals.setter
    def visualtotals(self, value):
        """Alias for VisualTotals.setter"""
        self.VisualTotals = value

    @property
    def visual_totals(self):
        """Alias for VisualTotals"""
        return self.VisualTotals

    @visual_totals.setter
    def visual_totals(self, value):
        """Alias for VisualTotals.setter"""
        self.VisualTotals = value

    @property
    def VisualTotalsForSets(self):
        return self.com_object.VisualTotalsForSets

    @VisualTotalsForSets.setter
    def VisualTotalsForSets(self, value):
        self.com_object.VisualTotalsForSets = value

    @property
    def visualtotalsforsets(self):
        """Alias for VisualTotalsForSets"""
        return self.VisualTotalsForSets

    @visualtotalsforsets.setter
    def visualtotalsforsets(self, value):
        """Alias for VisualTotalsForSets.setter"""
        self.VisualTotalsForSets = value

    @property
    def visual_totals_for_sets(self):
        """Alias for VisualTotalsForSets"""
        return self.VisualTotalsForSets

    @visual_totals_for_sets.setter
    def visual_totals_for_sets(self, value):
        """Alias for VisualTotalsForSets.setter"""
        self.VisualTotalsForSets = value

    def AddDataField(self, Field=None, Caption=None, Function=None):
        arguments = com_arguments([unwrap(a) for a in [Field, Caption, Function]])
        return PivotField(self.com_object.AddDataField(*arguments))

    def adddatafield(self, Field=None, Caption=None, Function=None):
        """Alias for AddDataField"""
        arguments = [Field, Caption, Function]
        return self.AddDataField(*arguments)

    def add_data_field(self, Field=None, Caption=None, Function=None):
        """Alias for AddDataField"""
        arguments = [Field, Caption, Function]
        return self.AddDataField(*arguments)

    def AddFields(self, RowFields=None, ColumnFields=None, PageFields=None, AddToTable=None):
        arguments = com_arguments([unwrap(a) for a in [RowFields, ColumnFields, PageFields, AddToTable]])
        return self.com_object.AddFields(*arguments)

    def addfields(self, RowFields=None, ColumnFields=None, PageFields=None, AddToTable=None):
        """Alias for AddFields"""
        arguments = [RowFields, ColumnFields, PageFields, AddToTable]
        return self.AddFields(*arguments)

    def add_fields(self, RowFields=None, ColumnFields=None, PageFields=None, AddToTable=None):
        """Alias for AddFields"""
        arguments = [RowFields, ColumnFields, PageFields, AddToTable]
        return self.AddFields(*arguments)

    def AllocateChanges(self):
        return self.com_object.AllocateChanges()

    def allocatechanges(self):
        """Alias for AllocateChanges"""
        return self.AllocateChanges()

    def allocate_changes(self):
        """Alias for AllocateChanges"""
        return self.AllocateChanges()

    def CalculatedFields(self):
        return CalculatedFields(self.com_object.CalculatedFields())

    def calculatedfields(self):
        """Alias for CalculatedFields"""
        return self.CalculatedFields()

    def calculated_fields(self):
        """Alias for CalculatedFields"""
        return self.CalculatedFields()

    def ChangeConnection(self, conn=None):
        arguments = com_arguments([unwrap(a) for a in [conn]])
        self.com_object.ChangeConnection(*arguments)

    def changeconnection(self, conn=None):
        """Alias for ChangeConnection"""
        arguments = [conn]
        return self.ChangeConnection(*arguments)

    def change_connection(self, conn=None):
        """Alias for ChangeConnection"""
        arguments = [conn]
        return self.ChangeConnection(*arguments)

    def ChangePivotCache(self, bstr=None):
        arguments = com_arguments([unwrap(a) for a in [bstr]])
        self.com_object.ChangePivotCache(*arguments)

    def changepivotcache(self, bstr=None):
        """Alias for ChangePivotCache"""
        arguments = [bstr]
        return self.ChangePivotCache(*arguments)

    def change_pivot_cache(self, bstr=None):
        """Alias for ChangePivotCache"""
        arguments = [bstr]
        return self.ChangePivotCache(*arguments)

    def ClearAllFilters(self):
        self.com_object.ClearAllFilters()

    def clearallfilters(self):
        """Alias for ClearAllFilters"""
        return self.ClearAllFilters()

    def clear_all_filters(self):
        """Alias for ClearAllFilters"""
        return self.ClearAllFilters()

    def ClearTable(self):
        self.com_object.ClearTable()

    def cleartable(self):
        """Alias for ClearTable"""
        return self.ClearTable()

    def clear_table(self):
        """Alias for ClearTable"""
        return self.ClearTable()

    def CommitChanges(self):
        return self.com_object.CommitChanges()

    def commitchanges(self):
        """Alias for CommitChanges"""
        return self.CommitChanges()

    def commit_changes(self):
        """Alias for CommitChanges"""
        return self.CommitChanges()

    def ConvertToFormulas(self, ConvertFilters=None):
        arguments = com_arguments([unwrap(a) for a in [ConvertFilters]])
        self.com_object.ConvertToFormulas(*arguments)

    def converttoformulas(self, ConvertFilters=None):
        """Alias for ConvertToFormulas"""
        arguments = [ConvertFilters]
        return self.ConvertToFormulas(*arguments)

    def convert_to_formulas(self, ConvertFilters=None):
        """Alias for ConvertToFormulas"""
        arguments = [ConvertFilters]
        return self.ConvertToFormulas(*arguments)

    def CreateCubeFile(self, File=None, Measures=None, Levels=None, Members=None, Properties=None):
        arguments = com_arguments([unwrap(a) for a in [File, Measures, Levels, Members, Properties]])
        return self.com_object.CreateCubeFile(*arguments)

    def createcubefile(self, File=None, Measures=None, Levels=None, Members=None, Properties=None):
        """Alias for CreateCubeFile"""
        arguments = [File, Measures, Levels, Members, Properties]
        return self.CreateCubeFile(*arguments)

    def create_cube_file(self, File=None, Measures=None, Levels=None, Members=None, Properties=None):
        """Alias for CreateCubeFile"""
        arguments = [File, Measures, Levels, Members, Properties]
        return self.CreateCubeFile(*arguments)

    def DiscardChanges(self):
        return self.com_object.DiscardChanges()

    def discardchanges(self):
        """Alias for DiscardChanges"""
        return self.DiscardChanges()

    def discard_changes(self):
        """Alias for DiscardChanges"""
        return self.DiscardChanges()

    def DrillDown(self, PivotItem=None, PivotLine=None):
        arguments = com_arguments([unwrap(a) for a in [PivotItem, PivotLine]])
        return self.com_object.DrillDown(*arguments)

    def drilldown(self, PivotItem=None, PivotLine=None):
        """Alias for DrillDown"""
        arguments = [PivotItem, PivotLine]
        return self.DrillDown(*arguments)

    def drill_down(self, PivotItem=None, PivotLine=None):
        """Alias for DrillDown"""
        arguments = [PivotItem, PivotLine]
        return self.DrillDown(*arguments)

    def DrillTo(self, PivotItem=None, CubeField=None, PivotLine=None):
        arguments = com_arguments([unwrap(a) for a in [PivotItem, CubeField, PivotLine]])
        return self.com_object.DrillTo(*arguments)

    def drillto(self, PivotItem=None, CubeField=None, PivotLine=None):
        """Alias for DrillTo"""
        arguments = [PivotItem, CubeField, PivotLine]
        return self.DrillTo(*arguments)

    def drill_to(self, PivotItem=None, CubeField=None, PivotLine=None):
        """Alias for DrillTo"""
        arguments = [PivotItem, CubeField, PivotLine]
        return self.DrillTo(*arguments)

    def DrillUp(self, PivotItem=None, PivotLine=None, LevelUniqueName=None):
        arguments = com_arguments([unwrap(a) for a in [PivotItem, PivotLine, LevelUniqueName]])
        return self.com_object.DrillUp(*arguments)

    def drillup(self, PivotItem=None, PivotLine=None, LevelUniqueName=None):
        """Alias for DrillUp"""
        arguments = [PivotItem, PivotLine, LevelUniqueName]
        return self.DrillUp(*arguments)

    def drill_up(self, PivotItem=None, PivotLine=None, LevelUniqueName=None):
        """Alias for DrillUp"""
        arguments = [PivotItem, PivotLine, LevelUniqueName]
        return self.DrillUp(*arguments)

    def GetData(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        return self.com_object.GetData(*arguments)

    def getdata(self, Name=None):
        """Alias for GetData"""
        arguments = [Name]
        return self.GetData(*arguments)

    def get_data(self, Name=None):
        """Alias for GetData"""
        arguments = [Name]
        return self.GetData(*arguments)

    def GetPivotData(self, DataField=None, Field1=None, Item1=None, Field2=None, Item2=None, Field3=None, Item3=None, Field4=None, Item4=None, Field5=None, Item5=None, Field6=None, Item6=None, Field7=None, Item7=None, Field8=None, Item8=None, Field9=None, Item9=None, Field10=None, Item10=None, Field11=None, Item11=None, Field12=None, Item12=None, Field13=None, Item13=None, Field14=None, Item14=None):
        arguments = com_arguments([unwrap(a) for a in [DataField, Field1, Item1, Field2, Item2, Field3, Item3, Field4, Item4, Field5, Item5, Field6, Item6, Field7, Item7, Field8, Item8, Field9, Item9, Field10, Item10, Field11, Item11, Field12, Item12, Field13, Item13, Field14, Item14]])
        return Range(self.com_object.GetPivotData(*arguments))

    def getpivotdata(self, DataField=None, Field1=None, Item1=None, Field2=None, Item2=None, Field3=None, Item3=None, Field4=None, Item4=None, Field5=None, Item5=None, Field6=None, Item6=None, Field7=None, Item7=None, Field8=None, Item8=None, Field9=None, Item9=None, Field10=None, Item10=None, Field11=None, Item11=None, Field12=None, Item12=None, Field13=None, Item13=None, Field14=None, Item14=None):
        """Alias for GetPivotData"""
        arguments = [DataField, Field1, Item1, Field2, Item2, Field3, Item3, Field4, Item4, Field5, Item5, Field6, Item6, Field7, Item7, Field8, Item8, Field9, Item9, Field10, Item10, Field11, Item11, Field12, Item12, Field13, Item13, Field14, Item14]
        return self.GetPivotData(*arguments)

    def get_pivot_data(self, DataField=None, Field1=None, Item1=None, Field2=None, Item2=None, Field3=None, Item3=None, Field4=None, Item4=None, Field5=None, Item5=None, Field6=None, Item6=None, Field7=None, Item7=None, Field8=None, Item8=None, Field9=None, Item9=None, Field10=None, Item10=None, Field11=None, Item11=None, Field12=None, Item12=None, Field13=None, Item13=None, Field14=None, Item14=None):
        """Alias for GetPivotData"""
        arguments = [DataField, Field1, Item1, Field2, Item2, Field3, Item3, Field4, Item4, Field5, Item5, Field6, Item6, Field7, Item7, Field8, Item8, Field9, Item9, Field10, Item10, Field11, Item11, Field12, Item12, Field13, Item13, Field14, Item14]
        return self.GetPivotData(*arguments)

    def ListFormulas(self):
        self.com_object.ListFormulas()

    def listformulas(self):
        """Alias for ListFormulas"""
        return self.ListFormulas()

    def list_formulas(self):
        """Alias for ListFormulas"""
        return self.ListFormulas()

    def PivotCache(self):
        return PivotCache(self.com_object.PivotCache())

    def pivotcache(self):
        """Alias for PivotCache"""
        return self.PivotCache()

    def pivot_cache(self):
        """Alias for PivotCache"""
        return self.PivotCache()

    def PivotFields(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.PivotFields(*arguments)

    def pivotfields(self, Index=None):
        """Alias for PivotFields"""
        arguments = [Index]
        return self.PivotFields(*arguments)

    def pivot_fields(self, Index=None):
        """Alias for PivotFields"""
        arguments = [Index]
        return self.PivotFields(*arguments)

    def PivotSelect(self, Name=None, Mode=None, UseStandardName=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Mode, UseStandardName]])
        self.com_object.PivotSelect(*arguments)

    def pivotselect(self, Name=None, Mode=None, UseStandardName=None):
        """Alias for PivotSelect"""
        arguments = [Name, Mode, UseStandardName]
        return self.PivotSelect(*arguments)

    def pivot_select(self, Name=None, Mode=None, UseStandardName=None):
        """Alias for PivotSelect"""
        arguments = [Name, Mode, UseStandardName]
        return self.PivotSelect(*arguments)

    def PivotTableWizard(self, SourceType=None, SourceData=None, TableDestination=None, TableName=None, RowGrand=None, ColumnGrand=None, SaveData=None, HasAutoFormat=None, AutoPage=None, Reserved=None, BackgroundQuery=None, OptimizeCache=None, PageFieldOrder=None, PageFieldWrapCount=None, ReadData=None, Connection=None):
        arguments = com_arguments([unwrap(a) for a in [SourceType, SourceData, TableDestination, TableName, RowGrand, ColumnGrand, SaveData, HasAutoFormat, AutoPage, Reserved, BackgroundQuery, OptimizeCache, PageFieldOrder, PageFieldWrapCount, ReadData, Connection]])
        self.com_object.PivotTableWizard(*arguments)

    def pivottablewizard(self, SourceType=None, SourceData=None, TableDestination=None, TableName=None, RowGrand=None, ColumnGrand=None, SaveData=None, HasAutoFormat=None, AutoPage=None, Reserved=None, BackgroundQuery=None, OptimizeCache=None, PageFieldOrder=None, PageFieldWrapCount=None, ReadData=None, Connection=None):
        """Alias for PivotTableWizard"""
        arguments = [SourceType, SourceData, TableDestination, TableName, RowGrand, ColumnGrand, SaveData, HasAutoFormat, AutoPage, Reserved, BackgroundQuery, OptimizeCache, PageFieldOrder, PageFieldWrapCount, ReadData, Connection]
        return self.PivotTableWizard(*arguments)

    def pivot_table_wizard(self, SourceType=None, SourceData=None, TableDestination=None, TableName=None, RowGrand=None, ColumnGrand=None, SaveData=None, HasAutoFormat=None, AutoPage=None, Reserved=None, BackgroundQuery=None, OptimizeCache=None, PageFieldOrder=None, PageFieldWrapCount=None, ReadData=None, Connection=None):
        """Alias for PivotTableWizard"""
        arguments = [SourceType, SourceData, TableDestination, TableName, RowGrand, ColumnGrand, SaveData, HasAutoFormat, AutoPage, Reserved, BackgroundQuery, OptimizeCache, PageFieldOrder, PageFieldWrapCount, ReadData, Connection]
        return self.PivotTableWizard(*arguments)

    def PivotValueCell(self, RowLine=None, ColumnLine=None):
        arguments = com_arguments([unwrap(a) for a in [RowLine, ColumnLine]])
        return PIVOTVALUECELL(self.com_object.PivotValueCell(*arguments))

    def pivotvaluecell(self, RowLine=None, ColumnLine=None):
        """Alias for PivotValueCell"""
        arguments = [RowLine, ColumnLine]
        return self.PivotValueCell(*arguments)

    def pivot_value_cell(self, RowLine=None, ColumnLine=None):
        """Alias for PivotValueCell"""
        arguments = [RowLine, ColumnLine]
        return self.PivotValueCell(*arguments)

    def RefreshDataSourceValues(self):
        return self.com_object.RefreshDataSourceValues()

    def refreshdatasourcevalues(self):
        """Alias for RefreshDataSourceValues"""
        return self.RefreshDataSourceValues()

    def refresh_data_source_values(self):
        """Alias for RefreshDataSourceValues"""
        return self.RefreshDataSourceValues()

    def RefreshTable(self):
        return self.com_object.RefreshTable()

    def refreshtable(self):
        """Alias for RefreshTable"""
        return self.RefreshTable()

    def refresh_table(self):
        """Alias for RefreshTable"""
        return self.RefreshTable()

    def RepeatAllLabels(self, Repeat=None):
        arguments = com_arguments([unwrap(a) for a in [Repeat]])
        return self.com_object.RepeatAllLabels(*arguments)

    def repeatalllabels(self, Repeat=None):
        """Alias for RepeatAllLabels"""
        arguments = [Repeat]
        return self.RepeatAllLabels(*arguments)

    def repeat_all_labels(self, Repeat=None):
        """Alias for RepeatAllLabels"""
        arguments = [Repeat]
        return self.RepeatAllLabels(*arguments)

    def RowAxisLayout(self, RowLayout=None):
        arguments = com_arguments([unwrap(a) for a in [RowLayout]])
        self.com_object.RowAxisLayout(*arguments)

    def rowaxislayout(self, RowLayout=None):
        """Alias for RowAxisLayout"""
        arguments = [RowLayout]
        return self.RowAxisLayout(*arguments)

    def row_axis_layout(self, RowLayout=None):
        """Alias for RowAxisLayout"""
        arguments = [RowLayout]
        return self.RowAxisLayout(*arguments)

    def ShowPages(self, PageField=None):
        arguments = com_arguments([unwrap(a) for a in [PageField]])
        return self.com_object.ShowPages(*arguments)

    def showpages(self, PageField=None):
        """Alias for ShowPages"""
        arguments = [PageField]
        return self.ShowPages(*arguments)

    def show_pages(self, PageField=None):
        """Alias for ShowPages"""
        arguments = [PageField]
        return self.ShowPages(*arguments)

    def SubtotalLocation(self, Location=None):
        arguments = com_arguments([unwrap(a) for a in [Location]])
        self.com_object.SubtotalLocation(*arguments)

    def subtotallocation(self, Location=None):
        """Alias for SubtotalLocation"""
        arguments = [Location]
        return self.SubtotalLocation(*arguments)

    def subtotal_location(self, Location=None):
        """Alias for SubtotalLocation"""
        arguments = [Location]
        return self.SubtotalLocation(*arguments)

    def Update(self):
        self.com_object.Update()

    def update(self):
        """Alias for Update"""
        return self.Update()


class PivotTableChangeList:

    def __init__(self, pivottablechangelist=None):
        self.com_object= pivottablechangelist

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return ValueChange(self.com_object.GetItem(*arguments))
        else:
            return ValueChange(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return PivotTable(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Tuple=None, Value=None, AllocationValue=None, AllocationMethod=None, AllocationWeightExpression=None):
        arguments = com_arguments([unwrap(a) for a in [Tuple, Value, AllocationValue, AllocationMethod, AllocationWeightExpression]])
        return ValueChange(self.com_object.Add(*arguments))

    def add(self, Tuple=None, Value=None, AllocationValue=None, AllocationMethod=None, AllocationWeightExpression=None):
        """Alias for Add"""
        arguments = [Tuple, Value, AllocationValue, AllocationMethod, AllocationWeightExpression]
        return self.Add(*arguments)


class PivotTables:

    def __init__(self, pivottables=None):
        self.com_object= pivottables

    def __call__(self, item):
        return PivotTable(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, PivotCache=None, TableDestination=None, TableName=None, ReadData=None, DefaultVersion=None):
        arguments = com_arguments([unwrap(a) for a in [PivotCache, TableDestination, TableName, ReadData, DefaultVersion]])
        return PivotTable(self.com_object.Add(*arguments))

    def add(self, PivotCache=None, TableDestination=None, TableName=None, ReadData=None, DefaultVersion=None):
        """Alias for Add"""
        arguments = [PivotCache, TableDestination, TableName, ReadData, DefaultVersion]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return PivotTable(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class PivotValueCell:

    def __init__(self, pivotvaluecell=None):
        self.com_object= pivotvaluecell

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PivotCell(self):
        return PivotCell(self.com_object.PivotCell)

    @property
    def pivotcell(self):
        """Alias for PivotCell"""
        return self.PivotCell

    @property
    def pivot_cell(self):
        """Alias for PivotCell"""
        return self.PivotCell

    @property
    def ServerActions(self):
        return self.com_object.ServerActions

    @property
    def serveractions(self):
        """Alias for ServerActions"""
        return self.ServerActions

    @property
    def server_actions(self):
        """Alias for ServerActions"""
        return self.ServerActions

    @property
    def Value(self):
        return self.com_object.Value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    def ShowDetail(self):
        return self.com_object.ShowDetail()

    def showdetail(self):
        """Alias for ShowDetail"""
        return self.ShowDetail()

    def show_detail(self):
        """Alias for ShowDetail"""
        return self.ShowDetail()


class PlotArea:

    def __init__(self, plotarea=None):
        self.com_object= plotarea

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def InsideHeight(self):
        return self.com_object.InsideHeight

    @InsideHeight.setter
    def InsideHeight(self, value):
        self.com_object.InsideHeight = value

    @property
    def insideheight(self):
        """Alias for InsideHeight"""
        return self.InsideHeight

    @insideheight.setter
    def insideheight(self, value):
        """Alias for InsideHeight.setter"""
        self.InsideHeight = value

    @property
    def inside_height(self):
        """Alias for InsideHeight"""
        return self.InsideHeight

    @inside_height.setter
    def inside_height(self, value):
        """Alias for InsideHeight.setter"""
        self.InsideHeight = value

    @property
    def InsideLeft(self):
        return self.com_object.InsideLeft

    @InsideLeft.setter
    def InsideLeft(self, value):
        self.com_object.InsideLeft = value

    @property
    def insideleft(self):
        """Alias for InsideLeft"""
        return self.InsideLeft

    @insideleft.setter
    def insideleft(self, value):
        """Alias for InsideLeft.setter"""
        self.InsideLeft = value

    @property
    def inside_left(self):
        """Alias for InsideLeft"""
        return self.InsideLeft

    @inside_left.setter
    def inside_left(self, value):
        """Alias for InsideLeft.setter"""
        self.InsideLeft = value

    @property
    def InsideTop(self):
        return self.com_object.InsideTop

    @InsideTop.setter
    def InsideTop(self, value):
        self.com_object.InsideTop = value

    @property
    def insidetop(self):
        """Alias for InsideTop"""
        return self.InsideTop

    @insidetop.setter
    def insidetop(self, value):
        """Alias for InsideTop.setter"""
        self.InsideTop = value

    @property
    def inside_top(self):
        """Alias for InsideTop"""
        return self.InsideTop

    @inside_top.setter
    def inside_top(self, value):
        """Alias for InsideTop.setter"""
        self.InsideTop = value

    @property
    def InsideWidth(self):
        return self.com_object.InsideWidth

    @InsideWidth.setter
    def InsideWidth(self, value):
        self.com_object.InsideWidth = value

    @property
    def insidewidth(self):
        """Alias for InsideWidth"""
        return self.InsideWidth

    @insidewidth.setter
    def insidewidth(self, value):
        """Alias for InsideWidth.setter"""
        self.InsideWidth = value

    @property
    def inside_width(self):
        """Alias for InsideWidth"""
        return self.InsideWidth

    @inside_width.setter
    def inside_width(self, value):
        """Alias for InsideWidth.setter"""
        self.InsideWidth = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Position(self):
        return XlChartElementPosition(self.com_object.Position)

    @Position.setter
    def Position(self, value):
        self.com_object.Position = value

    @property
    def position(self):
        """Alias for Position"""
        return self.Position

    @position.setter
    def position(self, value):
        """Alias for Position.setter"""
        self.Position = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def ClearFormats(self):
        return self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Select(self):
        return self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Point:

    def __init__(self, point=None):
        self.com_object= point

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ApplyPictToEnd(self):
        return self.com_object.ApplyPictToEnd

    @ApplyPictToEnd.setter
    def ApplyPictToEnd(self, value):
        self.com_object.ApplyPictToEnd = value

    @property
    def applypicttoend(self):
        """Alias for ApplyPictToEnd"""
        return self.ApplyPictToEnd

    @applypicttoend.setter
    def applypicttoend(self, value):
        """Alias for ApplyPictToEnd.setter"""
        self.ApplyPictToEnd = value

    @property
    def apply_pict_to_end(self):
        """Alias for ApplyPictToEnd"""
        return self.ApplyPictToEnd

    @apply_pict_to_end.setter
    def apply_pict_to_end(self, value):
        """Alias for ApplyPictToEnd.setter"""
        self.ApplyPictToEnd = value

    @property
    def ApplyPictToFront(self):
        return self.com_object.ApplyPictToFront

    @ApplyPictToFront.setter
    def ApplyPictToFront(self, value):
        self.com_object.ApplyPictToFront = value

    @property
    def applypicttofront(self):
        """Alias for ApplyPictToFront"""
        return self.ApplyPictToFront

    @applypicttofront.setter
    def applypicttofront(self, value):
        """Alias for ApplyPictToFront.setter"""
        self.ApplyPictToFront = value

    @property
    def apply_pict_to_front(self):
        """Alias for ApplyPictToFront"""
        return self.ApplyPictToFront

    @apply_pict_to_front.setter
    def apply_pict_to_front(self, value):
        """Alias for ApplyPictToFront.setter"""
        self.ApplyPictToFront = value

    @property
    def ApplyPictToSides(self):
        return self.com_object.ApplyPictToSides

    @ApplyPictToSides.setter
    def ApplyPictToSides(self, value):
        self.com_object.ApplyPictToSides = value

    @property
    def applypicttosides(self):
        """Alias for ApplyPictToSides"""
        return self.ApplyPictToSides

    @applypicttosides.setter
    def applypicttosides(self, value):
        """Alias for ApplyPictToSides.setter"""
        self.ApplyPictToSides = value

    @property
    def apply_pict_to_sides(self):
        """Alias for ApplyPictToSides"""
        return self.ApplyPictToSides

    @apply_pict_to_sides.setter
    def apply_pict_to_sides(self, value):
        """Alias for ApplyPictToSides.setter"""
        self.ApplyPictToSides = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DataLabel(self):
        return DataLabel(self.com_object.DataLabel)

    @property
    def datalabel(self):
        """Alias for DataLabel"""
        return self.DataLabel

    @property
    def data_label(self):
        """Alias for DataLabel"""
        return self.DataLabel

    @property
    def Explosion(self):
        return self.com_object.Explosion

    @Explosion.setter
    def Explosion(self, value):
        self.com_object.Explosion = value

    @property
    def explosion(self):
        """Alias for Explosion"""
        return self.Explosion

    @explosion.setter
    def explosion(self, value):
        """Alias for Explosion.setter"""
        self.Explosion = value

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Has3DEffect(self):
        return self.com_object.Has3DEffect

    @Has3DEffect.setter
    def Has3DEffect(self, value):
        self.com_object.Has3DEffect = value

    @property
    def has3deffect(self):
        """Alias for Has3DEffect"""
        return self.Has3DEffect

    @has3deffect.setter
    def has3deffect(self, value):
        """Alias for Has3DEffect.setter"""
        self.Has3DEffect = value

    @property
    def has3_d_effect(self):
        """Alias for Has3DEffect"""
        return self.Has3DEffect

    @has3_d_effect.setter
    def has3_d_effect(self, value):
        """Alias for Has3DEffect.setter"""
        self.Has3DEffect = value

    @property
    def HasDataLabel(self):
        return self.com_object.HasDataLabel

    @HasDataLabel.setter
    def HasDataLabel(self, value):
        self.com_object.HasDataLabel = value

    @property
    def hasdatalabel(self):
        """Alias for HasDataLabel"""
        return self.HasDataLabel

    @hasdatalabel.setter
    def hasdatalabel(self, value):
        """Alias for HasDataLabel.setter"""
        self.HasDataLabel = value

    @property
    def has_data_label(self):
        """Alias for HasDataLabel"""
        return self.HasDataLabel

    @has_data_label.setter
    def has_data_label(self, value):
        """Alias for HasDataLabel.setter"""
        self.HasDataLabel = value

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def InvertIfNegative(self):
        return self.com_object.InvertIfNegative

    @InvertIfNegative.setter
    def InvertIfNegative(self, value):
        self.com_object.InvertIfNegative = value

    @property
    def invertifnegative(self):
        """Alias for InvertIfNegative"""
        return self.InvertIfNegative

    @invertifnegative.setter
    def invertifnegative(self, value):
        """Alias for InvertIfNegative.setter"""
        self.InvertIfNegative = value

    @property
    def invert_if_negative(self):
        """Alias for InvertIfNegative"""
        return self.InvertIfNegative

    @invert_if_negative.setter
    def invert_if_negative(self, value):
        """Alias for InvertIfNegative.setter"""
        self.InvertIfNegative = value

    @property
    def IsTotal(self):
        return self.com_object.IsTotal

    @IsTotal.setter
    def IsTotal(self, value):
        self.com_object.IsTotal = value

    @property
    def istotal(self):
        """Alias for IsTotal"""
        return self.IsTotal

    @istotal.setter
    def istotal(self, value):
        """Alias for IsTotal.setter"""
        self.IsTotal = value

    @property
    def is_total(self):
        """Alias for IsTotal"""
        return self.IsTotal

    @is_total.setter
    def is_total(self, value):
        """Alias for IsTotal.setter"""
        self.IsTotal = value

    @property
    def Left(self):
        return self.com_object.Left

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @property
    def MarkerBackgroundColor(self):
        return self.com_object.MarkerBackgroundColor

    @MarkerBackgroundColor.setter
    def MarkerBackgroundColor(self, value):
        self.com_object.MarkerBackgroundColor = value

    @property
    def markerbackgroundcolor(self):
        """Alias for MarkerBackgroundColor"""
        return self.MarkerBackgroundColor

    @markerbackgroundcolor.setter
    def markerbackgroundcolor(self, value):
        """Alias for MarkerBackgroundColor.setter"""
        self.MarkerBackgroundColor = value

    @property
    def marker_background_color(self):
        """Alias for MarkerBackgroundColor"""
        return self.MarkerBackgroundColor

    @marker_background_color.setter
    def marker_background_color(self, value):
        """Alias for MarkerBackgroundColor.setter"""
        self.MarkerBackgroundColor = value

    @property
    def MarkerBackgroundColorIndex(self):
        return XlColorIndex(self.com_object.MarkerBackgroundColorIndex)

    @MarkerBackgroundColorIndex.setter
    def MarkerBackgroundColorIndex(self, value):
        self.com_object.MarkerBackgroundColorIndex = value

    @property
    def markerbackgroundcolorindex(self):
        """Alias for MarkerBackgroundColorIndex"""
        return self.MarkerBackgroundColorIndex

    @markerbackgroundcolorindex.setter
    def markerbackgroundcolorindex(self, value):
        """Alias for MarkerBackgroundColorIndex.setter"""
        self.MarkerBackgroundColorIndex = value

    @property
    def marker_background_color_index(self):
        """Alias for MarkerBackgroundColorIndex"""
        return self.MarkerBackgroundColorIndex

    @marker_background_color_index.setter
    def marker_background_color_index(self, value):
        """Alias for MarkerBackgroundColorIndex.setter"""
        self.MarkerBackgroundColorIndex = value

    @property
    def MarkerForegroundColor(self):
        return self.com_object.MarkerForegroundColor

    @MarkerForegroundColor.setter
    def MarkerForegroundColor(self, value):
        self.com_object.MarkerForegroundColor = value

    @property
    def markerforegroundcolor(self):
        """Alias for MarkerForegroundColor"""
        return self.MarkerForegroundColor

    @markerforegroundcolor.setter
    def markerforegroundcolor(self, value):
        """Alias for MarkerForegroundColor.setter"""
        self.MarkerForegroundColor = value

    @property
    def marker_foreground_color(self):
        """Alias for MarkerForegroundColor"""
        return self.MarkerForegroundColor

    @marker_foreground_color.setter
    def marker_foreground_color(self, value):
        """Alias for MarkerForegroundColor.setter"""
        self.MarkerForegroundColor = value

    @property
    def MarkerForegroundColorIndex(self):
        return XlColorIndex(self.com_object.MarkerForegroundColorIndex)

    @MarkerForegroundColorIndex.setter
    def MarkerForegroundColorIndex(self, value):
        self.com_object.MarkerForegroundColorIndex = value

    @property
    def markerforegroundcolorindex(self):
        """Alias for MarkerForegroundColorIndex"""
        return self.MarkerForegroundColorIndex

    @markerforegroundcolorindex.setter
    def markerforegroundcolorindex(self, value):
        """Alias for MarkerForegroundColorIndex.setter"""
        self.MarkerForegroundColorIndex = value

    @property
    def marker_foreground_color_index(self):
        """Alias for MarkerForegroundColorIndex"""
        return self.MarkerForegroundColorIndex

    @marker_foreground_color_index.setter
    def marker_foreground_color_index(self, value):
        """Alias for MarkerForegroundColorIndex.setter"""
        self.MarkerForegroundColorIndex = value

    @property
    def MarkerSize(self):
        return self.com_object.MarkerSize

    @MarkerSize.setter
    def MarkerSize(self, value):
        self.com_object.MarkerSize = value

    @property
    def markersize(self):
        """Alias for MarkerSize"""
        return self.MarkerSize

    @markersize.setter
    def markersize(self, value):
        """Alias for MarkerSize.setter"""
        self.MarkerSize = value

    @property
    def marker_size(self):
        """Alias for MarkerSize"""
        return self.MarkerSize

    @marker_size.setter
    def marker_size(self, value):
        """Alias for MarkerSize.setter"""
        self.MarkerSize = value

    @property
    def MarkerStyle(self):
        return XlMarkerStyle(self.com_object.MarkerStyle)

    @MarkerStyle.setter
    def MarkerStyle(self, value):
        self.com_object.MarkerStyle = value

    @property
    def markerstyle(self):
        """Alias for MarkerStyle"""
        return self.MarkerStyle

    @markerstyle.setter
    def markerstyle(self, value):
        """Alias for MarkerStyle.setter"""
        self.MarkerStyle = value

    @property
    def marker_style(self):
        """Alias for MarkerStyle"""
        return self.MarkerStyle

    @marker_style.setter
    def marker_style(self, value):
        """Alias for MarkerStyle.setter"""
        self.MarkerStyle = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PictureType(self):
        return XlChartPictureType(self.com_object.PictureType)

    @PictureType.setter
    def PictureType(self, value):
        self.com_object.PictureType = value

    @property
    def picturetype(self):
        """Alias for PictureType"""
        return self.PictureType

    @picturetype.setter
    def picturetype(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def picture_type(self):
        """Alias for PictureType"""
        return self.PictureType

    @picture_type.setter
    def picture_type(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def PictureUnit2(self):
        return PictureType(self.com_object.PictureUnit2)

    @PictureUnit2.setter
    def PictureUnit2(self, value):
        self.com_object.PictureUnit2 = value

    @property
    def pictureunit2(self):
        """Alias for PictureUnit2"""
        return self.PictureUnit2

    @pictureunit2.setter
    def pictureunit2(self, value):
        """Alias for PictureUnit2.setter"""
        self.PictureUnit2 = value

    @property
    def picture_unit2(self):
        """Alias for PictureUnit2"""
        return self.PictureUnit2

    @picture_unit2.setter
    def picture_unit2(self, value):
        """Alias for PictureUnit2.setter"""
        self.PictureUnit2 = value

    @property
    def SecondaryPlot(self):
        return self.com_object.SecondaryPlot

    @SecondaryPlot.setter
    def SecondaryPlot(self, value):
        self.com_object.SecondaryPlot = value

    @property
    def secondaryplot(self):
        """Alias for SecondaryPlot"""
        return self.SecondaryPlot

    @secondaryplot.setter
    def secondaryplot(self, value):
        """Alias for SecondaryPlot.setter"""
        self.SecondaryPlot = value

    @property
    def secondary_plot(self):
        """Alias for SecondaryPlot"""
        return self.SecondaryPlot

    @secondary_plot.setter
    def secondary_plot(self, value):
        """Alias for SecondaryPlot.setter"""
        self.SecondaryPlot = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Top(self):
        return self.com_object.Top

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    def ApplyDataLabels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        arguments = com_arguments([unwrap(a) for a in [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]])
        self.com_object.ApplyDataLabels(*arguments)

    def applydatalabels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        """Alias for ApplyDataLabels"""
        arguments = [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]
        return self.ApplyDataLabels(*arguments)

    def apply_data_labels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        """Alias for ApplyDataLabels"""
        arguments = [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]
        return self.ApplyDataLabels(*arguments)

    def ClearFormats(self):
        return self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Copy(self):
        return self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Paste(self):
        return self.com_object.Paste()

    def paste(self):
        """Alias for Paste"""
        return self.Paste()

    def PieSliceLocation(self, loc=None, Index=None):
        arguments = com_arguments([unwrap(a) for a in [loc, Index]])
        return self.com_object.PieSliceLocation(*arguments)

    def pieslicelocation(self, loc=None, Index=None):
        """Alias for PieSliceLocation"""
        arguments = [loc, Index]
        return self.PieSliceLocation(*arguments)

    def pie_slice_location(self, loc=None, Index=None):
        """Alias for PieSliceLocation"""
        arguments = [loc, Index]
        return self.PieSliceLocation(*arguments)

    def Select(self):
        return self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Points:

    def __init__(self, points=None):
        self.com_object= points

    def __call__(self, item):
        return Point(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Point(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ProtectedViewWindow:

    def __init__(self, protectedviewwindow=None):
        self.com_object= protectedviewwindow

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    @property
    def EnableResize(self):
        return self.com_object.EnableResize

    @EnableResize.setter
    def EnableResize(self, value):
        self.com_object.EnableResize = value

    @property
    def enableresize(self):
        """Alias for EnableResize"""
        return self.EnableResize

    @enableresize.setter
    def enableresize(self, value):
        """Alias for EnableResize.setter"""
        self.EnableResize = value

    @property
    def enable_resize(self):
        """Alias for EnableResize"""
        return self.EnableResize

    @enable_resize.setter
    def enable_resize(self, value):
        """Alias for EnableResize.setter"""
        self.EnableResize = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def SourceName(self):
        return self.com_object.SourceName

    @property
    def sourcename(self):
        """Alias for SourceName"""
        return self.SourceName

    @property
    def source_name(self):
        """Alias for SourceName"""
        return self.SourceName

    @property
    def SourcePath(self):
        return self.com_object.SourcePath

    @property
    def sourcepath(self):
        """Alias for SourcePath"""
        return self.SourcePath

    @property
    def source_path(self):
        """Alias for SourcePath"""
        return self.SourcePath

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def WindowState(self):
        return self.com_object.WindowState

    @WindowState.setter
    def WindowState(self, value):
        self.com_object.WindowState = value

    @property
    def windowstate(self):
        """Alias for WindowState"""
        return self.WindowState

    @windowstate.setter
    def windowstate(self, value):
        """Alias for WindowState.setter"""
        self.WindowState = value

    @property
    def window_state(self):
        """Alias for WindowState"""
        return self.WindowState

    @window_state.setter
    def window_state(self, value):
        """Alias for WindowState.setter"""
        self.WindowState = value

    @property
    def Workbook(self):
        return self.com_object.Workbook

    @property
    def workbook(self):
        """Alias for Workbook"""
        return self.Workbook

    def Activate(self):
        return self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()

    def Close(self):
        return self.com_object.Close()

    def close(self):
        """Alias for Close"""
        return self.Close()

    def Edit(self, WriteResPassword=None, UpdateLinks=None):
        arguments = com_arguments([unwrap(a) for a in [WriteResPassword, UpdateLinks]])
        return Workbook(self.com_object.Edit(*arguments))

    def edit(self, WriteResPassword=None, UpdateLinks=None):
        """Alias for Edit"""
        arguments = [WriteResPassword, UpdateLinks]
        return self.Edit(*arguments)


class ProtectedViewWindows:

    def __init__(self, protectedviewwindows=None):
        self.com_object= protectedviewwindows

    def __call__(self, item):
        return ProtectedViewWindow(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Open(self, FileName=None, Password=None, AddToMru=None, RepairMode=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, Password, AddToMru, RepairMode]])
        return ProtectedViewWindow(self.com_object.Open(*arguments))

    def open(self, FileName=None, Password=None, AddToMru=None, RepairMode=None):
        """Alias for Open"""
        arguments = [FileName, Password, AddToMru, RepairMode]
        return self.Open(*arguments)


class Protection:

    def __init__(self, protection=None):
        self.com_object= protection

    @property
    def AllowDeletingColumns(self):
        return self.com_object.AllowDeletingColumns

    @property
    def allowdeletingcolumns(self):
        """Alias for AllowDeletingColumns"""
        return self.AllowDeletingColumns

    @property
    def allow_deleting_columns(self):
        """Alias for AllowDeletingColumns"""
        return self.AllowDeletingColumns

    @property
    def AllowDeletingRows(self):
        return self.com_object.AllowDeletingRows

    @property
    def allowdeletingrows(self):
        """Alias for AllowDeletingRows"""
        return self.AllowDeletingRows

    @property
    def allow_deleting_rows(self):
        """Alias for AllowDeletingRows"""
        return self.AllowDeletingRows

    @property
    def AllowEditRanges(self):
        return AllowEditRanges(self.com_object.AllowEditRanges)

    @property
    def alloweditranges(self):
        """Alias for AllowEditRanges"""
        return self.AllowEditRanges

    @property
    def allow_edit_ranges(self):
        """Alias for AllowEditRanges"""
        return self.AllowEditRanges

    @property
    def AllowFiltering(self):
        return self.com_object.AllowFiltering

    @property
    def allowfiltering(self):
        """Alias for AllowFiltering"""
        return self.AllowFiltering

    @property
    def allow_filtering(self):
        """Alias for AllowFiltering"""
        return self.AllowFiltering

    @property
    def AllowFormattingCells(self):
        return self.com_object.AllowFormattingCells

    @property
    def allowformattingcells(self):
        """Alias for AllowFormattingCells"""
        return self.AllowFormattingCells

    @property
    def allow_formatting_cells(self):
        """Alias for AllowFormattingCells"""
        return self.AllowFormattingCells

    @property
    def AllowFormattingColumns(self):
        return self.com_object.AllowFormattingColumns

    @property
    def allowformattingcolumns(self):
        """Alias for AllowFormattingColumns"""
        return self.AllowFormattingColumns

    @property
    def allow_formatting_columns(self):
        """Alias for AllowFormattingColumns"""
        return self.AllowFormattingColumns

    @property
    def AllowFormattingRows(self):
        return self.com_object.AllowFormattingRows

    @property
    def allowformattingrows(self):
        """Alias for AllowFormattingRows"""
        return self.AllowFormattingRows

    @property
    def allow_formatting_rows(self):
        """Alias for AllowFormattingRows"""
        return self.AllowFormattingRows

    @property
    def AllowInsertingColumns(self):
        return self.com_object.AllowInsertingColumns

    @property
    def allowinsertingcolumns(self):
        """Alias for AllowInsertingColumns"""
        return self.AllowInsertingColumns

    @property
    def allow_inserting_columns(self):
        """Alias for AllowInsertingColumns"""
        return self.AllowInsertingColumns

    @property
    def AllowInsertingHyperlinks(self):
        return self.com_object.AllowInsertingHyperlinks

    @property
    def allowinsertinghyperlinks(self):
        """Alias for AllowInsertingHyperlinks"""
        return self.AllowInsertingHyperlinks

    @property
    def allow_inserting_hyperlinks(self):
        """Alias for AllowInsertingHyperlinks"""
        return self.AllowInsertingHyperlinks

    @property
    def AllowInsertingRows(self):
        return self.com_object.AllowInsertingRows

    @property
    def allowinsertingrows(self):
        """Alias for AllowInsertingRows"""
        return self.AllowInsertingRows

    @property
    def allow_inserting_rows(self):
        """Alias for AllowInsertingRows"""
        return self.AllowInsertingRows

    @property
    def AllowSorting(self):
        return self.com_object.AllowSorting

    @property
    def allowsorting(self):
        """Alias for AllowSorting"""
        return self.AllowSorting

    @property
    def allow_sorting(self):
        """Alias for AllowSorting"""
        return self.AllowSorting

    @property
    def AllowUsingPivotTables(self):
        return self.com_object.AllowUsingPivotTables

    @property
    def allowusingpivottables(self):
        """Alias for AllowUsingPivotTables"""
        return self.AllowUsingPivotTables

    @property
    def allow_using_pivot_tables(self):
        """Alias for AllowUsingPivotTables"""
        return self.AllowUsingPivotTables


class PublishObject:

    def __init__(self, publishobject=None):
        self.com_object= publishobject

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoRepublish(self):
        return self.com_object.AutoRepublish

    @AutoRepublish.setter
    def AutoRepublish(self, value):
        self.com_object.AutoRepublish = value

    @property
    def autorepublish(self):
        """Alias for AutoRepublish"""
        return self.AutoRepublish

    @autorepublish.setter
    def autorepublish(self, value):
        """Alias for AutoRepublish.setter"""
        self.AutoRepublish = value

    @property
    def auto_republish(self):
        """Alias for AutoRepublish"""
        return self.AutoRepublish

    @auto_republish.setter
    def auto_republish(self, value):
        """Alias for AutoRepublish.setter"""
        self.AutoRepublish = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DivID(self):
        return self.com_object.DivID

    @property
    def divid(self):
        """Alias for DivID"""
        return self.DivID

    @property
    def div_i_d(self):
        """Alias for DivID"""
        return self.DivID

    @property
    def Filename(self):
        return self.com_object.Filename

    @Filename.setter
    def Filename(self, value):
        self.com_object.Filename = value

    @property
    def filename(self):
        """Alias for Filename"""
        return self.Filename

    @filename.setter
    def filename(self, value):
        """Alias for Filename.setter"""
        self.Filename = value

    @property
    def HtmlType(self):
        return XlHtmlType(self.com_object.HtmlType)

    @HtmlType.setter
    def HtmlType(self, value):
        self.com_object.HtmlType = value

    @property
    def htmltype(self):
        """Alias for HtmlType"""
        return self.HtmlType

    @htmltype.setter
    def htmltype(self, value):
        """Alias for HtmlType.setter"""
        self.HtmlType = value

    @property
    def html_type(self):
        """Alias for HtmlType"""
        return self.HtmlType

    @html_type.setter
    def html_type(self, value):
        """Alias for HtmlType.setter"""
        self.HtmlType = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Sheet(self):
        return PublishObject(self.com_object.Sheet)

    @property
    def sheet(self):
        """Alias for Sheet"""
        return self.Sheet

    @property
    def Source(self):
        return self.com_object.Source

    @property
    def source(self):
        """Alias for Source"""
        return self.Source

    @property
    def SourceType(self):
        return XlSourceType(self.com_object.SourceType)

    @property
    def sourcetype(self):
        """Alias for SourceType"""
        return self.SourceType

    @property
    def source_type(self):
        """Alias for SourceType"""
        return self.SourceType

    @property
    def Title(self):
        return self.com_object.Title

    @Title.setter
    def Title(self, value):
        self.com_object.Title = value

    @property
    def title(self):
        """Alias for Title"""
        return self.Title

    @title.setter
    def title(self, value):
        """Alias for Title.setter"""
        self.Title = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Publish(self, Create=None):
        arguments = com_arguments([unwrap(a) for a in [Create]])
        self.com_object.Publish(*arguments)

    def publish(self, Create=None):
        """Alias for Publish"""
        arguments = [Create]
        return self.Publish(*arguments)


class PublishObjects:

    def __init__(self, publishobjects=None):
        self.com_object= publishobjects

    def __call__(self, item):
        return PublishObject(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, SourceType=None, FileName=None, Sheet=None, Source=None, HtmlType=None, DivID=None, Title=None):
        arguments = com_arguments([unwrap(a) for a in [SourceType, FileName, Sheet, Source, HtmlType, DivID, Title]])
        return PublishObject(self.com_object.Add(*arguments))

    def add(self, SourceType=None, FileName=None, Sheet=None, Source=None, HtmlType=None, DivID=None, Title=None):
        """Alias for Add"""
        arguments = [SourceType, FileName, Sheet, Source, HtmlType, DivID, Title]
        return self.Add(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Publish(self):
        self.com_object.Publish()

    def publish(self):
        """Alias for Publish"""
        return self.Publish()


class Queries:

    def __init__(self, queries=None):
        self.com_object= queries

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def FastCombine(self):
        return self.com_object.FastCombine

    @FastCombine.setter
    def FastCombine(self, value):
        self.com_object.FastCombine = value

    @property
    def fastcombine(self):
        """Alias for FastCombine"""
        return self.FastCombine

    @fastcombine.setter
    def fastcombine(self, value):
        """Alias for FastCombine.setter"""
        self.FastCombine = value

    @property
    def fast_combine(self):
        """Alias for FastCombine"""
        return self.FastCombine

    @fast_combine.setter
    def fast_combine(self, value):
        """Alias for FastCombine.setter"""
        self.FastCombine = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, Formula=None, Description=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Formula, Description]])
        return WorkbookQuery(self.com_object.Add(*arguments))

    def add(self, Name=None, Formula=None, Description=None):
        """Alias for Add"""
        arguments = [Name, Formula, Description]
        return self.Add(*arguments)

    def Item(self, NameOrIndex=None):
        arguments = com_arguments([unwrap(a) for a in [NameOrIndex]])
        return WorkbookQuery(self.com_object.Item(*arguments))

    def item(self, NameOrIndex=None):
        """Alias for Item"""
        arguments = [NameOrIndex]
        return self.Item(*arguments)


class QueryTable:

    def __init__(self, querytable=None):
        self.com_object= querytable

    @property
    def AdjustColumnWidth(self):
        return self.com_object.AdjustColumnWidth

    @AdjustColumnWidth.setter
    def AdjustColumnWidth(self, value):
        self.com_object.AdjustColumnWidth = value

    @property
    def adjustcolumnwidth(self):
        """Alias for AdjustColumnWidth"""
        return self.AdjustColumnWidth

    @adjustcolumnwidth.setter
    def adjustcolumnwidth(self, value):
        """Alias for AdjustColumnWidth.setter"""
        self.AdjustColumnWidth = value

    @property
    def adjust_column_width(self):
        """Alias for AdjustColumnWidth"""
        return self.AdjustColumnWidth

    @adjust_column_width.setter
    def adjust_column_width(self, value):
        """Alias for AdjustColumnWidth.setter"""
        self.AdjustColumnWidth = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BackgroundQuery(self):
        return self.com_object.BackgroundQuery

    @BackgroundQuery.setter
    def BackgroundQuery(self, value):
        self.com_object.BackgroundQuery = value

    @property
    def backgroundquery(self):
        """Alias for BackgroundQuery"""
        return self.BackgroundQuery

    @backgroundquery.setter
    def backgroundquery(self, value):
        """Alias for BackgroundQuery.setter"""
        self.BackgroundQuery = value

    @property
    def background_query(self):
        """Alias for BackgroundQuery"""
        return self.BackgroundQuery

    @background_query.setter
    def background_query(self, value):
        """Alias for BackgroundQuery.setter"""
        self.BackgroundQuery = value

    @property
    def CommandText(self):
        return self.com_object.CommandText

    @CommandText.setter
    def CommandText(self, value):
        self.com_object.CommandText = value

    @property
    def commandtext(self):
        """Alias for CommandText"""
        return self.CommandText

    @commandtext.setter
    def commandtext(self, value):
        """Alias for CommandText.setter"""
        self.CommandText = value

    @property
    def command_text(self):
        """Alias for CommandText"""
        return self.CommandText

    @command_text.setter
    def command_text(self, value):
        """Alias for CommandText.setter"""
        self.CommandText = value

    @property
    def CommandType(self):
        return XlCmdType(self.com_object.CommandType)

    @CommandType.setter
    def CommandType(self, value):
        self.com_object.CommandType = value

    @property
    def commandtype(self):
        """Alias for CommandType"""
        return self.CommandType

    @commandtype.setter
    def commandtype(self, value):
        """Alias for CommandType.setter"""
        self.CommandType = value

    @property
    def command_type(self):
        """Alias for CommandType"""
        return self.CommandType

    @command_type.setter
    def command_type(self, value):
        """Alias for CommandType.setter"""
        self.CommandType = value

    @property
    def Connection(self):
        return self.com_object.Connection

    @Connection.setter
    def Connection(self, value):
        self.com_object.Connection = value

    @property
    def connection(self):
        """Alias for Connection"""
        return self.Connection

    @connection.setter
    def connection(self, value):
        """Alias for Connection.setter"""
        self.Connection = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Destination(self):
        return Range(self.com_object.Destination)

    @property
    def destination(self):
        """Alias for Destination"""
        return self.Destination

    @property
    def EditWebPage(self):
        return self.com_object.EditWebPage

    @EditWebPage.setter
    def EditWebPage(self, value):
        self.com_object.EditWebPage = value

    @property
    def editwebpage(self):
        """Alias for EditWebPage"""
        return self.EditWebPage

    @editwebpage.setter
    def editwebpage(self, value):
        """Alias for EditWebPage.setter"""
        self.EditWebPage = value

    @property
    def edit_web_page(self):
        """Alias for EditWebPage"""
        return self.EditWebPage

    @edit_web_page.setter
    def edit_web_page(self, value):
        """Alias for EditWebPage.setter"""
        self.EditWebPage = value

    @property
    def EnableEditing(self):
        return self.com_object.EnableEditing

    @EnableEditing.setter
    def EnableEditing(self, value):
        self.com_object.EnableEditing = value

    @property
    def enableediting(self):
        """Alias for EnableEditing"""
        return self.EnableEditing

    @enableediting.setter
    def enableediting(self, value):
        """Alias for EnableEditing.setter"""
        self.EnableEditing = value

    @property
    def enable_editing(self):
        """Alias for EnableEditing"""
        return self.EnableEditing

    @enable_editing.setter
    def enable_editing(self, value):
        """Alias for EnableEditing.setter"""
        self.EnableEditing = value

    @property
    def EnableRefresh(self):
        return self.com_object.EnableRefresh

    @EnableRefresh.setter
    def EnableRefresh(self, value):
        self.com_object.EnableRefresh = value

    @property
    def enablerefresh(self):
        """Alias for EnableRefresh"""
        return self.EnableRefresh

    @enablerefresh.setter
    def enablerefresh(self, value):
        """Alias for EnableRefresh.setter"""
        self.EnableRefresh = value

    @property
    def enable_refresh(self):
        """Alias for EnableRefresh"""
        return self.EnableRefresh

    @enable_refresh.setter
    def enable_refresh(self, value):
        """Alias for EnableRefresh.setter"""
        self.EnableRefresh = value

    @property
    def FetchedRowOverflow(self):
        return self.com_object.FetchedRowOverflow

    @property
    def fetchedrowoverflow(self):
        """Alias for FetchedRowOverflow"""
        return self.FetchedRowOverflow

    @property
    def fetched_row_overflow(self):
        """Alias for FetchedRowOverflow"""
        return self.FetchedRowOverflow

    @property
    def FieldNames(self):
        return self.com_object.FieldNames

    @FieldNames.setter
    def FieldNames(self, value):
        self.com_object.FieldNames = value

    @property
    def fieldnames(self):
        """Alias for FieldNames"""
        return self.FieldNames

    @fieldnames.setter
    def fieldnames(self, value):
        """Alias for FieldNames.setter"""
        self.FieldNames = value

    @property
    def field_names(self):
        """Alias for FieldNames"""
        return self.FieldNames

    @field_names.setter
    def field_names(self, value):
        """Alias for FieldNames.setter"""
        self.FieldNames = value

    @property
    def FillAdjacentFormulas(self):
        return self.com_object.FillAdjacentFormulas

    @FillAdjacentFormulas.setter
    def FillAdjacentFormulas(self, value):
        self.com_object.FillAdjacentFormulas = value

    @property
    def filladjacentformulas(self):
        """Alias for FillAdjacentFormulas"""
        return self.FillAdjacentFormulas

    @filladjacentformulas.setter
    def filladjacentformulas(self, value):
        """Alias for FillAdjacentFormulas.setter"""
        self.FillAdjacentFormulas = value

    @property
    def fill_adjacent_formulas(self):
        """Alias for FillAdjacentFormulas"""
        return self.FillAdjacentFormulas

    @fill_adjacent_formulas.setter
    def fill_adjacent_formulas(self, value):
        """Alias for FillAdjacentFormulas.setter"""
        self.FillAdjacentFormulas = value

    @property
    def ListObject(self):
        return ListObject(self.com_object.ListObject)

    @property
    def listobject(self):
        """Alias for ListObject"""
        return self.ListObject

    @property
    def list_object(self):
        """Alias for ListObject"""
        return self.ListObject

    @property
    def MaintainConnection(self):
        return self.com_object.MaintainConnection

    @MaintainConnection.setter
    def MaintainConnection(self, value):
        self.com_object.MaintainConnection = value

    @property
    def maintainconnection(self):
        """Alias for MaintainConnection"""
        return self.MaintainConnection

    @maintainconnection.setter
    def maintainconnection(self, value):
        """Alias for MaintainConnection.setter"""
        self.MaintainConnection = value

    @property
    def maintain_connection(self):
        """Alias for MaintainConnection"""
        return self.MaintainConnection

    @maintain_connection.setter
    def maintain_connection(self, value):
        """Alias for MaintainConnection.setter"""
        self.MaintainConnection = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parameters(self):
        return Parameters(self.com_object.Parameters)

    @property
    def parameters(self):
        """Alias for Parameters"""
        return self.Parameters

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PostText(self):
        return self.com_object.PostText

    @PostText.setter
    def PostText(self, value):
        self.com_object.PostText = value

    @property
    def posttext(self):
        """Alias for PostText"""
        return self.PostText

    @posttext.setter
    def posttext(self, value):
        """Alias for PostText.setter"""
        self.PostText = value

    @property
    def post_text(self):
        """Alias for PostText"""
        return self.PostText

    @post_text.setter
    def post_text(self, value):
        """Alias for PostText.setter"""
        self.PostText = value

    @property
    def PreserveColumnInfo(self):
        return self.com_object.PreserveColumnInfo

    @PreserveColumnInfo.setter
    def PreserveColumnInfo(self, value):
        self.com_object.PreserveColumnInfo = value

    @property
    def preservecolumninfo(self):
        """Alias for PreserveColumnInfo"""
        return self.PreserveColumnInfo

    @preservecolumninfo.setter
    def preservecolumninfo(self, value):
        """Alias for PreserveColumnInfo.setter"""
        self.PreserveColumnInfo = value

    @property
    def preserve_column_info(self):
        """Alias for PreserveColumnInfo"""
        return self.PreserveColumnInfo

    @preserve_column_info.setter
    def preserve_column_info(self, value):
        """Alias for PreserveColumnInfo.setter"""
        self.PreserveColumnInfo = value

    @property
    def PreserveFormatting(self):
        return self.com_object.PreserveFormatting

    @property
    def preserveformatting(self):
        """Alias for PreserveFormatting"""
        return self.PreserveFormatting

    @property
    def preserve_formatting(self):
        """Alias for PreserveFormatting"""
        return self.PreserveFormatting

    @property
    def QueryType(self):
        return self.com_object.QueryType

    @property
    def querytype(self):
        """Alias for QueryType"""
        return self.QueryType

    @property
    def query_type(self):
        """Alias for QueryType"""
        return self.QueryType

    @property
    def Recordset(self):
        return self.com_object.Recordset

    @Recordset.setter
    def Recordset(self, value):
        self.com_object.Recordset = value

    @property
    def recordset(self):
        """Alias for Recordset"""
        return self.Recordset

    @recordset.setter
    def recordset(self, value):
        """Alias for Recordset.setter"""
        self.Recordset = value

    @property
    def Refreshing(self):
        return self.com_object.Refreshing

    @property
    def refreshing(self):
        """Alias for Refreshing"""
        return self.Refreshing

    @property
    def RefreshOnFileOpen(self):
        return self.com_object.RefreshOnFileOpen

    @RefreshOnFileOpen.setter
    def RefreshOnFileOpen(self, value):
        self.com_object.RefreshOnFileOpen = value

    @property
    def refreshonfileopen(self):
        """Alias for RefreshOnFileOpen"""
        return self.RefreshOnFileOpen

    @refreshonfileopen.setter
    def refreshonfileopen(self, value):
        """Alias for RefreshOnFileOpen.setter"""
        self.RefreshOnFileOpen = value

    @property
    def refresh_on_file_open(self):
        """Alias for RefreshOnFileOpen"""
        return self.RefreshOnFileOpen

    @refresh_on_file_open.setter
    def refresh_on_file_open(self, value):
        """Alias for RefreshOnFileOpen.setter"""
        self.RefreshOnFileOpen = value

    @property
    def RefreshPeriod(self):
        return self.com_object.RefreshPeriod

    @RefreshPeriod.setter
    def RefreshPeriod(self, value):
        self.com_object.RefreshPeriod = value

    @property
    def refreshperiod(self):
        """Alias for RefreshPeriod"""
        return self.RefreshPeriod

    @refreshperiod.setter
    def refreshperiod(self, value):
        """Alias for RefreshPeriod.setter"""
        self.RefreshPeriod = value

    @property
    def refresh_period(self):
        """Alias for RefreshPeriod"""
        return self.RefreshPeriod

    @refresh_period.setter
    def refresh_period(self, value):
        """Alias for RefreshPeriod.setter"""
        self.RefreshPeriod = value

    @property
    def RefreshStyle(self):
        return XlCellInsertionMode(self.com_object.RefreshStyle)

    @RefreshStyle.setter
    def RefreshStyle(self, value):
        self.com_object.RefreshStyle = value

    @property
    def refreshstyle(self):
        """Alias for RefreshStyle"""
        return self.RefreshStyle

    @refreshstyle.setter
    def refreshstyle(self, value):
        """Alias for RefreshStyle.setter"""
        self.RefreshStyle = value

    @property
    def refresh_style(self):
        """Alias for RefreshStyle"""
        return self.RefreshStyle

    @refresh_style.setter
    def refresh_style(self, value):
        """Alias for RefreshStyle.setter"""
        self.RefreshStyle = value

    @property
    def ResultRange(self):
        return Range(self.com_object.ResultRange)

    @property
    def resultrange(self):
        """Alias for ResultRange"""
        return self.ResultRange

    @property
    def result_range(self):
        """Alias for ResultRange"""
        return self.ResultRange

    @property
    def RobustConnect(self):
        return XlRobustConnect(self.com_object.RobustConnect)

    @RobustConnect.setter
    def RobustConnect(self, value):
        self.com_object.RobustConnect = value

    @property
    def robustconnect(self):
        """Alias for RobustConnect"""
        return self.RobustConnect

    @robustconnect.setter
    def robustconnect(self, value):
        """Alias for RobustConnect.setter"""
        self.RobustConnect = value

    @property
    def robust_connect(self):
        """Alias for RobustConnect"""
        return self.RobustConnect

    @robust_connect.setter
    def robust_connect(self, value):
        """Alias for RobustConnect.setter"""
        self.RobustConnect = value

    @property
    def RowNumbers(self):
        return self.com_object.RowNumbers

    @RowNumbers.setter
    def RowNumbers(self, value):
        self.com_object.RowNumbers = value

    @property
    def rownumbers(self):
        """Alias for RowNumbers"""
        return self.RowNumbers

    @rownumbers.setter
    def rownumbers(self, value):
        """Alias for RowNumbers.setter"""
        self.RowNumbers = value

    @property
    def row_numbers(self):
        """Alias for RowNumbers"""
        return self.RowNumbers

    @row_numbers.setter
    def row_numbers(self, value):
        """Alias for RowNumbers.setter"""
        self.RowNumbers = value

    @property
    def SaveData(self):
        return self.com_object.SaveData

    @SaveData.setter
    def SaveData(self, value):
        self.com_object.SaveData = value

    @property
    def savedata(self):
        """Alias for SaveData"""
        return self.SaveData

    @savedata.setter
    def savedata(self, value):
        """Alias for SaveData.setter"""
        self.SaveData = value

    @property
    def save_data(self):
        """Alias for SaveData"""
        return self.SaveData

    @save_data.setter
    def save_data(self, value):
        """Alias for SaveData.setter"""
        self.SaveData = value

    @property
    def SavePassword(self):
        return self.com_object.SavePassword

    @SavePassword.setter
    def SavePassword(self, value):
        self.com_object.SavePassword = value

    @property
    def savepassword(self):
        """Alias for SavePassword"""
        return self.SavePassword

    @savepassword.setter
    def savepassword(self, value):
        """Alias for SavePassword.setter"""
        self.SavePassword = value

    @property
    def save_password(self):
        """Alias for SavePassword"""
        return self.SavePassword

    @save_password.setter
    def save_password(self, value):
        """Alias for SavePassword.setter"""
        self.SavePassword = value

    @property
    def Sort(self):
        return self.com_object.Sort

    @property
    def sort(self):
        """Alias for Sort"""
        return self.Sort

    @property
    def SourceConnectionFile(self):
        return self.com_object.SourceConnectionFile

    @SourceConnectionFile.setter
    def SourceConnectionFile(self, value):
        self.com_object.SourceConnectionFile = value

    @property
    def sourceconnectionfile(self):
        """Alias for SourceConnectionFile"""
        return self.SourceConnectionFile

    @sourceconnectionfile.setter
    def sourceconnectionfile(self, value):
        """Alias for SourceConnectionFile.setter"""
        self.SourceConnectionFile = value

    @property
    def source_connection_file(self):
        """Alias for SourceConnectionFile"""
        return self.SourceConnectionFile

    @source_connection_file.setter
    def source_connection_file(self, value):
        """Alias for SourceConnectionFile.setter"""
        self.SourceConnectionFile = value

    @property
    def SourceDataFile(self):
        return self.com_object.SourceDataFile

    @SourceDataFile.setter
    def SourceDataFile(self, value):
        self.com_object.SourceDataFile = value

    @property
    def sourcedatafile(self):
        """Alias for SourceDataFile"""
        return self.SourceDataFile

    @sourcedatafile.setter
    def sourcedatafile(self, value):
        """Alias for SourceDataFile.setter"""
        self.SourceDataFile = value

    @property
    def source_data_file(self):
        """Alias for SourceDataFile"""
        return self.SourceDataFile

    @source_data_file.setter
    def source_data_file(self, value):
        """Alias for SourceDataFile.setter"""
        self.SourceDataFile = value

    @property
    def TextFileColumnDataTypes(self):
        return self.com_object.TextFileColumnDataTypes

    @TextFileColumnDataTypes.setter
    def TextFileColumnDataTypes(self, value):
        self.com_object.TextFileColumnDataTypes = value

    @property
    def textfilecolumndatatypes(self):
        """Alias for TextFileColumnDataTypes"""
        return self.TextFileColumnDataTypes

    @textfilecolumndatatypes.setter
    def textfilecolumndatatypes(self, value):
        """Alias for TextFileColumnDataTypes.setter"""
        self.TextFileColumnDataTypes = value

    @property
    def text_file_column_data_types(self):
        """Alias for TextFileColumnDataTypes"""
        return self.TextFileColumnDataTypes

    @text_file_column_data_types.setter
    def text_file_column_data_types(self, value):
        """Alias for TextFileColumnDataTypes.setter"""
        self.TextFileColumnDataTypes = value

    @property
    def TextFileCommaDelimiter(self):
        return self.com_object.TextFileCommaDelimiter

    @TextFileCommaDelimiter.setter
    def TextFileCommaDelimiter(self, value):
        self.com_object.TextFileCommaDelimiter = value

    @property
    def textfilecommadelimiter(self):
        """Alias for TextFileCommaDelimiter"""
        return self.TextFileCommaDelimiter

    @textfilecommadelimiter.setter
    def textfilecommadelimiter(self, value):
        """Alias for TextFileCommaDelimiter.setter"""
        self.TextFileCommaDelimiter = value

    @property
    def text_file_comma_delimiter(self):
        """Alias for TextFileCommaDelimiter"""
        return self.TextFileCommaDelimiter

    @text_file_comma_delimiter.setter
    def text_file_comma_delimiter(self, value):
        """Alias for TextFileCommaDelimiter.setter"""
        self.TextFileCommaDelimiter = value

    @property
    def TextFileConsecutiveDelimiter(self):
        return self.com_object.TextFileConsecutiveDelimiter

    @TextFileConsecutiveDelimiter.setter
    def TextFileConsecutiveDelimiter(self, value):
        self.com_object.TextFileConsecutiveDelimiter = value

    @property
    def textfileconsecutivedelimiter(self):
        """Alias for TextFileConsecutiveDelimiter"""
        return self.TextFileConsecutiveDelimiter

    @textfileconsecutivedelimiter.setter
    def textfileconsecutivedelimiter(self, value):
        """Alias for TextFileConsecutiveDelimiter.setter"""
        self.TextFileConsecutiveDelimiter = value

    @property
    def text_file_consecutive_delimiter(self):
        """Alias for TextFileConsecutiveDelimiter"""
        return self.TextFileConsecutiveDelimiter

    @text_file_consecutive_delimiter.setter
    def text_file_consecutive_delimiter(self, value):
        """Alias for TextFileConsecutiveDelimiter.setter"""
        self.TextFileConsecutiveDelimiter = value

    @property
    def TextFileDecimalSeparator(self):
        return self.com_object.TextFileDecimalSeparator

    @TextFileDecimalSeparator.setter
    def TextFileDecimalSeparator(self, value):
        self.com_object.TextFileDecimalSeparator = value

    @property
    def textfiledecimalseparator(self):
        """Alias for TextFileDecimalSeparator"""
        return self.TextFileDecimalSeparator

    @textfiledecimalseparator.setter
    def textfiledecimalseparator(self, value):
        """Alias for TextFileDecimalSeparator.setter"""
        self.TextFileDecimalSeparator = value

    @property
    def text_file_decimal_separator(self):
        """Alias for TextFileDecimalSeparator"""
        return self.TextFileDecimalSeparator

    @text_file_decimal_separator.setter
    def text_file_decimal_separator(self, value):
        """Alias for TextFileDecimalSeparator.setter"""
        self.TextFileDecimalSeparator = value

    @property
    def TextFileFixedColumnWidths(self):
        return self.com_object.TextFileFixedColumnWidths

    @TextFileFixedColumnWidths.setter
    def TextFileFixedColumnWidths(self, value):
        self.com_object.TextFileFixedColumnWidths = value

    @property
    def textfilefixedcolumnwidths(self):
        """Alias for TextFileFixedColumnWidths"""
        return self.TextFileFixedColumnWidths

    @textfilefixedcolumnwidths.setter
    def textfilefixedcolumnwidths(self, value):
        """Alias for TextFileFixedColumnWidths.setter"""
        self.TextFileFixedColumnWidths = value

    @property
    def text_file_fixed_column_widths(self):
        """Alias for TextFileFixedColumnWidths"""
        return self.TextFileFixedColumnWidths

    @text_file_fixed_column_widths.setter
    def text_file_fixed_column_widths(self, value):
        """Alias for TextFileFixedColumnWidths.setter"""
        self.TextFileFixedColumnWidths = value

    @property
    def TextFileOtherDelimiter(self):
        return self.com_object.TextFileOtherDelimiter

    @TextFileOtherDelimiter.setter
    def TextFileOtherDelimiter(self, value):
        self.com_object.TextFileOtherDelimiter = value

    @property
    def textfileotherdelimiter(self):
        """Alias for TextFileOtherDelimiter"""
        return self.TextFileOtherDelimiter

    @textfileotherdelimiter.setter
    def textfileotherdelimiter(self, value):
        """Alias for TextFileOtherDelimiter.setter"""
        self.TextFileOtherDelimiter = value

    @property
    def text_file_other_delimiter(self):
        """Alias for TextFileOtherDelimiter"""
        return self.TextFileOtherDelimiter

    @text_file_other_delimiter.setter
    def text_file_other_delimiter(self, value):
        """Alias for TextFileOtherDelimiter.setter"""
        self.TextFileOtherDelimiter = value

    @property
    def TextFileParseType(self):
        return XlTextParsingType(self.com_object.TextFileParseType)

    @TextFileParseType.setter
    def TextFileParseType(self, value):
        self.com_object.TextFileParseType = value

    @property
    def textfileparsetype(self):
        """Alias for TextFileParseType"""
        return self.TextFileParseType

    @textfileparsetype.setter
    def textfileparsetype(self, value):
        """Alias for TextFileParseType.setter"""
        self.TextFileParseType = value

    @property
    def text_file_parse_type(self):
        """Alias for TextFileParseType"""
        return self.TextFileParseType

    @text_file_parse_type.setter
    def text_file_parse_type(self, value):
        """Alias for TextFileParseType.setter"""
        self.TextFileParseType = value

    @property
    def TextFilePlatform(self):
        return XlPlatform(self.com_object.TextFilePlatform)

    @TextFilePlatform.setter
    def TextFilePlatform(self, value):
        self.com_object.TextFilePlatform = value

    @property
    def textfileplatform(self):
        """Alias for TextFilePlatform"""
        return self.TextFilePlatform

    @textfileplatform.setter
    def textfileplatform(self, value):
        """Alias for TextFilePlatform.setter"""
        self.TextFilePlatform = value

    @property
    def text_file_platform(self):
        """Alias for TextFilePlatform"""
        return self.TextFilePlatform

    @text_file_platform.setter
    def text_file_platform(self, value):
        """Alias for TextFilePlatform.setter"""
        self.TextFilePlatform = value

    @property
    def TextFilePromptOnRefresh(self):
        return self.com_object.TextFilePromptOnRefresh

    @TextFilePromptOnRefresh.setter
    def TextFilePromptOnRefresh(self, value):
        self.com_object.TextFilePromptOnRefresh = value

    @property
    def textfilepromptonrefresh(self):
        """Alias for TextFilePromptOnRefresh"""
        return self.TextFilePromptOnRefresh

    @textfilepromptonrefresh.setter
    def textfilepromptonrefresh(self, value):
        """Alias for TextFilePromptOnRefresh.setter"""
        self.TextFilePromptOnRefresh = value

    @property
    def text_file_prompt_on_refresh(self):
        """Alias for TextFilePromptOnRefresh"""
        return self.TextFilePromptOnRefresh

    @text_file_prompt_on_refresh.setter
    def text_file_prompt_on_refresh(self, value):
        """Alias for TextFilePromptOnRefresh.setter"""
        self.TextFilePromptOnRefresh = value

    @property
    def TextFileSemicolonDelimiter(self):
        return self.com_object.TextFileSemicolonDelimiter

    @TextFileSemicolonDelimiter.setter
    def TextFileSemicolonDelimiter(self, value):
        self.com_object.TextFileSemicolonDelimiter = value

    @property
    def textfilesemicolondelimiter(self):
        """Alias for TextFileSemicolonDelimiter"""
        return self.TextFileSemicolonDelimiter

    @textfilesemicolondelimiter.setter
    def textfilesemicolondelimiter(self, value):
        """Alias for TextFileSemicolonDelimiter.setter"""
        self.TextFileSemicolonDelimiter = value

    @property
    def text_file_semicolon_delimiter(self):
        """Alias for TextFileSemicolonDelimiter"""
        return self.TextFileSemicolonDelimiter

    @text_file_semicolon_delimiter.setter
    def text_file_semicolon_delimiter(self, value):
        """Alias for TextFileSemicolonDelimiter.setter"""
        self.TextFileSemicolonDelimiter = value

    @property
    def TextFileSpaceDelimiter(self):
        return self.com_object.TextFileSpaceDelimiter

    @TextFileSpaceDelimiter.setter
    def TextFileSpaceDelimiter(self, value):
        self.com_object.TextFileSpaceDelimiter = value

    @property
    def textfilespacedelimiter(self):
        """Alias for TextFileSpaceDelimiter"""
        return self.TextFileSpaceDelimiter

    @textfilespacedelimiter.setter
    def textfilespacedelimiter(self, value):
        """Alias for TextFileSpaceDelimiter.setter"""
        self.TextFileSpaceDelimiter = value

    @property
    def text_file_space_delimiter(self):
        """Alias for TextFileSpaceDelimiter"""
        return self.TextFileSpaceDelimiter

    @text_file_space_delimiter.setter
    def text_file_space_delimiter(self, value):
        """Alias for TextFileSpaceDelimiter.setter"""
        self.TextFileSpaceDelimiter = value

    @property
    def TextFileStartRow(self):
        return self.com_object.TextFileStartRow

    @TextFileStartRow.setter
    def TextFileStartRow(self, value):
        self.com_object.TextFileStartRow = value

    @property
    def textfilestartrow(self):
        """Alias for TextFileStartRow"""
        return self.TextFileStartRow

    @textfilestartrow.setter
    def textfilestartrow(self, value):
        """Alias for TextFileStartRow.setter"""
        self.TextFileStartRow = value

    @property
    def text_file_start_row(self):
        """Alias for TextFileStartRow"""
        return self.TextFileStartRow

    @text_file_start_row.setter
    def text_file_start_row(self, value):
        """Alias for TextFileStartRow.setter"""
        self.TextFileStartRow = value

    @property
    def TextFileTabDelimiter(self):
        return self.com_object.TextFileTabDelimiter

    @TextFileTabDelimiter.setter
    def TextFileTabDelimiter(self, value):
        self.com_object.TextFileTabDelimiter = value

    @property
    def textfiletabdelimiter(self):
        """Alias for TextFileTabDelimiter"""
        return self.TextFileTabDelimiter

    @textfiletabdelimiter.setter
    def textfiletabdelimiter(self, value):
        """Alias for TextFileTabDelimiter.setter"""
        self.TextFileTabDelimiter = value

    @property
    def text_file_tab_delimiter(self):
        """Alias for TextFileTabDelimiter"""
        return self.TextFileTabDelimiter

    @text_file_tab_delimiter.setter
    def text_file_tab_delimiter(self, value):
        """Alias for TextFileTabDelimiter.setter"""
        self.TextFileTabDelimiter = value

    @property
    def TextFileTextQualifier(self):
        return XlTextQualifier(self.com_object.TextFileTextQualifier)

    @TextFileTextQualifier.setter
    def TextFileTextQualifier(self, value):
        self.com_object.TextFileTextQualifier = value

    @property
    def textfiletextqualifier(self):
        """Alias for TextFileTextQualifier"""
        return self.TextFileTextQualifier

    @textfiletextqualifier.setter
    def textfiletextqualifier(self, value):
        """Alias for TextFileTextQualifier.setter"""
        self.TextFileTextQualifier = value

    @property
    def text_file_text_qualifier(self):
        """Alias for TextFileTextQualifier"""
        return self.TextFileTextQualifier

    @text_file_text_qualifier.setter
    def text_file_text_qualifier(self, value):
        """Alias for TextFileTextQualifier.setter"""
        self.TextFileTextQualifier = value

    @property
    def TextFileThousandsSeparator(self):
        return self.com_object.TextFileThousandsSeparator

    @TextFileThousandsSeparator.setter
    def TextFileThousandsSeparator(self, value):
        self.com_object.TextFileThousandsSeparator = value

    @property
    def textfilethousandsseparator(self):
        """Alias for TextFileThousandsSeparator"""
        return self.TextFileThousandsSeparator

    @textfilethousandsseparator.setter
    def textfilethousandsseparator(self, value):
        """Alias for TextFileThousandsSeparator.setter"""
        self.TextFileThousandsSeparator = value

    @property
    def text_file_thousands_separator(self):
        """Alias for TextFileThousandsSeparator"""
        return self.TextFileThousandsSeparator

    @text_file_thousands_separator.setter
    def text_file_thousands_separator(self, value):
        """Alias for TextFileThousandsSeparator.setter"""
        self.TextFileThousandsSeparator = value

    @property
    def TextFileTrailingMinusNumbers(self):
        return self.com_object.TextFileTrailingMinusNumbers

    @TextFileTrailingMinusNumbers.setter
    def TextFileTrailingMinusNumbers(self, value):
        self.com_object.TextFileTrailingMinusNumbers = value

    @property
    def textfiletrailingminusnumbers(self):
        """Alias for TextFileTrailingMinusNumbers"""
        return self.TextFileTrailingMinusNumbers

    @textfiletrailingminusnumbers.setter
    def textfiletrailingminusnumbers(self, value):
        """Alias for TextFileTrailingMinusNumbers.setter"""
        self.TextFileTrailingMinusNumbers = value

    @property
    def text_file_trailing_minus_numbers(self):
        """Alias for TextFileTrailingMinusNumbers"""
        return self.TextFileTrailingMinusNumbers

    @text_file_trailing_minus_numbers.setter
    def text_file_trailing_minus_numbers(self, value):
        """Alias for TextFileTrailingMinusNumbers.setter"""
        self.TextFileTrailingMinusNumbers = value

    @property
    def TextFileVisualLayout(self):
        return XlTextVisualLayoutType(self.com_object.TextFileVisualLayout)

    @TextFileVisualLayout.setter
    def TextFileVisualLayout(self, value):
        self.com_object.TextFileVisualLayout = value

    @property
    def textfilevisuallayout(self):
        """Alias for TextFileVisualLayout"""
        return self.TextFileVisualLayout

    @textfilevisuallayout.setter
    def textfilevisuallayout(self, value):
        """Alias for TextFileVisualLayout.setter"""
        self.TextFileVisualLayout = value

    @property
    def text_file_visual_layout(self):
        """Alias for TextFileVisualLayout"""
        return self.TextFileVisualLayout

    @text_file_visual_layout.setter
    def text_file_visual_layout(self, value):
        """Alias for TextFileVisualLayout.setter"""
        self.TextFileVisualLayout = value

    @property
    def WebConsecutiveDelimitersAsOne(self):
        return self.com_object.WebConsecutiveDelimitersAsOne

    @WebConsecutiveDelimitersAsOne.setter
    def WebConsecutiveDelimitersAsOne(self, value):
        self.com_object.WebConsecutiveDelimitersAsOne = value

    @property
    def webconsecutivedelimitersasone(self):
        """Alias for WebConsecutiveDelimitersAsOne"""
        return self.WebConsecutiveDelimitersAsOne

    @webconsecutivedelimitersasone.setter
    def webconsecutivedelimitersasone(self, value):
        """Alias for WebConsecutiveDelimitersAsOne.setter"""
        self.WebConsecutiveDelimitersAsOne = value

    @property
    def web_consecutive_delimiters_as_one(self):
        """Alias for WebConsecutiveDelimitersAsOne"""
        return self.WebConsecutiveDelimitersAsOne

    @web_consecutive_delimiters_as_one.setter
    def web_consecutive_delimiters_as_one(self, value):
        """Alias for WebConsecutiveDelimitersAsOne.setter"""
        self.WebConsecutiveDelimitersAsOne = value

    @property
    def WebDisableDateRecognition(self):
        return self.com_object.WebDisableDateRecognition

    @WebDisableDateRecognition.setter
    def WebDisableDateRecognition(self, value):
        self.com_object.WebDisableDateRecognition = value

    @property
    def webdisabledaterecognition(self):
        """Alias for WebDisableDateRecognition"""
        return self.WebDisableDateRecognition

    @webdisabledaterecognition.setter
    def webdisabledaterecognition(self, value):
        """Alias for WebDisableDateRecognition.setter"""
        self.WebDisableDateRecognition = value

    @property
    def web_disable_date_recognition(self):
        """Alias for WebDisableDateRecognition"""
        return self.WebDisableDateRecognition

    @web_disable_date_recognition.setter
    def web_disable_date_recognition(self, value):
        """Alias for WebDisableDateRecognition.setter"""
        self.WebDisableDateRecognition = value

    @property
    def WebDisableRedirections(self):
        return self.com_object.WebDisableRedirections

    @WebDisableRedirections.setter
    def WebDisableRedirections(self, value):
        self.com_object.WebDisableRedirections = value

    @property
    def webdisableredirections(self):
        """Alias for WebDisableRedirections"""
        return self.WebDisableRedirections

    @webdisableredirections.setter
    def webdisableredirections(self, value):
        """Alias for WebDisableRedirections.setter"""
        self.WebDisableRedirections = value

    @property
    def web_disable_redirections(self):
        """Alias for WebDisableRedirections"""
        return self.WebDisableRedirections

    @web_disable_redirections.setter
    def web_disable_redirections(self, value):
        """Alias for WebDisableRedirections.setter"""
        self.WebDisableRedirections = value

    @property
    def WebFormatting(self):
        return XlWebFormatting(self.com_object.WebFormatting)

    @WebFormatting.setter
    def WebFormatting(self, value):
        self.com_object.WebFormatting = value

    @property
    def webformatting(self):
        """Alias for WebFormatting"""
        return self.WebFormatting

    @webformatting.setter
    def webformatting(self, value):
        """Alias for WebFormatting.setter"""
        self.WebFormatting = value

    @property
    def web_formatting(self):
        """Alias for WebFormatting"""
        return self.WebFormatting

    @web_formatting.setter
    def web_formatting(self, value):
        """Alias for WebFormatting.setter"""
        self.WebFormatting = value

    @property
    def WebPreFormattedTextToColumns(self):
        return self.com_object.WebPreFormattedTextToColumns

    @WebPreFormattedTextToColumns.setter
    def WebPreFormattedTextToColumns(self, value):
        self.com_object.WebPreFormattedTextToColumns = value

    @property
    def webpreformattedtexttocolumns(self):
        """Alias for WebPreFormattedTextToColumns"""
        return self.WebPreFormattedTextToColumns

    @webpreformattedtexttocolumns.setter
    def webpreformattedtexttocolumns(self, value):
        """Alias for WebPreFormattedTextToColumns.setter"""
        self.WebPreFormattedTextToColumns = value

    @property
    def web_pre_formatted_text_to_columns(self):
        """Alias for WebPreFormattedTextToColumns"""
        return self.WebPreFormattedTextToColumns

    @web_pre_formatted_text_to_columns.setter
    def web_pre_formatted_text_to_columns(self, value):
        """Alias for WebPreFormattedTextToColumns.setter"""
        self.WebPreFormattedTextToColumns = value

    @property
    def WebSelectionType(self):
        return XlWebSelectionType(self.com_object.WebSelectionType)

    @WebSelectionType.setter
    def WebSelectionType(self, value):
        self.com_object.WebSelectionType = value

    @property
    def webselectiontype(self):
        """Alias for WebSelectionType"""
        return self.WebSelectionType

    @webselectiontype.setter
    def webselectiontype(self, value):
        """Alias for WebSelectionType.setter"""
        self.WebSelectionType = value

    @property
    def web_selection_type(self):
        """Alias for WebSelectionType"""
        return self.WebSelectionType

    @web_selection_type.setter
    def web_selection_type(self, value):
        """Alias for WebSelectionType.setter"""
        self.WebSelectionType = value

    @property
    def WebSingleBlockTextImport(self):
        return self.com_object.WebSingleBlockTextImport

    @WebSingleBlockTextImport.setter
    def WebSingleBlockTextImport(self, value):
        self.com_object.WebSingleBlockTextImport = value

    @property
    def websingleblocktextimport(self):
        """Alias for WebSingleBlockTextImport"""
        return self.WebSingleBlockTextImport

    @websingleblocktextimport.setter
    def websingleblocktextimport(self, value):
        """Alias for WebSingleBlockTextImport.setter"""
        self.WebSingleBlockTextImport = value

    @property
    def web_single_block_text_import(self):
        """Alias for WebSingleBlockTextImport"""
        return self.WebSingleBlockTextImport

    @web_single_block_text_import.setter
    def web_single_block_text_import(self, value):
        """Alias for WebSingleBlockTextImport.setter"""
        self.WebSingleBlockTextImport = value

    @property
    def WebTables(self):
        return self.com_object.WebTables

    @WebTables.setter
    def WebTables(self, value):
        self.com_object.WebTables = value

    @property
    def webtables(self):
        """Alias for WebTables"""
        return self.WebTables

    @webtables.setter
    def webtables(self, value):
        """Alias for WebTables.setter"""
        self.WebTables = value

    @property
    def web_tables(self):
        """Alias for WebTables"""
        return self.WebTables

    @web_tables.setter
    def web_tables(self, value):
        """Alias for WebTables.setter"""
        self.WebTables = value

    @property
    def WorkbookConnection(self):
        return WorkbookConnection(self.com_object.WorkbookConnection)

    @property
    def workbookconnection(self):
        """Alias for WorkbookConnection"""
        return self.WorkbookConnection

    @property
    def workbook_connection(self):
        """Alias for WorkbookConnection"""
        return self.WorkbookConnection

    def CancelRefresh(self):
        self.com_object.CancelRefresh()

    def cancelrefresh(self):
        """Alias for CancelRefresh"""
        return self.CancelRefresh()

    def cancel_refresh(self):
        """Alias for CancelRefresh"""
        return self.CancelRefresh()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Refresh(self, BackgroundQuery=None):
        arguments = com_arguments([unwrap(a) for a in [BackgroundQuery]])
        return self.com_object.Refresh(*arguments)

    def refresh(self, BackgroundQuery=None):
        """Alias for Refresh"""
        arguments = [BackgroundQuery]
        return self.Refresh(*arguments)

    def ResetTimer(self):
        self.com_object.ResetTimer()

    def resettimer(self):
        """Alias for ResetTimer"""
        return self.ResetTimer()

    def reset_timer(self):
        """Alias for ResetTimer"""
        return self.ResetTimer()

    def SaveAsODC(self, ODCFileName=None, Description=None, Keywords=None):
        arguments = com_arguments([unwrap(a) for a in [ODCFileName, Description, Keywords]])
        self.com_object.SaveAsODC(*arguments)

    def saveasodc(self, ODCFileName=None, Description=None, Keywords=None):
        """Alias for SaveAsODC"""
        arguments = [ODCFileName, Description, Keywords]
        return self.SaveAsODC(*arguments)

    def save_as_o_d_c(self, ODCFileName=None, Description=None, Keywords=None):
        """Alias for SaveAsODC"""
        arguments = [ODCFileName, Description, Keywords]
        return self.SaveAsODC(*arguments)


class QueryTables:

    def __init__(self, querytables=None):
        self.com_object= querytables

    def __call__(self, item):
        return QueryTable(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Connection=None, Destination=None, Sql=None):
        arguments = com_arguments([unwrap(a) for a in [Connection, Destination, Sql]])
        return QueryTable(self.com_object.Add(*arguments))

    def add(self, Connection=None, Destination=None, Sql=None):
        """Alias for Add"""
        arguments = [Connection, Destination, Sql]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return QueryTable(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class QuickAnalysis:

    def __init__(self, quickanalysis=None):
        self.com_object= quickanalysis

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Hide(self, XlQuickAnalysisMode=None):
        arguments = com_arguments([unwrap(a) for a in [XlQuickAnalysisMode]])
        return self.com_object.Hide(*arguments)

    def hide(self, XlQuickAnalysisMode=None):
        """Alias for Hide"""
        arguments = [XlQuickAnalysisMode]
        return self.Hide(*arguments)

    def Show(self, XlQuickAnalysisMode=None):
        arguments = com_arguments([unwrap(a) for a in [XlQuickAnalysisMode]])
        return self.com_object.Show(*arguments)

    def show(self, XlQuickAnalysisMode=None):
        """Alias for Show"""
        arguments = [XlQuickAnalysisMode]
        return self.Show(*arguments)


class Range:

    def __init__(self, range=None):
        self.com_object= range

    @property
    def AddIndent(self):
        return self.com_object.AddIndent

    @AddIndent.setter
    def AddIndent(self, value):
        self.com_object.AddIndent = value

    @property
    def addindent(self):
        """Alias for AddIndent"""
        return self.AddIndent

    @addindent.setter
    def addindent(self, value):
        """Alias for AddIndent.setter"""
        self.AddIndent = value

    @property
    def add_indent(self):
        """Alias for AddIndent"""
        return self.AddIndent

    @add_indent.setter
    def add_indent(self, value):
        """Alias for AddIndent.setter"""
        self.AddIndent = value

    def Address(self, RowAbsolute=None, ColumnAbsolute=None, ReferenceStyle=None, External=None, RelativeTo=None):
        arguments = com_arguments([unwrap(a) for a in [RowAbsolute, ColumnAbsolute, ReferenceStyle, External, RelativeTo]])
        if hasattr(self.com_object, "GetAddress"):
            return self.com_object.GetAddress(*arguments)
        else:
            return self.com_object.Address(*arguments)

    def address(self, RowAbsolute=None, ColumnAbsolute=None, ReferenceStyle=None, External=None, RelativeTo=None):
        """Alias for Address"""
        arguments = [RowAbsolute, ColumnAbsolute, ReferenceStyle, External, RelativeTo]
        return self.Address(*arguments)

    def AddressLocal(self, RowAbsolute=None, ColumnAbsolute=None, ReferenceStyle=None, External=None, RelativeTo=None):
        arguments = com_arguments([unwrap(a) for a in [RowAbsolute, ColumnAbsolute, ReferenceStyle, External, RelativeTo]])
        if hasattr(self.com_object, "GetAddressLocal"):
            return self.com_object.GetAddressLocal(*arguments)
        else:
            return self.com_object.AddressLocal(*arguments)

    def addresslocal(self, RowAbsolute=None, ColumnAbsolute=None, ReferenceStyle=None, External=None, RelativeTo=None):
        """Alias for AddressLocal"""
        arguments = [RowAbsolute, ColumnAbsolute, ReferenceStyle, External, RelativeTo]
        return self.AddressLocal(*arguments)

    def address_local(self, RowAbsolute=None, ColumnAbsolute=None, ReferenceStyle=None, External=None, RelativeTo=None):
        """Alias for AddressLocal"""
        arguments = [RowAbsolute, ColumnAbsolute, ReferenceStyle, External, RelativeTo]
        return self.AddressLocal(*arguments)

    @property
    def AllowEdit(self):
        return self.com_object.AllowEdit

    @property
    def allowedit(self):
        """Alias for AllowEdit"""
        return self.AllowEdit

    @property
    def allow_edit(self):
        """Alias for AllowEdit"""
        return self.AllowEdit

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Areas(self):
        return Areas(self.com_object.Areas)

    @property
    def areas(self):
        """Alias for Areas"""
        return self.Areas

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    def Cells(self, RowIndex=None, ColumnIndex=None):
        arguments = com_arguments([unwrap(a) for a in [RowIndex, ColumnIndex]])
        if hasattr(self.com_object, "GetCells"):
            return Range(self.com_object.GetCells(*arguments))
        else:
            return Range(self.com_object.Cells(*arguments))

    def cells(self, RowIndex=None, ColumnIndex=None):
        """Alias for Cells"""
        arguments = [RowIndex, ColumnIndex]
        return self.Cells(*arguments)

    def Characters(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        if hasattr(self.com_object, "GetCharacters"):
            return Characters(self.com_object.GetCharacters(*arguments))
        else:
            return Characters(self.com_object.Characters(*arguments))

    def characters(self, Start=None, Length=None):
        """Alias for Characters"""
        arguments = [Start, Length]
        return self.Characters(*arguments)

    @property
    def Column(self):
        return self.com_object.Column

    @property
    def column(self):
        """Alias for Column"""
        return self.Column

    @property
    def Columns(self):
        return Range(self.com_object.Columns)

    @property
    def columns(self):
        """Alias for Columns"""
        return self.Columns

    @property
    def ColumnWidth(self):
        return self.com_object.ColumnWidth

    @ColumnWidth.setter
    def ColumnWidth(self, value):
        self.com_object.ColumnWidth = value

    @property
    def columnwidth(self):
        """Alias for ColumnWidth"""
        return self.ColumnWidth

    @columnwidth.setter
    def columnwidth(self, value):
        """Alias for ColumnWidth.setter"""
        self.ColumnWidth = value

    @property
    def column_width(self):
        """Alias for ColumnWidth"""
        return self.ColumnWidth

    @column_width.setter
    def column_width(self, value):
        """Alias for ColumnWidth.setter"""
        self.ColumnWidth = value

    @property
    def Comment(self):
        return Comment(self.com_object.Comment)

    @property
    def comment(self):
        """Alias for Comment"""
        return self.Comment

    @property
    def CommentThreaded(self):
        return CommentThreaded(self.com_object.CommentThreaded)

    @property
    def commentthreaded(self):
        """Alias for CommentThreaded"""
        return self.CommentThreaded

    @property
    def comment_threaded(self):
        """Alias for CommentThreaded"""
        return self.CommentThreaded

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def CountLarge(self):
        return self.com_object.CountLarge

    @property
    def countlarge(self):
        """Alias for CountLarge"""
        return self.CountLarge

    @property
    def count_large(self):
        """Alias for CountLarge"""
        return self.CountLarge

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def CurrentArray(self):
        return self.com_object.CurrentArray

    @property
    def currentarray(self):
        """Alias for CurrentArray"""
        return self.CurrentArray

    @property
    def current_array(self):
        """Alias for CurrentArray"""
        return self.CurrentArray

    @property
    def CurrentRegion(self):
        return Range(self.com_object.CurrentRegion)

    @property
    def currentregion(self):
        """Alias for CurrentRegion"""
        return self.CurrentRegion

    @property
    def current_region(self):
        """Alias for CurrentRegion"""
        return self.CurrentRegion

    @property
    def Dependents(self):
        return Range(self.com_object.Dependents)

    @property
    def dependents(self):
        """Alias for Dependents"""
        return self.Dependents

    @property
    def DirectDependents(self):
        return Range(self.com_object.DirectDependents)

    @property
    def directdependents(self):
        """Alias for DirectDependents"""
        return self.DirectDependents

    @property
    def direct_dependents(self):
        """Alias for DirectDependents"""
        return self.DirectDependents

    @property
    def DirectPrecedents(self):
        return Range(self.com_object.DirectPrecedents)

    @property
    def directprecedents(self):
        """Alias for DirectPrecedents"""
        return self.DirectPrecedents

    @property
    def direct_precedents(self):
        """Alias for DirectPrecedents"""
        return self.DirectPrecedents

    @property
    def DisplayFormat(self):
        return DisplayFormat(self.com_object.DisplayFormat)

    @property
    def displayformat(self):
        """Alias for DisplayFormat"""
        return self.DisplayFormat

    @property
    def display_format(self):
        """Alias for DisplayFormat"""
        return self.DisplayFormat

    def End(self, Direction=None):
        arguments = com_arguments([unwrap(a) for a in [Direction]])
        if hasattr(self.com_object, "GetEnd"):
            return Range(self.com_object.GetEnd(*arguments))
        else:
            return Range(self.com_object.End(*arguments))

    def end(self, Direction=None):
        """Alias for End"""
        arguments = [Direction]
        return self.End(*arguments)

    @property
    def EntireColumn(self):
        return Range(self.com_object.EntireColumn)

    @property
    def entirecolumn(self):
        """Alias for EntireColumn"""
        return self.EntireColumn

    @property
    def entire_column(self):
        """Alias for EntireColumn"""
        return self.EntireColumn

    @property
    def EntireRow(self):
        return Range(self.com_object.EntireRow)

    @property
    def entirerow(self):
        """Alias for EntireRow"""
        return self.EntireRow

    @property
    def entire_row(self):
        """Alias for EntireRow"""
        return self.EntireRow

    @property
    def Errors(self):
        return self.com_object.Errors

    @property
    def errors(self):
        """Alias for Errors"""
        return self.Errors

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def FormatConditions(self):
        return FormatConditions(self.com_object.FormatConditions)

    @property
    def formatconditions(self):
        """Alias for FormatConditions"""
        return self.FormatConditions

    @property
    def format_conditions(self):
        """Alias for FormatConditions"""
        return self.FormatConditions

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def Formula2(self):
        return self.com_object.Formula2

    @Formula2.setter
    def Formula2(self, value):
        self.com_object.Formula2 = value

    @property
    def formula2(self):
        """Alias for Formula2"""
        return self.Formula2

    @formula2.setter
    def formula2(self, value):
        """Alias for Formula2.setter"""
        self.Formula2 = value

    @property
    def Formula2Local(self):
        return self.com_object.Formula2Local

    @property
    def formula2local(self):
        """Alias for Formula2Local"""
        return self.Formula2Local

    @property
    def formula2_local(self):
        """Alias for Formula2Local"""
        return self.Formula2Local

    @property
    def Formula2R1C1(self):
        return self.com_object.Formula2R1C1

    @property
    def formula2r1c1(self):
        """Alias for Formula2R1C1"""
        return self.Formula2R1C1

    @property
    def formula2_r1_c1(self):
        """Alias for Formula2R1C1"""
        return self.Formula2R1C1

    @property
    def Formula2R1C1Local(self):
        return self.com_object.Formula2R1C1Local

    @property
    def formula2r1c1local(self):
        """Alias for Formula2R1C1Local"""
        return self.Formula2R1C1Local

    @property
    def formula2_r1_c1_local(self):
        """Alias for Formula2R1C1Local"""
        return self.Formula2R1C1Local

    @property
    def FormulaArray(self):
        return self.com_object.FormulaArray

    @FormulaArray.setter
    def FormulaArray(self, value):
        self.com_object.FormulaArray = value

    @property
    def formulaarray(self):
        """Alias for FormulaArray"""
        return self.FormulaArray

    @formulaarray.setter
    def formulaarray(self, value):
        """Alias for FormulaArray.setter"""
        self.FormulaArray = value

    @property
    def formula_array(self):
        """Alias for FormulaArray"""
        return self.FormulaArray

    @formula_array.setter
    def formula_array(self, value):
        """Alias for FormulaArray.setter"""
        self.FormulaArray = value

    @property
    def FormulaHidden(self):
        return self.com_object.FormulaHidden

    @FormulaHidden.setter
    def FormulaHidden(self, value):
        self.com_object.FormulaHidden = value

    @property
    def formulahidden(self):
        """Alias for FormulaHidden"""
        return self.FormulaHidden

    @formulahidden.setter
    def formulahidden(self, value):
        """Alias for FormulaHidden.setter"""
        self.FormulaHidden = value

    @property
    def formula_hidden(self):
        """Alias for FormulaHidden"""
        return self.FormulaHidden

    @formula_hidden.setter
    def formula_hidden(self, value):
        """Alias for FormulaHidden.setter"""
        self.FormulaHidden = value

    @property
    def FormulaLocal(self):
        return self.com_object.FormulaLocal

    @FormulaLocal.setter
    def FormulaLocal(self, value):
        self.com_object.FormulaLocal = value

    @property
    def formulalocal(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formulalocal.setter
    def formulalocal(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def formula_local(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formula_local.setter
    def formula_local(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def FormulaR1C1(self):
        return self.com_object.FormulaR1C1

    @FormulaR1C1.setter
    def FormulaR1C1(self, value):
        self.com_object.FormulaR1C1 = value

    @property
    def formular1c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formular1c1.setter
    def formular1c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def formula_r1_c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formula_r1_c1.setter
    def formula_r1_c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def FormulaR1C1Local(self):
        return self.com_object.FormulaR1C1Local

    @FormulaR1C1Local.setter
    def FormulaR1C1Local(self, value):
        self.com_object.FormulaR1C1Local = value

    @property
    def formular1c1local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formular1c1local.setter
    def formular1c1local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def formula_r1_c1_local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formula_r1_c1_local.setter
    def formula_r1_c1_local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def HasArray(self):
        return self.com_object.HasArray

    @property
    def hasarray(self):
        """Alias for HasArray"""
        return self.HasArray

    @property
    def has_array(self):
        """Alias for HasArray"""
        return self.HasArray

    @property
    def HasFormula(self):
        return self.com_object.HasFormula

    @property
    def hasformula(self):
        """Alias for HasFormula"""
        return self.HasFormula

    @property
    def has_formula(self):
        """Alias for HasFormula"""
        return self.HasFormula

    @property
    def HasRichDataType(self):
        return self.com_object.HasRichDataType

    @property
    def hasrichdatatype(self):
        """Alias for HasRichDataType"""
        return self.HasRichDataType

    @property
    def has_rich_data_type(self):
        """Alias for HasRichDataType"""
        return self.HasRichDataType

    @property
    def HasSpill(self):
        return self.com_object.HasSpill

    @property
    def hasspill(self):
        """Alias for HasSpill"""
        return self.HasSpill

    @property
    def has_spill(self):
        """Alias for HasSpill"""
        return self.HasSpill

    @property
    def Height(self):
        return self.com_object.Height

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @property
    def Hidden(self):
        return self.com_object.Hidden

    @Hidden.setter
    def Hidden(self, value):
        self.com_object.Hidden = value

    @property
    def hidden(self):
        """Alias for Hidden"""
        return self.Hidden

    @hidden.setter
    def hidden(self, value):
        """Alias for Hidden.setter"""
        self.Hidden = value

    @property
    def HorizontalAlignment(self):
        return self.com_object.HorizontalAlignment

    @HorizontalAlignment.setter
    def HorizontalAlignment(self, value):
        self.com_object.HorizontalAlignment = value

    @property
    def horizontalalignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontalalignment.setter
    def horizontalalignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def horizontal_alignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def Hyperlinks(self):
        return Hyperlinks(self.com_object.Hyperlinks)

    @property
    def hyperlinks(self):
        """Alias for Hyperlinks"""
        return self.Hyperlinks

    @property
    def ID(self):
        return self.com_object.ID

    @ID.setter
    def ID(self, value):
        self.com_object.ID = value

    @property
    def id(self):
        """Alias for ID"""
        return self.ID

    @id.setter
    def id(self, value):
        """Alias for ID.setter"""
        self.ID = value

    @property
    def i_d(self):
        """Alias for ID"""
        return self.ID

    @i_d.setter
    def i_d(self, value):
        """Alias for ID.setter"""
        self.ID = value

    @property
    def IndentLevel(self):
        return self.com_object.IndentLevel

    @IndentLevel.setter
    def IndentLevel(self, value):
        self.com_object.IndentLevel = value

    @property
    def indentlevel(self):
        """Alias for IndentLevel"""
        return self.IndentLevel

    @indentlevel.setter
    def indentlevel(self, value):
        """Alias for IndentLevel.setter"""
        self.IndentLevel = value

    @property
    def indent_level(self):
        """Alias for IndentLevel"""
        return self.IndentLevel

    @indent_level.setter
    def indent_level(self, value):
        """Alias for IndentLevel.setter"""
        self.IndentLevel = value

    @property
    def Interior(self):
        return Interior(self.com_object.Interior)

    @property
    def interior(self):
        """Alias for Interior"""
        return self.Interior

    def Item(self, RowIndex=None, ColumnIndex=None):
        arguments = com_arguments([unwrap(a) for a in [RowIndex, ColumnIndex]])
        if hasattr(self.com_object, "GetItem"):
            return Range(self.com_object.GetItem(*arguments))
        else:
            return Range(self.com_object.Item(*arguments))

    def item(self, RowIndex=None, ColumnIndex=None):
        """Alias for Item"""
        arguments = [RowIndex, ColumnIndex]
        return self.Item(*arguments)

    @property
    def Left(self):
        return self.com_object.Left

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @property
    def LinkedDataTypeState(self):
        return XlLinkedDataTypeState(self.com_object.LinkedDataTypeState)

    @property
    def linkeddatatypestate(self):
        """Alias for LinkedDataTypeState"""
        return self.LinkedDataTypeState

    @property
    def linked_data_type_state(self):
        """Alias for LinkedDataTypeState"""
        return self.LinkedDataTypeState

    @property
    def ListHeaderRows(self):
        return self.com_object.ListHeaderRows

    @property
    def listheaderrows(self):
        """Alias for ListHeaderRows"""
        return self.ListHeaderRows

    @property
    def list_header_rows(self):
        """Alias for ListHeaderRows"""
        return self.ListHeaderRows

    @property
    def ListObject(self):
        return ListObject(self.com_object.ListObject)

    @property
    def listobject(self):
        """Alias for ListObject"""
        return self.ListObject

    @property
    def list_object(self):
        """Alias for ListObject"""
        return self.ListObject

    @property
    def LocationInTable(self):
        return PivotTable(self.com_object.LocationInTable)

    @property
    def locationintable(self):
        """Alias for LocationInTable"""
        return self.LocationInTable

    @property
    def location_in_table(self):
        """Alias for LocationInTable"""
        return self.LocationInTable

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def MDX(self):
        return Range(self.com_object.MDX)

    @property
    def mdx(self):
        """Alias for MDX"""
        return self.MDX

    @property
    def m_d_x(self):
        """Alias for MDX"""
        return self.MDX

    @property
    def MergeArea(self):
        return Range(self.com_object.MergeArea)

    @property
    def mergearea(self):
        """Alias for MergeArea"""
        return self.MergeArea

    @property
    def merge_area(self):
        """Alias for MergeArea"""
        return self.MergeArea

    @property
    def MergeCells(self):
        return self.com_object.MergeCells

    @MergeCells.setter
    def MergeCells(self, value):
        self.com_object.MergeCells = value

    @property
    def mergecells(self):
        """Alias for MergeCells"""
        return self.MergeCells

    @mergecells.setter
    def mergecells(self, value):
        """Alias for MergeCells.setter"""
        self.MergeCells = value

    @property
    def merge_cells(self):
        """Alias for MergeCells"""
        return self.MergeCells

    @merge_cells.setter
    def merge_cells(self, value):
        """Alias for MergeCells.setter"""
        self.MergeCells = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Next(self):
        return Range(self.com_object.Next)

    @property
    def next(self):
        """Alias for Next"""
        return self.Next

    @property
    def NumberFormat(self):
        return self.com_object.NumberFormat

    @NumberFormat.setter
    def NumberFormat(self, value):
        self.com_object.NumberFormat = value

    @property
    def numberformat(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @numberformat.setter
    def numberformat(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def number_format(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @number_format.setter
    def number_format(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def NumberFormatLocal(self):
        return self.com_object.NumberFormatLocal

    @NumberFormatLocal.setter
    def NumberFormatLocal(self, value):
        self.com_object.NumberFormatLocal = value

    @property
    def numberformatlocal(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @numberformatlocal.setter
    def numberformatlocal(self, value):
        """Alias for NumberFormatLocal.setter"""
        self.NumberFormatLocal = value

    @property
    def number_format_local(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @number_format_local.setter
    def number_format_local(self, value):
        """Alias for NumberFormatLocal.setter"""
        self.NumberFormatLocal = value

    def Offset(self, RowOffset=None, ColumnOffset=None):
        arguments = com_arguments([unwrap(a) for a in [RowOffset, ColumnOffset]])
        if hasattr(self.com_object, "GetOffset"):
            return Range(self.com_object.GetOffset(*arguments))
        else:
            return Range(self.com_object.Offset(*arguments))

    def offset(self, RowOffset=None, ColumnOffset=None):
        """Alias for Offset"""
        arguments = [RowOffset, ColumnOffset]
        return self.Offset(*arguments)

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def OutlineLevel(self):
        return self.com_object.OutlineLevel

    @OutlineLevel.setter
    def OutlineLevel(self, value):
        self.com_object.OutlineLevel = value

    @property
    def outlinelevel(self):
        """Alias for OutlineLevel"""
        return self.OutlineLevel

    @outlinelevel.setter
    def outlinelevel(self, value):
        """Alias for OutlineLevel.setter"""
        self.OutlineLevel = value

    @property
    def outline_level(self):
        """Alias for OutlineLevel"""
        return self.OutlineLevel

    @outline_level.setter
    def outline_level(self, value):
        """Alias for OutlineLevel.setter"""
        self.OutlineLevel = value

    @property
    def PageBreak(self):
        return XlPageBreak(self.com_object.PageBreak)

    @PageBreak.setter
    def PageBreak(self, value):
        self.com_object.PageBreak = value

    @property
    def pagebreak(self):
        """Alias for PageBreak"""
        return self.PageBreak

    @pagebreak.setter
    def pagebreak(self, value):
        """Alias for PageBreak.setter"""
        self.PageBreak = value

    @property
    def page_break(self):
        """Alias for PageBreak"""
        return self.PageBreak

    @page_break.setter
    def page_break(self, value):
        """Alias for PageBreak.setter"""
        self.PageBreak = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Phonetic(self):
        return Phonetic(self.com_object.Phonetic)

    @property
    def phonetic(self):
        """Alias for Phonetic"""
        return self.Phonetic

    @property
    def Phonetics(self):
        return Phonetics(self.com_object.Phonetics)

    @property
    def phonetics(self):
        """Alias for Phonetics"""
        return self.Phonetics

    @property
    def PivotCell(self):
        return PivotCell(self.com_object.PivotCell)

    @property
    def pivotcell(self):
        """Alias for PivotCell"""
        return self.PivotCell

    @property
    def pivot_cell(self):
        """Alias for PivotCell"""
        return self.PivotCell

    @property
    def PivotField(self):
        return PivotField(self.com_object.PivotField)

    @property
    def pivotfield(self):
        """Alias for PivotField"""
        return self.PivotField

    @property
    def pivot_field(self):
        """Alias for PivotField"""
        return self.PivotField

    @property
    def PivotItem(self):
        return PivotItem(self.com_object.PivotItem)

    @property
    def pivotitem(self):
        """Alias for PivotItem"""
        return self.PivotItem

    @property
    def pivot_item(self):
        """Alias for PivotItem"""
        return self.PivotItem

    @property
    def PivotTable(self):
        return PivotTable(self.com_object.PivotTable)

    @property
    def pivottable(self):
        """Alias for PivotTable"""
        return self.PivotTable

    @property
    def pivot_table(self):
        """Alias for PivotTable"""
        return self.PivotTable

    @property
    def Precedents(self):
        return Range(self.com_object.Precedents)

    @property
    def precedents(self):
        """Alias for Precedents"""
        return self.Precedents

    @property
    def PrefixCharacter(self):
        return self.com_object.PrefixCharacter

    @property
    def prefixcharacter(self):
        """Alias for PrefixCharacter"""
        return self.PrefixCharacter

    @property
    def prefix_character(self):
        """Alias for PrefixCharacter"""
        return self.PrefixCharacter

    @property
    def Previous(self):
        return Range(self.com_object.Previous)

    @property
    def previous(self):
        """Alias for Previous"""
        return self.Previous

    @property
    def QueryTable(self):
        return QueryTable(self.com_object.QueryTable)

    @property
    def querytable(self):
        """Alias for QueryTable"""
        return self.QueryTable

    @property
    def query_table(self):
        """Alias for QueryTable"""
        return self.QueryTable

    def Range(self, Cell1=None, Cell2=None):
        arguments = com_arguments([unwrap(a) for a in [Cell1, Cell2]])
        if hasattr(self.com_object, "GetRange"):
            return Range(self.com_object.GetRange(*arguments))
        else:
            return Range(self.com_object.Range(*arguments))

    def range(self, Cell1=None, Cell2=None):
        """Alias for Range"""
        arguments = [Cell1, Cell2]
        return self.Range(*arguments)

    @property
    def ReadingOrder(self):
        return self.com_object.ReadingOrder

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    def Resize(self, RowSize=None, ColumnSize=None):
        arguments = com_arguments([unwrap(a) for a in [RowSize, ColumnSize]])
        if hasattr(self.com_object, "GetResize"):
            return Range(self.com_object.GetResize(*arguments))
        else:
            return Range(self.com_object.Resize(*arguments))

    def resize(self, RowSize=None, ColumnSize=None):
        """Alias for Resize"""
        arguments = [RowSize, ColumnSize]
        return self.Resize(*arguments)

    @property
    def Row(self):
        return self.com_object.Row

    @property
    def row(self):
        """Alias for Row"""
        return self.Row

    @property
    def RowHeight(self):
        return self.com_object.RowHeight

    @RowHeight.setter
    def RowHeight(self, value):
        self.com_object.RowHeight = value

    @property
    def rowheight(self):
        """Alias for RowHeight"""
        return self.RowHeight

    @rowheight.setter
    def rowheight(self, value):
        """Alias for RowHeight.setter"""
        self.RowHeight = value

    @property
    def row_height(self):
        """Alias for RowHeight"""
        return self.RowHeight

    @row_height.setter
    def row_height(self, value):
        """Alias for RowHeight.setter"""
        self.RowHeight = value

    @property
    def Rows(self):
        return Range(self.com_object.Rows)

    @property
    def rows(self):
        """Alias for Rows"""
        return self.Rows

    @property
    def SavedAsArray(self):
        return self.com_object.SavedAsArray

    @property
    def savedasarray(self):
        """Alias for SavedAsArray"""
        return self.SavedAsArray

    @property
    def saved_as_array(self):
        """Alias for SavedAsArray"""
        return self.SavedAsArray

    @property
    def ServerActions(self):
        return self.com_object.ServerActions

    @property
    def serveractions(self):
        """Alias for ServerActions"""
        return self.ServerActions

    @property
    def server_actions(self):
        """Alias for ServerActions"""
        return self.ServerActions

    @property
    def ShowDetail(self):
        return self.com_object.ShowDetail

    @ShowDetail.setter
    def ShowDetail(self, value):
        self.com_object.ShowDetail = value

    @property
    def showdetail(self):
        """Alias for ShowDetail"""
        return self.ShowDetail

    @showdetail.setter
    def showdetail(self, value):
        """Alias for ShowDetail.setter"""
        self.ShowDetail = value

    @property
    def show_detail(self):
        """Alias for ShowDetail"""
        return self.ShowDetail

    @show_detail.setter
    def show_detail(self, value):
        """Alias for ShowDetail.setter"""
        self.ShowDetail = value

    @property
    def ShrinkToFit(self):
        return self.com_object.ShrinkToFit

    @ShrinkToFit.setter
    def ShrinkToFit(self, value):
        self.com_object.ShrinkToFit = value

    @property
    def shrinktofit(self):
        """Alias for ShrinkToFit"""
        return self.ShrinkToFit

    @shrinktofit.setter
    def shrinktofit(self, value):
        """Alias for ShrinkToFit.setter"""
        self.ShrinkToFit = value

    @property
    def shrink_to_fit(self):
        """Alias for ShrinkToFit"""
        return self.ShrinkToFit

    @shrink_to_fit.setter
    def shrink_to_fit(self, value):
        """Alias for ShrinkToFit.setter"""
        self.ShrinkToFit = value

    @property
    def SoundNote(self):
        return self.com_object.SoundNote

    @property
    def soundnote(self):
        """Alias for SoundNote"""
        return self.SoundNote

    @property
    def sound_note(self):
        """Alias for SoundNote"""
        return self.SoundNote

    @property
    def SparklineGroups(self):
        return SparklineGroups(self.com_object.SparklineGroups)

    @property
    def sparklinegroups(self):
        """Alias for SparklineGroups"""
        return self.SparklineGroups

    @property
    def sparkline_groups(self):
        """Alias for SparklineGroups"""
        return self.SparklineGroups

    @property
    def SpillParent(self):
        return self.com_object.SpillParent

    @property
    def spillparent(self):
        """Alias for SpillParent"""
        return self.SpillParent

    @property
    def spill_parent(self):
        """Alias for SpillParent"""
        return self.SpillParent

    @property
    def Style(self):
        return Style(self.com_object.Style)

    @Style.setter
    def Style(self, value):
        self.com_object.Style = value

    @property
    def style(self):
        """Alias for Style"""
        return self.Style

    @style.setter
    def style(self, value):
        """Alias for Style.setter"""
        self.Style = value

    @property
    def Summary(self):
        return self.com_object.Summary

    @property
    def summary(self):
        """Alias for Summary"""
        return self.Summary

    @property
    def Text(self):
        return self.com_object.Text

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @property
    def Top(self):
        return self.com_object.Top

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @property
    def UseStandardHeight(self):
        return self.com_object.UseStandardHeight

    @UseStandardHeight.setter
    def UseStandardHeight(self, value):
        self.com_object.UseStandardHeight = value

    @property
    def usestandardheight(self):
        """Alias for UseStandardHeight"""
        return self.UseStandardHeight

    @usestandardheight.setter
    def usestandardheight(self, value):
        """Alias for UseStandardHeight.setter"""
        self.UseStandardHeight = value

    @property
    def use_standard_height(self):
        """Alias for UseStandardHeight"""
        return self.UseStandardHeight

    @use_standard_height.setter
    def use_standard_height(self, value):
        """Alias for UseStandardHeight.setter"""
        self.UseStandardHeight = value

    @property
    def UseStandardWidth(self):
        return self.com_object.UseStandardWidth

    @UseStandardWidth.setter
    def UseStandardWidth(self, value):
        self.com_object.UseStandardWidth = value

    @property
    def usestandardwidth(self):
        """Alias for UseStandardWidth"""
        return self.UseStandardWidth

    @usestandardwidth.setter
    def usestandardwidth(self, value):
        """Alias for UseStandardWidth.setter"""
        self.UseStandardWidth = value

    @property
    def use_standard_width(self):
        """Alias for UseStandardWidth"""
        return self.UseStandardWidth

    @use_standard_width.setter
    def use_standard_width(self, value):
        """Alias for UseStandardWidth.setter"""
        self.UseStandardWidth = value

    @property
    def Validation(self):
        return Validation(self.com_object.Validation)

    @property
    def validation(self):
        """Alias for Validation"""
        return self.Validation

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    @property
    def Value2(self):
        return self.com_object.Value2

    @Value2.setter
    def Value2(self, value):
        self.com_object.Value2 = value

    @property
    def value2(self):
        """Alias for Value2"""
        return self.Value2

    @value2.setter
    def value2(self, value):
        """Alias for Value2.setter"""
        self.Value2 = value

    @property
    def VerticalAlignment(self):
        return self.com_object.VerticalAlignment

    @VerticalAlignment.setter
    def VerticalAlignment(self, value):
        self.com_object.VerticalAlignment = value

    @property
    def verticalalignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @verticalalignment.setter
    def verticalalignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def vertical_alignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @vertical_alignment.setter
    def vertical_alignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def Width(self):
        return self.com_object.Width

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @property
    def Worksheet(self):
        return Worksheet(self.com_object.Worksheet)

    @property
    def worksheet(self):
        """Alias for Worksheet"""
        return self.Worksheet

    @property
    def WrapText(self):
        return self.com_object.WrapText

    @WrapText.setter
    def WrapText(self, value):
        self.com_object.WrapText = value

    @property
    def wraptext(self):
        """Alias for WrapText"""
        return self.WrapText

    @wraptext.setter
    def wraptext(self, value):
        """Alias for WrapText.setter"""
        self.WrapText = value

    @property
    def wrap_text(self):
        """Alias for WrapText"""
        return self.WrapText

    @wrap_text.setter
    def wrap_text(self, value):
        """Alias for WrapText.setter"""
        self.WrapText = value

    @property
    def XPath(self):
        return XPath(self.com_object.XPath)

    @property
    def xpath(self):
        """Alias for XPath"""
        return self.XPath

    @property
    def x_path(self):
        """Alias for XPath"""
        return self.XPath

    def Activate(self):
        return self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()

    def AddComment(self, Text=None):
        arguments = com_arguments([unwrap(a) for a in [Text]])
        return Comment(self.com_object.AddComment(*arguments))

    def addcomment(self, Text=None):
        """Alias for AddComment"""
        arguments = [Text]
        return self.AddComment(*arguments)

    def add_comment(self, Text=None):
        """Alias for AddComment"""
        arguments = [Text]
        return self.AddComment(*arguments)

    def AddCommentThreaded(self, Text=None):
        arguments = com_arguments([unwrap(a) for a in [Text]])
        return CommentThreaded(self.com_object.AddCommentThreaded(*arguments))

    def addcommentthreaded(self, Text=None):
        """Alias for AddCommentThreaded"""
        arguments = [Text]
        return self.AddCommentThreaded(*arguments)

    def add_comment_threaded(self, Text=None):
        """Alias for AddCommentThreaded"""
        arguments = [Text]
        return self.AddCommentThreaded(*arguments)

    def AdvancedFilter(self, Action=None, CriteriaRange=None, CopyToRange=None, Unique=None):
        arguments = com_arguments([unwrap(a) for a in [Action, CriteriaRange, CopyToRange, Unique]])
        return self.com_object.AdvancedFilter(*arguments)

    def advancedfilter(self, Action=None, CriteriaRange=None, CopyToRange=None, Unique=None):
        """Alias for AdvancedFilter"""
        arguments = [Action, CriteriaRange, CopyToRange, Unique]
        return self.AdvancedFilter(*arguments)

    def advanced_filter(self, Action=None, CriteriaRange=None, CopyToRange=None, Unique=None):
        """Alias for AdvancedFilter"""
        arguments = [Action, CriteriaRange, CopyToRange, Unique]
        return self.AdvancedFilter(*arguments)

    def AllocateChanges(self):
        self.com_object.AllocateChanges()

    def allocatechanges(self):
        """Alias for AllocateChanges"""
        return self.AllocateChanges()

    def allocate_changes(self):
        """Alias for AllocateChanges"""
        return self.AllocateChanges()

    def ApplyNames(self, Names=None, IgnoreRelativeAbsolute=None, UseRowColumnNames=None, OmitColumn=None, OmitRow=None, Order=None, AppendLast=None):
        arguments = com_arguments([unwrap(a) for a in [Names, IgnoreRelativeAbsolute, UseRowColumnNames, OmitColumn, OmitRow, Order, AppendLast]])
        return self.com_object.ApplyNames(*arguments)

    def applynames(self, Names=None, IgnoreRelativeAbsolute=None, UseRowColumnNames=None, OmitColumn=None, OmitRow=None, Order=None, AppendLast=None):
        """Alias for ApplyNames"""
        arguments = [Names, IgnoreRelativeAbsolute, UseRowColumnNames, OmitColumn, OmitRow, Order, AppendLast]
        return self.ApplyNames(*arguments)

    def apply_names(self, Names=None, IgnoreRelativeAbsolute=None, UseRowColumnNames=None, OmitColumn=None, OmitRow=None, Order=None, AppendLast=None):
        """Alias for ApplyNames"""
        arguments = [Names, IgnoreRelativeAbsolute, UseRowColumnNames, OmitColumn, OmitRow, Order, AppendLast]
        return self.ApplyNames(*arguments)

    def ApplyOutlineStyles(self):
        return self.com_object.ApplyOutlineStyles()

    def applyoutlinestyles(self):
        """Alias for ApplyOutlineStyles"""
        return self.ApplyOutlineStyles()

    def apply_outline_styles(self):
        """Alias for ApplyOutlineStyles"""
        return self.ApplyOutlineStyles()

    def AutoComplete(self, String=None):
        arguments = com_arguments([unwrap(a) for a in [String]])
        return self.com_object.AutoComplete(*arguments)

    def autocomplete(self, String=None):
        """Alias for AutoComplete"""
        arguments = [String]
        return self.AutoComplete(*arguments)

    def auto_complete(self, String=None):
        """Alias for AutoComplete"""
        arguments = [String]
        return self.AutoComplete(*arguments)

    def AutoFill(self, Destination=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Destination, Type]])
        return self.com_object.AutoFill(*arguments)

    def autofill(self, Destination=None, Type=None):
        """Alias for AutoFill"""
        arguments = [Destination, Type]
        return self.AutoFill(*arguments)

    def auto_fill(self, Destination=None, Type=None):
        """Alias for AutoFill"""
        arguments = [Destination, Type]
        return self.AutoFill(*arguments)

    def AutoFilter(self, Field=None, Criteria1=None, Operator=None, Criteria2=None, SubField=None, VisibleDropDown=None):
        arguments = com_arguments([unwrap(a) for a in [Field, Criteria1, Operator, Criteria2, SubField, VisibleDropDown]])
        return self.com_object.AutoFilter(*arguments)

    def autofilter(self, Field=None, Criteria1=None, Operator=None, Criteria2=None, SubField=None, VisibleDropDown=None):
        """Alias for AutoFilter"""
        arguments = [Field, Criteria1, Operator, Criteria2, SubField, VisibleDropDown]
        return self.AutoFilter(*arguments)

    def auto_filter(self, Field=None, Criteria1=None, Operator=None, Criteria2=None, SubField=None, VisibleDropDown=None):
        """Alias for AutoFilter"""
        arguments = [Field, Criteria1, Operator, Criteria2, SubField, VisibleDropDown]
        return self.AutoFilter(*arguments)

    def AutoFit(self):
        return self.com_object.AutoFit()

    def autofit(self):
        """Alias for AutoFit"""
        return self.AutoFit()

    def auto_fit(self):
        """Alias for AutoFit"""
        return self.AutoFit()

    def AutoOutline(self):
        return self.com_object.AutoOutline()

    def autooutline(self):
        """Alias for AutoOutline"""
        return self.AutoOutline()

    def auto_outline(self):
        """Alias for AutoOutline"""
        return self.AutoOutline()

    def BorderAround(self, LineStyle=None, Weight=None, ColorIndex=None, Color=None, ThemeColor=None):
        arguments = com_arguments([unwrap(a) for a in [LineStyle, Weight, ColorIndex, Color, ThemeColor]])
        return self.com_object.BorderAround(*arguments)

    def borderaround(self, LineStyle=None, Weight=None, ColorIndex=None, Color=None, ThemeColor=None):
        """Alias for BorderAround"""
        arguments = [LineStyle, Weight, ColorIndex, Color, ThemeColor]
        return self.BorderAround(*arguments)

    def border_around(self, LineStyle=None, Weight=None, ColorIndex=None, Color=None, ThemeColor=None):
        """Alias for BorderAround"""
        arguments = [LineStyle, Weight, ColorIndex, Color, ThemeColor]
        return self.BorderAround(*arguments)

    def Calculate(self):
        return self.com_object.Calculate()

    def calculate(self):
        """Alias for Calculate"""
        return self.Calculate()

    def CalculateRowMajorOrder(self):
        return self.com_object.CalculateRowMajorOrder()

    def calculaterowmajororder(self):
        """Alias for CalculateRowMajorOrder"""
        return self.CalculateRowMajorOrder()

    def calculate_row_major_order(self):
        """Alias for CalculateRowMajorOrder"""
        return self.CalculateRowMajorOrder()

    def CheckSpelling(self, CustomDictionary=None, IgnoreUppercase=None, AlwaysSuggest=None, SpellLang=None):
        arguments = com_arguments([unwrap(a) for a in [CustomDictionary, IgnoreUppercase, AlwaysSuggest, SpellLang]])
        return self.com_object.CheckSpelling(*arguments)

    def checkspelling(self, CustomDictionary=None, IgnoreUppercase=None, AlwaysSuggest=None, SpellLang=None):
        """Alias for CheckSpelling"""
        arguments = [CustomDictionary, IgnoreUppercase, AlwaysSuggest, SpellLang]
        return self.CheckSpelling(*arguments)

    def check_spelling(self, CustomDictionary=None, IgnoreUppercase=None, AlwaysSuggest=None, SpellLang=None):
        """Alias for CheckSpelling"""
        arguments = [CustomDictionary, IgnoreUppercase, AlwaysSuggest, SpellLang]
        return self.CheckSpelling(*arguments)

    def Clear(self):
        return self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()

    def ClearComments(self):
        self.com_object.ClearComments()

    def clearcomments(self):
        """Alias for ClearComments"""
        return self.ClearComments()

    def clear_comments(self):
        """Alias for ClearComments"""
        return self.ClearComments()

    def ClearContents(self):
        return self.com_object.ClearContents()

    def clearcontents(self):
        """Alias for ClearContents"""
        return self.ClearContents()

    def clear_contents(self):
        """Alias for ClearContents"""
        return self.ClearContents()

    def ClearFormats(self):
        return self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def ClearHyperlinks(self):
        return self.com_object.ClearHyperlinks()

    def clearhyperlinks(self):
        """Alias for ClearHyperlinks"""
        return self.ClearHyperlinks()

    def clear_hyperlinks(self):
        """Alias for ClearHyperlinks"""
        return self.ClearHyperlinks()

    def ClearNotes(self):
        return self.com_object.ClearNotes()

    def clearnotes(self):
        """Alias for ClearNotes"""
        return self.ClearNotes()

    def clear_notes(self):
        """Alias for ClearNotes"""
        return self.ClearNotes()

    def ClearOutline(self):
        return self.com_object.ClearOutline()

    def clearoutline(self):
        """Alias for ClearOutline"""
        return self.ClearOutline()

    def clear_outline(self):
        """Alias for ClearOutline"""
        return self.ClearOutline()

    def ColumnDifferences(self, Comparison=None):
        arguments = com_arguments([unwrap(a) for a in [Comparison]])
        return Range(self.com_object.ColumnDifferences(*arguments))

    def columndifferences(self, Comparison=None):
        """Alias for ColumnDifferences"""
        arguments = [Comparison]
        return self.ColumnDifferences(*arguments)

    def column_differences(self, Comparison=None):
        """Alias for ColumnDifferences"""
        arguments = [Comparison]
        return self.ColumnDifferences(*arguments)

    def Consolidate(self, Sources=None, Function=None, TopRow=None, LeftColumn=None, CreateLinks=None):
        arguments = com_arguments([unwrap(a) for a in [Sources, Function, TopRow, LeftColumn, CreateLinks]])
        return self.com_object.Consolidate(*arguments)

    def consolidate(self, Sources=None, Function=None, TopRow=None, LeftColumn=None, CreateLinks=None):
        """Alias for Consolidate"""
        arguments = [Sources, Function, TopRow, LeftColumn, CreateLinks]
        return self.Consolidate(*arguments)

    def ConvertToLinkedDataType(self, ServiceID=None, LanguageCulture=None):
        arguments = com_arguments([unwrap(a) for a in [ServiceID, LanguageCulture]])
        self.com_object.ConvertToLinkedDataType(*arguments)

    def converttolinkeddatatype(self, ServiceID=None, LanguageCulture=None):
        """Alias for ConvertToLinkedDataType"""
        arguments = [ServiceID, LanguageCulture]
        return self.ConvertToLinkedDataType(*arguments)

    def convert_to_linked_data_type(self, ServiceID=None, LanguageCulture=None):
        """Alias for ConvertToLinkedDataType"""
        arguments = [ServiceID, LanguageCulture]
        return self.ConvertToLinkedDataType(*arguments)

    def Copy(self, Destination=None):
        arguments = com_arguments([unwrap(a) for a in [Destination]])
        return self.com_object.Copy(*arguments)

    def copy(self, Destination=None):
        """Alias for Copy"""
        arguments = [Destination]
        return self.Copy(*arguments)

    def CopyFromRecordset(self, Data=None, MaxRows=None, MaxColumns=None):
        arguments = com_arguments([unwrap(a) for a in [Data, MaxRows, MaxColumns]])
        return self.com_object.CopyFromRecordset(*arguments)

    def copyfromrecordset(self, Data=None, MaxRows=None, MaxColumns=None):
        """Alias for CopyFromRecordset"""
        arguments = [Data, MaxRows, MaxColumns]
        return self.CopyFromRecordset(*arguments)

    def copy_from_recordset(self, Data=None, MaxRows=None, MaxColumns=None):
        """Alias for CopyFromRecordset"""
        arguments = [Data, MaxRows, MaxColumns]
        return self.CopyFromRecordset(*arguments)

    def CopyPicture(self, Appearance=None, Format=None):
        arguments = com_arguments([unwrap(a) for a in [Appearance, Format]])
        return self.com_object.CopyPicture(*arguments)

    def copypicture(self, Appearance=None, Format=None):
        """Alias for CopyPicture"""
        arguments = [Appearance, Format]
        return self.CopyPicture(*arguments)

    def copy_picture(self, Appearance=None, Format=None):
        """Alias for CopyPicture"""
        arguments = [Appearance, Format]
        return self.CopyPicture(*arguments)

    def CreateNames(self, Top=None, Left=None, Bottom=None, Right=None):
        arguments = com_arguments([unwrap(a) for a in [Top, Left, Bottom, Right]])
        return self.com_object.CreateNames(*arguments)

    def createnames(self, Top=None, Left=None, Bottom=None, Right=None):
        """Alias for CreateNames"""
        arguments = [Top, Left, Bottom, Right]
        return self.CreateNames(*arguments)

    def create_names(self, Top=None, Left=None, Bottom=None, Right=None):
        """Alias for CreateNames"""
        arguments = [Top, Left, Bottom, Right]
        return self.CreateNames(*arguments)

    def Cut(self, Destination=None):
        arguments = com_arguments([unwrap(a) for a in [Destination]])
        return self.com_object.Cut(*arguments)

    def cut(self, Destination=None):
        """Alias for Cut"""
        arguments = [Destination]
        return self.Cut(*arguments)

    def DataSeries(self, Rowcol=None, Type=None, Date=None, Step=None, Stop=None, Trend=None):
        arguments = com_arguments([unwrap(a) for a in [Rowcol, Type, Date, Step, Stop, Trend]])
        return self.com_object.DataSeries(*arguments)

    def dataseries(self, Rowcol=None, Type=None, Date=None, Step=None, Stop=None, Trend=None):
        """Alias for DataSeries"""
        arguments = [Rowcol, Type, Date, Step, Stop, Trend]
        return self.DataSeries(*arguments)

    def data_series(self, Rowcol=None, Type=None, Date=None, Step=None, Stop=None, Trend=None):
        """Alias for DataSeries"""
        arguments = [Rowcol, Type, Date, Step, Stop, Trend]
        return self.DataSeries(*arguments)

    def DataTypeToText(self):
        self.com_object.DataTypeToText()

    def datatypetotext(self):
        """Alias for DataTypeToText"""
        return self.DataTypeToText()

    def data_type_to_text(self):
        """Alias for DataTypeToText"""
        return self.DataTypeToText()

    def Delete(self, Shift=None):
        arguments = com_arguments([unwrap(a) for a in [Shift]])
        return self.com_object.Delete(*arguments)

    def delete(self, Shift=None):
        """Alias for Delete"""
        arguments = [Shift]
        return self.Delete(*arguments)

    def DialogBox(self):
        return self.com_object.DialogBox()

    def dialogbox(self):
        """Alias for DialogBox"""
        return self.DialogBox()

    def dialog_box(self):
        """Alias for DialogBox"""
        return self.DialogBox()

    def Dirty(self):
        self.com_object.Dirty()

    def dirty(self):
        """Alias for Dirty"""
        return self.Dirty()

    def DiscardChanges(self):
        self.com_object.DiscardChanges()

    def discardchanges(self):
        """Alias for DiscardChanges"""
        return self.DiscardChanges()

    def discard_changes(self):
        """Alias for DiscardChanges"""
        return self.DiscardChanges()

    def EditionOptions(self, Type=None, Option=None, Name=None, Reference=None, Appearance=None, ChartSize=None, Format=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Option, Name, Reference, Appearance, ChartSize, Format]])
        return self.com_object.EditionOptions(*arguments)

    def editionoptions(self, Type=None, Option=None, Name=None, Reference=None, Appearance=None, ChartSize=None, Format=None):
        """Alias for EditionOptions"""
        arguments = [Type, Option, Name, Reference, Appearance, ChartSize, Format]
        return self.EditionOptions(*arguments)

    def edition_options(self, Type=None, Option=None, Name=None, Reference=None, Appearance=None, ChartSize=None, Format=None):
        """Alias for EditionOptions"""
        arguments = [Type, Option, Name, Reference, Appearance, ChartSize, Format]
        return self.EditionOptions(*arguments)

    def ExportAsFixedFormat(self, Type=None, FileName=None, Quality=None, IncludeDocProperties=None, IgnorePrintAreas=None, From=None, To=None, OpenAfterPublish=None, FixedFormatExtClassPtr=None):
        arguments = com_arguments([unwrap(a) for a in [Type, FileName, Quality, IncludeDocProperties, IgnorePrintAreas, From, To, OpenAfterPublish, FixedFormatExtClassPtr]])
        self.com_object.ExportAsFixedFormat(*arguments)

    def exportasfixedformat(self, Type=None, FileName=None, Quality=None, IncludeDocProperties=None, IgnorePrintAreas=None, From=None, To=None, OpenAfterPublish=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat"""
        arguments = [Type, FileName, Quality, IncludeDocProperties, IgnorePrintAreas, From, To, OpenAfterPublish, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat(*arguments)

    def export_as_fixed_format(self, Type=None, FileName=None, Quality=None, IncludeDocProperties=None, IgnorePrintAreas=None, From=None, To=None, OpenAfterPublish=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat"""
        arguments = [Type, FileName, Quality, IncludeDocProperties, IgnorePrintAreas, From, To, OpenAfterPublish, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat(*arguments)

    def FillDown(self):
        return self.com_object.FillDown()

    def filldown(self):
        """Alias for FillDown"""
        return self.FillDown()

    def fill_down(self):
        """Alias for FillDown"""
        return self.FillDown()

    def FillLeft(self):
        return self.com_object.FillLeft()

    def fillleft(self):
        """Alias for FillLeft"""
        return self.FillLeft()

    def fill_left(self):
        """Alias for FillLeft"""
        return self.FillLeft()

    def FillRight(self):
        return self.com_object.FillRight()

    def fillright(self):
        """Alias for FillRight"""
        return self.FillRight()

    def fill_right(self):
        """Alias for FillRight"""
        return self.FillRight()

    def FillUp(self):
        return self.com_object.FillUp()

    def fillup(self):
        """Alias for FillUp"""
        return self.FillUp()

    def fill_up(self):
        """Alias for FillUp"""
        return self.FillUp()

    def Find(self, What=None, After=None, LookIn=None, LookAt=None, SearchOrder=None, SearchDirection=None, MatchCase=None, MatchByte=None, SearchFormat=None):
        arguments = com_arguments([unwrap(a) for a in [What, After, LookIn, LookAt, SearchOrder, SearchDirection, MatchCase, MatchByte, SearchFormat]])
        return Range(self.com_object.Find(*arguments))

    def find(self, What=None, After=None, LookIn=None, LookAt=None, SearchOrder=None, SearchDirection=None, MatchCase=None, MatchByte=None, SearchFormat=None):
        """Alias for Find"""
        arguments = [What, After, LookIn, LookAt, SearchOrder, SearchDirection, MatchCase, MatchByte, SearchFormat]
        return self.Find(*arguments)

    def FindNext(self, After=None):
        arguments = com_arguments([unwrap(a) for a in [After]])
        return Range(self.com_object.FindNext(*arguments))

    def findnext(self, After=None):
        """Alias for FindNext"""
        arguments = [After]
        return self.FindNext(*arguments)

    def find_next(self, After=None):
        """Alias for FindNext"""
        arguments = [After]
        return self.FindNext(*arguments)

    def FindPrevious(self, Before=None):
        arguments = com_arguments([unwrap(a) for a in [Before]])
        return Range(self.com_object.FindPrevious(*arguments))

    def findprevious(self, Before=None):
        """Alias for FindPrevious"""
        arguments = [Before]
        return self.FindPrevious(*arguments)

    def find_previous(self, Before=None):
        """Alias for FindPrevious"""
        arguments = [Before]
        return self.FindPrevious(*arguments)

    def FlashFill(self):
        return self.com_object.FlashFill()

    def flashfill(self):
        """Alias for FlashFill"""
        return self.FlashFill()

    def flash_fill(self):
        """Alias for FlashFill"""
        return self.FlashFill()

    def FunctionWizard(self):
        return self.com_object.FunctionWizard()

    def functionwizard(self):
        """Alias for FunctionWizard"""
        return self.FunctionWizard()

    def function_wizard(self):
        """Alias for FunctionWizard"""
        return self.FunctionWizard()

    def Group(self, Start=None, End=None, By=None, Periods=None):
        arguments = com_arguments([unwrap(a) for a in [Start, End, By, Periods]])
        return self.com_object.Group(*arguments)

    def group(self, Start=None, End=None, By=None, Periods=None):
        """Alias for Group"""
        arguments = [Start, End, By, Periods]
        return self.Group(*arguments)

    def Insert(self, Shift=None, CopyOrigin=None):
        arguments = com_arguments([unwrap(a) for a in [Shift, CopyOrigin]])
        return self.com_object.Insert(*arguments)

    def insert(self, Shift=None, CopyOrigin=None):
        """Alias for Insert"""
        arguments = [Shift, CopyOrigin]
        return self.Insert(*arguments)

    def InsertIndent(self, InsertAmount=None):
        arguments = com_arguments([unwrap(a) for a in [InsertAmount]])
        self.com_object.InsertIndent(*arguments)

    def insertindent(self, InsertAmount=None):
        """Alias for InsertIndent"""
        arguments = [InsertAmount]
        return self.InsertIndent(*arguments)

    def insert_indent(self, InsertAmount=None):
        """Alias for InsertIndent"""
        arguments = [InsertAmount]
        return self.InsertIndent(*arguments)

    def Justify(self):
        return self.com_object.Justify()

    def justify(self):
        """Alias for Justify"""
        return self.Justify()

    def ListNames(self):
        return self.com_object.ListNames()

    def listnames(self):
        """Alias for ListNames"""
        return self.ListNames()

    def list_names(self):
        """Alias for ListNames"""
        return self.ListNames()

    def Merge(self, Across=None):
        arguments = com_arguments([unwrap(a) for a in [Across]])
        self.com_object.Merge(*arguments)

    def merge(self, Across=None):
        """Alias for Merge"""
        arguments = [Across]
        return self.Merge(*arguments)

    def NavigateArrow(self, TowardPrecedent=None, ArrowNumber=None, LinkNumber=None):
        arguments = com_arguments([unwrap(a) for a in [TowardPrecedent, ArrowNumber, LinkNumber]])
        return self.com_object.NavigateArrow(*arguments)

    def navigatearrow(self, TowardPrecedent=None, ArrowNumber=None, LinkNumber=None):
        """Alias for NavigateArrow"""
        arguments = [TowardPrecedent, ArrowNumber, LinkNumber]
        return self.NavigateArrow(*arguments)

    def navigate_arrow(self, TowardPrecedent=None, ArrowNumber=None, LinkNumber=None):
        """Alias for NavigateArrow"""
        arguments = [TowardPrecedent, ArrowNumber, LinkNumber]
        return self.NavigateArrow(*arguments)

    def NoteText(self, Text=None, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Text, Start, Length]])
        return self.com_object.NoteText(*arguments)

    def notetext(self, Text=None, Start=None, Length=None):
        """Alias for NoteText"""
        arguments = [Text, Start, Length]
        return self.NoteText(*arguments)

    def note_text(self, Text=None, Start=None, Length=None):
        """Alias for NoteText"""
        arguments = [Text, Start, Length]
        return self.NoteText(*arguments)

    def Parse(self, ParseLine=None, Destination=None):
        arguments = com_arguments([unwrap(a) for a in [ParseLine, Destination]])
        return self.com_object.Parse(*arguments)

    def parse(self, ParseLine=None, Destination=None):
        """Alias for Parse"""
        arguments = [ParseLine, Destination]
        return self.Parse(*arguments)

    def PasteSpecial(self, Paste=None, Operation=None, SkipBlanks=None, Transpose=None):
        arguments = com_arguments([unwrap(a) for a in [Paste, Operation, SkipBlanks, Transpose]])
        return self.com_object.PasteSpecial(*arguments)

    def pastespecial(self, Paste=None, Operation=None, SkipBlanks=None, Transpose=None):
        """Alias for PasteSpecial"""
        arguments = [Paste, Operation, SkipBlanks, Transpose]
        return self.PasteSpecial(*arguments)

    def paste_special(self, Paste=None, Operation=None, SkipBlanks=None, Transpose=None):
        """Alias for PasteSpecial"""
        arguments = [Paste, Operation, SkipBlanks, Transpose]
        return self.PasteSpecial(*arguments)

    def PrintOut(self, From=None, To=None, Copies=None, Preview=None, ActivePrinter=None, PrintToFile=None, Collate=None, PrToFileName=None):
        arguments = com_arguments([unwrap(a) for a in [From, To, Copies, Preview, ActivePrinter, PrintToFile, Collate, PrToFileName]])
        return self.com_object.PrintOut(*arguments)

    def printout(self, From=None, To=None, Copies=None, Preview=None, ActivePrinter=None, PrintToFile=None, Collate=None, PrToFileName=None):
        """Alias for PrintOut"""
        arguments = [From, To, Copies, Preview, ActivePrinter, PrintToFile, Collate, PrToFileName]
        return self.PrintOut(*arguments)

    def print_out(self, From=None, To=None, Copies=None, Preview=None, ActivePrinter=None, PrintToFile=None, Collate=None, PrToFileName=None):
        """Alias for PrintOut"""
        arguments = [From, To, Copies, Preview, ActivePrinter, PrintToFile, Collate, PrToFileName]
        return self.PrintOut(*arguments)

    def PrintPreview(self, EnableChanges=None):
        arguments = com_arguments([unwrap(a) for a in [EnableChanges]])
        return self.com_object.PrintPreview(*arguments)

    def printpreview(self, EnableChanges=None):
        """Alias for PrintPreview"""
        arguments = [EnableChanges]
        return self.PrintPreview(*arguments)

    def print_preview(self, EnableChanges=None):
        """Alias for PrintPreview"""
        arguments = [EnableChanges]
        return self.PrintPreview(*arguments)

    def RemoveDuplicates(self, Columns=None, Header=None):
        arguments = com_arguments([unwrap(a) for a in [Columns, Header]])
        self.com_object.RemoveDuplicates(*arguments)

    def removeduplicates(self, Columns=None, Header=None):
        """Alias for RemoveDuplicates"""
        arguments = [Columns, Header]
        return self.RemoveDuplicates(*arguments)

    def remove_duplicates(self, Columns=None, Header=None):
        """Alias for RemoveDuplicates"""
        arguments = [Columns, Header]
        return self.RemoveDuplicates(*arguments)

    def RemoveSubtotal(self):
        return self.com_object.RemoveSubtotal()

    def removesubtotal(self):
        """Alias for RemoveSubtotal"""
        return self.RemoveSubtotal()

    def remove_subtotal(self):
        """Alias for RemoveSubtotal"""
        return self.RemoveSubtotal()

    def Replace(self, What=None, Replacement=None, LookAt=None, SearchOrder=None, MatchCase=None, MatchByte=None, SearchFormat=None, ReplaceFormat=None, FormulaVersion=None):
        arguments = com_arguments([unwrap(a) for a in [What, Replacement, LookAt, SearchOrder, MatchCase, MatchByte, SearchFormat, ReplaceFormat, FormulaVersion]])
        return self.com_object.Replace(*arguments)

    def replace(self, What=None, Replacement=None, LookAt=None, SearchOrder=None, MatchCase=None, MatchByte=None, SearchFormat=None, ReplaceFormat=None, FormulaVersion=None):
        """Alias for Replace"""
        arguments = [What, Replacement, LookAt, SearchOrder, MatchCase, MatchByte, SearchFormat, ReplaceFormat, FormulaVersion]
        return self.Replace(*arguments)

    def ResetContents(self):
        self.com_object.ResetContents()

    def resetcontents(self):
        """Alias for ResetContents"""
        return self.ResetContents()

    def reset_contents(self):
        """Alias for ResetContents"""
        return self.ResetContents()

    def RowDifferences(self, Comparison=None):
        arguments = com_arguments([unwrap(a) for a in [Comparison]])
        return Range(self.com_object.RowDifferences(*arguments))

    def rowdifferences(self, Comparison=None):
        """Alias for RowDifferences"""
        arguments = [Comparison]
        return self.RowDifferences(*arguments)

    def row_differences(self, Comparison=None):
        """Alias for RowDifferences"""
        arguments = [Comparison]
        return self.RowDifferences(*arguments)

    def Run(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Run(*arguments)

    def run(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Run"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Run(*arguments)

    def Select(self):
        return self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()

    def SetCellDataTypeFromCell(self, Range=None, LanguageCulture=None):
        arguments = com_arguments([unwrap(a) for a in [Range, LanguageCulture]])
        self.com_object.SetCellDataTypeFromCell(*arguments)

    def setcelldatatypefromcell(self, Range=None, LanguageCulture=None):
        """Alias for SetCellDataTypeFromCell"""
        arguments = [Range, LanguageCulture]
        return self.SetCellDataTypeFromCell(*arguments)

    def set_cell_data_type_from_cell(self, Range=None, LanguageCulture=None):
        """Alias for SetCellDataTypeFromCell"""
        arguments = [Range, LanguageCulture]
        return self.SetCellDataTypeFromCell(*arguments)

    def SetPhonetic(self):
        self.com_object.SetPhonetic()

    def setphonetic(self):
        """Alias for SetPhonetic"""
        return self.SetPhonetic()

    def set_phonetic(self):
        """Alias for SetPhonetic"""
        return self.SetPhonetic()

    def Show(self):
        return self.com_object.Show()

    def show(self):
        """Alias for Show"""
        return self.Show()

    def ShowCard(self):
        self.com_object.ShowCard()

    def showcard(self):
        """Alias for ShowCard"""
        return self.ShowCard()

    def show_card(self):
        """Alias for ShowCard"""
        return self.ShowCard()

    def ShowDependents(self, Remove=None):
        arguments = com_arguments([unwrap(a) for a in [Remove]])
        return self.com_object.ShowDependents(*arguments)

    def showdependents(self, Remove=None):
        """Alias for ShowDependents"""
        arguments = [Remove]
        return self.ShowDependents(*arguments)

    def show_dependents(self, Remove=None):
        """Alias for ShowDependents"""
        arguments = [Remove]
        return self.ShowDependents(*arguments)

    def ShowErrors(self):
        return self.com_object.ShowErrors()

    def showerrors(self):
        """Alias for ShowErrors"""
        return self.ShowErrors()

    def show_errors(self):
        """Alias for ShowErrors"""
        return self.ShowErrors()

    def ShowPrecedents(self, Remove=None):
        arguments = com_arguments([unwrap(a) for a in [Remove]])
        return self.com_object.ShowPrecedents(*arguments)

    def showprecedents(self, Remove=None):
        """Alias for ShowPrecedents"""
        arguments = [Remove]
        return self.ShowPrecedents(*arguments)

    def show_precedents(self, Remove=None):
        """Alias for ShowPrecedents"""
        arguments = [Remove]
        return self.ShowPrecedents(*arguments)

    def Sort(self, Key1=None, Order1=None, Key2=None, Type=None, Order2=None, Key3=None, Order3=None, Header=None, OrderCustom=None, MatchCase=None, Orientation=None, SortMethod=None, DataOption1=None, DataOption2=None, DataOption3=None):
        arguments = com_arguments([unwrap(a) for a in [Key1, Order1, Key2, Type, Order2, Key3, Order3, Header, OrderCustom, MatchCase, Orientation, SortMethod, DataOption1, DataOption2, DataOption3]])
        return self.com_object.Sort(*arguments)

    def sort(self, Key1=None, Order1=None, Key2=None, Type=None, Order2=None, Key3=None, Order3=None, Header=None, OrderCustom=None, MatchCase=None, Orientation=None, SortMethod=None, DataOption1=None, DataOption2=None, DataOption3=None):
        """Alias for Sort"""
        arguments = [Key1, Order1, Key2, Type, Order2, Key3, Order3, Header, OrderCustom, MatchCase, Orientation, SortMethod, DataOption1, DataOption2, DataOption3]
        return self.Sort(*arguments)

    def SortSpecial(self, SortMethod=None, Key1=None, Order1=None, Type=None, Key2=None, Order2=None, Key3=None, Order3=None, Header=None, OrderCustom=None, MatchCase=None, Orientation=None, DataOption1=None, DataOption2=None, DataOption3=None):
        arguments = com_arguments([unwrap(a) for a in [SortMethod, Key1, Order1, Type, Key2, Order2, Key3, Order3, Header, OrderCustom, MatchCase, Orientation, DataOption1, DataOption2, DataOption3]])
        return self.com_object.SortSpecial(*arguments)

    def sortspecial(self, SortMethod=None, Key1=None, Order1=None, Type=None, Key2=None, Order2=None, Key3=None, Order3=None, Header=None, OrderCustom=None, MatchCase=None, Orientation=None, DataOption1=None, DataOption2=None, DataOption3=None):
        """Alias for SortSpecial"""
        arguments = [SortMethod, Key1, Order1, Type, Key2, Order2, Key3, Order3, Header, OrderCustom, MatchCase, Orientation, DataOption1, DataOption2, DataOption3]
        return self.SortSpecial(*arguments)

    def sort_special(self, SortMethod=None, Key1=None, Order1=None, Type=None, Key2=None, Order2=None, Key3=None, Order3=None, Header=None, OrderCustom=None, MatchCase=None, Orientation=None, DataOption1=None, DataOption2=None, DataOption3=None):
        """Alias for SortSpecial"""
        arguments = [SortMethod, Key1, Order1, Type, Key2, Order2, Key3, Order3, Header, OrderCustom, MatchCase, Orientation, DataOption1, DataOption2, DataOption3]
        return self.SortSpecial(*arguments)

    def Speak(self, SpeakDirection=None, SpeakFormulas=None):
        arguments = com_arguments([unwrap(a) for a in [SpeakDirection, SpeakFormulas]])
        self.com_object.Speak(*arguments)

    def speak(self, SpeakDirection=None, SpeakFormulas=None):
        """Alias for Speak"""
        arguments = [SpeakDirection, SpeakFormulas]
        return self.Speak(*arguments)

    def SpecialCells(self, Type=None, Value=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Value]])
        return Range(self.com_object.SpecialCells(*arguments))

    def specialcells(self, Type=None, Value=None):
        """Alias for SpecialCells"""
        arguments = [Type, Value]
        return self.SpecialCells(*arguments)

    def special_cells(self, Type=None, Value=None):
        """Alias for SpecialCells"""
        arguments = [Type, Value]
        return self.SpecialCells(*arguments)

    def SubscribeTo(self, Edition=None, Format=None):
        arguments = com_arguments([unwrap(a) for a in [Edition, Format]])
        return self.com_object.SubscribeTo(*arguments)

    def subscribeto(self, Edition=None, Format=None):
        """Alias for SubscribeTo"""
        arguments = [Edition, Format]
        return self.SubscribeTo(*arguments)

    def subscribe_to(self, Edition=None, Format=None):
        """Alias for SubscribeTo"""
        arguments = [Edition, Format]
        return self.SubscribeTo(*arguments)

    def Subtotal(self, GroupBy=None, Function=None, TotalList=None, Replace=None, PageBreaks=None, SummaryBelowData=None):
        arguments = com_arguments([unwrap(a) for a in [GroupBy, Function, TotalList, Replace, PageBreaks, SummaryBelowData]])
        return self.com_object.Subtotal(*arguments)

    def subtotal(self, GroupBy=None, Function=None, TotalList=None, Replace=None, PageBreaks=None, SummaryBelowData=None):
        """Alias for Subtotal"""
        arguments = [GroupBy, Function, TotalList, Replace, PageBreaks, SummaryBelowData]
        return self.Subtotal(*arguments)

    def Table(self, RowInput=None, ColumnInput=None):
        arguments = com_arguments([unwrap(a) for a in [RowInput, ColumnInput]])
        return self.com_object.Table(*arguments)

    def table(self, RowInput=None, ColumnInput=None):
        """Alias for Table"""
        arguments = [RowInput, ColumnInput]
        return self.Table(*arguments)

    def TextToColumns(self, Destination=None, DataType=None, TextQualifier=None, ConsecutiveDelimiter=None, Tab=None, Semicolon=None, Comma=None, Space=None, Other=None, OtherChar=None, FieldInfo=None, DecimalSeparator=None, ThousandsSeparator=None, TrailingMinusNumbers=None):
        arguments = com_arguments([unwrap(a) for a in [Destination, DataType, TextQualifier, ConsecutiveDelimiter, Tab, Semicolon, Comma, Space, Other, OtherChar, FieldInfo, DecimalSeparator, ThousandsSeparator, TrailingMinusNumbers]])
        return self.com_object.TextToColumns(*arguments)

    def texttocolumns(self, Destination=None, DataType=None, TextQualifier=None, ConsecutiveDelimiter=None, Tab=None, Semicolon=None, Comma=None, Space=None, Other=None, OtherChar=None, FieldInfo=None, DecimalSeparator=None, ThousandsSeparator=None, TrailingMinusNumbers=None):
        """Alias for TextToColumns"""
        arguments = [Destination, DataType, TextQualifier, ConsecutiveDelimiter, Tab, Semicolon, Comma, Space, Other, OtherChar, FieldInfo, DecimalSeparator, ThousandsSeparator, TrailingMinusNumbers]
        return self.TextToColumns(*arguments)

    def text_to_columns(self, Destination=None, DataType=None, TextQualifier=None, ConsecutiveDelimiter=None, Tab=None, Semicolon=None, Comma=None, Space=None, Other=None, OtherChar=None, FieldInfo=None, DecimalSeparator=None, ThousandsSeparator=None, TrailingMinusNumbers=None):
        """Alias for TextToColumns"""
        arguments = [Destination, DataType, TextQualifier, ConsecutiveDelimiter, Tab, Semicolon, Comma, Space, Other, OtherChar, FieldInfo, DecimalSeparator, ThousandsSeparator, TrailingMinusNumbers]
        return self.TextToColumns(*arguments)

    def Ungroup(self):
        return self.com_object.Ungroup()

    def ungroup(self):
        """Alias for Ungroup"""
        return self.Ungroup()

    def UnMerge(self):
        self.com_object.UnMerge()

    def unmerge(self):
        """Alias for UnMerge"""
        return self.UnMerge()

    def un_merge(self):
        """Alias for UnMerge"""
        return self.UnMerge()


class CellControl:

    def __init__(self, cellcontrol=None):
        self.com_object= cellcontrol


class Ranges:

    def __init__(self, ranges=None):
        self.com_object= ranges

    def __call__(self, item):
        return Range(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return Range(self.com_object.GetItem(*arguments))
        else:
            return Range(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class RecentFile:

    def __init__(self, recentfile=None):
        self.com_object= recentfile

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Path(self):
        return self.com_object.Path

    @property
    def path(self):
        """Alias for Path"""
        return self.Path

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Open(self):
        return Workbook(self.com_object.Open())

    def open(self):
        """Alias for Open"""
        return self.Open()


class RecentFiles:

    def __init__(self, recentfiles=None):
        self.com_object= recentfiles

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Maximum(self):
        return self.com_object.Maximum

    @Maximum.setter
    def Maximum(self, value):
        self.com_object.Maximum = value

    @property
    def maximum(self):
        """Alias for Maximum"""
        return self.Maximum

    @maximum.setter
    def maximum(self, value):
        """Alias for Maximum.setter"""
        self.Maximum = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        return RecentFile(self.com_object.Add(*arguments))

    def add(self, Name=None):
        """Alias for Add"""
        arguments = [Name]
        return self.Add(*arguments)


class RectangularGradient:

    def __init__(self, rectangulargradient=None):
        self.com_object= rectangulargradient

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ColorStops(self):
        return ColorStops(self.com_object.ColorStops)

    @property
    def colorstops(self):
        """Alias for ColorStops"""
        return self.ColorStops

    @property
    def color_stops(self):
        """Alias for ColorStops"""
        return self.ColorStops

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RectangleBottom(self):
        return self.com_object.RectangleBottom

    @RectangleBottom.setter
    def RectangleBottom(self, value):
        self.com_object.RectangleBottom = value

    @property
    def rectanglebottom(self):
        """Alias for RectangleBottom"""
        return self.RectangleBottom

    @rectanglebottom.setter
    def rectanglebottom(self, value):
        """Alias for RectangleBottom.setter"""
        self.RectangleBottom = value

    @property
    def rectangle_bottom(self):
        """Alias for RectangleBottom"""
        return self.RectangleBottom

    @rectangle_bottom.setter
    def rectangle_bottom(self, value):
        """Alias for RectangleBottom.setter"""
        self.RectangleBottom = value

    @property
    def RectangleLeft(self):
        return self.com_object.RectangleLeft

    @RectangleLeft.setter
    def RectangleLeft(self, value):
        self.com_object.RectangleLeft = value

    @property
    def rectangleleft(self):
        """Alias for RectangleLeft"""
        return self.RectangleLeft

    @rectangleleft.setter
    def rectangleleft(self, value):
        """Alias for RectangleLeft.setter"""
        self.RectangleLeft = value

    @property
    def rectangle_left(self):
        """Alias for RectangleLeft"""
        return self.RectangleLeft

    @rectangle_left.setter
    def rectangle_left(self, value):
        """Alias for RectangleLeft.setter"""
        self.RectangleLeft = value

    @property
    def RectangleRight(self):
        return self.com_object.RectangleRight

    @RectangleRight.setter
    def RectangleRight(self, value):
        self.com_object.RectangleRight = value

    @property
    def rectangleright(self):
        """Alias for RectangleRight"""
        return self.RectangleRight

    @rectangleright.setter
    def rectangleright(self, value):
        """Alias for RectangleRight.setter"""
        self.RectangleRight = value

    @property
    def rectangle_right(self):
        """Alias for RectangleRight"""
        return self.RectangleRight

    @rectangle_right.setter
    def rectangle_right(self, value):
        """Alias for RectangleRight.setter"""
        self.RectangleRight = value

    @property
    def RectangleTop(self):
        return self.com_object.RectangleTop

    @RectangleTop.setter
    def RectangleTop(self, value):
        self.com_object.RectangleTop = value

    @property
    def rectangletop(self):
        """Alias for RectangleTop"""
        return self.RectangleTop

    @rectangletop.setter
    def rectangletop(self, value):
        """Alias for RectangleTop.setter"""
        self.RectangleTop = value

    @property
    def rectangle_top(self):
        """Alias for RectangleTop"""
        return self.RectangleTop

    @rectangle_top.setter
    def rectangle_top(self, value):
        """Alias for RectangleTop.setter"""
        self.RectangleTop = value


class Research:

    def __init__(self, research=None):
        self.com_object= research

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def IsResearchService(self, ServiceID=None):
        arguments = com_arguments([unwrap(a) for a in [ServiceID]])
        return self.com_object.IsResearchService(*arguments)

    def isresearchservice(self, ServiceID=None):
        """Alias for IsResearchService"""
        arguments = [ServiceID]
        return self.IsResearchService(*arguments)

    def is_research_service(self, ServiceID=None):
        """Alias for IsResearchService"""
        arguments = [ServiceID]
        return self.IsResearchService(*arguments)

    def Query(self, ServiceID=None, QueryString=None, QueryLanguage=None, UseSelection=None, RequeryContextXML=None, NewQueryContextXML=None, LaunchQuery=None):
        arguments = com_arguments([unwrap(a) for a in [ServiceID, QueryString, QueryLanguage, UseSelection, RequeryContextXML, NewQueryContextXML, LaunchQuery]])
        return self.com_object.Query(*arguments)

    def query(self, ServiceID=None, QueryString=None, QueryLanguage=None, UseSelection=None, RequeryContextXML=None, NewQueryContextXML=None, LaunchQuery=None):
        """Alias for Query"""
        arguments = [ServiceID, QueryString, QueryLanguage, UseSelection, RequeryContextXML, NewQueryContextXML, LaunchQuery]
        return self.Query(*arguments)

    def SetLanguagePair(self, LanguageFrom=None, LanguageTo=None):
        arguments = com_arguments([unwrap(a) for a in [LanguageFrom, LanguageTo]])
        return self.com_object.SetLanguagePair(*arguments)

    def setlanguagepair(self, LanguageFrom=None, LanguageTo=None):
        """Alias for SetLanguagePair"""
        arguments = [LanguageFrom, LanguageTo]
        return self.SetLanguagePair(*arguments)

    def set_language_pair(self, LanguageFrom=None, LanguageTo=None):
        """Alias for SetLanguagePair"""
        arguments = [LanguageFrom, LanguageTo]
        return self.SetLanguagePair(*arguments)


class RoutingSlip:

    def __init__(self, routingslip=None):
        self.com_object= routingslip

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Delivery(self):
        return self.com_object.Delivery

    @property
    def delivery(self):
        """Alias for Delivery"""
        return self.Delivery

    @property
    def Message(self):
        return self.com_object.Message

    @property
    def message(self):
        """Alias for Message"""
        return self.Message

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Recipients(self):
        return self.com_object.Recipients

    @property
    def recipients(self):
        """Alias for Recipients"""
        return self.Recipients

    @property
    def ReturnWhenDone(self):
        return self.com_object.ReturnWhenDone

    @property
    def returnwhendone(self):
        """Alias for ReturnWhenDone"""
        return self.ReturnWhenDone

    @property
    def return_when_done(self):
        """Alias for ReturnWhenDone"""
        return self.ReturnWhenDone

    @property
    def Status(self):
        return self.com_object.Status

    @property
    def status(self):
        """Alias for Status"""
        return self.Status

    @property
    def Subject(self):
        return self.com_object.Subject

    @property
    def subject(self):
        """Alias for Subject"""
        return self.Subject

    @property
    def TrackStatus(self):
        return self.com_object.TrackStatus

    @property
    def trackstatus(self):
        """Alias for TrackStatus"""
        return self.TrackStatus

    @property
    def track_status(self):
        """Alias for TrackStatus"""
        return self.TrackStatus

    def Reset(self):
        self.com_object.Reset()

    def reset(self):
        """Alias for Reset"""
        return self.Reset()


class RTD:

    def __init__(self, rtd=None):
        self.com_object= rtd

    @property
    def ThrottleInterval(self):
        return self.com_object.ThrottleInterval

    @ThrottleInterval.setter
    def ThrottleInterval(self, value):
        self.com_object.ThrottleInterval = value

    @property
    def throttleinterval(self):
        """Alias for ThrottleInterval"""
        return self.ThrottleInterval

    @throttleinterval.setter
    def throttleinterval(self, value):
        """Alias for ThrottleInterval.setter"""
        self.ThrottleInterval = value

    @property
    def throttle_interval(self):
        """Alias for ThrottleInterval"""
        return self.ThrottleInterval

    @throttle_interval.setter
    def throttle_interval(self, value):
        """Alias for ThrottleInterval.setter"""
        self.ThrottleInterval = value

    def RefreshData(self):
        self.com_object.RefreshData()

    def refreshdata(self):
        """Alias for RefreshData"""
        return self.RefreshData()

    def refresh_data(self):
        """Alias for RefreshData"""
        return self.RefreshData()

    def RestartServers(self):
        self.com_object.RestartServers()

    def restartservers(self):
        """Alias for RestartServers"""
        return self.RestartServers()

    def restart_servers(self):
        """Alias for RestartServers"""
        return self.RestartServers()


class Scenario:

    def __init__(self, scenario=None):
        self.com_object= scenario

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ChangingCells(self):
        return Range(self.com_object.ChangingCells)

    @property
    def changingcells(self):
        """Alias for ChangingCells"""
        return self.ChangingCells

    @property
    def changing_cells(self):
        """Alias for ChangingCells"""
        return self.ChangingCells

    @property
    def Comment(self):
        return self.com_object.Comment

    @Comment.setter
    def Comment(self, value):
        self.com_object.Comment = value

    @property
    def comment(self):
        """Alias for Comment"""
        return self.Comment

    @comment.setter
    def comment(self, value):
        """Alias for Comment.setter"""
        self.Comment = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Hidden(self):
        return self.com_object.Hidden

    @Hidden.setter
    def Hidden(self, value):
        self.com_object.Hidden = value

    @property
    def hidden(self):
        """Alias for Hidden"""
        return self.Hidden

    @hidden.setter
    def hidden(self, value):
        """Alias for Hidden.setter"""
        self.Hidden = value

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Values(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetValues"):
            return self.com_object.GetValues(*arguments)
        else:
            return self.com_object.Values(*arguments)

    def values(self, Index=None):
        """Alias for Values"""
        arguments = [Index]
        return self.Values(*arguments)

    def ChangeScenario(self, ChangingCells=None, Values=None):
        arguments = com_arguments([unwrap(a) for a in [ChangingCells, Values]])
        return self.com_object.ChangeScenario(*arguments)

    def changescenario(self, ChangingCells=None, Values=None):
        """Alias for ChangeScenario"""
        arguments = [ChangingCells, Values]
        return self.ChangeScenario(*arguments)

    def change_scenario(self, ChangingCells=None, Values=None):
        """Alias for ChangeScenario"""
        arguments = [ChangingCells, Values]
        return self.ChangeScenario(*arguments)

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Show(self):
        return self.com_object.Show()

    def show(self):
        """Alias for Show"""
        return self.Show()


class Scenarios:

    def __init__(self, scenarios=None):
        self.com_object= scenarios

    def __call__(self, item):
        return Scenario(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, ChangingCells=None, Values=None, Comment=None, Locked=None, Hidden=None):
        arguments = com_arguments([unwrap(a) for a in [Name, ChangingCells, Values, Comment, Locked, Hidden]])
        return Scenario(self.com_object.Add(*arguments))

    def add(self, Name=None, ChangingCells=None, Values=None, Comment=None, Locked=None, Hidden=None):
        """Alias for Add"""
        arguments = [Name, ChangingCells, Values, Comment, Locked, Hidden]
        return self.Add(*arguments)

    def CreateSummary(self, ReportType=None, ResultCells=None):
        arguments = com_arguments([unwrap(a) for a in [ReportType, ResultCells]])
        return self.com_object.CreateSummary(*arguments)

    def createsummary(self, ReportType=None, ResultCells=None):
        """Alias for CreateSummary"""
        arguments = [ReportType, ResultCells]
        return self.CreateSummary(*arguments)

    def create_summary(self, ReportType=None, ResultCells=None):
        """Alias for CreateSummary"""
        arguments = [ReportType, ResultCells]
        return self.CreateSummary(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Scenario(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Merge(self, Source=None):
        arguments = com_arguments([unwrap(a) for a in [Source]])
        return self.com_object.Merge(*arguments)

    def merge(self, Source=None):
        """Alias for Merge"""
        arguments = [Source]
        return self.Merge(*arguments)


class Series:

    def __init__(self, series=None):
        self.com_object= series

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ApplyPictToEnd(self):
        return self.com_object.ApplyPictToEnd

    @ApplyPictToEnd.setter
    def ApplyPictToEnd(self, value):
        self.com_object.ApplyPictToEnd = value

    @property
    def applypicttoend(self):
        """Alias for ApplyPictToEnd"""
        return self.ApplyPictToEnd

    @applypicttoend.setter
    def applypicttoend(self, value):
        """Alias for ApplyPictToEnd.setter"""
        self.ApplyPictToEnd = value

    @property
    def apply_pict_to_end(self):
        """Alias for ApplyPictToEnd"""
        return self.ApplyPictToEnd

    @apply_pict_to_end.setter
    def apply_pict_to_end(self, value):
        """Alias for ApplyPictToEnd.setter"""
        self.ApplyPictToEnd = value

    @property
    def ApplyPictToFront(self):
        return self.com_object.ApplyPictToFront

    @ApplyPictToFront.setter
    def ApplyPictToFront(self, value):
        self.com_object.ApplyPictToFront = value

    @property
    def applypicttofront(self):
        """Alias for ApplyPictToFront"""
        return self.ApplyPictToFront

    @applypicttofront.setter
    def applypicttofront(self, value):
        """Alias for ApplyPictToFront.setter"""
        self.ApplyPictToFront = value

    @property
    def apply_pict_to_front(self):
        """Alias for ApplyPictToFront"""
        return self.ApplyPictToFront

    @apply_pict_to_front.setter
    def apply_pict_to_front(self, value):
        """Alias for ApplyPictToFront.setter"""
        self.ApplyPictToFront = value

    @property
    def ApplyPictToSides(self):
        return self.com_object.ApplyPictToSides

    @ApplyPictToSides.setter
    def ApplyPictToSides(self, value):
        self.com_object.ApplyPictToSides = value

    @property
    def applypicttosides(self):
        """Alias for ApplyPictToSides"""
        return self.ApplyPictToSides

    @applypicttosides.setter
    def applypicttosides(self, value):
        """Alias for ApplyPictToSides.setter"""
        self.ApplyPictToSides = value

    @property
    def apply_pict_to_sides(self):
        """Alias for ApplyPictToSides"""
        return self.ApplyPictToSides

    @apply_pict_to_sides.setter
    def apply_pict_to_sides(self, value):
        """Alias for ApplyPictToSides.setter"""
        self.ApplyPictToSides = value

    @property
    def AxisGroup(self):
        return self.com_object.AxisGroup

    @AxisGroup.setter
    def AxisGroup(self, value):
        self.com_object.AxisGroup = value

    @property
    def axisgroup(self):
        """Alias for AxisGroup"""
        return self.AxisGroup

    @axisgroup.setter
    def axisgroup(self, value):
        """Alias for AxisGroup.setter"""
        self.AxisGroup = value

    @property
    def axis_group(self):
        """Alias for AxisGroup"""
        return self.AxisGroup

    @axis_group.setter
    def axis_group(self, value):
        """Alias for AxisGroup.setter"""
        self.AxisGroup = value

    @property
    def BarShape(self):
        return XlBarShape(self.com_object.BarShape)

    @BarShape.setter
    def BarShape(self, value):
        self.com_object.BarShape = value

    @property
    def barshape(self):
        """Alias for BarShape"""
        return self.BarShape

    @barshape.setter
    def barshape(self, value):
        """Alias for BarShape.setter"""
        self.BarShape = value

    @property
    def bar_shape(self):
        """Alias for BarShape"""
        return self.BarShape

    @bar_shape.setter
    def bar_shape(self, value):
        """Alias for BarShape.setter"""
        self.BarShape = value

    @property
    def BubbleSizes(self):
        return self.com_object.BubbleSizes

    @BubbleSizes.setter
    def BubbleSizes(self, value):
        self.com_object.BubbleSizes = value

    @property
    def bubblesizes(self):
        """Alias for BubbleSizes"""
        return self.BubbleSizes

    @bubblesizes.setter
    def bubblesizes(self, value):
        """Alias for BubbleSizes.setter"""
        self.BubbleSizes = value

    @property
    def bubble_sizes(self):
        """Alias for BubbleSizes"""
        return self.BubbleSizes

    @bubble_sizes.setter
    def bubble_sizes(self, value):
        """Alias for BubbleSizes.setter"""
        self.BubbleSizes = value

    @property
    def ChartType(self):
        return XlChartType(self.com_object.ChartType)

    @ChartType.setter
    def ChartType(self, value):
        self.com_object.ChartType = value

    @property
    def charttype(self):
        """Alias for ChartType"""
        return self.ChartType

    @charttype.setter
    def charttype(self, value):
        """Alias for ChartType.setter"""
        self.ChartType = value

    @property
    def chart_type(self):
        """Alias for ChartType"""
        return self.ChartType

    @chart_type.setter
    def chart_type(self, value):
        """Alias for ChartType.setter"""
        self.ChartType = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ErrorBars(self):
        return ErrorBars(self.com_object.ErrorBars)

    @property
    def errorbars(self):
        """Alias for ErrorBars"""
        return self.ErrorBars

    @property
    def error_bars(self):
        """Alias for ErrorBars"""
        return self.ErrorBars

    @property
    def Explosion(self):
        return self.com_object.Explosion

    @Explosion.setter
    def Explosion(self, value):
        self.com_object.Explosion = value

    @property
    def explosion(self):
        """Alias for Explosion"""
        return self.Explosion

    @explosion.setter
    def explosion(self, value):
        """Alias for Explosion.setter"""
        self.Explosion = value

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def FormulaLocal(self):
        return self.com_object.FormulaLocal

    @FormulaLocal.setter
    def FormulaLocal(self, value):
        self.com_object.FormulaLocal = value

    @property
    def formulalocal(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formulalocal.setter
    def formulalocal(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def formula_local(self):
        """Alias for FormulaLocal"""
        return self.FormulaLocal

    @formula_local.setter
    def formula_local(self, value):
        """Alias for FormulaLocal.setter"""
        self.FormulaLocal = value

    @property
    def FormulaR1C1(self):
        return self.com_object.FormulaR1C1

    @FormulaR1C1.setter
    def FormulaR1C1(self, value):
        self.com_object.FormulaR1C1 = value

    @property
    def formular1c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formular1c1.setter
    def formular1c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def formula_r1_c1(self):
        """Alias for FormulaR1C1"""
        return self.FormulaR1C1

    @formula_r1_c1.setter
    def formula_r1_c1(self, value):
        """Alias for FormulaR1C1.setter"""
        self.FormulaR1C1 = value

    @property
    def FormulaR1C1Local(self):
        return self.com_object.FormulaR1C1Local

    @FormulaR1C1Local.setter
    def FormulaR1C1Local(self, value):
        self.com_object.FormulaR1C1Local = value

    @property
    def formular1c1local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formular1c1local.setter
    def formular1c1local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def formula_r1_c1_local(self):
        """Alias for FormulaR1C1Local"""
        return self.FormulaR1C1Local

    @formula_r1_c1_local.setter
    def formula_r1_c1_local(self, value):
        """Alias for FormulaR1C1Local.setter"""
        self.FormulaR1C1Local = value

    @property
    def Has3DEffect(self):
        return self.com_object.Has3DEffect

    @Has3DEffect.setter
    def Has3DEffect(self, value):
        self.com_object.Has3DEffect = value

    @property
    def has3deffect(self):
        """Alias for Has3DEffect"""
        return self.Has3DEffect

    @has3deffect.setter
    def has3deffect(self, value):
        """Alias for Has3DEffect.setter"""
        self.Has3DEffect = value

    @property
    def has3_d_effect(self):
        """Alias for Has3DEffect"""
        return self.Has3DEffect

    @has3_d_effect.setter
    def has3_d_effect(self, value):
        """Alias for Has3DEffect.setter"""
        self.Has3DEffect = value

    @property
    def HasDataLabels(self):
        return self.com_object.HasDataLabels

    @HasDataLabels.setter
    def HasDataLabels(self, value):
        self.com_object.HasDataLabels = value

    @property
    def hasdatalabels(self):
        """Alias for HasDataLabels"""
        return self.HasDataLabels

    @hasdatalabels.setter
    def hasdatalabels(self, value):
        """Alias for HasDataLabels.setter"""
        self.HasDataLabels = value

    @property
    def has_data_labels(self):
        """Alias for HasDataLabels"""
        return self.HasDataLabels

    @has_data_labels.setter
    def has_data_labels(self, value):
        """Alias for HasDataLabels.setter"""
        self.HasDataLabels = value

    @property
    def HasErrorBars(self):
        return self.com_object.HasErrorBars

    @HasErrorBars.setter
    def HasErrorBars(self, value):
        self.com_object.HasErrorBars = value

    @property
    def haserrorbars(self):
        """Alias for HasErrorBars"""
        return self.HasErrorBars

    @haserrorbars.setter
    def haserrorbars(self, value):
        """Alias for HasErrorBars.setter"""
        self.HasErrorBars = value

    @property
    def has_error_bars(self):
        """Alias for HasErrorBars"""
        return self.HasErrorBars

    @has_error_bars.setter
    def has_error_bars(self, value):
        """Alias for HasErrorBars.setter"""
        self.HasErrorBars = value

    @property
    def HasLeaderLines(self):
        return self.com_object.HasLeaderLines

    @HasLeaderLines.setter
    def HasLeaderLines(self, value):
        self.com_object.HasLeaderLines = value

    @property
    def hasleaderlines(self):
        """Alias for HasLeaderLines"""
        return self.HasLeaderLines

    @hasleaderlines.setter
    def hasleaderlines(self, value):
        """Alias for HasLeaderLines.setter"""
        self.HasLeaderLines = value

    @property
    def has_leader_lines(self):
        """Alias for HasLeaderLines"""
        return self.HasLeaderLines

    @has_leader_lines.setter
    def has_leader_lines(self, value):
        """Alias for HasLeaderLines.setter"""
        self.HasLeaderLines = value

    @property
    def InvertColor(self):
        return self.com_object.InvertColor

    @InvertColor.setter
    def InvertColor(self, value):
        self.com_object.InvertColor = value

    @property
    def invertcolor(self):
        """Alias for InvertColor"""
        return self.InvertColor

    @invertcolor.setter
    def invertcolor(self, value):
        """Alias for InvertColor.setter"""
        self.InvertColor = value

    @property
    def invert_color(self):
        """Alias for InvertColor"""
        return self.InvertColor

    @invert_color.setter
    def invert_color(self, value):
        """Alias for InvertColor.setter"""
        self.InvertColor = value

    @property
    def InvertColorIndex(self):
        return self.com_object.InvertColorIndex

    @InvertColorIndex.setter
    def InvertColorIndex(self, value):
        self.com_object.InvertColorIndex = value

    @property
    def invertcolorindex(self):
        """Alias for InvertColorIndex"""
        return self.InvertColorIndex

    @invertcolorindex.setter
    def invertcolorindex(self, value):
        """Alias for InvertColorIndex.setter"""
        self.InvertColorIndex = value

    @property
    def invert_color_index(self):
        """Alias for InvertColorIndex"""
        return self.InvertColorIndex

    @invert_color_index.setter
    def invert_color_index(self, value):
        """Alias for InvertColorIndex.setter"""
        self.InvertColorIndex = value

    @property
    def InvertIfNegative(self):
        return self.com_object.InvertIfNegative

    @InvertIfNegative.setter
    def InvertIfNegative(self, value):
        self.com_object.InvertIfNegative = value

    @property
    def invertifnegative(self):
        """Alias for InvertIfNegative"""
        return self.InvertIfNegative

    @invertifnegative.setter
    def invertifnegative(self, value):
        """Alias for InvertIfNegative.setter"""
        self.InvertIfNegative = value

    @property
    def invert_if_negative(self):
        """Alias for InvertIfNegative"""
        return self.InvertIfNegative

    @invert_if_negative.setter
    def invert_if_negative(self, value):
        """Alias for InvertIfNegative.setter"""
        self.InvertIfNegative = value

    @property
    def IsFiltered(self):
        return self.com_object.IsFiltered

    @IsFiltered.setter
    def IsFiltered(self, value):
        self.com_object.IsFiltered = value

    @property
    def isfiltered(self):
        """Alias for IsFiltered"""
        return self.IsFiltered

    @isfiltered.setter
    def isfiltered(self, value):
        """Alias for IsFiltered.setter"""
        self.IsFiltered = value

    @property
    def is_filtered(self):
        """Alias for IsFiltered"""
        return self.IsFiltered

    @is_filtered.setter
    def is_filtered(self, value):
        """Alias for IsFiltered.setter"""
        self.IsFiltered = value

    @property
    def LeaderLines(self):
        return LeaderLines(self.com_object.LeaderLines)

    @property
    def leaderlines(self):
        """Alias for LeaderLines"""
        return self.LeaderLines

    @property
    def leader_lines(self):
        """Alias for LeaderLines"""
        return self.LeaderLines

    @property
    def MarkerBackgroundColor(self):
        return self.com_object.MarkerBackgroundColor

    @MarkerBackgroundColor.setter
    def MarkerBackgroundColor(self, value):
        self.com_object.MarkerBackgroundColor = value

    @property
    def markerbackgroundcolor(self):
        """Alias for MarkerBackgroundColor"""
        return self.MarkerBackgroundColor

    @markerbackgroundcolor.setter
    def markerbackgroundcolor(self, value):
        """Alias for MarkerBackgroundColor.setter"""
        self.MarkerBackgroundColor = value

    @property
    def marker_background_color(self):
        """Alias for MarkerBackgroundColor"""
        return self.MarkerBackgroundColor

    @marker_background_color.setter
    def marker_background_color(self, value):
        """Alias for MarkerBackgroundColor.setter"""
        self.MarkerBackgroundColor = value

    @property
    def MarkerBackgroundColorIndex(self):
        return XlColorIndex(self.com_object.MarkerBackgroundColorIndex)

    @MarkerBackgroundColorIndex.setter
    def MarkerBackgroundColorIndex(self, value):
        self.com_object.MarkerBackgroundColorIndex = value

    @property
    def markerbackgroundcolorindex(self):
        """Alias for MarkerBackgroundColorIndex"""
        return self.MarkerBackgroundColorIndex

    @markerbackgroundcolorindex.setter
    def markerbackgroundcolorindex(self, value):
        """Alias for MarkerBackgroundColorIndex.setter"""
        self.MarkerBackgroundColorIndex = value

    @property
    def marker_background_color_index(self):
        """Alias for MarkerBackgroundColorIndex"""
        return self.MarkerBackgroundColorIndex

    @marker_background_color_index.setter
    def marker_background_color_index(self, value):
        """Alias for MarkerBackgroundColorIndex.setter"""
        self.MarkerBackgroundColorIndex = value

    @property
    def MarkerForegroundColor(self):
        return self.com_object.MarkerForegroundColor

    @MarkerForegroundColor.setter
    def MarkerForegroundColor(self, value):
        self.com_object.MarkerForegroundColor = value

    @property
    def markerforegroundcolor(self):
        """Alias for MarkerForegroundColor"""
        return self.MarkerForegroundColor

    @markerforegroundcolor.setter
    def markerforegroundcolor(self, value):
        """Alias for MarkerForegroundColor.setter"""
        self.MarkerForegroundColor = value

    @property
    def marker_foreground_color(self):
        """Alias for MarkerForegroundColor"""
        return self.MarkerForegroundColor

    @marker_foreground_color.setter
    def marker_foreground_color(self, value):
        """Alias for MarkerForegroundColor.setter"""
        self.MarkerForegroundColor = value

    @property
    def MarkerForegroundColorIndex(self):
        return XlColorIndex(self.com_object.MarkerForegroundColorIndex)

    @MarkerForegroundColorIndex.setter
    def MarkerForegroundColorIndex(self, value):
        self.com_object.MarkerForegroundColorIndex = value

    @property
    def markerforegroundcolorindex(self):
        """Alias for MarkerForegroundColorIndex"""
        return self.MarkerForegroundColorIndex

    @markerforegroundcolorindex.setter
    def markerforegroundcolorindex(self, value):
        """Alias for MarkerForegroundColorIndex.setter"""
        self.MarkerForegroundColorIndex = value

    @property
    def marker_foreground_color_index(self):
        """Alias for MarkerForegroundColorIndex"""
        return self.MarkerForegroundColorIndex

    @marker_foreground_color_index.setter
    def marker_foreground_color_index(self, value):
        """Alias for MarkerForegroundColorIndex.setter"""
        self.MarkerForegroundColorIndex = value

    @property
    def MarkerSize(self):
        return self.com_object.MarkerSize

    @MarkerSize.setter
    def MarkerSize(self, value):
        self.com_object.MarkerSize = value

    @property
    def markersize(self):
        """Alias for MarkerSize"""
        return self.MarkerSize

    @markersize.setter
    def markersize(self, value):
        """Alias for MarkerSize.setter"""
        self.MarkerSize = value

    @property
    def marker_size(self):
        """Alias for MarkerSize"""
        return self.MarkerSize

    @marker_size.setter
    def marker_size(self, value):
        """Alias for MarkerSize.setter"""
        self.MarkerSize = value

    @property
    def MarkerStyle(self):
        return XlMarkerStyle(self.com_object.MarkerStyle)

    @MarkerStyle.setter
    def MarkerStyle(self, value):
        self.com_object.MarkerStyle = value

    @property
    def markerstyle(self):
        """Alias for MarkerStyle"""
        return self.MarkerStyle

    @markerstyle.setter
    def markerstyle(self, value):
        """Alias for MarkerStyle.setter"""
        self.MarkerStyle = value

    @property
    def marker_style(self):
        """Alias for MarkerStyle"""
        return self.MarkerStyle

    @marker_style.setter
    def marker_style(self, value):
        """Alias for MarkerStyle.setter"""
        self.MarkerStyle = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ParentDataLabelOption(self):
        return self.com_object.ParentDataLabelOption

    @ParentDataLabelOption.setter
    def ParentDataLabelOption(self, value):
        self.com_object.ParentDataLabelOption = value

    @property
    def parentdatalabeloption(self):
        """Alias for ParentDataLabelOption"""
        return self.ParentDataLabelOption

    @parentdatalabeloption.setter
    def parentdatalabeloption(self, value):
        """Alias for ParentDataLabelOption.setter"""
        self.ParentDataLabelOption = value

    @property
    def parent_data_label_option(self):
        """Alias for ParentDataLabelOption"""
        return self.ParentDataLabelOption

    @parent_data_label_option.setter
    def parent_data_label_option(self, value):
        """Alias for ParentDataLabelOption.setter"""
        self.ParentDataLabelOption = value

    @property
    def PictureType(self):
        return XlChartPictureType(self.com_object.PictureType)

    @PictureType.setter
    def PictureType(self, value):
        self.com_object.PictureType = value

    @property
    def picturetype(self):
        """Alias for PictureType"""
        return self.PictureType

    @picturetype.setter
    def picturetype(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def picture_type(self):
        """Alias for PictureType"""
        return self.PictureType

    @picture_type.setter
    def picture_type(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def PictureUnit2(self):
        return PictureType(self.com_object.PictureUnit2)

    @PictureUnit2.setter
    def PictureUnit2(self, value):
        self.com_object.PictureUnit2 = value

    @property
    def pictureunit2(self):
        """Alias for PictureUnit2"""
        return self.PictureUnit2

    @pictureunit2.setter
    def pictureunit2(self, value):
        """Alias for PictureUnit2.setter"""
        self.PictureUnit2 = value

    @property
    def picture_unit2(self):
        """Alias for PictureUnit2"""
        return self.PictureUnit2

    @picture_unit2.setter
    def picture_unit2(self, value):
        """Alias for PictureUnit2.setter"""
        self.PictureUnit2 = value

    @property
    def PlotColorIndex(self):
        return self.com_object.PlotColorIndex

    @property
    def plotcolorindex(self):
        """Alias for PlotColorIndex"""
        return self.PlotColorIndex

    @property
    def plot_color_index(self):
        """Alias for PlotColorIndex"""
        return self.PlotColorIndex

    @property
    def PlotOrder(self):
        return self.com_object.PlotOrder

    @PlotOrder.setter
    def PlotOrder(self, value):
        self.com_object.PlotOrder = value

    @property
    def plotorder(self):
        """Alias for PlotOrder"""
        return self.PlotOrder

    @plotorder.setter
    def plotorder(self, value):
        """Alias for PlotOrder.setter"""
        self.PlotOrder = value

    @property
    def plot_order(self):
        """Alias for PlotOrder"""
        return self.PlotOrder

    @plot_order.setter
    def plot_order(self, value):
        """Alias for PlotOrder.setter"""
        self.PlotOrder = value

    @property
    def QuartileCalculationInclusiveMedian(self):
        return self.com_object.QuartileCalculationInclusiveMedian

    @QuartileCalculationInclusiveMedian.setter
    def QuartileCalculationInclusiveMedian(self, value):
        self.com_object.QuartileCalculationInclusiveMedian = value

    @property
    def quartilecalculationinclusivemedian(self):
        """Alias for QuartileCalculationInclusiveMedian"""
        return self.QuartileCalculationInclusiveMedian

    @quartilecalculationinclusivemedian.setter
    def quartilecalculationinclusivemedian(self, value):
        """Alias for QuartileCalculationInclusiveMedian.setter"""
        self.QuartileCalculationInclusiveMedian = value

    @property
    def quartile_calculation_inclusive_median(self):
        """Alias for QuartileCalculationInclusiveMedian"""
        return self.QuartileCalculationInclusiveMedian

    @quartile_calculation_inclusive_median.setter
    def quartile_calculation_inclusive_median(self, value):
        """Alias for QuartileCalculationInclusiveMedian.setter"""
        self.QuartileCalculationInclusiveMedian = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Smooth(self):
        return self.com_object.Smooth

    @Smooth.setter
    def Smooth(self, value):
        self.com_object.Smooth = value

    @property
    def smooth(self):
        """Alias for Smooth"""
        return self.Smooth

    @smooth.setter
    def smooth(self, value):
        """Alias for Smooth.setter"""
        self.Smooth = value

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    @property
    def Values(self):
        return self.com_object.Values

    @Values.setter
    def Values(self, value):
        self.com_object.Values = value

    @property
    def values(self):
        """Alias for Values"""
        return self.Values

    @values.setter
    def values(self, value):
        """Alias for Values.setter"""
        self.Values = value

    @property
    def XValues(self):
        return self.com_object.XValues

    @XValues.setter
    def XValues(self, value):
        self.com_object.XValues = value

    @property
    def xvalues(self):
        """Alias for XValues"""
        return self.XValues

    @xvalues.setter
    def xvalues(self, value):
        """Alias for XValues.setter"""
        self.XValues = value

    @property
    def x_values(self):
        """Alias for XValues"""
        return self.XValues

    @x_values.setter
    def x_values(self, value):
        """Alias for XValues.setter"""
        self.XValues = value

    def ApplyDataLabels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        arguments = com_arguments([unwrap(a) for a in [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]])
        self.com_object.ApplyDataLabels(*arguments)

    def applydatalabels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        """Alias for ApplyDataLabels"""
        arguments = [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]
        return self.ApplyDataLabels(*arguments)

    def apply_data_labels(self, Type=None, LegendKey=None, AutoText=None, HasLeaderLines=None, ShowSeriesName=None, ShowCategoryName=None, ShowValue=None, ShowPercentage=None, ShowBubbleSize=None, Separator=None):
        """Alias for ApplyDataLabels"""
        arguments = [Type, LegendKey, AutoText, HasLeaderLines, ShowSeriesName, ShowCategoryName, ShowValue, ShowPercentage, ShowBubbleSize, Separator]
        return self.ApplyDataLabels(*arguments)

    def ClearFormats(self):
        return self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Copy(self):
        return self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def DataLabels(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.DataLabels(*arguments)

    def datalabels(self, Index=None):
        """Alias for DataLabels"""
        arguments = [Index]
        return self.DataLabels(*arguments)

    def data_labels(self, Index=None):
        """Alias for DataLabels"""
        arguments = [Index]
        return self.DataLabels(*arguments)

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def ErrorBar(self, Direction=None, Include=None, Type=None, Amount=None, MinusValues=None):
        arguments = com_arguments([unwrap(a) for a in [Direction, Include, Type, Amount, MinusValues]])
        return self.com_object.ErrorBar(*arguments)

    def errorbar(self, Direction=None, Include=None, Type=None, Amount=None, MinusValues=None):
        """Alias for ErrorBar"""
        arguments = [Direction, Include, Type, Amount, MinusValues]
        return self.ErrorBar(*arguments)

    def error_bar(self, Direction=None, Include=None, Type=None, Amount=None, MinusValues=None):
        """Alias for ErrorBar"""
        arguments = [Direction, Include, Type, Amount, MinusValues]
        return self.ErrorBar(*arguments)

    def GeoMappingLevel(self):
        self.com_object.GeoMappingLevel()

    def geomappinglevel(self):
        """Alias for GeoMappingLevel"""
        return self.GeoMappingLevel()

    def geo_mapping_level(self):
        """Alias for GeoMappingLevel"""
        return self.GeoMappingLevel()

    def GeoProjectionType(self):
        self.com_object.GeoProjectionType()

    def geoprojectiontype(self):
        """Alias for GeoProjectionType"""
        return self.GeoProjectionType()

    def geo_projection_type(self):
        """Alias for GeoProjectionType"""
        return self.GeoProjectionType()

    def Paste(self):
        return self.com_object.Paste()

    def paste(self):
        """Alias for Paste"""
        return self.Paste()

    def Points(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Points(*arguments)

    def points(self, Index=None):
        """Alias for Points"""
        arguments = [Index]
        return self.Points(*arguments)

    def RegionLabelOptions(self):
        self.com_object.RegionLabelOptions()

    def regionlabeloptions(self):
        """Alias for RegionLabelOptions"""
        return self.RegionLabelOptions()

    def region_label_options(self):
        """Alias for RegionLabelOptions"""
        return self.RegionLabelOptions()

    def Select(self):
        return self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()

    def Trendlines(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Trendlines(*arguments)

    def trendlines(self, Index=None):
        """Alias for Trendlines"""
        arguments = [Index]
        return self.Trendlines(*arguments)


class SeriesCollection:

    def __init__(self, seriescollection=None):
        self.com_object= seriescollection

    def __call__(self, item):
        return Series(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Source=None, Rowcol=None, SeriesLabels=None, CategoryLabels=None, Replace=None):
        arguments = com_arguments([unwrap(a) for a in [Source, Rowcol, SeriesLabels, CategoryLabels, Replace]])
        return Series(self.com_object.Add(*arguments))

    def add(self, Source=None, Rowcol=None, SeriesLabels=None, CategoryLabels=None, Replace=None):
        """Alias for Add"""
        arguments = [Source, Rowcol, SeriesLabels, CategoryLabels, Replace]
        return self.Add(*arguments)

    def Extend(self, Source=None, RowCol=None, CategoryLabels=None):
        arguments = com_arguments([unwrap(a) for a in [Source, RowCol, CategoryLabels]])
        return self.com_object.Extend(*arguments)

    def extend(self, Source=None, RowCol=None, CategoryLabels=None):
        """Alias for Extend"""
        arguments = [Source, RowCol, CategoryLabels]
        return self.Extend(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Series(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def NewSeries(self):
        return Series(self.com_object.NewSeries())

    def newseries(self):
        """Alias for NewSeries"""
        return self.NewSeries()

    def new_series(self):
        """Alias for NewSeries"""
        return self.NewSeries()

    def Paste(self, RowCol=None, SeriesLabels=None, CategoryLabels=None, Replace=None, NewSeries=None):
        arguments = com_arguments([unwrap(a) for a in [RowCol, SeriesLabels, CategoryLabels, Replace, NewSeries]])
        return self.com_object.Paste(*arguments)

    def paste(self, RowCol=None, SeriesLabels=None, CategoryLabels=None, Replace=None, NewSeries=None):
        """Alias for Paste"""
        arguments = [RowCol, SeriesLabels, CategoryLabels, Replace, NewSeries]
        return self.Paste(*arguments)


class SeriesLines:

    def __init__(self, serieslines=None):
        self.com_object= serieslines

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Border(self):
        return Border(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        return self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class ServerViewableItems:

    def __init__(self, serverviewableitems=None):
        self.com_object= serverviewableitems

    def __call__(self, item):
        return ServerViewableItem(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Obj=None):
        arguments = com_arguments([unwrap(a) for a in [Obj]])
        return ServerViewableItem(self.com_object.Add(*arguments))

    def add(self, Obj=None):
        """Alias for Add"""
        arguments = [Obj]
        return self.Add(*arguments)

    def Delete(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Delete(*arguments)

    def delete(self, Index=None):
        """Alias for Delete"""
        arguments = [Index]
        return self.Delete(*arguments)

    def DeleteAll(self):
        self.com_object.DeleteAll()

    def deleteall(self):
        """Alias for DeleteAll"""
        return self.DeleteAll()

    def delete_all(self):
        """Alias for DeleteAll"""
        return self.DeleteAll()

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class ShadowFormat:

    def __init__(self, shadowformat=None):
        self.com_object= shadowformat

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Blur(self):
        return self.com_object.Blur

    @Blur.setter
    def Blur(self, value):
        self.com_object.Blur = value

    @property
    def blur(self):
        """Alias for Blur"""
        return self.Blur

    @blur.setter
    def blur(self, value):
        """Alias for Blur.setter"""
        self.Blur = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ForeColor(self):
        return ColorFormat(self.com_object.ForeColor)

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def Obscured(self):
        return self.com_object.Obscured

    @property
    def obscured(self):
        """Alias for Obscured"""
        return self.Obscured

    @property
    def OffsetX(self):
        return self.com_object.OffsetX

    @OffsetX.setter
    def OffsetX(self, value):
        self.com_object.OffsetX = value

    @property
    def offsetx(self):
        """Alias for OffsetX"""
        return self.OffsetX

    @offsetx.setter
    def offsetx(self, value):
        """Alias for OffsetX.setter"""
        self.OffsetX = value

    @property
    def offset_x(self):
        """Alias for OffsetX"""
        return self.OffsetX

    @offset_x.setter
    def offset_x(self, value):
        """Alias for OffsetX.setter"""
        self.OffsetX = value

    @property
    def OffsetY(self):
        return self.com_object.OffsetY

    @OffsetY.setter
    def OffsetY(self, value):
        self.com_object.OffsetY = value

    @property
    def offsety(self):
        """Alias for OffsetY"""
        return self.OffsetY

    @offsety.setter
    def offsety(self, value):
        """Alias for OffsetY.setter"""
        self.OffsetY = value

    @property
    def offset_y(self):
        """Alias for OffsetY"""
        return self.OffsetY

    @offset_y.setter
    def offset_y(self, value):
        """Alias for OffsetY.setter"""
        self.OffsetY = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RotateWithShape(self):
        return self.com_object.RotateWithShape

    @RotateWithShape.setter
    def RotateWithShape(self, value):
        self.com_object.RotateWithShape = value

    @property
    def rotatewithshape(self):
        """Alias for RotateWithShape"""
        return self.RotateWithShape

    @rotatewithshape.setter
    def rotatewithshape(self, value):
        """Alias for RotateWithShape.setter"""
        self.RotateWithShape = value

    @property
    def rotate_with_shape(self):
        """Alias for RotateWithShape"""
        return self.RotateWithShape

    @rotate_with_shape.setter
    def rotate_with_shape(self, value):
        """Alias for RotateWithShape.setter"""
        self.RotateWithShape = value

    @property
    def Size(self):
        return self.com_object.Size

    @Size.setter
    def Size(self, value):
        self.com_object.Size = value

    @property
    def size(self):
        """Alias for Size"""
        return self.Size

    @size.setter
    def size(self, value):
        """Alias for Size.setter"""
        self.Size = value

    @property
    def Style(self):
        return self.com_object.Style

    @Style.setter
    def Style(self, value):
        self.com_object.Style = value

    @property
    def style(self):
        """Alias for Style"""
        return self.Style

    @style.setter
    def style(self, value):
        """Alias for Style.setter"""
        self.Style = value

    @property
    def Transparency(self):
        return self.com_object.Transparency

    @Transparency.setter
    def Transparency(self, value):
        self.com_object.Transparency = value

    @property
    def transparency(self):
        """Alias for Transparency"""
        return self.Transparency

    @transparency.setter
    def transparency(self, value):
        """Alias for Transparency.setter"""
        self.Transparency = value

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    def IncrementOffsetX(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementOffsetX(*arguments)

    def incrementoffsetx(self, Increment=None):
        """Alias for IncrementOffsetX"""
        arguments = [Increment]
        return self.IncrementOffsetX(*arguments)

    def increment_offset_x(self, Increment=None):
        """Alias for IncrementOffsetX"""
        arguments = [Increment]
        return self.IncrementOffsetX(*arguments)

    def IncrementOffsetY(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementOffsetY(*arguments)

    def incrementoffsety(self, Increment=None):
        """Alias for IncrementOffsetY"""
        arguments = [Increment]
        return self.IncrementOffsetY(*arguments)

    def increment_offset_y(self, Increment=None):
        """Alias for IncrementOffsetY"""
        arguments = [Increment]
        return self.IncrementOffsetY(*arguments)


class Shape:

    def __init__(self, shape=None):
        self.com_object= shape

    @property
    def Adjustments(self):
        return Adjustments(self.com_object.Adjustments)

    @property
    def adjustments(self):
        """Alias for Adjustments"""
        return self.Adjustments

    @property
    def AlternativeText(self):
        return Shape(self.com_object.AlternativeText)

    @AlternativeText.setter
    def AlternativeText(self, value):
        self.com_object.AlternativeText = value

    @property
    def alternativetext(self):
        """Alias for AlternativeText"""
        return self.AlternativeText

    @alternativetext.setter
    def alternativetext(self, value):
        """Alias for AlternativeText.setter"""
        self.AlternativeText = value

    @property
    def alternative_text(self):
        """Alias for AlternativeText"""
        return self.AlternativeText

    @alternative_text.setter
    def alternative_text(self, value):
        """Alias for AlternativeText.setter"""
        self.AlternativeText = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoShapeType(self):
        return ShapeRange(self.com_object.AutoShapeType)

    @AutoShapeType.setter
    def AutoShapeType(self, value):
        self.com_object.AutoShapeType = value

    @property
    def autoshapetype(self):
        """Alias for AutoShapeType"""
        return self.AutoShapeType

    @autoshapetype.setter
    def autoshapetype(self, value):
        """Alias for AutoShapeType.setter"""
        self.AutoShapeType = value

    @property
    def auto_shape_type(self):
        """Alias for AutoShapeType"""
        return self.AutoShapeType

    @auto_shape_type.setter
    def auto_shape_type(self, value):
        """Alias for AutoShapeType.setter"""
        self.AutoShapeType = value

    @property
    def BackgroundStyle(self):
        return self.com_object.BackgroundStyle

    @BackgroundStyle.setter
    def BackgroundStyle(self, value):
        self.com_object.BackgroundStyle = value

    @property
    def backgroundstyle(self):
        """Alias for BackgroundStyle"""
        return self.BackgroundStyle

    @backgroundstyle.setter
    def backgroundstyle(self, value):
        """Alias for BackgroundStyle.setter"""
        self.BackgroundStyle = value

    @property
    def background_style(self):
        """Alias for BackgroundStyle"""
        return self.BackgroundStyle

    @background_style.setter
    def background_style(self, value):
        """Alias for BackgroundStyle.setter"""
        self.BackgroundStyle = value

    @property
    def BlackWhiteMode(self):
        return self.com_object.BlackWhiteMode

    @BlackWhiteMode.setter
    def BlackWhiteMode(self, value):
        self.com_object.BlackWhiteMode = value

    @property
    def blackwhitemode(self):
        """Alias for BlackWhiteMode"""
        return self.BlackWhiteMode

    @blackwhitemode.setter
    def blackwhitemode(self, value):
        """Alias for BlackWhiteMode.setter"""
        self.BlackWhiteMode = value

    @property
    def black_white_mode(self):
        """Alias for BlackWhiteMode"""
        return self.BlackWhiteMode

    @black_white_mode.setter
    def black_white_mode(self, value):
        """Alias for BlackWhiteMode.setter"""
        self.BlackWhiteMode = value

    @property
    def BottomRightCell(self):
        return Range(self.com_object.BottomRightCell)

    @property
    def bottomrightcell(self):
        """Alias for BottomRightCell"""
        return self.BottomRightCell

    @property
    def bottom_right_cell(self):
        """Alias for BottomRightCell"""
        return self.BottomRightCell

    @property
    def Callout(self):
        return CalloutFormat(self.com_object.Callout)

    @property
    def callout(self):
        """Alias for Callout"""
        return self.Callout

    @property
    def Chart(self):
        return Chart(self.com_object.Chart)

    @property
    def chart(self):
        """Alias for Chart"""
        return self.Chart

    @property
    def Child(self):
        return self.com_object.Child

    @property
    def child(self):
        """Alias for Child"""
        return self.Child

    @property
    def ConnectionSiteCount(self):
        return self.com_object.ConnectionSiteCount

    @property
    def connectionsitecount(self):
        """Alias for ConnectionSiteCount"""
        return self.ConnectionSiteCount

    @property
    def connection_site_count(self):
        """Alias for ConnectionSiteCount"""
        return self.ConnectionSiteCount

    @property
    def Connector(self):
        return self.com_object.Connector

    @property
    def connector(self):
        """Alias for Connector"""
        return self.Connector

    @property
    def ConnectorFormat(self):
        return ConnectorFormat(self.com_object.ConnectorFormat)

    @property
    def connectorformat(self):
        """Alias for ConnectorFormat"""
        return self.ConnectorFormat

    @property
    def connector_format(self):
        """Alias for ConnectorFormat"""
        return self.ConnectorFormat

    @property
    def ControlFormat(self):
        return ControlFormat(self.com_object.ControlFormat)

    @property
    def controlformat(self):
        """Alias for ControlFormat"""
        return self.ControlFormat

    @property
    def control_format(self):
        """Alias for ControlFormat"""
        return self.ControlFormat

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Decorative(self):
        return self.com_object.Decorative

    @Decorative.setter
    def Decorative(self, value):
        self.com_object.Decorative = value

    @property
    def decorative(self):
        """Alias for Decorative"""
        return self.Decorative

    @decorative.setter
    def decorative(self, value):
        """Alias for Decorative.setter"""
        self.Decorative = value

    @property
    def Fill(self):
        return FillFormat(self.com_object.Fill)

    @property
    def fill(self):
        """Alias for Fill"""
        return self.Fill

    @property
    def FormControlType(self):
        return XlFormControl(self.com_object.FormControlType)

    @property
    def formcontroltype(self):
        """Alias for FormControlType"""
        return self.FormControlType

    @property
    def form_control_type(self):
        """Alias for FormControlType"""
        return self.FormControlType

    @property
    def Glow(self):
        return self.com_object.Glow

    @property
    def glow(self):
        """Alias for Glow"""
        return self.Glow

    @property
    def GraphicStyle(self):
        return self.com_object.GraphicStyle

    @GraphicStyle.setter
    def GraphicStyle(self, value):
        self.com_object.GraphicStyle = value

    @property
    def graphicstyle(self):
        """Alias for GraphicStyle"""
        return self.GraphicStyle

    @graphicstyle.setter
    def graphicstyle(self, value):
        """Alias for GraphicStyle.setter"""
        self.GraphicStyle = value

    @property
    def graphic_style(self):
        """Alias for GraphicStyle"""
        return self.GraphicStyle

    @graphic_style.setter
    def graphic_style(self, value):
        """Alias for GraphicStyle.setter"""
        self.GraphicStyle = value

    @property
    def GroupItems(self):
        return GroupShapes(self.com_object.GroupItems)

    @property
    def groupitems(self):
        """Alias for GroupItems"""
        return self.GroupItems

    @property
    def group_items(self):
        """Alias for GroupItems"""
        return self.GroupItems

    @property
    def HasChart(self):
        return self.com_object.HasChart

    @property
    def haschart(self):
        """Alias for HasChart"""
        return self.HasChart

    @property
    def has_chart(self):
        """Alias for HasChart"""
        return self.HasChart

    @property
    def HasSmartArt(self):
        return self.com_object.HasSmartArt

    @property
    def hassmartart(self):
        """Alias for HasSmartArt"""
        return self.HasSmartArt

    @property
    def has_smart_art(self):
        """Alias for HasSmartArt"""
        return self.HasSmartArt

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HorizontalFlip(self):
        return self.com_object.HorizontalFlip

    @property
    def horizontalflip(self):
        """Alias for HorizontalFlip"""
        return self.HorizontalFlip

    @property
    def horizontal_flip(self):
        """Alias for HorizontalFlip"""
        return self.HorizontalFlip

    @property
    def Hyperlink(self):
        return Hyperlink(self.com_object.Hyperlink)

    @property
    def hyperlink(self):
        """Alias for Hyperlink"""
        return self.Hyperlink

    @property
    def ID(self):
        return self.com_object.ID

    @property
    def id(self):
        """Alias for ID"""
        return self.ID

    @property
    def i_d(self):
        """Alias for ID"""
        return self.ID

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Line(self):
        return LineFormat(self.com_object.Line)

    @property
    def line(self):
        """Alias for Line"""
        return self.Line

    @property
    def LinkFormat(self):
        return LinkFormat(self.com_object.LinkFormat)

    @property
    def linkformat(self):
        """Alias for LinkFormat"""
        return self.LinkFormat

    @property
    def link_format(self):
        """Alias for LinkFormat"""
        return self.LinkFormat

    @property
    def LockAspectRatio(self):
        return self.com_object.LockAspectRatio

    @LockAspectRatio.setter
    def LockAspectRatio(self, value):
        self.com_object.LockAspectRatio = value

    @property
    def lockaspectratio(self):
        """Alias for LockAspectRatio"""
        return self.LockAspectRatio

    @lockaspectratio.setter
    def lockaspectratio(self, value):
        """Alias for LockAspectRatio.setter"""
        self.LockAspectRatio = value

    @property
    def lock_aspect_ratio(self):
        """Alias for LockAspectRatio"""
        return self.LockAspectRatio

    @lock_aspect_ratio.setter
    def lock_aspect_ratio(self, value):
        """Alias for LockAspectRatio.setter"""
        self.LockAspectRatio = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def Model3D(self):
        return Model3DFormat(self.com_object.Model3D)

    @property
    def model3d(self):
        """Alias for Model3D"""
        return self.Model3D

    @property
    def model3_d(self):
        """Alias for Model3D"""
        return self.Model3D

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Nodes(self):
        return ShapeNodes(self.com_object.Nodes)

    @property
    def nodes(self):
        """Alias for Nodes"""
        return self.Nodes

    @property
    def OLEFormat(self):
        return OLEFormat(self.com_object.OLEFormat)

    @property
    def oleformat(self):
        """Alias for OLEFormat"""
        return self.OLEFormat

    @property
    def o_l_e_format(self):
        """Alias for OLEFormat"""
        return self.OLEFormat

    @property
    def OnAction(self):
        return self.com_object.OnAction

    @OnAction.setter
    def OnAction(self, value):
        self.com_object.OnAction = value

    @property
    def onaction(self):
        """Alias for OnAction"""
        return self.OnAction

    @onaction.setter
    def onaction(self, value):
        """Alias for OnAction.setter"""
        self.OnAction = value

    @property
    def on_action(self):
        """Alias for OnAction"""
        return self.OnAction

    @on_action.setter
    def on_action(self, value):
        """Alias for OnAction.setter"""
        self.OnAction = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ParentGroup(self):
        return Shape(self.com_object.ParentGroup)

    @property
    def parentgroup(self):
        """Alias for ParentGroup"""
        return self.ParentGroup

    @property
    def parent_group(self):
        """Alias for ParentGroup"""
        return self.ParentGroup

    @property
    def PictureFormat(self):
        return PictureFormat(self.com_object.PictureFormat)

    @property
    def pictureformat(self):
        """Alias for PictureFormat"""
        return self.PictureFormat

    @property
    def picture_format(self):
        """Alias for PictureFormat"""
        return self.PictureFormat

    @property
    def Placement(self):
        return XlPlacement(self.com_object.Placement)

    @Placement.setter
    def Placement(self, value):
        self.com_object.Placement = value

    @property
    def placement(self):
        """Alias for Placement"""
        return self.Placement

    @placement.setter
    def placement(self, value):
        """Alias for Placement.setter"""
        self.Placement = value

    @property
    def Reflection(self):
        return self.com_object.Reflection

    @property
    def reflection(self):
        """Alias for Reflection"""
        return self.Reflection

    @property
    def Rotation(self):
        return self.com_object.Rotation

    @Rotation.setter
    def Rotation(self, value):
        self.com_object.Rotation = value

    @property
    def rotation(self):
        """Alias for Rotation"""
        return self.Rotation

    @rotation.setter
    def rotation(self, value):
        """Alias for Rotation.setter"""
        self.Rotation = value

    @property
    def Shadow(self):
        return ShadowFormat(self.com_object.Shadow)

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @property
    def ShapeStyle(self):
        return self.com_object.ShapeStyle

    @ShapeStyle.setter
    def ShapeStyle(self, value):
        self.com_object.ShapeStyle = value

    @property
    def shapestyle(self):
        """Alias for ShapeStyle"""
        return self.ShapeStyle

    @shapestyle.setter
    def shapestyle(self, value):
        """Alias for ShapeStyle.setter"""
        self.ShapeStyle = value

    @property
    def shape_style(self):
        """Alias for ShapeStyle"""
        return self.ShapeStyle

    @shape_style.setter
    def shape_style(self, value):
        """Alias for ShapeStyle.setter"""
        self.ShapeStyle = value

    @property
    def SmartArt(self):
        return self.com_object.SmartArt

    @property
    def smartart(self):
        """Alias for SmartArt"""
        return self.SmartArt

    @property
    def smart_art(self):
        """Alias for SmartArt"""
        return self.SmartArt

    @property
    def SoftEdge(self):
        return self.com_object.SoftEdge

    @property
    def softedge(self):
        """Alias for SoftEdge"""
        return self.SoftEdge

    @property
    def soft_edge(self):
        """Alias for SoftEdge"""
        return self.SoftEdge

    @property
    def TextEffect(self):
        return TextEffectFormat(self.com_object.TextEffect)

    @property
    def texteffect(self):
        """Alias for TextEffect"""
        return self.TextEffect

    @property
    def text_effect(self):
        """Alias for TextEffect"""
        return self.TextEffect

    @property
    def TextFrame(self):
        return TextFrame(self.com_object.TextFrame)

    @property
    def textframe(self):
        """Alias for TextFrame"""
        return self.TextFrame

    @property
    def text_frame(self):
        """Alias for TextFrame"""
        return self.TextFrame

    @property
    def TextFrame2(self):
        return TextFrame2(self.com_object.TextFrame2)

    @property
    def textframe2(self):
        """Alias for TextFrame2"""
        return self.TextFrame2

    @property
    def text_frame2(self):
        """Alias for TextFrame2"""
        return self.TextFrame2

    @property
    def ThreeD(self):
        return ThreeDFormat(self.com_object.ThreeD)

    @property
    def threed(self):
        """Alias for ThreeD"""
        return self.ThreeD

    @property
    def three_d(self):
        """Alias for ThreeD"""
        return self.ThreeD

    @property
    def Title(self):
        return self.com_object.Title

    @Title.setter
    def Title(self, value):
        self.com_object.Title = value

    @property
    def title(self):
        """Alias for Title"""
        return self.Title

    @title.setter
    def title(self, value):
        """Alias for Title.setter"""
        self.Title = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TopLeftCell(self):
        return Range(self.com_object.TopLeftCell)

    @property
    def topleftcell(self):
        """Alias for TopLeftCell"""
        return self.TopLeftCell

    @property
    def top_left_cell(self):
        """Alias for TopLeftCell"""
        return self.TopLeftCell

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    @property
    def VerticalFlip(self):
        return self.com_object.VerticalFlip

    @property
    def verticalflip(self):
        """Alias for VerticalFlip"""
        return self.VerticalFlip

    @property
    def vertical_flip(self):
        """Alias for VerticalFlip"""
        return self.VerticalFlip

    @property
    def Vertices(self):
        return self.com_object.Vertices

    @property
    def vertices(self):
        """Alias for Vertices"""
        return self.Vertices

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def ZOrderPosition(self):
        return self.com_object.ZOrderPosition

    @property
    def zorderposition(self):
        """Alias for ZOrderPosition"""
        return self.ZOrderPosition

    @property
    def z_order_position(self):
        """Alias for ZOrderPosition"""
        return self.ZOrderPosition

    def Apply(self):
        self.com_object.Apply()

    def apply(self):
        """Alias for Apply"""
        return self.Apply()

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def CopyPicture(self, Appearance=None, Format=None):
        arguments = com_arguments([unwrap(a) for a in [Appearance, Format]])
        self.com_object.CopyPicture(*arguments)

    def copypicture(self, Appearance=None, Format=None):
        """Alias for CopyPicture"""
        arguments = [Appearance, Format]
        return self.CopyPicture(*arguments)

    def copy_picture(self, Appearance=None, Format=None):
        """Alias for CopyPicture"""
        arguments = [Appearance, Format]
        return self.CopyPicture(*arguments)

    def Cut(self):
        return self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Duplicate(self):
        return Shape(self.com_object.Duplicate())

    def duplicate(self):
        """Alias for Duplicate"""
        return self.Duplicate()

    def Flip(self, FlipCmd=None):
        arguments = com_arguments([unwrap(a) for a in [FlipCmd]])
        self.com_object.Flip(*arguments)

    def flip(self, FlipCmd=None):
        """Alias for Flip"""
        arguments = [FlipCmd]
        return self.Flip(*arguments)

    def IncrementLeft(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementLeft(*arguments)

    def incrementleft(self, Increment=None):
        """Alias for IncrementLeft"""
        arguments = [Increment]
        return self.IncrementLeft(*arguments)

    def increment_left(self, Increment=None):
        """Alias for IncrementLeft"""
        arguments = [Increment]
        return self.IncrementLeft(*arguments)

    def IncrementRotation(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotation(*arguments)

    def incrementrotation(self, Increment=None):
        """Alias for IncrementRotation"""
        arguments = [Increment]
        return self.IncrementRotation(*arguments)

    def increment_rotation(self, Increment=None):
        """Alias for IncrementRotation"""
        arguments = [Increment]
        return self.IncrementRotation(*arguments)

    def IncrementTop(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementTop(*arguments)

    def incrementtop(self, Increment=None):
        """Alias for IncrementTop"""
        arguments = [Increment]
        return self.IncrementTop(*arguments)

    def increment_top(self, Increment=None):
        """Alias for IncrementTop"""
        arguments = [Increment]
        return self.IncrementTop(*arguments)

    def PickUp(self):
        self.com_object.PickUp()

    def pickup(self):
        """Alias for PickUp"""
        return self.PickUp()

    def pick_up(self):
        """Alias for PickUp"""
        return self.PickUp()

    def RerouteConnections(self):
        self.com_object.RerouteConnections()

    def rerouteconnections(self):
        """Alias for RerouteConnections"""
        return self.RerouteConnections()

    def reroute_connections(self):
        """Alias for RerouteConnections"""
        return self.RerouteConnections()

    def ScaleHeight(self, Factor=None, RelativeToOriginalSize=None, Scale=None):
        arguments = com_arguments([unwrap(a) for a in [Factor, RelativeToOriginalSize, Scale]])
        self.com_object.ScaleHeight(*arguments)

    def scaleheight(self, Factor=None, RelativeToOriginalSize=None, Scale=None):
        """Alias for ScaleHeight"""
        arguments = [Factor, RelativeToOriginalSize, Scale]
        return self.ScaleHeight(*arguments)

    def scale_height(self, Factor=None, RelativeToOriginalSize=None, Scale=None):
        """Alias for ScaleHeight"""
        arguments = [Factor, RelativeToOriginalSize, Scale]
        return self.ScaleHeight(*arguments)

    def ScaleWidth(self, Factor=None, RelativeToOriginalSize=None, Scale=None):
        arguments = com_arguments([unwrap(a) for a in [Factor, RelativeToOriginalSize, Scale]])
        self.com_object.ScaleWidth(*arguments)

    def scalewidth(self, Factor=None, RelativeToOriginalSize=None, Scale=None):
        """Alias for ScaleWidth"""
        arguments = [Factor, RelativeToOriginalSize, Scale]
        return self.ScaleWidth(*arguments)

    def scale_width(self, Factor=None, RelativeToOriginalSize=None, Scale=None):
        """Alias for ScaleWidth"""
        arguments = [Factor, RelativeToOriginalSize, Scale]
        return self.ScaleWidth(*arguments)

    def Select(self, Replace=None):
        arguments = com_arguments([unwrap(a) for a in [Replace]])
        self.com_object.Select(*arguments)

    def select(self, Replace=None):
        """Alias for Select"""
        arguments = [Replace]
        return self.Select(*arguments)

    def SetShapesDefaultProperties(self):
        self.com_object.SetShapesDefaultProperties()

    def setshapesdefaultproperties(self):
        """Alias for SetShapesDefaultProperties"""
        return self.SetShapesDefaultProperties()

    def set_shapes_default_properties(self):
        """Alias for SetShapesDefaultProperties"""
        return self.SetShapesDefaultProperties()

    def Ungroup(self):
        return ShapeRange(self.com_object.Ungroup())

    def ungroup(self):
        """Alias for Ungroup"""
        return self.Ungroup()

    def ZOrder(self, ZOrderCmd=None):
        arguments = com_arguments([unwrap(a) for a in [ZOrderCmd]])
        self.com_object.ZOrder(*arguments)

    def zorder(self, ZOrderCmd=None):
        """Alias for ZOrder"""
        arguments = [ZOrderCmd]
        return self.ZOrder(*arguments)

    def z_order(self, ZOrderCmd=None):
        """Alias for ZOrder"""
        arguments = [ZOrderCmd]
        return self.ZOrder(*arguments)


class ShapeNode:

    def __init__(self, shapenode=None):
        self.com_object= shapenode

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def EditingType(self):
        return self.com_object.EditingType

    @property
    def editingtype(self):
        """Alias for EditingType"""
        return self.EditingType

    @property
    def editing_type(self):
        """Alias for EditingType"""
        return self.EditingType

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Points(self):
        return self.com_object.Points

    @property
    def points(self):
        """Alias for Points"""
        return self.Points

    @property
    def SegmentType(self):
        return self.com_object.SegmentType

    @property
    def segmenttype(self):
        """Alias for SegmentType"""
        return self.SegmentType

    @property
    def segment_type(self):
        """Alias for SegmentType"""
        return self.SegmentType


class ShapeNodes:

    def __init__(self, shapenodes=None):
        self.com_object= shapenodes

    def __call__(self, item):
        return ShapeNode(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.Delete(*arguments)

    def delete(self, Index=None):
        """Alias for Delete"""
        arguments = [Index]
        return self.Delete(*arguments)

    def Insert(self, Index=None, SegmentType=None, EditingType=None, X1=None, Y1=None, X2=None, Y2=None, X3=None, Y3=None):
        arguments = com_arguments([unwrap(a) for a in [Index, SegmentType, EditingType, X1, Y1, X2, Y2, X3, Y3]])
        self.com_object.Insert(*arguments)

    def insert(self, Index=None, SegmentType=None, EditingType=None, X1=None, Y1=None, X2=None, Y2=None, X3=None, Y3=None):
        """Alias for Insert"""
        arguments = [Index, SegmentType, EditingType, X1, Y1, X2, Y2, X3, Y3]
        return self.Insert(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return ShapeNode(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def SetEditingType(self, Index=None, EditingType=None):
        arguments = com_arguments([unwrap(a) for a in [Index, EditingType]])
        self.com_object.SetEditingType(*arguments)

    def seteditingtype(self, Index=None, EditingType=None):
        """Alias for SetEditingType"""
        arguments = [Index, EditingType]
        return self.SetEditingType(*arguments)

    def set_editing_type(self, Index=None, EditingType=None):
        """Alias for SetEditingType"""
        arguments = [Index, EditingType]
        return self.SetEditingType(*arguments)

    def SetPosition(self, Index=None, X1=None, Y1=None):
        arguments = com_arguments([unwrap(a) for a in [Index, X1, Y1]])
        self.com_object.SetPosition(*arguments)

    def setposition(self, Index=None, X1=None, Y1=None):
        """Alias for SetPosition"""
        arguments = [Index, X1, Y1]
        return self.SetPosition(*arguments)

    def set_position(self, Index=None, X1=None, Y1=None):
        """Alias for SetPosition"""
        arguments = [Index, X1, Y1]
        return self.SetPosition(*arguments)

    def SetSegmentType(self, Index=None, SegmentType=None):
        arguments = com_arguments([unwrap(a) for a in [Index, SegmentType]])
        self.com_object.SetSegmentType(*arguments)

    def setsegmenttype(self, Index=None, SegmentType=None):
        """Alias for SetSegmentType"""
        arguments = [Index, SegmentType]
        return self.SetSegmentType(*arguments)

    def set_segment_type(self, Index=None, SegmentType=None):
        """Alias for SetSegmentType"""
        arguments = [Index, SegmentType]
        return self.SetSegmentType(*arguments)


class Shapes:

    def __init__(self, shapes=None):
        self.com_object= shapes

    def __call__(self, item):
        return Shape(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Range(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetRange"):
            return ShapeRange(self.com_object.GetRange(*arguments))
        else:
            return ShapeRange(self.com_object.Range(*arguments))

    def range(self, Index=None):
        """Alias for Range"""
        arguments = [Index]
        return self.Range(*arguments)

    def Add3DModel(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height]])
        return Shape(self.com_object.Add3DModel(*arguments))

    def add3dmodel(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for Add3DModel"""
        arguments = [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height]
        return self.Add3DModel(*arguments)

    def add3_d_model(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for Add3DModel"""
        arguments = [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height]
        return self.Add3DModel(*arguments)

    def AddCallout(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Left, Top, Width, Height]])
        return Shape(self.com_object.AddCallout(*arguments))

    def addcallout(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddCallout"""
        arguments = [Type, Left, Top, Width, Height]
        return self.AddCallout(*arguments)

    def add_callout(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddCallout"""
        arguments = [Type, Left, Top, Width, Height]
        return self.AddCallout(*arguments)

    def AddChart2(self, Style=None, XlChartType=None, Left=None, Top=None, Width=None, Height=None, NewLayout=None):
        arguments = com_arguments([unwrap(a) for a in [Style, XlChartType, Left, Top, Width, Height, NewLayout]])
        return Shape(self.com_object.AddChart2(*arguments))

    def addchart2(self, Style=None, XlChartType=None, Left=None, Top=None, Width=None, Height=None, NewLayout=None):
        """Alias for AddChart2"""
        arguments = [Style, XlChartType, Left, Top, Width, Height, NewLayout]
        return self.AddChart2(*arguments)

    def add_chart2(self, Style=None, XlChartType=None, Left=None, Top=None, Width=None, Height=None, NewLayout=None):
        """Alias for AddChart2"""
        arguments = [Style, XlChartType, Left, Top, Width, Height, NewLayout]
        return self.AddChart2(*arguments)

    def AddConnector(self, Type=None, BeginX=None, BeginY=None, EndX=None, EndY=None):
        arguments = com_arguments([unwrap(a) for a in [Type, BeginX, BeginY, EndX, EndY]])
        return Shape(self.com_object.AddConnector(*arguments))

    def addconnector(self, Type=None, BeginX=None, BeginY=None, EndX=None, EndY=None):
        """Alias for AddConnector"""
        arguments = [Type, BeginX, BeginY, EndX, EndY]
        return self.AddConnector(*arguments)

    def add_connector(self, Type=None, BeginX=None, BeginY=None, EndX=None, EndY=None):
        """Alias for AddConnector"""
        arguments = [Type, BeginX, BeginY, EndX, EndY]
        return self.AddConnector(*arguments)

    def AddCurve(self, SafeArrayOfPoints=None):
        arguments = com_arguments([unwrap(a) for a in [SafeArrayOfPoints]])
        return Shape(self.com_object.AddCurve(*arguments))

    def addcurve(self, SafeArrayOfPoints=None):
        """Alias for AddCurve"""
        arguments = [SafeArrayOfPoints]
        return self.AddCurve(*arguments)

    def add_curve(self, SafeArrayOfPoints=None):
        """Alias for AddCurve"""
        arguments = [SafeArrayOfPoints]
        return self.AddCurve(*arguments)

    def AddFormControl(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Left, Top, Width, Height]])
        return Shape(self.com_object.AddFormControl(*arguments))

    def addformcontrol(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddFormControl"""
        arguments = [Type, Left, Top, Width, Height]
        return self.AddFormControl(*arguments)

    def add_form_control(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddFormControl"""
        arguments = [Type, Left, Top, Width, Height]
        return self.AddFormControl(*arguments)

    def AddLabel(self, Orientation=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Orientation, Left, Top, Width, Height]])
        return Shape(self.com_object.AddLabel(*arguments))

    def addlabel(self, Orientation=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddLabel"""
        arguments = [Orientation, Left, Top, Width, Height]
        return self.AddLabel(*arguments)

    def add_label(self, Orientation=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddLabel"""
        arguments = [Orientation, Left, Top, Width, Height]
        return self.AddLabel(*arguments)

    def AddLine(self, BeginX=None, BeginY=None, EndX=None, EndY=None):
        arguments = com_arguments([unwrap(a) for a in [BeginX, BeginY, EndX, EndY]])
        return Shape(self.com_object.AddLine(*arguments))

    def addline(self, BeginX=None, BeginY=None, EndX=None, EndY=None):
        """Alias for AddLine"""
        arguments = [BeginX, BeginY, EndX, EndY]
        return self.AddLine(*arguments)

    def add_line(self, BeginX=None, BeginY=None, EndX=None, EndY=None):
        """Alias for AddLine"""
        arguments = [BeginX, BeginY, EndX, EndY]
        return self.AddLine(*arguments)

    def AddOLEObject(self, ClassType=None, FileName=None, Link=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [ClassType, FileName, Link, DisplayAsIcon, IconFileName, IconIndex, IconLabel, Left, Top, Width, Height]])
        return Shape(self.com_object.AddOLEObject(*arguments))

    def addoleobject(self, ClassType=None, FileName=None, Link=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddOLEObject"""
        arguments = [ClassType, FileName, Link, DisplayAsIcon, IconFileName, IconIndex, IconLabel, Left, Top, Width, Height]
        return self.AddOLEObject(*arguments)

    def add_o_l_e_object(self, ClassType=None, FileName=None, Link=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddOLEObject"""
        arguments = [ClassType, FileName, Link, DisplayAsIcon, IconFileName, IconIndex, IconLabel, Left, Top, Width, Height]
        return self.AddOLEObject(*arguments)

    def AddPicture(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height]])
        return Shape(self.com_object.AddPicture(*arguments))

    def addpicture(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddPicture"""
        arguments = [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height]
        return self.AddPicture(*arguments)

    def add_picture(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddPicture"""
        arguments = [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height]
        return self.AddPicture(*arguments)

    def AddPicture2(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None, compress=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height, compress]])
        return Shape(self.com_object.AddPicture2(*arguments))

    def addpicture2(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None, compress=None):
        """Alias for AddPicture2"""
        arguments = [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height, compress]
        return self.AddPicture2(*arguments)

    def add_picture2(self, FileName=None, LinkToFile=None, SaveWithDocument=None, Left=None, Top=None, Width=None, Height=None, compress=None):
        """Alias for AddPicture2"""
        arguments = [FileName, LinkToFile, SaveWithDocument, Left, Top, Width, Height, compress]
        return self.AddPicture2(*arguments)

    def AddPolyline(self, SafeArrayOfPoints=None):
        arguments = com_arguments([unwrap(a) for a in [SafeArrayOfPoints]])
        return Shape(self.com_object.AddPolyline(*arguments))

    def addpolyline(self, SafeArrayOfPoints=None):
        """Alias for AddPolyline"""
        arguments = [SafeArrayOfPoints]
        return self.AddPolyline(*arguments)

    def add_polyline(self, SafeArrayOfPoints=None):
        """Alias for AddPolyline"""
        arguments = [SafeArrayOfPoints]
        return self.AddPolyline(*arguments)

    def AddShape(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Left, Top, Width, Height]])
        return Shape(self.com_object.AddShape(*arguments))

    def addshape(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddShape"""
        arguments = [Type, Left, Top, Width, Height]
        return self.AddShape(*arguments)

    def add_shape(self, Type=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddShape"""
        arguments = [Type, Left, Top, Width, Height]
        return self.AddShape(*arguments)

    def AddSmartArt(self, Layout=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Layout, Left, Top, Width, Height]])
        return Shape(self.com_object.AddSmartArt(*arguments))

    def addsmartart(self, Layout=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddSmartArt"""
        arguments = [Layout, Left, Top, Width, Height]
        return self.AddSmartArt(*arguments)

    def add_smart_art(self, Layout=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddSmartArt"""
        arguments = [Layout, Left, Top, Width, Height]
        return self.AddSmartArt(*arguments)

    def AddTextbox(self, Orientation=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Orientation, Left, Top, Width, Height]])
        return Shape(self.com_object.AddTextbox(*arguments))

    def addtextbox(self, Orientation=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddTextbox"""
        arguments = [Orientation, Left, Top, Width, Height]
        return self.AddTextbox(*arguments)

    def add_textbox(self, Orientation=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for AddTextbox"""
        arguments = [Orientation, Left, Top, Width, Height]
        return self.AddTextbox(*arguments)

    def AddTextEffect(self, PresetTextEffect=None, Text=None, FontName=None, FontSize=None, FontBold=None, FontItalic=None, Left=None, Top=None):
        arguments = com_arguments([unwrap(a) for a in [PresetTextEffect, Text, FontName, FontSize, FontBold, FontItalic, Left, Top]])
        return Shape(self.com_object.AddTextEffect(*arguments))

    def addtexteffect(self, PresetTextEffect=None, Text=None, FontName=None, FontSize=None, FontBold=None, FontItalic=None, Left=None, Top=None):
        """Alias for AddTextEffect"""
        arguments = [PresetTextEffect, Text, FontName, FontSize, FontBold, FontItalic, Left, Top]
        return self.AddTextEffect(*arguments)

    def add_text_effect(self, PresetTextEffect=None, Text=None, FontName=None, FontSize=None, FontBold=None, FontItalic=None, Left=None, Top=None):
        """Alias for AddTextEffect"""
        arguments = [PresetTextEffect, Text, FontName, FontSize, FontBold, FontItalic, Left, Top]
        return self.AddTextEffect(*arguments)

    def BuildFreeform(self, EditingType=None, X1=None, Y1=None):
        arguments = com_arguments([unwrap(a) for a in [EditingType, X1, Y1]])
        return FreeformBuilder(self.com_object.BuildFreeform(*arguments))

    def buildfreeform(self, EditingType=None, X1=None, Y1=None):
        """Alias for BuildFreeform"""
        arguments = [EditingType, X1, Y1]
        return self.BuildFreeform(*arguments)

    def build_freeform(self, EditingType=None, X1=None, Y1=None):
        """Alias for BuildFreeform"""
        arguments = [EditingType, X1, Y1]
        return self.BuildFreeform(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Shape(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def SelectAll(self):
        self.com_object.SelectAll()

    def selectall(self):
        """Alias for SelectAll"""
        return self.SelectAll()

    def select_all(self):
        """Alias for SelectAll"""
        return self.SelectAll()


class Sheets:

    def __init__(self, sheets=None):
        self.com_object= sheets

    def __call__(self, item):
        return Sheet(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def HPageBreaks(self):
        return HPageBreaks(self.com_object.HPageBreaks)

    @property
    def hpagebreaks(self):
        """Alias for HPageBreaks"""
        return self.HPageBreaks

    @property
    def h_page_breaks(self):
        """Alias for HPageBreaks"""
        return self.HPageBreaks

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def VPageBreaks(self):
        return VPageBreaks(self.com_object.VPageBreaks)

    @property
    def vpagebreaks(self):
        """Alias for VPageBreaks"""
        return self.VPageBreaks

    @property
    def v_page_breaks(self):
        """Alias for VPageBreaks"""
        return self.VPageBreaks

    def Add(self, Before=None, After=None, Count=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Before, After, Count, Type]])
        return Sheet(self.com_object.Add(*arguments))

    def add(self, Before=None, After=None, Count=None, Type=None):
        """Alias for Add"""
        arguments = [Before, After, Count, Type]
        return self.Add(*arguments)

    def Add2(self, Before=None, After=None, Count=None, NewLayout=None):
        arguments = com_arguments([unwrap(a) for a in [Before, After, Count, NewLayout]])
        return self.com_object.Add2(*arguments)

    def add2(self, Before=None, After=None, Count=None, NewLayout=None):
        """Alias for Add2"""
        arguments = [Before, After, Count, NewLayout]
        return self.Add2(*arguments)

    def Copy(self, Before=None, After=None):
        arguments = com_arguments([unwrap(a) for a in [Before, After]])
        self.com_object.Copy(*arguments)

    def copy(self, Before=None, After=None):
        """Alias for Copy"""
        arguments = [Before, After]
        return self.Copy(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def FillAcrossSheets(self, Range=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Range, Type]])
        self.com_object.FillAcrossSheets(*arguments)

    def fillacrosssheets(self, Range=None, Type=None):
        """Alias for FillAcrossSheets"""
        arguments = [Range, Type]
        return self.FillAcrossSheets(*arguments)

    def fill_across_sheets(self, Range=None, Type=None):
        """Alias for FillAcrossSheets"""
        arguments = [Range, Type]
        return self.FillAcrossSheets(*arguments)

    def Move(self, Before=None, After=None):
        arguments = com_arguments([unwrap(a) for a in [Before, After]])
        self.com_object.Move(*arguments)

    def move(self, Before=None, After=None):
        """Alias for Move"""
        arguments = [Before, After]
        return self.Move(*arguments)

    def PrintOut(self, From=None, To=None, Copies=None, Preview=None, ActivePrinter=None, PrintToFile=None, Collate=None, PrToFileName=None, IgnorePrintAreas=None):
        arguments = com_arguments([unwrap(a) for a in [From, To, Copies, Preview, ActivePrinter, PrintToFile, Collate, PrToFileName, IgnorePrintAreas]])
        return self.com_object.PrintOut(*arguments)

    def printout(self, From=None, To=None, Copies=None, Preview=None, ActivePrinter=None, PrintToFile=None, Collate=None, PrToFileName=None, IgnorePrintAreas=None):
        """Alias for PrintOut"""
        arguments = [From, To, Copies, Preview, ActivePrinter, PrintToFile, Collate, PrToFileName, IgnorePrintAreas]
        return self.PrintOut(*arguments)

    def print_out(self, From=None, To=None, Copies=None, Preview=None, ActivePrinter=None, PrintToFile=None, Collate=None, PrToFileName=None, IgnorePrintAreas=None):
        """Alias for PrintOut"""
        arguments = [From, To, Copies, Preview, ActivePrinter, PrintToFile, Collate, PrToFileName, IgnorePrintAreas]
        return self.PrintOut(*arguments)

    def PrintPreview(self, EnableChanges=None):
        arguments = com_arguments([unwrap(a) for a in [EnableChanges]])
        self.com_object.PrintPreview(*arguments)

    def printpreview(self, EnableChanges=None):
        """Alias for PrintPreview"""
        arguments = [EnableChanges]
        return self.PrintPreview(*arguments)

    def print_preview(self, EnableChanges=None):
        """Alias for PrintPreview"""
        arguments = [EnableChanges]
        return self.PrintPreview(*arguments)

    def Select(self, Replace=None):
        arguments = com_arguments([unwrap(a) for a in [Replace]])
        self.com_object.Select(*arguments)

    def select(self, Replace=None):
        """Alias for Select"""
        arguments = [Replace]
        return self.Select(*arguments)


class SheetViews:

    def __init__(self, sheetviews=None):
        self.com_object= sheetviews

    def __call__(self, item):
        return SheetView(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class Slicer:

    def __init__(self, slicer=None):
        self.com_object= slicer

    @property
    def ActiveItem(self):
        return SlicerItem(self.com_object.ActiveItem)

    @property
    def activeitem(self):
        """Alias for ActiveItem"""
        return self.ActiveItem

    @property
    def active_item(self):
        """Alias for ActiveItem"""
        return self.ActiveItem

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    @property
    def ColumnWidth(self):
        return self.com_object.ColumnWidth

    @ColumnWidth.setter
    def ColumnWidth(self, value):
        self.com_object.ColumnWidth = value

    @property
    def columnwidth(self):
        """Alias for ColumnWidth"""
        return self.ColumnWidth

    @columnwidth.setter
    def columnwidth(self, value):
        """Alias for ColumnWidth.setter"""
        self.ColumnWidth = value

    @property
    def column_width(self):
        """Alias for ColumnWidth"""
        return self.ColumnWidth

    @column_width.setter
    def column_width(self, value):
        """Alias for ColumnWidth.setter"""
        self.ColumnWidth = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DisableMoveResizeUI(self):
        return self.com_object.DisableMoveResizeUI

    @DisableMoveResizeUI.setter
    def DisableMoveResizeUI(self, value):
        self.com_object.DisableMoveResizeUI = value

    @property
    def disablemoveresizeui(self):
        """Alias for DisableMoveResizeUI"""
        return self.DisableMoveResizeUI

    @disablemoveresizeui.setter
    def disablemoveresizeui(self, value):
        """Alias for DisableMoveResizeUI.setter"""
        self.DisableMoveResizeUI = value

    @property
    def disable_move_resize_u_i(self):
        """Alias for DisableMoveResizeUI"""
        return self.DisableMoveResizeUI

    @disable_move_resize_u_i.setter
    def disable_move_resize_u_i(self, value):
        """Alias for DisableMoveResizeUI.setter"""
        self.DisableMoveResizeUI = value

    @property
    def DisplayHeader(self):
        return Caption(self.com_object.DisplayHeader)

    @DisplayHeader.setter
    def DisplayHeader(self, value):
        self.com_object.DisplayHeader = value

    @property
    def displayheader(self):
        """Alias for DisplayHeader"""
        return self.DisplayHeader

    @displayheader.setter
    def displayheader(self, value):
        """Alias for DisplayHeader.setter"""
        self.DisplayHeader = value

    @property
    def display_header(self):
        """Alias for DisplayHeader"""
        return self.DisplayHeader

    @display_header.setter
    def display_header(self, value):
        """Alias for DisplayHeader.setter"""
        self.DisplayHeader = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def NumberOfColumns(self):
        return self.com_object.NumberOfColumns

    @NumberOfColumns.setter
    def NumberOfColumns(self, value):
        self.com_object.NumberOfColumns = value

    @property
    def numberofcolumns(self):
        """Alias for NumberOfColumns"""
        return self.NumberOfColumns

    @numberofcolumns.setter
    def numberofcolumns(self, value):
        """Alias for NumberOfColumns.setter"""
        self.NumberOfColumns = value

    @property
    def number_of_columns(self):
        """Alias for NumberOfColumns"""
        return self.NumberOfColumns

    @number_of_columns.setter
    def number_of_columns(self, value):
        """Alias for NumberOfColumns.setter"""
        self.NumberOfColumns = value

    @property
    def Parent(self):
        return Worksheet(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RowHeight(self):
        return self.com_object.RowHeight

    @RowHeight.setter
    def RowHeight(self, value):
        self.com_object.RowHeight = value

    @property
    def rowheight(self):
        """Alias for RowHeight"""
        return self.RowHeight

    @rowheight.setter
    def rowheight(self, value):
        """Alias for RowHeight.setter"""
        self.RowHeight = value

    @property
    def row_height(self):
        """Alias for RowHeight"""
        return self.RowHeight

    @row_height.setter
    def row_height(self, value):
        """Alias for RowHeight.setter"""
        self.RowHeight = value

    @property
    def Shape(self):
        return Shape(self.com_object.Shape)

    @property
    def shape(self):
        """Alias for Shape"""
        return self.Shape

    @property
    def SlicerCache(self):
        return SlicerCache(self.com_object.SlicerCache)

    @property
    def slicercache(self):
        """Alias for SlicerCache"""
        return self.SlicerCache

    @property
    def slicer_cache(self):
        """Alias for SlicerCache"""
        return self.SlicerCache

    @property
    def SlicerCacheLevel(self):
        return SlicerCacheLevel(self.com_object.SlicerCacheLevel)

    @property
    def slicercachelevel(self):
        """Alias for SlicerCacheLevel"""
        return self.SlicerCacheLevel

    @property
    def slicer_cache_level(self):
        """Alias for SlicerCacheLevel"""
        return self.SlicerCacheLevel

    @property
    def SlicerCacheType(self):
        return XlSlicerCacheType(self.com_object.SlicerCacheType)

    @property
    def slicercachetype(self):
        """Alias for SlicerCacheType"""
        return self.SlicerCacheType

    @property
    def slicer_cache_type(self):
        """Alias for SlicerCacheType"""
        return self.SlicerCacheType

    @property
    def Style(self):
        return self.com_object.Style

    @Style.setter
    def Style(self, value):
        self.com_object.Style = value

    @property
    def style(self):
        """Alias for Style"""
        return self.Style

    @style.setter
    def style(self, value):
        """Alias for Style.setter"""
        self.Style = value

    @property
    def TimelineViewState(self):
        return self.com_object.TimelineViewState

    @property
    def timelineviewstate(self):
        """Alias for TimelineViewState"""
        return self.TimelineViewState

    @property
    def timeline_view_state(self):
        """Alias for TimelineViewState"""
        return self.TimelineViewState

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Copy(self):
        self.com_object.Copy()

    def copy(self):
        """Alias for Copy"""
        return self.Copy()

    def Cut(self):
        self.com_object.Cut()

    def cut(self):
        """Alias for Cut"""
        return self.Cut()

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class SlicerCache:

    def __init__(self, slicercache=None):
        self.com_object= slicercache

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def CrossFilterType(self):
        return self.com_object.CrossFilterType

    @CrossFilterType.setter
    def CrossFilterType(self, value):
        self.com_object.CrossFilterType = value

    @property
    def crossfiltertype(self):
        """Alias for CrossFilterType"""
        return self.CrossFilterType

    @crossfiltertype.setter
    def crossfiltertype(self, value):
        """Alias for CrossFilterType.setter"""
        self.CrossFilterType = value

    @property
    def cross_filter_type(self):
        """Alias for CrossFilterType"""
        return self.CrossFilterType

    @cross_filter_type.setter
    def cross_filter_type(self, value):
        """Alias for CrossFilterType.setter"""
        self.CrossFilterType = value

    @property
    def FilterCleared(self):
        return self.com_object.FilterCleared

    @property
    def filtercleared(self):
        """Alias for FilterCleared"""
        return self.FilterCleared

    @property
    def filter_cleared(self):
        """Alias for FilterCleared"""
        return self.FilterCleared

    @property
    def Index(self):
        return SlicerCaches(self.com_object.Index)

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def List(self):
        return self.com_object.List

    @property
    def list(self):
        """Alias for List"""
        return self.List

    @property
    def ListObject(self):
        return ListObject(self.com_object.ListObject)

    @property
    def listobject(self):
        """Alias for ListObject"""
        return self.ListObject

    @property
    def list_object(self):
        """Alias for ListObject"""
        return self.ListObject

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def OLAP(self):
        return self.com_object.OLAP

    @property
    def olap(self):
        """Alias for OLAP"""
        return self.OLAP

    @property
    def o_l_a_p(self):
        """Alias for OLAP"""
        return self.OLAP

    @property
    def Parent(self):
        return SlicerCaches(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PivotTables(self):
        return SlicerPivotTables(self.com_object.PivotTables)

    @property
    def pivottables(self):
        """Alias for PivotTables"""
        return self.PivotTables

    @property
    def pivot_tables(self):
        """Alias for PivotTables"""
        return self.PivotTables

    @property
    def RequireManualUpdate(self):
        return self.com_object.RequireManualUpdate

    @RequireManualUpdate.setter
    def RequireManualUpdate(self, value):
        self.com_object.RequireManualUpdate = value

    @property
    def requiremanualupdate(self):
        """Alias for RequireManualUpdate"""
        return self.RequireManualUpdate

    @requiremanualupdate.setter
    def requiremanualupdate(self, value):
        """Alias for RequireManualUpdate.setter"""
        self.RequireManualUpdate = value

    @property
    def require_manual_update(self):
        """Alias for RequireManualUpdate"""
        return self.RequireManualUpdate

    @require_manual_update.setter
    def require_manual_update(self, value):
        """Alias for RequireManualUpdate.setter"""
        self.RequireManualUpdate = value

    @property
    def ShowAllItems(self):
        return self.com_object.ShowAllItems

    @ShowAllItems.setter
    def ShowAllItems(self, value):
        self.com_object.ShowAllItems = value

    @property
    def showallitems(self):
        """Alias for ShowAllItems"""
        return self.ShowAllItems

    @showallitems.setter
    def showallitems(self, value):
        """Alias for ShowAllItems.setter"""
        self.ShowAllItems = value

    @property
    def show_all_items(self):
        """Alias for ShowAllItems"""
        return self.ShowAllItems

    @show_all_items.setter
    def show_all_items(self, value):
        """Alias for ShowAllItems.setter"""
        self.ShowAllItems = value

    @property
    def SlicerCacheLevels(self):
        return SlicerCacheLevel(self.com_object.SlicerCacheLevels)

    @property
    def slicercachelevels(self):
        """Alias for SlicerCacheLevels"""
        return self.SlicerCacheLevels

    @property
    def slicer_cache_levels(self):
        """Alias for SlicerCacheLevels"""
        return self.SlicerCacheLevels

    @property
    def SlicerCacheType(self):
        return XlSlicerCacheType(self.com_object.SlicerCacheType)

    @property
    def slicercachetype(self):
        """Alias for SlicerCacheType"""
        return self.SlicerCacheType

    @property
    def slicer_cache_type(self):
        """Alias for SlicerCacheType"""
        return self.SlicerCacheType

    @property
    def SlicerItems(self):
        return SlicerItems(self.com_object.SlicerItems)

    @property
    def sliceritems(self):
        """Alias for SlicerItems"""
        return self.SlicerItems

    @property
    def slicer_items(self):
        """Alias for SlicerItems"""
        return self.SlicerItems

    @property
    def Slicers(self):
        return Slicers(self.com_object.Slicers)

    @property
    def slicers(self):
        """Alias for Slicers"""
        return self.Slicers

    @property
    def SortItems(self):
        return XlSlicerSort(self.com_object.SortItems)

    @SortItems.setter
    def SortItems(self, value):
        self.com_object.SortItems = value

    @property
    def sortitems(self):
        """Alias for SortItems"""
        return self.SortItems

    @sortitems.setter
    def sortitems(self, value):
        """Alias for SortItems.setter"""
        self.SortItems = value

    @property
    def sort_items(self):
        """Alias for SortItems"""
        return self.SortItems

    @sort_items.setter
    def sort_items(self, value):
        """Alias for SortItems.setter"""
        self.SortItems = value

    @property
    def SortUsingCustomLists(self):
        return self.com_object.SortUsingCustomLists

    @SortUsingCustomLists.setter
    def SortUsingCustomLists(self, value):
        self.com_object.SortUsingCustomLists = value

    @property
    def sortusingcustomlists(self):
        """Alias for SortUsingCustomLists"""
        return self.SortUsingCustomLists

    @sortusingcustomlists.setter
    def sortusingcustomlists(self, value):
        """Alias for SortUsingCustomLists.setter"""
        self.SortUsingCustomLists = value

    @property
    def sort_using_custom_lists(self):
        """Alias for SortUsingCustomLists"""
        return self.SortUsingCustomLists

    @sort_using_custom_lists.setter
    def sort_using_custom_lists(self, value):
        """Alias for SortUsingCustomLists.setter"""
        self.SortUsingCustomLists = value

    @property
    def SourceName(self):
        return self.com_object.SourceName

    @property
    def sourcename(self):
        """Alias for SourceName"""
        return self.SourceName

    @property
    def source_name(self):
        """Alias for SourceName"""
        return self.SourceName

    @property
    def SourceType(self):
        return self.com_object.SourceType

    @property
    def sourcetype(self):
        """Alias for SourceType"""
        return self.SourceType

    @property
    def source_type(self):
        """Alias for SourceType"""
        return self.SourceType

    @property
    def TimelineState(self):
        return self.com_object.TimelineState

    @property
    def timelinestate(self):
        """Alias for TimelineState"""
        return self.TimelineState

    @property
    def timeline_state(self):
        """Alias for TimelineState"""
        return self.TimelineState

    @property
    def VisibleSlicerItems(self):
        return SlicerItems(self.com_object.VisibleSlicerItems)

    @property
    def visiblesliceritems(self):
        """Alias for VisibleSlicerItems"""
        return self.VisibleSlicerItems

    @property
    def visible_slicer_items(self):
        """Alias for VisibleSlicerItems"""
        return self.VisibleSlicerItems

    @property
    def VisibleSlicerItemsList(self):
        return self.com_object.VisibleSlicerItemsList

    @VisibleSlicerItemsList.setter
    def VisibleSlicerItemsList(self, value):
        self.com_object.VisibleSlicerItemsList = value

    @property
    def visiblesliceritemslist(self):
        """Alias for VisibleSlicerItemsList"""
        return self.VisibleSlicerItemsList

    @visiblesliceritemslist.setter
    def visiblesliceritemslist(self, value):
        """Alias for VisibleSlicerItemsList.setter"""
        self.VisibleSlicerItemsList = value

    @property
    def visible_slicer_items_list(self):
        """Alias for VisibleSlicerItemsList"""
        return self.VisibleSlicerItemsList

    @visible_slicer_items_list.setter
    def visible_slicer_items_list(self, value):
        """Alias for VisibleSlicerItemsList.setter"""
        self.VisibleSlicerItemsList = value

    @property
    def WorkbookConnection(self):
        return self.com_object.WorkbookConnection

    @WorkbookConnection.setter
    def WorkbookConnection(self, value):
        self.com_object.WorkbookConnection = value

    @property
    def workbookconnection(self):
        """Alias for WorkbookConnection"""
        return self.WorkbookConnection

    @workbookconnection.setter
    def workbookconnection(self, value):
        """Alias for WorkbookConnection.setter"""
        self.WorkbookConnection = value

    @property
    def workbook_connection(self):
        """Alias for WorkbookConnection"""
        return self.WorkbookConnection

    @workbook_connection.setter
    def workbook_connection(self, value):
        """Alias for WorkbookConnection.setter"""
        self.WorkbookConnection = value

    def ClearAllFilters(self):
        return self.com_object.ClearAllFilters()

    def clearallfilters(self):
        """Alias for ClearAllFilters"""
        return self.ClearAllFilters()

    def clear_all_filters(self):
        """Alias for ClearAllFilters"""
        return self.ClearAllFilters()

    def ClearDateFilter(self):
        return self.com_object.ClearDateFilter()

    def cleardatefilter(self):
        """Alias for ClearDateFilter"""
        return self.ClearDateFilter()

    def clear_date_filter(self):
        """Alias for ClearDateFilter"""
        return self.ClearDateFilter()

    def ClearManualFilter(self):
        return self.com_object.ClearManualFilter()

    def clearmanualfilter(self):
        """Alias for ClearManualFilter"""
        return self.ClearManualFilter()

    def clear_manual_filter(self):
        """Alias for ClearManualFilter"""
        return self.ClearManualFilter()

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class SlicerCacheLevel:

    def __init__(self, slicercachelevel=None):
        self.com_object= slicercachelevel

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return SlicerItem(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def CrossFilterType(self):
        return self.com_object.CrossFilterType

    @CrossFilterType.setter
    def CrossFilterType(self, value):
        self.com_object.CrossFilterType = value

    @property
    def crossfiltertype(self):
        """Alias for CrossFilterType"""
        return self.CrossFilterType

    @crossfiltertype.setter
    def crossfiltertype(self, value):
        """Alias for CrossFilterType.setter"""
        self.CrossFilterType = value

    @property
    def cross_filter_type(self):
        """Alias for CrossFilterType"""
        return self.CrossFilterType

    @cross_filter_type.setter
    def cross_filter_type(self, value):
        """Alias for CrossFilterType.setter"""
        self.CrossFilterType = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Ordinal(self):
        return SlicerCacheLevel(self.com_object.Ordinal)

    @property
    def ordinal(self):
        """Alias for Ordinal"""
        return self.Ordinal

    @property
    def Parent(self):
        return SlicerCache(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SlicerItems(self):
        return SlicerItems(self.com_object.SlicerItems)

    @property
    def sliceritems(self):
        """Alias for SlicerItems"""
        return self.SlicerItems

    @property
    def slicer_items(self):
        """Alias for SlicerItems"""
        return self.SlicerItems

    @property
    def SortItems(self):
        return self.com_object.SortItems

    @SortItems.setter
    def SortItems(self, value):
        self.com_object.SortItems = value

    @property
    def sortitems(self):
        """Alias for SortItems"""
        return self.SortItems

    @sortitems.setter
    def sortitems(self, value):
        """Alias for SortItems.setter"""
        self.SortItems = value

    @property
    def sort_items(self):
        """Alias for SortItems"""
        return self.SortItems

    @sort_items.setter
    def sort_items(self, value):
        """Alias for SortItems.setter"""
        self.SortItems = value

    @property
    def VisibleSlicerItemsList(self):
        return self.com_object.VisibleSlicerItemsList

    @property
    def visiblesliceritemslist(self):
        """Alias for VisibleSlicerItemsList"""
        return self.VisibleSlicerItemsList

    @property
    def visible_slicer_items_list(self):
        """Alias for VisibleSlicerItemsList"""
        return self.VisibleSlicerItemsList


class SlicerCacheLevels:

    def __init__(self, slicercachelevels=None):
        self.com_object= slicercachelevels

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return SlicerCache(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Level=None):
        arguments = com_arguments([unwrap(a) for a in [Level]])
        if hasattr(self.com_object, "GetItem"):
            return SlicerCacheLevel(self.com_object.GetItem(*arguments))
        else:
            return SlicerCacheLevel(self.com_object.Item(*arguments))

    def item(self, Level=None):
        """Alias for Item"""
        arguments = [Level]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return SlicerCache(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class SlicerCaches:

    def __init__(self, slicercaches=None):
        self.com_object= slicercaches

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return SlicerCache(self.com_object.GetItem(*arguments))
        else:
            return SlicerCache(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return Workbook(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Source=None, SourceField=None, Name=None, SlicerCacheType=None):
        arguments = com_arguments([unwrap(a) for a in [Source, SourceField, Name, SlicerCacheType]])
        return SlicerCache(self.com_object.Add(*arguments))

    def add(self, Source=None, SourceField=None, Name=None, SlicerCacheType=None):
        """Alias for Add"""
        arguments = [Source, SourceField, Name, SlicerCacheType]
        return self.Add(*arguments)


class SlicerItem:

    def __init__(self, sliceritem=None):
        self.com_object= sliceritem

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Caption(self):
        return self.com_object.Caption

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def HasData(self):
        return self.com_object.HasData

    @property
    def hasdata(self):
        """Alias for HasData"""
        return self.HasData

    @property
    def has_data(self):
        """Alias for HasData"""
        return self.HasData

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return SlicerCache(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Selected(self):
        return self.com_object.Selected

    @Selected.setter
    def Selected(self, value):
        self.com_object.Selected = value

    @property
    def selected(self):
        """Alias for Selected"""
        return self.Selected

    @selected.setter
    def selected(self, value):
        """Alias for Selected.setter"""
        self.Selected = value

    @property
    def SourceName(self):
        return self.com_object.SourceName

    @property
    def sourcename(self):
        """Alias for SourceName"""
        return self.SourceName

    @property
    def source_name(self):
        """Alias for SourceName"""
        return self.SourceName

    @property
    def SourceNameStandard(self):
        return self.com_object.SourceNameStandard

    @property
    def sourcenamestandard(self):
        """Alias for SourceNameStandard"""
        return self.SourceNameStandard

    @property
    def source_name_standard(self):
        """Alias for SourceNameStandard"""
        return self.SourceNameStandard

    @property
    def Value(self):
        return self.com_object.Value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value


class SlicerItems:

    def __init__(self, sliceritems=None):
        self.com_object= sliceritems

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return SlicerItem(self.com_object.GetItem(*arguments))
        else:
            return SlicerItem(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return SlicerCache(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class SlicerPivotTables:

    def __init__(self, slicerpivottables=None):
        self.com_object= slicerpivottables

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return PivotTable(self.com_object.GetItem(*arguments))
        else:
            return PivotTable(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return SlicerCache(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def AddPivotTable(self, PivotTable=None):
        arguments = com_arguments([unwrap(a) for a in [PivotTable]])
        return self.com_object.AddPivotTable(*arguments)

    def addpivottable(self, PivotTable=None):
        """Alias for AddPivotTable"""
        arguments = [PivotTable]
        return self.AddPivotTable(*arguments)

    def add_pivot_table(self, PivotTable=None):
        """Alias for AddPivotTable"""
        arguments = [PivotTable]
        return self.AddPivotTable(*arguments)

    def RemovePivotTable(self, PivotTable=None):
        arguments = com_arguments([unwrap(a) for a in [PivotTable]])
        return self.com_object.RemovePivotTable(*arguments)

    def removepivottable(self, PivotTable=None):
        """Alias for RemovePivotTable"""
        arguments = [PivotTable]
        return self.RemovePivotTable(*arguments)

    def remove_pivot_table(self, PivotTable=None):
        """Alias for RemovePivotTable"""
        arguments = [PivotTable]
        return self.RemovePivotTable(*arguments)


class Slicers:

    def __init__(self, slicers=None):
        self.com_object= slicers

    def __call__(self, item):
        return Slicer(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return Slicer(self.com_object.GetItem(*arguments))
        else:
            return Slicer(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return SlicerCache(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, SlicerDestination=None, Level=None, Name=None, Caption=None, Top=None, Left=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [SlicerDestination, Level, Name, Caption, Top, Left, Width, Height]])
        return Slicer(self.com_object.Add(*arguments))

    def add(self, SlicerDestination=None, Level=None, Name=None, Caption=None, Top=None, Left=None, Width=None, Height=None):
        """Alias for Add"""
        arguments = [SlicerDestination, Level, Name, Caption, Top, Left, Width, Height]
        return self.Add(*arguments)


class Sort:

    def __init__(self, sort=None):
        self.com_object= sort

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Header(self):
        return self.com_object.Header

    @Header.setter
    def Header(self, value):
        self.com_object.Header = value

    @property
    def header(self):
        """Alias for Header"""
        return self.Header

    @header.setter
    def header(self, value):
        """Alias for Header.setter"""
        self.Header = value

    @property
    def MatchCase(self):
        return self.com_object.MatchCase

    @MatchCase.setter
    def MatchCase(self, value):
        self.com_object.MatchCase = value

    @property
    def matchcase(self):
        """Alias for MatchCase"""
        return self.MatchCase

    @matchcase.setter
    def matchcase(self, value):
        """Alias for MatchCase.setter"""
        self.MatchCase = value

    @property
    def match_case(self):
        """Alias for MatchCase"""
        return self.MatchCase

    @match_case.setter
    def match_case(self, value):
        """Alias for MatchCase.setter"""
        self.MatchCase = value

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Rng(self):
        return self.com_object.Rng

    @property
    def rng(self):
        """Alias for Rng"""
        return self.Rng

    @property
    def SortFields(self):
        return SortFields(self.com_object.SortFields)

    @property
    def sortfields(self):
        """Alias for SortFields"""
        return self.SortFields

    @property
    def sort_fields(self):
        """Alias for SortFields"""
        return self.SortFields

    @property
    def SortMethod(self):
        return self.com_object.SortMethod

    @SortMethod.setter
    def SortMethod(self, value):
        self.com_object.SortMethod = value

    @property
    def sortmethod(self):
        """Alias for SortMethod"""
        return self.SortMethod

    @sortmethod.setter
    def sortmethod(self, value):
        """Alias for SortMethod.setter"""
        self.SortMethod = value

    @property
    def sort_method(self):
        """Alias for SortMethod"""
        return self.SortMethod

    @sort_method.setter
    def sort_method(self, value):
        """Alias for SortMethod.setter"""
        self.SortMethod = value

    def Apply(self):
        self.com_object.Apply()

    def apply(self):
        """Alias for Apply"""
        return self.Apply()

    def SetRange(self, Rng=None):
        arguments = com_arguments([unwrap(a) for a in [Rng]])
        self.com_object.SetRange(*arguments)

    def setrange(self, Rng=None):
        """Alias for SetRange"""
        arguments = [Rng]
        return self.SetRange(*arguments)

    def set_range(self, Rng=None):
        """Alias for SetRange"""
        arguments = [Rng]
        return self.SetRange(*arguments)


class SortField:

    def __init__(self, sortfield=None):
        self.com_object= sortfield

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def CustomOrder(self):
        return self.com_object.CustomOrder

    @CustomOrder.setter
    def CustomOrder(self, value):
        self.com_object.CustomOrder = value

    @property
    def customorder(self):
        """Alias for CustomOrder"""
        return self.CustomOrder

    @customorder.setter
    def customorder(self, value):
        """Alias for CustomOrder.setter"""
        self.CustomOrder = value

    @property
    def custom_order(self):
        """Alias for CustomOrder"""
        return self.CustomOrder

    @custom_order.setter
    def custom_order(self, value):
        """Alias for CustomOrder.setter"""
        self.CustomOrder = value

    @property
    def DataOption(self):
        return self.com_object.DataOption

    @DataOption.setter
    def DataOption(self, value):
        self.com_object.DataOption = value

    @property
    def dataoption(self):
        """Alias for DataOption"""
        return self.DataOption

    @dataoption.setter
    def dataoption(self, value):
        """Alias for DataOption.setter"""
        self.DataOption = value

    @property
    def data_option(self):
        """Alias for DataOption"""
        return self.DataOption

    @data_option.setter
    def data_option(self, value):
        """Alias for DataOption.setter"""
        self.DataOption = value

    @property
    def Key(self):
        return self.com_object.Key

    @property
    def key(self):
        """Alias for Key"""
        return self.Key

    @property
    def Order(self):
        return self.com_object.Order

    @Order.setter
    def Order(self, value):
        self.com_object.Order = value

    @property
    def order(self):
        """Alias for Order"""
        return self.Order

    @order.setter
    def order(self, value):
        """Alias for Order.setter"""
        self.Order = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Priority(self):
        return self.com_object.Priority

    @Priority.setter
    def Priority(self, value):
        self.com_object.Priority = value

    @property
    def priority(self):
        """Alias for Priority"""
        return self.Priority

    @priority.setter
    def priority(self, value):
        """Alias for Priority.setter"""
        self.Priority = value

    @property
    def SortOn(self):
        return XlSortOn(self.com_object.SortOn)

    @SortOn.setter
    def SortOn(self, value):
        self.com_object.SortOn = value

    @property
    def sorton(self):
        """Alias for SortOn"""
        return self.SortOn

    @sorton.setter
    def sorton(self, value):
        """Alias for SortOn.setter"""
        self.SortOn = value

    @property
    def sort_on(self):
        """Alias for SortOn"""
        return self.SortOn

    @sort_on.setter
    def sort_on(self, value):
        """Alias for SortOn.setter"""
        self.SortOn = value

    @property
    def SortOnValue(self):
        return SortField(self.com_object.SortOnValue)

    @property
    def sortonvalue(self):
        """Alias for SortOnValue"""
        return self.SortOnValue

    @property
    def sort_on_value(self):
        """Alias for SortOnValue"""
        return self.SortOnValue

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def ModifyKey(self, Key=None):
        arguments = com_arguments([unwrap(a) for a in [Key]])
        self.com_object.ModifyKey(*arguments)

    def modifykey(self, Key=None):
        """Alias for ModifyKey"""
        arguments = [Key]
        return self.ModifyKey(*arguments)

    def modify_key(self, Key=None):
        """Alias for ModifyKey"""
        arguments = [Key]
        return self.ModifyKey(*arguments)

    def SetIcon(self, Icon=None):
        arguments = com_arguments([unwrap(a) for a in [Icon]])
        self.com_object.SetIcon(*arguments)

    def seticon(self, Icon=None):
        """Alias for SetIcon"""
        arguments = [Icon]
        return self.SetIcon(*arguments)

    def set_icon(self, Icon=None):
        """Alias for SetIcon"""
        arguments = [Icon]
        return self.SetIcon(*arguments)


class SortFields:

    def __init__(self, sortfields=None):
        self.com_object= sortfields

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return SortField(self.com_object.GetItem(*arguments))
        else:
            return SortField(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Key=None, SortOn=None, Order=None, CustomOrder=None, DataOption=None):
        arguments = com_arguments([unwrap(a) for a in [Key, SortOn, Order, CustomOrder, DataOption]])
        return SortField(self.com_object.Add(*arguments))

    def add(self, Key=None, SortOn=None, Order=None, CustomOrder=None, DataOption=None):
        """Alias for Add"""
        arguments = [Key, SortOn, Order, CustomOrder, DataOption]
        return self.Add(*arguments)

    def Add2(self, Key=None, SortOn=None, Order=None, CustomOrder=None, DataOption=None, SubField=None):
        arguments = com_arguments([unwrap(a) for a in [Key, SortOn, Order, CustomOrder, DataOption, SubField]])
        return SortField(self.com_object.Add2(*arguments))

    def add2(self, Key=None, SortOn=None, Order=None, CustomOrder=None, DataOption=None, SubField=None):
        """Alias for Add2"""
        arguments = [Key, SortOn, Order, CustomOrder, DataOption, SubField]
        return self.Add2(*arguments)

    def Clear(self):
        self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()


class SparkAxes:

    def __init__(self, sparkaxes=None):
        self.com_object= sparkaxes

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Horizontal(self):
        return SparkHorizontalAxis(self.com_object.Horizontal)

    @property
    def horizontal(self):
        """Alias for Horizontal"""
        return self.Horizontal

    @property
    def Parent(self):
        return SparklineGroup(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Vertical(self):
        return SparkVerticalAxis(self.com_object.Vertical)

    @property
    def vertical(self):
        """Alias for Vertical"""
        return self.Vertical


class SparkColor:

    def __init__(self, sparkcolor=None):
        self.com_object= sparkcolor

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Color(self):
        return FormatColor(self.com_object.Color)

    @property
    def color(self):
        """Alias for Color"""
        return self.Color

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return SparklineGroup(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value


class SparkHorizontalAxis:

    def __init__(self, sparkhorizontalaxis=None):
        self.com_object= sparkhorizontalaxis

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Axis(self):
        return SparkColor(self.com_object.Axis)

    @property
    def axis(self):
        """Alias for Axis"""
        return self.Axis

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def IsDateAxis(self):
        return self.com_object.IsDateAxis

    @property
    def isdateaxis(self):
        """Alias for IsDateAxis"""
        return self.IsDateAxis

    @property
    def is_date_axis(self):
        """Alias for IsDateAxis"""
        return self.IsDateAxis

    @property
    def Parent(self):
        return SparklineGroup(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RightToLeftPlotOrder(self):
        return self.com_object.RightToLeftPlotOrder

    @RightToLeftPlotOrder.setter
    def RightToLeftPlotOrder(self, value):
        self.com_object.RightToLeftPlotOrder = value

    @property
    def righttoleftplotorder(self):
        """Alias for RightToLeftPlotOrder"""
        return self.RightToLeftPlotOrder

    @righttoleftplotorder.setter
    def righttoleftplotorder(self, value):
        """Alias for RightToLeftPlotOrder.setter"""
        self.RightToLeftPlotOrder = value

    @property
    def right_to_left_plot_order(self):
        """Alias for RightToLeftPlotOrder"""
        return self.RightToLeftPlotOrder

    @right_to_left_plot_order.setter
    def right_to_left_plot_order(self, value):
        """Alias for RightToLeftPlotOrder.setter"""
        self.RightToLeftPlotOrder = value


class Sparkline:

    def __init__(self, sparkline=None):
        self.com_object= sparkline

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Location(self):
        return self.com_object.Location

    @Location.setter
    def Location(self, value):
        self.com_object.Location = value

    @property
    def location(self):
        """Alias for Location"""
        return self.Location

    @location.setter
    def location(self, value):
        """Alias for Location.setter"""
        self.Location = value

    @property
    def Parent(self):
        return SparklineGroup(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SourceData(self):
        return self.com_object.SourceData

    @SourceData.setter
    def SourceData(self, value):
        self.com_object.SourceData = value

    @property
    def sourcedata(self):
        """Alias for SourceData"""
        return self.SourceData

    @sourcedata.setter
    def sourcedata(self, value):
        """Alias for SourceData.setter"""
        self.SourceData = value

    @property
    def source_data(self):
        """Alias for SourceData"""
        return self.SourceData

    @source_data.setter
    def source_data(self, value):
        """Alias for SourceData.setter"""
        self.SourceData = value

    def ModifyLocation(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        return self.com_object.ModifyLocation(*arguments)

    def modifylocation(self, Range=None):
        """Alias for ModifyLocation"""
        arguments = [Range]
        return self.ModifyLocation(*arguments)

    def modify_location(self, Range=None):
        """Alias for ModifyLocation"""
        arguments = [Range]
        return self.ModifyLocation(*arguments)

    def ModifySourceData(self, Formula=None):
        arguments = com_arguments([unwrap(a) for a in [Formula]])
        return self.com_object.ModifySourceData(*arguments)

    def modifysourcedata(self, Formula=None):
        """Alias for ModifySourceData"""
        arguments = [Formula]
        return self.ModifySourceData(*arguments)

    def modify_source_data(self, Formula=None):
        """Alias for ModifySourceData"""
        arguments = [Formula]
        return self.ModifySourceData(*arguments)


class SparklineGroup:

    def __init__(self, sparklinegroup=None):
        self.com_object= sparklinegroup

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Axes(self):
        return SparkAxes(self.com_object.Axes)

    @property
    def axes(self):
        """Alias for Axes"""
        return self.Axes

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DateRange(self):
        return self.com_object.DateRange

    @DateRange.setter
    def DateRange(self, value):
        self.com_object.DateRange = value

    @property
    def daterange(self):
        """Alias for DateRange"""
        return self.DateRange

    @daterange.setter
    def daterange(self, value):
        """Alias for DateRange.setter"""
        self.DateRange = value

    @property
    def date_range(self):
        """Alias for DateRange"""
        return self.DateRange

    @date_range.setter
    def date_range(self, value):
        """Alias for DateRange.setter"""
        self.DateRange = value

    @property
    def DisplayHidden(self):
        return self.com_object.DisplayHidden

    @DisplayHidden.setter
    def DisplayHidden(self, value):
        self.com_object.DisplayHidden = value

    @property
    def displayhidden(self):
        """Alias for DisplayHidden"""
        return self.DisplayHidden

    @displayhidden.setter
    def displayhidden(self, value):
        """Alias for DisplayHidden.setter"""
        self.DisplayHidden = value

    @property
    def display_hidden(self):
        """Alias for DisplayHidden"""
        return self.DisplayHidden

    @display_hidden.setter
    def display_hidden(self, value):
        """Alias for DisplayHidden.setter"""
        self.DisplayHidden = value

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return Sparkline(self.com_object.GetItem(*arguments))
        else:
            return Sparkline(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def LineWeight(self):
        return self.com_object.LineWeight

    @LineWeight.setter
    def LineWeight(self, value):
        self.com_object.LineWeight = value

    @property
    def lineweight(self):
        """Alias for LineWeight"""
        return self.LineWeight

    @lineweight.setter
    def lineweight(self, value):
        """Alias for LineWeight.setter"""
        self.LineWeight = value

    @property
    def line_weight(self):
        """Alias for LineWeight"""
        return self.LineWeight

    @line_weight.setter
    def line_weight(self, value):
        """Alias for LineWeight.setter"""
        self.LineWeight = value

    @property
    def Location(self):
        return self.com_object.Location

    @Location.setter
    def Location(self, value):
        self.com_object.Location = value

    @property
    def location(self):
        """Alias for Location"""
        return self.Location

    @location.setter
    def location(self, value):
        """Alias for Location.setter"""
        self.Location = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PlotBy(self):
        return self.com_object.PlotBy

    @PlotBy.setter
    def PlotBy(self, value):
        self.com_object.PlotBy = value

    @property
    def plotby(self):
        """Alias for PlotBy"""
        return self.PlotBy

    @plotby.setter
    def plotby(self, value):
        """Alias for PlotBy.setter"""
        self.PlotBy = value

    @property
    def plot_by(self):
        """Alias for PlotBy"""
        return self.PlotBy

    @plot_by.setter
    def plot_by(self, value):
        """Alias for PlotBy.setter"""
        self.PlotBy = value

    @property
    def Points(self):
        return SparkPoints(self.com_object.Points)

    @property
    def points(self):
        """Alias for Points"""
        return self.Points

    @property
    def SeriesColor(self):
        return FormatColor(self.com_object.SeriesColor)

    @property
    def seriescolor(self):
        """Alias for SeriesColor"""
        return self.SeriesColor

    @property
    def series_color(self):
        """Alias for SeriesColor"""
        return self.SeriesColor

    @property
    def SourceData(self):
        return self.com_object.SourceData

    @SourceData.setter
    def SourceData(self, value):
        self.com_object.SourceData = value

    @property
    def sourcedata(self):
        """Alias for SourceData"""
        return self.SourceData

    @sourcedata.setter
    def sourcedata(self, value):
        """Alias for SourceData.setter"""
        self.SourceData = value

    @property
    def source_data(self):
        """Alias for SourceData"""
        return self.SourceData

    @source_data.setter
    def source_data(self, value):
        """Alias for SourceData.setter"""
        self.SourceData = value

    @property
    def Type(self):
        return self.com_object.Type

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Modify(self, Location=None, SourceData=None):
        arguments = com_arguments([unwrap(a) for a in [Location, SourceData]])
        return self.com_object.Modify(*arguments)

    def modify(self, Location=None, SourceData=None):
        """Alias for Modify"""
        arguments = [Location, SourceData]
        return self.Modify(*arguments)

    def ModifyDateRange(self, DateRange=None):
        arguments = com_arguments([unwrap(a) for a in [DateRange]])
        return self.com_object.ModifyDateRange(*arguments)

    def modifydaterange(self, DateRange=None):
        """Alias for ModifyDateRange"""
        arguments = [DateRange]
        return self.ModifyDateRange(*arguments)

    def modify_date_range(self, DateRange=None):
        """Alias for ModifyDateRange"""
        arguments = [DateRange]
        return self.ModifyDateRange(*arguments)

    def ModifyLocation(self, Location=None):
        arguments = com_arguments([unwrap(a) for a in [Location]])
        return self.com_object.ModifyLocation(*arguments)

    def modifylocation(self, Location=None):
        """Alias for ModifyLocation"""
        arguments = [Location]
        return self.ModifyLocation(*arguments)

    def modify_location(self, Location=None):
        """Alias for ModifyLocation"""
        arguments = [Location]
        return self.ModifyLocation(*arguments)

    def ModifySourceData(self, SourceData=None):
        arguments = com_arguments([unwrap(a) for a in [SourceData]])
        return self.com_object.ModifySourceData(*arguments)

    def modifysourcedata(self, SourceData=None):
        """Alias for ModifySourceData"""
        arguments = [SourceData]
        return self.ModifySourceData(*arguments)

    def modify_source_data(self, SourceData=None):
        """Alias for ModifySourceData"""
        arguments = [SourceData]
        return self.ModifySourceData(*arguments)


class SparklineGroups:

    def __init__(self, sparklinegroups=None):
        self.com_object= sparklinegroups

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return Range(self.com_object.Count)

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return SparklineGroup(self.com_object.GetItem(*arguments))
        else:
            return SparklineGroup(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return Range(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Type=None, SourceData=None):
        arguments = com_arguments([unwrap(a) for a in [Type, SourceData]])
        return SparklineGroup(self.com_object.Add(*arguments))

    def add(self, Type=None, SourceData=None):
        """Alias for Add"""
        arguments = [Type, SourceData]
        return self.Add(*arguments)

    def Clear(self):
        return self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()

    def ClearGroups(self):
        return self.com_object.ClearGroups()

    def cleargroups(self):
        """Alias for ClearGroups"""
        return self.ClearGroups()

    def clear_groups(self):
        """Alias for ClearGroups"""
        return self.ClearGroups()

    def Group(self, Location=None):
        arguments = com_arguments([unwrap(a) for a in [Location]])
        return self.com_object.Group(*arguments)

    def group(self, Location=None):
        """Alias for Group"""
        arguments = [Location]
        return self.Group(*arguments)

    def Ungroup(self):
        return self.com_object.Ungroup()

    def ungroup(self):
        """Alias for Ungroup"""
        return self.Ungroup()


class SparkPoints:

    def __init__(self, sparkpoints=None):
        self.com_object= sparkpoints

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Firstpoint(self):
        return SparkColor(self.com_object.Firstpoint)

    @property
    def firstpoint(self):
        """Alias for Firstpoint"""
        return self.Firstpoint

    @property
    def Highpoint(self):
        return SparkColor(self.com_object.Highpoint)

    @property
    def highpoint(self):
        """Alias for Highpoint"""
        return self.Highpoint

    @property
    def Lastpoint(self):
        return SparkColor(self.com_object.Lastpoint)

    @property
    def lastpoint(self):
        """Alias for Lastpoint"""
        return self.Lastpoint

    @property
    def Lowpoint(self):
        return SparkColor(self.com_object.Lowpoint)

    @property
    def lowpoint(self):
        """Alias for Lowpoint"""
        return self.Lowpoint

    @property
    def Markers(self):
        return SparkColor(self.com_object.Markers)

    @property
    def markers(self):
        """Alias for Markers"""
        return self.Markers

    @property
    def Negative(self):
        return SparkColor(self.com_object.Negative)

    @property
    def negative(self):
        """Alias for Negative"""
        return self.Negative

    @property
    def Parent(self):
        return SparklineGroup(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class SparkVerticalAxis:

    def __init__(self, sparkverticalaxis=None):
        self.com_object= sparkverticalaxis

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def CustomMaxScaleValue(self):
        return self.com_object.CustomMaxScaleValue

    @CustomMaxScaleValue.setter
    def CustomMaxScaleValue(self, value):
        self.com_object.CustomMaxScaleValue = value

    @property
    def custommaxscalevalue(self):
        """Alias for CustomMaxScaleValue"""
        return self.CustomMaxScaleValue

    @custommaxscalevalue.setter
    def custommaxscalevalue(self, value):
        """Alias for CustomMaxScaleValue.setter"""
        self.CustomMaxScaleValue = value

    @property
    def custom_max_scale_value(self):
        """Alias for CustomMaxScaleValue"""
        return self.CustomMaxScaleValue

    @custom_max_scale_value.setter
    def custom_max_scale_value(self, value):
        """Alias for CustomMaxScaleValue.setter"""
        self.CustomMaxScaleValue = value

    @property
    def CustomMinScaleValue(self):
        return self.com_object.CustomMinScaleValue

    @CustomMinScaleValue.setter
    def CustomMinScaleValue(self, value):
        self.com_object.CustomMinScaleValue = value

    @property
    def customminscalevalue(self):
        """Alias for CustomMinScaleValue"""
        return self.CustomMinScaleValue

    @customminscalevalue.setter
    def customminscalevalue(self, value):
        """Alias for CustomMinScaleValue.setter"""
        self.CustomMinScaleValue = value

    @property
    def custom_min_scale_value(self):
        """Alias for CustomMinScaleValue"""
        return self.CustomMinScaleValue

    @custom_min_scale_value.setter
    def custom_min_scale_value(self, value):
        """Alias for CustomMinScaleValue.setter"""
        self.CustomMinScaleValue = value

    @property
    def MaxScaleType(self):
        return self.com_object.MaxScaleType

    @MaxScaleType.setter
    def MaxScaleType(self, value):
        self.com_object.MaxScaleType = value

    @property
    def maxscaletype(self):
        """Alias for MaxScaleType"""
        return self.MaxScaleType

    @maxscaletype.setter
    def maxscaletype(self, value):
        """Alias for MaxScaleType.setter"""
        self.MaxScaleType = value

    @property
    def max_scale_type(self):
        """Alias for MaxScaleType"""
        return self.MaxScaleType

    @max_scale_type.setter
    def max_scale_type(self, value):
        """Alias for MaxScaleType.setter"""
        self.MaxScaleType = value

    @property
    def MinScaleType(self):
        return self.com_object.MinScaleType

    @MinScaleType.setter
    def MinScaleType(self, value):
        self.com_object.MinScaleType = value

    @property
    def minscaletype(self):
        """Alias for MinScaleType"""
        return self.MinScaleType

    @minscaletype.setter
    def minscaletype(self, value):
        """Alias for MinScaleType.setter"""
        self.MinScaleType = value

    @property
    def min_scale_type(self):
        """Alias for MinScaleType"""
        return self.MinScaleType

    @min_scale_type.setter
    def min_scale_type(self, value):
        """Alias for MinScaleType.setter"""
        self.MinScaleType = value

    @property
    def Parent(self):
        return SparklineGroup(self.com_object.Parent)

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class Speech:

    def __init__(self, speech=None):
        self.com_object= speech

    @property
    def Direction(self):
        return XlSpeakDirection(self.com_object.Direction)

    @Direction.setter
    def Direction(self, value):
        self.com_object.Direction = value

    @property
    def direction(self):
        """Alias for Direction"""
        return self.Direction

    @direction.setter
    def direction(self, value):
        """Alias for Direction.setter"""
        self.Direction = value

    @property
    def SpeakCellOnEnter(self):
        return self.com_object.SpeakCellOnEnter

    @SpeakCellOnEnter.setter
    def SpeakCellOnEnter(self, value):
        self.com_object.SpeakCellOnEnter = value

    @property
    def speakcellonenter(self):
        """Alias for SpeakCellOnEnter"""
        return self.SpeakCellOnEnter

    @speakcellonenter.setter
    def speakcellonenter(self, value):
        """Alias for SpeakCellOnEnter.setter"""
        self.SpeakCellOnEnter = value

    @property
    def speak_cell_on_enter(self):
        """Alias for SpeakCellOnEnter"""
        return self.SpeakCellOnEnter

    @speak_cell_on_enter.setter
    def speak_cell_on_enter(self, value):
        """Alias for SpeakCellOnEnter.setter"""
        self.SpeakCellOnEnter = value

    def Speak(self, Text=None, SpeakAsync=None, SpeakXML=None, Purge=None):
        arguments = com_arguments([unwrap(a) for a in [Text, SpeakAsync, SpeakXML, Purge]])
        self.com_object.Speak(*arguments)

    def speak(self, Text=None, SpeakAsync=None, SpeakXML=None, Purge=None):
        """Alias for Speak"""
        arguments = [Text, SpeakAsync, SpeakXML, Purge]
        return self.Speak(*arguments)


class SpellingOptions:

    def __init__(self, spellingoptions=None):
        self.com_object= spellingoptions

    @property
    def ArabicModes(self):
        return XlArabicModes(self.com_object.ArabicModes)

    @ArabicModes.setter
    def ArabicModes(self, value):
        self.com_object.ArabicModes = value

    @property
    def arabicmodes(self):
        """Alias for ArabicModes"""
        return self.ArabicModes

    @arabicmodes.setter
    def arabicmodes(self, value):
        """Alias for ArabicModes.setter"""
        self.ArabicModes = value

    @property
    def arabic_modes(self):
        """Alias for ArabicModes"""
        return self.ArabicModes

    @arabic_modes.setter
    def arabic_modes(self, value):
        """Alias for ArabicModes.setter"""
        self.ArabicModes = value

    @property
    def ArabicStrictAlefHamza(self):
        return self.com_object.ArabicStrictAlefHamza

    @ArabicStrictAlefHamza.setter
    def ArabicStrictAlefHamza(self, value):
        self.com_object.ArabicStrictAlefHamza = value

    @property
    def arabicstrictalefhamza(self):
        """Alias for ArabicStrictAlefHamza"""
        return self.ArabicStrictAlefHamza

    @arabicstrictalefhamza.setter
    def arabicstrictalefhamza(self, value):
        """Alias for ArabicStrictAlefHamza.setter"""
        self.ArabicStrictAlefHamza = value

    @property
    def arabic_strict_alef_hamza(self):
        """Alias for ArabicStrictAlefHamza"""
        return self.ArabicStrictAlefHamza

    @arabic_strict_alef_hamza.setter
    def arabic_strict_alef_hamza(self, value):
        """Alias for ArabicStrictAlefHamza.setter"""
        self.ArabicStrictAlefHamza = value

    @property
    def ArabicStrictFinalYaa(self):
        return self.com_object.ArabicStrictFinalYaa

    @ArabicStrictFinalYaa.setter
    def ArabicStrictFinalYaa(self, value):
        self.com_object.ArabicStrictFinalYaa = value

    @property
    def arabicstrictfinalyaa(self):
        """Alias for ArabicStrictFinalYaa"""
        return self.ArabicStrictFinalYaa

    @arabicstrictfinalyaa.setter
    def arabicstrictfinalyaa(self, value):
        """Alias for ArabicStrictFinalYaa.setter"""
        self.ArabicStrictFinalYaa = value

    @property
    def arabic_strict_final_yaa(self):
        """Alias for ArabicStrictFinalYaa"""
        return self.ArabicStrictFinalYaa

    @arabic_strict_final_yaa.setter
    def arabic_strict_final_yaa(self, value):
        """Alias for ArabicStrictFinalYaa.setter"""
        self.ArabicStrictFinalYaa = value

    @property
    def ArabicStrictTaaMarboota(self):
        return self.com_object.ArabicStrictTaaMarboota

    @ArabicStrictTaaMarboota.setter
    def ArabicStrictTaaMarboota(self, value):
        self.com_object.ArabicStrictTaaMarboota = value

    @property
    def arabicstricttaamarboota(self):
        """Alias for ArabicStrictTaaMarboota"""
        return self.ArabicStrictTaaMarboota

    @arabicstricttaamarboota.setter
    def arabicstricttaamarboota(self, value):
        """Alias for ArabicStrictTaaMarboota.setter"""
        self.ArabicStrictTaaMarboota = value

    @property
    def arabic_strict_taa_marboota(self):
        """Alias for ArabicStrictTaaMarboota"""
        return self.ArabicStrictTaaMarboota

    @arabic_strict_taa_marboota.setter
    def arabic_strict_taa_marboota(self, value):
        """Alias for ArabicStrictTaaMarboota.setter"""
        self.ArabicStrictTaaMarboota = value

    @property
    def BrazilReform(self):
        return self.com_object.BrazilReform

    @BrazilReform.setter
    def BrazilReform(self, value):
        self.com_object.BrazilReform = value

    @property
    def brazilreform(self):
        """Alias for BrazilReform"""
        return self.BrazilReform

    @brazilreform.setter
    def brazilreform(self, value):
        """Alias for BrazilReform.setter"""
        self.BrazilReform = value

    @property
    def brazil_reform(self):
        """Alias for BrazilReform"""
        return self.BrazilReform

    @brazil_reform.setter
    def brazil_reform(self, value):
        """Alias for BrazilReform.setter"""
        self.BrazilReform = value

    @property
    def DictLang(self):
        return self.com_object.DictLang

    @DictLang.setter
    def DictLang(self, value):
        self.com_object.DictLang = value

    @property
    def dictlang(self):
        """Alias for DictLang"""
        return self.DictLang

    @dictlang.setter
    def dictlang(self, value):
        """Alias for DictLang.setter"""
        self.DictLang = value

    @property
    def dict_lang(self):
        """Alias for DictLang"""
        return self.DictLang

    @dict_lang.setter
    def dict_lang(self, value):
        """Alias for DictLang.setter"""
        self.DictLang = value

    @property
    def GermanPostReform(self):
        return self.com_object.GermanPostReform

    @GermanPostReform.setter
    def GermanPostReform(self, value):
        self.com_object.GermanPostReform = value

    @property
    def germanpostreform(self):
        """Alias for GermanPostReform"""
        return self.GermanPostReform

    @germanpostreform.setter
    def germanpostreform(self, value):
        """Alias for GermanPostReform.setter"""
        self.GermanPostReform = value

    @property
    def german_post_reform(self):
        """Alias for GermanPostReform"""
        return self.GermanPostReform

    @german_post_reform.setter
    def german_post_reform(self, value):
        """Alias for GermanPostReform.setter"""
        self.GermanPostReform = value

    @property
    def HebrewModes(self):
        return XlHebrewModes(self.com_object.HebrewModes)

    @HebrewModes.setter
    def HebrewModes(self, value):
        self.com_object.HebrewModes = value

    @property
    def hebrewmodes(self):
        """Alias for HebrewModes"""
        return self.HebrewModes

    @hebrewmodes.setter
    def hebrewmodes(self, value):
        """Alias for HebrewModes.setter"""
        self.HebrewModes = value

    @property
    def hebrew_modes(self):
        """Alias for HebrewModes"""
        return self.HebrewModes

    @hebrew_modes.setter
    def hebrew_modes(self, value):
        """Alias for HebrewModes.setter"""
        self.HebrewModes = value

    @property
    def IgnoreCaps(self):
        return self.com_object.IgnoreCaps

    @IgnoreCaps.setter
    def IgnoreCaps(self, value):
        self.com_object.IgnoreCaps = value

    @property
    def ignorecaps(self):
        """Alias for IgnoreCaps"""
        return self.IgnoreCaps

    @ignorecaps.setter
    def ignorecaps(self, value):
        """Alias for IgnoreCaps.setter"""
        self.IgnoreCaps = value

    @property
    def ignore_caps(self):
        """Alias for IgnoreCaps"""
        return self.IgnoreCaps

    @ignore_caps.setter
    def ignore_caps(self, value):
        """Alias for IgnoreCaps.setter"""
        self.IgnoreCaps = value

    @property
    def IgnoreFileNames(self):
        return self.com_object.IgnoreFileNames

    @IgnoreFileNames.setter
    def IgnoreFileNames(self, value):
        self.com_object.IgnoreFileNames = value

    @property
    def ignorefilenames(self):
        """Alias for IgnoreFileNames"""
        return self.IgnoreFileNames

    @ignorefilenames.setter
    def ignorefilenames(self, value):
        """Alias for IgnoreFileNames.setter"""
        self.IgnoreFileNames = value

    @property
    def ignore_file_names(self):
        """Alias for IgnoreFileNames"""
        return self.IgnoreFileNames

    @ignore_file_names.setter
    def ignore_file_names(self, value):
        """Alias for IgnoreFileNames.setter"""
        self.IgnoreFileNames = value

    @property
    def IgnoreMixedDigits(self):
        return self.com_object.IgnoreMixedDigits

    @IgnoreMixedDigits.setter
    def IgnoreMixedDigits(self, value):
        self.com_object.IgnoreMixedDigits = value

    @property
    def ignoremixeddigits(self):
        """Alias for IgnoreMixedDigits"""
        return self.IgnoreMixedDigits

    @ignoremixeddigits.setter
    def ignoremixeddigits(self, value):
        """Alias for IgnoreMixedDigits.setter"""
        self.IgnoreMixedDigits = value

    @property
    def ignore_mixed_digits(self):
        """Alias for IgnoreMixedDigits"""
        return self.IgnoreMixedDigits

    @ignore_mixed_digits.setter
    def ignore_mixed_digits(self, value):
        """Alias for IgnoreMixedDigits.setter"""
        self.IgnoreMixedDigits = value

    @property
    def KoreanCombineAux(self):
        return self.com_object.KoreanCombineAux

    @KoreanCombineAux.setter
    def KoreanCombineAux(self, value):
        self.com_object.KoreanCombineAux = value

    @property
    def koreancombineaux(self):
        """Alias for KoreanCombineAux"""
        return self.KoreanCombineAux

    @koreancombineaux.setter
    def koreancombineaux(self, value):
        """Alias for KoreanCombineAux.setter"""
        self.KoreanCombineAux = value

    @property
    def korean_combine_aux(self):
        """Alias for KoreanCombineAux"""
        return self.KoreanCombineAux

    @korean_combine_aux.setter
    def korean_combine_aux(self, value):
        """Alias for KoreanCombineAux.setter"""
        self.KoreanCombineAux = value

    @property
    def KoreanProcessCompound(self):
        return self.com_object.KoreanProcessCompound

    @KoreanProcessCompound.setter
    def KoreanProcessCompound(self, value):
        self.com_object.KoreanProcessCompound = value

    @property
    def koreanprocesscompound(self):
        """Alias for KoreanProcessCompound"""
        return self.KoreanProcessCompound

    @koreanprocesscompound.setter
    def koreanprocesscompound(self, value):
        """Alias for KoreanProcessCompound.setter"""
        self.KoreanProcessCompound = value

    @property
    def korean_process_compound(self):
        """Alias for KoreanProcessCompound"""
        return self.KoreanProcessCompound

    @korean_process_compound.setter
    def korean_process_compound(self, value):
        """Alias for KoreanProcessCompound.setter"""
        self.KoreanProcessCompound = value

    @property
    def KoreanUseAutoChangeList(self):
        return self.com_object.KoreanUseAutoChangeList

    @KoreanUseAutoChangeList.setter
    def KoreanUseAutoChangeList(self, value):
        self.com_object.KoreanUseAutoChangeList = value

    @property
    def koreanuseautochangelist(self):
        """Alias for KoreanUseAutoChangeList"""
        return self.KoreanUseAutoChangeList

    @koreanuseautochangelist.setter
    def koreanuseautochangelist(self, value):
        """Alias for KoreanUseAutoChangeList.setter"""
        self.KoreanUseAutoChangeList = value

    @property
    def korean_use_auto_change_list(self):
        """Alias for KoreanUseAutoChangeList"""
        return self.KoreanUseAutoChangeList

    @korean_use_auto_change_list.setter
    def korean_use_auto_change_list(self, value):
        """Alias for KoreanUseAutoChangeList.setter"""
        self.KoreanUseAutoChangeList = value

    @property
    def PortugalReform(self):
        return self.com_object.PortugalReform

    @PortugalReform.setter
    def PortugalReform(self, value):
        self.com_object.PortugalReform = value

    @property
    def portugalreform(self):
        """Alias for PortugalReform"""
        return self.PortugalReform

    @portugalreform.setter
    def portugalreform(self, value):
        """Alias for PortugalReform.setter"""
        self.PortugalReform = value

    @property
    def portugal_reform(self):
        """Alias for PortugalReform"""
        return self.PortugalReform

    @portugal_reform.setter
    def portugal_reform(self, value):
        """Alias for PortugalReform.setter"""
        self.PortugalReform = value

    @property
    def RussianStrictE(self):
        return self.com_object.RussianStrictE

    @RussianStrictE.setter
    def RussianStrictE(self, value):
        self.com_object.RussianStrictE = value

    @property
    def russianstricte(self):
        """Alias for RussianStrictE"""
        return self.RussianStrictE

    @russianstricte.setter
    def russianstricte(self, value):
        """Alias for RussianStrictE.setter"""
        self.RussianStrictE = value

    @property
    def russian_strict_e(self):
        """Alias for RussianStrictE"""
        return self.RussianStrictE

    @russian_strict_e.setter
    def russian_strict_e(self, value):
        """Alias for RussianStrictE.setter"""
        self.RussianStrictE = value

    @property
    def SpanishModes(self):
        return self.com_object.SpanishModes

    @SpanishModes.setter
    def SpanishModes(self, value):
        self.com_object.SpanishModes = value

    @property
    def spanishmodes(self):
        """Alias for SpanishModes"""
        return self.SpanishModes

    @spanishmodes.setter
    def spanishmodes(self, value):
        """Alias for SpanishModes.setter"""
        self.SpanishModes = value

    @property
    def spanish_modes(self):
        """Alias for SpanishModes"""
        return self.SpanishModes

    @spanish_modes.setter
    def spanish_modes(self, value):
        """Alias for SpanishModes.setter"""
        self.SpanishModes = value

    @property
    def SuggestMainOnly(self):
        return self.com_object.SuggestMainOnly

    @SuggestMainOnly.setter
    def SuggestMainOnly(self, value):
        self.com_object.SuggestMainOnly = value

    @property
    def suggestmainonly(self):
        """Alias for SuggestMainOnly"""
        return self.SuggestMainOnly

    @suggestmainonly.setter
    def suggestmainonly(self, value):
        """Alias for SuggestMainOnly.setter"""
        self.SuggestMainOnly = value

    @property
    def suggest_main_only(self):
        """Alias for SuggestMainOnly"""
        return self.SuggestMainOnly

    @suggest_main_only.setter
    def suggest_main_only(self, value):
        """Alias for SuggestMainOnly.setter"""
        self.SuggestMainOnly = value

    @property
    def UserDict(self):
        return self.com_object.UserDict

    @UserDict.setter
    def UserDict(self, value):
        self.com_object.UserDict = value

    @property
    def userdict(self):
        """Alias for UserDict"""
        return self.UserDict

    @userdict.setter
    def userdict(self, value):
        """Alias for UserDict.setter"""
        self.UserDict = value

    @property
    def user_dict(self):
        """Alias for UserDict"""
        return self.UserDict

    @user_dict.setter
    def user_dict(self, value):
        """Alias for UserDict.setter"""
        self.UserDict = value


class Style:

    def __init__(self, style=None):
        self.com_object= style

    @property
    def AddIndent(self):
        return self.com_object.AddIndent

    @AddIndent.setter
    def AddIndent(self, value):
        self.com_object.AddIndent = value

    @property
    def addindent(self):
        """Alias for AddIndent"""
        return self.AddIndent

    @addindent.setter
    def addindent(self, value):
        """Alias for AddIndent.setter"""
        self.AddIndent = value

    @property
    def add_indent(self):
        """Alias for AddIndent"""
        return self.AddIndent

    @add_indent.setter
    def add_indent(self, value):
        """Alias for AddIndent.setter"""
        self.AddIndent = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def BuiltIn(self):
        return self.com_object.BuiltIn

    @property
    def builtin(self):
        """Alias for BuiltIn"""
        return self.BuiltIn

    @property
    def built_in(self):
        """Alias for BuiltIn"""
        return self.BuiltIn

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def FormulaHidden(self):
        return self.com_object.FormulaHidden

    @FormulaHidden.setter
    def FormulaHidden(self, value):
        self.com_object.FormulaHidden = value

    @property
    def formulahidden(self):
        """Alias for FormulaHidden"""
        return self.FormulaHidden

    @formulahidden.setter
    def formulahidden(self, value):
        """Alias for FormulaHidden.setter"""
        self.FormulaHidden = value

    @property
    def formula_hidden(self):
        """Alias for FormulaHidden"""
        return self.FormulaHidden

    @formula_hidden.setter
    def formula_hidden(self, value):
        """Alias for FormulaHidden.setter"""
        self.FormulaHidden = value

    @property
    def HorizontalAlignment(self):
        return XlHAlign(self.com_object.HorizontalAlignment)

    @HorizontalAlignment.setter
    def HorizontalAlignment(self, value):
        self.com_object.HorizontalAlignment = value

    @property
    def horizontalalignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontalalignment.setter
    def horizontalalignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def horizontal_alignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def IncludeAlignment(self):
        return self.com_object.IncludeAlignment

    @IncludeAlignment.setter
    def IncludeAlignment(self, value):
        self.com_object.IncludeAlignment = value

    @property
    def includealignment(self):
        """Alias for IncludeAlignment"""
        return self.IncludeAlignment

    @includealignment.setter
    def includealignment(self, value):
        """Alias for IncludeAlignment.setter"""
        self.IncludeAlignment = value

    @property
    def include_alignment(self):
        """Alias for IncludeAlignment"""
        return self.IncludeAlignment

    @include_alignment.setter
    def include_alignment(self, value):
        """Alias for IncludeAlignment.setter"""
        self.IncludeAlignment = value

    @property
    def IncludeBorder(self):
        return self.com_object.IncludeBorder

    @IncludeBorder.setter
    def IncludeBorder(self, value):
        self.com_object.IncludeBorder = value

    @property
    def includeborder(self):
        """Alias for IncludeBorder"""
        return self.IncludeBorder

    @includeborder.setter
    def includeborder(self, value):
        """Alias for IncludeBorder.setter"""
        self.IncludeBorder = value

    @property
    def include_border(self):
        """Alias for IncludeBorder"""
        return self.IncludeBorder

    @include_border.setter
    def include_border(self, value):
        """Alias for IncludeBorder.setter"""
        self.IncludeBorder = value

    @property
    def IncludeFont(self):
        return self.com_object.IncludeFont

    @IncludeFont.setter
    def IncludeFont(self, value):
        self.com_object.IncludeFont = value

    @property
    def includefont(self):
        """Alias for IncludeFont"""
        return self.IncludeFont

    @includefont.setter
    def includefont(self, value):
        """Alias for IncludeFont.setter"""
        self.IncludeFont = value

    @property
    def include_font(self):
        """Alias for IncludeFont"""
        return self.IncludeFont

    @include_font.setter
    def include_font(self, value):
        """Alias for IncludeFont.setter"""
        self.IncludeFont = value

    @property
    def IncludeNumber(self):
        return self.com_object.IncludeNumber

    @IncludeNumber.setter
    def IncludeNumber(self, value):
        self.com_object.IncludeNumber = value

    @property
    def includenumber(self):
        """Alias for IncludeNumber"""
        return self.IncludeNumber

    @includenumber.setter
    def includenumber(self, value):
        """Alias for IncludeNumber.setter"""
        self.IncludeNumber = value

    @property
    def include_number(self):
        """Alias for IncludeNumber"""
        return self.IncludeNumber

    @include_number.setter
    def include_number(self, value):
        """Alias for IncludeNumber.setter"""
        self.IncludeNumber = value

    @property
    def IncludePatterns(self):
        return self.com_object.IncludePatterns

    @IncludePatterns.setter
    def IncludePatterns(self, value):
        self.com_object.IncludePatterns = value

    @property
    def includepatterns(self):
        """Alias for IncludePatterns"""
        return self.IncludePatterns

    @includepatterns.setter
    def includepatterns(self, value):
        """Alias for IncludePatterns.setter"""
        self.IncludePatterns = value

    @property
    def include_patterns(self):
        """Alias for IncludePatterns"""
        return self.IncludePatterns

    @include_patterns.setter
    def include_patterns(self, value):
        """Alias for IncludePatterns.setter"""
        self.IncludePatterns = value

    @property
    def IncludeProtection(self):
        return self.com_object.IncludeProtection

    @IncludeProtection.setter
    def IncludeProtection(self, value):
        self.com_object.IncludeProtection = value

    @property
    def includeprotection(self):
        """Alias for IncludeProtection"""
        return self.IncludeProtection

    @includeprotection.setter
    def includeprotection(self, value):
        """Alias for IncludeProtection.setter"""
        self.IncludeProtection = value

    @property
    def include_protection(self):
        """Alias for IncludeProtection"""
        return self.IncludeProtection

    @include_protection.setter
    def include_protection(self, value):
        """Alias for IncludeProtection.setter"""
        self.IncludeProtection = value

    @property
    def IndentLevel(self):
        return self.com_object.IndentLevel

    @IndentLevel.setter
    def IndentLevel(self, value):
        self.com_object.IndentLevel = value

    @property
    def indentlevel(self):
        """Alias for IndentLevel"""
        return self.IndentLevel

    @indentlevel.setter
    def indentlevel(self, value):
        """Alias for IndentLevel.setter"""
        self.IndentLevel = value

    @property
    def indent_level(self):
        """Alias for IndentLevel"""
        return self.IndentLevel

    @indent_level.setter
    def indent_level(self, value):
        """Alias for IndentLevel.setter"""
        self.IndentLevel = value

    @property
    def Interior(self):
        return Interior(self.com_object.Interior)

    @property
    def interior(self):
        """Alias for Interior"""
        return self.Interior

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def MergeCells(self):
        return self.com_object.MergeCells

    @MergeCells.setter
    def MergeCells(self, value):
        self.com_object.MergeCells = value

    @property
    def mergecells(self):
        """Alias for MergeCells"""
        return self.MergeCells

    @mergecells.setter
    def mergecells(self, value):
        """Alias for MergeCells.setter"""
        self.MergeCells = value

    @property
    def merge_cells(self):
        """Alias for MergeCells"""
        return self.MergeCells

    @merge_cells.setter
    def merge_cells(self, value):
        """Alias for MergeCells.setter"""
        self.MergeCells = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NameLocal(self):
        return self.com_object.NameLocal

    @NameLocal.setter
    def NameLocal(self, value):
        self.com_object.NameLocal = value

    @property
    def namelocal(self):
        """Alias for NameLocal"""
        return self.NameLocal

    @namelocal.setter
    def namelocal(self, value):
        """Alias for NameLocal.setter"""
        self.NameLocal = value

    @property
    def name_local(self):
        """Alias for NameLocal"""
        return self.NameLocal

    @name_local.setter
    def name_local(self, value):
        """Alias for NameLocal.setter"""
        self.NameLocal = value

    @property
    def NumberFormat(self):
        return self.com_object.NumberFormat

    @NumberFormat.setter
    def NumberFormat(self, value):
        self.com_object.NumberFormat = value

    @property
    def numberformat(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @numberformat.setter
    def numberformat(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def number_format(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @number_format.setter
    def number_format(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def NumberFormatLocal(self):
        return self.com_object.NumberFormatLocal

    @NumberFormatLocal.setter
    def NumberFormatLocal(self, value):
        self.com_object.NumberFormatLocal = value

    @property
    def numberformatlocal(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @numberformatlocal.setter
    def numberformatlocal(self, value):
        """Alias for NumberFormatLocal.setter"""
        self.NumberFormatLocal = value

    @property
    def number_format_local(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @number_format_local.setter
    def number_format_local(self, value):
        """Alias for NumberFormatLocal.setter"""
        self.NumberFormatLocal = value

    @property
    def Orientation(self):
        return XlOrientation(self.com_object.Orientation)

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ReadingOrder(self):
        return self.com_object.ReadingOrder

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def ShrinkToFit(self):
        return self.com_object.ShrinkToFit

    @ShrinkToFit.setter
    def ShrinkToFit(self, value):
        self.com_object.ShrinkToFit = value

    @property
    def shrinktofit(self):
        """Alias for ShrinkToFit"""
        return self.ShrinkToFit

    @shrinktofit.setter
    def shrinktofit(self, value):
        """Alias for ShrinkToFit.setter"""
        self.ShrinkToFit = value

    @property
    def shrink_to_fit(self):
        """Alias for ShrinkToFit"""
        return self.ShrinkToFit

    @shrink_to_fit.setter
    def shrink_to_fit(self, value):
        """Alias for ShrinkToFit.setter"""
        self.ShrinkToFit = value

    @property
    def Value(self):
        return self.com_object.Value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @property
    def VerticalAlignment(self):
        return XlVAlign(self.com_object.VerticalAlignment)

    @VerticalAlignment.setter
    def VerticalAlignment(self, value):
        self.com_object.VerticalAlignment = value

    @property
    def verticalalignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @verticalalignment.setter
    def verticalalignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def vertical_alignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @vertical_alignment.setter
    def vertical_alignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def WrapText(self):
        return self.com_object.WrapText

    @WrapText.setter
    def WrapText(self, value):
        self.com_object.WrapText = value

    @property
    def wraptext(self):
        """Alias for WrapText"""
        return self.WrapText

    @wraptext.setter
    def wraptext(self, value):
        """Alias for WrapText.setter"""
        self.WrapText = value

    @property
    def wrap_text(self):
        """Alias for WrapText"""
        return self.WrapText

    @wrap_text.setter
    def wrap_text(self, value):
        """Alias for WrapText.setter"""
        self.WrapText = value

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class Styles:

    def __init__(self, styles=None):
        self.com_object= styles

    def __call__(self, item):
        return Style(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        return Style(self.com_object.Add(*arguments))

    def add(self, Name=None):
        """Alias for Add"""
        arguments = [Name]
        return self.Add(*arguments)

    def Merge(self, Workbook=None):
        arguments = com_arguments([unwrap(a) for a in [Workbook]])
        return self.com_object.Merge(*arguments)

    def merge(self, Workbook=None):
        """Alias for Merge"""
        arguments = [Workbook]
        return self.Merge(*arguments)


class Tab:

    def __init__(self, tab=None):
        self.com_object= tab

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Color(self):
        return RGB(self.com_object.Color)

    @Color.setter
    def Color(self, value):
        self.com_object.Color = value

    @property
    def color(self):
        """Alias for Color"""
        return self.Color

    @color.setter
    def color(self, value):
        """Alias for Color.setter"""
        self.Color = value

    @property
    def ColorIndex(self):
        return self.com_object.ColorIndex

    @ColorIndex.setter
    def ColorIndex(self, value):
        self.com_object.ColorIndex = value

    @property
    def colorindex(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @colorindex.setter
    def colorindex(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def color_index(self):
        """Alias for ColorIndex"""
        return self.ColorIndex

    @color_index.setter
    def color_index(self, value):
        """Alias for ColorIndex.setter"""
        self.ColorIndex = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ThemeColor(self):
        return XlThemeColor(self.com_object.ThemeColor)

    @ThemeColor.setter
    def ThemeColor(self, value):
        self.com_object.ThemeColor = value

    @property
    def themecolor(self):
        """Alias for ThemeColor"""
        return self.ThemeColor

    @themecolor.setter
    def themecolor(self, value):
        """Alias for ThemeColor.setter"""
        self.ThemeColor = value

    @property
    def theme_color(self):
        """Alias for ThemeColor"""
        return self.ThemeColor

    @theme_color.setter
    def theme_color(self, value):
        """Alias for ThemeColor.setter"""
        self.ThemeColor = value

    @property
    def TintAndShade(self):
        return self.com_object.TintAndShade

    @TintAndShade.setter
    def TintAndShade(self, value):
        self.com_object.TintAndShade = value

    @property
    def tintandshade(self):
        """Alias for TintAndShade"""
        return self.TintAndShade

    @tintandshade.setter
    def tintandshade(self, value):
        """Alias for TintAndShade.setter"""
        self.TintAndShade = value

    @property
    def tint_and_shade(self):
        """Alias for TintAndShade"""
        return self.TintAndShade

    @tint_and_shade.setter
    def tint_and_shade(self, value):
        """Alias for TintAndShade.setter"""
        self.TintAndShade = value


class TableObject:

    def __init__(self, tableobject=None):
        self.com_object= tableobject

    @property
    def AdjustColumnWidth(self):
        return self.com_object.AdjustColumnWidth

    @AdjustColumnWidth.setter
    def AdjustColumnWidth(self, value):
        self.com_object.AdjustColumnWidth = value

    @property
    def adjustcolumnwidth(self):
        """Alias for AdjustColumnWidth"""
        return self.AdjustColumnWidth

    @adjustcolumnwidth.setter
    def adjustcolumnwidth(self, value):
        """Alias for AdjustColumnWidth.setter"""
        self.AdjustColumnWidth = value

    @property
    def adjust_column_width(self):
        """Alias for AdjustColumnWidth"""
        return self.AdjustColumnWidth

    @adjust_column_width.setter
    def adjust_column_width(self, value):
        """Alias for AdjustColumnWidth.setter"""
        self.AdjustColumnWidth = value

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Destination(self):
        return TableObject(self.com_object.Destination)

    @property
    def destination(self):
        """Alias for Destination"""
        return self.Destination

    @property
    def EnableEditing(self):
        return self.com_object.EnableEditing

    @EnableEditing.setter
    def EnableEditing(self, value):
        self.com_object.EnableEditing = value

    @property
    def enableediting(self):
        """Alias for EnableEditing"""
        return self.EnableEditing

    @enableediting.setter
    def enableediting(self, value):
        """Alias for EnableEditing.setter"""
        self.EnableEditing = value

    @property
    def enable_editing(self):
        """Alias for EnableEditing"""
        return self.EnableEditing

    @enable_editing.setter
    def enable_editing(self, value):
        """Alias for EnableEditing.setter"""
        self.EnableEditing = value

    @property
    def EnableRefresh(self):
        return self.com_object.EnableRefresh

    @EnableRefresh.setter
    def EnableRefresh(self, value):
        self.com_object.EnableRefresh = value

    @property
    def enablerefresh(self):
        """Alias for EnableRefresh"""
        return self.EnableRefresh

    @enablerefresh.setter
    def enablerefresh(self, value):
        """Alias for EnableRefresh.setter"""
        self.EnableRefresh = value

    @property
    def enable_refresh(self):
        """Alias for EnableRefresh"""
        return self.EnableRefresh

    @enable_refresh.setter
    def enable_refresh(self, value):
        """Alias for EnableRefresh.setter"""
        self.EnableRefresh = value

    @property
    def FetchedRowOverflow(self):
        return self.com_object.FetchedRowOverflow

    @property
    def fetchedrowoverflow(self):
        """Alias for FetchedRowOverflow"""
        return self.FetchedRowOverflow

    @property
    def fetched_row_overflow(self):
        """Alias for FetchedRowOverflow"""
        return self.FetchedRowOverflow

    @property
    def ListObject(self):
        return ListObject(self.com_object.ListObject)

    @property
    def listobject(self):
        """Alias for ListObject"""
        return self.ListObject

    @property
    def list_object(self):
        """Alias for ListObject"""
        return self.ListObject

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PreserveColumnInfo(self):
        return self.com_object.PreserveColumnInfo

    @PreserveColumnInfo.setter
    def PreserveColumnInfo(self, value):
        self.com_object.PreserveColumnInfo = value

    @property
    def preservecolumninfo(self):
        """Alias for PreserveColumnInfo"""
        return self.PreserveColumnInfo

    @preservecolumninfo.setter
    def preservecolumninfo(self, value):
        """Alias for PreserveColumnInfo.setter"""
        self.PreserveColumnInfo = value

    @property
    def preserve_column_info(self):
        """Alias for PreserveColumnInfo"""
        return self.PreserveColumnInfo

    @preserve_column_info.setter
    def preserve_column_info(self, value):
        """Alias for PreserveColumnInfo.setter"""
        self.PreserveColumnInfo = value

    @property
    def PreserveFormatting(self):
        return self.com_object.PreserveFormatting

    @PreserveFormatting.setter
    def PreserveFormatting(self, value):
        self.com_object.PreserveFormatting = value

    @property
    def preserveformatting(self):
        """Alias for PreserveFormatting"""
        return self.PreserveFormatting

    @preserveformatting.setter
    def preserveformatting(self, value):
        """Alias for PreserveFormatting.setter"""
        self.PreserveFormatting = value

    @property
    def preserve_formatting(self):
        """Alias for PreserveFormatting"""
        return self.PreserveFormatting

    @preserve_formatting.setter
    def preserve_formatting(self, value):
        """Alias for PreserveFormatting.setter"""
        self.PreserveFormatting = value

    @property
    def RefreshStyle(self):
        return XlCellInsertionMode(self.com_object.RefreshStyle)

    @RefreshStyle.setter
    def RefreshStyle(self, value):
        self.com_object.RefreshStyle = value

    @property
    def refreshstyle(self):
        """Alias for RefreshStyle"""
        return self.RefreshStyle

    @refreshstyle.setter
    def refreshstyle(self, value):
        """Alias for RefreshStyle.setter"""
        self.RefreshStyle = value

    @property
    def refresh_style(self):
        """Alias for RefreshStyle"""
        return self.RefreshStyle

    @refresh_style.setter
    def refresh_style(self, value):
        """Alias for RefreshStyle.setter"""
        self.RefreshStyle = value

    @property
    def ResultRange(self):
        return Range(self.com_object.ResultRange)

    @property
    def resultrange(self):
        """Alias for ResultRange"""
        return self.ResultRange

    @property
    def result_range(self):
        """Alias for ResultRange"""
        return self.ResultRange

    @property
    def RowNumbers(self):
        return self.com_object.RowNumbers

    @RowNumbers.setter
    def RowNumbers(self, value):
        self.com_object.RowNumbers = value

    @property
    def rownumbers(self):
        """Alias for RowNumbers"""
        return self.RowNumbers

    @rownumbers.setter
    def rownumbers(self, value):
        """Alias for RowNumbers.setter"""
        self.RowNumbers = value

    @property
    def row_numbers(self):
        """Alias for RowNumbers"""
        return self.RowNumbers

    @row_numbers.setter
    def row_numbers(self, value):
        """Alias for RowNumbers.setter"""
        self.RowNumbers = value

    @property
    def WorkbookConnection(self):
        return WorkbookConnection(self.com_object.WorkbookConnection)

    @property
    def workbookconnection(self):
        """Alias for WorkbookConnection"""
        return self.WorkbookConnection

    @property
    def workbook_connection(self):
        """Alias for WorkbookConnection"""
        return self.WorkbookConnection

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Refresh(self):
        return self.com_object.Refresh()

    def refresh(self):
        """Alias for Refresh"""
        return self.Refresh()


class TableStyle:

    def __init__(self, tablestyle=None):
        self.com_object= tablestyle

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BuiltIn(self):
        return self.com_object.BuiltIn

    @property
    def builtin(self):
        """Alias for BuiltIn"""
        return self.BuiltIn

    @property
    def built_in(self):
        """Alias for BuiltIn"""
        return self.BuiltIn

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NameLocal(self):
        return self.com_object.NameLocal

    @NameLocal.setter
    def NameLocal(self, value):
        self.com_object.NameLocal = value

    @property
    def namelocal(self):
        """Alias for NameLocal"""
        return self.NameLocal

    @namelocal.setter
    def namelocal(self, value):
        """Alias for NameLocal.setter"""
        self.NameLocal = value

    @property
    def name_local(self):
        """Alias for NameLocal"""
        return self.NameLocal

    @name_local.setter
    def name_local(self, value):
        """Alias for NameLocal.setter"""
        self.NameLocal = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ShowAsAvailablePivotTableStyle(self):
        return self.com_object.ShowAsAvailablePivotTableStyle

    @ShowAsAvailablePivotTableStyle.setter
    def ShowAsAvailablePivotTableStyle(self, value):
        self.com_object.ShowAsAvailablePivotTableStyle = value

    @property
    def showasavailablepivottablestyle(self):
        """Alias for ShowAsAvailablePivotTableStyle"""
        return self.ShowAsAvailablePivotTableStyle

    @showasavailablepivottablestyle.setter
    def showasavailablepivottablestyle(self, value):
        """Alias for ShowAsAvailablePivotTableStyle.setter"""
        self.ShowAsAvailablePivotTableStyle = value

    @property
    def show_as_available_pivot_table_style(self):
        """Alias for ShowAsAvailablePivotTableStyle"""
        return self.ShowAsAvailablePivotTableStyle

    @show_as_available_pivot_table_style.setter
    def show_as_available_pivot_table_style(self, value):
        """Alias for ShowAsAvailablePivotTableStyle.setter"""
        self.ShowAsAvailablePivotTableStyle = value

    @property
    def ShowAsAvailableSlicerStyle(self):
        return self.com_object.ShowAsAvailableSlicerStyle

    @ShowAsAvailableSlicerStyle.setter
    def ShowAsAvailableSlicerStyle(self, value):
        self.com_object.ShowAsAvailableSlicerStyle = value

    @property
    def showasavailableslicerstyle(self):
        """Alias for ShowAsAvailableSlicerStyle"""
        return self.ShowAsAvailableSlicerStyle

    @showasavailableslicerstyle.setter
    def showasavailableslicerstyle(self, value):
        """Alias for ShowAsAvailableSlicerStyle.setter"""
        self.ShowAsAvailableSlicerStyle = value

    @property
    def show_as_available_slicer_style(self):
        """Alias for ShowAsAvailableSlicerStyle"""
        return self.ShowAsAvailableSlicerStyle

    @show_as_available_slicer_style.setter
    def show_as_available_slicer_style(self, value):
        """Alias for ShowAsAvailableSlicerStyle.setter"""
        self.ShowAsAvailableSlicerStyle = value

    @property
    def ShowAsAvailableTableStyle(self):
        return self.com_object.ShowAsAvailableTableStyle

    @ShowAsAvailableTableStyle.setter
    def ShowAsAvailableTableStyle(self, value):
        self.com_object.ShowAsAvailableTableStyle = value

    @property
    def showasavailabletablestyle(self):
        """Alias for ShowAsAvailableTableStyle"""
        return self.ShowAsAvailableTableStyle

    @showasavailabletablestyle.setter
    def showasavailabletablestyle(self, value):
        """Alias for ShowAsAvailableTableStyle.setter"""
        self.ShowAsAvailableTableStyle = value

    @property
    def show_as_available_table_style(self):
        """Alias for ShowAsAvailableTableStyle"""
        return self.ShowAsAvailableTableStyle

    @show_as_available_table_style.setter
    def show_as_available_table_style(self, value):
        """Alias for ShowAsAvailableTableStyle.setter"""
        self.ShowAsAvailableTableStyle = value

    @property
    def ShowAsAvailableTimelineStyle(self):
        return self.com_object.ShowAsAvailableTimelineStyle

    @ShowAsAvailableTimelineStyle.setter
    def ShowAsAvailableTimelineStyle(self, value):
        self.com_object.ShowAsAvailableTimelineStyle = value

    @property
    def showasavailabletimelinestyle(self):
        """Alias for ShowAsAvailableTimelineStyle"""
        return self.ShowAsAvailableTimelineStyle

    @showasavailabletimelinestyle.setter
    def showasavailabletimelinestyle(self, value):
        """Alias for ShowAsAvailableTimelineStyle.setter"""
        self.ShowAsAvailableTimelineStyle = value

    @property
    def show_as_available_timeline_style(self):
        """Alias for ShowAsAvailableTimelineStyle"""
        return self.ShowAsAvailableTimelineStyle

    @show_as_available_timeline_style.setter
    def show_as_available_timeline_style(self, value):
        """Alias for ShowAsAvailableTimelineStyle.setter"""
        self.ShowAsAvailableTimelineStyle = value

    @property
    def TableStyleElements(self):
        return TableStyleElements(self.com_object.TableStyleElements)

    @property
    def tablestyleelements(self):
        """Alias for TableStyleElements"""
        return self.TableStyleElements

    @property
    def table_style_elements(self):
        """Alias for TableStyleElements"""
        return self.TableStyleElements

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Duplicate(self, NewTableStyleName=None):
        arguments = com_arguments([unwrap(a) for a in [NewTableStyleName]])
        return TableStyle(self.com_object.Duplicate(*arguments))

    def duplicate(self, NewTableStyleName=None):
        """Alias for Duplicate"""
        arguments = [NewTableStyleName]
        return self.Duplicate(*arguments)


class TableStyleElement:

    def __init__(self, tablestyleelement=None):
        self.com_object= tablestyleelement

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def HasFormat(self):
        return self.com_object.HasFormat

    @property
    def hasformat(self):
        """Alias for HasFormat"""
        return self.HasFormat

    @property
    def has_format(self):
        """Alias for HasFormat"""
        return self.HasFormat

    @property
    def Interior(self):
        return Interior(self.com_object.Interior)

    @property
    def interior(self):
        """Alias for Interior"""
        return self.Interior

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def StripeSize(self):
        return self.com_object.StripeSize

    @StripeSize.setter
    def StripeSize(self, value):
        self.com_object.StripeSize = value

    @property
    def stripesize(self):
        """Alias for StripeSize"""
        return self.StripeSize

    @stripesize.setter
    def stripesize(self, value):
        """Alias for StripeSize.setter"""
        self.StripeSize = value

    @property
    def stripe_size(self):
        """Alias for StripeSize"""
        return self.StripeSize

    @stripe_size.setter
    def stripe_size(self, value):
        """Alias for StripeSize.setter"""
        self.StripeSize = value

    def Clear(self):
        self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()


class TableStyleElements:

    def __init__(self, tablestyleelements=None):
        self.com_object= tablestyleelements

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return TableStyleElement(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class TableStyles:

    def __init__(self, tablestyles=None):
        self.com_object= tablestyles

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, TableStyleName=None):
        arguments = com_arguments([unwrap(a) for a in [TableStyleName]])
        return TableStyle(self.com_object.Add(*arguments))

    def add(self, TableStyleName=None):
        """Alias for Add"""
        arguments = [TableStyleName]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return TableStyle(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class TextConnection:

    def __init__(self, textconnection=None):
        self.com_object= textconnection

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Connection(self):
        return self.com_object.Connection

    @Connection.setter
    def Connection(self, value):
        self.com_object.Connection = value

    @property
    def connection(self):
        """Alias for Connection"""
        return self.Connection

    @connection.setter
    def connection(self, value):
        """Alias for Connection.setter"""
        self.Connection = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def TextFileColumnDataTypes(self):
        return self.com_object.TextFileColumnDataTypes

    @TextFileColumnDataTypes.setter
    def TextFileColumnDataTypes(self, value):
        self.com_object.TextFileColumnDataTypes = value

    @property
    def textfilecolumndatatypes(self):
        """Alias for TextFileColumnDataTypes"""
        return self.TextFileColumnDataTypes

    @textfilecolumndatatypes.setter
    def textfilecolumndatatypes(self, value):
        """Alias for TextFileColumnDataTypes.setter"""
        self.TextFileColumnDataTypes = value

    @property
    def text_file_column_data_types(self):
        """Alias for TextFileColumnDataTypes"""
        return self.TextFileColumnDataTypes

    @text_file_column_data_types.setter
    def text_file_column_data_types(self, value):
        """Alias for TextFileColumnDataTypes.setter"""
        self.TextFileColumnDataTypes = value

    @property
    def TextFileCommaDelimiter(self):
        return self.com_object.TextFileCommaDelimiter

    @TextFileCommaDelimiter.setter
    def TextFileCommaDelimiter(self, value):
        self.com_object.TextFileCommaDelimiter = value

    @property
    def textfilecommadelimiter(self):
        """Alias for TextFileCommaDelimiter"""
        return self.TextFileCommaDelimiter

    @textfilecommadelimiter.setter
    def textfilecommadelimiter(self, value):
        """Alias for TextFileCommaDelimiter.setter"""
        self.TextFileCommaDelimiter = value

    @property
    def text_file_comma_delimiter(self):
        """Alias for TextFileCommaDelimiter"""
        return self.TextFileCommaDelimiter

    @text_file_comma_delimiter.setter
    def text_file_comma_delimiter(self, value):
        """Alias for TextFileCommaDelimiter.setter"""
        self.TextFileCommaDelimiter = value

    @property
    def TextFileConsecutiveDelimiter(self):
        return self.com_object.TextFileConsecutiveDelimiter

    @TextFileConsecutiveDelimiter.setter
    def TextFileConsecutiveDelimiter(self, value):
        self.com_object.TextFileConsecutiveDelimiter = value

    @property
    def textfileconsecutivedelimiter(self):
        """Alias for TextFileConsecutiveDelimiter"""
        return self.TextFileConsecutiveDelimiter

    @textfileconsecutivedelimiter.setter
    def textfileconsecutivedelimiter(self, value):
        """Alias for TextFileConsecutiveDelimiter.setter"""
        self.TextFileConsecutiveDelimiter = value

    @property
    def text_file_consecutive_delimiter(self):
        """Alias for TextFileConsecutiveDelimiter"""
        return self.TextFileConsecutiveDelimiter

    @text_file_consecutive_delimiter.setter
    def text_file_consecutive_delimiter(self, value):
        """Alias for TextFileConsecutiveDelimiter.setter"""
        self.TextFileConsecutiveDelimiter = value

    @property
    def TextFileDecimalSeparator(self):
        return self.com_object.TextFileDecimalSeparator

    @TextFileDecimalSeparator.setter
    def TextFileDecimalSeparator(self, value):
        self.com_object.TextFileDecimalSeparator = value

    @property
    def textfiledecimalseparator(self):
        """Alias for TextFileDecimalSeparator"""
        return self.TextFileDecimalSeparator

    @textfiledecimalseparator.setter
    def textfiledecimalseparator(self, value):
        """Alias for TextFileDecimalSeparator.setter"""
        self.TextFileDecimalSeparator = value

    @property
    def text_file_decimal_separator(self):
        """Alias for TextFileDecimalSeparator"""
        return self.TextFileDecimalSeparator

    @text_file_decimal_separator.setter
    def text_file_decimal_separator(self, value):
        """Alias for TextFileDecimalSeparator.setter"""
        self.TextFileDecimalSeparator = value

    @property
    def TextFileFixedColumnWidths(self):
        return self.com_object.TextFileFixedColumnWidths

    @TextFileFixedColumnWidths.setter
    def TextFileFixedColumnWidths(self, value):
        self.com_object.TextFileFixedColumnWidths = value

    @property
    def textfilefixedcolumnwidths(self):
        """Alias for TextFileFixedColumnWidths"""
        return self.TextFileFixedColumnWidths

    @textfilefixedcolumnwidths.setter
    def textfilefixedcolumnwidths(self, value):
        """Alias for TextFileFixedColumnWidths.setter"""
        self.TextFileFixedColumnWidths = value

    @property
    def text_file_fixed_column_widths(self):
        """Alias for TextFileFixedColumnWidths"""
        return self.TextFileFixedColumnWidths

    @text_file_fixed_column_widths.setter
    def text_file_fixed_column_widths(self, value):
        """Alias for TextFileFixedColumnWidths.setter"""
        self.TextFileFixedColumnWidths = value

    @property
    def TextFileHeaderRow(self):
        return self.com_object.TextFileHeaderRow

    @TextFileHeaderRow.setter
    def TextFileHeaderRow(self, value):
        self.com_object.TextFileHeaderRow = value

    @property
    def textfileheaderrow(self):
        """Alias for TextFileHeaderRow"""
        return self.TextFileHeaderRow

    @textfileheaderrow.setter
    def textfileheaderrow(self, value):
        """Alias for TextFileHeaderRow.setter"""
        self.TextFileHeaderRow = value

    @property
    def text_file_header_row(self):
        """Alias for TextFileHeaderRow"""
        return self.TextFileHeaderRow

    @text_file_header_row.setter
    def text_file_header_row(self, value):
        """Alias for TextFileHeaderRow.setter"""
        self.TextFileHeaderRow = value

    @property
    def TextFileOtherDelimiter(self):
        return self.com_object.TextFileOtherDelimiter

    @TextFileOtherDelimiter.setter
    def TextFileOtherDelimiter(self, value):
        self.com_object.TextFileOtherDelimiter = value

    @property
    def textfileotherdelimiter(self):
        """Alias for TextFileOtherDelimiter"""
        return self.TextFileOtherDelimiter

    @textfileotherdelimiter.setter
    def textfileotherdelimiter(self, value):
        """Alias for TextFileOtherDelimiter.setter"""
        self.TextFileOtherDelimiter = value

    @property
    def text_file_other_delimiter(self):
        """Alias for TextFileOtherDelimiter"""
        return self.TextFileOtherDelimiter

    @text_file_other_delimiter.setter
    def text_file_other_delimiter(self, value):
        """Alias for TextFileOtherDelimiter.setter"""
        self.TextFileOtherDelimiter = value

    @property
    def TextFileParseType(self):
        return XlTextParsingType(self.com_object.TextFileParseType)

    @TextFileParseType.setter
    def TextFileParseType(self, value):
        self.com_object.TextFileParseType = value

    @property
    def textfileparsetype(self):
        """Alias for TextFileParseType"""
        return self.TextFileParseType

    @textfileparsetype.setter
    def textfileparsetype(self, value):
        """Alias for TextFileParseType.setter"""
        self.TextFileParseType = value

    @property
    def text_file_parse_type(self):
        """Alias for TextFileParseType"""
        return self.TextFileParseType

    @text_file_parse_type.setter
    def text_file_parse_type(self, value):
        """Alias for TextFileParseType.setter"""
        self.TextFileParseType = value

    @property
    def TextFilePlatform(self):
        return XlPlatform(self.com_object.TextFilePlatform)

    @TextFilePlatform.setter
    def TextFilePlatform(self, value):
        self.com_object.TextFilePlatform = value

    @property
    def textfileplatform(self):
        """Alias for TextFilePlatform"""
        return self.TextFilePlatform

    @textfileplatform.setter
    def textfileplatform(self, value):
        """Alias for TextFilePlatform.setter"""
        self.TextFilePlatform = value

    @property
    def text_file_platform(self):
        """Alias for TextFilePlatform"""
        return self.TextFilePlatform

    @text_file_platform.setter
    def text_file_platform(self, value):
        """Alias for TextFilePlatform.setter"""
        self.TextFilePlatform = value

    @property
    def TextFilePromptOnRefresh(self):
        return self.com_object.TextFilePromptOnRefresh

    @TextFilePromptOnRefresh.setter
    def TextFilePromptOnRefresh(self, value):
        self.com_object.TextFilePromptOnRefresh = value

    @property
    def textfilepromptonrefresh(self):
        """Alias for TextFilePromptOnRefresh"""
        return self.TextFilePromptOnRefresh

    @textfilepromptonrefresh.setter
    def textfilepromptonrefresh(self, value):
        """Alias for TextFilePromptOnRefresh.setter"""
        self.TextFilePromptOnRefresh = value

    @property
    def text_file_prompt_on_refresh(self):
        """Alias for TextFilePromptOnRefresh"""
        return self.TextFilePromptOnRefresh

    @text_file_prompt_on_refresh.setter
    def text_file_prompt_on_refresh(self, value):
        """Alias for TextFilePromptOnRefresh.setter"""
        self.TextFilePromptOnRefresh = value

    @property
    def TextFileSemicolonDelimiter(self):
        return self.com_object.TextFileSemicolonDelimiter

    @TextFileSemicolonDelimiter.setter
    def TextFileSemicolonDelimiter(self, value):
        self.com_object.TextFileSemicolonDelimiter = value

    @property
    def textfilesemicolondelimiter(self):
        """Alias for TextFileSemicolonDelimiter"""
        return self.TextFileSemicolonDelimiter

    @textfilesemicolondelimiter.setter
    def textfilesemicolondelimiter(self, value):
        """Alias for TextFileSemicolonDelimiter.setter"""
        self.TextFileSemicolonDelimiter = value

    @property
    def text_file_semicolon_delimiter(self):
        """Alias for TextFileSemicolonDelimiter"""
        return self.TextFileSemicolonDelimiter

    @text_file_semicolon_delimiter.setter
    def text_file_semicolon_delimiter(self, value):
        """Alias for TextFileSemicolonDelimiter.setter"""
        self.TextFileSemicolonDelimiter = value

    @property
    def TextFileSpaceDelimiter(self):
        return self.com_object.TextFileSpaceDelimiter

    @TextFileSpaceDelimiter.setter
    def TextFileSpaceDelimiter(self, value):
        self.com_object.TextFileSpaceDelimiter = value

    @property
    def textfilespacedelimiter(self):
        """Alias for TextFileSpaceDelimiter"""
        return self.TextFileSpaceDelimiter

    @textfilespacedelimiter.setter
    def textfilespacedelimiter(self, value):
        """Alias for TextFileSpaceDelimiter.setter"""
        self.TextFileSpaceDelimiter = value

    @property
    def text_file_space_delimiter(self):
        """Alias for TextFileSpaceDelimiter"""
        return self.TextFileSpaceDelimiter

    @text_file_space_delimiter.setter
    def text_file_space_delimiter(self, value):
        """Alias for TextFileSpaceDelimiter.setter"""
        self.TextFileSpaceDelimiter = value

    @property
    def TextFileStartRow(self):
        return self.com_object.TextFileStartRow

    @TextFileStartRow.setter
    def TextFileStartRow(self, value):
        self.com_object.TextFileStartRow = value

    @property
    def textfilestartrow(self):
        """Alias for TextFileStartRow"""
        return self.TextFileStartRow

    @textfilestartrow.setter
    def textfilestartrow(self, value):
        """Alias for TextFileStartRow.setter"""
        self.TextFileStartRow = value

    @property
    def text_file_start_row(self):
        """Alias for TextFileStartRow"""
        return self.TextFileStartRow

    @text_file_start_row.setter
    def text_file_start_row(self, value):
        """Alias for TextFileStartRow.setter"""
        self.TextFileStartRow = value

    @property
    def TextFileTabDelimiter(self):
        return self.com_object.TextFileTabDelimiter

    @TextFileTabDelimiter.setter
    def TextFileTabDelimiter(self, value):
        self.com_object.TextFileTabDelimiter = value

    @property
    def textfiletabdelimiter(self):
        """Alias for TextFileTabDelimiter"""
        return self.TextFileTabDelimiter

    @textfiletabdelimiter.setter
    def textfiletabdelimiter(self, value):
        """Alias for TextFileTabDelimiter.setter"""
        self.TextFileTabDelimiter = value

    @property
    def text_file_tab_delimiter(self):
        """Alias for TextFileTabDelimiter"""
        return self.TextFileTabDelimiter

    @text_file_tab_delimiter.setter
    def text_file_tab_delimiter(self, value):
        """Alias for TextFileTabDelimiter.setter"""
        self.TextFileTabDelimiter = value

    @property
    def TextFileTextQualifier(self):
        return XlTextQualifier(self.com_object.TextFileTextQualifier)

    @TextFileTextQualifier.setter
    def TextFileTextQualifier(self, value):
        self.com_object.TextFileTextQualifier = value

    @property
    def textfiletextqualifier(self):
        """Alias for TextFileTextQualifier"""
        return self.TextFileTextQualifier

    @textfiletextqualifier.setter
    def textfiletextqualifier(self, value):
        """Alias for TextFileTextQualifier.setter"""
        self.TextFileTextQualifier = value

    @property
    def text_file_text_qualifier(self):
        """Alias for TextFileTextQualifier"""
        return self.TextFileTextQualifier

    @text_file_text_qualifier.setter
    def text_file_text_qualifier(self, value):
        """Alias for TextFileTextQualifier.setter"""
        self.TextFileTextQualifier = value

    @property
    def TextFileThousandsSeparator(self):
        return self.com_object.TextFileThousandsSeparator

    @TextFileThousandsSeparator.setter
    def TextFileThousandsSeparator(self, value):
        self.com_object.TextFileThousandsSeparator = value

    @property
    def textfilethousandsseparator(self):
        """Alias for TextFileThousandsSeparator"""
        return self.TextFileThousandsSeparator

    @textfilethousandsseparator.setter
    def textfilethousandsseparator(self, value):
        """Alias for TextFileThousandsSeparator.setter"""
        self.TextFileThousandsSeparator = value

    @property
    def text_file_thousands_separator(self):
        """Alias for TextFileThousandsSeparator"""
        return self.TextFileThousandsSeparator

    @text_file_thousands_separator.setter
    def text_file_thousands_separator(self, value):
        """Alias for TextFileThousandsSeparator.setter"""
        self.TextFileThousandsSeparator = value

    @property
    def TextFileTrailingMinusNumbers(self):
        return self.com_object.TextFileTrailingMinusNumbers

    @TextFileTrailingMinusNumbers.setter
    def TextFileTrailingMinusNumbers(self, value):
        self.com_object.TextFileTrailingMinusNumbers = value

    @property
    def textfiletrailingminusnumbers(self):
        """Alias for TextFileTrailingMinusNumbers"""
        return self.TextFileTrailingMinusNumbers

    @textfiletrailingminusnumbers.setter
    def textfiletrailingminusnumbers(self, value):
        """Alias for TextFileTrailingMinusNumbers.setter"""
        self.TextFileTrailingMinusNumbers = value

    @property
    def text_file_trailing_minus_numbers(self):
        """Alias for TextFileTrailingMinusNumbers"""
        return self.TextFileTrailingMinusNumbers

    @text_file_trailing_minus_numbers.setter
    def text_file_trailing_minus_numbers(self, value):
        """Alias for TextFileTrailingMinusNumbers.setter"""
        self.TextFileTrailingMinusNumbers = value

    @property
    def TextFileVisualLayout(self):
        return XlTextVisualLayoutType(self.com_object.TextFileVisualLayout)

    @TextFileVisualLayout.setter
    def TextFileVisualLayout(self, value):
        self.com_object.TextFileVisualLayout = value

    @property
    def textfilevisuallayout(self):
        """Alias for TextFileVisualLayout"""
        return self.TextFileVisualLayout

    @textfilevisuallayout.setter
    def textfilevisuallayout(self, value):
        """Alias for TextFileVisualLayout.setter"""
        self.TextFileVisualLayout = value

    @property
    def text_file_visual_layout(self):
        """Alias for TextFileVisualLayout"""
        return self.TextFileVisualLayout

    @text_file_visual_layout.setter
    def text_file_visual_layout(self, value):
        """Alias for TextFileVisualLayout.setter"""
        self.TextFileVisualLayout = value


class TextEffectFormat:

    def __init__(self, texteffectformat=None):
        self.com_object= texteffectformat

    @property
    def Alignment(self):
        return self.com_object.Alignment

    @Alignment.setter
    def Alignment(self, value):
        self.com_object.Alignment = value

    @property
    def alignment(self):
        """Alias for Alignment"""
        return self.Alignment

    @alignment.setter
    def alignment(self, value):
        """Alias for Alignment.setter"""
        self.Alignment = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def FontBold(self):
        return self.com_object.FontBold

    @FontBold.setter
    def FontBold(self, value):
        self.com_object.FontBold = value

    @property
    def fontbold(self):
        """Alias for FontBold"""
        return self.FontBold

    @fontbold.setter
    def fontbold(self, value):
        """Alias for FontBold.setter"""
        self.FontBold = value

    @property
    def font_bold(self):
        """Alias for FontBold"""
        return self.FontBold

    @font_bold.setter
    def font_bold(self, value):
        """Alias for FontBold.setter"""
        self.FontBold = value

    @property
    def FontItalic(self):
        return self.com_object.FontItalic

    @FontItalic.setter
    def FontItalic(self, value):
        self.com_object.FontItalic = value

    @property
    def fontitalic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @fontitalic.setter
    def fontitalic(self, value):
        """Alias for FontItalic.setter"""
        self.FontItalic = value

    @property
    def font_italic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @font_italic.setter
    def font_italic(self, value):
        """Alias for FontItalic.setter"""
        self.FontItalic = value

    @property
    def FontName(self):
        return self.com_object.FontName

    @FontName.setter
    def FontName(self, value):
        self.com_object.FontName = value

    @property
    def fontname(self):
        """Alias for FontName"""
        return self.FontName

    @fontname.setter
    def fontname(self, value):
        """Alias for FontName.setter"""
        self.FontName = value

    @property
    def font_name(self):
        """Alias for FontName"""
        return self.FontName

    @font_name.setter
    def font_name(self, value):
        """Alias for FontName.setter"""
        self.FontName = value

    @property
    def FontSize(self):
        return self.com_object.FontSize

    @FontSize.setter
    def FontSize(self, value):
        self.com_object.FontSize = value

    @property
    def fontsize(self):
        """Alias for FontSize"""
        return self.FontSize

    @fontsize.setter
    def fontsize(self, value):
        """Alias for FontSize.setter"""
        self.FontSize = value

    @property
    def font_size(self):
        """Alias for FontSize"""
        return self.FontSize

    @font_size.setter
    def font_size(self, value):
        """Alias for FontSize.setter"""
        self.FontSize = value

    @property
    def KernedPairs(self):
        return self.com_object.KernedPairs

    @KernedPairs.setter
    def KernedPairs(self, value):
        self.com_object.KernedPairs = value

    @property
    def kernedpairs(self):
        """Alias for KernedPairs"""
        return self.KernedPairs

    @kernedpairs.setter
    def kernedpairs(self, value):
        """Alias for KernedPairs.setter"""
        self.KernedPairs = value

    @property
    def kerned_pairs(self):
        """Alias for KernedPairs"""
        return self.KernedPairs

    @kerned_pairs.setter
    def kerned_pairs(self, value):
        """Alias for KernedPairs.setter"""
        self.KernedPairs = value

    @property
    def NormalizedHeight(self):
        return self.com_object.NormalizedHeight

    @NormalizedHeight.setter
    def NormalizedHeight(self, value):
        self.com_object.NormalizedHeight = value

    @property
    def normalizedheight(self):
        """Alias for NormalizedHeight"""
        return self.NormalizedHeight

    @normalizedheight.setter
    def normalizedheight(self, value):
        """Alias for NormalizedHeight.setter"""
        self.NormalizedHeight = value

    @property
    def normalized_height(self):
        """Alias for NormalizedHeight"""
        return self.NormalizedHeight

    @normalized_height.setter
    def normalized_height(self, value):
        """Alias for NormalizedHeight.setter"""
        self.NormalizedHeight = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PresetShape(self):
        return self.com_object.PresetShape

    @PresetShape.setter
    def PresetShape(self, value):
        self.com_object.PresetShape = value

    @property
    def presetshape(self):
        """Alias for PresetShape"""
        return self.PresetShape

    @presetshape.setter
    def presetshape(self, value):
        """Alias for PresetShape.setter"""
        self.PresetShape = value

    @property
    def preset_shape(self):
        """Alias for PresetShape"""
        return self.PresetShape

    @preset_shape.setter
    def preset_shape(self, value):
        """Alias for PresetShape.setter"""
        self.PresetShape = value

    @property
    def PresetTextEffect(self):
        return self.com_object.PresetTextEffect

    @PresetTextEffect.setter
    def PresetTextEffect(self, value):
        self.com_object.PresetTextEffect = value

    @property
    def presettexteffect(self):
        """Alias for PresetTextEffect"""
        return self.PresetTextEffect

    @presettexteffect.setter
    def presettexteffect(self, value):
        """Alias for PresetTextEffect.setter"""
        self.PresetTextEffect = value

    @property
    def preset_text_effect(self):
        """Alias for PresetTextEffect"""
        return self.PresetTextEffect

    @preset_text_effect.setter
    def preset_text_effect(self, value):
        """Alias for PresetTextEffect.setter"""
        self.PresetTextEffect = value

    @property
    def RotatedChars(self):
        return self.com_object.RotatedChars

    @RotatedChars.setter
    def RotatedChars(self, value):
        self.com_object.RotatedChars = value

    @property
    def rotatedchars(self):
        """Alias for RotatedChars"""
        return self.RotatedChars

    @rotatedchars.setter
    def rotatedchars(self, value):
        """Alias for RotatedChars.setter"""
        self.RotatedChars = value

    @property
    def rotated_chars(self):
        """Alias for RotatedChars"""
        return self.RotatedChars

    @rotated_chars.setter
    def rotated_chars(self, value):
        """Alias for RotatedChars.setter"""
        self.RotatedChars = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def Tracking(self):
        return self.com_object.Tracking

    @Tracking.setter
    def Tracking(self, value):
        self.com_object.Tracking = value

    @property
    def tracking(self):
        """Alias for Tracking"""
        return self.Tracking

    @tracking.setter
    def tracking(self, value):
        """Alias for Tracking.setter"""
        self.Tracking = value

    def ToggleVerticalText(self):
        self.com_object.ToggleVerticalText()

    def toggleverticaltext(self):
        """Alias for ToggleVerticalText"""
        return self.ToggleVerticalText()

    def toggle_vertical_text(self):
        """Alias for ToggleVerticalText"""
        return self.ToggleVerticalText()


class TextFrame:

    def __init__(self, textframe=None):
        self.com_object= textframe

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoMargins(self):
        return self.com_object.AutoMargins

    @AutoMargins.setter
    def AutoMargins(self, value):
        self.com_object.AutoMargins = value

    @property
    def automargins(self):
        """Alias for AutoMargins"""
        return self.AutoMargins

    @automargins.setter
    def automargins(self, value):
        """Alias for AutoMargins.setter"""
        self.AutoMargins = value

    @property
    def auto_margins(self):
        """Alias for AutoMargins"""
        return self.AutoMargins

    @auto_margins.setter
    def auto_margins(self, value):
        """Alias for AutoMargins.setter"""
        self.AutoMargins = value

    @property
    def AutoSize(self):
        return self.com_object.AutoSize

    @AutoSize.setter
    def AutoSize(self, value):
        self.com_object.AutoSize = value

    @property
    def autosize(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @autosize.setter
    def autosize(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def auto_size(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @auto_size.setter
    def auto_size(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def HorizontalAlignment(self):
        return XlHAlign(self.com_object.HorizontalAlignment)

    @HorizontalAlignment.setter
    def HorizontalAlignment(self, value):
        self.com_object.HorizontalAlignment = value

    @property
    def horizontalalignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontalalignment.setter
    def horizontalalignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def horizontal_alignment(self):
        """Alias for HorizontalAlignment"""
        return self.HorizontalAlignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, value):
        """Alias for HorizontalAlignment.setter"""
        self.HorizontalAlignment = value

    @property
    def HorizontalOverflow(self):
        return self.com_object.HorizontalOverflow

    @HorizontalOverflow.setter
    def HorizontalOverflow(self, value):
        self.com_object.HorizontalOverflow = value

    @property
    def horizontaloverflow(self):
        """Alias for HorizontalOverflow"""
        return self.HorizontalOverflow

    @horizontaloverflow.setter
    def horizontaloverflow(self, value):
        """Alias for HorizontalOverflow.setter"""
        self.HorizontalOverflow = value

    @property
    def horizontal_overflow(self):
        """Alias for HorizontalOverflow"""
        return self.HorizontalOverflow

    @horizontal_overflow.setter
    def horizontal_overflow(self, value):
        """Alias for HorizontalOverflow.setter"""
        self.HorizontalOverflow = value

    @property
    def MarginBottom(self):
        return self.com_object.MarginBottom

    @MarginBottom.setter
    def MarginBottom(self, value):
        self.com_object.MarginBottom = value

    @property
    def marginbottom(self):
        """Alias for MarginBottom"""
        return self.MarginBottom

    @marginbottom.setter
    def marginbottom(self, value):
        """Alias for MarginBottom.setter"""
        self.MarginBottom = value

    @property
    def margin_bottom(self):
        """Alias for MarginBottom"""
        return self.MarginBottom

    @margin_bottom.setter
    def margin_bottom(self, value):
        """Alias for MarginBottom.setter"""
        self.MarginBottom = value

    @property
    def MarginLeft(self):
        return self.com_object.MarginLeft

    @MarginLeft.setter
    def MarginLeft(self, value):
        self.com_object.MarginLeft = value

    @property
    def marginleft(self):
        """Alias for MarginLeft"""
        return self.MarginLeft

    @marginleft.setter
    def marginleft(self, value):
        """Alias for MarginLeft.setter"""
        self.MarginLeft = value

    @property
    def margin_left(self):
        """Alias for MarginLeft"""
        return self.MarginLeft

    @margin_left.setter
    def margin_left(self, value):
        """Alias for MarginLeft.setter"""
        self.MarginLeft = value

    @property
    def MarginRight(self):
        return self.com_object.MarginRight

    @MarginRight.setter
    def MarginRight(self, value):
        self.com_object.MarginRight = value

    @property
    def marginright(self):
        """Alias for MarginRight"""
        return self.MarginRight

    @marginright.setter
    def marginright(self, value):
        """Alias for MarginRight.setter"""
        self.MarginRight = value

    @property
    def margin_right(self):
        """Alias for MarginRight"""
        return self.MarginRight

    @margin_right.setter
    def margin_right(self, value):
        """Alias for MarginRight.setter"""
        self.MarginRight = value

    @property
    def MarginTop(self):
        return self.com_object.MarginTop

    @MarginTop.setter
    def MarginTop(self, value):
        self.com_object.MarginTop = value

    @property
    def margintop(self):
        """Alias for MarginTop"""
        return self.MarginTop

    @margintop.setter
    def margintop(self, value):
        """Alias for MarginTop.setter"""
        self.MarginTop = value

    @property
    def margin_top(self):
        """Alias for MarginTop"""
        return self.MarginTop

    @margin_top.setter
    def margin_top(self, value):
        """Alias for MarginTop.setter"""
        self.MarginTop = value

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ReadingOrder(self):
        return self.com_object.ReadingOrder

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def VerticalAlignment(self):
        return XlVAlign(self.com_object.VerticalAlignment)

    @VerticalAlignment.setter
    def VerticalAlignment(self, value):
        self.com_object.VerticalAlignment = value

    @property
    def verticalalignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @verticalalignment.setter
    def verticalalignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def vertical_alignment(self):
        """Alias for VerticalAlignment"""
        return self.VerticalAlignment

    @vertical_alignment.setter
    def vertical_alignment(self, value):
        """Alias for VerticalAlignment.setter"""
        self.VerticalAlignment = value

    @property
    def VerticalOverflow(self):
        return self.com_object.VerticalOverflow

    @VerticalOverflow.setter
    def VerticalOverflow(self, value):
        self.com_object.VerticalOverflow = value

    @property
    def verticaloverflow(self):
        """Alias for VerticalOverflow"""
        return self.VerticalOverflow

    @verticaloverflow.setter
    def verticaloverflow(self, value):
        """Alias for VerticalOverflow.setter"""
        self.VerticalOverflow = value

    @property
    def vertical_overflow(self):
        """Alias for VerticalOverflow"""
        return self.VerticalOverflow

    @vertical_overflow.setter
    def vertical_overflow(self, value):
        """Alias for VerticalOverflow.setter"""
        self.VerticalOverflow = value

    def Characters(self, Start=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [Start, Length]])
        return Characters(self.com_object.Characters(*arguments))

    def characters(self, Start=None, Length=None):
        """Alias for Characters"""
        arguments = [Start, Length]
        return self.Characters(*arguments)


class TextFrame2:

    def __init__(self, textframe2=None):
        self.com_object= textframe2

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoSize(self):
        return self.com_object.AutoSize

    @AutoSize.setter
    def AutoSize(self, value):
        self.com_object.AutoSize = value

    @property
    def autosize(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @autosize.setter
    def autosize(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def auto_size(self):
        """Alias for AutoSize"""
        return self.AutoSize

    @auto_size.setter
    def auto_size(self, value):
        """Alias for AutoSize.setter"""
        self.AutoSize = value

    @property
    def Column(self):
        return self.com_object.Column

    @property
    def column(self):
        """Alias for Column"""
        return self.Column

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def HasText(self):
        return self.com_object.HasText

    @property
    def hastext(self):
        """Alias for HasText"""
        return self.HasText

    @property
    def has_text(self):
        """Alias for HasText"""
        return self.HasText

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def MarginBottom(self):
        return self.com_object.MarginBottom

    @MarginBottom.setter
    def MarginBottom(self, value):
        self.com_object.MarginBottom = value

    @property
    def marginbottom(self):
        """Alias for MarginBottom"""
        return self.MarginBottom

    @marginbottom.setter
    def marginbottom(self, value):
        """Alias for MarginBottom.setter"""
        self.MarginBottom = value

    @property
    def margin_bottom(self):
        """Alias for MarginBottom"""
        return self.MarginBottom

    @margin_bottom.setter
    def margin_bottom(self, value):
        """Alias for MarginBottom.setter"""
        self.MarginBottom = value

    @property
    def MarginLeft(self):
        return self.com_object.MarginLeft

    @MarginLeft.setter
    def MarginLeft(self, value):
        self.com_object.MarginLeft = value

    @property
    def marginleft(self):
        """Alias for MarginLeft"""
        return self.MarginLeft

    @marginleft.setter
    def marginleft(self, value):
        """Alias for MarginLeft.setter"""
        self.MarginLeft = value

    @property
    def margin_left(self):
        """Alias for MarginLeft"""
        return self.MarginLeft

    @margin_left.setter
    def margin_left(self, value):
        """Alias for MarginLeft.setter"""
        self.MarginLeft = value

    @property
    def MarginRight(self):
        return self.com_object.MarginRight

    @MarginRight.setter
    def MarginRight(self, value):
        self.com_object.MarginRight = value

    @property
    def marginright(self):
        """Alias for MarginRight"""
        return self.MarginRight

    @marginright.setter
    def marginright(self, value):
        """Alias for MarginRight.setter"""
        self.MarginRight = value

    @property
    def margin_right(self):
        """Alias for MarginRight"""
        return self.MarginRight

    @margin_right.setter
    def margin_right(self, value):
        """Alias for MarginRight.setter"""
        self.MarginRight = value

    @property
    def MarginTop(self):
        return self.com_object.MarginTop

    @MarginTop.setter
    def MarginTop(self, value):
        self.com_object.MarginTop = value

    @property
    def margintop(self):
        """Alias for MarginTop"""
        return self.MarginTop

    @margintop.setter
    def margintop(self, value):
        """Alias for MarginTop.setter"""
        self.MarginTop = value

    @property
    def margin_top(self):
        """Alias for MarginTop"""
        return self.MarginTop

    @margin_top.setter
    def margin_top(self, value):
        """Alias for MarginTop.setter"""
        self.MarginTop = value

    @property
    def NoTextRotation(self):
        return self.com_object.NoTextRotation

    @NoTextRotation.setter
    def NoTextRotation(self, value):
        self.com_object.NoTextRotation = value

    @property
    def notextrotation(self):
        """Alias for NoTextRotation"""
        return self.NoTextRotation

    @notextrotation.setter
    def notextrotation(self, value):
        """Alias for NoTextRotation.setter"""
        self.NoTextRotation = value

    @property
    def no_text_rotation(self):
        """Alias for NoTextRotation"""
        return self.NoTextRotation

    @no_text_rotation.setter
    def no_text_rotation(self, value):
        """Alias for NoTextRotation.setter"""
        self.NoTextRotation = value

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PathFormat(self):
        return self.com_object.PathFormat

    @PathFormat.setter
    def PathFormat(self, value):
        self.com_object.PathFormat = value

    @property
    def pathformat(self):
        """Alias for PathFormat"""
        return self.PathFormat

    @pathformat.setter
    def pathformat(self, value):
        """Alias for PathFormat.setter"""
        self.PathFormat = value

    @property
    def path_format(self):
        """Alias for PathFormat"""
        return self.PathFormat

    @path_format.setter
    def path_format(self, value):
        """Alias for PathFormat.setter"""
        self.PathFormat = value

    @property
    def Ruler(self):
        return self.com_object.Ruler

    @property
    def ruler(self):
        """Alias for Ruler"""
        return self.Ruler

    @property
    def TextRange(self):
        return self.com_object.TextRange

    @property
    def textrange(self):
        """Alias for TextRange"""
        return self.TextRange

    @property
    def text_range(self):
        """Alias for TextRange"""
        return self.TextRange

    @property
    def ThreeD(self):
        return ThreeDFormat(self.com_object.ThreeD)

    @property
    def threed(self):
        """Alias for ThreeD"""
        return self.ThreeD

    @property
    def three_d(self):
        """Alias for ThreeD"""
        return self.ThreeD

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def WarpFormat(self):
        return self.com_object.WarpFormat

    @WarpFormat.setter
    def WarpFormat(self, value):
        self.com_object.WarpFormat = value

    @property
    def warpformat(self):
        """Alias for WarpFormat"""
        return self.WarpFormat

    @warpformat.setter
    def warpformat(self, value):
        """Alias for WarpFormat.setter"""
        self.WarpFormat = value

    @property
    def warp_format(self):
        """Alias for WarpFormat"""
        return self.WarpFormat

    @warp_format.setter
    def warp_format(self, value):
        """Alias for WarpFormat.setter"""
        self.WarpFormat = value

    @property
    def WordArtformat(self):
        return self.com_object.WordArtformat

    @WordArtformat.setter
    def WordArtformat(self, value):
        self.com_object.WordArtformat = value

    @property
    def wordartformat(self):
        """Alias for WordArtformat"""
        return self.WordArtformat

    @wordartformat.setter
    def wordartformat(self, value):
        """Alias for WordArtformat.setter"""
        self.WordArtformat = value

    @property
    def word_artformat(self):
        """Alias for WordArtformat"""
        return self.WordArtformat

    @word_artformat.setter
    def word_artformat(self, value):
        """Alias for WordArtformat.setter"""
        self.WordArtformat = value

    @property
    def WordWrap(self):
        return self.com_object.WordWrap

    @WordWrap.setter
    def WordWrap(self, value):
        self.com_object.WordWrap = value

    @property
    def wordwrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @wordwrap.setter
    def wordwrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value

    @property
    def word_wrap(self):
        """Alias for WordWrap"""
        return self.WordWrap

    @word_wrap.setter
    def word_wrap(self, value):
        """Alias for WordWrap.setter"""
        self.WordWrap = value

    def DeleteText(self):
        self.com_object.DeleteText()

    def deletetext(self):
        """Alias for DeleteText"""
        return self.DeleteText()

    def delete_text(self):
        """Alias for DeleteText"""
        return self.DeleteText()


class ThreeDFormat:

    def __init__(self, threedformat=None):
        self.com_object= threedformat

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BevelBottomDepth(self):
        return ThreeDFormat(self.com_object.BevelBottomDepth)

    @BevelBottomDepth.setter
    def BevelBottomDepth(self, value):
        self.com_object.BevelBottomDepth = value

    @property
    def bevelbottomdepth(self):
        """Alias for BevelBottomDepth"""
        return self.BevelBottomDepth

    @bevelbottomdepth.setter
    def bevelbottomdepth(self, value):
        """Alias for BevelBottomDepth.setter"""
        self.BevelBottomDepth = value

    @property
    def bevel_bottom_depth(self):
        """Alias for BevelBottomDepth"""
        return self.BevelBottomDepth

    @bevel_bottom_depth.setter
    def bevel_bottom_depth(self, value):
        """Alias for BevelBottomDepth.setter"""
        self.BevelBottomDepth = value

    @property
    def BevelBottomInset(self):
        return ThreeDFormat(self.com_object.BevelBottomInset)

    @BevelBottomInset.setter
    def BevelBottomInset(self, value):
        self.com_object.BevelBottomInset = value

    @property
    def bevelbottominset(self):
        """Alias for BevelBottomInset"""
        return self.BevelBottomInset

    @bevelbottominset.setter
    def bevelbottominset(self, value):
        """Alias for BevelBottomInset.setter"""
        self.BevelBottomInset = value

    @property
    def bevel_bottom_inset(self):
        """Alias for BevelBottomInset"""
        return self.BevelBottomInset

    @bevel_bottom_inset.setter
    def bevel_bottom_inset(self, value):
        """Alias for BevelBottomInset.setter"""
        self.BevelBottomInset = value

    @property
    def BevelBottomType(self):
        return self.com_object.BevelBottomType

    @BevelBottomType.setter
    def BevelBottomType(self, value):
        self.com_object.BevelBottomType = value

    @property
    def bevelbottomtype(self):
        """Alias for BevelBottomType"""
        return self.BevelBottomType

    @bevelbottomtype.setter
    def bevelbottomtype(self, value):
        """Alias for BevelBottomType.setter"""
        self.BevelBottomType = value

    @property
    def bevel_bottom_type(self):
        """Alias for BevelBottomType"""
        return self.BevelBottomType

    @bevel_bottom_type.setter
    def bevel_bottom_type(self, value):
        """Alias for BevelBottomType.setter"""
        self.BevelBottomType = value

    @property
    def BevelTopDepth(self):
        return ThreeDFormat(self.com_object.BevelTopDepth)

    @BevelTopDepth.setter
    def BevelTopDepth(self, value):
        self.com_object.BevelTopDepth = value

    @property
    def beveltopdepth(self):
        """Alias for BevelTopDepth"""
        return self.BevelTopDepth

    @beveltopdepth.setter
    def beveltopdepth(self, value):
        """Alias for BevelTopDepth.setter"""
        self.BevelTopDepth = value

    @property
    def bevel_top_depth(self):
        """Alias for BevelTopDepth"""
        return self.BevelTopDepth

    @bevel_top_depth.setter
    def bevel_top_depth(self, value):
        """Alias for BevelTopDepth.setter"""
        self.BevelTopDepth = value

    @property
    def BevelTopInset(self):
        return ThreeDFormat(self.com_object.BevelTopInset)

    @BevelTopInset.setter
    def BevelTopInset(self, value):
        self.com_object.BevelTopInset = value

    @property
    def beveltopinset(self):
        """Alias for BevelTopInset"""
        return self.BevelTopInset

    @beveltopinset.setter
    def beveltopinset(self, value):
        """Alias for BevelTopInset.setter"""
        self.BevelTopInset = value

    @property
    def bevel_top_inset(self):
        """Alias for BevelTopInset"""
        return self.BevelTopInset

    @bevel_top_inset.setter
    def bevel_top_inset(self, value):
        """Alias for BevelTopInset.setter"""
        self.BevelTopInset = value

    @property
    def BevelTopType(self):
        return self.com_object.BevelTopType

    @BevelTopType.setter
    def BevelTopType(self, value):
        self.com_object.BevelTopType = value

    @property
    def beveltoptype(self):
        """Alias for BevelTopType"""
        return self.BevelTopType

    @beveltoptype.setter
    def beveltoptype(self, value):
        """Alias for BevelTopType.setter"""
        self.BevelTopType = value

    @property
    def bevel_top_type(self):
        """Alias for BevelTopType"""
        return self.BevelTopType

    @bevel_top_type.setter
    def bevel_top_type(self, value):
        """Alias for BevelTopType.setter"""
        self.BevelTopType = value

    @property
    def ContourColor(self):
        return ColorFormat(self.com_object.ContourColor)

    @property
    def contourcolor(self):
        """Alias for ContourColor"""
        return self.ContourColor

    @property
    def contour_color(self):
        """Alias for ContourColor"""
        return self.ContourColor

    @property
    def ContourWidth(self):
        return ThreeDFormat(self.com_object.ContourWidth)

    @ContourWidth.setter
    def ContourWidth(self, value):
        self.com_object.ContourWidth = value

    @property
    def contourwidth(self):
        """Alias for ContourWidth"""
        return self.ContourWidth

    @contourwidth.setter
    def contourwidth(self, value):
        """Alias for ContourWidth.setter"""
        self.ContourWidth = value

    @property
    def contour_width(self):
        """Alias for ContourWidth"""
        return self.ContourWidth

    @contour_width.setter
    def contour_width(self, value):
        """Alias for ContourWidth.setter"""
        self.ContourWidth = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Depth(self):
        return self.com_object.Depth

    @Depth.setter
    def Depth(self, value):
        self.com_object.Depth = value

    @property
    def depth(self):
        """Alias for Depth"""
        return self.Depth

    @depth.setter
    def depth(self, value):
        """Alias for Depth.setter"""
        self.Depth = value

    @property
    def ExtrusionColor(self):
        return ColorFormat(self.com_object.ExtrusionColor)

    @property
    def extrusioncolor(self):
        """Alias for ExtrusionColor"""
        return self.ExtrusionColor

    @property
    def extrusion_color(self):
        """Alias for ExtrusionColor"""
        return self.ExtrusionColor

    @property
    def ExtrusionColorType(self):
        return self.com_object.ExtrusionColorType

    @ExtrusionColorType.setter
    def ExtrusionColorType(self, value):
        self.com_object.ExtrusionColorType = value

    @property
    def extrusioncolortype(self):
        """Alias for ExtrusionColorType"""
        return self.ExtrusionColorType

    @extrusioncolortype.setter
    def extrusioncolortype(self, value):
        """Alias for ExtrusionColorType.setter"""
        self.ExtrusionColorType = value

    @property
    def extrusion_color_type(self):
        """Alias for ExtrusionColorType"""
        return self.ExtrusionColorType

    @extrusion_color_type.setter
    def extrusion_color_type(self, value):
        """Alias for ExtrusionColorType.setter"""
        self.ExtrusionColorType = value

    @property
    def FieldOfView(self):
        return ThreeDFormat(self.com_object.FieldOfView)

    @FieldOfView.setter
    def FieldOfView(self, value):
        self.com_object.FieldOfView = value

    @property
    def fieldofview(self):
        """Alias for FieldOfView"""
        return self.FieldOfView

    @fieldofview.setter
    def fieldofview(self, value):
        """Alias for FieldOfView.setter"""
        self.FieldOfView = value

    @property
    def field_of_view(self):
        """Alias for FieldOfView"""
        return self.FieldOfView

    @field_of_view.setter
    def field_of_view(self, value):
        """Alias for FieldOfView.setter"""
        self.FieldOfView = value

    @property
    def LightAngle(self):
        return ThreeDFormat(self.com_object.LightAngle)

    @LightAngle.setter
    def LightAngle(self, value):
        self.com_object.LightAngle = value

    @property
    def lightangle(self):
        """Alias for LightAngle"""
        return self.LightAngle

    @lightangle.setter
    def lightangle(self, value):
        """Alias for LightAngle.setter"""
        self.LightAngle = value

    @property
    def light_angle(self):
        """Alias for LightAngle"""
        return self.LightAngle

    @light_angle.setter
    def light_angle(self, value):
        """Alias for LightAngle.setter"""
        self.LightAngle = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Perspective(self):
        return self.com_object.Perspective

    @Perspective.setter
    def Perspective(self, value):
        self.com_object.Perspective = value

    @property
    def perspective(self):
        """Alias for Perspective"""
        return self.Perspective

    @perspective.setter
    def perspective(self, value):
        """Alias for Perspective.setter"""
        self.Perspective = value

    @property
    def PresetCamera(self):
        return self.com_object.PresetCamera

    @PresetCamera.setter
    def PresetCamera(self, value):
        self.com_object.PresetCamera = value

    @property
    def presetcamera(self):
        """Alias for PresetCamera"""
        return self.PresetCamera

    @presetcamera.setter
    def presetcamera(self, value):
        """Alias for PresetCamera.setter"""
        self.PresetCamera = value

    @property
    def preset_camera(self):
        """Alias for PresetCamera"""
        return self.PresetCamera

    @preset_camera.setter
    def preset_camera(self, value):
        """Alias for PresetCamera.setter"""
        self.PresetCamera = value

    @property
    def PresetExtrusionDirection(self):
        return self.com_object.PresetExtrusionDirection

    @property
    def presetextrusiondirection(self):
        """Alias for PresetExtrusionDirection"""
        return self.PresetExtrusionDirection

    @property
    def preset_extrusion_direction(self):
        """Alias for PresetExtrusionDirection"""
        return self.PresetExtrusionDirection

    @property
    def PresetLighting(self):
        return self.com_object.PresetLighting

    @PresetLighting.setter
    def PresetLighting(self, value):
        self.com_object.PresetLighting = value

    @property
    def presetlighting(self):
        """Alias for PresetLighting"""
        return self.PresetLighting

    @presetlighting.setter
    def presetlighting(self, value):
        """Alias for PresetLighting.setter"""
        self.PresetLighting = value

    @property
    def preset_lighting(self):
        """Alias for PresetLighting"""
        return self.PresetLighting

    @preset_lighting.setter
    def preset_lighting(self, value):
        """Alias for PresetLighting.setter"""
        self.PresetLighting = value

    @property
    def PresetLightingDirection(self):
        return self.com_object.PresetLightingDirection

    @PresetLightingDirection.setter
    def PresetLightingDirection(self, value):
        self.com_object.PresetLightingDirection = value

    @property
    def presetlightingdirection(self):
        """Alias for PresetLightingDirection"""
        return self.PresetLightingDirection

    @presetlightingdirection.setter
    def presetlightingdirection(self, value):
        """Alias for PresetLightingDirection.setter"""
        self.PresetLightingDirection = value

    @property
    def preset_lighting_direction(self):
        """Alias for PresetLightingDirection"""
        return self.PresetLightingDirection

    @preset_lighting_direction.setter
    def preset_lighting_direction(self, value):
        """Alias for PresetLightingDirection.setter"""
        self.PresetLightingDirection = value

    @property
    def PresetLightingSoftness(self):
        return self.com_object.PresetLightingSoftness

    @PresetLightingSoftness.setter
    def PresetLightingSoftness(self, value):
        self.com_object.PresetLightingSoftness = value

    @property
    def presetlightingsoftness(self):
        """Alias for PresetLightingSoftness"""
        return self.PresetLightingSoftness

    @presetlightingsoftness.setter
    def presetlightingsoftness(self, value):
        """Alias for PresetLightingSoftness.setter"""
        self.PresetLightingSoftness = value

    @property
    def preset_lighting_softness(self):
        """Alias for PresetLightingSoftness"""
        return self.PresetLightingSoftness

    @preset_lighting_softness.setter
    def preset_lighting_softness(self, value):
        """Alias for PresetLightingSoftness.setter"""
        self.PresetLightingSoftness = value

    @property
    def PresetMaterial(self):
        return self.com_object.PresetMaterial

    @PresetMaterial.setter
    def PresetMaterial(self, value):
        self.com_object.PresetMaterial = value

    @property
    def presetmaterial(self):
        """Alias for PresetMaterial"""
        return self.PresetMaterial

    @presetmaterial.setter
    def presetmaterial(self, value):
        """Alias for PresetMaterial.setter"""
        self.PresetMaterial = value

    @property
    def preset_material(self):
        """Alias for PresetMaterial"""
        return self.PresetMaterial

    @preset_material.setter
    def preset_material(self, value):
        """Alias for PresetMaterial.setter"""
        self.PresetMaterial = value

    @property
    def PresetThreeDFormat(self):
        return self.com_object.PresetThreeDFormat

    @property
    def presetthreedformat(self):
        """Alias for PresetThreeDFormat"""
        return self.PresetThreeDFormat

    @property
    def preset_three_d_format(self):
        """Alias for PresetThreeDFormat"""
        return self.PresetThreeDFormat

    @property
    def ProjectText(self):
        return self.com_object.ProjectText

    @ProjectText.setter
    def ProjectText(self, value):
        self.com_object.ProjectText = value

    @property
    def projecttext(self):
        """Alias for ProjectText"""
        return self.ProjectText

    @projecttext.setter
    def projecttext(self, value):
        """Alias for ProjectText.setter"""
        self.ProjectText = value

    @property
    def project_text(self):
        """Alias for ProjectText"""
        return self.ProjectText

    @project_text.setter
    def project_text(self, value):
        """Alias for ProjectText.setter"""
        self.ProjectText = value

    @property
    def RotationX(self):
        return self.com_object.RotationX

    @RotationX.setter
    def RotationX(self, value):
        self.com_object.RotationX = value

    @property
    def rotationx(self):
        """Alias for RotationX"""
        return self.RotationX

    @rotationx.setter
    def rotationx(self, value):
        """Alias for RotationX.setter"""
        self.RotationX = value

    @property
    def rotation_x(self):
        """Alias for RotationX"""
        return self.RotationX

    @rotation_x.setter
    def rotation_x(self, value):
        """Alias for RotationX.setter"""
        self.RotationX = value

    @property
    def RotationY(self):
        return self.com_object.RotationY

    @RotationY.setter
    def RotationY(self, value):
        self.com_object.RotationY = value

    @property
    def rotationy(self):
        """Alias for RotationY"""
        return self.RotationY

    @rotationy.setter
    def rotationy(self, value):
        """Alias for RotationY.setter"""
        self.RotationY = value

    @property
    def rotation_y(self):
        """Alias for RotationY"""
        return self.RotationY

    @rotation_y.setter
    def rotation_y(self, value):
        """Alias for RotationY.setter"""
        self.RotationY = value

    @property
    def RotationZ(self):
        return self.com_object.RotationZ

    @RotationZ.setter
    def RotationZ(self, value):
        self.com_object.RotationZ = value

    @property
    def rotationz(self):
        """Alias for RotationZ"""
        return self.RotationZ

    @rotationz.setter
    def rotationz(self, value):
        """Alias for RotationZ.setter"""
        self.RotationZ = value

    @property
    def rotation_z(self):
        """Alias for RotationZ"""
        return self.RotationZ

    @rotation_z.setter
    def rotation_z(self, value):
        """Alias for RotationZ.setter"""
        self.RotationZ = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Z(self):
        return ThreeDFormat(self.com_object.Z)

    @Z.setter
    def Z(self, value):
        self.com_object.Z = value

    @property
    def z(self):
        """Alias for Z"""
        return self.Z

    @z.setter
    def z(self, value):
        """Alias for Z.setter"""
        self.Z = value

    def IncrementRotationHorizontal(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotationHorizontal(*arguments)

    def incrementrotationhorizontal(self, Increment=None):
        """Alias for IncrementRotationHorizontal"""
        arguments = [Increment]
        return self.IncrementRotationHorizontal(*arguments)

    def increment_rotation_horizontal(self, Increment=None):
        """Alias for IncrementRotationHorizontal"""
        arguments = [Increment]
        return self.IncrementRotationHorizontal(*arguments)

    def IncrementRotationVertical(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotationVertical(*arguments)

    def incrementrotationvertical(self, Increment=None):
        """Alias for IncrementRotationVertical"""
        arguments = [Increment]
        return self.IncrementRotationVertical(*arguments)

    def increment_rotation_vertical(self, Increment=None):
        """Alias for IncrementRotationVertical"""
        arguments = [Increment]
        return self.IncrementRotationVertical(*arguments)

    def IncrementRotationX(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotationX(*arguments)

    def incrementrotationx(self, Increment=None):
        """Alias for IncrementRotationX"""
        arguments = [Increment]
        return self.IncrementRotationX(*arguments)

    def increment_rotation_x(self, Increment=None):
        """Alias for IncrementRotationX"""
        arguments = [Increment]
        return self.IncrementRotationX(*arguments)

    def IncrementRotationY(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotationY(*arguments)

    def incrementrotationy(self, Increment=None):
        """Alias for IncrementRotationY"""
        arguments = [Increment]
        return self.IncrementRotationY(*arguments)

    def increment_rotation_y(self, Increment=None):
        """Alias for IncrementRotationY"""
        arguments = [Increment]
        return self.IncrementRotationY(*arguments)

    def IncrementRotationZ(self, Increment=None):
        arguments = com_arguments([unwrap(a) for a in [Increment]])
        self.com_object.IncrementRotationZ(*arguments)

    def incrementrotationz(self, Increment=None):
        """Alias for IncrementRotationZ"""
        arguments = [Increment]
        return self.IncrementRotationZ(*arguments)

    def increment_rotation_z(self, Increment=None):
        """Alias for IncrementRotationZ"""
        arguments = [Increment]
        return self.IncrementRotationZ(*arguments)

    def ResetRotation(self):
        self.com_object.ResetRotation()

    def resetrotation(self):
        """Alias for ResetRotation"""
        return self.ResetRotation()

    def reset_rotation(self):
        """Alias for ResetRotation"""
        return self.ResetRotation()

    def SetExtrusionDirection(self, PresetExtrusionDirection=None):
        arguments = com_arguments([unwrap(a) for a in [PresetExtrusionDirection]])
        self.com_object.SetExtrusionDirection(*arguments)

    def setextrusiondirection(self, PresetExtrusionDirection=None):
        """Alias for SetExtrusionDirection"""
        arguments = [PresetExtrusionDirection]
        return self.SetExtrusionDirection(*arguments)

    def set_extrusion_direction(self, PresetExtrusionDirection=None):
        """Alias for SetExtrusionDirection"""
        arguments = [PresetExtrusionDirection]
        return self.SetExtrusionDirection(*arguments)

    def SetPresetCamera(self, PresetCamera=None):
        arguments = com_arguments([unwrap(a) for a in [PresetCamera]])
        self.com_object.SetPresetCamera(*arguments)

    def setpresetcamera(self, PresetCamera=None):
        """Alias for SetPresetCamera"""
        arguments = [PresetCamera]
        return self.SetPresetCamera(*arguments)

    def set_preset_camera(self, PresetCamera=None):
        """Alias for SetPresetCamera"""
        arguments = [PresetCamera]
        return self.SetPresetCamera(*arguments)

    def SetThreeDFormat(self, PresetThreeDFormat=None):
        arguments = com_arguments([unwrap(a) for a in [PresetThreeDFormat]])
        self.com_object.SetThreeDFormat(*arguments)

    def setthreedformat(self, PresetThreeDFormat=None):
        """Alias for SetThreeDFormat"""
        arguments = [PresetThreeDFormat]
        return self.SetThreeDFormat(*arguments)

    def set_three_d_format(self, PresetThreeDFormat=None):
        """Alias for SetThreeDFormat"""
        arguments = [PresetThreeDFormat]
        return self.SetThreeDFormat(*arguments)


class TickLabels:

    def __init__(self, ticklabels=None):
        self.com_object= ticklabels

    @property
    def Alignment(self):
        return self.com_object.Alignment

    @Alignment.setter
    def Alignment(self, value):
        self.com_object.Alignment = value

    @property
    def alignment(self):
        """Alias for Alignment"""
        return self.Alignment

    @alignment.setter
    def alignment(self, value):
        """Alias for Alignment.setter"""
        self.Alignment = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Depth(self):
        return self.com_object.Depth

    @property
    def depth(self):
        """Alias for Depth"""
        return self.Depth

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def MultiLevel(self):
        return self.com_object.MultiLevel

    @MultiLevel.setter
    def MultiLevel(self, value):
        self.com_object.MultiLevel = value

    @property
    def multilevel(self):
        """Alias for MultiLevel"""
        return self.MultiLevel

    @multilevel.setter
    def multilevel(self, value):
        """Alias for MultiLevel.setter"""
        self.MultiLevel = value

    @property
    def multi_level(self):
        """Alias for MultiLevel"""
        return self.MultiLevel

    @multi_level.setter
    def multi_level(self, value):
        """Alias for MultiLevel.setter"""
        self.MultiLevel = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NumberFormat(self):
        return self.com_object.NumberFormat

    @NumberFormat.setter
    def NumberFormat(self, value):
        self.com_object.NumberFormat = value

    @property
    def numberformat(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @numberformat.setter
    def numberformat(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def number_format(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @number_format.setter
    def number_format(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def NumberFormatLinked(self):
        return self.com_object.NumberFormatLinked

    @NumberFormatLinked.setter
    def NumberFormatLinked(self, value):
        self.com_object.NumberFormatLinked = value

    @property
    def numberformatlinked(self):
        """Alias for NumberFormatLinked"""
        return self.NumberFormatLinked

    @numberformatlinked.setter
    def numberformatlinked(self, value):
        """Alias for NumberFormatLinked.setter"""
        self.NumberFormatLinked = value

    @property
    def number_format_linked(self):
        """Alias for NumberFormatLinked"""
        return self.NumberFormatLinked

    @number_format_linked.setter
    def number_format_linked(self, value):
        """Alias for NumberFormatLinked.setter"""
        self.NumberFormatLinked = value

    @property
    def NumberFormatLocal(self):
        return self.com_object.NumberFormatLocal

    @NumberFormatLocal.setter
    def NumberFormatLocal(self, value):
        self.com_object.NumberFormatLocal = value

    @property
    def numberformatlocal(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @numberformatlocal.setter
    def numberformatlocal(self, value):
        """Alias for NumberFormatLocal.setter"""
        self.NumberFormatLocal = value

    @property
    def number_format_local(self):
        """Alias for NumberFormatLocal"""
        return self.NumberFormatLocal

    @number_format_local.setter
    def number_format_local(self, value):
        """Alias for NumberFormatLocal.setter"""
        self.NumberFormatLocal = value

    @property
    def Offset(self):
        return self.com_object.Offset

    @Offset.setter
    def Offset(self, value):
        self.com_object.Offset = value

    @property
    def offset(self):
        """Alias for Offset"""
        return self.Offset

    @offset.setter
    def offset(self, value):
        """Alias for Offset.setter"""
        self.Offset = value

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ReadingOrder(self):
        return self.com_object.ReadingOrder

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        return self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class TimelineState:

    def __init__(self, timelinestate=None):
        self.com_object= timelinestate

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def EndDate(self):
        return self.com_object.EndDate

    @property
    def enddate(self):
        """Alias for EndDate"""
        return self.EndDate

    @property
    def end_date(self):
        """Alias for EndDate"""
        return self.EndDate

    @property
    def FilterType(self):
        return XlPivotFilterType(self.com_object.FilterType)

    @property
    def filtertype(self):
        """Alias for FilterType"""
        return self.FilterType

    @property
    def filter_type(self):
        """Alias for FilterType"""
        return self.FilterType

    @property
    def FilterValue1(self):
        return self.com_object.FilterValue1

    @property
    def filtervalue1(self):
        """Alias for FilterValue1"""
        return self.FilterValue1

    @property
    def filter_value1(self):
        """Alias for FilterValue1"""
        return self.FilterValue1

    @property
    def FilterValue2(self):
        return self.com_object.FilterValue2

    @property
    def filtervalue2(self):
        """Alias for FilterValue2"""
        return self.FilterValue2

    @property
    def filter_value2(self):
        """Alias for FilterValue2"""
        return self.FilterValue2

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SingleRangeFilterState(self):
        return self.com_object.SingleRangeFilterState

    @property
    def singlerangefilterstate(self):
        """Alias for SingleRangeFilterState"""
        return self.SingleRangeFilterState

    @property
    def single_range_filter_state(self):
        """Alias for SingleRangeFilterState"""
        return self.SingleRangeFilterState

    @property
    def StartDate(self):
        return self.com_object.StartDate

    @property
    def startdate(self):
        """Alias for StartDate"""
        return self.StartDate

    @property
    def start_date(self):
        """Alias for StartDate"""
        return self.StartDate

    def SetFilterDateRange(self, StartDate=None, EndDate=None):
        arguments = com_arguments([unwrap(a) for a in [StartDate, EndDate]])
        return XlFilterStatus(self.com_object.SetFilterDateRange(*arguments))

    def setfilterdaterange(self, StartDate=None, EndDate=None):
        """Alias for SetFilterDateRange"""
        arguments = [StartDate, EndDate]
        return self.SetFilterDateRange(*arguments)

    def set_filter_date_range(self, StartDate=None, EndDate=None):
        """Alias for SetFilterDateRange"""
        arguments = [StartDate, EndDate]
        return self.SetFilterDateRange(*arguments)


class TimelineViewState:

    def __init__(self, timelineviewstate=None):
        self.com_object= timelineviewstate

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Level(self):
        return self.com_object.Level

    @Level.setter
    def Level(self, value):
        self.com_object.Level = value

    @property
    def level(self):
        """Alias for Level"""
        return self.Level

    @level.setter
    def level(self, value):
        """Alias for Level.setter"""
        self.Level = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ShowHeader(self):
        return self.com_object.ShowHeader

    @ShowHeader.setter
    def ShowHeader(self, value):
        self.com_object.ShowHeader = value

    @property
    def showheader(self):
        """Alias for ShowHeader"""
        return self.ShowHeader

    @showheader.setter
    def showheader(self, value):
        """Alias for ShowHeader.setter"""
        self.ShowHeader = value

    @property
    def show_header(self):
        """Alias for ShowHeader"""
        return self.ShowHeader

    @show_header.setter
    def show_header(self, value):
        """Alias for ShowHeader.setter"""
        self.ShowHeader = value

    @property
    def ShowHorizontalScrollbar(self):
        return self.com_object.ShowHorizontalScrollbar

    @ShowHorizontalScrollbar.setter
    def ShowHorizontalScrollbar(self, value):
        self.com_object.ShowHorizontalScrollbar = value

    @property
    def showhorizontalscrollbar(self):
        """Alias for ShowHorizontalScrollbar"""
        return self.ShowHorizontalScrollbar

    @showhorizontalscrollbar.setter
    def showhorizontalscrollbar(self, value):
        """Alias for ShowHorizontalScrollbar.setter"""
        self.ShowHorizontalScrollbar = value

    @property
    def show_horizontal_scrollbar(self):
        """Alias for ShowHorizontalScrollbar"""
        return self.ShowHorizontalScrollbar

    @show_horizontal_scrollbar.setter
    def show_horizontal_scrollbar(self, value):
        """Alias for ShowHorizontalScrollbar.setter"""
        self.ShowHorizontalScrollbar = value

    @property
    def ShowSelectionLabel(self):
        return self.com_object.ShowSelectionLabel

    @ShowSelectionLabel.setter
    def ShowSelectionLabel(self, value):
        self.com_object.ShowSelectionLabel = value

    @property
    def showselectionlabel(self):
        """Alias for ShowSelectionLabel"""
        return self.ShowSelectionLabel

    @showselectionlabel.setter
    def showselectionlabel(self, value):
        """Alias for ShowSelectionLabel.setter"""
        self.ShowSelectionLabel = value

    @property
    def show_selection_label(self):
        """Alias for ShowSelectionLabel"""
        return self.ShowSelectionLabel

    @show_selection_label.setter
    def show_selection_label(self, value):
        """Alias for ShowSelectionLabel.setter"""
        self.ShowSelectionLabel = value

    @property
    def ShowTimeLevel(self):
        return self.com_object.ShowTimeLevel

    @ShowTimeLevel.setter
    def ShowTimeLevel(self, value):
        self.com_object.ShowTimeLevel = value

    @property
    def showtimelevel(self):
        """Alias for ShowTimeLevel"""
        return self.ShowTimeLevel

    @showtimelevel.setter
    def showtimelevel(self, value):
        """Alias for ShowTimeLevel.setter"""
        self.ShowTimeLevel = value

    @property
    def show_time_level(self):
        """Alias for ShowTimeLevel"""
        return self.ShowTimeLevel

    @show_time_level.setter
    def show_time_level(self, value):
        """Alias for ShowTimeLevel.setter"""
        self.ShowTimeLevel = value


class Top10:

    def __init__(self, top10=None):
        self.com_object= top10

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AppliesTo(self):
        return Range(self.com_object.AppliesTo)

    @property
    def appliesto(self):
        """Alias for AppliesTo"""
        return self.AppliesTo

    @property
    def applies_to(self):
        """Alias for AppliesTo"""
        return self.AppliesTo

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def CalcFor(self):
        return XlCalcFor(self.com_object.CalcFor)

    @CalcFor.setter
    def CalcFor(self, value):
        self.com_object.CalcFor = value

    @property
    def calcfor(self):
        """Alias for CalcFor"""
        return self.CalcFor

    @calcfor.setter
    def calcfor(self, value):
        """Alias for CalcFor.setter"""
        self.CalcFor = value

    @property
    def calc_for(self):
        """Alias for CalcFor"""
        return self.CalcFor

    @calc_for.setter
    def calc_for(self, value):
        """Alias for CalcFor.setter"""
        self.CalcFor = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def Interior(self):
        return Interior(self.com_object.Interior)

    @property
    def interior(self):
        """Alias for Interior"""
        return self.Interior

    @property
    def NumberFormat(self):
        return self.com_object.NumberFormat

    @NumberFormat.setter
    def NumberFormat(self, value):
        self.com_object.NumberFormat = value

    @property
    def numberformat(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @numberformat.setter
    def numberformat(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def number_format(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @number_format.setter
    def number_format(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Percent(self):
        return self.com_object.Percent

    @Percent.setter
    def Percent(self, value):
        self.com_object.Percent = value

    @property
    def percent(self):
        """Alias for Percent"""
        return self.Percent

    @percent.setter
    def percent(self, value):
        """Alias for Percent.setter"""
        self.Percent = value

    @property
    def Priority(self):
        return self.com_object.Priority

    @Priority.setter
    def Priority(self, value):
        self.com_object.Priority = value

    @property
    def priority(self):
        """Alias for Priority"""
        return self.Priority

    @priority.setter
    def priority(self, value):
        """Alias for Priority.setter"""
        self.Priority = value

    @property
    def PTCondition(self):
        return self.com_object.PTCondition

    @property
    def ptcondition(self):
        """Alias for PTCondition"""
        return self.PTCondition

    @property
    def p_t_condition(self):
        """Alias for PTCondition"""
        return self.PTCondition

    @property
    def Rank(self):
        return self.com_object.Rank

    @Rank.setter
    def Rank(self, value):
        self.com_object.Rank = value

    @property
    def rank(self):
        """Alias for Rank"""
        return self.Rank

    @rank.setter
    def rank(self, value):
        """Alias for Rank.setter"""
        self.Rank = value

    @property
    def ScopeType(self):
        return XlPivotConditionScope(self.com_object.ScopeType)

    @ScopeType.setter
    def ScopeType(self, value):
        self.com_object.ScopeType = value

    @property
    def scopetype(self):
        """Alias for ScopeType"""
        return self.ScopeType

    @scopetype.setter
    def scopetype(self, value):
        """Alias for ScopeType.setter"""
        self.ScopeType = value

    @property
    def scope_type(self):
        """Alias for ScopeType"""
        return self.ScopeType

    @scope_type.setter
    def scope_type(self, value):
        """Alias for ScopeType.setter"""
        self.ScopeType = value

    @property
    def StopIfTrue(self):
        return self.com_object.StopIfTrue

    @StopIfTrue.setter
    def StopIfTrue(self, value):
        self.com_object.StopIfTrue = value

    @property
    def stopiftrue(self):
        """Alias for StopIfTrue"""
        return self.StopIfTrue

    @stopiftrue.setter
    def stopiftrue(self, value):
        """Alias for StopIfTrue.setter"""
        self.StopIfTrue = value

    @property
    def stop_if_true(self):
        """Alias for StopIfTrue"""
        return self.StopIfTrue

    @stop_if_true.setter
    def stop_if_true(self, value):
        """Alias for StopIfTrue.setter"""
        self.StopIfTrue = value

    @property
    def TopBottom(self):
        return XlTopBottom(self.com_object.TopBottom)

    @TopBottom.setter
    def TopBottom(self, value):
        self.com_object.TopBottom = value

    @property
    def topbottom(self):
        """Alias for TopBottom"""
        return self.TopBottom

    @topbottom.setter
    def topbottom(self, value):
        """Alias for TopBottom.setter"""
        self.TopBottom = value

    @property
    def top_bottom(self):
        """Alias for TopBottom"""
        return self.TopBottom

    @top_bottom.setter
    def top_bottom(self, value):
        """Alias for TopBottom.setter"""
        self.TopBottom = value

    @property
    def Type(self):
        return XlFormatConditionType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def ModifyAppliesToRange(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        self.com_object.ModifyAppliesToRange(*arguments)

    def modifyappliestorange(self, Range=None):
        """Alias for ModifyAppliesToRange"""
        arguments = [Range]
        return self.ModifyAppliesToRange(*arguments)

    def modify_applies_to_range(self, Range=None):
        """Alias for ModifyAppliesToRange"""
        arguments = [Range]
        return self.ModifyAppliesToRange(*arguments)

    def SetFirstPriority(self):
        self.com_object.SetFirstPriority()

    def setfirstpriority(self):
        """Alias for SetFirstPriority"""
        return self.SetFirstPriority()

    def set_first_priority(self):
        """Alias for SetFirstPriority"""
        return self.SetFirstPriority()

    def SetLastPriority(self):
        self.com_object.SetLastPriority()

    def setlastpriority(self):
        """Alias for SetLastPriority"""
        return self.SetLastPriority()

    def set_last_priority(self):
        """Alias for SetLastPriority"""
        return self.SetLastPriority()


class TreeviewControl:

    def __init__(self, treeviewcontrol=None):
        self.com_object= treeviewcontrol

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Drilled(self):
        return self.com_object.Drilled

    @Drilled.setter
    def Drilled(self, value):
        self.com_object.Drilled = value

    @property
    def drilled(self):
        """Alias for Drilled"""
        return self.Drilled

    @drilled.setter
    def drilled(self, value):
        """Alias for Drilled.setter"""
        self.Drilled = value

    @property
    def Hidden(self):
        return self.com_object.Hidden

    @Hidden.setter
    def Hidden(self, value):
        self.com_object.Hidden = value

    @property
    def hidden(self):
        """Alias for Hidden"""
        return self.Hidden

    @hidden.setter
    def hidden(self, value):
        """Alias for Hidden.setter"""
        self.Hidden = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class Trendline:

    def __init__(self, trendline=None):
        self.com_object= trendline

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Backward2(self):
        return self.com_object.Backward2

    @Backward2.setter
    def Backward2(self, value):
        self.com_object.Backward2 = value

    @property
    def backward2(self):
        """Alias for Backward2"""
        return self.Backward2

    @backward2.setter
    def backward2(self, value):
        """Alias for Backward2.setter"""
        self.Backward2 = value

    @property
    def Border(self):
        return Border(self.com_object.Border)

    @property
    def border(self):
        """Alias for Border"""
        return self.Border

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DataLabel(self):
        return DataLabel(self.com_object.DataLabel)

    @property
    def datalabel(self):
        """Alias for DataLabel"""
        return self.DataLabel

    @property
    def data_label(self):
        """Alias for DataLabel"""
        return self.DataLabel

    @property
    def DisplayEquation(self):
        return self.com_object.DisplayEquation

    @DisplayEquation.setter
    def DisplayEquation(self, value):
        self.com_object.DisplayEquation = value

    @property
    def displayequation(self):
        """Alias for DisplayEquation"""
        return self.DisplayEquation

    @displayequation.setter
    def displayequation(self, value):
        """Alias for DisplayEquation.setter"""
        self.DisplayEquation = value

    @property
    def display_equation(self):
        """Alias for DisplayEquation"""
        return self.DisplayEquation

    @display_equation.setter
    def display_equation(self, value):
        """Alias for DisplayEquation.setter"""
        self.DisplayEquation = value

    @property
    def DisplayRSquared(self):
        return self.com_object.DisplayRSquared

    @DisplayRSquared.setter
    def DisplayRSquared(self, value):
        self.com_object.DisplayRSquared = value

    @property
    def displayrsquared(self):
        """Alias for DisplayRSquared"""
        return self.DisplayRSquared

    @displayrsquared.setter
    def displayrsquared(self, value):
        """Alias for DisplayRSquared.setter"""
        self.DisplayRSquared = value

    @property
    def display_r_squared(self):
        """Alias for DisplayRSquared"""
        return self.DisplayRSquared

    @display_r_squared.setter
    def display_r_squared(self, value):
        """Alias for DisplayRSquared.setter"""
        self.DisplayRSquared = value

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Forward2(self):
        return self.com_object.Forward2

    @Forward2.setter
    def Forward2(self, value):
        self.com_object.Forward2 = value

    @property
    def forward2(self):
        """Alias for Forward2"""
        return self.Forward2

    @forward2.setter
    def forward2(self, value):
        """Alias for Forward2.setter"""
        self.Forward2 = value

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Intercept(self):
        return self.com_object.Intercept

    @Intercept.setter
    def Intercept(self, value):
        self.com_object.Intercept = value

    @property
    def intercept(self):
        """Alias for Intercept"""
        return self.Intercept

    @intercept.setter
    def intercept(self, value):
        """Alias for Intercept.setter"""
        self.Intercept = value

    @property
    def InterceptIsAuto(self):
        return self.com_object.InterceptIsAuto

    @InterceptIsAuto.setter
    def InterceptIsAuto(self, value):
        self.com_object.InterceptIsAuto = value

    @property
    def interceptisauto(self):
        """Alias for InterceptIsAuto"""
        return self.InterceptIsAuto

    @interceptisauto.setter
    def interceptisauto(self, value):
        """Alias for InterceptIsAuto.setter"""
        self.InterceptIsAuto = value

    @property
    def intercept_is_auto(self):
        """Alias for InterceptIsAuto"""
        return self.InterceptIsAuto

    @intercept_is_auto.setter
    def intercept_is_auto(self, value):
        """Alias for InterceptIsAuto.setter"""
        self.InterceptIsAuto = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def NameIsAuto(self):
        return self.com_object.NameIsAuto

    @NameIsAuto.setter
    def NameIsAuto(self, value):
        self.com_object.NameIsAuto = value

    @property
    def nameisauto(self):
        """Alias for NameIsAuto"""
        return self.NameIsAuto

    @nameisauto.setter
    def nameisauto(self, value):
        """Alias for NameIsAuto.setter"""
        self.NameIsAuto = value

    @property
    def name_is_auto(self):
        """Alias for NameIsAuto"""
        return self.NameIsAuto

    @name_is_auto.setter
    def name_is_auto(self, value):
        """Alias for NameIsAuto.setter"""
        self.NameIsAuto = value

    @property
    def Order(self):
        return XlTrendlineType(self.com_object.Order)

    @Order.setter
    def Order(self, value):
        self.com_object.Order = value

    @property
    def order(self):
        """Alias for Order"""
        return self.Order

    @order.setter
    def order(self, value):
        """Alias for Order.setter"""
        self.Order = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Period(self):
        return self.com_object.Period

    @Period.setter
    def Period(self, value):
        self.com_object.Period = value

    @property
    def period(self):
        """Alias for Period"""
        return self.Period

    @period.setter
    def period(self, value):
        """Alias for Period.setter"""
        self.Period = value

    @property
    def Type(self):
        return XlTrendlineType(self.com_object.Type)

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    def ClearFormats(self):
        return self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        return self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Trendlines:

    def __init__(self, trendlines=None):
        self.com_object= trendlines

    def __call__(self, item):
        return Trendline(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Type=None, Order=None, Period=None, Forward=None, Backward=None, Intercept=None, DisplayEquation=None, DisplayRSquared=None, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Order, Period, Forward, Backward, Intercept, DisplayEquation, DisplayRSquared, Name]])
        return Trendline(self.com_object.Add(*arguments))

    def add(self, Type=None, Order=None, Period=None, Forward=None, Backward=None, Intercept=None, DisplayEquation=None, DisplayRSquared=None, Name=None):
        """Alias for Add"""
        arguments = [Type, Order, Period, Forward, Backward, Intercept, DisplayEquation, DisplayRSquared, Name]
        return self.Add(*arguments)

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return Trendline(self.com_object.Item(*arguments))

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)


class UniqueValues:

    def __init__(self, uniquevalues=None):
        self.com_object= uniquevalues

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AppliesTo(self):
        return Range(self.com_object.AppliesTo)

    @property
    def appliesto(self):
        """Alias for AppliesTo"""
        return self.AppliesTo

    @property
    def applies_to(self):
        """Alias for AppliesTo"""
        return self.AppliesTo

    @property
    def Borders(self):
        return Borders(self.com_object.Borders)

    @property
    def borders(self):
        """Alias for Borders"""
        return self.Borders

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DupeUnique(self):
        return XlDupeUnique(self.com_object.DupeUnique)

    @DupeUnique.setter
    def DupeUnique(self, value):
        self.com_object.DupeUnique = value

    @property
    def dupeunique(self):
        """Alias for DupeUnique"""
        return self.DupeUnique

    @dupeunique.setter
    def dupeunique(self, value):
        """Alias for DupeUnique.setter"""
        self.DupeUnique = value

    @property
    def dupe_unique(self):
        """Alias for DupeUnique"""
        return self.DupeUnique

    @dupe_unique.setter
    def dupe_unique(self, value):
        """Alias for DupeUnique.setter"""
        self.DupeUnique = value

    @property
    def Font(self):
        return Font(self.com_object.Font)

    @property
    def font(self):
        """Alias for Font"""
        return self.Font

    @property
    def Interior(self):
        return Interior(self.com_object.Interior)

    @property
    def interior(self):
        """Alias for Interior"""
        return self.Interior

    @property
    def NumberFormat(self):
        return self.com_object.NumberFormat

    @NumberFormat.setter
    def NumberFormat(self, value):
        self.com_object.NumberFormat = value

    @property
    def numberformat(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @numberformat.setter
    def numberformat(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def number_format(self):
        """Alias for NumberFormat"""
        return self.NumberFormat

    @number_format.setter
    def number_format(self, value):
        """Alias for NumberFormat.setter"""
        self.NumberFormat = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Priority(self):
        return self.com_object.Priority

    @Priority.setter
    def Priority(self, value):
        self.com_object.Priority = value

    @property
    def priority(self):
        """Alias for Priority"""
        return self.Priority

    @priority.setter
    def priority(self, value):
        """Alias for Priority.setter"""
        self.Priority = value

    @property
    def PTCondition(self):
        return self.com_object.PTCondition

    @property
    def ptcondition(self):
        """Alias for PTCondition"""
        return self.PTCondition

    @property
    def p_t_condition(self):
        """Alias for PTCondition"""
        return self.PTCondition

    @property
    def ScopeType(self):
        return XlPivotConditionScope(self.com_object.ScopeType)

    @ScopeType.setter
    def ScopeType(self, value):
        self.com_object.ScopeType = value

    @property
    def scopetype(self):
        """Alias for ScopeType"""
        return self.ScopeType

    @scopetype.setter
    def scopetype(self, value):
        """Alias for ScopeType.setter"""
        self.ScopeType = value

    @property
    def scope_type(self):
        """Alias for ScopeType"""
        return self.ScopeType

    @scope_type.setter
    def scope_type(self, value):
        """Alias for ScopeType.setter"""
        self.ScopeType = value

    @property
    def StopIfTrue(self):
        return self.com_object.StopIfTrue

    @StopIfTrue.setter
    def StopIfTrue(self, value):
        self.com_object.StopIfTrue = value

    @property
    def stopiftrue(self):
        """Alias for StopIfTrue"""
        return self.StopIfTrue

    @stopiftrue.setter
    def stopiftrue(self, value):
        """Alias for StopIfTrue.setter"""
        self.StopIfTrue = value

    @property
    def stop_if_true(self):
        """Alias for StopIfTrue"""
        return self.StopIfTrue

    @stop_if_true.setter
    def stop_if_true(self, value):
        """Alias for StopIfTrue.setter"""
        self.StopIfTrue = value

    @property
    def Type(self):
        return XlFormatConditionType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def ModifyAppliesToRange(self, Range=None):
        arguments = com_arguments([unwrap(a) for a in [Range]])
        self.com_object.ModifyAppliesToRange(*arguments)

    def modifyappliestorange(self, Range=None):
        """Alias for ModifyAppliesToRange"""
        arguments = [Range]
        return self.ModifyAppliesToRange(*arguments)

    def modify_applies_to_range(self, Range=None):
        """Alias for ModifyAppliesToRange"""
        arguments = [Range]
        return self.ModifyAppliesToRange(*arguments)

    def SetFirstPriority(self):
        self.com_object.SetFirstPriority()

    def setfirstpriority(self):
        """Alias for SetFirstPriority"""
        return self.SetFirstPriority()

    def set_first_priority(self):
        """Alias for SetFirstPriority"""
        return self.SetFirstPriority()

    def SetLastPriority(self):
        self.com_object.SetLastPriority()

    def setlastpriority(self):
        """Alias for SetLastPriority"""
        return self.SetLastPriority()

    def set_last_priority(self):
        """Alias for SetLastPriority"""
        return self.SetLastPriority()


class UpBars:

    def __init__(self, upbars=None):
        self.com_object= upbars

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Select(self):
        return self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class UsedObjects:

    def __init__(self, usedobjects=None):
        self.com_object= usedobjects

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class UserAccess:

    def __init__(self, useraccess=None):
        self.com_object= useraccess

    @property
    def AllowEdit(self):
        return self.com_object.AllowEdit

    @AllowEdit.setter
    def AllowEdit(self, value):
        self.com_object.AllowEdit = value

    @property
    def allowedit(self):
        """Alias for AllowEdit"""
        return self.AllowEdit

    @allowedit.setter
    def allowedit(self, value):
        """Alias for AllowEdit.setter"""
        self.AllowEdit = value

    @property
    def allow_edit(self):
        """Alias for AllowEdit"""
        return self.AllowEdit

    @allow_edit.setter
    def allow_edit(self, value):
        """Alias for AllowEdit.setter"""
        self.AllowEdit = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class UserAccessList:

    def __init__(self, useraccesslist=None):
        self.com_object= useraccesslist

    def __call__(self, item):
        return UserAccessList(self.com_object(item))

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Add(self, Name=None, AllowEdit=None):
        arguments = com_arguments([unwrap(a) for a in [Name, AllowEdit]])
        return UserAccess(self.com_object.Add(*arguments))

    def add(self, Name=None, AllowEdit=None):
        """Alias for Add"""
        arguments = [Name, AllowEdit]
        return self.Add(*arguments)

    def DeleteAll(self):
        self.com_object.DeleteAll()

    def deleteall(self):
        """Alias for DeleteAll"""
        return self.DeleteAll()

    def delete_all(self):
        """Alias for DeleteAll"""
        return self.DeleteAll()


class Validation:

    def __init__(self, validation=None):
        self.com_object= validation

    @property
    def AlertStyle(self):
        return XlDVAlertStyle(self.com_object.AlertStyle)

    @property
    def alertstyle(self):
        """Alias for AlertStyle"""
        return self.AlertStyle

    @property
    def alert_style(self):
        """Alias for AlertStyle"""
        return self.AlertStyle

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def ErrorMessage(self):
        return self.com_object.ErrorMessage

    @ErrorMessage.setter
    def ErrorMessage(self, value):
        self.com_object.ErrorMessage = value

    @property
    def errormessage(self):
        """Alias for ErrorMessage"""
        return self.ErrorMessage

    @errormessage.setter
    def errormessage(self, value):
        """Alias for ErrorMessage.setter"""
        self.ErrorMessage = value

    @property
    def error_message(self):
        """Alias for ErrorMessage"""
        return self.ErrorMessage

    @error_message.setter
    def error_message(self, value):
        """Alias for ErrorMessage.setter"""
        self.ErrorMessage = value

    @property
    def ErrorTitle(self):
        return self.com_object.ErrorTitle

    @ErrorTitle.setter
    def ErrorTitle(self, value):
        self.com_object.ErrorTitle = value

    @property
    def errortitle(self):
        """Alias for ErrorTitle"""
        return self.ErrorTitle

    @errortitle.setter
    def errortitle(self, value):
        """Alias for ErrorTitle.setter"""
        self.ErrorTitle = value

    @property
    def error_title(self):
        """Alias for ErrorTitle"""
        return self.ErrorTitle

    @error_title.setter
    def error_title(self, value):
        """Alias for ErrorTitle.setter"""
        self.ErrorTitle = value

    @property
    def Formula1(self):
        return self.com_object.Formula1

    @property
    def formula1(self):
        """Alias for Formula1"""
        return self.Formula1

    @property
    def Formula2(self):
        return self.com_object.Formula2

    @property
    def formula2(self):
        """Alias for Formula2"""
        return self.Formula2

    @property
    def IgnoreBlank(self):
        return self.com_object.IgnoreBlank

    @IgnoreBlank.setter
    def IgnoreBlank(self, value):
        self.com_object.IgnoreBlank = value

    @property
    def ignoreblank(self):
        """Alias for IgnoreBlank"""
        return self.IgnoreBlank

    @ignoreblank.setter
    def ignoreblank(self, value):
        """Alias for IgnoreBlank.setter"""
        self.IgnoreBlank = value

    @property
    def ignore_blank(self):
        """Alias for IgnoreBlank"""
        return self.IgnoreBlank

    @ignore_blank.setter
    def ignore_blank(self, value):
        """Alias for IgnoreBlank.setter"""
        self.IgnoreBlank = value

    @property
    def IMEMode(self):
        return XlIMEMode(self.com_object.IMEMode)

    @IMEMode.setter
    def IMEMode(self, value):
        self.com_object.IMEMode = value

    @property
    def imemode(self):
        """Alias for IMEMode"""
        return self.IMEMode

    @imemode.setter
    def imemode(self, value):
        """Alias for IMEMode.setter"""
        self.IMEMode = value

    @property
    def i_m_e_mode(self):
        """Alias for IMEMode"""
        return self.IMEMode

    @i_m_e_mode.setter
    def i_m_e_mode(self, value):
        """Alias for IMEMode.setter"""
        self.IMEMode = value

    @property
    def InCellDropdown(self):
        return self.com_object.InCellDropdown

    @InCellDropdown.setter
    def InCellDropdown(self, value):
        self.com_object.InCellDropdown = value

    @property
    def incelldropdown(self):
        """Alias for InCellDropdown"""
        return self.InCellDropdown

    @incelldropdown.setter
    def incelldropdown(self, value):
        """Alias for InCellDropdown.setter"""
        self.InCellDropdown = value

    @property
    def in_cell_dropdown(self):
        """Alias for InCellDropdown"""
        return self.InCellDropdown

    @in_cell_dropdown.setter
    def in_cell_dropdown(self, value):
        """Alias for InCellDropdown.setter"""
        self.InCellDropdown = value

    @property
    def InputMessage(self):
        return self.com_object.InputMessage

    @InputMessage.setter
    def InputMessage(self, value):
        self.com_object.InputMessage = value

    @property
    def inputmessage(self):
        """Alias for InputMessage"""
        return self.InputMessage

    @inputmessage.setter
    def inputmessage(self, value):
        """Alias for InputMessage.setter"""
        self.InputMessage = value

    @property
    def input_message(self):
        """Alias for InputMessage"""
        return self.InputMessage

    @input_message.setter
    def input_message(self, value):
        """Alias for InputMessage.setter"""
        self.InputMessage = value

    @property
    def InputTitle(self):
        return self.com_object.InputTitle

    @InputTitle.setter
    def InputTitle(self, value):
        self.com_object.InputTitle = value

    @property
    def inputtitle(self):
        """Alias for InputTitle"""
        return self.InputTitle

    @inputtitle.setter
    def inputtitle(self, value):
        """Alias for InputTitle.setter"""
        self.InputTitle = value

    @property
    def input_title(self):
        """Alias for InputTitle"""
        return self.InputTitle

    @input_title.setter
    def input_title(self, value):
        """Alias for InputTitle.setter"""
        self.InputTitle = value

    @property
    def Operator(self):
        return XlFormatConditionOperator(self.com_object.Operator)

    @property
    def operator(self):
        """Alias for Operator"""
        return self.Operator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ShowError(self):
        return self.com_object.ShowError

    @ShowError.setter
    def ShowError(self, value):
        self.com_object.ShowError = value

    @property
    def showerror(self):
        """Alias for ShowError"""
        return self.ShowError

    @showerror.setter
    def showerror(self, value):
        """Alias for ShowError.setter"""
        self.ShowError = value

    @property
    def show_error(self):
        """Alias for ShowError"""
        return self.ShowError

    @show_error.setter
    def show_error(self, value):
        """Alias for ShowError.setter"""
        self.ShowError = value

    @property
    def ShowInput(self):
        return self.com_object.ShowInput

    @ShowInput.setter
    def ShowInput(self, value):
        self.com_object.ShowInput = value

    @property
    def showinput(self):
        """Alias for ShowInput"""
        return self.ShowInput

    @showinput.setter
    def showinput(self, value):
        """Alias for ShowInput.setter"""
        self.ShowInput = value

    @property
    def show_input(self):
        """Alias for ShowInput"""
        return self.ShowInput

    @show_input.setter
    def show_input(self, value):
        """Alias for ShowInput.setter"""
        self.ShowInput = value

    @property
    def Type(self):
        return XlDVType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def Value(self):
        return self.com_object.Value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    def Add(self, Type=None, AlertStyle=None, Operator=None, Formula1=None, Formula2=None):
        arguments = com_arguments([unwrap(a) for a in [Type, AlertStyle, Operator, Formula1, Formula2]])
        self.com_object.Add(*arguments)

    def add(self, Type=None, AlertStyle=None, Operator=None, Formula1=None, Formula2=None):
        """Alias for Add"""
        arguments = [Type, AlertStyle, Operator, Formula1, Formula2]
        return self.Add(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Modify(self, Type=None, AlertStyle=None, Operator=None, Formula1=None, Formula2=None):
        arguments = com_arguments([unwrap(a) for a in [Type, AlertStyle, Operator, Formula1, Formula2]])
        self.com_object.Modify(*arguments)

    def modify(self, Type=None, AlertStyle=None, Operator=None, Formula1=None, Formula2=None):
        """Alias for Modify"""
        arguments = [Type, AlertStyle, Operator, Formula1, Formula2]
        return self.Modify(*arguments)


class ValueChange:

    def __init__(self, valuechange=None):
        self.com_object= valuechange

    @property
    def AllocationMethod(self):
        return self.com_object.AllocationMethod

    @property
    def allocationmethod(self):
        """Alias for AllocationMethod"""
        return self.AllocationMethod

    @property
    def allocation_method(self):
        """Alias for AllocationMethod"""
        return self.AllocationMethod

    @property
    def AllocationValue(self):
        return self.com_object.AllocationValue

    @property
    def allocationvalue(self):
        """Alias for AllocationValue"""
        return self.AllocationValue

    @property
    def allocation_value(self):
        """Alias for AllocationValue"""
        return self.AllocationValue

    @property
    def AllocationWeightExpression(self):
        return self.com_object.AllocationWeightExpression

    @property
    def allocationweightexpression(self):
        """Alias for AllocationWeightExpression"""
        return self.AllocationWeightExpression

    @property
    def allocation_weight_expression(self):
        """Alias for AllocationWeightExpression"""
        return self.AllocationWeightExpression

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Order(self):
        return PivotTableChangeList(self.com_object.Order)

    @property
    def order(self):
        """Alias for Order"""
        return self.Order

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PivotCell(self):
        return PivotCell(self.com_object.PivotCell)

    @property
    def pivotcell(self):
        """Alias for PivotCell"""
        return self.PivotCell

    @property
    def pivot_cell(self):
        """Alias for PivotCell"""
        return self.PivotCell

    @property
    def Tuple(self):
        return self.com_object.Tuple

    @property
    def tuple(self):
        """Alias for Tuple"""
        return self.Tuple

    @property
    def Value(self):
        return self.com_object.Value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @property
    def VisibleInPivotTable(self):
        return self.com_object.VisibleInPivotTable

    @property
    def visibleinpivottable(self):
        """Alias for VisibleInPivotTable"""
        return self.VisibleInPivotTable

    @property
    def visible_in_pivot_table(self):
        """Alias for VisibleInPivotTable"""
        return self.VisibleInPivotTable

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class VPageBreak:

    def __init__(self, vpagebreak=None):
        self.com_object= vpagebreak

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Extent(self):
        return XlPageBreakExtent(self.com_object.Extent)

    @property
    def extent(self):
        """Alias for Extent"""
        return self.Extent

    @property
    def Location(self):
        return Range(self.com_object.Location)

    @property
    def location(self):
        """Alias for Location"""
        return self.Location

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Type(self):
        return XlPageBreak(self.com_object.Type)

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def DragOff(self, Direction=None, RegionIndex=None):
        arguments = com_arguments([unwrap(a) for a in [Direction, RegionIndex]])
        self.com_object.DragOff(*arguments)

    def dragoff(self, Direction=None, RegionIndex=None):
        """Alias for DragOff"""
        arguments = [Direction, RegionIndex]
        return self.DragOff(*arguments)

    def drag_off(self, Direction=None, RegionIndex=None):
        """Alias for DragOff"""
        arguments = [Direction, RegionIndex]
        return self.DragOff(*arguments)


class VPageBreaks:

    def __init__(self, vpagebreaks=None):
        self.com_object= vpagebreaks

    def __call__(self, item):
        return VPageBreak(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Before=None):
        arguments = com_arguments([unwrap(a) for a in [Before]])
        return VPageBreak(self.com_object.Add(*arguments))

    def add(self, Before=None):
        """Alias for Add"""
        arguments = [Before]
        return self.Add(*arguments)


class Walls:

    def __init__(self, walls=None):
        self.com_object= walls

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Format(self):
        return ChartFormat(self.com_object.Format)

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PictureType(self):
        return self.com_object.PictureType

    @PictureType.setter
    def PictureType(self, value):
        self.com_object.PictureType = value

    @property
    def picturetype(self):
        """Alias for PictureType"""
        return self.PictureType

    @picturetype.setter
    def picturetype(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def picture_type(self):
        """Alias for PictureType"""
        return self.PictureType

    @picture_type.setter
    def picture_type(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def PictureUnit(self):
        return PictureType(self.com_object.PictureUnit)

    @PictureUnit.setter
    def PictureUnit(self, value):
        self.com_object.PictureUnit = value

    @property
    def pictureunit(self):
        """Alias for PictureUnit"""
        return self.PictureUnit

    @pictureunit.setter
    def pictureunit(self, value):
        """Alias for PictureUnit.setter"""
        self.PictureUnit = value

    @property
    def picture_unit(self):
        """Alias for PictureUnit"""
        return self.PictureUnit

    @picture_unit.setter
    def picture_unit(self, value):
        """Alias for PictureUnit.setter"""
        self.PictureUnit = value

    @property
    def Thickness(self):
        return self.com_object.Thickness

    @Thickness.setter
    def Thickness(self, value):
        self.com_object.Thickness = value

    @property
    def thickness(self):
        """Alias for Thickness"""
        return self.Thickness

    @thickness.setter
    def thickness(self, value):
        """Alias for Thickness.setter"""
        self.Thickness = value

    def ClearFormats(self):
        return self.com_object.ClearFormats()

    def clearformats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def clear_formats(self):
        """Alias for ClearFormats"""
        return self.ClearFormats()

    def Paste(self):
        self.com_object.Paste()

    def paste(self):
        """Alias for Paste"""
        return self.Paste()

    def Select(self):
        return self.com_object.Select()

    def select(self):
        """Alias for Select"""
        return self.Select()


class Watch:

    def __init__(self, watch=None):
        self.com_object= watch

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Source(self):
        return self.com_object.Source

    @property
    def source(self):
        """Alias for Source"""
        return self.Source

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class Watches:

    def __init__(self, watches=None):
        self.com_object= watches

    def __call__(self, item):
        return Watche(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Source=None):
        arguments = com_arguments([unwrap(a) for a in [Source]])
        return Watch(self.com_object.Add(*arguments))

    def add(self, Source=None):
        """Alias for Add"""
        arguments = [Source]
        return self.Add(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class WebOptions:

    def __init__(self, weboptions=None):
        self.com_object= weboptions

    @property
    def AllowPNG(self):
        return self.com_object.AllowPNG

    @AllowPNG.setter
    def AllowPNG(self, value):
        self.com_object.AllowPNG = value

    @property
    def allowpng(self):
        """Alias for AllowPNG"""
        return self.AllowPNG

    @allowpng.setter
    def allowpng(self, value):
        """Alias for AllowPNG.setter"""
        self.AllowPNG = value

    @property
    def allow_p_n_g(self):
        """Alias for AllowPNG"""
        return self.AllowPNG

    @allow_p_n_g.setter
    def allow_p_n_g(self, value):
        """Alias for AllowPNG.setter"""
        self.AllowPNG = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DownloadComponents(self):
        return self.com_object.DownloadComponents

    @DownloadComponents.setter
    def DownloadComponents(self, value):
        self.com_object.DownloadComponents = value

    @property
    def downloadcomponents(self):
        """Alias for DownloadComponents"""
        return self.DownloadComponents

    @downloadcomponents.setter
    def downloadcomponents(self, value):
        """Alias for DownloadComponents.setter"""
        self.DownloadComponents = value

    @property
    def download_components(self):
        """Alias for DownloadComponents"""
        return self.DownloadComponents

    @download_components.setter
    def download_components(self, value):
        """Alias for DownloadComponents.setter"""
        self.DownloadComponents = value

    @property
    def Encoding(self):
        return self.com_object.Encoding

    @Encoding.setter
    def Encoding(self, value):
        self.com_object.Encoding = value

    @property
    def encoding(self):
        """Alias for Encoding"""
        return self.Encoding

    @encoding.setter
    def encoding(self, value):
        """Alias for Encoding.setter"""
        self.Encoding = value

    @property
    def FolderSuffix(self):
        return self.com_object.FolderSuffix

    @property
    def foldersuffix(self):
        """Alias for FolderSuffix"""
        return self.FolderSuffix

    @property
    def folder_suffix(self):
        """Alias for FolderSuffix"""
        return self.FolderSuffix

    @property
    def LocationOfComponents(self):
        return self.com_object.LocationOfComponents

    @LocationOfComponents.setter
    def LocationOfComponents(self, value):
        self.com_object.LocationOfComponents = value

    @property
    def locationofcomponents(self):
        """Alias for LocationOfComponents"""
        return self.LocationOfComponents

    @locationofcomponents.setter
    def locationofcomponents(self, value):
        """Alias for LocationOfComponents.setter"""
        self.LocationOfComponents = value

    @property
    def location_of_components(self):
        """Alias for LocationOfComponents"""
        return self.LocationOfComponents

    @location_of_components.setter
    def location_of_components(self, value):
        """Alias for LocationOfComponents.setter"""
        self.LocationOfComponents = value

    @property
    def OrganizeInFolder(self):
        return self.com_object.OrganizeInFolder

    @OrganizeInFolder.setter
    def OrganizeInFolder(self, value):
        self.com_object.OrganizeInFolder = value

    @property
    def organizeinfolder(self):
        """Alias for OrganizeInFolder"""
        return self.OrganizeInFolder

    @organizeinfolder.setter
    def organizeinfolder(self, value):
        """Alias for OrganizeInFolder.setter"""
        self.OrganizeInFolder = value

    @property
    def organize_in_folder(self):
        """Alias for OrganizeInFolder"""
        return self.OrganizeInFolder

    @organize_in_folder.setter
    def organize_in_folder(self, value):
        """Alias for OrganizeInFolder.setter"""
        self.OrganizeInFolder = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PixelsPerInch(self):
        return self.com_object.PixelsPerInch

    @PixelsPerInch.setter
    def PixelsPerInch(self, value):
        self.com_object.PixelsPerInch = value

    @property
    def pixelsperinch(self):
        """Alias for PixelsPerInch"""
        return self.PixelsPerInch

    @pixelsperinch.setter
    def pixelsperinch(self, value):
        """Alias for PixelsPerInch.setter"""
        self.PixelsPerInch = value

    @property
    def pixels_per_inch(self):
        """Alias for PixelsPerInch"""
        return self.PixelsPerInch

    @pixels_per_inch.setter
    def pixels_per_inch(self, value):
        """Alias for PixelsPerInch.setter"""
        self.PixelsPerInch = value

    @property
    def RelyOnCSS(self):
        return self.com_object.RelyOnCSS

    @RelyOnCSS.setter
    def RelyOnCSS(self, value):
        self.com_object.RelyOnCSS = value

    @property
    def relyoncss(self):
        """Alias for RelyOnCSS"""
        return self.RelyOnCSS

    @relyoncss.setter
    def relyoncss(self, value):
        """Alias for RelyOnCSS.setter"""
        self.RelyOnCSS = value

    @property
    def rely_on_c_s_s(self):
        """Alias for RelyOnCSS"""
        return self.RelyOnCSS

    @rely_on_c_s_s.setter
    def rely_on_c_s_s(self, value):
        """Alias for RelyOnCSS.setter"""
        self.RelyOnCSS = value

    @property
    def RelyOnVML(self):
        return self.com_object.RelyOnVML

    @RelyOnVML.setter
    def RelyOnVML(self, value):
        self.com_object.RelyOnVML = value

    @property
    def relyonvml(self):
        """Alias for RelyOnVML"""
        return self.RelyOnVML

    @relyonvml.setter
    def relyonvml(self, value):
        """Alias for RelyOnVML.setter"""
        self.RelyOnVML = value

    @property
    def rely_on_v_m_l(self):
        """Alias for RelyOnVML"""
        return self.RelyOnVML

    @rely_on_v_m_l.setter
    def rely_on_v_m_l(self, value):
        """Alias for RelyOnVML.setter"""
        self.RelyOnVML = value

    @property
    def ScreenSize(self):
        return self.com_object.ScreenSize

    @ScreenSize.setter
    def ScreenSize(self, value):
        self.com_object.ScreenSize = value

    @property
    def screensize(self):
        """Alias for ScreenSize"""
        return self.ScreenSize

    @screensize.setter
    def screensize(self, value):
        """Alias for ScreenSize.setter"""
        self.ScreenSize = value

    @property
    def screen_size(self):
        """Alias for ScreenSize"""
        return self.ScreenSize

    @screen_size.setter
    def screen_size(self, value):
        """Alias for ScreenSize.setter"""
        self.ScreenSize = value

    @property
    def TargetBrowser(self):
        return self.com_object.TargetBrowser

    @TargetBrowser.setter
    def TargetBrowser(self, value):
        self.com_object.TargetBrowser = value

    @property
    def targetbrowser(self):
        """Alias for TargetBrowser"""
        return self.TargetBrowser

    @targetbrowser.setter
    def targetbrowser(self, value):
        """Alias for TargetBrowser.setter"""
        self.TargetBrowser = value

    @property
    def target_browser(self):
        """Alias for TargetBrowser"""
        return self.TargetBrowser

    @target_browser.setter
    def target_browser(self, value):
        """Alias for TargetBrowser.setter"""
        self.TargetBrowser = value

    @property
    def UseLongFileNames(self):
        return self.com_object.UseLongFileNames

    @UseLongFileNames.setter
    def UseLongFileNames(self, value):
        self.com_object.UseLongFileNames = value

    @property
    def uselongfilenames(self):
        """Alias for UseLongFileNames"""
        return self.UseLongFileNames

    @uselongfilenames.setter
    def uselongfilenames(self, value):
        """Alias for UseLongFileNames.setter"""
        self.UseLongFileNames = value

    @property
    def use_long_file_names(self):
        """Alias for UseLongFileNames"""
        return self.UseLongFileNames

    @use_long_file_names.setter
    def use_long_file_names(self, value):
        """Alias for UseLongFileNames.setter"""
        self.UseLongFileNames = value

    def UseDefaultFolderSuffix(self):
        self.com_object.UseDefaultFolderSuffix()

    def usedefaultfoldersuffix(self):
        """Alias for UseDefaultFolderSuffix"""
        return self.UseDefaultFolderSuffix()

    def use_default_folder_suffix(self):
        """Alias for UseDefaultFolderSuffix"""
        return self.UseDefaultFolderSuffix()


class Window:

    def __init__(self, window=None):
        self.com_object= window

    @property
    def ActiveCell(self):
        return Range(self.com_object.ActiveCell)

    @property
    def activecell(self):
        """Alias for ActiveCell"""
        return self.ActiveCell

    @property
    def active_cell(self):
        """Alias for ActiveCell"""
        return self.ActiveCell

    @property
    def ActiveChart(self):
        return Chart(self.com_object.ActiveChart)

    @property
    def activechart(self):
        """Alias for ActiveChart"""
        return self.ActiveChart

    @property
    def active_chart(self):
        """Alias for ActiveChart"""
        return self.ActiveChart

    @property
    def ActivePane(self):
        return Pane(self.com_object.ActivePane)

    @property
    def activepane(self):
        """Alias for ActivePane"""
        return self.ActivePane

    @property
    def active_pane(self):
        """Alias for ActivePane"""
        return self.ActivePane

    @property
    def ActiveSheet(self):
        return self.com_object.ActiveSheet

    @property
    def activesheet(self):
        """Alias for ActiveSheet"""
        return self.ActiveSheet

    @property
    def active_sheet(self):
        """Alias for ActiveSheet"""
        return self.ActiveSheet

    @property
    def ActiveSheetView(self):
        return self.com_object.ActiveSheetView

    @property
    def activesheetview(self):
        """Alias for ActiveSheetView"""
        return self.ActiveSheetView

    @property
    def active_sheet_view(self):
        """Alias for ActiveSheetView"""
        return self.ActiveSheetView

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoFilterDateGrouping(self):
        return self.com_object.AutoFilterDateGrouping

    @AutoFilterDateGrouping.setter
    def AutoFilterDateGrouping(self, value):
        self.com_object.AutoFilterDateGrouping = value

    @property
    def autofilterdategrouping(self):
        """Alias for AutoFilterDateGrouping"""
        return self.AutoFilterDateGrouping

    @autofilterdategrouping.setter
    def autofilterdategrouping(self, value):
        """Alias for AutoFilterDateGrouping.setter"""
        self.AutoFilterDateGrouping = value

    @property
    def auto_filter_date_grouping(self):
        """Alias for AutoFilterDateGrouping"""
        return self.AutoFilterDateGrouping

    @auto_filter_date_grouping.setter
    def auto_filter_date_grouping(self, value):
        """Alias for AutoFilterDateGrouping.setter"""
        self.AutoFilterDateGrouping = value

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DisplayFormulas(self):
        return self.com_object.DisplayFormulas

    @DisplayFormulas.setter
    def DisplayFormulas(self, value):
        self.com_object.DisplayFormulas = value

    @property
    def displayformulas(self):
        """Alias for DisplayFormulas"""
        return self.DisplayFormulas

    @displayformulas.setter
    def displayformulas(self, value):
        """Alias for DisplayFormulas.setter"""
        self.DisplayFormulas = value

    @property
    def display_formulas(self):
        """Alias for DisplayFormulas"""
        return self.DisplayFormulas

    @display_formulas.setter
    def display_formulas(self, value):
        """Alias for DisplayFormulas.setter"""
        self.DisplayFormulas = value

    @property
    def DisplayGridlines(self):
        return self.com_object.DisplayGridlines

    @DisplayGridlines.setter
    def DisplayGridlines(self, value):
        self.com_object.DisplayGridlines = value

    @property
    def displaygridlines(self):
        """Alias for DisplayGridlines"""
        return self.DisplayGridlines

    @displaygridlines.setter
    def displaygridlines(self, value):
        """Alias for DisplayGridlines.setter"""
        self.DisplayGridlines = value

    @property
    def display_gridlines(self):
        """Alias for DisplayGridlines"""
        return self.DisplayGridlines

    @display_gridlines.setter
    def display_gridlines(self, value):
        """Alias for DisplayGridlines.setter"""
        self.DisplayGridlines = value

    @property
    def DisplayHeadings(self):
        return self.com_object.DisplayHeadings

    @DisplayHeadings.setter
    def DisplayHeadings(self, value):
        self.com_object.DisplayHeadings = value

    @property
    def displayheadings(self):
        """Alias for DisplayHeadings"""
        return self.DisplayHeadings

    @displayheadings.setter
    def displayheadings(self, value):
        """Alias for DisplayHeadings.setter"""
        self.DisplayHeadings = value

    @property
    def display_headings(self):
        """Alias for DisplayHeadings"""
        return self.DisplayHeadings

    @display_headings.setter
    def display_headings(self, value):
        """Alias for DisplayHeadings.setter"""
        self.DisplayHeadings = value

    @property
    def DisplayHorizontalScrollBar(self):
        return self.com_object.DisplayHorizontalScrollBar

    @DisplayHorizontalScrollBar.setter
    def DisplayHorizontalScrollBar(self, value):
        self.com_object.DisplayHorizontalScrollBar = value

    @property
    def displayhorizontalscrollbar(self):
        """Alias for DisplayHorizontalScrollBar"""
        return self.DisplayHorizontalScrollBar

    @displayhorizontalscrollbar.setter
    def displayhorizontalscrollbar(self, value):
        """Alias for DisplayHorizontalScrollBar.setter"""
        self.DisplayHorizontalScrollBar = value

    @property
    def display_horizontal_scroll_bar(self):
        """Alias for DisplayHorizontalScrollBar"""
        return self.DisplayHorizontalScrollBar

    @display_horizontal_scroll_bar.setter
    def display_horizontal_scroll_bar(self, value):
        """Alias for DisplayHorizontalScrollBar.setter"""
        self.DisplayHorizontalScrollBar = value

    @property
    def DisplayOutline(self):
        return self.com_object.DisplayOutline

    @DisplayOutline.setter
    def DisplayOutline(self, value):
        self.com_object.DisplayOutline = value

    @property
    def displayoutline(self):
        """Alias for DisplayOutline"""
        return self.DisplayOutline

    @displayoutline.setter
    def displayoutline(self, value):
        """Alias for DisplayOutline.setter"""
        self.DisplayOutline = value

    @property
    def display_outline(self):
        """Alias for DisplayOutline"""
        return self.DisplayOutline

    @display_outline.setter
    def display_outline(self, value):
        """Alias for DisplayOutline.setter"""
        self.DisplayOutline = value

    @property
    def DisplayRightToLeft(self):
        return self.com_object.DisplayRightToLeft

    @property
    def displayrighttoleft(self):
        """Alias for DisplayRightToLeft"""
        return self.DisplayRightToLeft

    @property
    def display_right_to_left(self):
        """Alias for DisplayRightToLeft"""
        return self.DisplayRightToLeft

    @property
    def DisplayRuler(self):
        return self.com_object.DisplayRuler

    @DisplayRuler.setter
    def DisplayRuler(self, value):
        self.com_object.DisplayRuler = value

    @property
    def displayruler(self):
        """Alias for DisplayRuler"""
        return self.DisplayRuler

    @displayruler.setter
    def displayruler(self, value):
        """Alias for DisplayRuler.setter"""
        self.DisplayRuler = value

    @property
    def display_ruler(self):
        """Alias for DisplayRuler"""
        return self.DisplayRuler

    @display_ruler.setter
    def display_ruler(self, value):
        """Alias for DisplayRuler.setter"""
        self.DisplayRuler = value

    @property
    def DisplayVerticalScrollBar(self):
        return self.com_object.DisplayVerticalScrollBar

    @DisplayVerticalScrollBar.setter
    def DisplayVerticalScrollBar(self, value):
        self.com_object.DisplayVerticalScrollBar = value

    @property
    def displayverticalscrollbar(self):
        """Alias for DisplayVerticalScrollBar"""
        return self.DisplayVerticalScrollBar

    @displayverticalscrollbar.setter
    def displayverticalscrollbar(self, value):
        """Alias for DisplayVerticalScrollBar.setter"""
        self.DisplayVerticalScrollBar = value

    @property
    def display_vertical_scroll_bar(self):
        """Alias for DisplayVerticalScrollBar"""
        return self.DisplayVerticalScrollBar

    @display_vertical_scroll_bar.setter
    def display_vertical_scroll_bar(self, value):
        """Alias for DisplayVerticalScrollBar.setter"""
        self.DisplayVerticalScrollBar = value

    @property
    def DisplayWhitespace(self):
        return self.com_object.DisplayWhitespace

    @DisplayWhitespace.setter
    def DisplayWhitespace(self, value):
        self.com_object.DisplayWhitespace = value

    @property
    def displaywhitespace(self):
        """Alias for DisplayWhitespace"""
        return self.DisplayWhitespace

    @displaywhitespace.setter
    def displaywhitespace(self, value):
        """Alias for DisplayWhitespace.setter"""
        self.DisplayWhitespace = value

    @property
    def display_whitespace(self):
        """Alias for DisplayWhitespace"""
        return self.DisplayWhitespace

    @display_whitespace.setter
    def display_whitespace(self, value):
        """Alias for DisplayWhitespace.setter"""
        self.DisplayWhitespace = value

    @property
    def DisplayWorkbookTabs(self):
        return self.com_object.DisplayWorkbookTabs

    @DisplayWorkbookTabs.setter
    def DisplayWorkbookTabs(self, value):
        self.com_object.DisplayWorkbookTabs = value

    @property
    def displayworkbooktabs(self):
        """Alias for DisplayWorkbookTabs"""
        return self.DisplayWorkbookTabs

    @displayworkbooktabs.setter
    def displayworkbooktabs(self, value):
        """Alias for DisplayWorkbookTabs.setter"""
        self.DisplayWorkbookTabs = value

    @property
    def display_workbook_tabs(self):
        """Alias for DisplayWorkbookTabs"""
        return self.DisplayWorkbookTabs

    @display_workbook_tabs.setter
    def display_workbook_tabs(self, value):
        """Alias for DisplayWorkbookTabs.setter"""
        self.DisplayWorkbookTabs = value

    @property
    def DisplayZeros(self):
        return self.com_object.DisplayZeros

    @DisplayZeros.setter
    def DisplayZeros(self, value):
        self.com_object.DisplayZeros = value

    @property
    def displayzeros(self):
        """Alias for DisplayZeros"""
        return self.DisplayZeros

    @displayzeros.setter
    def displayzeros(self, value):
        """Alias for DisplayZeros.setter"""
        self.DisplayZeros = value

    @property
    def display_zeros(self):
        """Alias for DisplayZeros"""
        return self.DisplayZeros

    @display_zeros.setter
    def display_zeros(self, value):
        """Alias for DisplayZeros.setter"""
        self.DisplayZeros = value

    @property
    def EnableResize(self):
        return self.com_object.EnableResize

    @EnableResize.setter
    def EnableResize(self, value):
        self.com_object.EnableResize = value

    @property
    def enableresize(self):
        """Alias for EnableResize"""
        return self.EnableResize

    @enableresize.setter
    def enableresize(self, value):
        """Alias for EnableResize.setter"""
        self.EnableResize = value

    @property
    def enable_resize(self):
        """Alias for EnableResize"""
        return self.EnableResize

    @enable_resize.setter
    def enable_resize(self, value):
        """Alias for EnableResize.setter"""
        self.EnableResize = value

    @property
    def FreezePanes(self):
        return self.com_object.FreezePanes

    @FreezePanes.setter
    def FreezePanes(self, value):
        self.com_object.FreezePanes = value

    @property
    def freezepanes(self):
        """Alias for FreezePanes"""
        return self.FreezePanes

    @freezepanes.setter
    def freezepanes(self, value):
        """Alias for FreezePanes.setter"""
        self.FreezePanes = value

    @property
    def freeze_panes(self):
        """Alias for FreezePanes"""
        return self.FreezePanes

    @freeze_panes.setter
    def freeze_panes(self, value):
        """Alias for FreezePanes.setter"""
        self.FreezePanes = value

    @property
    def GridlineColor(self):
        return self.com_object.GridlineColor

    @GridlineColor.setter
    def GridlineColor(self, value):
        self.com_object.GridlineColor = value

    @property
    def gridlinecolor(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridlinecolor.setter
    def gridlinecolor(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def gridline_color(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridline_color.setter
    def gridline_color(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def GridlineColorIndex(self):
        return XlColorIndex(self.com_object.GridlineColorIndex)

    @GridlineColorIndex.setter
    def GridlineColorIndex(self, value):
        self.com_object.GridlineColorIndex = value

    @property
    def gridlinecolorindex(self):
        """Alias for GridlineColorIndex"""
        return self.GridlineColorIndex

    @gridlinecolorindex.setter
    def gridlinecolorindex(self, value):
        """Alias for GridlineColorIndex.setter"""
        self.GridlineColorIndex = value

    @property
    def gridline_color_index(self):
        """Alias for GridlineColorIndex"""
        return self.GridlineColorIndex

    @gridline_color_index.setter
    def gridline_color_index(self, value):
        """Alias for GridlineColorIndex.setter"""
        self.GridlineColorIndex = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def hWnd(self):
        return self.com_object.hWnd

    @property
    def hwnd(self):
        """Alias for hWnd"""
        return self.hWnd

    @property
    def h_wnd(self):
        """Alias for hWnd"""
        return self.hWnd

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def OnWindow(self):
        return self.com_object.OnWindow

    @OnWindow.setter
    def OnWindow(self, value):
        self.com_object.OnWindow = value

    @property
    def onwindow(self):
        """Alias for OnWindow"""
        return self.OnWindow

    @onwindow.setter
    def onwindow(self, value):
        """Alias for OnWindow.setter"""
        self.OnWindow = value

    @property
    def on_window(self):
        """Alias for OnWindow"""
        return self.OnWindow

    @on_window.setter
    def on_window(self, value):
        """Alias for OnWindow.setter"""
        self.OnWindow = value

    @property
    def Panes(self):
        return Panes(self.com_object.Panes)

    @property
    def panes(self):
        """Alias for Panes"""
        return self.Panes

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def RangeSelection(self):
        return Range(self.com_object.RangeSelection)

    @property
    def rangeselection(self):
        """Alias for RangeSelection"""
        return self.RangeSelection

    @property
    def range_selection(self):
        """Alias for RangeSelection"""
        return self.RangeSelection

    @property
    def ScrollColumn(self):
        return self.com_object.ScrollColumn

    @ScrollColumn.setter
    def ScrollColumn(self, value):
        self.com_object.ScrollColumn = value

    @property
    def scrollcolumn(self):
        """Alias for ScrollColumn"""
        return self.ScrollColumn

    @scrollcolumn.setter
    def scrollcolumn(self, value):
        """Alias for ScrollColumn.setter"""
        self.ScrollColumn = value

    @property
    def scroll_column(self):
        """Alias for ScrollColumn"""
        return self.ScrollColumn

    @scroll_column.setter
    def scroll_column(self, value):
        """Alias for ScrollColumn.setter"""
        self.ScrollColumn = value

    @property
    def ScrollRow(self):
        return self.com_object.ScrollRow

    @ScrollRow.setter
    def ScrollRow(self, value):
        self.com_object.ScrollRow = value

    @property
    def scrollrow(self):
        """Alias for ScrollRow"""
        return self.ScrollRow

    @scrollrow.setter
    def scrollrow(self, value):
        """Alias for ScrollRow.setter"""
        self.ScrollRow = value

    @property
    def scroll_row(self):
        """Alias for ScrollRow"""
        return self.ScrollRow

    @scroll_row.setter
    def scroll_row(self, value):
        """Alias for ScrollRow.setter"""
        self.ScrollRow = value

    @property
    def SelectedSheets(self):
        return Sheets(self.com_object.SelectedSheets)

    @property
    def selectedsheets(self):
        """Alias for SelectedSheets"""
        return self.SelectedSheets

    @property
    def selected_sheets(self):
        """Alias for SelectedSheets"""
        return self.SelectedSheets

    @property
    def Selection(self):
        return Windows(self.com_object.Selection)

    @property
    def selection(self):
        """Alias for Selection"""
        return self.Selection

    @property
    def SheetViews(self):
        return SheetViews(self.com_object.SheetViews)

    @property
    def sheetviews(self):
        """Alias for SheetViews"""
        return self.SheetViews

    @property
    def sheet_views(self):
        """Alias for SheetViews"""
        return self.SheetViews

    @property
    def Split(self):
        return self.com_object.Split

    @Split.setter
    def Split(self, value):
        self.com_object.Split = value

    @property
    def split(self):
        """Alias for Split"""
        return self.Split

    @split.setter
    def split(self, value):
        """Alias for Split.setter"""
        self.Split = value

    @property
    def SplitColumn(self):
        return self.com_object.SplitColumn

    @SplitColumn.setter
    def SplitColumn(self, value):
        self.com_object.SplitColumn = value

    @property
    def splitcolumn(self):
        """Alias for SplitColumn"""
        return self.SplitColumn

    @splitcolumn.setter
    def splitcolumn(self, value):
        """Alias for SplitColumn.setter"""
        self.SplitColumn = value

    @property
    def split_column(self):
        """Alias for SplitColumn"""
        return self.SplitColumn

    @split_column.setter
    def split_column(self, value):
        """Alias for SplitColumn.setter"""
        self.SplitColumn = value

    @property
    def SplitHorizontal(self):
        return self.com_object.SplitHorizontal

    @SplitHorizontal.setter
    def SplitHorizontal(self, value):
        self.com_object.SplitHorizontal = value

    @property
    def splithorizontal(self):
        """Alias for SplitHorizontal"""
        return self.SplitHorizontal

    @splithorizontal.setter
    def splithorizontal(self, value):
        """Alias for SplitHorizontal.setter"""
        self.SplitHorizontal = value

    @property
    def split_horizontal(self):
        """Alias for SplitHorizontal"""
        return self.SplitHorizontal

    @split_horizontal.setter
    def split_horizontal(self, value):
        """Alias for SplitHorizontal.setter"""
        self.SplitHorizontal = value

    @property
    def SplitRow(self):
        return self.com_object.SplitRow

    @SplitRow.setter
    def SplitRow(self, value):
        self.com_object.SplitRow = value

    @property
    def splitrow(self):
        """Alias for SplitRow"""
        return self.SplitRow

    @splitrow.setter
    def splitrow(self, value):
        """Alias for SplitRow.setter"""
        self.SplitRow = value

    @property
    def split_row(self):
        """Alias for SplitRow"""
        return self.SplitRow

    @split_row.setter
    def split_row(self, value):
        """Alias for SplitRow.setter"""
        self.SplitRow = value

    @property
    def SplitVertical(self):
        return self.com_object.SplitVertical

    @SplitVertical.setter
    def SplitVertical(self, value):
        self.com_object.SplitVertical = value

    @property
    def splitvertical(self):
        """Alias for SplitVertical"""
        return self.SplitVertical

    @splitvertical.setter
    def splitvertical(self, value):
        """Alias for SplitVertical.setter"""
        self.SplitVertical = value

    @property
    def split_vertical(self):
        """Alias for SplitVertical"""
        return self.SplitVertical

    @split_vertical.setter
    def split_vertical(self, value):
        """Alias for SplitVertical.setter"""
        self.SplitVertical = value

    @property
    def TabRatio(self):
        return self.com_object.TabRatio

    @TabRatio.setter
    def TabRatio(self, value):
        self.com_object.TabRatio = value

    @property
    def tabratio(self):
        """Alias for TabRatio"""
        return self.TabRatio

    @tabratio.setter
    def tabratio(self, value):
        """Alias for TabRatio.setter"""
        self.TabRatio = value

    @property
    def tab_ratio(self):
        """Alias for TabRatio"""
        return self.TabRatio

    @tab_ratio.setter
    def tab_ratio(self, value):
        """Alias for TabRatio.setter"""
        self.TabRatio = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def Type(self):
        return XlWindowType(self.com_object.Type)

    @Type.setter
    def Type(self, value):
        self.com_object.Type = value

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @type.setter
    def type(self, value):
        """Alias for Type.setter"""
        self.Type = value

    @property
    def UsableHeight(self):
        return self.com_object.UsableHeight

    @property
    def usableheight(self):
        """Alias for UsableHeight"""
        return self.UsableHeight

    @property
    def usable_height(self):
        """Alias for UsableHeight"""
        return self.UsableHeight

    @property
    def UsableWidth(self):
        return self.com_object.UsableWidth

    @property
    def usablewidth(self):
        """Alias for UsableWidth"""
        return self.UsableWidth

    @property
    def usable_width(self):
        """Alias for UsableWidth"""
        return self.UsableWidth

    @property
    def View(self):
        return XlWindowView(self.com_object.View)

    @View.setter
    def View(self, value):
        self.com_object.View = value

    @property
    def view(self):
        """Alias for View"""
        return self.View

    @view.setter
    def view(self, value):
        """Alias for View.setter"""
        self.View = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def VisibleRange(self):
        return Range(self.com_object.VisibleRange)

    @property
    def visiblerange(self):
        """Alias for VisibleRange"""
        return self.VisibleRange

    @property
    def visible_range(self):
        """Alias for VisibleRange"""
        return self.VisibleRange

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def WindowNumber(self):
        return self.com_object.WindowNumber

    @property
    def windownumber(self):
        """Alias for WindowNumber"""
        return self.WindowNumber

    @property
    def window_number(self):
        """Alias for WindowNumber"""
        return self.WindowNumber

    @property
    def WindowState(self):
        return XlWindowState(self.com_object.WindowState)

    @WindowState.setter
    def WindowState(self, value):
        self.com_object.WindowState = value

    @property
    def windowstate(self):
        """Alias for WindowState"""
        return self.WindowState

    @windowstate.setter
    def windowstate(self, value):
        """Alias for WindowState.setter"""
        self.WindowState = value

    @property
    def window_state(self):
        """Alias for WindowState"""
        return self.WindowState

    @window_state.setter
    def window_state(self, value):
        """Alias for WindowState.setter"""
        self.WindowState = value

    @property
    def Zoom(self):
        return self.com_object.Zoom

    @Zoom.setter
    def Zoom(self, value):
        self.com_object.Zoom = value

    @property
    def zoom(self):
        """Alias for Zoom"""
        return self.Zoom

    @zoom.setter
    def zoom(self, value):
        """Alias for Zoom.setter"""
        self.Zoom = value

    def Activate(self):
        return self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()

    def ActivateNext(self):
        return self.com_object.ActivateNext()

    def activatenext(self):
        """Alias for ActivateNext"""
        return self.ActivateNext()

    def activate_next(self):
        """Alias for ActivateNext"""
        return self.ActivateNext()

    def ActivatePrevious(self):
        return self.com_object.ActivatePrevious()

    def activateprevious(self):
        """Alias for ActivatePrevious"""
        return self.ActivatePrevious()

    def activate_previous(self):
        """Alias for ActivatePrevious"""
        return self.ActivatePrevious()

    def Close(self, SaveChanges=None, FileName=None, RouteWorkbook=None):
        arguments = com_arguments([unwrap(a) for a in [SaveChanges, FileName, RouteWorkbook]])
        return self.com_object.Close(*arguments)

    def close(self, SaveChanges=None, FileName=None, RouteWorkbook=None):
        """Alias for Close"""
        arguments = [SaveChanges, FileName, RouteWorkbook]
        return self.Close(*arguments)

    def LargeScroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        arguments = com_arguments([unwrap(a) for a in [Down, Up, ToRight, ToLeft]])
        return self.com_object.LargeScroll(*arguments)

    def largescroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        """Alias for LargeScroll"""
        arguments = [Down, Up, ToRight, ToLeft]
        return self.LargeScroll(*arguments)

    def large_scroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        """Alias for LargeScroll"""
        arguments = [Down, Up, ToRight, ToLeft]
        return self.LargeScroll(*arguments)

    def NewWindow(self):
        return Window(self.com_object.NewWindow())

    def newwindow(self):
        """Alias for NewWindow"""
        return self.NewWindow()

    def new_window(self):
        """Alias for NewWindow"""
        return self.NewWindow()

    def PointsToScreenPixelsX(self, Points=None):
        arguments = com_arguments([unwrap(a) for a in [Points]])
        return self.com_object.PointsToScreenPixelsX(*arguments)

    def pointstoscreenpixelsx(self, Points=None):
        """Alias for PointsToScreenPixelsX"""
        arguments = [Points]
        return self.PointsToScreenPixelsX(*arguments)

    def points_to_screen_pixels_x(self, Points=None):
        """Alias for PointsToScreenPixelsX"""
        arguments = [Points]
        return self.PointsToScreenPixelsX(*arguments)

    def PointsToScreenPixelsY(self, Points=None):
        arguments = com_arguments([unwrap(a) for a in [Points]])
        return self.com_object.PointsToScreenPixelsY(*arguments)

    def pointstoscreenpixelsy(self, Points=None):
        """Alias for PointsToScreenPixelsY"""
        arguments = [Points]
        return self.PointsToScreenPixelsY(*arguments)

    def points_to_screen_pixels_y(self, Points=None):
        """Alias for PointsToScreenPixelsY"""
        arguments = [Points]
        return self.PointsToScreenPixelsY(*arguments)

    def PrintOut(self, From=None, To=None, Copies=None, Preview=None, ActivePrinter=None, PrintToFile=None, Collate=None, PrToFileName=None):
        arguments = com_arguments([unwrap(a) for a in [From, To, Copies, Preview, ActivePrinter, PrintToFile, Collate, PrToFileName]])
        return self.com_object.PrintOut(*arguments)

    def printout(self, From=None, To=None, Copies=None, Preview=None, ActivePrinter=None, PrintToFile=None, Collate=None, PrToFileName=None):
        """Alias for PrintOut"""
        arguments = [From, To, Copies, Preview, ActivePrinter, PrintToFile, Collate, PrToFileName]
        return self.PrintOut(*arguments)

    def print_out(self, From=None, To=None, Copies=None, Preview=None, ActivePrinter=None, PrintToFile=None, Collate=None, PrToFileName=None):
        """Alias for PrintOut"""
        arguments = [From, To, Copies, Preview, ActivePrinter, PrintToFile, Collate, PrToFileName]
        return self.PrintOut(*arguments)

    def PrintPreview(self, EnableChanges=None):
        arguments = com_arguments([unwrap(a) for a in [EnableChanges]])
        return self.com_object.PrintPreview(*arguments)

    def printpreview(self, EnableChanges=None):
        """Alias for PrintPreview"""
        arguments = [EnableChanges]
        return self.PrintPreview(*arguments)

    def print_preview(self, EnableChanges=None):
        """Alias for PrintPreview"""
        arguments = [EnableChanges]
        return self.PrintPreview(*arguments)

    def RangeFromPoint(self, x=None, y=None):
        arguments = com_arguments([unwrap(a) for a in [x, y]])
        return self.com_object.RangeFromPoint(*arguments)

    def rangefrompoint(self, x=None, y=None):
        """Alias for RangeFromPoint"""
        arguments = [x, y]
        return self.RangeFromPoint(*arguments)

    def range_from_point(self, x=None, y=None):
        """Alias for RangeFromPoint"""
        arguments = [x, y]
        return self.RangeFromPoint(*arguments)

    def ScrollIntoView(self, Left=None, Top=None, Width=None, Height=None, Start=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height, Start]])
        self.com_object.ScrollIntoView(*arguments)

    def scrollintoview(self, Left=None, Top=None, Width=None, Height=None, Start=None):
        """Alias for ScrollIntoView"""
        arguments = [Left, Top, Width, Height, Start]
        return self.ScrollIntoView(*arguments)

    def scroll_into_view(self, Left=None, Top=None, Width=None, Height=None, Start=None):
        """Alias for ScrollIntoView"""
        arguments = [Left, Top, Width, Height, Start]
        return self.ScrollIntoView(*arguments)

    def ScrollWorkbookTabs(self, Sheets=None, Position=None):
        arguments = com_arguments([unwrap(a) for a in [Sheets, Position]])
        return self.com_object.ScrollWorkbookTabs(*arguments)

    def scrollworkbooktabs(self, Sheets=None, Position=None):
        """Alias for ScrollWorkbookTabs"""
        arguments = [Sheets, Position]
        return self.ScrollWorkbookTabs(*arguments)

    def scroll_workbook_tabs(self, Sheets=None, Position=None):
        """Alias for ScrollWorkbookTabs"""
        arguments = [Sheets, Position]
        return self.ScrollWorkbookTabs(*arguments)

    def SmallScroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        arguments = com_arguments([unwrap(a) for a in [Down, Up, ToRight, ToLeft]])
        return self.com_object.SmallScroll(*arguments)

    def smallscroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        """Alias for SmallScroll"""
        arguments = [Down, Up, ToRight, ToLeft]
        return self.SmallScroll(*arguments)

    def small_scroll(self, Down=None, Up=None, ToRight=None, ToLeft=None):
        """Alias for SmallScroll"""
        arguments = [Down, Up, ToRight, ToLeft]
        return self.SmallScroll(*arguments)


class Windows:

    def __init__(self, windows=None):
        self.com_object= windows

    def __call__(self, item):
        return Window(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SyncScrollingSideBySide(self):
        return self.com_object.SyncScrollingSideBySide

    @property
    def syncscrollingsidebyside(self):
        """Alias for SyncScrollingSideBySide"""
        return self.SyncScrollingSideBySide

    @property
    def sync_scrolling_side_by_side(self):
        """Alias for SyncScrollingSideBySide"""
        return self.SyncScrollingSideBySide

    def Arrange(self, ArrangeStyle=None, ActiveWorkbook=None, SyncHorizontal=None, SyncVertical=None):
        arguments = com_arguments([unwrap(a) for a in [ArrangeStyle, ActiveWorkbook, SyncHorizontal, SyncVertical]])
        return self.com_object.Arrange(*arguments)

    def arrange(self, ArrangeStyle=None, ActiveWorkbook=None, SyncHorizontal=None, SyncVertical=None):
        """Alias for Arrange"""
        arguments = [ArrangeStyle, ActiveWorkbook, SyncHorizontal, SyncVertical]
        return self.Arrange(*arguments)

    def BreakSideBySide(self):
        return self.com_object.BreakSideBySide()

    def breaksidebyside(self):
        """Alias for BreakSideBySide"""
        return self.BreakSideBySide()

    def break_side_by_side(self):
        """Alias for BreakSideBySide"""
        return self.BreakSideBySide()

    def CompareSideBySideWith(self, WindowName=None):
        arguments = com_arguments([unwrap(a) for a in [WindowName]])
        return self.com_object.CompareSideBySideWith(*arguments)

    def comparesidebysidewith(self, WindowName=None):
        """Alias for CompareSideBySideWith"""
        arguments = [WindowName]
        return self.CompareSideBySideWith(*arguments)

    def compare_side_by_side_with(self, WindowName=None):
        """Alias for CompareSideBySideWith"""
        arguments = [WindowName]
        return self.CompareSideBySideWith(*arguments)

    def ResetPositionsSideBySide(self):
        self.com_object.ResetPositionsSideBySide()

    def resetpositionssidebyside(self):
        """Alias for ResetPositionsSideBySide"""
        return self.ResetPositionsSideBySide()

    def reset_positions_side_by_side(self):
        """Alias for ResetPositionsSideBySide"""
        return self.ResetPositionsSideBySide()


class Workbook:

    def __init__(self, workbook=None):
        self.com_object= workbook

    @property
    def AccuracyVersion(self):
        return self.com_object.AccuracyVersion

    @AccuracyVersion.setter
    def AccuracyVersion(self, value):
        self.com_object.AccuracyVersion = value

    @property
    def accuracyversion(self):
        """Alias for AccuracyVersion"""
        return self.AccuracyVersion

    @accuracyversion.setter
    def accuracyversion(self, value):
        """Alias for AccuracyVersion.setter"""
        self.AccuracyVersion = value

    @property
    def accuracy_version(self):
        """Alias for AccuracyVersion"""
        return self.AccuracyVersion

    @accuracy_version.setter
    def accuracy_version(self, value):
        """Alias for AccuracyVersion.setter"""
        self.AccuracyVersion = value

    @property
    def ActiveChart(self):
        return Chart(self.com_object.ActiveChart)

    @property
    def activechart(self):
        """Alias for ActiveChart"""
        return self.ActiveChart

    @property
    def active_chart(self):
        """Alias for ActiveChart"""
        return self.ActiveChart

    @property
    def ActiveSheet(self):
        return Worksheet(self.com_object.ActiveSheet)

    @property
    def activesheet(self):
        """Alias for ActiveSheet"""
        return self.ActiveSheet

    @property
    def active_sheet(self):
        """Alias for ActiveSheet"""
        return self.ActiveSheet

    @property
    def ActiveSlicer(self):
        return self.com_object.ActiveSlicer

    @property
    def activeslicer(self):
        """Alias for ActiveSlicer"""
        return self.ActiveSlicer

    @property
    def active_slicer(self):
        """Alias for ActiveSlicer"""
        return self.ActiveSlicer

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoSaveOn(self):
        return self.com_object.AutoSaveOn

    @AutoSaveOn.setter
    def AutoSaveOn(self, value):
        self.com_object.AutoSaveOn = value

    @property
    def autosaveon(self):
        """Alias for AutoSaveOn"""
        return self.AutoSaveOn

    @autosaveon.setter
    def autosaveon(self, value):
        """Alias for AutoSaveOn.setter"""
        self.AutoSaveOn = value

    @property
    def auto_save_on(self):
        """Alias for AutoSaveOn"""
        return self.AutoSaveOn

    @auto_save_on.setter
    def auto_save_on(self, value):
        """Alias for AutoSaveOn.setter"""
        self.AutoSaveOn = value

    @property
    def AutoUpdateFrequency(self):
        return self.com_object.AutoUpdateFrequency

    @AutoUpdateFrequency.setter
    def AutoUpdateFrequency(self, value):
        self.com_object.AutoUpdateFrequency = value

    @property
    def autoupdatefrequency(self):
        """Alias for AutoUpdateFrequency"""
        return self.AutoUpdateFrequency

    @autoupdatefrequency.setter
    def autoupdatefrequency(self, value):
        """Alias for AutoUpdateFrequency.setter"""
        self.AutoUpdateFrequency = value

    @property
    def auto_update_frequency(self):
        """Alias for AutoUpdateFrequency"""
        return self.AutoUpdateFrequency

    @auto_update_frequency.setter
    def auto_update_frequency(self, value):
        """Alias for AutoUpdateFrequency.setter"""
        self.AutoUpdateFrequency = value

    @property
    def AutoUpdateSaveChanges(self):
        return self.com_object.AutoUpdateSaveChanges

    @AutoUpdateSaveChanges.setter
    def AutoUpdateSaveChanges(self, value):
        self.com_object.AutoUpdateSaveChanges = value

    @property
    def autoupdatesavechanges(self):
        """Alias for AutoUpdateSaveChanges"""
        return self.AutoUpdateSaveChanges

    @autoupdatesavechanges.setter
    def autoupdatesavechanges(self, value):
        """Alias for AutoUpdateSaveChanges.setter"""
        self.AutoUpdateSaveChanges = value

    @property
    def auto_update_save_changes(self):
        """Alias for AutoUpdateSaveChanges"""
        return self.AutoUpdateSaveChanges

    @auto_update_save_changes.setter
    def auto_update_save_changes(self, value):
        """Alias for AutoUpdateSaveChanges.setter"""
        self.AutoUpdateSaveChanges = value

    @property
    def BuiltinDocumentProperties(self):
        return self.com_object.BuiltinDocumentProperties

    @property
    def builtindocumentproperties(self):
        """Alias for BuiltinDocumentProperties"""
        return self.BuiltinDocumentProperties

    @property
    def builtin_document_properties(self):
        """Alias for BuiltinDocumentProperties"""
        return self.BuiltinDocumentProperties

    @property
    def CalculationVersion(self):
        return self.com_object.CalculationVersion

    @property
    def calculationversion(self):
        """Alias for CalculationVersion"""
        return self.CalculationVersion

    @property
    def calculation_version(self):
        """Alias for CalculationVersion"""
        return self.CalculationVersion

    @property
    def CaseSensitive(self):
        return self.com_object.CaseSensitive

    @property
    def casesensitive(self):
        """Alias for CaseSensitive"""
        return self.CaseSensitive

    @property
    def case_sensitive(self):
        """Alias for CaseSensitive"""
        return self.CaseSensitive

    @property
    def ChangeHistoryDuration(self):
        return self.com_object.ChangeHistoryDuration

    @ChangeHistoryDuration.setter
    def ChangeHistoryDuration(self, value):
        self.com_object.ChangeHistoryDuration = value

    @property
    def changehistoryduration(self):
        """Alias for ChangeHistoryDuration"""
        return self.ChangeHistoryDuration

    @changehistoryduration.setter
    def changehistoryduration(self, value):
        """Alias for ChangeHistoryDuration.setter"""
        self.ChangeHistoryDuration = value

    @property
    def change_history_duration(self):
        """Alias for ChangeHistoryDuration"""
        return self.ChangeHistoryDuration

    @change_history_duration.setter
    def change_history_duration(self, value):
        """Alias for ChangeHistoryDuration.setter"""
        self.ChangeHistoryDuration = value

    @property
    def ChartDataPointTrack(self):
        return self.com_object.ChartDataPointTrack

    @ChartDataPointTrack.setter
    def ChartDataPointTrack(self, value):
        self.com_object.ChartDataPointTrack = value

    @property
    def chartdatapointtrack(self):
        """Alias for ChartDataPointTrack"""
        return self.ChartDataPointTrack

    @chartdatapointtrack.setter
    def chartdatapointtrack(self, value):
        """Alias for ChartDataPointTrack.setter"""
        self.ChartDataPointTrack = value

    @property
    def chart_data_point_track(self):
        """Alias for ChartDataPointTrack"""
        return self.ChartDataPointTrack

    @chart_data_point_track.setter
    def chart_data_point_track(self, value):
        """Alias for ChartDataPointTrack.setter"""
        self.ChartDataPointTrack = value

    @property
    def Charts(self):
        return Sheets(self.com_object.Charts)

    @property
    def charts(self):
        """Alias for Charts"""
        return self.Charts

    @property
    def CheckCompatibility(self):
        return self.com_object.CheckCompatibility

    @CheckCompatibility.setter
    def CheckCompatibility(self, value):
        self.com_object.CheckCompatibility = value

    @property
    def checkcompatibility(self):
        """Alias for CheckCompatibility"""
        return self.CheckCompatibility

    @checkcompatibility.setter
    def checkcompatibility(self, value):
        """Alias for CheckCompatibility.setter"""
        self.CheckCompatibility = value

    @property
    def check_compatibility(self):
        """Alias for CheckCompatibility"""
        return self.CheckCompatibility

    @check_compatibility.setter
    def check_compatibility(self, value):
        """Alias for CheckCompatibility.setter"""
        self.CheckCompatibility = value

    @property
    def CodeName(self):
        return self.com_object.CodeName

    @property
    def codename(self):
        """Alias for CodeName"""
        return self.CodeName

    @property
    def code_name(self):
        """Alias for CodeName"""
        return self.CodeName

    @property
    def Colors(self):
        return self.com_object.Colors

    @Colors.setter
    def Colors(self, value):
        self.com_object.Colors = value

    @property
    def colors(self):
        """Alias for Colors"""
        return self.Colors

    @colors.setter
    def colors(self, value):
        """Alias for Colors.setter"""
        self.Colors = value

    @property
    def CommandBars(self):
        return CommandBars(self.com_object.CommandBars)

    @property
    def commandbars(self):
        """Alias for CommandBars"""
        return self.CommandBars

    @property
    def command_bars(self):
        """Alias for CommandBars"""
        return self.CommandBars

    @property
    def ConflictResolution(self):
        return XlSaveConflictResolution(self.com_object.ConflictResolution)

    @ConflictResolution.setter
    def ConflictResolution(self, value):
        self.com_object.ConflictResolution = value

    @property
    def conflictresolution(self):
        """Alias for ConflictResolution"""
        return self.ConflictResolution

    @conflictresolution.setter
    def conflictresolution(self, value):
        """Alias for ConflictResolution.setter"""
        self.ConflictResolution = value

    @property
    def conflict_resolution(self):
        """Alias for ConflictResolution"""
        return self.ConflictResolution

    @conflict_resolution.setter
    def conflict_resolution(self, value):
        """Alias for ConflictResolution.setter"""
        self.ConflictResolution = value

    @property
    def Connections(self):
        return self.com_object.Connections

    @property
    def connections(self):
        """Alias for Connections"""
        return self.Connections

    @property
    def ConnectionsDisabled(self):
        return self.com_object.ConnectionsDisabled

    @property
    def connectionsdisabled(self):
        """Alias for ConnectionsDisabled"""
        return self.ConnectionsDisabled

    @property
    def connections_disabled(self):
        """Alias for ConnectionsDisabled"""
        return self.ConnectionsDisabled

    @property
    def Container(self):
        return self.com_object.Container

    @property
    def container(self):
        """Alias for Container"""
        return self.Container

    @property
    def ContentTypeProperties(self):
        return self.com_object.ContentTypeProperties

    @property
    def contenttypeproperties(self):
        """Alias for ContentTypeProperties"""
        return self.ContentTypeProperties

    @property
    def content_type_properties(self):
        """Alias for ContentTypeProperties"""
        return self.ContentTypeProperties

    @property
    def CreateBackup(self):
        return self.com_object.CreateBackup

    @property
    def createbackup(self):
        """Alias for CreateBackup"""
        return self.CreateBackup

    @property
    def create_backup(self):
        """Alias for CreateBackup"""
        return self.CreateBackup

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def CustomDocumentProperties(self):
        return self.com_object.CustomDocumentProperties

    @CustomDocumentProperties.setter
    def CustomDocumentProperties(self, value):
        self.com_object.CustomDocumentProperties = value

    @property
    def customdocumentproperties(self):
        """Alias for CustomDocumentProperties"""
        return self.CustomDocumentProperties

    @customdocumentproperties.setter
    def customdocumentproperties(self, value):
        """Alias for CustomDocumentProperties.setter"""
        self.CustomDocumentProperties = value

    @property
    def custom_document_properties(self):
        """Alias for CustomDocumentProperties"""
        return self.CustomDocumentProperties

    @custom_document_properties.setter
    def custom_document_properties(self, value):
        """Alias for CustomDocumentProperties.setter"""
        self.CustomDocumentProperties = value

    @property
    def CustomViews(self):
        return CustomViews(self.com_object.CustomViews)

    @property
    def customviews(self):
        """Alias for CustomViews"""
        return self.CustomViews

    @property
    def custom_views(self):
        """Alias for CustomViews"""
        return self.CustomViews

    @property
    def CustomXMLParts(self):
        return self.com_object.CustomXMLParts

    @property
    def customxmlparts(self):
        """Alias for CustomXMLParts"""
        return self.CustomXMLParts

    @property
    def custom_x_m_l_parts(self):
        """Alias for CustomXMLParts"""
        return self.CustomXMLParts

    @property
    def Date1904(self):
        return self.com_object.Date1904

    @Date1904.setter
    def Date1904(self, value):
        self.com_object.Date1904 = value

    @property
    def date1904(self):
        """Alias for Date1904"""
        return self.Date1904

    @date1904.setter
    def date1904(self, value):
        """Alias for Date1904.setter"""
        self.Date1904 = value

    @property
    def DefaultPivotTableStyle(self):
        return self.com_object.DefaultPivotTableStyle

    @DefaultPivotTableStyle.setter
    def DefaultPivotTableStyle(self, value):
        self.com_object.DefaultPivotTableStyle = value

    @property
    def defaultpivottablestyle(self):
        """Alias for DefaultPivotTableStyle"""
        return self.DefaultPivotTableStyle

    @defaultpivottablestyle.setter
    def defaultpivottablestyle(self, value):
        """Alias for DefaultPivotTableStyle.setter"""
        self.DefaultPivotTableStyle = value

    @property
    def default_pivot_table_style(self):
        """Alias for DefaultPivotTableStyle"""
        return self.DefaultPivotTableStyle

    @default_pivot_table_style.setter
    def default_pivot_table_style(self, value):
        """Alias for DefaultPivotTableStyle.setter"""
        self.DefaultPivotTableStyle = value

    @property
    def DefaultSlicerStyle(self):
        return self.com_object.DefaultSlicerStyle

    @DefaultSlicerStyle.setter
    def DefaultSlicerStyle(self, value):
        self.com_object.DefaultSlicerStyle = value

    @property
    def defaultslicerstyle(self):
        """Alias for DefaultSlicerStyle"""
        return self.DefaultSlicerStyle

    @defaultslicerstyle.setter
    def defaultslicerstyle(self, value):
        """Alias for DefaultSlicerStyle.setter"""
        self.DefaultSlicerStyle = value

    @property
    def default_slicer_style(self):
        """Alias for DefaultSlicerStyle"""
        return self.DefaultSlicerStyle

    @default_slicer_style.setter
    def default_slicer_style(self, value):
        """Alias for DefaultSlicerStyle.setter"""
        self.DefaultSlicerStyle = value

    @property
    def DefaultTableStyle(self):
        return self.com_object.DefaultTableStyle

    @DefaultTableStyle.setter
    def DefaultTableStyle(self, value):
        self.com_object.DefaultTableStyle = value

    @property
    def defaulttablestyle(self):
        """Alias for DefaultTableStyle"""
        return self.DefaultTableStyle

    @defaulttablestyle.setter
    def defaulttablestyle(self, value):
        """Alias for DefaultTableStyle.setter"""
        self.DefaultTableStyle = value

    @property
    def default_table_style(self):
        """Alias for DefaultTableStyle"""
        return self.DefaultTableStyle

    @default_table_style.setter
    def default_table_style(self, value):
        """Alias for DefaultTableStyle.setter"""
        self.DefaultTableStyle = value

    @property
    def DefaultTimelineStyle(self):
        return self.com_object.DefaultTimelineStyle

    @DefaultTimelineStyle.setter
    def DefaultTimelineStyle(self, value):
        self.com_object.DefaultTimelineStyle = value

    @property
    def defaulttimelinestyle(self):
        """Alias for DefaultTimelineStyle"""
        return self.DefaultTimelineStyle

    @defaulttimelinestyle.setter
    def defaulttimelinestyle(self, value):
        """Alias for DefaultTimelineStyle.setter"""
        self.DefaultTimelineStyle = value

    @property
    def default_timeline_style(self):
        """Alias for DefaultTimelineStyle"""
        return self.DefaultTimelineStyle

    @default_timeline_style.setter
    def default_timeline_style(self, value):
        """Alias for DefaultTimelineStyle.setter"""
        self.DefaultTimelineStyle = value

    @property
    def DisplayDrawingObjects(self):
        return self.com_object.DisplayDrawingObjects

    @DisplayDrawingObjects.setter
    def DisplayDrawingObjects(self, value):
        self.com_object.DisplayDrawingObjects = value

    @property
    def displaydrawingobjects(self):
        """Alias for DisplayDrawingObjects"""
        return self.DisplayDrawingObjects

    @displaydrawingobjects.setter
    def displaydrawingobjects(self, value):
        """Alias for DisplayDrawingObjects.setter"""
        self.DisplayDrawingObjects = value

    @property
    def display_drawing_objects(self):
        """Alias for DisplayDrawingObjects"""
        return self.DisplayDrawingObjects

    @display_drawing_objects.setter
    def display_drawing_objects(self, value):
        """Alias for DisplayDrawingObjects.setter"""
        self.DisplayDrawingObjects = value

    @property
    def DisplayInkComments(self):
        return self.com_object.DisplayInkComments

    @DisplayInkComments.setter
    def DisplayInkComments(self, value):
        self.com_object.DisplayInkComments = value

    @property
    def displayinkcomments(self):
        """Alias for DisplayInkComments"""
        return self.DisplayInkComments

    @displayinkcomments.setter
    def displayinkcomments(self, value):
        """Alias for DisplayInkComments.setter"""
        self.DisplayInkComments = value

    @property
    def display_ink_comments(self):
        """Alias for DisplayInkComments"""
        return self.DisplayInkComments

    @display_ink_comments.setter
    def display_ink_comments(self, value):
        """Alias for DisplayInkComments.setter"""
        self.DisplayInkComments = value

    @property
    def DocumentInspectors(self):
        return self.com_object.DocumentInspectors

    @property
    def documentinspectors(self):
        """Alias for DocumentInspectors"""
        return self.DocumentInspectors

    @property
    def document_inspectors(self):
        """Alias for DocumentInspectors"""
        return self.DocumentInspectors

    @property
    def DocumentLibraryVersions(self):
        return self.com_object.DocumentLibraryVersions

    @property
    def documentlibraryversions(self):
        """Alias for DocumentLibraryVersions"""
        return self.DocumentLibraryVersions

    @property
    def document_library_versions(self):
        """Alias for DocumentLibraryVersions"""
        return self.DocumentLibraryVersions

    @property
    def DoNotPromptForConvert(self):
        return self.com_object.DoNotPromptForConvert

    @DoNotPromptForConvert.setter
    def DoNotPromptForConvert(self, value):
        self.com_object.DoNotPromptForConvert = value

    @property
    def donotpromptforconvert(self):
        """Alias for DoNotPromptForConvert"""
        return self.DoNotPromptForConvert

    @donotpromptforconvert.setter
    def donotpromptforconvert(self, value):
        """Alias for DoNotPromptForConvert.setter"""
        self.DoNotPromptForConvert = value

    @property
    def do_not_prompt_for_convert(self):
        """Alias for DoNotPromptForConvert"""
        return self.DoNotPromptForConvert

    @do_not_prompt_for_convert.setter
    def do_not_prompt_for_convert(self, value):
        """Alias for DoNotPromptForConvert.setter"""
        self.DoNotPromptForConvert = value

    @property
    def EnableAutoRecover(self):
        return self.com_object.EnableAutoRecover

    @EnableAutoRecover.setter
    def EnableAutoRecover(self, value):
        self.com_object.EnableAutoRecover = value

    @property
    def enableautorecover(self):
        """Alias for EnableAutoRecover"""
        return self.EnableAutoRecover

    @enableautorecover.setter
    def enableautorecover(self, value):
        """Alias for EnableAutoRecover.setter"""
        self.EnableAutoRecover = value

    @property
    def enable_auto_recover(self):
        """Alias for EnableAutoRecover"""
        return self.EnableAutoRecover

    @enable_auto_recover.setter
    def enable_auto_recover(self, value):
        """Alias for EnableAutoRecover.setter"""
        self.EnableAutoRecover = value

    @property
    def EncryptionProvider(self):
        return self.com_object.EncryptionProvider

    @EncryptionProvider.setter
    def EncryptionProvider(self, value):
        self.com_object.EncryptionProvider = value

    @property
    def encryptionprovider(self):
        """Alias for EncryptionProvider"""
        return self.EncryptionProvider

    @encryptionprovider.setter
    def encryptionprovider(self, value):
        """Alias for EncryptionProvider.setter"""
        self.EncryptionProvider = value

    @property
    def encryption_provider(self):
        """Alias for EncryptionProvider"""
        return self.EncryptionProvider

    @encryption_provider.setter
    def encryption_provider(self, value):
        """Alias for EncryptionProvider.setter"""
        self.EncryptionProvider = value

    @property
    def EnvelopeVisible(self):
        return self.com_object.EnvelopeVisible

    @EnvelopeVisible.setter
    def EnvelopeVisible(self, value):
        self.com_object.EnvelopeVisible = value

    @property
    def envelopevisible(self):
        """Alias for EnvelopeVisible"""
        return self.EnvelopeVisible

    @envelopevisible.setter
    def envelopevisible(self, value):
        """Alias for EnvelopeVisible.setter"""
        self.EnvelopeVisible = value

    @property
    def envelope_visible(self):
        """Alias for EnvelopeVisible"""
        return self.EnvelopeVisible

    @envelope_visible.setter
    def envelope_visible(self, value):
        """Alias for EnvelopeVisible.setter"""
        self.EnvelopeVisible = value

    @property
    def Excel4IntlMacroSheets(self):
        return Sheets(self.com_object.Excel4IntlMacroSheets)

    @property
    def excel4intlmacrosheets(self):
        """Alias for Excel4IntlMacroSheets"""
        return self.Excel4IntlMacroSheets

    @property
    def excel4_intl_macro_sheets(self):
        """Alias for Excel4IntlMacroSheets"""
        return self.Excel4IntlMacroSheets

    @property
    def Excel4MacroSheets(self):
        return Sheets(self.com_object.Excel4MacroSheets)

    @property
    def excel4macrosheets(self):
        """Alias for Excel4MacroSheets"""
        return self.Excel4MacroSheets

    @property
    def excel4_macro_sheets(self):
        """Alias for Excel4MacroSheets"""
        return self.Excel4MacroSheets

    @property
    def Excel8CompatibilityMode(self):
        return self.com_object.Excel8CompatibilityMode

    @property
    def excel8compatibilitymode(self):
        """Alias for Excel8CompatibilityMode"""
        return self.Excel8CompatibilityMode

    @property
    def excel8_compatibility_mode(self):
        """Alias for Excel8CompatibilityMode"""
        return self.Excel8CompatibilityMode

    @property
    def FileFormat(self):
        return XlFileFormat(self.com_object.FileFormat)

    @property
    def fileformat(self):
        """Alias for FileFormat"""
        return self.FileFormat

    @property
    def file_format(self):
        """Alias for FileFormat"""
        return self.FileFormat

    @property
    def Final(self):
        return self.com_object.Final

    @Final.setter
    def Final(self, value):
        self.com_object.Final = value

    @property
    def final(self):
        """Alias for Final"""
        return self.Final

    @final.setter
    def final(self, value):
        """Alias for Final.setter"""
        self.Final = value

    @property
    def ForceFullCalculation(self):
        return self.com_object.ForceFullCalculation

    @ForceFullCalculation.setter
    def ForceFullCalculation(self, value):
        self.com_object.ForceFullCalculation = value

    @property
    def forcefullcalculation(self):
        """Alias for ForceFullCalculation"""
        return self.ForceFullCalculation

    @forcefullcalculation.setter
    def forcefullcalculation(self, value):
        """Alias for ForceFullCalculation.setter"""
        self.ForceFullCalculation = value

    @property
    def force_full_calculation(self):
        """Alias for ForceFullCalculation"""
        return self.ForceFullCalculation

    @force_full_calculation.setter
    def force_full_calculation(self, value):
        """Alias for ForceFullCalculation.setter"""
        self.ForceFullCalculation = value

    @property
    def FullName(self):
        return self.com_object.FullName

    @property
    def fullname(self):
        """Alias for FullName"""
        return self.FullName

    @property
    def full_name(self):
        """Alias for FullName"""
        return self.FullName

    @property
    def FullNameURLEncoded(self):
        return self.com_object.FullNameURLEncoded

    @property
    def fullnameurlencoded(self):
        """Alias for FullNameURLEncoded"""
        return self.FullNameURLEncoded

    @property
    def full_name_u_r_l_encoded(self):
        """Alias for FullNameURLEncoded"""
        return self.FullNameURLEncoded

    @property
    def HasPassword(self):
        return self.com_object.HasPassword

    @property
    def haspassword(self):
        """Alias for HasPassword"""
        return self.HasPassword

    @property
    def has_password(self):
        """Alias for HasPassword"""
        return self.HasPassword

    @property
    def HasVBProject(self):
        return self.com_object.HasVBProject

    @property
    def hasvbproject(self):
        """Alias for HasVBProject"""
        return self.HasVBProject

    @property
    def has_v_b_project(self):
        """Alias for HasVBProject"""
        return self.HasVBProject

    @property
    def HighlightChangesOnScreen(self):
        return self.com_object.HighlightChangesOnScreen

    @HighlightChangesOnScreen.setter
    def HighlightChangesOnScreen(self, value):
        self.com_object.HighlightChangesOnScreen = value

    @property
    def highlightchangesonscreen(self):
        """Alias for HighlightChangesOnScreen"""
        return self.HighlightChangesOnScreen

    @highlightchangesonscreen.setter
    def highlightchangesonscreen(self, value):
        """Alias for HighlightChangesOnScreen.setter"""
        self.HighlightChangesOnScreen = value

    @property
    def highlight_changes_on_screen(self):
        """Alias for HighlightChangesOnScreen"""
        return self.HighlightChangesOnScreen

    @highlight_changes_on_screen.setter
    def highlight_changes_on_screen(self, value):
        """Alias for HighlightChangesOnScreen.setter"""
        self.HighlightChangesOnScreen = value

    @property
    def IconSets(self):
        return self.com_object.IconSets

    @property
    def iconsets(self):
        """Alias for IconSets"""
        return self.IconSets

    @property
    def icon_sets(self):
        """Alias for IconSets"""
        return self.IconSets

    @property
    def InactiveListBorderVisible(self):
        return self.com_object.InactiveListBorderVisible

    @InactiveListBorderVisible.setter
    def InactiveListBorderVisible(self, value):
        self.com_object.InactiveListBorderVisible = value

    @property
    def inactivelistbordervisible(self):
        """Alias for InactiveListBorderVisible"""
        return self.InactiveListBorderVisible

    @inactivelistbordervisible.setter
    def inactivelistbordervisible(self, value):
        """Alias for InactiveListBorderVisible.setter"""
        self.InactiveListBorderVisible = value

    @property
    def inactive_list_border_visible(self):
        """Alias for InactiveListBorderVisible"""
        return self.InactiveListBorderVisible

    @inactive_list_border_visible.setter
    def inactive_list_border_visible(self, value):
        """Alias for InactiveListBorderVisible.setter"""
        self.InactiveListBorderVisible = value

    @property
    def IsAddin(self):
        return self.com_object.IsAddin

    @IsAddin.setter
    def IsAddin(self, value):
        self.com_object.IsAddin = value

    @property
    def isaddin(self):
        """Alias for IsAddin"""
        return self.IsAddin

    @isaddin.setter
    def isaddin(self, value):
        """Alias for IsAddin.setter"""
        self.IsAddin = value

    @property
    def is_addin(self):
        """Alias for IsAddin"""
        return self.IsAddin

    @is_addin.setter
    def is_addin(self, value):
        """Alias for IsAddin.setter"""
        self.IsAddin = value

    @property
    def IsInplace(self):
        return self.com_object.IsInplace

    @property
    def isinplace(self):
        """Alias for IsInplace"""
        return self.IsInplace

    @property
    def is_inplace(self):
        """Alias for IsInplace"""
        return self.IsInplace

    @property
    def KeepChangeHistory(self):
        return self.com_object.KeepChangeHistory

    @KeepChangeHistory.setter
    def KeepChangeHistory(self, value):
        self.com_object.KeepChangeHistory = value

    @property
    def keepchangehistory(self):
        """Alias for KeepChangeHistory"""
        return self.KeepChangeHistory

    @keepchangehistory.setter
    def keepchangehistory(self, value):
        """Alias for KeepChangeHistory.setter"""
        self.KeepChangeHistory = value

    @property
    def keep_change_history(self):
        """Alias for KeepChangeHistory"""
        return self.KeepChangeHistory

    @keep_change_history.setter
    def keep_change_history(self, value):
        """Alias for KeepChangeHistory.setter"""
        self.KeepChangeHistory = value

    @property
    def ListChangesOnNewSheet(self):
        return self.com_object.ListChangesOnNewSheet

    @ListChangesOnNewSheet.setter
    def ListChangesOnNewSheet(self, value):
        self.com_object.ListChangesOnNewSheet = value

    @property
    def listchangesonnewsheet(self):
        """Alias for ListChangesOnNewSheet"""
        return self.ListChangesOnNewSheet

    @listchangesonnewsheet.setter
    def listchangesonnewsheet(self, value):
        """Alias for ListChangesOnNewSheet.setter"""
        self.ListChangesOnNewSheet = value

    @property
    def list_changes_on_new_sheet(self):
        """Alias for ListChangesOnNewSheet"""
        return self.ListChangesOnNewSheet

    @list_changes_on_new_sheet.setter
    def list_changes_on_new_sheet(self, value):
        """Alias for ListChangesOnNewSheet.setter"""
        self.ListChangesOnNewSheet = value

    @property
    def Mailer(self):
        return self.com_object.Mailer

    @property
    def mailer(self):
        """Alias for Mailer"""
        return self.Mailer

    @property
    def Model(self):
        return Model(self.com_object.Model)

    @property
    def model(self):
        """Alias for Model"""
        return self.Model

    @property
    def MultiUserEditing(self):
        return self.com_object.MultiUserEditing

    @property
    def multiuserediting(self):
        """Alias for MultiUserEditing"""
        return self.MultiUserEditing

    @property
    def multi_user_editing(self):
        """Alias for MultiUserEditing"""
        return self.MultiUserEditing

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Names(self):
        return Names(self.com_object.Names)

    @property
    def names(self):
        """Alias for Names"""
        return self.Names

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Password(self):
        return self.com_object.Password

    @Password.setter
    def Password(self, value):
        self.com_object.Password = value

    @property
    def password(self):
        """Alias for Password"""
        return self.Password

    @password.setter
    def password(self, value):
        """Alias for Password.setter"""
        self.Password = value

    @property
    def PasswordEncryptionAlgorithm(self):
        return self.com_object.PasswordEncryptionAlgorithm

    @property
    def passwordencryptionalgorithm(self):
        """Alias for PasswordEncryptionAlgorithm"""
        return self.PasswordEncryptionAlgorithm

    @property
    def password_encryption_algorithm(self):
        """Alias for PasswordEncryptionAlgorithm"""
        return self.PasswordEncryptionAlgorithm

    @property
    def PasswordEncryptionFileProperties(self):
        return self.com_object.PasswordEncryptionFileProperties

    @property
    def passwordencryptionfileproperties(self):
        """Alias for PasswordEncryptionFileProperties"""
        return self.PasswordEncryptionFileProperties

    @property
    def password_encryption_file_properties(self):
        """Alias for PasswordEncryptionFileProperties"""
        return self.PasswordEncryptionFileProperties

    @property
    def PasswordEncryptionKeyLength(self):
        return self.com_object.PasswordEncryptionKeyLength

    @property
    def passwordencryptionkeylength(self):
        """Alias for PasswordEncryptionKeyLength"""
        return self.PasswordEncryptionKeyLength

    @property
    def password_encryption_key_length(self):
        """Alias for PasswordEncryptionKeyLength"""
        return self.PasswordEncryptionKeyLength

    @property
    def PasswordEncryptionProvider(self):
        return self.com_object.PasswordEncryptionProvider

    @property
    def passwordencryptionprovider(self):
        """Alias for PasswordEncryptionProvider"""
        return self.PasswordEncryptionProvider

    @property
    def password_encryption_provider(self):
        """Alias for PasswordEncryptionProvider"""
        return self.PasswordEncryptionProvider

    @property
    def Path(self):
        return self.com_object.Path

    @property
    def path(self):
        """Alias for Path"""
        return self.Path

    @property
    def Permission(self):
        return self.com_object.Permission

    @property
    def permission(self):
        """Alias for Permission"""
        return self.Permission

    @property
    def PersonalViewListSettings(self):
        return self.com_object.PersonalViewListSettings

    @PersonalViewListSettings.setter
    def PersonalViewListSettings(self, value):
        self.com_object.PersonalViewListSettings = value

    @property
    def personalviewlistsettings(self):
        """Alias for PersonalViewListSettings"""
        return self.PersonalViewListSettings

    @personalviewlistsettings.setter
    def personalviewlistsettings(self, value):
        """Alias for PersonalViewListSettings.setter"""
        self.PersonalViewListSettings = value

    @property
    def personal_view_list_settings(self):
        """Alias for PersonalViewListSettings"""
        return self.PersonalViewListSettings

    @personal_view_list_settings.setter
    def personal_view_list_settings(self, value):
        """Alias for PersonalViewListSettings.setter"""
        self.PersonalViewListSettings = value

    @property
    def PersonalViewPrintSettings(self):
        return self.com_object.PersonalViewPrintSettings

    @PersonalViewPrintSettings.setter
    def PersonalViewPrintSettings(self, value):
        self.com_object.PersonalViewPrintSettings = value

    @property
    def personalviewprintsettings(self):
        """Alias for PersonalViewPrintSettings"""
        return self.PersonalViewPrintSettings

    @personalviewprintsettings.setter
    def personalviewprintsettings(self, value):
        """Alias for PersonalViewPrintSettings.setter"""
        self.PersonalViewPrintSettings = value

    @property
    def personal_view_print_settings(self):
        """Alias for PersonalViewPrintSettings"""
        return self.PersonalViewPrintSettings

    @personal_view_print_settings.setter
    def personal_view_print_settings(self, value):
        """Alias for PersonalViewPrintSettings.setter"""
        self.PersonalViewPrintSettings = value

    @property
    def PivotTables(self):
        return self.com_object.PivotTables

    @property
    def pivottables(self):
        """Alias for PivotTables"""
        return self.PivotTables

    @property
    def pivot_tables(self):
        """Alias for PivotTables"""
        return self.PivotTables

    @property
    def PrecisionAsDisplayed(self):
        return self.com_object.PrecisionAsDisplayed

    @PrecisionAsDisplayed.setter
    def PrecisionAsDisplayed(self, value):
        self.com_object.PrecisionAsDisplayed = value

    @property
    def precisionasdisplayed(self):
        """Alias for PrecisionAsDisplayed"""
        return self.PrecisionAsDisplayed

    @precisionasdisplayed.setter
    def precisionasdisplayed(self, value):
        """Alias for PrecisionAsDisplayed.setter"""
        self.PrecisionAsDisplayed = value

    @property
    def precision_as_displayed(self):
        """Alias for PrecisionAsDisplayed"""
        return self.PrecisionAsDisplayed

    @precision_as_displayed.setter
    def precision_as_displayed(self, value):
        """Alias for PrecisionAsDisplayed.setter"""
        self.PrecisionAsDisplayed = value

    @property
    def ProtectStructure(self):
        return self.com_object.ProtectStructure

    @property
    def protectstructure(self):
        """Alias for ProtectStructure"""
        return self.ProtectStructure

    @property
    def protect_structure(self):
        """Alias for ProtectStructure"""
        return self.ProtectStructure

    @property
    def ProtectWindows(self):
        return self.com_object.ProtectWindows

    @property
    def protectwindows(self):
        """Alias for ProtectWindows"""
        return self.ProtectWindows

    @property
    def protect_windows(self):
        """Alias for ProtectWindows"""
        return self.ProtectWindows

    @property
    def PublishObjects(self):
        return PublishObjects(self.com_object.PublishObjects)

    @property
    def publishobjects(self):
        """Alias for PublishObjects"""
        return self.PublishObjects

    @property
    def publish_objects(self):
        """Alias for PublishObjects"""
        return self.PublishObjects

    @property
    def Queries(self):
        return Queries(self.com_object.Queries)

    @property
    def queries(self):
        """Alias for Queries"""
        return self.Queries

    @property
    def ReadOnly(self):
        return self.com_object.ReadOnly

    @property
    def readonly(self):
        """Alias for ReadOnly"""
        return self.ReadOnly

    @property
    def read_only(self):
        """Alias for ReadOnly"""
        return self.ReadOnly

    @property
    def ReadOnlyRecommended(self):
        return self.com_object.ReadOnlyRecommended

    @property
    def readonlyrecommended(self):
        """Alias for ReadOnlyRecommended"""
        return self.ReadOnlyRecommended

    @property
    def read_only_recommended(self):
        """Alias for ReadOnlyRecommended"""
        return self.ReadOnlyRecommended

    @property
    def RemovePersonalInformation(self):
        return self.com_object.RemovePersonalInformation

    @RemovePersonalInformation.setter
    def RemovePersonalInformation(self, value):
        self.com_object.RemovePersonalInformation = value

    @property
    def removepersonalinformation(self):
        """Alias for RemovePersonalInformation"""
        return self.RemovePersonalInformation

    @removepersonalinformation.setter
    def removepersonalinformation(self, value):
        """Alias for RemovePersonalInformation.setter"""
        self.RemovePersonalInformation = value

    @property
    def remove_personal_information(self):
        """Alias for RemovePersonalInformation"""
        return self.RemovePersonalInformation

    @remove_personal_information.setter
    def remove_personal_information(self, value):
        """Alias for RemovePersonalInformation.setter"""
        self.RemovePersonalInformation = value

    @property
    def Research(self):
        return Research(self.com_object.Research)

    @property
    def research(self):
        """Alias for Research"""
        return self.Research

    @property
    def RevisionNumber(self):
        return self.com_object.RevisionNumber

    @property
    def revisionnumber(self):
        """Alias for RevisionNumber"""
        return self.RevisionNumber

    @property
    def revision_number(self):
        """Alias for RevisionNumber"""
        return self.RevisionNumber

    @property
    def Saved(self):
        return self.com_object.Saved

    @Saved.setter
    def Saved(self, value):
        self.com_object.Saved = value

    @property
    def saved(self):
        """Alias for Saved"""
        return self.Saved

    @saved.setter
    def saved(self, value):
        """Alias for Saved.setter"""
        self.Saved = value

    @property
    def SaveLinkValues(self):
        return self.com_object.SaveLinkValues

    @SaveLinkValues.setter
    def SaveLinkValues(self, value):
        self.com_object.SaveLinkValues = value

    @property
    def savelinkvalues(self):
        """Alias for SaveLinkValues"""
        return self.SaveLinkValues

    @savelinkvalues.setter
    def savelinkvalues(self, value):
        """Alias for SaveLinkValues.setter"""
        self.SaveLinkValues = value

    @property
    def save_link_values(self):
        """Alias for SaveLinkValues"""
        return self.SaveLinkValues

    @save_link_values.setter
    def save_link_values(self, value):
        """Alias for SaveLinkValues.setter"""
        self.SaveLinkValues = value

    @property
    def SensitivityLabel(self):
        return self.com_object.SensitivityLabel

    @property
    def sensitivitylabel(self):
        """Alias for SensitivityLabel"""
        return self.SensitivityLabel

    @property
    def sensitivity_label(self):
        """Alias for SensitivityLabel"""
        return self.SensitivityLabel

    @property
    def ServerPolicy(self):
        return self.com_object.ServerPolicy

    @property
    def serverpolicy(self):
        """Alias for ServerPolicy"""
        return self.ServerPolicy

    @property
    def server_policy(self):
        """Alias for ServerPolicy"""
        return self.ServerPolicy

    @property
    def ServerViewableItems(self):
        return self.com_object.ServerViewableItems

    @property
    def serverviewableitems(self):
        """Alias for ServerViewableItems"""
        return self.ServerViewableItems

    @property
    def server_viewable_items(self):
        """Alias for ServerViewableItems"""
        return self.ServerViewableItems

    @property
    def SharedWorkspace(self):
        return self.com_object.SharedWorkspace

    @property
    def sharedworkspace(self):
        """Alias for SharedWorkspace"""
        return self.SharedWorkspace

    @property
    def shared_workspace(self):
        """Alias for SharedWorkspace"""
        return self.SharedWorkspace

    @property
    def Sheets(self):
        return Sheets(self.com_object.Sheets)

    @property
    def sheets(self):
        """Alias for Sheets"""
        return self.Sheets

    @property
    def ShowConflictHistory(self):
        return self.com_object.ShowConflictHistory

    @ShowConflictHistory.setter
    def ShowConflictHistory(self, value):
        self.com_object.ShowConflictHistory = value

    @property
    def showconflicthistory(self):
        """Alias for ShowConflictHistory"""
        return self.ShowConflictHistory

    @showconflicthistory.setter
    def showconflicthistory(self, value):
        """Alias for ShowConflictHistory.setter"""
        self.ShowConflictHistory = value

    @property
    def show_conflict_history(self):
        """Alias for ShowConflictHistory"""
        return self.ShowConflictHistory

    @show_conflict_history.setter
    def show_conflict_history(self, value):
        """Alias for ShowConflictHistory.setter"""
        self.ShowConflictHistory = value

    @property
    def ShowPivotChartActiveFields(self):
        return self.com_object.ShowPivotChartActiveFields

    @ShowPivotChartActiveFields.setter
    def ShowPivotChartActiveFields(self, value):
        self.com_object.ShowPivotChartActiveFields = value

    @property
    def showpivotchartactivefields(self):
        """Alias for ShowPivotChartActiveFields"""
        return self.ShowPivotChartActiveFields

    @showpivotchartactivefields.setter
    def showpivotchartactivefields(self, value):
        """Alias for ShowPivotChartActiveFields.setter"""
        self.ShowPivotChartActiveFields = value

    @property
    def show_pivot_chart_active_fields(self):
        """Alias for ShowPivotChartActiveFields"""
        return self.ShowPivotChartActiveFields

    @show_pivot_chart_active_fields.setter
    def show_pivot_chart_active_fields(self, value):
        """Alias for ShowPivotChartActiveFields.setter"""
        self.ShowPivotChartActiveFields = value

    @property
    def ShowPivotTableFieldList(self):
        return self.com_object.ShowPivotTableFieldList

    @ShowPivotTableFieldList.setter
    def ShowPivotTableFieldList(self, value):
        self.com_object.ShowPivotTableFieldList = value

    @property
    def showpivottablefieldlist(self):
        """Alias for ShowPivotTableFieldList"""
        return self.ShowPivotTableFieldList

    @showpivottablefieldlist.setter
    def showpivottablefieldlist(self, value):
        """Alias for ShowPivotTableFieldList.setter"""
        self.ShowPivotTableFieldList = value

    @property
    def show_pivot_table_field_list(self):
        """Alias for ShowPivotTableFieldList"""
        return self.ShowPivotTableFieldList

    @show_pivot_table_field_list.setter
    def show_pivot_table_field_list(self, value):
        """Alias for ShowPivotTableFieldList.setter"""
        self.ShowPivotTableFieldList = value

    @property
    def Signatures(self):
        return self.com_object.Signatures

    @property
    def signatures(self):
        """Alias for Signatures"""
        return self.Signatures

    @property
    def SlicerCaches(self):
        return SlicerCaches(self.com_object.SlicerCaches)

    @property
    def slicercaches(self):
        """Alias for SlicerCaches"""
        return self.SlicerCaches

    @property
    def slicer_caches(self):
        """Alias for SlicerCaches"""
        return self.SlicerCaches

    @property
    def SmartDocument(self):
        return self.com_object.SmartDocument

    @property
    def smartdocument(self):
        """Alias for SmartDocument"""
        return self.SmartDocument

    @property
    def smart_document(self):
        """Alias for SmartDocument"""
        return self.SmartDocument

    @property
    def Styles(self):
        return Styles(self.com_object.Styles)

    @property
    def styles(self):
        """Alias for Styles"""
        return self.Styles

    @property
    def Sync(self):
        return self.com_object.Sync

    @property
    def sync(self):
        """Alias for Sync"""
        return self.Sync

    @property
    def TableStyles(self):
        return TableStyles(self.com_object.TableStyles)

    @property
    def tablestyles(self):
        """Alias for TableStyles"""
        return self.TableStyles

    @property
    def table_styles(self):
        """Alias for TableStyles"""
        return self.TableStyles

    @property
    def TemplateRemoveExtData(self):
        return self.com_object.TemplateRemoveExtData

    @TemplateRemoveExtData.setter
    def TemplateRemoveExtData(self, value):
        self.com_object.TemplateRemoveExtData = value

    @property
    def templateremoveextdata(self):
        """Alias for TemplateRemoveExtData"""
        return self.TemplateRemoveExtData

    @templateremoveextdata.setter
    def templateremoveextdata(self, value):
        """Alias for TemplateRemoveExtData.setter"""
        self.TemplateRemoveExtData = value

    @property
    def template_remove_ext_data(self):
        """Alias for TemplateRemoveExtData"""
        return self.TemplateRemoveExtData

    @template_remove_ext_data.setter
    def template_remove_ext_data(self, value):
        """Alias for TemplateRemoveExtData.setter"""
        self.TemplateRemoveExtData = value

    @property
    def Theme(self):
        return self.com_object.Theme

    @property
    def theme(self):
        """Alias for Theme"""
        return self.Theme

    @property
    def UpdateLinks(self):
        return self.com_object.UpdateLinks

    @UpdateLinks.setter
    def UpdateLinks(self, value):
        self.com_object.UpdateLinks = value

    @property
    def updatelinks(self):
        """Alias for UpdateLinks"""
        return self.UpdateLinks

    @updatelinks.setter
    def updatelinks(self, value):
        """Alias for UpdateLinks.setter"""
        self.UpdateLinks = value

    @property
    def update_links(self):
        """Alias for UpdateLinks"""
        return self.UpdateLinks

    @update_links.setter
    def update_links(self, value):
        """Alias for UpdateLinks.setter"""
        self.UpdateLinks = value

    @property
    def UpdateRemoteReferences(self):
        return self.com_object.UpdateRemoteReferences

    @UpdateRemoteReferences.setter
    def UpdateRemoteReferences(self, value):
        self.com_object.UpdateRemoteReferences = value

    @property
    def updateremotereferences(self):
        """Alias for UpdateRemoteReferences"""
        return self.UpdateRemoteReferences

    @updateremotereferences.setter
    def updateremotereferences(self, value):
        """Alias for UpdateRemoteReferences.setter"""
        self.UpdateRemoteReferences = value

    @property
    def update_remote_references(self):
        """Alias for UpdateRemoteReferences"""
        return self.UpdateRemoteReferences

    @update_remote_references.setter
    def update_remote_references(self, value):
        """Alias for UpdateRemoteReferences.setter"""
        self.UpdateRemoteReferences = value

    @property
    def UserStatus(self):
        return self.com_object.UserStatus

    @property
    def userstatus(self):
        """Alias for UserStatus"""
        return self.UserStatus

    @property
    def user_status(self):
        """Alias for UserStatus"""
        return self.UserStatus

    @property
    def UseWholeCellCriteria(self):
        return self.com_object.UseWholeCellCriteria

    @property
    def usewholecellcriteria(self):
        """Alias for UseWholeCellCriteria"""
        return self.UseWholeCellCriteria

    @property
    def use_whole_cell_criteria(self):
        """Alias for UseWholeCellCriteria"""
        return self.UseWholeCellCriteria

    @property
    def UseWildcards(self):
        return self.com_object.UseWildcards

    @property
    def usewildcards(self):
        """Alias for UseWildcards"""
        return self.UseWildcards

    @property
    def use_wildcards(self):
        """Alias for UseWildcards"""
        return self.UseWildcards

    @property
    def VBASigned(self):
        return self.com_object.VBASigned

    @property
    def vbasigned(self):
        """Alias for VBASigned"""
        return self.VBASigned

    @property
    def v_b_a_signed(self):
        """Alias for VBASigned"""
        return self.VBASigned

    @property
    def VBProject(self):
        return self.com_object.VBProject

    @property
    def vbproject(self):
        """Alias for VBProject"""
        return self.VBProject

    @property
    def v_b_project(self):
        """Alias for VBProject"""
        return self.VBProject

    @property
    def WebOptions(self):
        return WebOptions(self.com_object.WebOptions)

    @property
    def weboptions(self):
        """Alias for WebOptions"""
        return self.WebOptions

    @property
    def web_options(self):
        """Alias for WebOptions"""
        return self.WebOptions

    @property
    def Windows(self):
        return Windows(self.com_object.Windows)

    @property
    def windows(self):
        """Alias for Windows"""
        return self.Windows

    @property
    def Worksheets(self):
        return Worksheets(self.com_object.Worksheets)

    @property
    def worksheets(self):
        """Alias for Worksheets"""
        return self.Worksheets

    @property
    def WritePassword(self):
        return self.com_object.WritePassword

    @WritePassword.setter
    def WritePassword(self, value):
        self.com_object.WritePassword = value

    @property
    def writepassword(self):
        """Alias for WritePassword"""
        return self.WritePassword

    @writepassword.setter
    def writepassword(self, value):
        """Alias for WritePassword.setter"""
        self.WritePassword = value

    @property
    def write_password(self):
        """Alias for WritePassword"""
        return self.WritePassword

    @write_password.setter
    def write_password(self, value):
        """Alias for WritePassword.setter"""
        self.WritePassword = value

    @property
    def WriteReserved(self):
        return self.com_object.WriteReserved

    @property
    def writereserved(self):
        """Alias for WriteReserved"""
        return self.WriteReserved

    @property
    def write_reserved(self):
        """Alias for WriteReserved"""
        return self.WriteReserved

    @property
    def WriteReservedBy(self):
        return self.com_object.WriteReservedBy

    @property
    def writereservedby(self):
        """Alias for WriteReservedBy"""
        return self.WriteReservedBy

    @property
    def write_reserved_by(self):
        """Alias for WriteReservedBy"""
        return self.WriteReservedBy

    @property
    def XmlMaps(self):
        return XmlMaps(self.com_object.XmlMaps)

    @property
    def xmlmaps(self):
        """Alias for XmlMaps"""
        return self.XmlMaps

    @property
    def xml_maps(self):
        """Alias for XmlMaps"""
        return self.XmlMaps

    @property
    def XmlNamespaces(self):
        return XmlNamespaces(self.com_object.XmlNamespaces)

    @property
    def xmlnamespaces(self):
        """Alias for XmlNamespaces"""
        return self.XmlNamespaces

    @property
    def xml_namespaces(self):
        """Alias for XmlNamespaces"""
        return self.XmlNamespaces

    def AcceptAllChanges(self, When=None, Who=None, Where=None):
        arguments = com_arguments([unwrap(a) for a in [When, Who, Where]])
        self.com_object.AcceptAllChanges(*arguments)

    def acceptallchanges(self, When=None, Who=None, Where=None):
        """Alias for AcceptAllChanges"""
        arguments = [When, Who, Where]
        return self.AcceptAllChanges(*arguments)

    def accept_all_changes(self, When=None, Who=None, Where=None):
        """Alias for AcceptAllChanges"""
        arguments = [When, Who, Where]
        return self.AcceptAllChanges(*arguments)

    def Activate(self):
        self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()

    def AddToFavorites(self):
        self.com_object.AddToFavorites()

    def addtofavorites(self):
        """Alias for AddToFavorites"""
        return self.AddToFavorites()

    def add_to_favorites(self):
        """Alias for AddToFavorites"""
        return self.AddToFavorites()

    def ApplyTheme(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        self.com_object.ApplyTheme(*arguments)

    def applytheme(self, FileName=None):
        """Alias for ApplyTheme"""
        arguments = [FileName]
        return self.ApplyTheme(*arguments)

    def apply_theme(self, FileName=None):
        """Alias for ApplyTheme"""
        arguments = [FileName]
        return self.ApplyTheme(*arguments)

    def BreakLink(self, Name=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Type]])
        self.com_object.BreakLink(*arguments)

    def breaklink(self, Name=None, Type=None):
        """Alias for BreakLink"""
        arguments = [Name, Type]
        return self.BreakLink(*arguments)

    def break_link(self, Name=None, Type=None):
        """Alias for BreakLink"""
        arguments = [Name, Type]
        return self.BreakLink(*arguments)

    def CanCheckIn(self):
        return self.com_object.CanCheckIn()

    def cancheckin(self):
        """Alias for CanCheckIn"""
        return self.CanCheckIn()

    def can_check_in(self):
        """Alias for CanCheckIn"""
        return self.CanCheckIn()

    def ChangeFileAccess(self, Mode=None, WritePassword=None, Notify=None):
        arguments = com_arguments([unwrap(a) for a in [Mode, WritePassword, Notify]])
        self.com_object.ChangeFileAccess(*arguments)

    def changefileaccess(self, Mode=None, WritePassword=None, Notify=None):
        """Alias for ChangeFileAccess"""
        arguments = [Mode, WritePassword, Notify]
        return self.ChangeFileAccess(*arguments)

    def change_file_access(self, Mode=None, WritePassword=None, Notify=None):
        """Alias for ChangeFileAccess"""
        arguments = [Mode, WritePassword, Notify]
        return self.ChangeFileAccess(*arguments)

    def ChangeLink(self, Name=None, NewName=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Name, NewName, Type]])
        self.com_object.ChangeLink(*arguments)

    def changelink(self, Name=None, NewName=None, Type=None):
        """Alias for ChangeLink"""
        arguments = [Name, NewName, Type]
        return self.ChangeLink(*arguments)

    def change_link(self, Name=None, NewName=None, Type=None):
        """Alias for ChangeLink"""
        arguments = [Name, NewName, Type]
        return self.ChangeLink(*arguments)

    def CheckIn(self, SaveChanges=None, Comments=None, MakePublic=None):
        arguments = com_arguments([unwrap(a) for a in [SaveChanges, Comments, MakePublic]])
        self.com_object.CheckIn(*arguments)

    def checkin(self, SaveChanges=None, Comments=None, MakePublic=None):
        """Alias for CheckIn"""
        arguments = [SaveChanges, Comments, MakePublic]
        return self.CheckIn(*arguments)

    def check_in(self, SaveChanges=None, Comments=None, MakePublic=None):
        """Alias for CheckIn"""
        arguments = [SaveChanges, Comments, MakePublic]
        return self.CheckIn(*arguments)

    def CheckInWithVersion(self, SaveChanges=None, Comments=None, MakePublic=None, VersionType=None):
        arguments = com_arguments([unwrap(a) for a in [SaveChanges, Comments, MakePublic, VersionType]])
        return self.com_object.CheckInWithVersion(*arguments)

    def checkinwithversion(self, SaveChanges=None, Comments=None, MakePublic=None, VersionType=None):
        """Alias for CheckInWithVersion"""
        arguments = [SaveChanges, Comments, MakePublic, VersionType]
        return self.CheckInWithVersion(*arguments)

    def check_in_with_version(self, SaveChanges=None, Comments=None, MakePublic=None, VersionType=None):
        """Alias for CheckInWithVersion"""
        arguments = [SaveChanges, Comments, MakePublic, VersionType]
        return self.CheckInWithVersion(*arguments)

    def Close(self, SaveChanges=None, FileName=None, RouteWorkbook=None):
        arguments = com_arguments([unwrap(a) for a in [SaveChanges, FileName, RouteWorkbook]])
        self.com_object.Close(*arguments)

    def close(self, SaveChanges=None, FileName=None, RouteWorkbook=None):
        """Alias for Close"""
        arguments = [SaveChanges, FileName, RouteWorkbook]
        return self.Close(*arguments)

    def ConvertComments(self):
        self.com_object.ConvertComments()

    def convertcomments(self):
        """Alias for ConvertComments"""
        return self.ConvertComments()

    def convert_comments(self):
        """Alias for ConvertComments"""
        return self.ConvertComments()

    def CreateForecastSheet(self, Timeline=None, Values=None, ForecastStart=None, ForecastEnd=None, ConfInt=None, Seasonality=None, DataCompletion=None, Aggregation=None, ChartType=None, ShowStatsTable=None):
        arguments = com_arguments([unwrap(a) for a in [Timeline, Values, ForecastStart, ForecastEnd, ConfInt, Seasonality, DataCompletion, Aggregation, ChartType, ShowStatsTable]])
        return self.com_object.CreateForecastSheet(*arguments)

    def createforecastsheet(self, Timeline=None, Values=None, ForecastStart=None, ForecastEnd=None, ConfInt=None, Seasonality=None, DataCompletion=None, Aggregation=None, ChartType=None, ShowStatsTable=None):
        """Alias for CreateForecastSheet"""
        arguments = [Timeline, Values, ForecastStart, ForecastEnd, ConfInt, Seasonality, DataCompletion, Aggregation, ChartType, ShowStatsTable]
        return self.CreateForecastSheet(*arguments)

    def create_forecast_sheet(self, Timeline=None, Values=None, ForecastStart=None, ForecastEnd=None, ConfInt=None, Seasonality=None, DataCompletion=None, Aggregation=None, ChartType=None, ShowStatsTable=None):
        """Alias for CreateForecastSheet"""
        arguments = [Timeline, Values, ForecastStart, ForecastEnd, ConfInt, Seasonality, DataCompletion, Aggregation, ChartType, ShowStatsTable]
        return self.CreateForecastSheet(*arguments)

    def DeleteNumberFormat(self, NumberFormat=None):
        arguments = com_arguments([unwrap(a) for a in [NumberFormat]])
        self.com_object.DeleteNumberFormat(*arguments)

    def deletenumberformat(self, NumberFormat=None):
        """Alias for DeleteNumberFormat"""
        arguments = [NumberFormat]
        return self.DeleteNumberFormat(*arguments)

    def delete_number_format(self, NumberFormat=None):
        """Alias for DeleteNumberFormat"""
        arguments = [NumberFormat]
        return self.DeleteNumberFormat(*arguments)

    def EnableConnections(self):
        self.com_object.EnableConnections()

    def enableconnections(self):
        """Alias for EnableConnections"""
        return self.EnableConnections()

    def enable_connections(self):
        """Alias for EnableConnections"""
        return self.EnableConnections()

    def EndReview(self):
        self.com_object.EndReview()

    def endreview(self):
        """Alias for EndReview"""
        return self.EndReview()

    def end_review(self):
        """Alias for EndReview"""
        return self.EndReview()

    def ExclusiveAccess(self):
        return self.com_object.ExclusiveAccess()

    def exclusiveaccess(self):
        """Alias for ExclusiveAccess"""
        return self.ExclusiveAccess()

    def exclusive_access(self):
        """Alias for ExclusiveAccess"""
        return self.ExclusiveAccess()

    def ExportAsFixedFormat(self, Type=None, FileName=None, Quality=None, IncludeDocProperties=None, IgnorePrintAreas=None, From=None, To=None, OpenAfterPublish=None, FixedFormatExtClassPtr=None):
        arguments = com_arguments([unwrap(a) for a in [Type, FileName, Quality, IncludeDocProperties, IgnorePrintAreas, From, To, OpenAfterPublish, FixedFormatExtClassPtr]])
        self.com_object.ExportAsFixedFormat(*arguments)

    def exportasfixedformat(self, Type=None, FileName=None, Quality=None, IncludeDocProperties=None, IgnorePrintAreas=None, From=None, To=None, OpenAfterPublish=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat"""
        arguments = [Type, FileName, Quality, IncludeDocProperties, IgnorePrintAreas, From, To, OpenAfterPublish, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat(*arguments)

    def export_as_fixed_format(self, Type=None, FileName=None, Quality=None, IncludeDocProperties=None, IgnorePrintAreas=None, From=None, To=None, OpenAfterPublish=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat"""
        arguments = [Type, FileName, Quality, IncludeDocProperties, IgnorePrintAreas, From, To, OpenAfterPublish, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat(*arguments)

    def FollowHyperlink(self, Address=None, SubAddress=None, NewWindow=None, AddHistory=None, ExtraInfo=None, Method=None, HeaderInfo=None):
        arguments = com_arguments([unwrap(a) for a in [Address, SubAddress, NewWindow, AddHistory, ExtraInfo, Method, HeaderInfo]])
        self.com_object.FollowHyperlink(*arguments)

    def followhyperlink(self, Address=None, SubAddress=None, NewWindow=None, AddHistory=None, ExtraInfo=None, Method=None, HeaderInfo=None):
        """Alias for FollowHyperlink"""
        arguments = [Address, SubAddress, NewWindow, AddHistory, ExtraInfo, Method, HeaderInfo]
        return self.FollowHyperlink(*arguments)

    def follow_hyperlink(self, Address=None, SubAddress=None, NewWindow=None, AddHistory=None, ExtraInfo=None, Method=None, HeaderInfo=None):
        """Alias for FollowHyperlink"""
        arguments = [Address, SubAddress, NewWindow, AddHistory, ExtraInfo, Method, HeaderInfo]
        return self.FollowHyperlink(*arguments)

    def ForwardMailer(self):
        self.com_object.ForwardMailer()

    def forwardmailer(self):
        """Alias for ForwardMailer"""
        return self.ForwardMailer()

    def forward_mailer(self):
        """Alias for ForwardMailer"""
        return self.ForwardMailer()

    def GetWorkflowTasks(self):
        return self.com_object.GetWorkflowTasks()

    def getworkflowtasks(self):
        """Alias for GetWorkflowTasks"""
        return self.GetWorkflowTasks()

    def get_workflow_tasks(self):
        """Alias for GetWorkflowTasks"""
        return self.GetWorkflowTasks()

    def GetWorkflowTemplates(self):
        return self.com_object.GetWorkflowTemplates()

    def getworkflowtemplates(self):
        """Alias for GetWorkflowTemplates"""
        return self.GetWorkflowTemplates()

    def get_workflow_templates(self):
        """Alias for GetWorkflowTemplates"""
        return self.GetWorkflowTemplates()

    def HighlightChangesOptions(self, When=None, Who=None, Where=None):
        arguments = com_arguments([unwrap(a) for a in [When, Who, Where]])
        self.com_object.HighlightChangesOptions(*arguments)

    def highlightchangesoptions(self, When=None, Who=None, Where=None):
        """Alias for HighlightChangesOptions"""
        arguments = [When, Who, Where]
        return self.HighlightChangesOptions(*arguments)

    def highlight_changes_options(self, When=None, Who=None, Where=None):
        """Alias for HighlightChangesOptions"""
        arguments = [When, Who, Where]
        return self.HighlightChangesOptions(*arguments)

    def LinkInfo(self, Name=None, LinkInfo=None, Type=None, EditionRef=None):
        arguments = com_arguments([unwrap(a) for a in [Name, LinkInfo, Type, EditionRef]])
        return self.com_object.LinkInfo(*arguments)

    def linkinfo(self, Name=None, LinkInfo=None, Type=None, EditionRef=None):
        """Alias for LinkInfo"""
        arguments = [Name, LinkInfo, Type, EditionRef]
        return self.LinkInfo(*arguments)

    def link_info(self, Name=None, LinkInfo=None, Type=None, EditionRef=None):
        """Alias for LinkInfo"""
        arguments = [Name, LinkInfo, Type, EditionRef]
        return self.LinkInfo(*arguments)

    def LinkSources(self, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Type]])
        return self.com_object.LinkSources(*arguments)

    def linksources(self, Type=None):
        """Alias for LinkSources"""
        arguments = [Type]
        return self.LinkSources(*arguments)

    def link_sources(self, Type=None):
        """Alias for LinkSources"""
        arguments = [Type]
        return self.LinkSources(*arguments)

    def LockServerFile(self):
        self.com_object.LockServerFile()

    def lockserverfile(self):
        """Alias for LockServerFile"""
        return self.LockServerFile()

    def lock_server_file(self):
        """Alias for LockServerFile"""
        return self.LockServerFile()

    def MergeWorkbook(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        self.com_object.MergeWorkbook(*arguments)

    def mergeworkbook(self, FileName=None):
        """Alias for MergeWorkbook"""
        arguments = [FileName]
        return self.MergeWorkbook(*arguments)

    def merge_workbook(self, FileName=None):
        """Alias for MergeWorkbook"""
        arguments = [FileName]
        return self.MergeWorkbook(*arguments)

    def NewWindow(self):
        return Window(self.com_object.NewWindow())

    def newwindow(self):
        """Alias for NewWindow"""
        return self.NewWindow()

    def new_window(self):
        """Alias for NewWindow"""
        return self.NewWindow()

    def OpenLinks(self, Name=None, ReadOnly=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Name, ReadOnly, Type]])
        self.com_object.OpenLinks(*arguments)

    def openlinks(self, Name=None, ReadOnly=None, Type=None):
        """Alias for OpenLinks"""
        arguments = [Name, ReadOnly, Type]
        return self.OpenLinks(*arguments)

    def open_links(self, Name=None, ReadOnly=None, Type=None):
        """Alias for OpenLinks"""
        arguments = [Name, ReadOnly, Type]
        return self.OpenLinks(*arguments)

    def PivotCaches(self):
        return PivotCaches(self.com_object.PivotCaches())

    def pivotcaches(self):
        """Alias for PivotCaches"""
        return self.PivotCaches()

    def pivot_caches(self):
        """Alias for PivotCaches"""
        return self.PivotCaches()

    def Post(self, DestName=None):
        arguments = com_arguments([unwrap(a) for a in [DestName]])
        self.com_object.Post(*arguments)

    def post(self, DestName=None):
        """Alias for Post"""
        arguments = [DestName]
        return self.Post(*arguments)

    def PrintOut(self, From=None, To=None, Copies=None, Preview=None, ActivePrinter=None, PrintToFile=None, Collate=None, PrToFileName=None, IgnorePrintAreas=None):
        arguments = com_arguments([unwrap(a) for a in [From, To, Copies, Preview, ActivePrinter, PrintToFile, Collate, PrToFileName, IgnorePrintAreas]])
        return self.com_object.PrintOut(*arguments)

    def printout(self, From=None, To=None, Copies=None, Preview=None, ActivePrinter=None, PrintToFile=None, Collate=None, PrToFileName=None, IgnorePrintAreas=None):
        """Alias for PrintOut"""
        arguments = [From, To, Copies, Preview, ActivePrinter, PrintToFile, Collate, PrToFileName, IgnorePrintAreas]
        return self.PrintOut(*arguments)

    def print_out(self, From=None, To=None, Copies=None, Preview=None, ActivePrinter=None, PrintToFile=None, Collate=None, PrToFileName=None, IgnorePrintAreas=None):
        """Alias for PrintOut"""
        arguments = [From, To, Copies, Preview, ActivePrinter, PrintToFile, Collate, PrToFileName, IgnorePrintAreas]
        return self.PrintOut(*arguments)

    def PrintPreview(self, EnableChanges=None):
        arguments = com_arguments([unwrap(a) for a in [EnableChanges]])
        self.com_object.PrintPreview(*arguments)

    def printpreview(self, EnableChanges=None):
        """Alias for PrintPreview"""
        arguments = [EnableChanges]
        return self.PrintPreview(*arguments)

    def print_preview(self, EnableChanges=None):
        """Alias for PrintPreview"""
        arguments = [EnableChanges]
        return self.PrintPreview(*arguments)

    def Protect(self, Password=None, Structure=None, Windows=None):
        arguments = com_arguments([unwrap(a) for a in [Password, Structure, Windows]])
        self.com_object.Protect(*arguments)

    def protect(self, Password=None, Structure=None, Windows=None):
        """Alias for Protect"""
        arguments = [Password, Structure, Windows]
        return self.Protect(*arguments)

    def ProtectSharing(self, FileName=None, Password=None, WriteResPassword=None, ReadOnlyRecommended=None, CreateBackup=None, SharingPassword=None, FileFormat=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, Password, WriteResPassword, ReadOnlyRecommended, CreateBackup, SharingPassword, FileFormat]])
        self.com_object.ProtectSharing(*arguments)

    def protectsharing(self, FileName=None, Password=None, WriteResPassword=None, ReadOnlyRecommended=None, CreateBackup=None, SharingPassword=None, FileFormat=None):
        """Alias for ProtectSharing"""
        arguments = [FileName, Password, WriteResPassword, ReadOnlyRecommended, CreateBackup, SharingPassword, FileFormat]
        return self.ProtectSharing(*arguments)

    def protect_sharing(self, FileName=None, Password=None, WriteResPassword=None, ReadOnlyRecommended=None, CreateBackup=None, SharingPassword=None, FileFormat=None):
        """Alias for ProtectSharing"""
        arguments = [FileName, Password, WriteResPassword, ReadOnlyRecommended, CreateBackup, SharingPassword, FileFormat]
        return self.ProtectSharing(*arguments)

    def PublishToDocs(self):
        self.com_object.PublishToDocs()

    def publishtodocs(self):
        """Alias for PublishToDocs"""
        return self.PublishToDocs()

    def publish_to_docs(self):
        """Alias for PublishToDocs"""
        return self.PublishToDocs()

    def PurgeChangeHistoryNow(self, Days=None, SharingPassword=None):
        arguments = com_arguments([unwrap(a) for a in [Days, SharingPassword]])
        self.com_object.PurgeChangeHistoryNow(*arguments)

    def purgechangehistorynow(self, Days=None, SharingPassword=None):
        """Alias for PurgeChangeHistoryNow"""
        arguments = [Days, SharingPassword]
        return self.PurgeChangeHistoryNow(*arguments)

    def purge_change_history_now(self, Days=None, SharingPassword=None):
        """Alias for PurgeChangeHistoryNow"""
        arguments = [Days, SharingPassword]
        return self.PurgeChangeHistoryNow(*arguments)

    def RefreshAll(self):
        self.com_object.RefreshAll()

    def refreshall(self):
        """Alias for RefreshAll"""
        return self.RefreshAll()

    def refresh_all(self):
        """Alias for RefreshAll"""
        return self.RefreshAll()

    def RejectAllChanges(self, When=None, Who=None, Where=None):
        arguments = com_arguments([unwrap(a) for a in [When, Who, Where]])
        self.com_object.RejectAllChanges(*arguments)

    def rejectallchanges(self, When=None, Who=None, Where=None):
        """Alias for RejectAllChanges"""
        arguments = [When, Who, Where]
        return self.RejectAllChanges(*arguments)

    def reject_all_changes(self, When=None, Who=None, Where=None):
        """Alias for RejectAllChanges"""
        arguments = [When, Who, Where]
        return self.RejectAllChanges(*arguments)

    def ReloadAs(self, Encoding=None):
        arguments = com_arguments([unwrap(a) for a in [Encoding]])
        self.com_object.ReloadAs(*arguments)

    def reloadas(self, Encoding=None):
        """Alias for ReloadAs"""
        arguments = [Encoding]
        return self.ReloadAs(*arguments)

    def reload_as(self, Encoding=None):
        """Alias for ReloadAs"""
        arguments = [Encoding]
        return self.ReloadAs(*arguments)

    def RemoveDocumentInformation(self, RemoveDocInfoType=None):
        arguments = com_arguments([unwrap(a) for a in [RemoveDocInfoType]])
        self.com_object.RemoveDocumentInformation(*arguments)

    def removedocumentinformation(self, RemoveDocInfoType=None):
        """Alias for RemoveDocumentInformation"""
        arguments = [RemoveDocInfoType]
        return self.RemoveDocumentInformation(*arguments)

    def remove_document_information(self, RemoveDocInfoType=None):
        """Alias for RemoveDocumentInformation"""
        arguments = [RemoveDocInfoType]
        return self.RemoveDocumentInformation(*arguments)

    def RemoveUser(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.RemoveUser(*arguments)

    def removeuser(self, Index=None):
        """Alias for RemoveUser"""
        arguments = [Index]
        return self.RemoveUser(*arguments)

    def remove_user(self, Index=None):
        """Alias for RemoveUser"""
        arguments = [Index]
        return self.RemoveUser(*arguments)

    def Reply(self):
        self.com_object.Reply()

    def reply(self):
        """Alias for Reply"""
        return self.Reply()

    def ReplyAll(self):
        self.com_object.ReplyAll()

    def replyall(self):
        """Alias for ReplyAll"""
        return self.ReplyAll()

    def reply_all(self):
        """Alias for ReplyAll"""
        return self.ReplyAll()

    def ReplyWithChanges(self, ShowMessage=None):
        arguments = com_arguments([unwrap(a) for a in [ShowMessage]])
        self.com_object.ReplyWithChanges(*arguments)

    def replywithchanges(self, ShowMessage=None):
        """Alias for ReplyWithChanges"""
        arguments = [ShowMessage]
        return self.ReplyWithChanges(*arguments)

    def reply_with_changes(self, ShowMessage=None):
        """Alias for ReplyWithChanges"""
        arguments = [ShowMessage]
        return self.ReplyWithChanges(*arguments)

    def ResetColors(self):
        self.com_object.ResetColors()

    def resetcolors(self):
        """Alias for ResetColors"""
        return self.ResetColors()

    def reset_colors(self):
        """Alias for ResetColors"""
        return self.ResetColors()

    def RunAutoMacros(self, Which=None):
        arguments = com_arguments([unwrap(a) for a in [Which]])
        self.com_object.RunAutoMacros(*arguments)

    def runautomacros(self, Which=None):
        """Alias for RunAutoMacros"""
        arguments = [Which]
        return self.RunAutoMacros(*arguments)

    def run_auto_macros(self, Which=None):
        """Alias for RunAutoMacros"""
        arguments = [Which]
        return self.RunAutoMacros(*arguments)

    def Save(self):
        self.com_object.Save()

    def save(self):
        """Alias for Save"""
        return self.Save()

    def SaveAs(self, FileName=None, FileFormat=None, Password=None, WriteResPassword=None, ReadOnlyRecommended=None, CreateBackup=None, AccessMode=None, ConflictResolution=None, AddToMru=None, TextCodepage=None, TextVisualLayout=None, Local=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, FileFormat, Password, WriteResPassword, ReadOnlyRecommended, CreateBackup, AccessMode, ConflictResolution, AddToMru, TextCodepage, TextVisualLayout, Local]])
        self.com_object.SaveAs(*arguments)

    def saveas(self, FileName=None, FileFormat=None, Password=None, WriteResPassword=None, ReadOnlyRecommended=None, CreateBackup=None, AccessMode=None, ConflictResolution=None, AddToMru=None, TextCodepage=None, TextVisualLayout=None, Local=None):
        """Alias for SaveAs"""
        arguments = [FileName, FileFormat, Password, WriteResPassword, ReadOnlyRecommended, CreateBackup, AccessMode, ConflictResolution, AddToMru, TextCodepage, TextVisualLayout, Local]
        return self.SaveAs(*arguments)

    def save_as(self, FileName=None, FileFormat=None, Password=None, WriteResPassword=None, ReadOnlyRecommended=None, CreateBackup=None, AccessMode=None, ConflictResolution=None, AddToMru=None, TextCodepage=None, TextVisualLayout=None, Local=None):
        """Alias for SaveAs"""
        arguments = [FileName, FileFormat, Password, WriteResPassword, ReadOnlyRecommended, CreateBackup, AccessMode, ConflictResolution, AddToMru, TextCodepage, TextVisualLayout, Local]
        return self.SaveAs(*arguments)

    def SaveAsXMLData(self, FileName=None, Map=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, Map]])
        self.com_object.SaveAsXMLData(*arguments)

    def saveasxmldata(self, FileName=None, Map=None):
        """Alias for SaveAsXMLData"""
        arguments = [FileName, Map]
        return self.SaveAsXMLData(*arguments)

    def save_as_x_m_l_data(self, FileName=None, Map=None):
        """Alias for SaveAsXMLData"""
        arguments = [FileName, Map]
        return self.SaveAsXMLData(*arguments)

    def SaveCopyAs(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        self.com_object.SaveCopyAs(*arguments)

    def savecopyas(self, FileName=None):
        """Alias for SaveCopyAs"""
        arguments = [FileName]
        return self.SaveCopyAs(*arguments)

    def save_copy_as(self, FileName=None):
        """Alias for SaveCopyAs"""
        arguments = [FileName]
        return self.SaveCopyAs(*arguments)

    def SendFaxOverInternet(self, Recipients=None, Subject=None, ShowMessage=None):
        arguments = com_arguments([unwrap(a) for a in [Recipients, Subject, ShowMessage]])
        self.com_object.SendFaxOverInternet(*arguments)

    def sendfaxoverinternet(self, Recipients=None, Subject=None, ShowMessage=None):
        """Alias for SendFaxOverInternet"""
        arguments = [Recipients, Subject, ShowMessage]
        return self.SendFaxOverInternet(*arguments)

    def send_fax_over_internet(self, Recipients=None, Subject=None, ShowMessage=None):
        """Alias for SendFaxOverInternet"""
        arguments = [Recipients, Subject, ShowMessage]
        return self.SendFaxOverInternet(*arguments)

    def SendForReview(self, Recipients=None, Subject=None, ShowMessage=None, IncludeAttachment=None):
        arguments = com_arguments([unwrap(a) for a in [Recipients, Subject, ShowMessage, IncludeAttachment]])
        self.com_object.SendForReview(*arguments)

    def sendforreview(self, Recipients=None, Subject=None, ShowMessage=None, IncludeAttachment=None):
        """Alias for SendForReview"""
        arguments = [Recipients, Subject, ShowMessage, IncludeAttachment]
        return self.SendForReview(*arguments)

    def send_for_review(self, Recipients=None, Subject=None, ShowMessage=None, IncludeAttachment=None):
        """Alias for SendForReview"""
        arguments = [Recipients, Subject, ShowMessage, IncludeAttachment]
        return self.SendForReview(*arguments)

    def SendMail(self, Recipients=None, Subject=None, ReturnReceipt=None):
        arguments = com_arguments([unwrap(a) for a in [Recipients, Subject, ReturnReceipt]])
        self.com_object.SendMail(*arguments)

    def sendmail(self, Recipients=None, Subject=None, ReturnReceipt=None):
        """Alias for SendMail"""
        arguments = [Recipients, Subject, ReturnReceipt]
        return self.SendMail(*arguments)

    def send_mail(self, Recipients=None, Subject=None, ReturnReceipt=None):
        """Alias for SendMail"""
        arguments = [Recipients, Subject, ReturnReceipt]
        return self.SendMail(*arguments)

    def SendMailer(self, FileFormat=None, Priority=None):
        arguments = com_arguments([unwrap(a) for a in [FileFormat, Priority]])
        self.com_object.SendMailer(*arguments)

    def sendmailer(self, FileFormat=None, Priority=None):
        """Alias for SendMailer"""
        arguments = [FileFormat, Priority]
        return self.SendMailer(*arguments)

    def send_mailer(self, FileFormat=None, Priority=None):
        """Alias for SendMailer"""
        arguments = [FileFormat, Priority]
        return self.SendMailer(*arguments)

    def SetLinkOnData(self, Name=None, Procedure=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Procedure]])
        self.com_object.SetLinkOnData(*arguments)

    def setlinkondata(self, Name=None, Procedure=None):
        """Alias for SetLinkOnData"""
        arguments = [Name, Procedure]
        return self.SetLinkOnData(*arguments)

    def set_link_on_data(self, Name=None, Procedure=None):
        """Alias for SetLinkOnData"""
        arguments = [Name, Procedure]
        return self.SetLinkOnData(*arguments)

    def SetPasswordEncryptionOptions(self, PasswordEncryptionProvider=None, PasswordEncryptionAlgorithm=None, PasswordEncryptionKeyLength=None, PasswordEncryptionFileProperties=None):
        arguments = com_arguments([unwrap(a) for a in [PasswordEncryptionProvider, PasswordEncryptionAlgorithm, PasswordEncryptionKeyLength, PasswordEncryptionFileProperties]])
        self.com_object.SetPasswordEncryptionOptions(*arguments)

    def setpasswordencryptionoptions(self, PasswordEncryptionProvider=None, PasswordEncryptionAlgorithm=None, PasswordEncryptionKeyLength=None, PasswordEncryptionFileProperties=None):
        """Alias for SetPasswordEncryptionOptions"""
        arguments = [PasswordEncryptionProvider, PasswordEncryptionAlgorithm, PasswordEncryptionKeyLength, PasswordEncryptionFileProperties]
        return self.SetPasswordEncryptionOptions(*arguments)

    def set_password_encryption_options(self, PasswordEncryptionProvider=None, PasswordEncryptionAlgorithm=None, PasswordEncryptionKeyLength=None, PasswordEncryptionFileProperties=None):
        """Alias for SetPasswordEncryptionOptions"""
        arguments = [PasswordEncryptionProvider, PasswordEncryptionAlgorithm, PasswordEncryptionKeyLength, PasswordEncryptionFileProperties]
        return self.SetPasswordEncryptionOptions(*arguments)

    def ToggleFormsDesign(self):
        self.com_object.ToggleFormsDesign()

    def toggleformsdesign(self):
        """Alias for ToggleFormsDesign"""
        return self.ToggleFormsDesign()

    def toggle_forms_design(self):
        """Alias for ToggleFormsDesign"""
        return self.ToggleFormsDesign()

    def Unprotect(self, Password=None):
        arguments = com_arguments([unwrap(a) for a in [Password]])
        self.com_object.Unprotect(*arguments)

    def unprotect(self, Password=None):
        """Alias for Unprotect"""
        arguments = [Password]
        return self.Unprotect(*arguments)

    def UnprotectSharing(self, SharingPassword=None):
        arguments = com_arguments([unwrap(a) for a in [SharingPassword]])
        self.com_object.UnprotectSharing(*arguments)

    def unprotectsharing(self, SharingPassword=None):
        """Alias for UnprotectSharing"""
        arguments = [SharingPassword]
        return self.UnprotectSharing(*arguments)

    def unprotect_sharing(self, SharingPassword=None):
        """Alias for UnprotectSharing"""
        arguments = [SharingPassword]
        return self.UnprotectSharing(*arguments)

    def UpdateFromFile(self):
        self.com_object.UpdateFromFile()

    def updatefromfile(self):
        """Alias for UpdateFromFile"""
        return self.UpdateFromFile()

    def update_from_file(self):
        """Alias for UpdateFromFile"""
        return self.UpdateFromFile()

    def UpdateLink(self, Name=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Type]])
        self.com_object.UpdateLink(*arguments)

    def updatelink(self, Name=None, Type=None):
        """Alias for UpdateLink"""
        arguments = [Name, Type]
        return self.UpdateLink(*arguments)

    def update_link(self, Name=None, Type=None):
        """Alias for UpdateLink"""
        arguments = [Name, Type]
        return self.UpdateLink(*arguments)

    def WebPagePreview(self):
        self.com_object.WebPagePreview()

    def webpagepreview(self):
        """Alias for WebPagePreview"""
        return self.WebPagePreview()

    def web_page_preview(self):
        """Alias for WebPagePreview"""
        return self.WebPagePreview()

    def XmlImport(self, Url=None, ImportMap=None, Overwrite=None, Destination=None):
        arguments = com_arguments([unwrap(a) for a in [Url, ImportMap, Overwrite, Destination]])
        return XlXmlImportResult(self.com_object.XmlImport(*arguments))

    def xmlimport(self, Url=None, ImportMap=None, Overwrite=None, Destination=None):
        """Alias for XmlImport"""
        arguments = [Url, ImportMap, Overwrite, Destination]
        return self.XmlImport(*arguments)

    def xml_import(self, Url=None, ImportMap=None, Overwrite=None, Destination=None):
        """Alias for XmlImport"""
        arguments = [Url, ImportMap, Overwrite, Destination]
        return self.XmlImport(*arguments)

    def XmlImportXml(self, Data=None, ImportMap=None, Overwrite=None, Destination=None):
        arguments = com_arguments([unwrap(a) for a in [Data, ImportMap, Overwrite, Destination]])
        return XlXmlImportResult(self.com_object.XmlImportXml(*arguments))

    def xmlimportxml(self, Data=None, ImportMap=None, Overwrite=None, Destination=None):
        """Alias for XmlImportXml"""
        arguments = [Data, ImportMap, Overwrite, Destination]
        return self.XmlImportXml(*arguments)

    def xml_import_xml(self, Data=None, ImportMap=None, Overwrite=None, Destination=None):
        """Alias for XmlImportXml"""
        arguments = [Data, ImportMap, Overwrite, Destination]
        return self.XmlImportXml(*arguments)


class WorkbookQuery:

    def __init__(self, workbookquery=None):
        self.com_object= workbookquery

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Description(self):
        return self.com_object.Description

    @Description.setter
    def Description(self, value):
        self.com_object.Description = value

    @property
    def description(self):
        """Alias for Description"""
        return self.Description

    @description.setter
    def description(self, value):
        """Alias for Description.setter"""
        self.Description = value

    @property
    def Formula(self):
        return self.com_object.Formula

    @Formula.setter
    def Formula(self, value):
        self.com_object.Formula = value

    @property
    def formula(self):
        """Alias for Formula"""
        return self.Formula

    @formula.setter
    def formula(self, value):
        """Alias for Formula.setter"""
        self.Formula = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Delete(self, DeleteConnection=None):
        arguments = com_arguments([unwrap(a) for a in [DeleteConnection]])
        return self.com_object.Delete(*arguments)

    def delete(self, DeleteConnection=None):
        """Alias for Delete"""
        arguments = [DeleteConnection]
        return self.Delete(*arguments)

    def Refresh(self):
        return self.com_object.Refresh()

    def refresh(self):
        """Alias for Refresh"""
        return self.Refresh()


class Workbooks:

    def __init__(self, workbooks=None):
        self.com_object= workbooks

    def __call__(self, item):
        return Workbook(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Template=None):
        arguments = com_arguments([unwrap(a) for a in [Template]])
        return Workbook(self.com_object.Add(*arguments))

    def add(self, Template=None):
        """Alias for Add"""
        arguments = [Template]
        return self.Add(*arguments)

    def CanCheckOut(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        return self.com_object.CanCheckOut(*arguments)

    def cancheckout(self, FileName=None):
        """Alias for CanCheckOut"""
        arguments = [FileName]
        return self.CanCheckOut(*arguments)

    def can_check_out(self, FileName=None):
        """Alias for CanCheckOut"""
        arguments = [FileName]
        return self.CanCheckOut(*arguments)

    def CheckOut(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        self.com_object.CheckOut(*arguments)

    def checkout(self, FileName=None):
        """Alias for CheckOut"""
        arguments = [FileName]
        return self.CheckOut(*arguments)

    def check_out(self, FileName=None):
        """Alias for CheckOut"""
        arguments = [FileName]
        return self.CheckOut(*arguments)

    def Close(self):
        self.com_object.Close()

    def close(self):
        """Alias for Close"""
        return self.Close()

    def Open(self, FileName=None, UpdateLinks=None, ReadOnly=None, Format=None, Password=None, WriteResPassword=None, IgnoreReadOnlyRecommended=None, Origin=None, Delimiter=None, Editable=None, Notify=None, Converter=None, AddToMru=None, Local=None, CorruptLoad=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, UpdateLinks, ReadOnly, Format, Password, WriteResPassword, IgnoreReadOnlyRecommended, Origin, Delimiter, Editable, Notify, Converter, AddToMru, Local, CorruptLoad]])
        return Workbook(self.com_object.Open(*arguments))

    def open(self, FileName=None, UpdateLinks=None, ReadOnly=None, Format=None, Password=None, WriteResPassword=None, IgnoreReadOnlyRecommended=None, Origin=None, Delimiter=None, Editable=None, Notify=None, Converter=None, AddToMru=None, Local=None, CorruptLoad=None):
        """Alias for Open"""
        arguments = [FileName, UpdateLinks, ReadOnly, Format, Password, WriteResPassword, IgnoreReadOnlyRecommended, Origin, Delimiter, Editable, Notify, Converter, AddToMru, Local, CorruptLoad]
        return self.Open(*arguments)

    def OpenDatabase(self, FileName=None, CommandText=None, CommandType=None, BackgroundQuery=None, ImportDataAs=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, CommandText, CommandType, BackgroundQuery, ImportDataAs]])
        return Workbook(self.com_object.OpenDatabase(*arguments))

    def opendatabase(self, FileName=None, CommandText=None, CommandType=None, BackgroundQuery=None, ImportDataAs=None):
        """Alias for OpenDatabase"""
        arguments = [FileName, CommandText, CommandType, BackgroundQuery, ImportDataAs]
        return self.OpenDatabase(*arguments)

    def open_database(self, FileName=None, CommandText=None, CommandType=None, BackgroundQuery=None, ImportDataAs=None):
        """Alias for OpenDatabase"""
        arguments = [FileName, CommandText, CommandType, BackgroundQuery, ImportDataAs]
        return self.OpenDatabase(*arguments)

    def OpenText(self, FileName=None, Origin=None, StartRow=None, DataType=None, TextQualifier=None, ConsecutiveDelimiter=None, Tab=None, Semicolon=None, Comma=None, Space=None, Other=None, OtherChar=None, FieldInfo=None, TextVisualLayout=None, DecimalSeparator=None, ThousandsSeparator=None, TrailingMinusNumbers=None, Local=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, Origin, StartRow, DataType, TextQualifier, ConsecutiveDelimiter, Tab, Semicolon, Comma, Space, Other, OtherChar, FieldInfo, TextVisualLayout, DecimalSeparator, ThousandsSeparator, TrailingMinusNumbers, Local]])
        self.com_object.OpenText(*arguments)

    def opentext(self, FileName=None, Origin=None, StartRow=None, DataType=None, TextQualifier=None, ConsecutiveDelimiter=None, Tab=None, Semicolon=None, Comma=None, Space=None, Other=None, OtherChar=None, FieldInfo=None, TextVisualLayout=None, DecimalSeparator=None, ThousandsSeparator=None, TrailingMinusNumbers=None, Local=None):
        """Alias for OpenText"""
        arguments = [FileName, Origin, StartRow, DataType, TextQualifier, ConsecutiveDelimiter, Tab, Semicolon, Comma, Space, Other, OtherChar, FieldInfo, TextVisualLayout, DecimalSeparator, ThousandsSeparator, TrailingMinusNumbers, Local]
        return self.OpenText(*arguments)

    def open_text(self, FileName=None, Origin=None, StartRow=None, DataType=None, TextQualifier=None, ConsecutiveDelimiter=None, Tab=None, Semicolon=None, Comma=None, Space=None, Other=None, OtherChar=None, FieldInfo=None, TextVisualLayout=None, DecimalSeparator=None, ThousandsSeparator=None, TrailingMinusNumbers=None, Local=None):
        """Alias for OpenText"""
        arguments = [FileName, Origin, StartRow, DataType, TextQualifier, ConsecutiveDelimiter, Tab, Semicolon, Comma, Space, Other, OtherChar, FieldInfo, TextVisualLayout, DecimalSeparator, ThousandsSeparator, TrailingMinusNumbers, Local]
        return self.OpenText(*arguments)

    def OpenXML(self, FileName=None, Stylesheets=None, LoadOption=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, Stylesheets, LoadOption]])
        return Workbook(self.com_object.OpenXML(*arguments))

    def openxml(self, FileName=None, Stylesheets=None, LoadOption=None):
        """Alias for OpenXML"""
        arguments = [FileName, Stylesheets, LoadOption]
        return self.OpenXML(*arguments)

    def open_x_m_l(self, FileName=None, Stylesheets=None, LoadOption=None):
        """Alias for OpenXML"""
        arguments = [FileName, Stylesheets, LoadOption]
        return self.OpenXML(*arguments)


class Worksheet:

    def __init__(self, worksheet=None):
        self.com_object= worksheet

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoFilter(self):
        return AutoFilter(self.com_object.AutoFilter)

    @property
    def autofilter(self):
        """Alias for AutoFilter"""
        return self.AutoFilter

    @property
    def auto_filter(self):
        """Alias for AutoFilter"""
        return self.AutoFilter

    @property
    def AutoFilterMode(self):
        return self.com_object.AutoFilterMode

    @AutoFilterMode.setter
    def AutoFilterMode(self, value):
        self.com_object.AutoFilterMode = value

    @property
    def autofiltermode(self):
        """Alias for AutoFilterMode"""
        return self.AutoFilterMode

    @autofiltermode.setter
    def autofiltermode(self, value):
        """Alias for AutoFilterMode.setter"""
        self.AutoFilterMode = value

    @property
    def auto_filter_mode(self):
        """Alias for AutoFilterMode"""
        return self.AutoFilterMode

    @auto_filter_mode.setter
    def auto_filter_mode(self, value):
        """Alias for AutoFilterMode.setter"""
        self.AutoFilterMode = value

    def Cells(self, RowIndex=None, ColumnIndex=None):
        arguments = com_arguments([unwrap(a) for a in [RowIndex, ColumnIndex]])
        if hasattr(self.com_object, "GetCells"):
            return Range(self.com_object.GetCells(*arguments))
        else:
            return Range(self.com_object.Cells(*arguments))

    def cells(self, RowIndex=None, ColumnIndex=None):
        """Alias for Cells"""
        arguments = [RowIndex, ColumnIndex]
        return self.Cells(*arguments)

    @property
    def CircularReference(self):
        return Range(self.com_object.CircularReference)

    @property
    def circularreference(self):
        """Alias for CircularReference"""
        return self.CircularReference

    @property
    def circular_reference(self):
        """Alias for CircularReference"""
        return self.CircularReference

    @property
    def CodeName(self):
        return self.com_object.CodeName

    @property
    def codename(self):
        """Alias for CodeName"""
        return self.CodeName

    @property
    def code_name(self):
        """Alias for CodeName"""
        return self.CodeName

    @property
    def Columns(self):
        return Range(self.com_object.Columns)

    @property
    def columns(self):
        """Alias for Columns"""
        return self.Columns

    @property
    def Comments(self):
        return Comments(self.com_object.Comments)

    @property
    def comments(self):
        """Alias for Comments"""
        return self.Comments

    @property
    def CommentsThreaded(self):
        return CommentsThreaded(self.com_object.CommentsThreaded)

    @property
    def commentsthreaded(self):
        """Alias for CommentsThreaded"""
        return self.CommentsThreaded

    @property
    def comments_threaded(self):
        """Alias for CommentsThreaded"""
        return self.CommentsThreaded

    @property
    def ConsolidationFunction(self):
        return XlConsolidationFunction(self.com_object.ConsolidationFunction)

    @property
    def consolidationfunction(self):
        """Alias for ConsolidationFunction"""
        return self.ConsolidationFunction

    @property
    def consolidation_function(self):
        """Alias for ConsolidationFunction"""
        return self.ConsolidationFunction

    @property
    def ConsolidationOptions(self):
        return self.com_object.ConsolidationOptions

    @property
    def consolidationoptions(self):
        """Alias for ConsolidationOptions"""
        return self.ConsolidationOptions

    @property
    def consolidation_options(self):
        """Alias for ConsolidationOptions"""
        return self.ConsolidationOptions

    @property
    def ConsolidationSources(self):
        return self.com_object.ConsolidationSources

    @property
    def consolidationsources(self):
        """Alias for ConsolidationSources"""
        return self.ConsolidationSources

    @property
    def consolidation_sources(self):
        """Alias for ConsolidationSources"""
        return self.ConsolidationSources

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def CustomProperties(self):
        return CustomProperties(self.com_object.CustomProperties)

    @property
    def customproperties(self):
        """Alias for CustomProperties"""
        return self.CustomProperties

    @property
    def custom_properties(self):
        """Alias for CustomProperties"""
        return self.CustomProperties

    @property
    def DisplayPageBreaks(self):
        return self.com_object.DisplayPageBreaks

    @DisplayPageBreaks.setter
    def DisplayPageBreaks(self, value):
        self.com_object.DisplayPageBreaks = value

    @property
    def displaypagebreaks(self):
        """Alias for DisplayPageBreaks"""
        return self.DisplayPageBreaks

    @displaypagebreaks.setter
    def displaypagebreaks(self, value):
        """Alias for DisplayPageBreaks.setter"""
        self.DisplayPageBreaks = value

    @property
    def display_page_breaks(self):
        """Alias for DisplayPageBreaks"""
        return self.DisplayPageBreaks

    @display_page_breaks.setter
    def display_page_breaks(self, value):
        """Alias for DisplayPageBreaks.setter"""
        self.DisplayPageBreaks = value

    @property
    def DisplayRightToLeft(self):
        return self.com_object.DisplayRightToLeft

    @property
    def displayrighttoleft(self):
        """Alias for DisplayRightToLeft"""
        return self.DisplayRightToLeft

    @property
    def display_right_to_left(self):
        """Alias for DisplayRightToLeft"""
        return self.DisplayRightToLeft

    @property
    def EnableAutoFilter(self):
        return self.com_object.EnableAutoFilter

    @EnableAutoFilter.setter
    def EnableAutoFilter(self, value):
        self.com_object.EnableAutoFilter = value

    @property
    def enableautofilter(self):
        """Alias for EnableAutoFilter"""
        return self.EnableAutoFilter

    @enableautofilter.setter
    def enableautofilter(self, value):
        """Alias for EnableAutoFilter.setter"""
        self.EnableAutoFilter = value

    @property
    def enable_auto_filter(self):
        """Alias for EnableAutoFilter"""
        return self.EnableAutoFilter

    @enable_auto_filter.setter
    def enable_auto_filter(self, value):
        """Alias for EnableAutoFilter.setter"""
        self.EnableAutoFilter = value

    @property
    def EnableCalculation(self):
        return self.com_object.EnableCalculation

    @EnableCalculation.setter
    def EnableCalculation(self, value):
        self.com_object.EnableCalculation = value

    @property
    def enablecalculation(self):
        """Alias for EnableCalculation"""
        return self.EnableCalculation

    @enablecalculation.setter
    def enablecalculation(self, value):
        """Alias for EnableCalculation.setter"""
        self.EnableCalculation = value

    @property
    def enable_calculation(self):
        """Alias for EnableCalculation"""
        return self.EnableCalculation

    @enable_calculation.setter
    def enable_calculation(self, value):
        """Alias for EnableCalculation.setter"""
        self.EnableCalculation = value

    @property
    def EnableFormatConditionsCalculation(self):
        return self.com_object.EnableFormatConditionsCalculation

    @EnableFormatConditionsCalculation.setter
    def EnableFormatConditionsCalculation(self, value):
        self.com_object.EnableFormatConditionsCalculation = value

    @property
    def enableformatconditionscalculation(self):
        """Alias for EnableFormatConditionsCalculation"""
        return self.EnableFormatConditionsCalculation

    @enableformatconditionscalculation.setter
    def enableformatconditionscalculation(self, value):
        """Alias for EnableFormatConditionsCalculation.setter"""
        self.EnableFormatConditionsCalculation = value

    @property
    def enable_format_conditions_calculation(self):
        """Alias for EnableFormatConditionsCalculation"""
        return self.EnableFormatConditionsCalculation

    @enable_format_conditions_calculation.setter
    def enable_format_conditions_calculation(self, value):
        """Alias for EnableFormatConditionsCalculation.setter"""
        self.EnableFormatConditionsCalculation = value

    @property
    def EnableOutlining(self):
        return self.com_object.EnableOutlining

    @EnableOutlining.setter
    def EnableOutlining(self, value):
        self.com_object.EnableOutlining = value

    @property
    def enableoutlining(self):
        """Alias for EnableOutlining"""
        return self.EnableOutlining

    @enableoutlining.setter
    def enableoutlining(self, value):
        """Alias for EnableOutlining.setter"""
        self.EnableOutlining = value

    @property
    def enable_outlining(self):
        """Alias for EnableOutlining"""
        return self.EnableOutlining

    @enable_outlining.setter
    def enable_outlining(self, value):
        """Alias for EnableOutlining.setter"""
        self.EnableOutlining = value

    @property
    def EnablePivotTable(self):
        return self.com_object.EnablePivotTable

    @EnablePivotTable.setter
    def EnablePivotTable(self, value):
        self.com_object.EnablePivotTable = value

    @property
    def enablepivottable(self):
        """Alias for EnablePivotTable"""
        return self.EnablePivotTable

    @enablepivottable.setter
    def enablepivottable(self, value):
        """Alias for EnablePivotTable.setter"""
        self.EnablePivotTable = value

    @property
    def enable_pivot_table(self):
        """Alias for EnablePivotTable"""
        return self.EnablePivotTable

    @enable_pivot_table.setter
    def enable_pivot_table(self, value):
        """Alias for EnablePivotTable.setter"""
        self.EnablePivotTable = value

    @property
    def EnableSelection(self):
        return XlEnableSelection(self.com_object.EnableSelection)

    @EnableSelection.setter
    def EnableSelection(self, value):
        self.com_object.EnableSelection = value

    @property
    def enableselection(self):
        """Alias for EnableSelection"""
        return self.EnableSelection

    @enableselection.setter
    def enableselection(self, value):
        """Alias for EnableSelection.setter"""
        self.EnableSelection = value

    @property
    def enable_selection(self):
        """Alias for EnableSelection"""
        return self.EnableSelection

    @enable_selection.setter
    def enable_selection(self, value):
        """Alias for EnableSelection.setter"""
        self.EnableSelection = value

    @property
    def FilterMode(self):
        return self.com_object.FilterMode

    @property
    def filtermode(self):
        """Alias for FilterMode"""
        return self.FilterMode

    @property
    def filter_mode(self):
        """Alias for FilterMode"""
        return self.FilterMode

    @property
    def HPageBreaks(self):
        return HPageBreaks(self.com_object.HPageBreaks)

    @property
    def hpagebreaks(self):
        """Alias for HPageBreaks"""
        return self.HPageBreaks

    @property
    def h_page_breaks(self):
        """Alias for HPageBreaks"""
        return self.HPageBreaks

    @property
    def Hyperlinks(self):
        return Hyperlinks(self.com_object.Hyperlinks)

    @property
    def hyperlinks(self):
        """Alias for Hyperlinks"""
        return self.Hyperlinks

    @property
    def Index(self):
        return self.com_object.Index

    @property
    def index(self):
        """Alias for Index"""
        return self.Index

    @property
    def ListObjects(self):
        return ListObjects(self.com_object.ListObjects)

    @property
    def listobjects(self):
        """Alias for ListObjects"""
        return self.ListObjects

    @property
    def list_objects(self):
        """Alias for ListObjects"""
        return self.ListObjects

    @property
    def MailEnvelope(self):
        return self.com_object.MailEnvelope

    @property
    def mailenvelope(self):
        """Alias for MailEnvelope"""
        return self.MailEnvelope

    @property
    def mail_envelope(self):
        """Alias for MailEnvelope"""
        return self.MailEnvelope

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Names(self):
        return Names(self.com_object.Names)

    @property
    def names(self):
        """Alias for Names"""
        return self.Names

    @property
    def Next(self):
        return Worksheet(self.com_object.Next)

    @property
    def next(self):
        """Alias for Next"""
        return self.Next

    @property
    def Outline(self):
        return Outline(self.com_object.Outline)

    @property
    def outline(self):
        """Alias for Outline"""
        return self.Outline

    @property
    def PageSetup(self):
        return PageSetup(self.com_object.PageSetup)

    @property
    def pagesetup(self):
        """Alias for PageSetup"""
        return self.PageSetup

    @property
    def page_setup(self):
        """Alias for PageSetup"""
        return self.PageSetup

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Previous(self):
        return Worksheet(self.com_object.Previous)

    @property
    def previous(self):
        """Alias for Previous"""
        return self.Previous

    @property
    def PrintedCommentPages(self):
        return self.com_object.PrintedCommentPages

    @property
    def printedcommentpages(self):
        """Alias for PrintedCommentPages"""
        return self.PrintedCommentPages

    @property
    def printed_comment_pages(self):
        """Alias for PrintedCommentPages"""
        return self.PrintedCommentPages

    @property
    def ProtectContents(self):
        return self.com_object.ProtectContents

    @property
    def protectcontents(self):
        """Alias for ProtectContents"""
        return self.ProtectContents

    @property
    def protect_contents(self):
        """Alias for ProtectContents"""
        return self.ProtectContents

    @property
    def ProtectDrawingObjects(self):
        return self.com_object.ProtectDrawingObjects

    @property
    def protectdrawingobjects(self):
        """Alias for ProtectDrawingObjects"""
        return self.ProtectDrawingObjects

    @property
    def protect_drawing_objects(self):
        """Alias for ProtectDrawingObjects"""
        return self.ProtectDrawingObjects

    @property
    def Protection(self):
        return Protection(self.com_object.Protection)

    @property
    def protection(self):
        """Alias for Protection"""
        return self.Protection

    @property
    def ProtectionMode(self):
        return self.com_object.ProtectionMode

    @property
    def protectionmode(self):
        """Alias for ProtectionMode"""
        return self.ProtectionMode

    @property
    def protection_mode(self):
        """Alias for ProtectionMode"""
        return self.ProtectionMode

    @property
    def ProtectScenarios(self):
        return self.com_object.ProtectScenarios

    @property
    def protectscenarios(self):
        """Alias for ProtectScenarios"""
        return self.ProtectScenarios

    @property
    def protect_scenarios(self):
        """Alias for ProtectScenarios"""
        return self.ProtectScenarios

    @property
    def QueryTables(self):
        return QueryTables(self.com_object.QueryTables)

    @property
    def querytables(self):
        """Alias for QueryTables"""
        return self.QueryTables

    @property
    def query_tables(self):
        """Alias for QueryTables"""
        return self.QueryTables

    def Range(self, Cell1=None, Cell2=None):
        arguments = com_arguments([unwrap(a) for a in [Cell1, Cell2]])
        if hasattr(self.com_object, "GetRange"):
            return Range(self.com_object.GetRange(*arguments))
        else:
            return Range(self.com_object.Range(*arguments))

    def range(self, Cell1=None, Cell2=None):
        """Alias for Range"""
        arguments = [Cell1, Cell2]
        return self.Range(*arguments)

    @property
    def Rows(self):
        return Range(self.com_object.Rows)

    @property
    def rows(self):
        """Alias for Rows"""
        return self.Rows

    @property
    def ScrollArea(self):
        return self.com_object.ScrollArea

    @ScrollArea.setter
    def ScrollArea(self, value):
        self.com_object.ScrollArea = value

    @property
    def scrollarea(self):
        """Alias for ScrollArea"""
        return self.ScrollArea

    @scrollarea.setter
    def scrollarea(self, value):
        """Alias for ScrollArea.setter"""
        self.ScrollArea = value

    @property
    def scroll_area(self):
        """Alias for ScrollArea"""
        return self.ScrollArea

    @scroll_area.setter
    def scroll_area(self, value):
        """Alias for ScrollArea.setter"""
        self.ScrollArea = value

    @property
    def Shapes(self):
        return Shapes(self.com_object.Shapes)

    @property
    def shapes(self):
        """Alias for Shapes"""
        return self.Shapes

    @property
    def Sort(self):
        return Sort(self.com_object.Sort)

    @property
    def sort(self):
        """Alias for Sort"""
        return self.Sort

    @property
    def StandardHeight(self):
        return self.com_object.StandardHeight

    @property
    def standardheight(self):
        """Alias for StandardHeight"""
        return self.StandardHeight

    @property
    def standard_height(self):
        """Alias for StandardHeight"""
        return self.StandardHeight

    @property
    def StandardWidth(self):
        return self.com_object.StandardWidth

    @StandardWidth.setter
    def StandardWidth(self, value):
        self.com_object.StandardWidth = value

    @property
    def standardwidth(self):
        """Alias for StandardWidth"""
        return self.StandardWidth

    @standardwidth.setter
    def standardwidth(self, value):
        """Alias for StandardWidth.setter"""
        self.StandardWidth = value

    @property
    def standard_width(self):
        """Alias for StandardWidth"""
        return self.StandardWidth

    @standard_width.setter
    def standard_width(self, value):
        """Alias for StandardWidth.setter"""
        self.StandardWidth = value

    @property
    def Tab(self):
        return Tab(self.com_object.Tab)

    @property
    def tab(self):
        """Alias for Tab"""
        return self.Tab

    @property
    def TransitionExpEval(self):
        return self.com_object.TransitionExpEval

    @TransitionExpEval.setter
    def TransitionExpEval(self, value):
        self.com_object.TransitionExpEval = value

    @property
    def transitionexpeval(self):
        """Alias for TransitionExpEval"""
        return self.TransitionExpEval

    @transitionexpeval.setter
    def transitionexpeval(self, value):
        """Alias for TransitionExpEval.setter"""
        self.TransitionExpEval = value

    @property
    def transition_exp_eval(self):
        """Alias for TransitionExpEval"""
        return self.TransitionExpEval

    @transition_exp_eval.setter
    def transition_exp_eval(self, value):
        """Alias for TransitionExpEval.setter"""
        self.TransitionExpEval = value

    @property
    def TransitionFormEntry(self):
        return self.com_object.TransitionFormEntry

    @TransitionFormEntry.setter
    def TransitionFormEntry(self, value):
        self.com_object.TransitionFormEntry = value

    @property
    def transitionformentry(self):
        """Alias for TransitionFormEntry"""
        return self.TransitionFormEntry

    @transitionformentry.setter
    def transitionformentry(self, value):
        """Alias for TransitionFormEntry.setter"""
        self.TransitionFormEntry = value

    @property
    def transition_form_entry(self):
        """Alias for TransitionFormEntry"""
        return self.TransitionFormEntry

    @transition_form_entry.setter
    def transition_form_entry(self, value):
        """Alias for TransitionFormEntry.setter"""
        self.TransitionFormEntry = value

    @property
    def Type(self):
        return XlSheetType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    @property
    def UsedRange(self):
        return Range(self.com_object.UsedRange)

    @property
    def usedrange(self):
        """Alias for UsedRange"""
        return self.UsedRange

    @property
    def used_range(self):
        """Alias for UsedRange"""
        return self.UsedRange

    @property
    def Visible(self):
        return XlSheetVisibility(self.com_object.Visible)

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def VPageBreaks(self):
        return VPageBreaks(self.com_object.VPageBreaks)

    @property
    def vpagebreaks(self):
        """Alias for VPageBreaks"""
        return self.VPageBreaks

    @property
    def v_page_breaks(self):
        """Alias for VPageBreaks"""
        return self.VPageBreaks

    def Activate(self):
        self.com_object.Activate()

    def activate(self):
        """Alias for Activate"""
        return self.Activate()

    def Calculate(self):
        self.com_object.Calculate()

    def calculate(self):
        """Alias for Calculate"""
        return self.Calculate()

    def ChartObjects(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.ChartObjects(*arguments)

    def chartobjects(self, Index=None):
        """Alias for ChartObjects"""
        arguments = [Index]
        return self.ChartObjects(*arguments)

    def chart_objects(self, Index=None):
        """Alias for ChartObjects"""
        arguments = [Index]
        return self.ChartObjects(*arguments)

    def CheckSpelling(self, CustomDictionary=None, IgnoreUppercase=None, AlwaysSuggest=None, SpellLang=None):
        arguments = com_arguments([unwrap(a) for a in [CustomDictionary, IgnoreUppercase, AlwaysSuggest, SpellLang]])
        self.com_object.CheckSpelling(*arguments)

    def checkspelling(self, CustomDictionary=None, IgnoreUppercase=None, AlwaysSuggest=None, SpellLang=None):
        """Alias for CheckSpelling"""
        arguments = [CustomDictionary, IgnoreUppercase, AlwaysSuggest, SpellLang]
        return self.CheckSpelling(*arguments)

    def check_spelling(self, CustomDictionary=None, IgnoreUppercase=None, AlwaysSuggest=None, SpellLang=None):
        """Alias for CheckSpelling"""
        arguments = [CustomDictionary, IgnoreUppercase, AlwaysSuggest, SpellLang]
        return self.CheckSpelling(*arguments)

    def CircleInvalid(self):
        self.com_object.CircleInvalid()

    def circleinvalid(self):
        """Alias for CircleInvalid"""
        return self.CircleInvalid()

    def circle_invalid(self):
        """Alias for CircleInvalid"""
        return self.CircleInvalid()

    def ClearArrows(self):
        self.com_object.ClearArrows()

    def cleararrows(self):
        """Alias for ClearArrows"""
        return self.ClearArrows()

    def clear_arrows(self):
        """Alias for ClearArrows"""
        return self.ClearArrows()

    def ClearCircles(self):
        self.com_object.ClearCircles()

    def clearcircles(self):
        """Alias for ClearCircles"""
        return self.ClearCircles()

    def clear_circles(self):
        """Alias for ClearCircles"""
        return self.ClearCircles()

    def Copy(self, Before=None, After=None):
        arguments = com_arguments([unwrap(a) for a in [Before, After]])
        self.com_object.Copy(*arguments)

    def copy(self, Before=None, After=None):
        """Alias for Copy"""
        arguments = [Before, After]
        return self.Copy(*arguments)

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Evaluate(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        return self.com_object.Evaluate(*arguments)

    def evaluate(self, Name=None):
        """Alias for Evaluate"""
        arguments = [Name]
        return self.Evaluate(*arguments)

    def ExportAsFixedFormat(self, Type=None, FileName=None, Quality=None, IncludeDocProperties=None, IgnorePrintAreas=None, From=None, To=None, OpenAfterPublish=None, FixedFormatExtClassPtr=None):
        arguments = com_arguments([unwrap(a) for a in [Type, FileName, Quality, IncludeDocProperties, IgnorePrintAreas, From, To, OpenAfterPublish, FixedFormatExtClassPtr]])
        self.com_object.ExportAsFixedFormat(*arguments)

    def exportasfixedformat(self, Type=None, FileName=None, Quality=None, IncludeDocProperties=None, IgnorePrintAreas=None, From=None, To=None, OpenAfterPublish=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat"""
        arguments = [Type, FileName, Quality, IncludeDocProperties, IgnorePrintAreas, From, To, OpenAfterPublish, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat(*arguments)

    def export_as_fixed_format(self, Type=None, FileName=None, Quality=None, IncludeDocProperties=None, IgnorePrintAreas=None, From=None, To=None, OpenAfterPublish=None, FixedFormatExtClassPtr=None):
        """Alias for ExportAsFixedFormat"""
        arguments = [Type, FileName, Quality, IncludeDocProperties, IgnorePrintAreas, From, To, OpenAfterPublish, FixedFormatExtClassPtr]
        return self.ExportAsFixedFormat(*arguments)

    def Move(self, Before=None, After=None):
        arguments = com_arguments([unwrap(a) for a in [Before, After]])
        self.com_object.Move(*arguments)

    def move(self, Before=None, After=None):
        """Alias for Move"""
        arguments = [Before, After]
        return self.Move(*arguments)

    def OLEObjects(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.OLEObjects(*arguments)

    def oleobjects(self, Index=None):
        """Alias for OLEObjects"""
        arguments = [Index]
        return self.OLEObjects(*arguments)

    def o_l_e_objects(self, Index=None):
        """Alias for OLEObjects"""
        arguments = [Index]
        return self.OLEObjects(*arguments)

    def Paste(self, Destination=None, Link=None):
        arguments = com_arguments([unwrap(a) for a in [Destination, Link]])
        self.com_object.Paste(*arguments)

    def paste(self, Destination=None, Link=None):
        """Alias for Paste"""
        arguments = [Destination, Link]
        return self.Paste(*arguments)

    def PasteSpecial(self, Format=None, Link=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, NoHTMLFormatting=None):
        arguments = com_arguments([unwrap(a) for a in [Format, Link, DisplayAsIcon, IconFileName, IconIndex, IconLabel, NoHTMLFormatting]])
        self.com_object.PasteSpecial(*arguments)

    def pastespecial(self, Format=None, Link=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, NoHTMLFormatting=None):
        """Alias for PasteSpecial"""
        arguments = [Format, Link, DisplayAsIcon, IconFileName, IconIndex, IconLabel, NoHTMLFormatting]
        return self.PasteSpecial(*arguments)

    def paste_special(self, Format=None, Link=None, DisplayAsIcon=None, IconFileName=None, IconIndex=None, IconLabel=None, NoHTMLFormatting=None):
        """Alias for PasteSpecial"""
        arguments = [Format, Link, DisplayAsIcon, IconFileName, IconIndex, IconLabel, NoHTMLFormatting]
        return self.PasteSpecial(*arguments)

    def PivotTables(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return PivotTable(self.com_object.PivotTables(*arguments))

    def pivottables(self, Index=None):
        """Alias for PivotTables"""
        arguments = [Index]
        return self.PivotTables(*arguments)

    def pivot_tables(self, Index=None):
        """Alias for PivotTables"""
        arguments = [Index]
        return self.PivotTables(*arguments)

    def PivotTableWizard(self, SourceType=None, SourceData=None, TableDestination=None, TableName=None, RowGrand=None, ColumnGrand=None, SaveData=None, HasAutoFormat=None, AutoPage=None, Reserved=None, BackgroundQuery=None, OptimizeCache=None, PageFieldOrder=None, PageFieldWrapCount=None, ReadData=None, Connection=None):
        arguments = com_arguments([unwrap(a) for a in [SourceType, SourceData, TableDestination, TableName, RowGrand, ColumnGrand, SaveData, HasAutoFormat, AutoPage, Reserved, BackgroundQuery, OptimizeCache, PageFieldOrder, PageFieldWrapCount, ReadData, Connection]])
        return PivotTable(self.com_object.PivotTableWizard(*arguments))

    def pivottablewizard(self, SourceType=None, SourceData=None, TableDestination=None, TableName=None, RowGrand=None, ColumnGrand=None, SaveData=None, HasAutoFormat=None, AutoPage=None, Reserved=None, BackgroundQuery=None, OptimizeCache=None, PageFieldOrder=None, PageFieldWrapCount=None, ReadData=None, Connection=None):
        """Alias for PivotTableWizard"""
        arguments = [SourceType, SourceData, TableDestination, TableName, RowGrand, ColumnGrand, SaveData, HasAutoFormat, AutoPage, Reserved, BackgroundQuery, OptimizeCache, PageFieldOrder, PageFieldWrapCount, ReadData, Connection]
        return self.PivotTableWizard(*arguments)

    def pivot_table_wizard(self, SourceType=None, SourceData=None, TableDestination=None, TableName=None, RowGrand=None, ColumnGrand=None, SaveData=None, HasAutoFormat=None, AutoPage=None, Reserved=None, BackgroundQuery=None, OptimizeCache=None, PageFieldOrder=None, PageFieldWrapCount=None, ReadData=None, Connection=None):
        """Alias for PivotTableWizard"""
        arguments = [SourceType, SourceData, TableDestination, TableName, RowGrand, ColumnGrand, SaveData, HasAutoFormat, AutoPage, Reserved, BackgroundQuery, OptimizeCache, PageFieldOrder, PageFieldWrapCount, ReadData, Connection]
        return self.PivotTableWizard(*arguments)

    def PrintOut(self, From=None, To=None, Copies=None, Preview=None, ActivePrinter=None, PrintToFile=None, Collate=None, PrToFileName=None, IgnorePrintAreas=None):
        arguments = com_arguments([unwrap(a) for a in [From, To, Copies, Preview, ActivePrinter, PrintToFile, Collate, PrToFileName, IgnorePrintAreas]])
        return self.com_object.PrintOut(*arguments)

    def printout(self, From=None, To=None, Copies=None, Preview=None, ActivePrinter=None, PrintToFile=None, Collate=None, PrToFileName=None, IgnorePrintAreas=None):
        """Alias for PrintOut"""
        arguments = [From, To, Copies, Preview, ActivePrinter, PrintToFile, Collate, PrToFileName, IgnorePrintAreas]
        return self.PrintOut(*arguments)

    def print_out(self, From=None, To=None, Copies=None, Preview=None, ActivePrinter=None, PrintToFile=None, Collate=None, PrToFileName=None, IgnorePrintAreas=None):
        """Alias for PrintOut"""
        arguments = [From, To, Copies, Preview, ActivePrinter, PrintToFile, Collate, PrToFileName, IgnorePrintAreas]
        return self.PrintOut(*arguments)

    def PrintPreview(self, EnableChanges=None):
        arguments = com_arguments([unwrap(a) for a in [EnableChanges]])
        self.com_object.PrintPreview(*arguments)

    def printpreview(self, EnableChanges=None):
        """Alias for PrintPreview"""
        arguments = [EnableChanges]
        return self.PrintPreview(*arguments)

    def print_preview(self, EnableChanges=None):
        """Alias for PrintPreview"""
        arguments = [EnableChanges]
        return self.PrintPreview(*arguments)

    def Protect(self, Password=None, DrawingObjects=None, Contents=None, Scenarios=None, UserInterfaceOnly=None, AllowFormattingCells=None, AllowFormattingColumns=None, AllowFormattingRows=None, AllowInsertingColumns=None, AllowInsertingRows=None, AllowInsertingHyperlinks=None, AllowDeletingColumns=None, AllowDeletingRows=None, AllowSorting=None, AllowFiltering=None, AllowUsingPivotTables=None):
        arguments = com_arguments([unwrap(a) for a in [Password, DrawingObjects, Contents, Scenarios, UserInterfaceOnly, AllowFormattingCells, AllowFormattingColumns, AllowFormattingRows, AllowInsertingColumns, AllowInsertingRows, AllowInsertingHyperlinks, AllowDeletingColumns, AllowDeletingRows, AllowSorting, AllowFiltering, AllowUsingPivotTables]])
        self.com_object.Protect(*arguments)

    def protect(self, Password=None, DrawingObjects=None, Contents=None, Scenarios=None, UserInterfaceOnly=None, AllowFormattingCells=None, AllowFormattingColumns=None, AllowFormattingRows=None, AllowInsertingColumns=None, AllowInsertingRows=None, AllowInsertingHyperlinks=None, AllowDeletingColumns=None, AllowDeletingRows=None, AllowSorting=None, AllowFiltering=None, AllowUsingPivotTables=None):
        """Alias for Protect"""
        arguments = [Password, DrawingObjects, Contents, Scenarios, UserInterfaceOnly, AllowFormattingCells, AllowFormattingColumns, AllowFormattingRows, AllowInsertingColumns, AllowInsertingRows, AllowInsertingHyperlinks, AllowDeletingColumns, AllowDeletingRows, AllowSorting, AllowFiltering, AllowUsingPivotTables]
        return self.Protect(*arguments)

    def ResetAllPageBreaks(self):
        self.com_object.ResetAllPageBreaks()

    def resetallpagebreaks(self):
        """Alias for ResetAllPageBreaks"""
        return self.ResetAllPageBreaks()

    def reset_all_page_breaks(self):
        """Alias for ResetAllPageBreaks"""
        return self.ResetAllPageBreaks()

    def SaveAs(self, FileName=None, FileFormat=None, Password=None, WriteResPassword=None, ReadOnlyRecommended=None, CreateBackup=None, AddToMru=None, TextCodepage=None, TextVisualLayout=None, Local=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, FileFormat, Password, WriteResPassword, ReadOnlyRecommended, CreateBackup, AddToMru, TextCodepage, TextVisualLayout, Local]])
        self.com_object.SaveAs(*arguments)

    def saveas(self, FileName=None, FileFormat=None, Password=None, WriteResPassword=None, ReadOnlyRecommended=None, CreateBackup=None, AddToMru=None, TextCodepage=None, TextVisualLayout=None, Local=None):
        """Alias for SaveAs"""
        arguments = [FileName, FileFormat, Password, WriteResPassword, ReadOnlyRecommended, CreateBackup, AddToMru, TextCodepage, TextVisualLayout, Local]
        return self.SaveAs(*arguments)

    def save_as(self, FileName=None, FileFormat=None, Password=None, WriteResPassword=None, ReadOnlyRecommended=None, CreateBackup=None, AddToMru=None, TextCodepage=None, TextVisualLayout=None, Local=None):
        """Alias for SaveAs"""
        arguments = [FileName, FileFormat, Password, WriteResPassword, ReadOnlyRecommended, CreateBackup, AddToMru, TextCodepage, TextVisualLayout, Local]
        return self.SaveAs(*arguments)

    def Scenarios(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        return self.com_object.Scenarios(*arguments)

    def scenarios(self, Index=None):
        """Alias for Scenarios"""
        arguments = [Index]
        return self.Scenarios(*arguments)

    def Select(self, Replace=None):
        arguments = com_arguments([unwrap(a) for a in [Replace]])
        self.com_object.Select(*arguments)

    def select(self, Replace=None):
        """Alias for Select"""
        arguments = [Replace]
        return self.Select(*arguments)

    def SetBackgroundPicture(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        self.com_object.SetBackgroundPicture(*arguments)

    def setbackgroundpicture(self, FileName=None):
        """Alias for SetBackgroundPicture"""
        arguments = [FileName]
        return self.SetBackgroundPicture(*arguments)

    def set_background_picture(self, FileName=None):
        """Alias for SetBackgroundPicture"""
        arguments = [FileName]
        return self.SetBackgroundPicture(*arguments)

    def ShowAllData(self):
        self.com_object.ShowAllData()

    def showalldata(self):
        """Alias for ShowAllData"""
        return self.ShowAllData()

    def show_all_data(self):
        """Alias for ShowAllData"""
        return self.ShowAllData()

    def ShowDataForm(self):
        self.com_object.ShowDataForm()

    def showdataform(self):
        """Alias for ShowDataForm"""
        return self.ShowDataForm()

    def show_data_form(self):
        """Alias for ShowDataForm"""
        return self.ShowDataForm()

    def Unprotect(self, Password=None):
        arguments = com_arguments([unwrap(a) for a in [Password]])
        self.com_object.Unprotect(*arguments)

    def unprotect(self, Password=None):
        """Alias for Unprotect"""
        arguments = [Password]
        return self.Unprotect(*arguments)

    def XmlDataQuery(self, XPath=None, SelectionNamespaces=None, Map=None):
        arguments = com_arguments([unwrap(a) for a in [XPath, SelectionNamespaces, Map]])
        return Range(self.com_object.XmlDataQuery(*arguments))

    def xmldataquery(self, XPath=None, SelectionNamespaces=None, Map=None):
        """Alias for XmlDataQuery"""
        arguments = [XPath, SelectionNamespaces, Map]
        return self.XmlDataQuery(*arguments)

    def xml_data_query(self, XPath=None, SelectionNamespaces=None, Map=None):
        """Alias for XmlDataQuery"""
        arguments = [XPath, SelectionNamespaces, Map]
        return self.XmlDataQuery(*arguments)

    def XmlMapQuery(self, XPath=None, SelectionNamespaces=None, Map=None):
        arguments = com_arguments([unwrap(a) for a in [XPath, SelectionNamespaces, Map]])
        return Range(self.com_object.XmlMapQuery(*arguments))

    def xmlmapquery(self, XPath=None, SelectionNamespaces=None, Map=None):
        """Alias for XmlMapQuery"""
        arguments = [XPath, SelectionNamespaces, Map]
        return self.XmlMapQuery(*arguments)

    def xml_map_query(self, XPath=None, SelectionNamespaces=None, Map=None):
        """Alias for XmlMapQuery"""
        arguments = [XPath, SelectionNamespaces, Map]
        return self.XmlMapQuery(*arguments)


class WorksheetDataConnection:

    def __init__(self, worksheetdataconnection=None):
        self.com_object= worksheetdataconnection

    @property
    def Application(self):
        return Application(self.com_object.Application)

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def CommandText(self):
        return self.com_object.CommandText

    @CommandText.setter
    def CommandText(self, value):
        self.com_object.CommandText = value

    @property
    def commandtext(self):
        """Alias for CommandText"""
        return self.CommandText

    @commandtext.setter
    def commandtext(self, value):
        """Alias for CommandText.setter"""
        self.CommandText = value

    @property
    def command_text(self):
        """Alias for CommandText"""
        return self.CommandText

    @command_text.setter
    def command_text(self, value):
        """Alias for CommandText.setter"""
        self.CommandText = value

    @property
    def CommandType(self):
        return XlCmdType(self.com_object.CommandType)

    @CommandType.setter
    def CommandType(self, value):
        self.com_object.CommandType = value

    @property
    def commandtype(self):
        """Alias for CommandType"""
        return self.CommandType

    @commandtype.setter
    def commandtype(self, value):
        """Alias for CommandType.setter"""
        self.CommandType = value

    @property
    def command_type(self):
        """Alias for CommandType"""
        return self.CommandType

    @command_type.setter
    def command_type(self, value):
        """Alias for CommandType.setter"""
        self.CommandType = value

    @property
    def Connection(self):
        return self.com_object.Connection

    @property
    def connection(self):
        """Alias for Connection"""
        return self.Connection

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class WorksheetFunction:

    def __init__(self, worksheetfunction=None):
        self.com_object= worksheetfunction

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def AccrInt(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7]])
        return self.com_object.AccrInt(*arguments)

    def accrint(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None):
        """Alias for AccrInt"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7]
        return self.AccrInt(*arguments)

    def accr_int(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None):
        """Alias for AccrInt"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7]
        return self.AccrInt(*arguments)

    def AccrIntM(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5]])
        return self.com_object.AccrIntM(*arguments)

    def accrintm(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for AccrIntM"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.AccrIntM(*arguments)

    def accr_int_m(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for AccrIntM"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.AccrIntM(*arguments)

    def Acos(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Acos(*arguments)

    def acos(self, Arg1=None):
        """Alias for Acos"""
        arguments = [Arg1]
        return self.Acos(*arguments)

    def Acosh(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Acosh(*arguments)

    def acosh(self, Arg1=None):
        """Alias for Acosh"""
        arguments = [Arg1]
        return self.Acosh(*arguments)

    def Acot(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Acot(*arguments)

    def acot(self, Arg1=None):
        """Alias for Acot"""
        arguments = [Arg1]
        return self.Acot(*arguments)

    def Acoth(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Acoth(*arguments)

    def acoth(self, Arg1=None):
        """Alias for Acoth"""
        arguments = [Arg1]
        return self.Acoth(*arguments)

    def Aggregate(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Aggregate(*arguments)

    def aggregate(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Aggregate"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Aggregate(*arguments)

    def AmorDegrc(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7]])
        return self.com_object.AmorDegrc(*arguments)

    def amordegrc(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None):
        """Alias for AmorDegrc"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7]
        return self.AmorDegrc(*arguments)

    def amor_degrc(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None):
        """Alias for AmorDegrc"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7]
        return self.AmorDegrc(*arguments)

    def AmorLinc(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7]])
        return self.com_object.AmorLinc(*arguments)

    def amorlinc(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None):
        """Alias for AmorLinc"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7]
        return self.AmorLinc(*arguments)

    def amor_linc(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None):
        """Alias for AmorLinc"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7]
        return self.AmorLinc(*arguments)

    def And(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.And(*arguments)

    def Arabic(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Arabic(*arguments)

    def arabic(self, Arg1=None):
        """Alias for Arabic"""
        arguments = [Arg1]
        return self.Arabic(*arguments)

    def Asc(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Asc(*arguments)

    def asc(self, Arg1=None):
        """Alias for Asc"""
        arguments = [Arg1]
        return self.Asc(*arguments)

    def Asin(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Asin(*arguments)

    def asin(self, Arg1=None):
        """Alias for Asin"""
        arguments = [Arg1]
        return self.Asin(*arguments)

    def Asinh(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Asinh(*arguments)

    def asinh(self, Arg1=None):
        """Alias for Asinh"""
        arguments = [Arg1]
        return self.Asinh(*arguments)

    def Atan2(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Atan2(*arguments)

    def atan2(self, Arg1=None, Arg2=None):
        """Alias for Atan2"""
        arguments = [Arg1, Arg2]
        return self.Atan2(*arguments)

    def Atanh(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Atanh(*arguments)

    def atanh(self, Arg1=None):
        """Alias for Atanh"""
        arguments = [Arg1]
        return self.Atanh(*arguments)

    def AveDev(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.AveDev(*arguments)

    def avedev(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for AveDev"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.AveDev(*arguments)

    def ave_dev(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for AveDev"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.AveDev(*arguments)

    def Average(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Average(*arguments)

    def average(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Average"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Average(*arguments)

    def AverageIf(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.AverageIf(*arguments)

    def averageif(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for AverageIf"""
        arguments = [Arg1, Arg2, Arg3]
        return self.AverageIf(*arguments)

    def average_if(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for AverageIf"""
        arguments = [Arg1, Arg2, Arg3]
        return self.AverageIf(*arguments)

    def AverageIfs(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.AverageIfs(*arguments)

    def averageifs(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for AverageIfs"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.AverageIfs(*arguments)

    def average_ifs(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for AverageIfs"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.AverageIfs(*arguments)

    def BahtText(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.BahtText(*arguments)

    def bahttext(self, Arg1=None):
        """Alias for BahtText"""
        arguments = [Arg1]
        return self.BahtText(*arguments)

    def baht_text(self, Arg1=None):
        """Alias for BahtText"""
        arguments = [Arg1]
        return self.BahtText(*arguments)

    def Base(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Base(*arguments)

    def base(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Base"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Base(*arguments)

    def BesselI(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.BesselI(*arguments)

    def besseli(self, Arg1=None, Arg2=None):
        """Alias for BesselI"""
        arguments = [Arg1, Arg2]
        return self.BesselI(*arguments)

    def bessel_i(self, Arg1=None, Arg2=None):
        """Alias for BesselI"""
        arguments = [Arg1, Arg2]
        return self.BesselI(*arguments)

    def BesselJ(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.BesselJ(*arguments)

    def besselj(self, Arg1=None, Arg2=None):
        """Alias for BesselJ"""
        arguments = [Arg1, Arg2]
        return self.BesselJ(*arguments)

    def bessel_j(self, Arg1=None, Arg2=None):
        """Alias for BesselJ"""
        arguments = [Arg1, Arg2]
        return self.BesselJ(*arguments)

    def BesselK(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.BesselK(*arguments)

    def besselk(self, Arg1=None, Arg2=None):
        """Alias for BesselK"""
        arguments = [Arg1, Arg2]
        return self.BesselK(*arguments)

    def bessel_k(self, Arg1=None, Arg2=None):
        """Alias for BesselK"""
        arguments = [Arg1, Arg2]
        return self.BesselK(*arguments)

    def BesselY(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.BesselY(*arguments)

    def bessely(self, Arg1=None, Arg2=None):
        """Alias for BesselY"""
        arguments = [Arg1, Arg2]
        return self.BesselY(*arguments)

    def bessel_y(self, Arg1=None, Arg2=None):
        """Alias for BesselY"""
        arguments = [Arg1, Arg2]
        return self.BesselY(*arguments)

    def BetaDist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5]])
        return self.com_object.BetaDist(*arguments)

    def betadist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for BetaDist"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.BetaDist(*arguments)

    def beta_dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for BetaDist"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.BetaDist(*arguments)

    def BetaInv(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5]])
        return self.com_object.BetaInv(*arguments)

    def betainv(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for BetaInv"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.BetaInv(*arguments)

    def beta_inv(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for BetaInv"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.BetaInv(*arguments)

    def Beta_Dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]])
        return self.com_object.Beta_Dist(*arguments)

    def beta_dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        """Alias for Beta_Dist"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]
        return self.Beta_Dist(*arguments)

    def beta__dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        """Alias for Beta_Dist"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]
        return self.Beta_Dist(*arguments)

    def Beta_Inv(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5]])
        return self.com_object.Beta_Inv(*arguments)

    def beta_inv(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for Beta_Inv"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.Beta_Inv(*arguments)

    def beta__inv(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for Beta_Inv"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.Beta_Inv(*arguments)

    def Bin2Dec(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Bin2Dec(*arguments)

    def bin2dec(self, Arg1=None):
        """Alias for Bin2Dec"""
        arguments = [Arg1]
        return self.Bin2Dec(*arguments)

    def bin2_dec(self, Arg1=None):
        """Alias for Bin2Dec"""
        arguments = [Arg1]
        return self.Bin2Dec(*arguments)

    def Bin2Hex(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Bin2Hex(*arguments)

    def bin2hex(self, Arg1=None, Arg2=None):
        """Alias for Bin2Hex"""
        arguments = [Arg1, Arg2]
        return self.Bin2Hex(*arguments)

    def bin2_hex(self, Arg1=None, Arg2=None):
        """Alias for Bin2Hex"""
        arguments = [Arg1, Arg2]
        return self.Bin2Hex(*arguments)

    def Bin2Oct(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Bin2Oct(*arguments)

    def bin2oct(self, Arg1=None, Arg2=None):
        """Alias for Bin2Oct"""
        arguments = [Arg1, Arg2]
        return self.Bin2Oct(*arguments)

    def bin2_oct(self, Arg1=None, Arg2=None):
        """Alias for Bin2Oct"""
        arguments = [Arg1, Arg2]
        return self.Bin2Oct(*arguments)

    def BinomDist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.BinomDist(*arguments)

    def binomdist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for BinomDist"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.BinomDist(*arguments)

    def binom_dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for BinomDist"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.BinomDist(*arguments)

    def Binom_Dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.Binom_Dist(*arguments)

    def binom_dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for Binom_Dist"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.Binom_Dist(*arguments)

    def binom__dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for Binom_Dist"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.Binom_Dist(*arguments)

    def Binom_Dist_Range(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.Binom_Dist_Range(*arguments)

    def binom_dist_range(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for Binom_Dist_Range"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.Binom_Dist_Range(*arguments)

    def binom__dist__range(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for Binom_Dist_Range"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.Binom_Dist_Range(*arguments)

    def Binom_Inv(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Binom_Inv(*arguments)

    def binom_inv(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Binom_Inv"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Binom_Inv(*arguments)

    def binom__inv(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Binom_Inv"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Binom_Inv(*arguments)

    def Bitand(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Bitand(*arguments)

    def bitand(self, Arg1=None, Arg2=None):
        """Alias for Bitand"""
        arguments = [Arg1, Arg2]
        return self.Bitand(*arguments)

    def Bitlshift(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Bitlshift(*arguments)

    def bitlshift(self, Arg1=None, Arg2=None):
        """Alias for Bitlshift"""
        arguments = [Arg1, Arg2]
        return self.Bitlshift(*arguments)

    def Bitor(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Bitor(*arguments)

    def bitor(self, Arg1=None, Arg2=None):
        """Alias for Bitor"""
        arguments = [Arg1, Arg2]
        return self.Bitor(*arguments)

    def Bitrshift(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Bitrshift(*arguments)

    def bitrshift(self, Arg1=None, Arg2=None):
        """Alias for Bitrshift"""
        arguments = [Arg1, Arg2]
        return self.Bitrshift(*arguments)

    def Bitxor(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Bitxor(*arguments)

    def bitxor(self, Arg1=None, Arg2=None):
        """Alias for Bitxor"""
        arguments = [Arg1, Arg2]
        return self.Bitxor(*arguments)

    def Ceiling(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Ceiling(*arguments)

    def ceiling(self, Arg1=None, Arg2=None):
        """Alias for Ceiling"""
        arguments = [Arg1, Arg2]
        return self.Ceiling(*arguments)

    def Ceiling_Math(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Ceiling_Math(*arguments)

    def ceiling_math(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Ceiling_Math"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Ceiling_Math(*arguments)

    def ceiling__math(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Ceiling_Math"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Ceiling_Math(*arguments)

    def Ceiling_Precise(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Ceiling_Precise(*arguments)

    def ceiling_precise(self, Arg1=None, Arg2=None):
        """Alias for Ceiling_Precise"""
        arguments = [Arg1, Arg2]
        return self.Ceiling_Precise(*arguments)

    def ceiling__precise(self, Arg1=None, Arg2=None):
        """Alias for Ceiling_Precise"""
        arguments = [Arg1, Arg2]
        return self.Ceiling_Precise(*arguments)

    def ChiDist(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.ChiDist(*arguments)

    def chidist(self, Arg1=None, Arg2=None):
        """Alias for ChiDist"""
        arguments = [Arg1, Arg2]
        return self.ChiDist(*arguments)

    def chi_dist(self, Arg1=None, Arg2=None):
        """Alias for ChiDist"""
        arguments = [Arg1, Arg2]
        return self.ChiDist(*arguments)

    def ChiInv(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.ChiInv(*arguments)

    def chiinv(self, Arg1=None, Arg2=None):
        """Alias for ChiInv"""
        arguments = [Arg1, Arg2]
        return self.ChiInv(*arguments)

    def chi_inv(self, Arg1=None, Arg2=None):
        """Alias for ChiInv"""
        arguments = [Arg1, Arg2]
        return self.ChiInv(*arguments)

    def ChiSq_Dist(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.ChiSq_Dist(*arguments)

    def chisq_dist(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for ChiSq_Dist"""
        arguments = [Arg1, Arg2, Arg3]
        return self.ChiSq_Dist(*arguments)

    def chi_sq__dist(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for ChiSq_Dist"""
        arguments = [Arg1, Arg2, Arg3]
        return self.ChiSq_Dist(*arguments)

    def ChiSq_Dist_RT(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.ChiSq_Dist_RT(*arguments)

    def chisq_dist_rt(self, Arg1=None, Arg2=None):
        """Alias for ChiSq_Dist_RT"""
        arguments = [Arg1, Arg2]
        return self.ChiSq_Dist_RT(*arguments)

    def chi_sq__dist__r_t(self, Arg1=None, Arg2=None):
        """Alias for ChiSq_Dist_RT"""
        arguments = [Arg1, Arg2]
        return self.ChiSq_Dist_RT(*arguments)

    def ChiSq_Inv(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.ChiSq_Inv(*arguments)

    def chisq_inv(self, Arg1=None, Arg2=None):
        """Alias for ChiSq_Inv"""
        arguments = [Arg1, Arg2]
        return self.ChiSq_Inv(*arguments)

    def chi_sq__inv(self, Arg1=None, Arg2=None):
        """Alias for ChiSq_Inv"""
        arguments = [Arg1, Arg2]
        return self.ChiSq_Inv(*arguments)

    def ChiSq_Inv_RT(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.ChiSq_Inv_RT(*arguments)

    def chisq_inv_rt(self, Arg1=None, Arg2=None):
        """Alias for ChiSq_Inv_RT"""
        arguments = [Arg1, Arg2]
        return self.ChiSq_Inv_RT(*arguments)

    def chi_sq__inv__r_t(self, Arg1=None, Arg2=None):
        """Alias for ChiSq_Inv_RT"""
        arguments = [Arg1, Arg2]
        return self.ChiSq_Inv_RT(*arguments)

    def ChiSq_Test(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.ChiSq_Test(*arguments)

    def chisq_test(self, Arg1=None, Arg2=None):
        """Alias for ChiSq_Test"""
        arguments = [Arg1, Arg2]
        return self.ChiSq_Test(*arguments)

    def chi_sq__test(self, Arg1=None, Arg2=None):
        """Alias for ChiSq_Test"""
        arguments = [Arg1, Arg2]
        return self.ChiSq_Test(*arguments)

    def ChiTest(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.ChiTest(*arguments)

    def chitest(self, Arg1=None, Arg2=None):
        """Alias for ChiTest"""
        arguments = [Arg1, Arg2]
        return self.ChiTest(*arguments)

    def chi_test(self, Arg1=None, Arg2=None):
        """Alias for ChiTest"""
        arguments = [Arg1, Arg2]
        return self.ChiTest(*arguments)

    def Choose(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Choose(*arguments)

    def choose(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Choose"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Choose(*arguments)

    def Clean(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Clean(*arguments)

    def clean(self, Arg1=None):
        """Alias for Clean"""
        arguments = [Arg1]
        return self.Clean(*arguments)

    def Combin(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Combin(*arguments)

    def combin(self, Arg1=None, Arg2=None):
        """Alias for Combin"""
        arguments = [Arg1, Arg2]
        return self.Combin(*arguments)

    def Combina(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Combina(*arguments)

    def combina(self, Arg1=None, Arg2=None):
        """Alias for Combina"""
        arguments = [Arg1, Arg2]
        return self.Combina(*arguments)

    def Complex(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Complex(*arguments)

    def complex(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Complex"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Complex(*arguments)

    def Confidence(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Confidence(*arguments)

    def confidence(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Confidence"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Confidence(*arguments)

    def Confidence_Norm(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Confidence_Norm(*arguments)

    def confidence_norm(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Confidence_Norm"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Confidence_Norm(*arguments)

    def confidence__norm(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Confidence_Norm"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Confidence_Norm(*arguments)

    def Confidence_T(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Confidence_T(*arguments)

    def confidence_t(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Confidence_T"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Confidence_T(*arguments)

    def confidence__t(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Confidence_T"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Confidence_T(*arguments)

    def Convert(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Convert(*arguments)

    def convert(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Convert"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Convert(*arguments)

    def Correl(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Correl(*arguments)

    def correl(self, Arg1=None, Arg2=None):
        """Alias for Correl"""
        arguments = [Arg1, Arg2]
        return self.Correl(*arguments)

    def Cosh(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Cosh(*arguments)

    def cosh(self, Arg1=None):
        """Alias for Cosh"""
        arguments = [Arg1]
        return self.Cosh(*arguments)

    def Cot(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Cot(*arguments)

    def cot(self, Arg1=None):
        """Alias for Cot"""
        arguments = [Arg1]
        return self.Cot(*arguments)

    def Coth(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Coth(*arguments)

    def coth(self, Arg1=None):
        """Alias for Coth"""
        arguments = [Arg1]
        return self.Coth(*arguments)

    def Count(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Count(*arguments)

    def count(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Count"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Count(*arguments)

    def CountA(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.CountA(*arguments)

    def counta(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for CountA"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.CountA(*arguments)

    def count_a(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for CountA"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.CountA(*arguments)

    def CountBlank(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.CountBlank(*arguments)

    def countblank(self, Arg1=None):
        """Alias for CountBlank"""
        arguments = [Arg1]
        return self.CountBlank(*arguments)

    def count_blank(self, Arg1=None):
        """Alias for CountBlank"""
        arguments = [Arg1]
        return self.CountBlank(*arguments)

    def CountIf(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.CountIf(*arguments)

    def countif(self, Arg1=None, Arg2=None):
        """Alias for CountIf"""
        arguments = [Arg1, Arg2]
        return self.CountIf(*arguments)

    def count_if(self, Arg1=None, Arg2=None):
        """Alias for CountIf"""
        arguments = [Arg1, Arg2]
        return self.CountIf(*arguments)

    def CountIfs(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.CountIfs(*arguments)

    def countifs(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for CountIfs"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.CountIfs(*arguments)

    def count_ifs(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for CountIfs"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.CountIfs(*arguments)

    def CoupDayBs(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.CoupDayBs(*arguments)

    def coupdaybs(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for CoupDayBs"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.CoupDayBs(*arguments)

    def coup_day_bs(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for CoupDayBs"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.CoupDayBs(*arguments)

    def CoupDays(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.CoupDays(*arguments)

    def coupdays(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for CoupDays"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.CoupDays(*arguments)

    def coup_days(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for CoupDays"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.CoupDays(*arguments)

    def CoupDaysNc(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.CoupDaysNc(*arguments)

    def coupdaysnc(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for CoupDaysNc"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.CoupDaysNc(*arguments)

    def coup_days_nc(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for CoupDaysNc"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.CoupDaysNc(*arguments)

    def CoupNcd(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.CoupNcd(*arguments)

    def coupncd(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for CoupNcd"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.CoupNcd(*arguments)

    def coup_ncd(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for CoupNcd"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.CoupNcd(*arguments)

    def CoupNum(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.CoupNum(*arguments)

    def coupnum(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for CoupNum"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.CoupNum(*arguments)

    def coup_num(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for CoupNum"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.CoupNum(*arguments)

    def Covar(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Covar(*arguments)

    def covar(self, Arg1=None, Arg2=None):
        """Alias for Covar"""
        arguments = [Arg1, Arg2]
        return self.Covar(*arguments)

    def Covariance_P(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Covariance_P(*arguments)

    def covariance_p(self, Arg1=None, Arg2=None):
        """Alias for Covariance_P"""
        arguments = [Arg1, Arg2]
        return self.Covariance_P(*arguments)

    def covariance__p(self, Arg1=None, Arg2=None):
        """Alias for Covariance_P"""
        arguments = [Arg1, Arg2]
        return self.Covariance_P(*arguments)

    def Covariance_S(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Covariance_S(*arguments)

    def covariance_s(self, Arg1=None, Arg2=None):
        """Alias for Covariance_S"""
        arguments = [Arg1, Arg2]
        return self.Covariance_S(*arguments)

    def covariance__s(self, Arg1=None, Arg2=None):
        """Alias for Covariance_S"""
        arguments = [Arg1, Arg2]
        return self.Covariance_S(*arguments)

    def CritBinom(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.CritBinom(*arguments)

    def critbinom(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for CritBinom"""
        arguments = [Arg1, Arg2, Arg3]
        return self.CritBinom(*arguments)

    def crit_binom(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for CritBinom"""
        arguments = [Arg1, Arg2, Arg3]
        return self.CritBinom(*arguments)

    def Csc(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Csc(*arguments)

    def csc(self, Arg1=None):
        """Alias for Csc"""
        arguments = [Arg1]
        return self.Csc(*arguments)

    def Csch(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Csch(*arguments)

    def csch(self, Arg1=None):
        """Alias for Csch"""
        arguments = [Arg1]
        return self.Csch(*arguments)

    def CumIPmt(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]])
        return self.com_object.CumIPmt(*arguments)

    def cumipmt(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        """Alias for CumIPmt"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]
        return self.CumIPmt(*arguments)

    def cum_i_pmt(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        """Alias for CumIPmt"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]
        return self.CumIPmt(*arguments)

    def CumPrinc(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]])
        return self.com_object.CumPrinc(*arguments)

    def cumprinc(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        """Alias for CumPrinc"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]
        return self.CumPrinc(*arguments)

    def cum_princ(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        """Alias for CumPrinc"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]
        return self.CumPrinc(*arguments)

    def DAverage(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.DAverage(*arguments)

    def daverage(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for DAverage"""
        arguments = [Arg1, Arg2, Arg3]
        return self.DAverage(*arguments)

    def d_average(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for DAverage"""
        arguments = [Arg1, Arg2, Arg3]
        return self.DAverage(*arguments)

    def Days(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Days(*arguments)

    def days(self, Arg1=None, Arg2=None):
        """Alias for Days"""
        arguments = [Arg1, Arg2]
        return self.Days(*arguments)

    def Days360(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Days360(*arguments)

    def days360(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Days360"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Days360(*arguments)

    def Db(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5]])
        return self.com_object.Db(*arguments)

    def db(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for Db"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.Db(*arguments)

    def Dbcs(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Dbcs(*arguments)

    def dbcs(self, Arg1=None):
        """Alias for Dbcs"""
        arguments = [Arg1]
        return self.Dbcs(*arguments)

    def DCount(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.DCount(*arguments)

    def dcount(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for DCount"""
        arguments = [Arg1, Arg2, Arg3]
        return self.DCount(*arguments)

    def d_count(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for DCount"""
        arguments = [Arg1, Arg2, Arg3]
        return self.DCount(*arguments)

    def DCountA(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.DCountA(*arguments)

    def dcounta(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for DCountA"""
        arguments = [Arg1, Arg2, Arg3]
        return self.DCountA(*arguments)

    def d_count_a(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for DCountA"""
        arguments = [Arg1, Arg2, Arg3]
        return self.DCountA(*arguments)

    def Ddb(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5]])
        return self.com_object.Ddb(*arguments)

    def ddb(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for Ddb"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.Ddb(*arguments)

    def Dec2Bin(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Dec2Bin(*arguments)

    def dec2bin(self, Arg1=None, Arg2=None):
        """Alias for Dec2Bin"""
        arguments = [Arg1, Arg2]
        return self.Dec2Bin(*arguments)

    def dec2_bin(self, Arg1=None, Arg2=None):
        """Alias for Dec2Bin"""
        arguments = [Arg1, Arg2]
        return self.Dec2Bin(*arguments)

    def Dec2Hex(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Dec2Hex(*arguments)

    def dec2hex(self, Arg1=None, Arg2=None):
        """Alias for Dec2Hex"""
        arguments = [Arg1, Arg2]
        return self.Dec2Hex(*arguments)

    def dec2_hex(self, Arg1=None, Arg2=None):
        """Alias for Dec2Hex"""
        arguments = [Arg1, Arg2]
        return self.Dec2Hex(*arguments)

    def Dec2Oct(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Dec2Oct(*arguments)

    def dec2oct(self, Arg1=None, Arg2=None):
        """Alias for Dec2Oct"""
        arguments = [Arg1, Arg2]
        return self.Dec2Oct(*arguments)

    def dec2_oct(self, Arg1=None, Arg2=None):
        """Alias for Dec2Oct"""
        arguments = [Arg1, Arg2]
        return self.Dec2Oct(*arguments)

    def Decimal(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Decimal(*arguments)

    def decimal(self, Arg1=None, Arg2=None):
        """Alias for Decimal"""
        arguments = [Arg1, Arg2]
        return self.Decimal(*arguments)

    def Degrees(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Degrees(*arguments)

    def degrees(self, Arg1=None):
        """Alias for Degrees"""
        arguments = [Arg1]
        return self.Degrees(*arguments)

    def Delta(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Delta(*arguments)

    def delta(self, Arg1=None, Arg2=None):
        """Alias for Delta"""
        arguments = [Arg1, Arg2]
        return self.Delta(*arguments)

    def DevSq(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.DevSq(*arguments)

    def devsq(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for DevSq"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.DevSq(*arguments)

    def dev_sq(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for DevSq"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.DevSq(*arguments)

    def DGet(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.DGet(*arguments)

    def dget(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for DGet"""
        arguments = [Arg1, Arg2, Arg3]
        return self.DGet(*arguments)

    def d_get(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for DGet"""
        arguments = [Arg1, Arg2, Arg3]
        return self.DGet(*arguments)

    def Disc(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5]])
        return self.com_object.Disc(*arguments)

    def disc(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for Disc"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.Disc(*arguments)

    def DMax(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.DMax(*arguments)

    def dmax(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for DMax"""
        arguments = [Arg1, Arg2, Arg3]
        return self.DMax(*arguments)

    def d_max(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for DMax"""
        arguments = [Arg1, Arg2, Arg3]
        return self.DMax(*arguments)

    def DMin(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.DMin(*arguments)

    def dmin(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for DMin"""
        arguments = [Arg1, Arg2, Arg3]
        return self.DMin(*arguments)

    def d_min(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for DMin"""
        arguments = [Arg1, Arg2, Arg3]
        return self.DMin(*arguments)

    def Dollar(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Dollar(*arguments)

    def dollar(self, Arg1=None, Arg2=None):
        """Alias for Dollar"""
        arguments = [Arg1, Arg2]
        return self.Dollar(*arguments)

    def DollarDe(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.DollarDe(*arguments)

    def dollarde(self, Arg1=None, Arg2=None):
        """Alias for DollarDe"""
        arguments = [Arg1, Arg2]
        return self.DollarDe(*arguments)

    def dollar_de(self, Arg1=None, Arg2=None):
        """Alias for DollarDe"""
        arguments = [Arg1, Arg2]
        return self.DollarDe(*arguments)

    def DollarFr(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.DollarFr(*arguments)

    def dollarfr(self, Arg1=None, Arg2=None):
        """Alias for DollarFr"""
        arguments = [Arg1, Arg2]
        return self.DollarFr(*arguments)

    def dollar_fr(self, Arg1=None, Arg2=None):
        """Alias for DollarFr"""
        arguments = [Arg1, Arg2]
        return self.DollarFr(*arguments)

    def DProduct(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.DProduct(*arguments)

    def dproduct(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for DProduct"""
        arguments = [Arg1, Arg2, Arg3]
        return self.DProduct(*arguments)

    def d_product(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for DProduct"""
        arguments = [Arg1, Arg2, Arg3]
        return self.DProduct(*arguments)

    def DStDev(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.DStDev(*arguments)

    def dstdev(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for DStDev"""
        arguments = [Arg1, Arg2, Arg3]
        return self.DStDev(*arguments)

    def d_st_dev(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for DStDev"""
        arguments = [Arg1, Arg2, Arg3]
        return self.DStDev(*arguments)

    def DStDevP(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.DStDevP(*arguments)

    def dstdevp(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for DStDevP"""
        arguments = [Arg1, Arg2, Arg3]
        return self.DStDevP(*arguments)

    def d_st_dev_p(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for DStDevP"""
        arguments = [Arg1, Arg2, Arg3]
        return self.DStDevP(*arguments)

    def DSum(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.DSum(*arguments)

    def dsum(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for DSum"""
        arguments = [Arg1, Arg2, Arg3]
        return self.DSum(*arguments)

    def d_sum(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for DSum"""
        arguments = [Arg1, Arg2, Arg3]
        return self.DSum(*arguments)

    def Duration(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]])
        return self.com_object.Duration(*arguments)

    def duration(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        """Alias for Duration"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]
        return self.Duration(*arguments)

    def DVar(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.DVar(*arguments)

    def dvar(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for DVar"""
        arguments = [Arg1, Arg2, Arg3]
        return self.DVar(*arguments)

    def d_var(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for DVar"""
        arguments = [Arg1, Arg2, Arg3]
        return self.DVar(*arguments)

    def DVarP(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.DVarP(*arguments)

    def dvarp(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for DVarP"""
        arguments = [Arg1, Arg2, Arg3]
        return self.DVarP(*arguments)

    def d_var_p(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for DVarP"""
        arguments = [Arg1, Arg2, Arg3]
        return self.DVarP(*arguments)

    def EDate(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.EDate(*arguments)

    def edate(self, Arg1=None, Arg2=None):
        """Alias for EDate"""
        arguments = [Arg1, Arg2]
        return self.EDate(*arguments)

    def e_date(self, Arg1=None, Arg2=None):
        """Alias for EDate"""
        arguments = [Arg1, Arg2]
        return self.EDate(*arguments)

    def Effect(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Effect(*arguments)

    def effect(self, Arg1=None, Arg2=None):
        """Alias for Effect"""
        arguments = [Arg1, Arg2]
        return self.Effect(*arguments)

    def EncodeUrl(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.EncodeUrl(*arguments)

    def encodeurl(self, Arg1=None):
        """Alias for EncodeUrl"""
        arguments = [Arg1]
        return self.EncodeUrl(*arguments)

    def encode_url(self, Arg1=None):
        """Alias for EncodeUrl"""
        arguments = [Arg1]
        return self.EncodeUrl(*arguments)

    def EoMonth(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.EoMonth(*arguments)

    def eomonth(self, Arg1=None, Arg2=None):
        """Alias for EoMonth"""
        arguments = [Arg1, Arg2]
        return self.EoMonth(*arguments)

    def eo_month(self, Arg1=None, Arg2=None):
        """Alias for EoMonth"""
        arguments = [Arg1, Arg2]
        return self.EoMonth(*arguments)

    def Erf(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Erf(*arguments)

    def erf(self, Arg1=None, Arg2=None):
        """Alias for Erf"""
        arguments = [Arg1, Arg2]
        return self.Erf(*arguments)

    def ErfC(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.ErfC(*arguments)

    def erfc(self, Arg1=None, Arg2=None):
        """Alias for ErfC"""
        arguments = [Arg1, Arg2]
        return self.ErfC(*arguments)

    def erf_c(self, Arg1=None, Arg2=None):
        """Alias for ErfC"""
        arguments = [Arg1, Arg2]
        return self.ErfC(*arguments)

    def ErfC_Precise(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.ErfC_Precise(*arguments)

    def erfc_precise(self, Arg1=None):
        """Alias for ErfC_Precise"""
        arguments = [Arg1]
        return self.ErfC_Precise(*arguments)

    def erf_c__precise(self, Arg1=None):
        """Alias for ErfC_Precise"""
        arguments = [Arg1]
        return self.ErfC_Precise(*arguments)

    def Erf_Precise(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Erf_Precise(*arguments)

    def erf_precise(self, Arg1=None):
        """Alias for Erf_Precise"""
        arguments = [Arg1]
        return self.Erf_Precise(*arguments)

    def erf__precise(self, Arg1=None):
        """Alias for Erf_Precise"""
        arguments = [Arg1]
        return self.Erf_Precise(*arguments)

    def Even(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Even(*arguments)

    def even(self, Arg1=None):
        """Alias for Even"""
        arguments = [Arg1]
        return self.Even(*arguments)

    def ExponDist(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.ExponDist(*arguments)

    def expondist(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for ExponDist"""
        arguments = [Arg1, Arg2, Arg3]
        return self.ExponDist(*arguments)

    def expon_dist(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for ExponDist"""
        arguments = [Arg1, Arg2, Arg3]
        return self.ExponDist(*arguments)

    def Expon_Dist(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Expon_Dist(*arguments)

    def expon_dist(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Expon_Dist"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Expon_Dist(*arguments)

    def expon__dist(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Expon_Dist"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Expon_Dist(*arguments)

    def Fact(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Fact(*arguments)

    def fact(self, Arg1=None):
        """Alias for Fact"""
        arguments = [Arg1]
        return self.Fact(*arguments)

    def FactDouble(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.FactDouble(*arguments)

    def factdouble(self, Arg1=None):
        """Alias for FactDouble"""
        arguments = [Arg1]
        return self.FactDouble(*arguments)

    def fact_double(self, Arg1=None):
        """Alias for FactDouble"""
        arguments = [Arg1]
        return self.FactDouble(*arguments)

    def FDist(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.FDist(*arguments)

    def fdist(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for FDist"""
        arguments = [Arg1, Arg2, Arg3]
        return self.FDist(*arguments)

    def f_dist(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for FDist"""
        arguments = [Arg1, Arg2, Arg3]
        return self.FDist(*arguments)

    def FilterXML(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.FilterXML(*arguments)

    def filterxml(self, Arg1=None, Arg2=None):
        """Alias for FilterXML"""
        arguments = [Arg1, Arg2]
        return self.FilterXML(*arguments)

    def filter_x_m_l(self, Arg1=None, Arg2=None):
        """Alias for FilterXML"""
        arguments = [Arg1, Arg2]
        return self.FilterXML(*arguments)

    def Find(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Find(*arguments)

    def find(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Find"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Find(*arguments)

    def FindB(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.FindB(*arguments)

    def findb(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for FindB"""
        arguments = [Arg1, Arg2, Arg3]
        return self.FindB(*arguments)

    def find_b(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for FindB"""
        arguments = [Arg1, Arg2, Arg3]
        return self.FindB(*arguments)

    def FInv(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.FInv(*arguments)

    def finv(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for FInv"""
        arguments = [Arg1, Arg2, Arg3]
        return self.FInv(*arguments)

    def f_inv(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for FInv"""
        arguments = [Arg1, Arg2, Arg3]
        return self.FInv(*arguments)

    def Fisher(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Fisher(*arguments)

    def fisher(self, Arg1=None):
        """Alias for Fisher"""
        arguments = [Arg1]
        return self.Fisher(*arguments)

    def FisherInv(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.FisherInv(*arguments)

    def fisherinv(self, Arg1=None):
        """Alias for FisherInv"""
        arguments = [Arg1]
        return self.FisherInv(*arguments)

    def fisher_inv(self, Arg1=None):
        """Alias for FisherInv"""
        arguments = [Arg1]
        return self.FisherInv(*arguments)

    def Fixed(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Fixed(*arguments)

    def fixed(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Fixed"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Fixed(*arguments)

    def Floor(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Floor(*arguments)

    def floor(self, Arg1=None, Arg2=None):
        """Alias for Floor"""
        arguments = [Arg1, Arg2]
        return self.Floor(*arguments)

    def Floor_Math(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Floor_Math(*arguments)

    def floor_math(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Floor_Math"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Floor_Math(*arguments)

    def floor__math(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Floor_Math"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Floor_Math(*arguments)

    def Floor_Precise(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Floor_Precise(*arguments)

    def floor_precise(self, Arg1=None, Arg2=None):
        """Alias for Floor_Precise"""
        arguments = [Arg1, Arg2]
        return self.Floor_Precise(*arguments)

    def floor__precise(self, Arg1=None, Arg2=None):
        """Alias for Floor_Precise"""
        arguments = [Arg1, Arg2]
        return self.Floor_Precise(*arguments)

    def Forecast(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Forecast(*arguments)

    def forecast(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Forecast"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Forecast(*arguments)

    def Forecast_ETS(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]])
        return self.com_object.Forecast_ETS(*arguments)

    def forecast_ets(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        """Alias for Forecast_ETS"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]
        return self.Forecast_ETS(*arguments)

    def forecast__e_t_s(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        """Alias for Forecast_ETS"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]
        return self.Forecast_ETS(*arguments)

    def Forecast_ETS_ConfInt(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7]])
        return self.com_object.Forecast_ETS_ConfInt(*arguments)

    def forecast_ets_confint(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None):
        """Alias for Forecast_ETS_ConfInt"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7]
        return self.Forecast_ETS_ConfInt(*arguments)

    def forecast__e_t_s__conf_int(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None):
        """Alias for Forecast_ETS_ConfInt"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7]
        return self.Forecast_ETS_ConfInt(*arguments)

    def Forecast_ETS_Seasonality(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.Forecast_ETS_Seasonality(*arguments)

    def forecast_ets_seasonality(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for Forecast_ETS_Seasonality"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.Forecast_ETS_Seasonality(*arguments)

    def forecast__e_t_s__seasonality(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for Forecast_ETS_Seasonality"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.Forecast_ETS_Seasonality(*arguments)

    def Forecast_ETS_STAT(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]])
        return self.com_object.Forecast_ETS_STAT(*arguments)

    def forecast_ets_stat(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        """Alias for Forecast_ETS_STAT"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]
        return self.Forecast_ETS_STAT(*arguments)

    def forecast__e_t_s__s_t_a_t(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        """Alias for Forecast_ETS_STAT"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]
        return self.Forecast_ETS_STAT(*arguments)

    def Forecast_Linear(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Forecast_Linear(*arguments)

    def forecast_linear(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Forecast_Linear"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Forecast_Linear(*arguments)

    def forecast__linear(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Forecast_Linear"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Forecast_Linear(*arguments)

    def Frequency(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Frequency(*arguments)

    def frequency(self, Arg1=None, Arg2=None):
        """Alias for Frequency"""
        arguments = [Arg1, Arg2]
        return self.Frequency(*arguments)

    def FTest(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.FTest(*arguments)

    def ftest(self, Arg1=None, Arg2=None):
        """Alias for FTest"""
        arguments = [Arg1, Arg2]
        return self.FTest(*arguments)

    def f_test(self, Arg1=None, Arg2=None):
        """Alias for FTest"""
        arguments = [Arg1, Arg2]
        return self.FTest(*arguments)

    def Fv(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5]])
        return self.com_object.Fv(*arguments)

    def fv(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for Fv"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.Fv(*arguments)

    def FVSchedule(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.FVSchedule(*arguments)

    def fvschedule(self, Arg1=None, Arg2=None):
        """Alias for FVSchedule"""
        arguments = [Arg1, Arg2]
        return self.FVSchedule(*arguments)

    def f_v_schedule(self, Arg1=None, Arg2=None):
        """Alias for FVSchedule"""
        arguments = [Arg1, Arg2]
        return self.FVSchedule(*arguments)

    def F_Dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.F_Dist(*arguments)

    def f_dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for F_Dist"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.F_Dist(*arguments)

    def f__dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for F_Dist"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.F_Dist(*arguments)

    def F_Dist_RT(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.F_Dist_RT(*arguments)

    def f_dist_rt(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for F_Dist_RT"""
        arguments = [Arg1, Arg2, Arg3]
        return self.F_Dist_RT(*arguments)

    def f__dist__r_t(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for F_Dist_RT"""
        arguments = [Arg1, Arg2, Arg3]
        return self.F_Dist_RT(*arguments)

    def F_Inv(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.F_Inv(*arguments)

    def f_inv(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for F_Inv"""
        arguments = [Arg1, Arg2, Arg3]
        return self.F_Inv(*arguments)

    def f__inv(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for F_Inv"""
        arguments = [Arg1, Arg2, Arg3]
        return self.F_Inv(*arguments)

    def F_Inv_RT(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.F_Inv_RT(*arguments)

    def f_inv_rt(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for F_Inv_RT"""
        arguments = [Arg1, Arg2, Arg3]
        return self.F_Inv_RT(*arguments)

    def f__inv__r_t(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for F_Inv_RT"""
        arguments = [Arg1, Arg2, Arg3]
        return self.F_Inv_RT(*arguments)

    def F_Test(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.F_Test(*arguments)

    def f_test(self, Arg1=None, Arg2=None):
        """Alias for F_Test"""
        arguments = [Arg1, Arg2]
        return self.F_Test(*arguments)

    def f__test(self, Arg1=None, Arg2=None):
        """Alias for F_Test"""
        arguments = [Arg1, Arg2]
        return self.F_Test(*arguments)

    def Gamma(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Gamma(*arguments)

    def gamma(self, Arg1=None):
        """Alias for Gamma"""
        arguments = [Arg1]
        return self.Gamma(*arguments)

    def GammaDist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.GammaDist(*arguments)

    def gammadist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for GammaDist"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.GammaDist(*arguments)

    def gamma_dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for GammaDist"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.GammaDist(*arguments)

    def GammaInv(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.GammaInv(*arguments)

    def gammainv(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for GammaInv"""
        arguments = [Arg1, Arg2, Arg3]
        return self.GammaInv(*arguments)

    def gamma_inv(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for GammaInv"""
        arguments = [Arg1, Arg2, Arg3]
        return self.GammaInv(*arguments)

    def GammaLn(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.GammaLn(*arguments)

    def gammaln(self, Arg1=None):
        """Alias for GammaLn"""
        arguments = [Arg1]
        return self.GammaLn(*arguments)

    def gamma_ln(self, Arg1=None):
        """Alias for GammaLn"""
        arguments = [Arg1]
        return self.GammaLn(*arguments)

    def GammaLn_Precise(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.GammaLn_Precise(*arguments)

    def gammaln_precise(self, Arg1=None):
        """Alias for GammaLn_Precise"""
        arguments = [Arg1]
        return self.GammaLn_Precise(*arguments)

    def gamma_ln__precise(self, Arg1=None):
        """Alias for GammaLn_Precise"""
        arguments = [Arg1]
        return self.GammaLn_Precise(*arguments)

    def Gamma_Dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.Gamma_Dist(*arguments)

    def gamma_dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for Gamma_Dist"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.Gamma_Dist(*arguments)

    def gamma__dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for Gamma_Dist"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.Gamma_Dist(*arguments)

    def Gamma_Inv(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Gamma_Inv(*arguments)

    def gamma_inv(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Gamma_Inv"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Gamma_Inv(*arguments)

    def gamma__inv(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Gamma_Inv"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Gamma_Inv(*arguments)

    def Gauss(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Gauss(*arguments)

    def gauss(self, Arg1=None):
        """Alias for Gauss"""
        arguments = [Arg1]
        return self.Gauss(*arguments)

    def Gcd(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Gcd(*arguments)

    def gcd(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Gcd"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Gcd(*arguments)

    def GeoMean(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.GeoMean(*arguments)

    def geomean(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for GeoMean"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.GeoMean(*arguments)

    def geo_mean(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for GeoMean"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.GeoMean(*arguments)

    def GeStep(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.GeStep(*arguments)

    def gestep(self, Arg1=None, Arg2=None):
        """Alias for GeStep"""
        arguments = [Arg1, Arg2]
        return self.GeStep(*arguments)

    def ge_step(self, Arg1=None, Arg2=None):
        """Alias for GeStep"""
        arguments = [Arg1, Arg2]
        return self.GeStep(*arguments)

    def Growth(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.Growth(*arguments)

    def growth(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for Growth"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.Growth(*arguments)

    def HarMean(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.HarMean(*arguments)

    def harmean(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for HarMean"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.HarMean(*arguments)

    def har_mean(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for HarMean"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.HarMean(*arguments)

    def Hex2Bin(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Hex2Bin(*arguments)

    def hex2bin(self, Arg1=None, Arg2=None):
        """Alias for Hex2Bin"""
        arguments = [Arg1, Arg2]
        return self.Hex2Bin(*arguments)

    def hex2_bin(self, Arg1=None, Arg2=None):
        """Alias for Hex2Bin"""
        arguments = [Arg1, Arg2]
        return self.Hex2Bin(*arguments)

    def Hex2Dec(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Hex2Dec(*arguments)

    def hex2dec(self, Arg1=None):
        """Alias for Hex2Dec"""
        arguments = [Arg1]
        return self.Hex2Dec(*arguments)

    def hex2_dec(self, Arg1=None):
        """Alias for Hex2Dec"""
        arguments = [Arg1]
        return self.Hex2Dec(*arguments)

    def Hex2Oct(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Hex2Oct(*arguments)

    def hex2oct(self, Arg1=None, Arg2=None):
        """Alias for Hex2Oct"""
        arguments = [Arg1, Arg2]
        return self.Hex2Oct(*arguments)

    def hex2_oct(self, Arg1=None, Arg2=None):
        """Alias for Hex2Oct"""
        arguments = [Arg1, Arg2]
        return self.Hex2Oct(*arguments)

    def HLookup(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.HLookup(*arguments)

    def hlookup(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for HLookup"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.HLookup(*arguments)

    def h_lookup(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for HLookup"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.HLookup(*arguments)

    def HypGeomDist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.HypGeomDist(*arguments)

    def hypgeomdist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for HypGeomDist"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.HypGeomDist(*arguments)

    def hyp_geom_dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for HypGeomDist"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.HypGeomDist(*arguments)

    def HypGeom_Dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5]])
        return self.com_object.HypGeom_Dist(*arguments)

    def hypgeom_dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for HypGeom_Dist"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.HypGeom_Dist(*arguments)

    def hyp_geom__dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for HypGeom_Dist"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.HypGeom_Dist(*arguments)

    def IfError(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.IfError(*arguments)

    def iferror(self, Arg1=None, Arg2=None):
        """Alias for IfError"""
        arguments = [Arg1, Arg2]
        return self.IfError(*arguments)

    def if_error(self, Arg1=None, Arg2=None):
        """Alias for IfError"""
        arguments = [Arg1, Arg2]
        return self.IfError(*arguments)

    def IfNa(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.IfNa(*arguments)

    def ifna(self, Arg1=None, Arg2=None):
        """Alias for IfNa"""
        arguments = [Arg1, Arg2]
        return self.IfNa(*arguments)

    def if_na(self, Arg1=None, Arg2=None):
        """Alias for IfNa"""
        arguments = [Arg1, Arg2]
        return self.IfNa(*arguments)

    def ImAbs(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.ImAbs(*arguments)

    def imabs(self, Arg1=None):
        """Alias for ImAbs"""
        arguments = [Arg1]
        return self.ImAbs(*arguments)

    def im_abs(self, Arg1=None):
        """Alias for ImAbs"""
        arguments = [Arg1]
        return self.ImAbs(*arguments)

    def Imaginary(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Imaginary(*arguments)

    def imaginary(self, Arg1=None):
        """Alias for Imaginary"""
        arguments = [Arg1]
        return self.Imaginary(*arguments)

    def ImArgument(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.ImArgument(*arguments)

    def imargument(self, Arg1=None):
        """Alias for ImArgument"""
        arguments = [Arg1]
        return self.ImArgument(*arguments)

    def im_argument(self, Arg1=None):
        """Alias for ImArgument"""
        arguments = [Arg1]
        return self.ImArgument(*arguments)

    def ImConjugate(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.ImConjugate(*arguments)

    def imconjugate(self, Arg1=None):
        """Alias for ImConjugate"""
        arguments = [Arg1]
        return self.ImConjugate(*arguments)

    def im_conjugate(self, Arg1=None):
        """Alias for ImConjugate"""
        arguments = [Arg1]
        return self.ImConjugate(*arguments)

    def ImCos(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.ImCos(*arguments)

    def imcos(self, Arg1=None):
        """Alias for ImCos"""
        arguments = [Arg1]
        return self.ImCos(*arguments)

    def im_cos(self, Arg1=None):
        """Alias for ImCos"""
        arguments = [Arg1]
        return self.ImCos(*arguments)

    def ImCosh(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.ImCosh(*arguments)

    def imcosh(self, Arg1=None):
        """Alias for ImCosh"""
        arguments = [Arg1]
        return self.ImCosh(*arguments)

    def im_cosh(self, Arg1=None):
        """Alias for ImCosh"""
        arguments = [Arg1]
        return self.ImCosh(*arguments)

    def ImCot(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.ImCot(*arguments)

    def imcot(self, Arg1=None):
        """Alias for ImCot"""
        arguments = [Arg1]
        return self.ImCot(*arguments)

    def im_cot(self, Arg1=None):
        """Alias for ImCot"""
        arguments = [Arg1]
        return self.ImCot(*arguments)

    def ImCsc(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.ImCsc(*arguments)

    def imcsc(self, Arg1=None):
        """Alias for ImCsc"""
        arguments = [Arg1]
        return self.ImCsc(*arguments)

    def im_csc(self, Arg1=None):
        """Alias for ImCsc"""
        arguments = [Arg1]
        return self.ImCsc(*arguments)

    def ImCsch(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.ImCsch(*arguments)

    def imcsch(self, Arg1=None):
        """Alias for ImCsch"""
        arguments = [Arg1]
        return self.ImCsch(*arguments)

    def im_csch(self, Arg1=None):
        """Alias for ImCsch"""
        arguments = [Arg1]
        return self.ImCsch(*arguments)

    def ImDiv(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.ImDiv(*arguments)

    def imdiv(self, Arg1=None, Arg2=None):
        """Alias for ImDiv"""
        arguments = [Arg1, Arg2]
        return self.ImDiv(*arguments)

    def im_div(self, Arg1=None, Arg2=None):
        """Alias for ImDiv"""
        arguments = [Arg1, Arg2]
        return self.ImDiv(*arguments)

    def ImExp(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.ImExp(*arguments)

    def imexp(self, Arg1=None):
        """Alias for ImExp"""
        arguments = [Arg1]
        return self.ImExp(*arguments)

    def im_exp(self, Arg1=None):
        """Alias for ImExp"""
        arguments = [Arg1]
        return self.ImExp(*arguments)

    def ImLn(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.ImLn(*arguments)

    def imln(self, Arg1=None):
        """Alias for ImLn"""
        arguments = [Arg1]
        return self.ImLn(*arguments)

    def im_ln(self, Arg1=None):
        """Alias for ImLn"""
        arguments = [Arg1]
        return self.ImLn(*arguments)

    def ImLog10(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.ImLog10(*arguments)

    def imlog10(self, Arg1=None):
        """Alias for ImLog10"""
        arguments = [Arg1]
        return self.ImLog10(*arguments)

    def im_log10(self, Arg1=None):
        """Alias for ImLog10"""
        arguments = [Arg1]
        return self.ImLog10(*arguments)

    def ImLog2(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.ImLog2(*arguments)

    def imlog2(self, Arg1=None):
        """Alias for ImLog2"""
        arguments = [Arg1]
        return self.ImLog2(*arguments)

    def im_log2(self, Arg1=None):
        """Alias for ImLog2"""
        arguments = [Arg1]
        return self.ImLog2(*arguments)

    def ImPower(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.ImPower(*arguments)

    def impower(self, Arg1=None, Arg2=None):
        """Alias for ImPower"""
        arguments = [Arg1, Arg2]
        return self.ImPower(*arguments)

    def im_power(self, Arg1=None, Arg2=None):
        """Alias for ImPower"""
        arguments = [Arg1, Arg2]
        return self.ImPower(*arguments)

    def ImProduct(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.ImProduct(*arguments)

    def improduct(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for ImProduct"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.ImProduct(*arguments)

    def im_product(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for ImProduct"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.ImProduct(*arguments)

    def ImReal(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.ImReal(*arguments)

    def imreal(self, Arg1=None):
        """Alias for ImReal"""
        arguments = [Arg1]
        return self.ImReal(*arguments)

    def im_real(self, Arg1=None):
        """Alias for ImReal"""
        arguments = [Arg1]
        return self.ImReal(*arguments)

    def ImSec(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.ImSec(*arguments)

    def imsec(self, Arg1=None):
        """Alias for ImSec"""
        arguments = [Arg1]
        return self.ImSec(*arguments)

    def im_sec(self, Arg1=None):
        """Alias for ImSec"""
        arguments = [Arg1]
        return self.ImSec(*arguments)

    def ImSech(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.ImSech(*arguments)

    def imsech(self, Arg1=None):
        """Alias for ImSech"""
        arguments = [Arg1]
        return self.ImSech(*arguments)

    def im_sech(self, Arg1=None):
        """Alias for ImSech"""
        arguments = [Arg1]
        return self.ImSech(*arguments)

    def ImSin(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.ImSin(*arguments)

    def imsin(self, Arg1=None):
        """Alias for ImSin"""
        arguments = [Arg1]
        return self.ImSin(*arguments)

    def im_sin(self, Arg1=None):
        """Alias for ImSin"""
        arguments = [Arg1]
        return self.ImSin(*arguments)

    def ImSinh(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.ImSinh(*arguments)

    def imsinh(self, Arg1=None):
        """Alias for ImSinh"""
        arguments = [Arg1]
        return self.ImSinh(*arguments)

    def im_sinh(self, Arg1=None):
        """Alias for ImSinh"""
        arguments = [Arg1]
        return self.ImSinh(*arguments)

    def ImSqrt(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.ImSqrt(*arguments)

    def imsqrt(self, Arg1=None):
        """Alias for ImSqrt"""
        arguments = [Arg1]
        return self.ImSqrt(*arguments)

    def im_sqrt(self, Arg1=None):
        """Alias for ImSqrt"""
        arguments = [Arg1]
        return self.ImSqrt(*arguments)

    def ImSub(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.ImSub(*arguments)

    def imsub(self, Arg1=None, Arg2=None):
        """Alias for ImSub"""
        arguments = [Arg1, Arg2]
        return self.ImSub(*arguments)

    def im_sub(self, Arg1=None, Arg2=None):
        """Alias for ImSub"""
        arguments = [Arg1, Arg2]
        return self.ImSub(*arguments)

    def ImSum(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.ImSum(*arguments)

    def imsum(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for ImSum"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.ImSum(*arguments)

    def im_sum(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for ImSum"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.ImSum(*arguments)

    def ImTan(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.ImTan(*arguments)

    def imtan(self, Arg1=None):
        """Alias for ImTan"""
        arguments = [Arg1]
        return self.ImTan(*arguments)

    def im_tan(self, Arg1=None):
        """Alias for ImTan"""
        arguments = [Arg1]
        return self.ImTan(*arguments)

    def Intercept(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Intercept(*arguments)

    def intercept(self, Arg1=None, Arg2=None):
        """Alias for Intercept"""
        arguments = [Arg1, Arg2]
        return self.Intercept(*arguments)

    def IntRate(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5]])
        return self.com_object.IntRate(*arguments)

    def intrate(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for IntRate"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.IntRate(*arguments)

    def int_rate(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for IntRate"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.IntRate(*arguments)

    def Ipmt(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]])
        return self.com_object.Ipmt(*arguments)

    def ipmt(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        """Alias for Ipmt"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]
        return self.Ipmt(*arguments)

    def Irr(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Irr(*arguments)

    def irr(self, Arg1=None, Arg2=None):
        """Alias for Irr"""
        arguments = [Arg1, Arg2]
        return self.Irr(*arguments)

    def IsErr(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.IsErr(*arguments)

    def iserr(self, Arg1=None):
        """Alias for IsErr"""
        arguments = [Arg1]
        return self.IsErr(*arguments)

    def is_err(self, Arg1=None):
        """Alias for IsErr"""
        arguments = [Arg1]
        return self.IsErr(*arguments)

    def IsError(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.IsError(*arguments)

    def iserror(self, Arg1=None):
        """Alias for IsError"""
        arguments = [Arg1]
        return self.IsError(*arguments)

    def is_error(self, Arg1=None):
        """Alias for IsError"""
        arguments = [Arg1]
        return self.IsError(*arguments)

    def IsEven(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.IsEven(*arguments)

    def iseven(self, Arg1=None):
        """Alias for IsEven"""
        arguments = [Arg1]
        return self.IsEven(*arguments)

    def is_even(self, Arg1=None):
        """Alias for IsEven"""
        arguments = [Arg1]
        return self.IsEven(*arguments)

    def IsFormula(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.IsFormula(*arguments)

    def isformula(self, Arg1=None):
        """Alias for IsFormula"""
        arguments = [Arg1]
        return self.IsFormula(*arguments)

    def is_formula(self, Arg1=None):
        """Alias for IsFormula"""
        arguments = [Arg1]
        return self.IsFormula(*arguments)

    def IsLogical(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.IsLogical(*arguments)

    def islogical(self, Arg1=None):
        """Alias for IsLogical"""
        arguments = [Arg1]
        return self.IsLogical(*arguments)

    def is_logical(self, Arg1=None):
        """Alias for IsLogical"""
        arguments = [Arg1]
        return self.IsLogical(*arguments)

    def IsNA(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.IsNA(*arguments)

    def isna(self, Arg1=None):
        """Alias for IsNA"""
        arguments = [Arg1]
        return self.IsNA(*arguments)

    def is_n_a(self, Arg1=None):
        """Alias for IsNA"""
        arguments = [Arg1]
        return self.IsNA(*arguments)

    def IsNonText(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.IsNonText(*arguments)

    def isnontext(self, Arg1=None):
        """Alias for IsNonText"""
        arguments = [Arg1]
        return self.IsNonText(*arguments)

    def is_non_text(self, Arg1=None):
        """Alias for IsNonText"""
        arguments = [Arg1]
        return self.IsNonText(*arguments)

    def IsNumber(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.IsNumber(*arguments)

    def isnumber(self, Arg1=None):
        """Alias for IsNumber"""
        arguments = [Arg1]
        return self.IsNumber(*arguments)

    def is_number(self, Arg1=None):
        """Alias for IsNumber"""
        arguments = [Arg1]
        return self.IsNumber(*arguments)

    def IsOdd(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.IsOdd(*arguments)

    def isodd(self, Arg1=None):
        """Alias for IsOdd"""
        arguments = [Arg1]
        return self.IsOdd(*arguments)

    def is_odd(self, Arg1=None):
        """Alias for IsOdd"""
        arguments = [Arg1]
        return self.IsOdd(*arguments)

    def IsoWeekNum(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.IsoWeekNum(*arguments)

    def isoweeknum(self, Arg1=None, Arg2=None):
        """Alias for IsoWeekNum"""
        arguments = [Arg1, Arg2]
        return self.IsoWeekNum(*arguments)

    def iso_week_num(self, Arg1=None, Arg2=None):
        """Alias for IsoWeekNum"""
        arguments = [Arg1, Arg2]
        return self.IsoWeekNum(*arguments)

    def ISO_Ceiling(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.ISO_Ceiling(*arguments)

    def iso_ceiling(self, Arg1=None, Arg2=None):
        """Alias for ISO_Ceiling"""
        arguments = [Arg1, Arg2]
        return self.ISO_Ceiling(*arguments)

    def i_s_o__ceiling(self, Arg1=None, Arg2=None):
        """Alias for ISO_Ceiling"""
        arguments = [Arg1, Arg2]
        return self.ISO_Ceiling(*arguments)

    def Ispmt(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.Ispmt(*arguments)

    def ispmt(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for Ispmt"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.Ispmt(*arguments)

    def IsText(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.IsText(*arguments)

    def istext(self, Arg1=None):
        """Alias for IsText"""
        arguments = [Arg1]
        return self.IsText(*arguments)

    def is_text(self, Arg1=None):
        """Alias for IsText"""
        arguments = [Arg1]
        return self.IsText(*arguments)

    def Kurt(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Kurt(*arguments)

    def kurt(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Kurt"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Kurt(*arguments)

    def Large(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Large(*arguments)

    def large(self, Arg1=None, Arg2=None):
        """Alias for Large"""
        arguments = [Arg1, Arg2]
        return self.Large(*arguments)

    def Lcm(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Lcm(*arguments)

    def lcm(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Lcm"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Lcm(*arguments)

    def LinEst(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.LinEst(*arguments)

    def linest(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for LinEst"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.LinEst(*arguments)

    def lin_est(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for LinEst"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.LinEst(*arguments)

    def Ln(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Ln(*arguments)

    def ln(self, Arg1=None):
        """Alias for Ln"""
        arguments = [Arg1]
        return self.Ln(*arguments)

    def Log(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Log(*arguments)

    def log(self, Arg1=None, Arg2=None):
        """Alias for Log"""
        arguments = [Arg1, Arg2]
        return self.Log(*arguments)

    def Log10(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Log10(*arguments)

    def log10(self, Arg1=None):
        """Alias for Log10"""
        arguments = [Arg1]
        return self.Log10(*arguments)

    def LogEst(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.LogEst(*arguments)

    def logest(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for LogEst"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.LogEst(*arguments)

    def log_est(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for LogEst"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.LogEst(*arguments)

    def LogInv(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.LogInv(*arguments)

    def loginv(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for LogInv"""
        arguments = [Arg1, Arg2, Arg3]
        return self.LogInv(*arguments)

    def log_inv(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for LogInv"""
        arguments = [Arg1, Arg2, Arg3]
        return self.LogInv(*arguments)

    def LogNormDist(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.LogNormDist(*arguments)

    def lognormdist(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for LogNormDist"""
        arguments = [Arg1, Arg2, Arg3]
        return self.LogNormDist(*arguments)

    def log_norm_dist(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for LogNormDist"""
        arguments = [Arg1, Arg2, Arg3]
        return self.LogNormDist(*arguments)

    def LogNorm_Dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.LogNorm_Dist(*arguments)

    def lognorm_dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for LogNorm_Dist"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.LogNorm_Dist(*arguments)

    def log_norm__dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for LogNorm_Dist"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.LogNorm_Dist(*arguments)

    def LogNorm_Inv(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.LogNorm_Inv(*arguments)

    def lognorm_inv(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for LogNorm_Inv"""
        arguments = [Arg1, Arg2, Arg3]
        return self.LogNorm_Inv(*arguments)

    def log_norm__inv(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for LogNorm_Inv"""
        arguments = [Arg1, Arg2, Arg3]
        return self.LogNorm_Inv(*arguments)

    def Lookup(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Lookup(*arguments)

    def lookup(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Lookup"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Lookup(*arguments)

    def Match(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Match(*arguments)

    def match(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Match"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Match(*arguments)

    def Max(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Max(*arguments)

    def max(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Max"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Max(*arguments)

    def MDeterm(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.MDeterm(*arguments)

    def mdeterm(self, Arg1=None):
        """Alias for MDeterm"""
        arguments = [Arg1]
        return self.MDeterm(*arguments)

    def m_determ(self, Arg1=None):
        """Alias for MDeterm"""
        arguments = [Arg1]
        return self.MDeterm(*arguments)

    def MDuration(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]])
        return self.com_object.MDuration(*arguments)

    def mduration(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        """Alias for MDuration"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]
        return self.MDuration(*arguments)

    def m_duration(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        """Alias for MDuration"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]
        return self.MDuration(*arguments)

    def Median(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Median(*arguments)

    def median(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Median"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Median(*arguments)

    def Min(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Min(*arguments)

    def min(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Min"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Min(*arguments)

    def MInverse(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.MInverse(*arguments)

    def minverse(self, Arg1=None):
        """Alias for MInverse"""
        arguments = [Arg1]
        return self.MInverse(*arguments)

    def m_inverse(self, Arg1=None):
        """Alias for MInverse"""
        arguments = [Arg1]
        return self.MInverse(*arguments)

    def MIrr(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.MIrr(*arguments)

    def mirr(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for MIrr"""
        arguments = [Arg1, Arg2, Arg3]
        return self.MIrr(*arguments)

    def m_irr(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for MIrr"""
        arguments = [Arg1, Arg2, Arg3]
        return self.MIrr(*arguments)

    def MMult(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.MMult(*arguments)

    def mmult(self, Arg1=None, Arg2=None):
        """Alias for MMult"""
        arguments = [Arg1, Arg2]
        return self.MMult(*arguments)

    def m_mult(self, Arg1=None, Arg2=None):
        """Alias for MMult"""
        arguments = [Arg1, Arg2]
        return self.MMult(*arguments)

    def Mode(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Mode(*arguments)

    def mode(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Mode"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Mode(*arguments)

    def Mode_Mult(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Mode_Mult(*arguments)

    def mode_mult(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Mode_Mult"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Mode_Mult(*arguments)

    def mode__mult(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Mode_Mult"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Mode_Mult(*arguments)

    def Mode_Sngl(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Mode_Sngl(*arguments)

    def mode_sngl(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Mode_Sngl"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Mode_Sngl(*arguments)

    def mode__sngl(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Mode_Sngl"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Mode_Sngl(*arguments)

    def MRound(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.MRound(*arguments)

    def mround(self, Arg1=None, Arg2=None):
        """Alias for MRound"""
        arguments = [Arg1, Arg2]
        return self.MRound(*arguments)

    def m_round(self, Arg1=None, Arg2=None):
        """Alias for MRound"""
        arguments = [Arg1, Arg2]
        return self.MRound(*arguments)

    def MultiNomial(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.MultiNomial(*arguments)

    def multinomial(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for MultiNomial"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.MultiNomial(*arguments)

    def multi_nomial(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for MultiNomial"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.MultiNomial(*arguments)

    def Munit(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Munit(*arguments)

    def munit(self, Arg1=None):
        """Alias for Munit"""
        arguments = [Arg1]
        return self.Munit(*arguments)

    def NegBinomDist(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.NegBinomDist(*arguments)

    def negbinomdist(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for NegBinomDist"""
        arguments = [Arg1, Arg2, Arg3]
        return self.NegBinomDist(*arguments)

    def neg_binom_dist(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for NegBinomDist"""
        arguments = [Arg1, Arg2, Arg3]
        return self.NegBinomDist(*arguments)

    def NegBinom_Dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.NegBinom_Dist(*arguments)

    def negbinom_dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for NegBinom_Dist"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.NegBinom_Dist(*arguments)

    def neg_binom__dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for NegBinom_Dist"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.NegBinom_Dist(*arguments)

    def NetworkDays(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.NetworkDays(*arguments)

    def networkdays(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for NetworkDays"""
        arguments = [Arg1, Arg2, Arg3]
        return self.NetworkDays(*arguments)

    def network_days(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for NetworkDays"""
        arguments = [Arg1, Arg2, Arg3]
        return self.NetworkDays(*arguments)

    def NetworkDays_Intl(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.NetworkDays_Intl(*arguments)

    def networkdays_intl(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for NetworkDays_Intl"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.NetworkDays_Intl(*arguments)

    def network_days__intl(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for NetworkDays_Intl"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.NetworkDays_Intl(*arguments)

    def Nominal(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Nominal(*arguments)

    def nominal(self, Arg1=None, Arg2=None):
        """Alias for Nominal"""
        arguments = [Arg1, Arg2]
        return self.Nominal(*arguments)

    def NormDist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.NormDist(*arguments)

    def normdist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for NormDist"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.NormDist(*arguments)

    def norm_dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for NormDist"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.NormDist(*arguments)

    def NormInv(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.NormInv(*arguments)

    def norminv(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for NormInv"""
        arguments = [Arg1, Arg2, Arg3]
        return self.NormInv(*arguments)

    def norm_inv(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for NormInv"""
        arguments = [Arg1, Arg2, Arg3]
        return self.NormInv(*arguments)

    def NormSDist(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.NormSDist(*arguments)

    def normsdist(self, Arg1=None):
        """Alias for NormSDist"""
        arguments = [Arg1]
        return self.NormSDist(*arguments)

    def norm_s_dist(self, Arg1=None):
        """Alias for NormSDist"""
        arguments = [Arg1]
        return self.NormSDist(*arguments)

    def NormSInv(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.NormSInv(*arguments)

    def normsinv(self, Arg1=None):
        """Alias for NormSInv"""
        arguments = [Arg1]
        return self.NormSInv(*arguments)

    def norm_s_inv(self, Arg1=None):
        """Alias for NormSInv"""
        arguments = [Arg1]
        return self.NormSInv(*arguments)

    def Norm_Dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.Norm_Dist(*arguments)

    def norm_dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for Norm_Dist"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.Norm_Dist(*arguments)

    def norm__dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for Norm_Dist"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.Norm_Dist(*arguments)

    def Norm_Inv(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Norm_Inv(*arguments)

    def norm_inv(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Norm_Inv"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Norm_Inv(*arguments)

    def norm__inv(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Norm_Inv"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Norm_Inv(*arguments)

    def Norm_S_Dist(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Norm_S_Dist(*arguments)

    def norm_s_dist(self, Arg1=None, Arg2=None):
        """Alias for Norm_S_Dist"""
        arguments = [Arg1, Arg2]
        return self.Norm_S_Dist(*arguments)

    def norm__s__dist(self, Arg1=None, Arg2=None):
        """Alias for Norm_S_Dist"""
        arguments = [Arg1, Arg2]
        return self.Norm_S_Dist(*arguments)

    def Norm_S_Inv(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Norm_S_Inv(*arguments)

    def norm_s_inv(self, Arg1=None):
        """Alias for Norm_S_Inv"""
        arguments = [Arg1]
        return self.Norm_S_Inv(*arguments)

    def norm__s__inv(self, Arg1=None):
        """Alias for Norm_S_Inv"""
        arguments = [Arg1]
        return self.Norm_S_Inv(*arguments)

    def NPer(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5]])
        return self.com_object.NPer(*arguments)

    def nper(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for NPer"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.NPer(*arguments)

    def n_per(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for NPer"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.NPer(*arguments)

    def Npv(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Npv(*arguments)

    def npv(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Npv"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Npv(*arguments)

    def NumberValue(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.NumberValue(*arguments)

    def numbervalue(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for NumberValue"""
        arguments = [Arg1, Arg2, Arg3]
        return self.NumberValue(*arguments)

    def number_value(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for NumberValue"""
        arguments = [Arg1, Arg2, Arg3]
        return self.NumberValue(*arguments)

    def Oct2Bin(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Oct2Bin(*arguments)

    def oct2bin(self, Arg1=None, Arg2=None):
        """Alias for Oct2Bin"""
        arguments = [Arg1, Arg2]
        return self.Oct2Bin(*arguments)

    def oct2_bin(self, Arg1=None, Arg2=None):
        """Alias for Oct2Bin"""
        arguments = [Arg1, Arg2]
        return self.Oct2Bin(*arguments)

    def Oct2Dec(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Oct2Dec(*arguments)

    def oct2dec(self, Arg1=None):
        """Alias for Oct2Dec"""
        arguments = [Arg1]
        return self.Oct2Dec(*arguments)

    def oct2_dec(self, Arg1=None):
        """Alias for Oct2Dec"""
        arguments = [Arg1]
        return self.Oct2Dec(*arguments)

    def Oct2Hex(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Oct2Hex(*arguments)

    def oct2hex(self, Arg1=None, Arg2=None):
        """Alias for Oct2Hex"""
        arguments = [Arg1, Arg2]
        return self.Oct2Hex(*arguments)

    def oct2_hex(self, Arg1=None, Arg2=None):
        """Alias for Oct2Hex"""
        arguments = [Arg1, Arg2]
        return self.Oct2Hex(*arguments)

    def Odd(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Odd(*arguments)

    def odd(self, Arg1=None):
        """Alias for Odd"""
        arguments = [Arg1]
        return self.Odd(*arguments)

    def OddFPrice(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9]])
        return self.com_object.OddFPrice(*arguments)

    def oddfprice(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None):
        """Alias for OddFPrice"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9]
        return self.OddFPrice(*arguments)

    def odd_f_price(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None):
        """Alias for OddFPrice"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9]
        return self.OddFPrice(*arguments)

    def OddFYield(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9]])
        return self.com_object.OddFYield(*arguments)

    def oddfyield(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None):
        """Alias for OddFYield"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9]
        return self.OddFYield(*arguments)

    def odd_f_yield(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None):
        """Alias for OddFYield"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9]
        return self.OddFYield(*arguments)

    def OddLPrice(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8]])
        return self.com_object.OddLPrice(*arguments)

    def oddlprice(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None):
        """Alias for OddLPrice"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8]
        return self.OddLPrice(*arguments)

    def odd_l_price(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None):
        """Alias for OddLPrice"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8]
        return self.OddLPrice(*arguments)

    def OddLYield(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8]])
        return self.com_object.OddLYield(*arguments)

    def oddlyield(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None):
        """Alias for OddLYield"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8]
        return self.OddLYield(*arguments)

    def odd_l_yield(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None):
        """Alias for OddLYield"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8]
        return self.OddLYield(*arguments)

    def Or(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Or(*arguments)

    def PDuration(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.PDuration(*arguments)

    def pduration(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for PDuration"""
        arguments = [Arg1, Arg2, Arg3]
        return self.PDuration(*arguments)

    def p_duration(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for PDuration"""
        arguments = [Arg1, Arg2, Arg3]
        return self.PDuration(*arguments)

    def Pearson(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Pearson(*arguments)

    def pearson(self, Arg1=None, Arg2=None):
        """Alias for Pearson"""
        arguments = [Arg1, Arg2]
        return self.Pearson(*arguments)

    def Percentile(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Percentile(*arguments)

    def percentile(self, Arg1=None, Arg2=None):
        """Alias for Percentile"""
        arguments = [Arg1, Arg2]
        return self.Percentile(*arguments)

    def Percentile_Exc(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Percentile_Exc(*arguments)

    def percentile_exc(self, Arg1=None, Arg2=None):
        """Alias for Percentile_Exc"""
        arguments = [Arg1, Arg2]
        return self.Percentile_Exc(*arguments)

    def percentile__exc(self, Arg1=None, Arg2=None):
        """Alias for Percentile_Exc"""
        arguments = [Arg1, Arg2]
        return self.Percentile_Exc(*arguments)

    def Percentile_Inc(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Percentile_Inc(*arguments)

    def percentile_inc(self, Arg1=None, Arg2=None):
        """Alias for Percentile_Inc"""
        arguments = [Arg1, Arg2]
        return self.Percentile_Inc(*arguments)

    def percentile__inc(self, Arg1=None, Arg2=None):
        """Alias for Percentile_Inc"""
        arguments = [Arg1, Arg2]
        return self.Percentile_Inc(*arguments)

    def PercentRank(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.PercentRank(*arguments)

    def percentrank(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for PercentRank"""
        arguments = [Arg1, Arg2, Arg3]
        return self.PercentRank(*arguments)

    def percent_rank(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for PercentRank"""
        arguments = [Arg1, Arg2, Arg3]
        return self.PercentRank(*arguments)

    def PercentRank_Exc(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.PercentRank_Exc(*arguments)

    def percentrank_exc(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for PercentRank_Exc"""
        arguments = [Arg1, Arg2, Arg3]
        return self.PercentRank_Exc(*arguments)

    def percent_rank__exc(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for PercentRank_Exc"""
        arguments = [Arg1, Arg2, Arg3]
        return self.PercentRank_Exc(*arguments)

    def PercentRank_Inc(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.PercentRank_Inc(*arguments)

    def percentrank_inc(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for PercentRank_Inc"""
        arguments = [Arg1, Arg2, Arg3]
        return self.PercentRank_Inc(*arguments)

    def percent_rank__inc(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for PercentRank_Inc"""
        arguments = [Arg1, Arg2, Arg3]
        return self.PercentRank_Inc(*arguments)

    def Permut(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Permut(*arguments)

    def permut(self, Arg1=None, Arg2=None):
        """Alias for Permut"""
        arguments = [Arg1, Arg2]
        return self.Permut(*arguments)

    def Permutationa(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Permutationa(*arguments)

    def permutationa(self, Arg1=None, Arg2=None):
        """Alias for Permutationa"""
        arguments = [Arg1, Arg2]
        return self.Permutationa(*arguments)

    def Phi(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Phi(*arguments)

    def phi(self, Arg1=None):
        """Alias for Phi"""
        arguments = [Arg1]
        return self.Phi(*arguments)

    def Phonetic(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Phonetic(*arguments)

    def phonetic(self, Arg1=None):
        """Alias for Phonetic"""
        arguments = [Arg1]
        return self.Phonetic(*arguments)

    def Pi(self):
        return self.com_object.Pi()

    def pi(self):
        """Alias for Pi"""
        return self.Pi()

    def Pmt(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5]])
        return self.com_object.Pmt(*arguments)

    def pmt(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for Pmt"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.Pmt(*arguments)

    def Poisson(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Poisson(*arguments)

    def poisson(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Poisson"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Poisson(*arguments)

    def Poisson_Dist(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Poisson_Dist(*arguments)

    def poisson_dist(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Poisson_Dist"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Poisson_Dist(*arguments)

    def poisson__dist(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Poisson_Dist"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Poisson_Dist(*arguments)

    def Power(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Power(*arguments)

    def power(self, Arg1=None, Arg2=None):
        """Alias for Power"""
        arguments = [Arg1, Arg2]
        return self.Power(*arguments)

    def Ppmt(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]])
        return self.com_object.Ppmt(*arguments)

    def ppmt(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        """Alias for Ppmt"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]
        return self.Ppmt(*arguments)

    def Price(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7]])
        return self.com_object.Price(*arguments)

    def price(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None):
        """Alias for Price"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7]
        return self.Price(*arguments)

    def PriceDisc(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5]])
        return self.com_object.PriceDisc(*arguments)

    def pricedisc(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for PriceDisc"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.PriceDisc(*arguments)

    def price_disc(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for PriceDisc"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.PriceDisc(*arguments)

    def PriceMat(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]])
        return self.com_object.PriceMat(*arguments)

    def pricemat(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        """Alias for PriceMat"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]
        return self.PriceMat(*arguments)

    def price_mat(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        """Alias for PriceMat"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]
        return self.PriceMat(*arguments)

    def Prob(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.Prob(*arguments)

    def prob(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for Prob"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.Prob(*arguments)

    def Product(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Product(*arguments)

    def product(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Product"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Product(*arguments)

    def Proper(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Proper(*arguments)

    def proper(self, Arg1=None):
        """Alias for Proper"""
        arguments = [Arg1]
        return self.Proper(*arguments)

    def Pv(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5]])
        return self.com_object.Pv(*arguments)

    def pv(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for Pv"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.Pv(*arguments)

    def Quartile(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Quartile(*arguments)

    def quartile(self, Arg1=None, Arg2=None):
        """Alias for Quartile"""
        arguments = [Arg1, Arg2]
        return self.Quartile(*arguments)

    def Quartile_Exc(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Quartile_Exc(*arguments)

    def quartile_exc(self, Arg1=None, Arg2=None):
        """Alias for Quartile_Exc"""
        arguments = [Arg1, Arg2]
        return self.Quartile_Exc(*arguments)

    def quartile__exc(self, Arg1=None, Arg2=None):
        """Alias for Quartile_Exc"""
        arguments = [Arg1, Arg2]
        return self.Quartile_Exc(*arguments)

    def Quartile_Inc(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Quartile_Inc(*arguments)

    def quartile_inc(self, Arg1=None, Arg2=None):
        """Alias for Quartile_Inc"""
        arguments = [Arg1, Arg2]
        return self.Quartile_Inc(*arguments)

    def quartile__inc(self, Arg1=None, Arg2=None):
        """Alias for Quartile_Inc"""
        arguments = [Arg1, Arg2]
        return self.Quartile_Inc(*arguments)

    def Quotient(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Quotient(*arguments)

    def quotient(self, Arg1=None, Arg2=None):
        """Alias for Quotient"""
        arguments = [Arg1, Arg2]
        return self.Quotient(*arguments)

    def Radians(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Radians(*arguments)

    def radians(self, Arg1=None):
        """Alias for Radians"""
        arguments = [Arg1]
        return self.Radians(*arguments)

    def RandBetween(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.RandBetween(*arguments)

    def randbetween(self, Arg1=None, Arg2=None):
        """Alias for RandBetween"""
        arguments = [Arg1, Arg2]
        return self.RandBetween(*arguments)

    def rand_between(self, Arg1=None, Arg2=None):
        """Alias for RandBetween"""
        arguments = [Arg1, Arg2]
        return self.RandBetween(*arguments)

    def Rank(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Rank(*arguments)

    def rank(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Rank"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Rank(*arguments)

    def Rank_Avg(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Rank_Avg(*arguments)

    def rank_avg(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Rank_Avg"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Rank_Avg(*arguments)

    def rank__avg(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Rank_Avg"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Rank_Avg(*arguments)

    def Rank_Eq(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Rank_Eq(*arguments)

    def rank_eq(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Rank_Eq"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Rank_Eq(*arguments)

    def rank__eq(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Rank_Eq"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Rank_Eq(*arguments)

    def Rate(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]])
        return self.com_object.Rate(*arguments)

    def rate(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        """Alias for Rate"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]
        return self.Rate(*arguments)

    def Received(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5]])
        return self.com_object.Received(*arguments)

    def received(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for Received"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.Received(*arguments)

    def Replace(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.Replace(*arguments)

    def replace(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for Replace"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.Replace(*arguments)

    def ReplaceB(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.ReplaceB(*arguments)

    def replaceb(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for ReplaceB"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.ReplaceB(*arguments)

    def replace_b(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for ReplaceB"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.ReplaceB(*arguments)

    def Rept(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Rept(*arguments)

    def rept(self, Arg1=None, Arg2=None):
        """Alias for Rept"""
        arguments = [Arg1, Arg2]
        return self.Rept(*arguments)

    def Roman(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Roman(*arguments)

    def roman(self, Arg1=None, Arg2=None):
        """Alias for Roman"""
        arguments = [Arg1, Arg2]
        return self.Roman(*arguments)

    def Round(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Round(*arguments)

    def round(self, Arg1=None, Arg2=None):
        """Alias for Round"""
        arguments = [Arg1, Arg2]
        return self.Round(*arguments)

    def RoundDown(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.RoundDown(*arguments)

    def rounddown(self, Arg1=None, Arg2=None):
        """Alias for RoundDown"""
        arguments = [Arg1, Arg2]
        return self.RoundDown(*arguments)

    def round_down(self, Arg1=None, Arg2=None):
        """Alias for RoundDown"""
        arguments = [Arg1, Arg2]
        return self.RoundDown(*arguments)

    def RoundUp(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.RoundUp(*arguments)

    def roundup(self, Arg1=None, Arg2=None):
        """Alias for RoundUp"""
        arguments = [Arg1, Arg2]
        return self.RoundUp(*arguments)

    def round_up(self, Arg1=None, Arg2=None):
        """Alias for RoundUp"""
        arguments = [Arg1, Arg2]
        return self.RoundUp(*arguments)

    def Rri(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Rri(*arguments)

    def rri(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Rri"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Rri(*arguments)

    def RSq(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.RSq(*arguments)

    def rsq(self, Arg1=None, Arg2=None):
        """Alias for RSq"""
        arguments = [Arg1, Arg2]
        return self.RSq(*arguments)

    def r_sq(self, Arg1=None, Arg2=None):
        """Alias for RSq"""
        arguments = [Arg1, Arg2]
        return self.RSq(*arguments)

    def RTD(self, progID=None, server=None, topic1=None, topic2=None, topic3=None, topic4=None, topic5=None, topic6=None, topic7=None, topic8=None, topic9=None, topic10=None, topic11=None, topic12=None, topic13=None, topic14=None, topic15=None, topic16=None, topic17=None, topic18=None, topic19=None, topic20=None, topic21=None, topic22=None, topic23=None, topic24=None, topic25=None, topic26=None, topic27=None, topic28=None):
        arguments = com_arguments([unwrap(a) for a in [progID, server, topic1, topic2, topic3, topic4, topic5, topic6, topic7, topic8, topic9, topic10, topic11, topic12, topic13, topic14, topic15, topic16, topic17, topic18, topic19, topic20, topic21, topic22, topic23, topic24, topic25, topic26, topic27, topic28]])
        return self.com_object.RTD(*arguments)

    def rtd(self, progID=None, server=None, topic1=None, topic2=None, topic3=None, topic4=None, topic5=None, topic6=None, topic7=None, topic8=None, topic9=None, topic10=None, topic11=None, topic12=None, topic13=None, topic14=None, topic15=None, topic16=None, topic17=None, topic18=None, topic19=None, topic20=None, topic21=None, topic22=None, topic23=None, topic24=None, topic25=None, topic26=None, topic27=None, topic28=None):
        """Alias for RTD"""
        arguments = [progID, server, topic1, topic2, topic3, topic4, topic5, topic6, topic7, topic8, topic9, topic10, topic11, topic12, topic13, topic14, topic15, topic16, topic17, topic18, topic19, topic20, topic21, topic22, topic23, topic24, topic25, topic26, topic27, topic28]
        return self.RTD(*arguments)

    def r_t_d(self, progID=None, server=None, topic1=None, topic2=None, topic3=None, topic4=None, topic5=None, topic6=None, topic7=None, topic8=None, topic9=None, topic10=None, topic11=None, topic12=None, topic13=None, topic14=None, topic15=None, topic16=None, topic17=None, topic18=None, topic19=None, topic20=None, topic21=None, topic22=None, topic23=None, topic24=None, topic25=None, topic26=None, topic27=None, topic28=None):
        """Alias for RTD"""
        arguments = [progID, server, topic1, topic2, topic3, topic4, topic5, topic6, topic7, topic8, topic9, topic10, topic11, topic12, topic13, topic14, topic15, topic16, topic17, topic18, topic19, topic20, topic21, topic22, topic23, topic24, topic25, topic26, topic27, topic28]
        return self.RTD(*arguments)

    def Search(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Search(*arguments)

    def search(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Search"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Search(*arguments)

    def SearchB(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.SearchB(*arguments)

    def searchb(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for SearchB"""
        arguments = [Arg1, Arg2, Arg3]
        return self.SearchB(*arguments)

    def search_b(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for SearchB"""
        arguments = [Arg1, Arg2, Arg3]
        return self.SearchB(*arguments)

    def Sec(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Sec(*arguments)

    def sec(self, Arg1=None):
        """Alias for Sec"""
        arguments = [Arg1]
        return self.Sec(*arguments)

    def Sech(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Sech(*arguments)

    def sech(self, Arg1=None):
        """Alias for Sech"""
        arguments = [Arg1]
        return self.Sech(*arguments)

    def SeriesSum(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.SeriesSum(*arguments)

    def seriessum(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for SeriesSum"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.SeriesSum(*arguments)

    def series_sum(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for SeriesSum"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.SeriesSum(*arguments)

    def Sinh(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Sinh(*arguments)

    def sinh(self, Arg1=None):
        """Alias for Sinh"""
        arguments = [Arg1]
        return self.Sinh(*arguments)

    def Skew(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Skew(*arguments)

    def skew(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Skew"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Skew(*arguments)

    def Skew_p(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Skew_p(*arguments)

    def skew_p(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Skew_p"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Skew_p(*arguments)

    def Sln(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Sln(*arguments)

    def sln(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Sln"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Sln(*arguments)

    def Slope(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Slope(*arguments)

    def slope(self, Arg1=None, Arg2=None):
        """Alias for Slope"""
        arguments = [Arg1, Arg2]
        return self.Slope(*arguments)

    def Small(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Small(*arguments)

    def small(self, Arg1=None, Arg2=None):
        """Alias for Small"""
        arguments = [Arg1, Arg2]
        return self.Small(*arguments)

    def SqrtPi(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.SqrtPi(*arguments)

    def sqrtpi(self, Arg1=None):
        """Alias for SqrtPi"""
        arguments = [Arg1]
        return self.SqrtPi(*arguments)

    def sqrt_pi(self, Arg1=None):
        """Alias for SqrtPi"""
        arguments = [Arg1]
        return self.SqrtPi(*arguments)

    def Standardize(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Standardize(*arguments)

    def standardize(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Standardize"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Standardize(*arguments)

    def StDev(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.StDev(*arguments)

    def stdev(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for StDev"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.StDev(*arguments)

    def st_dev(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for StDev"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.StDev(*arguments)

    def StDevP(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.StDevP(*arguments)

    def stdevp(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for StDevP"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.StDevP(*arguments)

    def st_dev_p(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for StDevP"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.StDevP(*arguments)

    def StDev_P(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.StDev_P(*arguments)

    def stdev_p(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for StDev_P"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.StDev_P(*arguments)

    def st_dev__p(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for StDev_P"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.StDev_P(*arguments)

    def StDev_S(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.StDev_S(*arguments)

    def stdev_s(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for StDev_S"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.StDev_S(*arguments)

    def st_dev__s(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for StDev_S"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.StDev_S(*arguments)

    def StEyx(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.StEyx(*arguments)

    def steyx(self, Arg1=None, Arg2=None):
        """Alias for StEyx"""
        arguments = [Arg1, Arg2]
        return self.StEyx(*arguments)

    def st_eyx(self, Arg1=None, Arg2=None):
        """Alias for StEyx"""
        arguments = [Arg1, Arg2]
        return self.StEyx(*arguments)

    def Substitute(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.Substitute(*arguments)

    def substitute(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for Substitute"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.Substitute(*arguments)

    def Subtotal(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Subtotal(*arguments)

    def subtotal(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Subtotal"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Subtotal(*arguments)

    def Sum(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Sum(*arguments)

    def sum(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Sum"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Sum(*arguments)

    def SumIf(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.SumIf(*arguments)

    def sumif(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for SumIf"""
        arguments = [Arg1, Arg2, Arg3]
        return self.SumIf(*arguments)

    def sum_if(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for SumIf"""
        arguments = [Arg1, Arg2, Arg3]
        return self.SumIf(*arguments)

    def SumIfs(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.SumIfs(*arguments)

    def sumifs(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for SumIfs"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.SumIfs(*arguments)

    def sum_ifs(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for SumIfs"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.SumIfs(*arguments)

    def SumProduct(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.SumProduct(*arguments)

    def sumproduct(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for SumProduct"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.SumProduct(*arguments)

    def sum_product(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for SumProduct"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.SumProduct(*arguments)

    def SumSq(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.SumSq(*arguments)

    def sumsq(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for SumSq"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.SumSq(*arguments)

    def sum_sq(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for SumSq"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.SumSq(*arguments)

    def SumX2MY2(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.SumX2MY2(*arguments)

    def sumx2my2(self, Arg1=None, Arg2=None):
        """Alias for SumX2MY2"""
        arguments = [Arg1, Arg2]
        return self.SumX2MY2(*arguments)

    def sum_x2_m_y2(self, Arg1=None, Arg2=None):
        """Alias for SumX2MY2"""
        arguments = [Arg1, Arg2]
        return self.SumX2MY2(*arguments)

    def SumX2PY2(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.SumX2PY2(*arguments)

    def sumx2py2(self, Arg1=None, Arg2=None):
        """Alias for SumX2PY2"""
        arguments = [Arg1, Arg2]
        return self.SumX2PY2(*arguments)

    def sum_x2_p_y2(self, Arg1=None, Arg2=None):
        """Alias for SumX2PY2"""
        arguments = [Arg1, Arg2]
        return self.SumX2PY2(*arguments)

    def SumXMY2(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.SumXMY2(*arguments)

    def sumxmy2(self, Arg1=None, Arg2=None):
        """Alias for SumXMY2"""
        arguments = [Arg1, Arg2]
        return self.SumXMY2(*arguments)

    def sum_x_m_y2(self, Arg1=None, Arg2=None):
        """Alias for SumXMY2"""
        arguments = [Arg1, Arg2]
        return self.SumXMY2(*arguments)

    def Syd(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.Syd(*arguments)

    def syd(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for Syd"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.Syd(*arguments)

    def Tanh(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Tanh(*arguments)

    def tanh(self, Arg1=None):
        """Alias for Tanh"""
        arguments = [Arg1]
        return self.Tanh(*arguments)

    def TBillEq(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.TBillEq(*arguments)

    def tbilleq(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for TBillEq"""
        arguments = [Arg1, Arg2, Arg3]
        return self.TBillEq(*arguments)

    def t_bill_eq(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for TBillEq"""
        arguments = [Arg1, Arg2, Arg3]
        return self.TBillEq(*arguments)

    def TBillPrice(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.TBillPrice(*arguments)

    def tbillprice(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for TBillPrice"""
        arguments = [Arg1, Arg2, Arg3]
        return self.TBillPrice(*arguments)

    def t_bill_price(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for TBillPrice"""
        arguments = [Arg1, Arg2, Arg3]
        return self.TBillPrice(*arguments)

    def TBillYield(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.TBillYield(*arguments)

    def tbillyield(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for TBillYield"""
        arguments = [Arg1, Arg2, Arg3]
        return self.TBillYield(*arguments)

    def t_bill_yield(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for TBillYield"""
        arguments = [Arg1, Arg2, Arg3]
        return self.TBillYield(*arguments)

    def TDist(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.TDist(*arguments)

    def tdist(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for TDist"""
        arguments = [Arg1, Arg2, Arg3]
        return self.TDist(*arguments)

    def t_dist(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for TDist"""
        arguments = [Arg1, Arg2, Arg3]
        return self.TDist(*arguments)

    def Text(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Text(*arguments)

    def text(self, Arg1=None, Arg2=None):
        """Alias for Text"""
        arguments = [Arg1, Arg2]
        return self.Text(*arguments)

    def TInv(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.TInv(*arguments)

    def tinv(self, Arg1=None, Arg2=None):
        """Alias for TInv"""
        arguments = [Arg1, Arg2]
        return self.TInv(*arguments)

    def t_inv(self, Arg1=None, Arg2=None):
        """Alias for TInv"""
        arguments = [Arg1, Arg2]
        return self.TInv(*arguments)

    def Transpose(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Transpose(*arguments)

    def transpose(self, Arg1=None):
        """Alias for Transpose"""
        arguments = [Arg1]
        return self.Transpose(*arguments)

    def Trend(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.Trend(*arguments)

    def trend(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for Trend"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.Trend(*arguments)

    def Trim(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Trim(*arguments)

    def trim(self, Arg1=None):
        """Alias for Trim"""
        arguments = [Arg1]
        return self.Trim(*arguments)

    def TrimMean(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.TrimMean(*arguments)

    def trimmean(self, Arg1=None, Arg2=None):
        """Alias for TrimMean"""
        arguments = [Arg1, Arg2]
        return self.TrimMean(*arguments)

    def trim_mean(self, Arg1=None, Arg2=None):
        """Alias for TrimMean"""
        arguments = [Arg1, Arg2]
        return self.TrimMean(*arguments)

    def TTest(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.TTest(*arguments)

    def ttest(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for TTest"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.TTest(*arguments)

    def t_test(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for TTest"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.TTest(*arguments)

    def T_Dist(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.T_Dist(*arguments)

    def t_dist(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for T_Dist"""
        arguments = [Arg1, Arg2, Arg3]
        return self.T_Dist(*arguments)

    def t__dist(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for T_Dist"""
        arguments = [Arg1, Arg2, Arg3]
        return self.T_Dist(*arguments)

    def T_Dist_2T(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.T_Dist_2T(*arguments)

    def t_dist_2t(self, Arg1=None, Arg2=None):
        """Alias for T_Dist_2T"""
        arguments = [Arg1, Arg2]
        return self.T_Dist_2T(*arguments)

    def t__dist_2_t(self, Arg1=None, Arg2=None):
        """Alias for T_Dist_2T"""
        arguments = [Arg1, Arg2]
        return self.T_Dist_2T(*arguments)

    def T_Dist_RT(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.T_Dist_RT(*arguments)

    def t_dist_rt(self, Arg1=None, Arg2=None):
        """Alias for T_Dist_RT"""
        arguments = [Arg1, Arg2]
        return self.T_Dist_RT(*arguments)

    def t__dist__r_t(self, Arg1=None, Arg2=None):
        """Alias for T_Dist_RT"""
        arguments = [Arg1, Arg2]
        return self.T_Dist_RT(*arguments)

    def T_Inv(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.T_Inv(*arguments)

    def t_inv(self, Arg1=None, Arg2=None):
        """Alias for T_Inv"""
        arguments = [Arg1, Arg2]
        return self.T_Inv(*arguments)

    def t__inv(self, Arg1=None, Arg2=None):
        """Alias for T_Inv"""
        arguments = [Arg1, Arg2]
        return self.T_Inv(*arguments)

    def T_Inv_2T(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.T_Inv_2T(*arguments)

    def t_inv_2t(self, Arg1=None, Arg2=None):
        """Alias for T_Inv_2T"""
        arguments = [Arg1, Arg2]
        return self.T_Inv_2T(*arguments)

    def t__inv_2_t(self, Arg1=None, Arg2=None):
        """Alias for T_Inv_2T"""
        arguments = [Arg1, Arg2]
        return self.T_Inv_2T(*arguments)

    def T_Test(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.T_Test(*arguments)

    def t_test(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for T_Test"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.T_Test(*arguments)

    def t__test(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for T_Test"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.T_Test(*arguments)

    def Unichar(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Unichar(*arguments)

    def unichar(self, Arg1=None):
        """Alias for Unichar"""
        arguments = [Arg1]
        return self.Unichar(*arguments)

    def Unicode(self, Arg1=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1]])
        return self.com_object.Unicode(*arguments)

    def unicode(self, Arg1=None):
        """Alias for Unicode"""
        arguments = [Arg1]
        return self.Unicode(*arguments)

    def USDollar(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.USDollar(*arguments)

    def usdollar(self, Arg1=None, Arg2=None):
        """Alias for USDollar"""
        arguments = [Arg1, Arg2]
        return self.USDollar(*arguments)

    def u_s_dollar(self, Arg1=None, Arg2=None):
        """Alias for USDollar"""
        arguments = [Arg1, Arg2]
        return self.USDollar(*arguments)

    def Var(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Var(*arguments)

    def var(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Var"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Var(*arguments)

    def VarP(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.VarP(*arguments)

    def varp(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for VarP"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.VarP(*arguments)

    def var_p(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for VarP"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.VarP(*arguments)

    def Var_P(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Var_P(*arguments)

    def var_p(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Var_P"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Var_P(*arguments)

    def var__p(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Var_P"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Var_P(*arguments)

    def Var_S(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Var_S(*arguments)

    def var_s(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Var_S"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Var_S(*arguments)

    def var__s(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Var_S"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Var_S(*arguments)

    def Vdb(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7]])
        return self.com_object.Vdb(*arguments)

    def vdb(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None):
        """Alias for Vdb"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7]
        return self.Vdb(*arguments)

    def VLookup(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.VLookup(*arguments)

    def vlookup(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for VLookup"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.VLookup(*arguments)

    def v_lookup(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for VLookup"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.VLookup(*arguments)

    def WebService(self, Url=None):
        arguments = com_arguments([unwrap(a) for a in [Url]])
        return self.com_object.WebService(*arguments)

    def webservice(self, Url=None):
        """Alias for WebService"""
        arguments = [Url]
        return self.WebService(*arguments)

    def web_service(self, Url=None):
        """Alias for WebService"""
        arguments = [Url]
        return self.WebService(*arguments)

    def Weekday(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Weekday(*arguments)

    def weekday(self, Arg1=None, Arg2=None):
        """Alias for Weekday"""
        arguments = [Arg1, Arg2]
        return self.Weekday(*arguments)

    def WeekNum(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.WeekNum(*arguments)

    def weeknum(self, Arg1=None, Arg2=None):
        """Alias for WeekNum"""
        arguments = [Arg1, Arg2]
        return self.WeekNum(*arguments)

    def week_num(self, Arg1=None, Arg2=None):
        """Alias for WeekNum"""
        arguments = [Arg1, Arg2]
        return self.WeekNum(*arguments)

    def Weibull(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.Weibull(*arguments)

    def weibull(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for Weibull"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.Weibull(*arguments)

    def Weibull_Dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.Weibull_Dist(*arguments)

    def weibull_dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for Weibull_Dist"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.Weibull_Dist(*arguments)

    def weibull__dist(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for Weibull_Dist"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.Weibull_Dist(*arguments)

    def WorkDay(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.WorkDay(*arguments)

    def workday(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for WorkDay"""
        arguments = [Arg1, Arg2, Arg3]
        return self.WorkDay(*arguments)

    def work_day(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for WorkDay"""
        arguments = [Arg1, Arg2, Arg3]
        return self.WorkDay(*arguments)

    def WorkDay_Intl(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4]])
        return self.com_object.WorkDay_Intl(*arguments)

    def workday_intl(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for WorkDay_Intl"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.WorkDay_Intl(*arguments)

    def work_day__intl(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None):
        """Alias for WorkDay_Intl"""
        arguments = [Arg1, Arg2, Arg3, Arg4]
        return self.WorkDay_Intl(*arguments)

    def Xirr(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Xirr(*arguments)

    def xirr(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Xirr"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Xirr(*arguments)

    def Xnpv(self, Arg1=None, Arg2=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2]])
        return self.com_object.Xnpv(*arguments)

    def xnpv(self, Arg1=None, Arg2=None):
        """Alias for Xnpv"""
        arguments = [Arg1, Arg2]
        return self.Xnpv(*arguments)

    def Xor(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Xor(*arguments)

    def xor(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Xor"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Xor(*arguments)

    def YearFrac(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.YearFrac(*arguments)

    def yearfrac(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for YearFrac"""
        arguments = [Arg1, Arg2, Arg3]
        return self.YearFrac(*arguments)

    def year_frac(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for YearFrac"""
        arguments = [Arg1, Arg2, Arg3]
        return self.YearFrac(*arguments)

    def YieldDisc(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5]])
        return self.com_object.YieldDisc(*arguments)

    def yielddisc(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for YieldDisc"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.YieldDisc(*arguments)

    def yield_disc(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None):
        """Alias for YieldDisc"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5]
        return self.YieldDisc(*arguments)

    def YieldMat(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]])
        return self.com_object.YieldMat(*arguments)

    def yieldmat(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        """Alias for YieldMat"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]
        return self.YieldMat(*arguments)

    def yield_mat(self, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None):
        """Alias for YieldMat"""
        arguments = [Arg1, Arg2, Arg3, Arg4, Arg5, Arg6]
        return self.YieldMat(*arguments)

    def ZTest(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.ZTest(*arguments)

    def ztest(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for ZTest"""
        arguments = [Arg1, Arg2, Arg3]
        return self.ZTest(*arguments)

    def z_test(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for ZTest"""
        arguments = [Arg1, Arg2, Arg3]
        return self.ZTest(*arguments)

    def Z_Test(self, Arg1=None, Arg2=None, Arg3=None):
        arguments = com_arguments([unwrap(a) for a in [Arg1, Arg2, Arg3]])
        return self.com_object.Z_Test(*arguments)

    def z_test(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Z_Test"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Z_Test(*arguments)

    def z__test(self, Arg1=None, Arg2=None, Arg3=None):
        """Alias for Z_Test"""
        arguments = [Arg1, Arg2, Arg3]
        return self.Z_Test(*arguments)


class Worksheets:

    def __init__(self, worksheets=None):
        self.com_object= worksheets

    def __call__(self, item):
        return Worksheet(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def HPageBreaks(self):
        return HPageBreaks(self.com_object.HPageBreaks)

    @property
    def hpagebreaks(self):
        """Alias for HPageBreaks"""
        return self.HPageBreaks

    @property
    def h_page_breaks(self):
        """Alias for HPageBreaks"""
        return self.HPageBreaks

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def VPageBreaks(self):
        return VPageBreaks(self.com_object.VPageBreaks)

    @property
    def vpagebreaks(self):
        """Alias for VPageBreaks"""
        return self.VPageBreaks

    @property
    def v_page_breaks(self):
        """Alias for VPageBreaks"""
        return self.VPageBreaks

    def Add(self, Before=None, After=None, Count=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Before, After, Count, Type]])
        return Worksheet(self.com_object.Add(*arguments))

    def add(self, Before=None, After=None, Count=None, Type=None):
        """Alias for Add"""
        arguments = [Before, After, Count, Type]
        return self.Add(*arguments)

    def Add2(self, Before=None, After=None, Count=None, NewLayout=None):
        arguments = com_arguments([unwrap(a) for a in [Before, After, Count, NewLayout]])
        return self.com_object.Add2(*arguments)

    def add2(self, Before=None, After=None, Count=None, NewLayout=None):
        """Alias for Add2"""
        arguments = [Before, After, Count, NewLayout]
        return self.Add2(*arguments)

    def Copy(self, Before=None, After=None):
        arguments = com_arguments([unwrap(a) for a in [Before, After]])
        self.com_object.Copy(*arguments)

    def copy(self, Before=None, After=None):
        """Alias for Copy"""
        arguments = [Before, After]
        return self.Copy(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def FillAcrossSheets(self, Range=None, Type=None):
        arguments = com_arguments([unwrap(a) for a in [Range, Type]])
        self.com_object.FillAcrossSheets(*arguments)

    def fillacrosssheets(self, Range=None, Type=None):
        """Alias for FillAcrossSheets"""
        arguments = [Range, Type]
        return self.FillAcrossSheets(*arguments)

    def fill_across_sheets(self, Range=None, Type=None):
        """Alias for FillAcrossSheets"""
        arguments = [Range, Type]
        return self.FillAcrossSheets(*arguments)

    def Move(self, Before=None, After=None):
        arguments = com_arguments([unwrap(a) for a in [Before, After]])
        self.com_object.Move(*arguments)

    def move(self, Before=None, After=None):
        """Alias for Move"""
        arguments = [Before, After]
        return self.Move(*arguments)

    def PrintOut(self, From=None, To=None, Copies=None, Preview=None, ActivePrinter=None, PrintToFile=None, Collate=None, PrToFileName=None, IgnorePrintAreas=None):
        arguments = com_arguments([unwrap(a) for a in [From, To, Copies, Preview, ActivePrinter, PrintToFile, Collate, PrToFileName, IgnorePrintAreas]])
        return self.com_object.PrintOut(*arguments)

    def printout(self, From=None, To=None, Copies=None, Preview=None, ActivePrinter=None, PrintToFile=None, Collate=None, PrToFileName=None, IgnorePrintAreas=None):
        """Alias for PrintOut"""
        arguments = [From, To, Copies, Preview, ActivePrinter, PrintToFile, Collate, PrToFileName, IgnorePrintAreas]
        return self.PrintOut(*arguments)

    def print_out(self, From=None, To=None, Copies=None, Preview=None, ActivePrinter=None, PrintToFile=None, Collate=None, PrToFileName=None, IgnorePrintAreas=None):
        """Alias for PrintOut"""
        arguments = [From, To, Copies, Preview, ActivePrinter, PrintToFile, Collate, PrToFileName, IgnorePrintAreas]
        return self.PrintOut(*arguments)

    def PrintPreview(self, EnableChanges=None):
        arguments = com_arguments([unwrap(a) for a in [EnableChanges]])
        self.com_object.PrintPreview(*arguments)

    def printpreview(self, EnableChanges=None):
        """Alias for PrintPreview"""
        arguments = [EnableChanges]
        return self.PrintPreview(*arguments)

    def print_preview(self, EnableChanges=None):
        """Alias for PrintPreview"""
        arguments = [EnableChanges]
        return self.PrintPreview(*arguments)

    def Select(self, Replace=None):
        arguments = com_arguments([unwrap(a) for a in [Replace]])
        self.com_object.Select(*arguments)

    def select(self, Replace=None):
        """Alias for Select"""
        arguments = [Replace]
        return self.Select(*arguments)


class WorksheetView:

    def __init__(self, worksheetview=None):
        self.com_object= worksheetview

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DisplayFormulas(self):
        return self.com_object.DisplayFormulas

    @DisplayFormulas.setter
    def DisplayFormulas(self, value):
        self.com_object.DisplayFormulas = value

    @property
    def displayformulas(self):
        """Alias for DisplayFormulas"""
        return self.DisplayFormulas

    @displayformulas.setter
    def displayformulas(self, value):
        """Alias for DisplayFormulas.setter"""
        self.DisplayFormulas = value

    @property
    def display_formulas(self):
        """Alias for DisplayFormulas"""
        return self.DisplayFormulas

    @display_formulas.setter
    def display_formulas(self, value):
        """Alias for DisplayFormulas.setter"""
        self.DisplayFormulas = value

    @property
    def DisplayGridlines(self):
        return self.com_object.DisplayGridlines

    @DisplayGridlines.setter
    def DisplayGridlines(self, value):
        self.com_object.DisplayGridlines = value

    @property
    def displaygridlines(self):
        """Alias for DisplayGridlines"""
        return self.DisplayGridlines

    @displaygridlines.setter
    def displaygridlines(self, value):
        """Alias for DisplayGridlines.setter"""
        self.DisplayGridlines = value

    @property
    def display_gridlines(self):
        """Alias for DisplayGridlines"""
        return self.DisplayGridlines

    @display_gridlines.setter
    def display_gridlines(self, value):
        """Alias for DisplayGridlines.setter"""
        self.DisplayGridlines = value

    @property
    def DisplayHeadings(self):
        return self.com_object.DisplayHeadings

    @DisplayHeadings.setter
    def DisplayHeadings(self, value):
        self.com_object.DisplayHeadings = value

    @property
    def displayheadings(self):
        """Alias for DisplayHeadings"""
        return self.DisplayHeadings

    @displayheadings.setter
    def displayheadings(self, value):
        """Alias for DisplayHeadings.setter"""
        self.DisplayHeadings = value

    @property
    def display_headings(self):
        """Alias for DisplayHeadings"""
        return self.DisplayHeadings

    @display_headings.setter
    def display_headings(self, value):
        """Alias for DisplayHeadings.setter"""
        self.DisplayHeadings = value

    @property
    def DisplayOutline(self):
        return self.com_object.DisplayOutline

    @DisplayOutline.setter
    def DisplayOutline(self, value):
        self.com_object.DisplayOutline = value

    @property
    def displayoutline(self):
        """Alias for DisplayOutline"""
        return self.DisplayOutline

    @displayoutline.setter
    def displayoutline(self, value):
        """Alias for DisplayOutline.setter"""
        self.DisplayOutline = value

    @property
    def display_outline(self):
        """Alias for DisplayOutline"""
        return self.DisplayOutline

    @display_outline.setter
    def display_outline(self, value):
        """Alias for DisplayOutline.setter"""
        self.DisplayOutline = value

    @property
    def DisplayZeros(self):
        return self.com_object.DisplayZeros

    @DisplayZeros.setter
    def DisplayZeros(self, value):
        self.com_object.DisplayZeros = value

    @property
    def displayzeros(self):
        """Alias for DisplayZeros"""
        return self.DisplayZeros

    @displayzeros.setter
    def displayzeros(self, value):
        """Alias for DisplayZeros.setter"""
        self.DisplayZeros = value

    @property
    def display_zeros(self):
        """Alias for DisplayZeros"""
        return self.DisplayZeros

    @display_zeros.setter
    def display_zeros(self, value):
        """Alias for DisplayZeros.setter"""
        self.DisplayZeros = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Sheet(self):
        return WorksheetView(self.com_object.Sheet)

    @property
    def sheet(self):
        """Alias for Sheet"""
        return self.Sheet


# XlAboveBelow enumeration
xlAboveAverage = 0
xlAboveStdDev = 4
xlBelowAverage = 1
xlBelowStdDev = 5
xlEqualAboveAverage = 2
xlEqualBelowAverage = 3

# XlActionType enumeration
xlActionTypeDrillthrough = 256
xlActionTypeReport = 128
xlActionTypeRowset = 16
xlActionTypeUrl = 1

# XlAllocation enumeration
xlAutomaticAllocation = 2
xlManualAllocation = 1

# XlAllocationMethod enumeration
xlEqualAllocation = 1
xlWeightedAllocation = 2

# XlAllocationValue enumeration
xlAllocateIncrement = 2
xlAllocateValue = 1

# XlApplicationInternational enumeration
xl24HourClock = 33
xl4DigitYears = 43
xlAlternateArraySeparator = 16
xlColumnSeparator = 14
xlCountryCode = 1
xlCountrySetting = 2
xlCurrencyBefore = 37
xlCurrencyCode = 25
xlCurrencyDigits = 27
xlCurrencyLeadingZeros = 40
xlCurrencyMinusSign = 38
xlCurrencyNegative = 28
xlCurrencySpaceBefore = 36
xlCurrencyTrailingZeros = 39
xlDateOrder = 32
xlDateSeparator = 17
xlDayCode = 21
xlDayLeadingZero = 42
xlDecimalSeparator = 3
xlGeneralFormatName = 26
xlHourCode = 22
xlLeftBrace = 12
xlLeftBracket = 10
xlListSeparator = 5
xlLowerCaseColumnLetter = 9
xlLowerCaseRowLetter = 8
xlMDY = 44
xlMetric = 35
xlMinuteCode = 23
xlMonthCode = 20
xlMonthLeadingZero = 41
xlMonthNameChars = 30
xlNoncurrencyDigits = 29
xlNonEnglishFunctions = 34
xlRightBrace = 13
xlRightBracket = 11
xlRowSeparator = 15
xlSecondCode = 24
xlThousandsSeparator = 4
xlTimeLeadingZero = 45
xlTimeSeparator = 18
xlUpperCaseColumnLetter = 7
xlUpperCaseRowLetter = 6
xlWeekdayNameChars = 31
xlYearCode = 19

# XlApplyNamesOrder enumeration
xlColumnThenRow = 2
xlRowThenColumn = 1

# XlArabicModes enumeration
xlArabicBothStrict = 3
xlArabicNone = 0
xlArabicStrictAlefHamza = 1
xlArabicStrictFinalYaa = 2

# XlArrangeStyle enumeration
xlArrangeStyleCascade = 7
xlArrangeStyleHorizontal = -4128
xlArrangeStyleTiled = 1
xlArrangeStyleVertical = -4166

# XlArrowHeadLength enumeration
xlArrowHeadLengthLong = 3
xlArrowHeadLengthMedium = -4138
xlArrowHeadLengthShort = 1

# XlArrowHeadStyle enumeration
xlArrowHeadStyleClosed = 3
xlArrowHeadStyleDoubleClosed = 5
xlArrowHeadStyleDoubleOpen = 4
xlArrowHeadStyleNone = -4142
xlArrowHeadStyleOpen = 2

# XlArrowHeadWidth enumeration
xlArrowHeadWidthMedium = -4138
xlArrowHeadWidthNarrow = 1
xlArrowHeadWidthWide = 3

# XlAutoFillType enumeration
xlFillCopy = 1
xlFillDays = 5
xlFillDefault = 0
xlFillFormats = 3
xlFillMonths = 7
xlFillSeries = 2
xlFillValues = 4
xlFillWeekdays = 6
xlFillYears = 8
xlGrowthTrend = 10
xlLinearTrend = 9
xlFlashFill = 11

# XlAutoFilterOperator enumeration
xlAnd = 1
xlBottom10Items = 4
xlBottom10Percent = 6
xlFilterCellColor = 8
xlFilterDynamic = 11
xlFilterFontColor = 9
xlFilterIcon = 10
xlFilterValues = 7
xlOr = 2
xlTop10Items = 3
xlTop10Percent = 5

# XlAxisCrosses enumeration
xlAxisCrossesAutomatic = -4105
xlAxisCrossesCustom = -4114
xlAxisCrossesMaximum = 2
xlAxisCrossesMinimum = 4

# XlAxisGroup enumeration
xlPrimary = 1
xlSecondary = 2

# XlAxisType enumeration
xlCategory = 1
xlSeriesAxis = 3
xlValue = 2

# XlBackground enumeration
xlBackgroundAutomatic = -4105
xlBackgroundOpaque = 3
xlBackgroundTransparent = 2

# XlBarShape enumeration
xlBox = 0
xlConeToMax = 5
xlConeToPoint = 4
xlCylinder = 3
xlPyramidToMax = 2
xlPyramidToPoint = 1

# XlBordersIndex enumeration
xlDiagonalDown = 5
xlDiagonalUp = 6
xlEdgeBottom = 9
xlEdgeLeft = 7
xlEdgeRight = 10
xlEdgeTop = 8
xlInsideHorizontal = 12
xlInsideVertical = 11

# XlBorderWeight enumeration
xlHairline = 1
xlMedium = -4138
xlThick = 4
xlThin = 2

# XlBuiltInDialog enumeration
xlDialogActivate = 103
xlDialogActiveCellFont = 476
xlDialogAddChartAutoformat = 390
xlDialogAddinManager = 321
xlDialogAlignment = 43
xlDialogApplyNames = 133
xlDialogApplyStyle = 212
xlDialogAppMove = 170
xlDialogAppSize = 171
xlDialogArrangeAll = 12
xlDialogAssignToObject = 213
xlDialogAssignToTool = 293
xlDialogAttachText = 80
xlDialogAttachToolbars = 323
xlDialogAutoCorrect = 485
xlDialogAxes = 78
xlDialogBorder = 45
xlDialogCalculation = 32
xlDialogCellProtection = 46
xlDialogChangeLink = 166
xlDialogChartAddData = 392
xlDialogChartLocation = 527
xlDialogChartOptionsDataLabelMultiple = 724
xlDialogChartOptionsDataLabels = 505
xlDialogChartOptionsDataTable = 506
xlDialogChartSourceData = 540
xlDialogChartTrend = 350
xlDialogChartType = 526
xlDialogChartWizard = 288
xlDialogCheckboxProperties = 435
xlDialogClear = 52
xlDialogColorPalette = 161
xlDialogColumnWidth = 47
xlDialogCombination = 73
xlDialogConditionalFormatting = 583
xlDialogConsolidate = 191
xlDialogCopyChart = 147
xlDialogCopyPicture = 108
xlDialogCreateList = 796
xlDialogCreateNames = 62
xlDialogCreatePublisher = 217
xlDialogCreateRelationship = 1272
xlDialogCustomizeToolbar = 276
xlDialogCustomViews = 493
xlDialogDataDelete = 36
xlDialogDataLabel = 379
xlDialogDataLabelMultiple = 723
xlDialogDataSeries = 40
xlDialogDataValidation = 525
xlDialogDefineName = 61
xlDialogDefineStyle = 229
xlDialogDeleteFormat = 111
xlDialogDeleteName = 110
xlDialogDemote = 203
xlDialogDisplay = 27
xlDialogDocumentInspector = 862
xlDialogEditboxProperties = 438
xlDialogEditColor = 223
xlDialogEditDelete = 54
xlDialogEditionOptions = 251
xlDialogEditSeries = 228
xlDialogErrorbarX = 463
xlDialogErrorbarY = 464
xlDialogErrorChecking = 732
xlDialogEvaluateFormula = 709
xlDialogExternalDataProperties = 530
xlDialogExtract = 35
xlDialogFileDelete = 6
xlDialogFileSharing = 481
xlDialogFillGroup = 200
xlDialogFillWorkgroup = 301
xlDialogFilter = 447
xlDialogFilterAdvanced = 370
xlDialogFindFile = 475
xlDialogFont = 26
xlDialogFontProperties = 381
xlDialogFormatAuto = 269
xlDialogFormatChart = 465
xlDialogFormatCharttype = 423
xlDialogFormatFont = 150
xlDialogFormatLegend = 88
xlDialogFormatMain = 225
xlDialogFormatMove = 128
xlDialogFormatNumber = 42
xlDialogFormatOverlay = 226
xlDialogFormatSize = 129
xlDialogFormatText = 89
xlDialogFormulaFind = 64
xlDialogFormulaGoto = 63
xlDialogFormulaReplace = 130
xlDialogFunctionWizard = 450
xlDialogGallery3dArea = 193
xlDialogGallery3dBar = 272
xlDialogGallery3dColumn = 194
xlDialogGallery3dLine = 195
xlDialogGallery3dPie = 196
xlDialogGallery3dSurface = 273
xlDialogGalleryArea = 67
xlDialogGalleryBar = 68
xlDialogGalleryColumn = 69
xlDialogGalleryCustom = 388
xlDialogGalleryDoughnut = 344
xlDialogGalleryLine = 70
xlDialogGalleryPie = 71
xlDialogGalleryRadar = 249
xlDialogGalleryScatter = 72
xlDialogGoalSeek = 198
xlDialogGridlines = 76
xlDialogImportTextFile = 666
xlDialogInsert = 55
xlDialogInsertHyperlink = 596
xlDialogInsertObject = 259
xlDialogInsertPicture = 342
xlDialogInsertTitle = 380
xlDialogLabelProperties = 436
xlDialogListboxProperties = 437
xlDialogMacroOptions = 382
xlDialogMailEditMailer = 470
xlDialogMailLogon = 339
xlDialogMailNextLetter = 378
xlDialogMainChart = 85
xlDialogMainChartType = 185
xlDialogManageRelationships = 1271
xlDialogMenuEditor = 322
xlDialogMove = 262
xlDialogMyPermission = 834
xlDialogNameManager = 977
xlDialogNew = 119
xlDialogNewName = 978
xlDialogNewWebQuery = 667
xlDialogNote = 154
xlDialogObjectProperties = 207
xlDialogObjectProtection = 214
xlDialogOpen = 1
xlDialogOpenLinks = 2
xlDialogOpenMail = 188
xlDialogOpenText = 441
xlDialogOptionsCalculation = 318
xlDialogOptionsChart = 325
xlDialogOptionsEdit = 319
xlDialogOptionsGeneral = 356
xlDialogOptionsListsAdd = 458
xlDialogOptionsME = 647
xlDialogOptionsTransition = 355
xlDialogOptionsView = 320
xlDialogOutline = 142
xlDialogOverlay = 86
xlDialogOverlayChartType = 186
xlDialogPageSetup = 7
xlDialogParse = 91
xlDialogPasteNames = 58
xlDialogPasteSpecial = 53
xlDialogPatterns = 84
xlDialogPermission = 832
xlDialogPhonetic = 656
xlDialogPivotCalculatedField = 570
xlDialogPivotCalculatedItem = 572
xlDialogPivotClientServerSet = 689
xlDialogPivotFieldGroup = 433
xlDialogPivotFieldProperties = 313
xlDialogPivotFieldUngroup = 434
xlDialogPivotShowPages = 421
xlDialogPivotSolveOrder = 568
xlDialogPivotTableOptions = 567
xlDialogPivotTableSlicerConnections = 1183
xlDialogPivotTableWhatIfAnalysisSettings = 1153
xlDialogPivotTableWizard = 312
xlDialogPlacement = 300
xlDialogPrint = 8
xlDialogPrinterSetup = 9
xlDialogPrintPreview = 222
xlDialogPromote = 202
xlDialogProperties = 474
xlDialogPropertyFields = 754
xlDialogProtectDocument = 28
xlDialogProtectSharing = 620
xlDialogPublishAsWebPage = 653
xlDialogPushbuttonProperties = 445
xlDialogRecommendedPivotTables = 1258
xlDialogReplaceFont = 134
xlDialogRoutingSlip = 336
xlDialogRowHeight = 127
xlDialogRun = 17
xlDialogSaveAs = 5
xlDialogSaveCopyAs = 456
xlDialogSaveNewObject = 208
xlDialogSaveWorkbook = 145
xlDialogSaveWorkspace = 285
xlDialogScale = 87
xlDialogScenarioAdd = 307
xlDialogScenarioCells = 305
xlDialogScenarioEdit = 308
xlDialogScenarioMerge = 473
xlDialogScenarioSummary = 311
xlDialogScrollbarProperties = 420
xlDialogSearch = 731
xlDialogSelectSpecial = 132
xlDialogSendMail = 189
xlDialogSeriesAxes = 460
xlDialogSeriesOptions = 557
xlDialogSeriesOrder = 466
xlDialogSeriesShape = 504
xlDialogSeriesX = 461
xlDialogSeriesY = 462
xlDialogSetBackgroundPicture = 509
xlDialogSetManager = 1109
xlDialogSetMDXEditor = 1208
xlDialogSetPrintTitles = 23
xlDialogSetTupleEditorOnColumns = 1108
xlDialogSetTupleEditorOnRows = 1107
xlDialogSetUpdateStatus = 159
xlDialogShowDetail = 204
xlDialogShowToolbar = 220
xlDialogSize = 261
xlDialogSlicerCreation = 1182
xlDialogSlicerPivotTableConnections = 1184
xlDialogSlicerSettings = 1179
xlDialogSort = 39
xlDialogSortSpecial = 192
xlDialogSparklineInsertColumn = 1134
xlDialogSparklineInsertLine = 1133
xlDialogSparklineInsertWinLoss = 1135
xlDialogSplit = 137
xlDialogStandardFont = 190
xlDialogStandardWidth = 472
xlDialogStyle = 44
xlDialogSubscribeTo = 218
xlDialogSubtotalCreate = 398
xlDialogSummaryInfo = 474
xlDialogTable = 41
xlDialogTabOrder = 394
xlDialogTextToColumns = 422
xlDialogUnhide = 94
xlDialogUpdateLink = 201
xlDialogVbaInsertFile = 328
xlDialogVbaMakeAddin = 478
xlDialogVbaProcedureDefinition = 330
xlDialogView3d = 197
xlDialogWebOptionsBrowsers = 773
xlDialogWebOptionsEncoding = 686
xlDialogWebOptionsFiles = 684
xlDialogWebOptionsFonts = 687
xlDialogWebOptionsGeneral = 683
xlDialogWebOptionsPictures = 685
xlDialogWindowMove = 14
xlDialogWindowSize = 13
xlDialogWorkbookAdd = 281
xlDialogWorkbookCopy = 283
xlDialogWorkbookInsert = 354
xlDialogWorkbookMove = 282
xlDialogWorkbookName = 386
xlDialogWorkbookNew = 302
xlDialogWorkbookOptions = 284
xlDialogWorkbookProtect = 417
xlDialogWorkbookTabSplit = 415
xlDialogWorkbookUnhide = 384
xlDialogWorkgroup = 199
xlDialogWorkspace = 95
xlDialogZoom = 256

# XlCalcFor enumeration
xlAllValues = 0
xlColGroups = 2
xlRowGroups = 1

# XlCalculatedMemberType enumeration
xlCalculatedMeasure = 2
xlCalculatedMember = 0
xlCalculatedSet = 1

# XlCalculation enumeration
xlCalculationAutomatic = -4105
xlCalculationManual = -4135
xlCalculationSemiautomatic = 2

# XlCalculationInterruptKey enumeration
xlAnyKey = 2
xlEscKey = 1
xlNoKey = 0

# XlCalculationState enumeration
xlCalculating = 1
xlDone = 0
xlPending = 2

# XlCategoryType enumeration
xlAutomaticScale = -4105
xlCategoryScale = 2
xlTimeScale = 3

# XlCellChangedState enumeration
xlCellChangeApplied = 3
xlCellChanged = 2
xlCellNotChanged = 1

# XlCellInsertionMode enumeration
xlInsertDeleteCells = 1
xlInsertEntireRows = 2
xlOverwriteCells = 0

# XlCellType enumeration
xlCellTypeAllFormatConditions = -4172
xlCellTypeAllValidation = -4174
xlCellTypeBlanks = 4
xlCellTypeComments = -4144
xlCellTypeConstants = 2
xlCellTypeFormulas = -4123
xlCellTypeLastCell = 11
xlCellTypeSameFormatConditions = -4173
xlCellTypeSameValidation = -4175
xlCellTypeVisible = 12

# XlChartElementPosition enumeration
xlChartElementPositionAutomatic = -4105
xlChartElementPositionCustom = -4114

# XlChartGallery enumeration
xlAnyGallery = 23
xlBuiltIn = 21
xlUserDefined = 22

# XlChartItem enumeration
xlAxis = 21
xlAxisTitle = 17
xlChartArea = 2
xlChartTitle = 4
xlCorners = 6
xlDataLabel = 0
xlDataTable = 7
xlDisplayUnitLabel = 30
xlDownBars = 20
xlDropLines = 26
xlErrorBars = 9
xlFloor = 23
xlHiLoLines = 25
xlLeaderLines = 29
xlLegend = 24
xlLegendEntry = 12
xlLegendKey = 13
xlMajorGridlines = 15
xlMinorGridlines = 16
xlNothing = 28
xlPivotChartDropZone = 32
xlPivotChartFieldButton = 31
xlPlotArea = 19
xlRadarAxisLabels = 27
xlSeries = 3
xlSeriesLines = 22
xlShape = 14
xlTrendline = 8
xlUpBars = 18
xlWalls = 5
xlXErrorBars = 10
xlYErrorBars = 11

# XlChartLocation enumeration
xlLocationAsNewSheet = 1
xlLocationAsObject = 2
xlLocationAutomatic = 3

# XlChartPicturePlacement enumeration
xlAllFaces = 7
xlEnd = 2
xlEndSides = 3
xlFront = 4
xlFrontEnd = 6
xlFrontSides = 5
xlSides = 1

# XlChartPictureType enumeration
xlStack = 2
xlStackScale = 3
xlStretch = 1

# XlChartSplitType enumeration
xlSplitByCustomSplit = 4
xlSplitByPercentValue = 3
xlSplitByPosition = 1
xlSplitByValue = 2

# XlChartType enumeration
xl3DArea = -4098
xl3DAreaStacked = 78
xl3DAreaStacked100 = 79
xl3DBarClustered = 60
xl3DBarStacked = 61
xl3DBarStacked100 = 62
xl3DColumn = -4100
xl3DColumnClustered = 54
xl3DColumnStacked = 55
xl3DColumnStacked100 = 56
xl3DLine = -4101
xl3DPie = -4102
xl3DPieExploded = 70
xlArea = 1
xlAreaEx = 135
xlAreaStacked = 76
xlAreaStacked100 = 77
xlAreaStacked100Ex = 137
xlAreaStackedEx = 136
xlBarClustered = 57
xlBarClusteredEx = 132
xlBarOfPie = 71
xlBarStacked = 58
xlBarStacked100 = 59
xlBarStacked100Ex = 134
xlBarStackedEx = 133
xlBoxwhisker = 121
xlBubble = 15
xlBubble3DEffect = 87
xlBubbleEx = 139
xlColumnClustered = 51
xlColumnClusteredEx = 124
xlColumnStacked = 52
xlColumnStacked100 = 53
xlColumnStacked100Ex = 126
xlColumnStackedEx = 125
xlCombo = -4152
xlComboAreaStackedColumnClustered = 115
xlComboColumnClusteredLine = 113
xlComboColumnClusteredLineSecondaryAxis = 114
xlConeBarClustered = 102
xlConeBarStacked = 103
xlConeBarStacked100 = 104
xlConeCol = 105
xlConeColClustered = 99
xlConeColStacked = 100
xlConeColStacked100 = 101
xlCylinderBarClustered = 95
xlCylinderBarStacked = 96
xlCylinderBarStacked100 = 97
xlCylinderCol = 98
xlCylinderColClustered = 92
xlCylinderColStacked = 93
xlCylinderColStacked100 = 94
xlDoughnut = -4120
xlDoughnutEx = 131
xlDoughnutExploded = 80
xlFunnel = 123
xlHistogram = 118
xlLine = 4
xlLineEx = 127
xlLineMarkers = 65
xlLineMarkersStacked = 66
xlLineMarkersStacked100 = 67
xlLineStacked = 63
xlLineStacked100 = 64
xlLineStacked100Ex = 129
xlLineStackedEx = 128
xlOtherCombinations = 116
xlPareto = 122
xlPie = 5
xlPieEx = 130
xlPieExploded = 69
xlPieOfPie = 68
xlPyramidBarClustered = 109
xlPyramidBarStacked = 110
xlPyramidBarStacked100 = 111
xlPyramidCol = 112
xlPyramidColClustered = 106
xlPyramidColStacked = 107
xlPyramidColStacked100 = 108
xlRadar = -4151
xlRadarFilled = 82
xlRadarMarkers = 81
xlRegionMap = 140
xlStockHLC = 88
xlStockOHLC = 89
xlStockVHLC = 90
xlStockVOHLC = 91
xlSuggestedChart = -2
xlSunburst = 120
xlSurface = 83
xlSurfaceTopView = 85
xlSurfaceTopViewWireframe = 86
xlSurfaceWireframe = 84
xlTreemap = 117
xlWaterfall = 119
xlXYScatter = -4169
xlXYScatterEx = 138
xlXYScatterLines = 74
xlXYScatterLinesNoMarkers = 75
xlXYScatterSmooth = 72
xlXYScatterSmoothNoMarkers = 73

# XlCheckInVersionType enumeration
xlCheckInMajorVersion = 1
xlCheckInMinorVersion = 0
xlCheckInOverwriteVersion = 2

# XlClipboardFormat enumeration
xlClipboardFormatBIFF = 8
xlClipboardFormatBIFF12 = 63
xlClipboardFormatBIFF2 = 18
xlClipboardFormatBIFF3 = 20
xlClipboardFormatBIFF4 = 30
xlClipboardFormatBinary = 15
xlClipboardFormatBitmap = 9
xlClipboardFormatCGM = 13
xlClipboardFormatCSV = 5
xlClipboardFormatDIF = 4
xlClipboardFormatDspText = 12
xlClipboardFormatEmbeddedObject = 21
xlClipboardFormatEmbedSource = 22
xlClipboardFormatLink = 11
xlClipboardFormatLinkSource = 23
xlClipboardFormatLinkSourceDesc = 32
xlClipboardFormatMovie = 24
xlClipboardFormatNative = 14
xlClipboardFormatObjectDesc = 31
xlClipboardFormatObjectLink = 19
xlClipboardFormatOwnerLink = 17
xlClipboardFormatPICT = 2
xlClipboardFormatPrintPICT = 3
xlClipboardFormatRTF = 7
xlClipboardFormatScreenPICT = 29
xlClipboardFormatStandardFont = 28
xlClipboardFormatStandardScale = 27
xlClipboardFormatSYLK = 6
xlClipboardFormatTable = 16
xlClipboardFormatText = 0
xlClipboardFormatToolFace = 25
xlClipboardFormatToolFacePICT = 26
xlClipboardFormatVALU = 1
xlClipboardFormatWK1 = 10

# XlCmdType enumeration
xlCmdCube = 1
xlCmdDAX = 8
xlCmdDefault = 4
xlCmdExcel = 7
xlCmdList = 5
xlCmdSql = 2
xlCmdTable = 3
xlCmdTableCollection = 6

# XlColorIndex enumeration
xlColorIndexAutomatic = -4105
xlColorIndexNone = -4142

# XlColumnDataType enumeration
xlDMYFormat = 4
xlDYMFormat = 7
xlEMDFormat = 10
xlGeneralFormat = 1
xlMDYFormat = 3
xlMYDFormat = 6
xlSkipColumn = 9
xlTextFormat = 2
xlYDMFormat = 8
xlYMDFormat = 5

# XlCommandUnderlines enumeration
xlCommandUnderlinesAutomatic = -4105
xlCommandUnderlinesOff = -4146
xlCommandUnderlinesOn = 1

# XlCommentDisplayMode enumeration
xlCommentAndIndicator = 1
xlCommentIndicatorOnly = -1
xlNoIndicator = 0

# XlConditionValueTypes enumeration
xlConditionValueAutomaticMax = 7
xlConditionValueAutomaticMin = 6
xlConditionValueFormula = 4
xlConditionValueHighestValue = 2
xlConditionValueLowestValue = 1
xlConditionValueNone = -1
xlConditionValueNumber = 0
xlConditionValuePercent = 3
xlConditionValuePercentile = 5

# XlConnectionType enumeration
xlConnectionTypeDATAFEED = 6
xlConnectionTypeMODEL = 7
xlConnectionTypeNOSOURCE = 9
xlConnectionTypeODBC = 2
xlConnectionTypeOLEDB = 1
xlConnectionTypeTEXT = 4
xlConnectionTypeWEB = 5
xlConnectionTypeWORKSHEET = 8
xlConnectionTypeXMLMAP = 3

# XlConsolidationFunction enumeration
xlAverage = -4106
xlCount = -4112
xlCountNums = -4113
xlDistinctCount = 11
xlMax = -4136
xlMin = -4139
xlProduct = -4149
xlStDev = -4155
xlStDevP = -4156
xlSum = -4157
xlUnknown = 1000
xlVar = -4164
xlVarP = -4165

# XlContainsOperator enumeration
xlBeginsWith = 2
xlContains = 0
xlDoesNotContain = 1
xlEndsWith = 3

# XlCopyPictureFormat enumeration
xlBitmap = 2
xlPicture = -4147

# XlCorruptLoad enumeration
xlExtractData = 2
xlNormalLoad = 0
xlRepairFile = 1

# XlCreator enumeration
xlCreatorCode = 1480803660

# XlCredentialsMethod enumeration
CredentialsMethodIntegrated = 0
CredentialsMethodNone = 1
CredentialsMethodStored = 2

# XlCubeFieldSubType enumeration
xlCubeAttribute = 4
xlCubeCalculatedMeasure = 5
xlCubeHierarchy = 1
xlCubeImplicitMeasure = 11
xlCubeKPIGoal = 7
xlCubeKPIStatus = 8
xlCubeKPITrend = 9
xlCubeKPIValue = 6
xlCubeKPIWeight = 10
xlCubeMeasure = 2
xlCubeSet = 3

# XlCubeFieldType enumeration
xlHierarchy = 1
xlMeasure = 2
xlSet = 3

# XlCutCopyMode enumeration
xlCopy = 1
xlCut = 2

# XlCVError enumeration
xlErrDiv0 = 2007
xlErrNA = 2042
xlErrName = 2029
xlErrNull = 2000
xlErrNum = 2036
xlErrRef = 2023
xlErrValue = 2015
xlErrSpill = 2045

# XlDataBarAxisPosition enumeration
xlDataBarAxisAutomatic = 0
xlDataBarAxisMidpoint = 1
xlDataBarAxisNone = 2

# XlDataBarBorderType enumeration
xlDataBarBorderNone = 0
xlDataBarBorderSolid = 1

# XlDataBarFillType enumeration
xlDataBarFillGradient = 1
xlDataBarFillSolid = 0

# XlDataBarNegativeColorType enumeration
xlDataBarColor = 0
xlDataBarSameAsPositive = 1

# XlDataLabelPosition enumeration
xlLabelPositionAbove = 0
xlLabelPositionBelow = 1
xlLabelPositionBestFit = 5
xlLabelPositionCenter = -4108
xlLabelPositionCustom = 7
xlLabelPositionInsideBase = 4
xlLabelPositionInsideEnd = 3
xlLabelPositionLeft = -4131
xlLabelPositionMixed = 6
xlLabelPositionOutsideEnd = 2
xlLabelPositionRight = -4152

# XlDataLabelSeparator enumeration
xlDataLabelSeparatorDefault = 1

# XlDataLabelsType enumeration
xlDataLabelsShowBubbleSizes = 6
xlDataLabelsShowLabel = 4
xlDataLabelsShowLabelAndPercent = 5
xlDataLabelsShowNone = -4142
xlDataLabelsShowPercent = 3
xlDataLabelsShowValue = 2

# XlDataSeriesDate enumeration
xlDay = 1
xlMonth = 3
xlWeekday = 2
xlYear = 4

# XlDataSeriesType enumeration
xlAutoFill = 4
xlChronological = 3
xlDataSeriesLinear = -4132
xlGrowth = 2

# XlDeleteShiftDirection enumeration
xlShiftToLeft = -4159
xlShiftUp = -4162

# XlDirection enumeration
xlDown = -4121
xlToLeft = -4159
xlToRight = -4161
xlUp = -4162

# XlDisplayBlanksAs enumeration
xlInterpolated = 3
xlNotPlotted = 1
xlZero = 2

# XlDisplayDrawingObjects enumeration
xlDisplayShapes = -4104
xlHide = 3
xlPlaceholders = 2

# XlDisplayUnit enumeration
xlHundredMillions = -8
xlHundreds = -2
xlHundredThousands = -5
xlMillionMillions = -10
xlMillions = -6
xlTenMillions = -7
xlTenThousands = -4
xlThousandMillions = -9
xlThousands = -3

# XlDupeUnique enumeration
xlDuplicate = 1
xlUnique = 0

# XlDVAlertStyle enumeration
xlValidAlertInformation = 3
xlValidAlertStop = 1
xlValidAlertWarning = 2

# XlDVType enumeration
xlValidateCustom = 7
xlValidateDate = 4
xlValidateDecimal = 2
xlValidateInputOnly = 0
xlValidateList = 3
xlValidateTextLength = 6
xlValidateTime = 5
xlValidateWholeNumber = 1

# XlDynamicFilterCriteria enumeration
xlFilterAboveAverage = 33
xlFilterAllDatesInPeriodApril = 24
xlFilterAllDatesInPeriodAugust = 28
xlFilterAllDatesInPeriodDecember = 32
xlFilterAllDatesInPeriodFebruary = 22
xlFilterAllDatesInPeriodJanuary = 21
xlFilterAllDatesInPeriodJuly = 27
xlFilterAllDatesInPeriodJune = 26
xlFilterAllDatesInPeriodMarch = 23
xlFilterAllDatesInPeriodMay = 25
xlFilterAllDatesInPeriodNovember = 31
xlFilterAllDatesInPeriodOctober = 30
xlFilterAllDatesInPeriodQuarter1 = 17
xlFilterAllDatesInPeriodQuarter2 = 18
xlFilterAllDatesInPeriodQuarter3 = 19
xlFilterAllDatesInPeriodQuarter4 = 20
xlFilterAllDatesInPeriodSeptember = 29
xlFilterBelowAverage = 34
xlFilterLastMonth = 8
xlFilterLastQuarter = 11
xlFilterLastWeek = 5
xlFilterLastYear = 14
xlFilterNextMonth = 9
xlFilterNextQuarter = 12
xlFilterNextWeek = 6
xlFilterNextYear = 15
xlFilterThisMonth = 7
xlFilterThisQuarter = 10
xlFilterThisWeek = 4
xlFilterThisYear = 13
xlFilterToday = 1
xlFilterTomorrow = 3
xlFilterYearToDate = 16
xlFilterYesterday = 2

# XlEditionFormat enumeration
xlBIFF = 2
xlPICT = 1
xlRTF = 4
xlVALU = 8

# XlEditionOptionsOption enumeration
xlAutomaticUpdate = 4
xlCancel = 1
xlChangeAttributes = 6
xlManualUpdate = 5
xlOpenSource = 3
xlSelect = 3
xlSendPublisher = 2
xlUpdateSubscriber = 2

# XlEditionType enumeration
xlPublisher = 1
xlSubscriber = 2

# XlEnableCancelKey enumeration
xlDisabled = 0
xlErrorHandler = 2
xlInterrupt = 1

# XlEnableSelection enumeration
xlNoRestrictions = 0
xlNoSelection = -4142
xlUnlockedCells = 1

# XlEndStyleCap enumeration
xlCap = 1
xlNoCap = 2

# XlErrorBarDirection enumeration
xlX = -4168
xlY = 1

# XlErrorBarInclude enumeration
xlErrorBarIncludeBoth = 1
xlErrorBarIncludeMinusValues = 3
xlErrorBarIncludeNone = -4142
xlErrorBarIncludePlusValues = 2

# XlErrorBarType enumeration
xlErrorBarTypeCustom = -4114
xlErrorBarTypeFixedValue = 1
xlErrorBarTypePercent = 2
xlErrorBarTypeStDev = -4155
xlErrorBarTypeStError = 4

# XlErrorChecks enumeration
xlEmptyCellReferences = 7
xlEvaluateToError = 1
xlInconsistentFormula = 4
xlInconsistentListFormula = 9
xlListDataValidation = 8
xlNumberAsText = 3
xlOmittedCells = 5
xlStaleValue = 12
xlTextDate = 2
xlUnlockedFormulaCells = 6

# XlFileAccess enumeration
xlReadOnly = 3
xlReadWrite = 2

# XlFileFormat enumeration
xlAddIn = 18
xlAddIn8 = 18
xlCSV = 6
xlCSVMac = 22
xlCSVMSDOS = 24
xlCSVUTF8 = 62
xlCSVWindows = 23
xlCurrentPlatformText = -4158
xlDBF2 = 7
xlDBF3 = 8
xlDBF4 = 11
xlDIF = 9
xlExcel12 = 50
xlExcel2 = 16
xlExcel2FarEast = 27
xlExcel3 = 29
xlExcel4 = 33
xlExcel4Workbook = 35
xlExcel5 = 39
xlExcel7 = 39
xlExcel8 = 56
xlExcel9795 = 43
xlHtml = 44
xlIntlAddIn = 26
xlIntlMacro = 25
xlOpenDocumentSpreadsheet = 60
xlOpenXMLAddIn = 55
xlOpenXMLStrictWorkbook = "61 (&H3D)"
xlOpenXMLTemplate = 54
xlOpenXMLTemplateMacroEnabled = 53
xlOpenXMLWorkbook = 51
xlOpenXMLWorkbookMacroEnabled = 52
xlSYLK = 2
xlTemplate = 17
xlTemplate8 = 17
xlTextMac = 19
xlTextMSDOS = 21
xlTextPrinter = 36
xlTextWindows = 20
xlUnicodeText = 42
xlWebArchive = 45
xlWJ2WD1 = 14
xlWJ3 = 40
xlWJ3FJ3 = 41
xlWK1 = 5
xlWK1ALL = 31
xlWK1FMT = 30
xlWK3 = 15
xlWK3FM3 = 32
xlWK4 = 38
xlWKS = 4
xlWorkbookDefault = 51
xlWorkbookNormal = -4143
xlWorks2FarEast = 28
xlWQ1 = 34
xlXMLSpreadsheet = 46

# XlFileValidationPivotMode enumeration
xlFileValidationPivotDefault = 0
xlFileValidationPivotRun = 1
xlFileValidationPivotSkip = 2

# XlFillWith enumeration
xlFillWithAll = -4104
xlFillWithContents = 2
xlFillWithFormats = -4122

# XlFilterAction enumeration
xlFilterCopy = 2
xlFilterInPlace = 1

# XlFilterAllDatesInPeriod enumeration
xlFilterAllDatesInPeriodDay = 2
xlFilterAllDatesInPeriodHour = 3
xlFilterAllDatesInPeriodMinute = 4
xlFilterAllDatesInPeriodMonth = 1
xlFilterAllDatesInPeriodSecond = 5
xlFilterAllDatesInPeriodYear = 0

# XlFindLookIn enumeration
xlComments = -4144
xlCommentsThreaded = -4184
xlFormulas = -4123
xlValues = -4163

# XlFixedFormatQuality enumeration
xlQualityMinimum = 1
xlQualityStandard = 0

# XlFixedFormatType enumeration
xlTypePDF = 0
xlTypeXPS = 1

# XlFormatConditionOperator enumeration
xlBetween = 1
xlEqual = 3
xlGreater = 5
xlGreaterEqual = 7
xlLess = 6
xlLessEqual = 8
xlNotBetween = 2
xlNotEqual = 4

# XlFormatConditionType enumeration
xlAboveAverageCondition = 12
xlBlanksCondition = 10
xlCellValue = 1
xlColorScale = 3
xlDataBar = 4
xlErrorsCondition = 16
xlExpression = 2
xlIconSet = 6
xlNoBlanksCondition = 13
xlNoErrorsCondition = 17
xlTextString = 9
xlTimePeriod = 11
xlTop10 = 5
xlUniqueValues = 8

# XlFormatFilterTypes enumeration
FilterBottom = 0
FilterBottomPercent = 2
FilterTop = 1
FilterTopPercent = 3

# XlFormControl enumeration
xlButtonControl = 0
xlCheckBox = 1
xlDropDown = 2
xlEditBox = 3
xlGroupBox = 4
xlLabel = 5
xlListBox = 6
xlOptionButton = 7
xlScrollBar = 8
xlSpinner = 9

# XlFormulaLabel enumeration
xlColumnLabels = 2
xlMixedLabels = 3
xlNoLabels = -4142
xlRowLabels = 1

# XlGenerateTableRefs enumeration
xlA1TableRefs = 0
xlTableNames = 1

# XlGradientFillType enumeration
GradientFillLinear = 0
GradientFillPath = 1

# XlHAlign enumeration
xlHAlignCenter = -4108
xlHAlignCenterAcrossSelection = 7
xlHAlignDistributed = -4117
xlHAlignFill = 5
xlHAlignGeneral = 1
xlHAlignJustify = -4130
xlHAlignLeft = -4131
xlHAlignRight = -4152

# XlHebrewModes enumeration
xlHebrewFullScript = 0
xlHebrewMixedAuthorizedScript = 3
xlHebrewMixedScript = 2
xlHebrewPartialScript = 1

# XlHighlightChangesTime enumeration
xlAllChanges = 2
xlNotYetReviewed = 3
xlSinceMyLastSave = 1

# XlHtmlType enumeration
xlHtmlCalc = 1
xlHtmlChart = 3
xlHtmlList = 2
xlHtmlStatic = 0

# XlIcon enumeration
xlIcon0Bars = 37
xlIcon0FilledBoxes = 52
xlIcon1Bar = 38
xlIcon1FilledBox = 51
xlIcon2Bars = 39
xlIcon2FilledBoxes = 50
xlIcon3Bars = 40
xlIcon3FilledBoxes = 49
xlIcon4Bars = 41
xlIcon4FilledBoxes = 48
xlIconBlackCircle = 32
xlIconBlackCircleWithBorder = 13
xlIconCircleWithOneWhiteQuarter = 33
xlIconCircleWithThreeWhiteQuarters = 35
xlIconCircleWithTwoWhiteQuarters = 34
xlIconGoldStar = 42
xlIconGrayCircle = 31
xlIconGrayDownArrow = 6
xlIconGrayDownInclineArrow = 28
xlIconGraySideArrow = 5
xlIconGrayUpArrow = 4
xlIconGrayUpInclineArrow = 27
xlIconGreenCheck = 22
xlIconGreenCheckSymbol = 19
xlIconGreenCircle = 10
xlIconGreenFlag = 7
xlIconGreenTrafficLight = 14
xlIconGreenUpArrow = 1
xlIconGreenUpTriangle = 45
xlIconHalfGoldStar = 43
xlIconNoCellIcon = -1
xlIconPinkCircle = 30
xlIconRedCircle = 29
xlIconRedCircleWithBorder = 12
xlIconRedCross = 24
xlIconRedCrossSymbol = 21
xlIconRedDiamond = 18
xlIconRedDownArrow = 3
xlIconRedDownTriangle = 47
xlIconRedFlag = 9
xlIconRedTrafficLight = 16
xlIconSilverStar = 44
xlIconWhiteCircleAllWhiteQuarters = 36
xlIconYellowCircle = 11
xlIconYellowDash = 46
xlIconYellowDownInclineArrow = 26
xlIconYellowExclamation = 23
xlIconYellowExclamationSymbol = 20
xlIconYellowFlag = 8
xlIconYellowSideArrow = 2
xlIconYellowTrafficLight = 15
xlIconYellowTriangle = 17
xlIconYellowUpInclineArrow = 25

# XlIconSet enumeration
xl3Arrows = 1
xl3ArrowsGray = 2
xl3Flags = 3
xl3Signs = 6
xl3Symbols = 7
xl3TrafficLights1 = 4
xl3TrafficLights2 = 5
xl4Arrows = 8
xl4ArrowsGray = 9
xl4CRV = 11
xl4RedToBlack = 10
xl4TrafficLights = 12
xl5Arrows = 13
xl5ArrowsGray = 14
xl5CRV = 15
xl5Quarters = 16

# XlIMEMode enumeration
xlIMEModeAlpha = 8
xlIMEModeAlphaFull = 7
xlIMEModeDisable = 3
xlIMEModeHangul = 10
xlIMEModeHangulFull = 9
xlIMEModeHiragana = 4
xlIMEModeKatakana = 5
xlIMEModeKatakanaHalf = 6
xlIMEModeNoControl = 0
xlIMEModeOff = 2
xlIMEModeOn = 1

# XlImportDataAs enumeration
xlPivotTableReport = 1
xlQueryTable = 0

# XlInsertFormatOrigin enumeration
xlFormatFromLeftOrAbove = 0
xlFormatFromRightOrBelow = 1

# XlInsertShiftDirection enumeration
xlShiftDown = -4121
xlShiftToRight = -4161

# XlLayoutFormType enumeration
xlOutline = 1
xlTabular = 0

# XlLayoutRowType enumeration
xlCompactRow = 0
xlOutlineRow = 2
xlTabularRow = 1

# XlLegendPosition enumeration
xlLegendPositionBottom = -4107
xlLegendPositionCorner = 2
xlLegendPositionCustom = -4161
xlLegendPositionLeft = -4131
xlLegendPositionRight = -4152
xlLegendPositionTop = -4160

# XlLineStyle enumeration
xlContinuous = 1
xlDash = -4115
xlDashDot = 4
xlDashDotDot = 5
xlDot = -4118
xlDouble = -4119
xlLineStyleNone = -4142
xlSlantDashDot = 13

# XlLink enumeration
xlExcelLinks = 1
xlOLELinks = 2
xlPublishers = 5
xlSubscribers = 6

# XlLinkedDataTypeState enumeration
xlLinkedDataTypeStateNone = 0
xlLinkedDataTypeStateValidLinkedData = 1
xlLinkedDataTypeStateDisambiguationNeeded = 2
xlLinkedDataTypeStateBrokenLinkedData = 3
xlLinkedDataTypeStateFetchingData = 4

# XlLinkInfo enumeration
xlEditionDate = 2
xlLinkInfoStatus = 3
xlUpdateState = 1

# XlLinkInfoType enumeration
xlLinkInfoOLELinks = 2
xlLinkInfoPublishers = 5
xlLinkInfoSubscribers = 6

# XlLinkStatus enumeration
xlLinkStatusCopiedValues = 10
xlLinkStatusIndeterminate = 5
xlLinkStatusInvalidName = 7
xlLinkStatusMissingFile = 1
xlLinkStatusMissingSheet = 2
xlLinkStatusNotStarted = 6
xlLinkStatusOK = 0
xlLinkStatusOld = 3
xlLinkStatusSourceNotCalculated = 4
xlLinkStatusSourceNotOpen = 8
xlLinkStatusSourceOpen = 9

# XlLinkType enumeration
xlLinkTypeExcelLinks = 1
xlLinkTypeOLELinks = 2

# XlListConflict enumeration
xlListConflictDialog = 0
xlListConflictDiscardAllConflicts = 2
xlListConflictError = 3
xlListConflictRetryAllConflicts = 1

# XlListDataType enumeration
xlListDataTypeCheckbox = 9
xlListDataTypeChoice = 6
xlListDataTypeChoiceMulti = 7
xlListDataTypeCounter = 11
xlListDataTypeCurrency = 4
xlListDataTypeDateTime = 5
xlListDataTypeHyperLink = 10
xlListDataTypeListLookup = 8
xlListDataTypeMultiLineRichText = 12
xlListDataTypeMultiLineText = 2
xlListDataTypeNone = 0
xlListDataTypeNumber = 3
xlListDataTypeText = 1

# XlListObjectSourceType enumeration
xlSrcExternal = 0
xlSrcModel = 4
xlSrcQuery = 3
xlSrcRange = 1
xlSrcXml = 2

# XlLocationInTable enumeration
xlColumnHeader = -4110
xlColumnItem = 5
xlDataHeader = 3
xlDataItem = 7
xlPageHeader = 2
xlPageItem = 6
xlRowHeader = -4153
xlRowItem = 4
xlTableBody = 8

# XlLookAt enumeration
xlPart = 2
xlWhole = 1

# XlLookFor enumeration
LookForBlanks = 0
LookForErrors = 1
LookForFormulas = 2

# XlMailSystem enumeration
xlMAPI = 1
xlNoMailSystem = 0
xlPowerTalk = 2

# XlMarkerStyle enumeration
xlMarkerStyleAutomatic = -4105
xlMarkerStyleCircle = 8
xlMarkerStyleDash = -4115
xlMarkerStyleDiamond = 2
xlMarkerStyleDot = -4118
xlMarkerStyleNone = -4142
xlMarkerStylePicture = -4147
xlMarkerStylePlus = 9
xlMarkerStyleSquare = 1
xlMarkerStyleStar = 5
xlMarkerStyleTriangle = 3
xlMarkerStyleX = -4168

# XlMeasurementUnits enumeration
xlCentimeters = 1
xlInches = 0
xlMillimeters = 2

# XlModelChangeSource enumeration
xlChangeByExcel = 0
xlChangeByPowerPivotAddIn = 1

# XlMouseButton enumeration
xlNoButton = 0
xlPrimaryButton = 1
xlSecondaryButton = 2

# XlMousePointer enumeration
xlDefault = -4143
xlIBeam = 3
xlNorthwestArrow = 1
xlWait = 2

# XlMSApplication enumeration
xlMicrosoftAccess = 4
xlMicrosoftFoxPro = 5
xlMicrosoftMail = 3
xlMicrosoftPowerPoint = 2
xlMicrosoftProject = 6
xlMicrosoftSchedulePlus = 7
xlMicrosoftWord = 1

# XlOartHorizontalOverflow enumeration
xlOartHorizontalOverflowClip = 1
xlOartHorizontalOverflowOverflow = 0

# XlOartVerticalOverflow enumeration
xlOartVerticalOverflowClip = 1
xlOartVerticalOverflowEllipsis = 2
xlOartVerticalOverflowOverflow = 0

# XlObjectSize enumeration
xlFitToPage = 2
xlFullPage = 3
xlScreenSize = 1

# XlOLEType enumeration
xlOLEControl = 2
xlOLEEmbed = 1
xlOLELink = 0

# XlOLEVerb enumeration
xlVerbOpen = 2
xlVerbPrimary = 1

# XlOrder enumeration
xlDownThenOver = 1
xlOverThenDown = 2

# XlOrientation enumeration
xlDownward = -4170
xlHorizontal = -4128
xlUpward = -4171
xlVertical = -4166

# XlPageBreak enumeration
xlPageBreakAutomatic = -4105
xlPageBreakManual = -4135
xlPageBreakNone = -4142

# XlPageBreakExtent enumeration
xlPageBreakFull = 1
xlPageBreakPartial = 2

# XlPageOrientation enumeration
xlLandscape = 2
xlPortrait = 1

# XlPaperSize enumeration
xlPaper10x14 = 16
xlPaper11x17 = 17
xlPaperA3 = 8
xlPaperA4 = 9
xlPaperA4Small = 10
xlPaperA5 = 11
xlPaperB4 = 12
xlPaperB5 = 13
xlPaperCsheet = 24
xlPaperDsheet = 25
xlPaperEnvelope10 = 20
xlPaperEnvelope11 = 21
xlPaperEnvelope12 = 22
xlPaperEnvelope14 = 23
xlPaperEnvelope9 = 19
xlPaperEnvelopeB4 = 33
xlPaperEnvelopeB5 = 34
xlPaperEnvelopeB6 = 35
xlPaperEnvelopeC3 = 29
xlPaperEnvelopeC4 = 30
xlPaperEnvelopeC5 = 28
xlPaperEnvelopeC6 = 31
xlPaperEnvelopeC65 = 32
xlPaperEnvelopeDL = 27
xlPaperEnvelopeItaly = 36
xlPaperEnvelopeMonarch = 37
xlPaperEnvelopePersonal = 38
xlPaperEsheet = 26
xlPaperExecutive = 7
xlPaperFanfoldLegalGerman = 41
xlPaperFanfoldStdGerman = 40
xlPaperFanfoldUS = 39
xlPaperFolio = 14
xlPaperLedger = 4
xlPaperLegal = 5
xlPaperLetter = 1
xlPaperLetterSmall = 2
xlPaperNote = 18
xlPaperQuarto = 15
xlPaperStatement = 6
xlPaperTabloid = 3
xlPaperUser = 256

# XlParameterDataType enumeration
xlParamTypeBigInt = -5
xlParamTypeBinary = -2
xlParamTypeBit = -7
xlParamTypeChar = 1
xlParamTypeDate = 9
xlParamTypeDecimal = 3
xlParamTypeDouble = 8
xlParamTypeFloat = 6
xlParamTypeInteger = 4
xlParamTypeLongVarBinary = -4
xlParamTypeLongVarChar = -1
xlParamTypeNumeric = 2
xlParamTypeReal = 7
xlParamTypeSmallInt = 5
xlParamTypeTime = 10
xlParamTypeTimestamp = 11
xlParamTypeTinyInt = -6
xlParamTypeUnknown = 0
xlParamTypeVarBinary = -3
xlParamTypeVarChar = 12
xlParamTypeWChar = -8

# XlParameterType enumeration
xlConstant = 1
xlPrompt = 0
xlRange = 2

# XlPasteSpecialOperation enumeration
xlPasteSpecialOperationAdd = 2
xlPasteSpecialOperationDivide = 5
xlPasteSpecialOperationMultiply = 4
xlPasteSpecialOperationNone = -4142
xlPasteSpecialOperationSubtract = 3

# XlPasteType enumeration
xlPasteAll = -4104
xlPasteAllExceptBorders = 7
xlPasteAllMergingConditionalFormats = 14
xlPasteAllUsingSourceTheme = 13
xlPasteColumnWidths = 8
xlPasteComments = -4144
xlPasteFormats = -4122
xlPasteFormulas = -4123
xlPasteFormulasAndNumberFormats = 11
xlPasteValidation = 6
xlPasteValues = -4163
xlPasteValuesAndNumberFormats = 12

# XlPattern enumeration
xlPatternAutomatic = -4105
xlPatternChecker = 9
xlPatternCrissCross = 16
xlPatternDown = -4121
xlPatternGray16 = 17
xlPatternGray25 = -4124
xlPatternGray50 = -4125
xlPatternGray75 = -4126
xlPatternGray8 = 18
xlPatternGrid = 15
xlPatternHorizontal = -4128
xlPatternLightDown = 13
xlPatternLightHorizontal = 11
xlPatternLightUp = 14
xlPatternLightVertical = 12
xlPatternNone = -4142
xlPatternSemiGray75 = 10
xlPatternSolid = 1
xlPatternUp = -4162
xlPatternVertical = -4166

# XlPhoneticAlignment enumeration
xlPhoneticAlignCenter = 2
xlPhoneticAlignDistributed = 3
xlPhoneticAlignLeft = 1
xlPhoneticAlignNoControl = 0

# XlPhoneticCharacterType enumeration
xlHiragana = 2
xlKatakana = 1
xlKatakanaHalf = 0
xlNoConversion = 3

# XlPictureAppearance enumeration
xlPrinter = 2
xlScreen = 1

# XlPictureConvertorType enumeration
xlBMP = 1
xlCGM = 7
xlDRW = 4
xlDXF = 5
xlEPS = 8
xlHGL = 6
xlPCT = 13
xlPCX = 10
xlPIC = 11
xlPLT = 12
xlTIF = 9
xlWMF = 2
xlWPG = 3

# XlPieSliceIndex enumeration
xlCenterPoint = 5
xlInnerCenterPoint = 8
xlInnerClockwisePoint = 7
xlInnerCounterClockwisePoint = 9
xlMidClockwiseRadiusPoint = 4
xlMidCounterClockwiseRadiusPoint = 6
xlOuterCenterPoint = 2
xlOuterClockwisePoint = 3
xlOuterCounterClockwisePoint = 1

# XlPieSliceLocation enumeration
xlHorizontalCoordinate = 1
xlVerticalCoordinate = 2

# XlPivotCellType enumeration
xlPivotCellBlankCell = 9
xlPivotCellCustomSubtotal = 7
xlPivotCellDataField = 4
xlPivotCellDataPivotField = 8
xlPivotCellGrandTotal = 3
xlPivotCellPageFieldItem = 6
xlPivotCellPivotField = 5
xlPivotCellPivotItem = 1
xlPivotCellSubtotal = 2
xlPivotCellValue = 0

# XlPivotConditionScope enumeration
xlDataFieldScope = 2
xlFieldsScope = 1
xlSelectionScope = 0

# XlPivotFieldCalculation enumeration
xlDifferenceFrom = 2
xlIndex = 9
xlNoAdditionalCalculation = -4143
xlPercentDifferenceFrom = 4
xlPercentOf = 3
xlPercentOfColumn = 7
xlPercentOfParent = 12
xlPercentOfParentColumn = 11
xlPercentOfParentRow = 10
xlPercentOfRow = 6
xlPercentOfTotal = 8
xlPercentRunningTotal = 13
xlRankAscending = 14
xlRankDecending = 15
xlRunningTotal = 5

# XlPivotFieldDataType enumeration
xlDate = 2
xlNumber = -4145
xlText = -4158

# XlPivotFieldOrientation enumeration
xlColumnField = 2
xlDataField = 4
xlHidden = 0
xlPageField = 3
xlRowField = 1

# XlPivotFieldRepeatLabels enumeration
xlDoNotRepeatLabels = 1
xlRepeatLabels = 2

# XlPivotFilterType enumeration
xlBefore = 31
xlBeforeOrEqualTo = 32
xlAfter = 33
xlAfterOrEqualTo = 34
xlAllDatesInPeriodJanuary = 57
xlAllDatesInPeriodFebruary = 58
xlAllDatesInPeriodMarch = 59
xlAllDatesInPeriodApril = 60
xlAllDatesInPeriodMay = 61
xlAllDatesInPeriodJune = 62
xlAllDatesInPeriodJuly = 63
xlAllDatesInPeriodAugust = 64
xlAllDatesInPeriodSeptember = 65
xlAllDatesInPeriodOctober = 66
xlAllDatesInPeriodNovember = 67
xlAllDatesInPeriodDecember = 68
xlAllDatesInPeriodQuarter1 = 53
xlAllDatesInPeriodQuarter2 = 54
xlAllDatesInPeriodQuarter3 = 55
xlAllDatesInPeriodQuarter4 = 56
xlBottomCount = 2
xlBottomPercent = 4
xlBottomSum = 6
xlCaptionBeginsWith = 17
xlCaptionContains = 21
xlCaptionDoesNotBeginWith = 18
xlCaptionDoesNotContain = 22
xlCaptionDoesNotEndWith = 20
xlCaptionDoesNotEqual = 16
xlCaptionEndsWith = 19
xlCaptionEquals = 15
xlCaptionIsBetween = 27
xlCaptionIsGreaterThan = 23
xlCaptionIsGreaterThanOrEqualTo = 24
xlCaptionIsLessThan = 25
xlCaptionIsLessThanOrEqualTo = 26
xlCaptionIsNotBetween = 28
xlDateBetween = 35
xlDateLastMonth = 45
xlDateLastQuarter = 48
xlDateLastWeek = 42
xlDateLastYear = 51
xlDateNextMonth = 43
xlDateNextQuarter = 46
xlDateNextWeek = 40
xlDateNextYear = 49
xlDateThisMonth = 44
xlDateThisQuarter = 47
xlDateThisWeek = 41
xlDateThisYear = 50
xlDateToday = 38
xlDateTomorrow = 37
xlDateYesterday = 39
xlNotSpecificDate = 30
xlSpecificDate = 29
xlTopCount = 1
xlTopPercent = 3
xlTopSum = 5
xlValueDoesNotEqual = 8
xlValueEquals = 7
xlValueIsBetween = 13
xlValueIsGreaterThan = 9
xlValueIsGreaterThanOrEqualTo = 10
xlValueIsLessThan = 11
xlValueIsLessThanOrEqualTo = 12
xlValueIsNotBetween = 14
xlYearToDate = 52

# XlPivotFormatType enumeration
xlPTClassic = 20
xlPTNone = 21
xlReport1 = 0
xlReport10 = 9
xlReport2 = 1
xlReport3 = 2
xlReport4 = 3
xlReport5 = 4
xlReport6 = 5
xlReport7 = 6
xlReport8 = 7
xlReport9 = 8
xlTable1 = 10
xlTable10 = 19
xlTable2 = 11
xlTable3 = 12
xlTable4 = 13
xlTable5 = 14
xlTable6 = 15
xlTable7 = 16
xlTable8 = 17
xlTable9 = 18

# XlPivotLineType enumeration
xlPivotLineBlank = 3
xlPivotLineGrandTotal = 2
xlPivotLineRegular = 0
xlPivotLineSubtotal = 1

# XlPivotTableMissingItems enumeration
xlMissingItemsDefault = -1
xlMissingItemsMax = 32500
xlMissingItemsMax2 = 1048576
xlMissingItemsNone = 0

# XlPivotTableSourceType enumeration
xlConsolidation = 3
xlDatabase = 1
xlExternal = 2
xlPivotTable = -4148
xlScenario = 4

# XlPivotTableVersionList enumeration
xlPivotTableVersion2000 = 0
xlPivotTableVersion10 = 1
xlPivotTableVersion11 = 2
xlPivotTableVersion12 = 3
xlPivotTableVersion14 = 4
xlPivotTableVersion15 = 5
xlPivotTableVersionCurrent = -1

# XlPlacement enumeration
xlFreeFloating = 3
xlMove = 2
xlMoveAndSize = 1

# XlPlatform enumeration
xlMacintosh = 1
xlMSDOS = 3
xlWindows = 2

# XlPortugueseReform enumeration
xlPortugueseBoth = 3
xlPortuguesePostReform = 2
xlPortuguesePreReform = 1

# XlPrintErrors enumeration
xlPrintErrorsBlank = 1
xlPrintErrorsDash = 2
xlPrintErrorsDisplayed = 0
xlPrintErrorsNA = 3

# XlPrintLocation enumeration
xlPrintInPlace = 16
xlPrintNoComments = -4142
xlPrintSheetEnd = 1

# XlPriority enumeration
xlPriorityHigh = -4127
xlPriorityLow = -4134
xlPriorityNormal = -4143

# XlPropertyDisplayedIn enumeration
xlDisplayPropertyInPivotTable = 1
xlDisplayPropertyInPivotTableAndTooltip = 3
xlDisplayPropertyInTooltip = 2

# XlProtectedViewCloseReason enumeration
xlProtectedViewCloseEdit = 1
xlProtectedViewCloseForced = 2
xlProtectedViewCloseNormal = 0

# XlProtectedViewWindowState enumeration
xlProtectedViewWindowMaximized = 2
xlProtectedViewWindowMinimized = 1
xlProtectedViewWindowNormal = 0

# XlPTSelectionMode enumeration
xlBlanks = 4
xlButton = 15
xlDataAndLabel = 0
xlDataOnly = 2
xlFirstRow = 256
xlLabelOnly = 1
xlOrigin = 3

# XlQueryType enumeration
xlADORecordset = 7
xlDAORecordset = 2
xlODBCQuery = 1
xlOLEDBQuery = 5
xlTextImport = 6
xlWebQuery = 4

# XlRangeAutoFormat enumeration
xlRangeAutoFormat3DEffects1 = 13
xlRangeAutoFormat3DEffects2 = 14
xlRangeAutoFormatAccounting1 = 4
xlRangeAutoFormatAccounting2 = 5
xlRangeAutoFormatAccounting3 = 6
xlRangeAutoFormatAccounting4 = 17
xlRangeAutoFormatClassic1 = 1
xlRangeAutoFormatClassic2 = 2
xlRangeAutoFormatClassic3 = 3
xlRangeAutoFormatClassicPivotTable = 31
xlRangeAutoFormatColor1 = 7
xlRangeAutoFormatColor2 = 8
xlRangeAutoFormatColor3 = 9
xlRangeAutoFormatList1 = 10
xlRangeAutoFormatList2 = 11
xlRangeAutoFormatList3 = 12
xlRangeAutoFormatLocalFormat1 = 15
xlRangeAutoFormatLocalFormat2 = 16
xlRangeAutoFormatLocalFormat3 = 19
xlRangeAutoFormatLocalFormat4 = 20
xlRangeAutoFormatNone = -4142
xlRangeAutoFormatPTNone = 42
xlRangeAutoFormatReport1 = 21
xlRangeAutoFormatReport10 = 30
xlRangeAutoFormatReport2 = 22
xlRangeAutoFormatReport3 = 23
xlRangeAutoFormatReport4 = 24
xlRangeAutoFormatReport5 = 25
xlRangeAutoFormatReport6 = 26
xlRangeAutoFormatReport7 = 27
xlRangeAutoFormatReport8 = 28
xlRangeAutoFormatReport9 = 29
xlRangeAutoFormatSimple = -4154
xlRangeAutoFormatTable1 = 32
xlRangeAutoFormatTable10 = 41
xlRangeAutoFormatTable2 = 33
xlRangeAutoFormatTable3 = 34
xlRangeAutoFormatTable4 = 35
xlRangeAutoFormatTable5 = 36
xlRangeAutoFormatTable6 = 37
xlRangeAutoFormatTable7 = 38
xlRangeAutoFormatTable8 = 39
xlRangeAutoFormatTable9 = 40

# XlRangeValueDataType enumeration
xlRangeValueDefault = 10
xlRangeValueMSPersistXML = 12
xlRangeValueXMLSpreadsheet = 11

# XlReferenceStyle enumeration
xlA1 = 1
xlR1C1 = -4150

# XlReferenceType enumeration
xlAbsolute = 1
xlAbsRowRelColumn = 2
xlRelative = 4
xlRelRowAbsColumn = 3

# XlRemoveDocInfoType enumeration
xlRDIAll = 99
xlRDIComments = 1
xlRDIContentType = 16
xlRDIDefinedNameComments = 18
xlRDIDocumentManagementPolicy = 15
xlRDIDocumentProperties = 8
xlRDIDocumentServerProperties = 14
xlRDIDocumentWorkspace = 10
xlRDIEmailHeader = 5
xlRDIExcelDataModel = 23
xlRDIInactiveDataConnections = 19
xlRDIInkAnnotations = 11
xlRDIInlineWebExtensions = 21
xlRDIPrinterPath = 20
xlRDIPublishInfo = 13
xlRDIRemovePersonalInformation = 4
xlRDIRoutingSlip = 6
xlRDIScenarioComments = 12
xlRDISendForReview = 7
xlRDITaskpaneWebExtensions = 22

# XlRgbColor enumeration
rgbAliceBlue = 16775408
rgbAntiqueWhite = 14150650
rgbAqua = 16776960
rgbAquamarine = 13959039
rgbAzure = 16777200
rgbBeige = 14480885
rgbBisque = 12903679
rgbBlack = 0
rgbBlanchedAlmond = 13495295
rgbBlue = 16711680
rgbBlueViolet = 14822282
rgbBrown = 2763429
rgbBurlyWood = 8894686
rgbCadetBlue = 10526303
rgbChartreuse = 65407
rgbCoral = 5275647
rgbCornflowerBlue = 15570276
rgbCornsilk = 14481663
rgbCrimson = 3937500
rgbDarkBlue = 9109504
rgbDarkCyan = 9145088
rgbDarkGoldenrod = 755384
rgbDarkGray = 11119017
rgbDarkGreen = 25600
rgbDarkGrey = 11119017
rgbDarkKhaki = 7059389
rgbDarkMagenta = 9109643
rgbDarkOliveGreen = 3107669
rgbDarkOrange = 36095
rgbDarkOrchid = 13382297
rgbDarkRed = 139
rgbDarkSalmon = 8034025
rgbDarkSeaGreen = 9419919
rgbDarkSlateBlue = 9125192
rgbDarkSlateGray = 5197615
rgbDarkSlateGrey = 5197615
rgbDarkTurquoise = 13749760
rgbDarkViolet = 13828244
rgbDeepPink = 9639167
rgbDeepSkyBlue = 16760576
rgbDimGray = 6908265
rgbDimGrey = 6908265
rgbDodgerBlue = 16748574
rgbFireBrick = 2237106
rgbFloralWhite = 15792895
rgbForestGreen = 2263842
rgbFuchsia = 16711935
rgbGainsboro = 14474460
rgbGhostWhite = 16775416
rgbGold = 55295
rgbGoldenrod = 2139610
rgbGray = 8421504
rgbGreen = 32768
rgbGreenYellow = 3145645
rgbGrey = 8421504
rgbHoneydew = 15794160
rgbHotPink = 11823615
rgbIndianRed = 6053069
rgbIndigo = 8519755
rgbIvory = 15794175
rgbKhaki = 9234160
rgbLavender = 16443110
rgbLavenderBlush = 16118015
rgbLawnGreen = 64636
rgbLemonChiffon = 13499135
rgbLightBlue = 15128749
rgbLightCoral = 8421616
rgbLightCyan = 9145088
rgbLightGoldenrodYellow = 13826810
rgbLightGray = 13882323
rgbLightGreen = 9498256
rgbLightGrey = 13882323
rgbLightPink = 12695295
rgbLightSalmon = 8036607
rgbLightSeaGreen = 11186720
rgbLightSkyBlue = 16436871
rgbLightSlateGray = 10061943
rgbLightSteelBlue = 14599344
rgbLightYellow = 14745599
rgbLime = 65280
rgbLimeGreen = 3329330
rgbLinen = 15134970
rgbMaroon = 128
rgbMediumAquamarine = 11206502
rgbMediumBlue = 13434880
rgbMediumOrchid = 13850042
rgbMediumPurple = 14381203
rgbMediumSeaGreen = 7451452
rgbMediumSlateBlue = 15624315
rgbMediumSpringGreen = 10156544
rgbMediumTurquoise = 13422920
rgbMediumVioletRed = 8721863
rgbMidnightBlue = 7346457
rgbMintCream = 16449525
rgbMistyRose = 14804223
rgbMoccasin = 11920639
rgbNavajoWhite = 11394815
rgbNavy = 8388608
rgbNavyBlue = 8388608
rgbOldLace = 15136253
rgbOlive = 32896
rgbOliveDrab = 2330219
rgbOrange = 42495
rgbOrangeRed = 17919
rgbOrchid = 14053594
rgbPaleGoldenrod = 7071982
rgbPaleGreen = 10025880
rgbPaleTurquoise = 15658671
rgbPaleVioletRed = 9662683
rgbPapayaWhip = 14020607
rgbPeachPuff = 12180223
rgbPeru = 4163021
rgbPink = 13353215
rgbPlum = 14524637
rgbPowderBlue = 15130800
rgbPurple = 8388736
rgbRed = 255
rgbRosyBrown = 9408444
rgbRoyalBlue = 14772545
rgbSalmon = 7504122
rgbSandyBrown = 6333684
rgbSeaGreen = 5737262
rgbSeashell = 15660543
rgbSienna = 2970272
rgbSilver = 12632256
rgbSkyBlue = 15453831
rgbSlateBlue = 13458026
rgbSlateGray = 9470064
rgbSnow = 16448255
rgbSpringGreen = 8388352
rgbSteelBlue = 11829830
rgbTan = 9221330
rgbTeal = 8421376
rgbThistle = 14204888
rgbTomato = 4678655
rgbTurquoise = 13688896
rgbViolet = 15631086
rgbWheat = 11788021
rgbWhite = 16777215
rgbWhiteSmoke = 16119285
rgbYellow = 65535
rgbYellowGreen = 3329434

# XlRobustConnect enumeration
xlAlways = 1
xlAsRequired = 0
xlNever = 2

# XlRowCol enumeration
xlColumns = 2
xlRows = 1

# XlRunAutoMacro enumeration
xlAutoActivate = 3
xlAutoClose = 2
xlAutoDeactivate = 4
xlAutoOpen = 1

# XlSaveAction enumeration
xlDoNotSaveChanges = 2
xlSaveChanges = 1

# XlSaveAsAccessMode enumeration
xlExclusive = 3
xlNoChange = 1
xlShared = 2

# XlSaveConflictResolution enumeration
xlLocalSessionChanges = 2
xlOtherSessionChanges = 3
xlUserResolution = 1

# XlScaleType enumeration
xlScaleLinear = -4132
xlScaleLogarithmic = -4133

# XlSearchDirection enumeration
xlNext = 1
xlPrevious = 2

# XlSearchOrder enumeration
xlByColumns = 2
xlByRows = 1

# XlSearchWithin enumeration
xlWithinSheet = 1
xlWithinWorkbook = 2

# XlSheetType enumeration
xlChart = -4109
xlDialogSheet = -4116
xlExcel4IntlMacroSheet = 4
xlExcel4MacroSheet = 3
xlWorksheet = -4167

# XlSheetVisibility enumeration
xlSheetHidden = 0
xlSheetVeryHidden = 2
xlSheetVisible = -1

# XlSizeRepresents enumeration
xlSizeIsArea = 1
xlSizeIsWidth = 2

# XlSlicerCrossFilterType enumeration
xlSlicerCrossFilterHideButtonsWithNoData = 4
xlSlicerCrossFilterShowItemsWithDataAtTop = 2
xlSlicerCrossFilterShowItemsWithNoData = 3
xlSlicerNoCrossFilter = 1

# XlSlicerSort enumeration
xlSlicerSortAscending = 2
xlSlicerSortDataSourceOrder = 1
xlSlicerSortDescending = 3

# XlSortDataOption enumeration
xlSortNormal = 0
xlSortTextAsNumbers = 1

# XlSortMethod enumeration
xlPinYin = 1
xlStroke = 2

# XlSortMethodOld enumeration
xlCodePage = 2
xlSyllabary = 1

# XlSortOn enumeration
xlSortOnCellColor = 1
xlSortOnFontColor = 2
xlSortOnIcon = 3
xlSortOnValues = 0

# XlSortOrder enumeration
xlAscending = 1
xlDescending = 2
xlManual = -4135

# XlSortOrientation enumeration
xlSortColumns = 1
xlSortRows = 2

# XlSortType enumeration
xlSortLabels = 2
xlSortValues = 1

# XlSourceType enumeration
xlSourceAutoFilter = 3
xlSourceChart = 5
xlSourcePivotTable = 6
xlSourcePrintArea = 2
xlSourceQuery = 7
xlSourceRange = 4
xlSourceSheet = 1
xlSourceWorkbook = 0

# XlSpanishModes enumeration
xlSpanishTuteoAndVoseo = 1
xlSpanishTuteoOnly = 0
xlSpanishVoseoOnly = 2

# XlSparklineRowCol enumeration
xlSparklineColumnsSquare = 2
xlSparklineNonSquare = 0
xlSparklineRowsSquare = 1

# XlSparkScale enumeration
xlSparkScaleCustom = 3
xlSparkScaleGroup = 1
xlSparkScaleSingle = 2

# XlSparkType enumeration
xlSparkColumn = 2
xlSparkColumnStacked100 = 3
xlSparkLine = 1

# XlSpeakDirection enumeration
xlSpeakByColumns = 1
xlSpeakByRows = 0

# XlSpecialCellsValue enumeration
xlErrors = 16
xlLogical = 4
xlNumbers = 1
xlTextValues = 2

# XlStdColorScale enumeration
ColorScaleBlackWhite = 3
ColorScaleGYR = 2
ColorScaleRYG = 1
ColorScaleWhiteBlack = 4

# XlSubscribeToFormat enumeration
xlSubscribeToPicture = -4147
xlSubscribeToText = -4158

# XlSubtotalLocationType enumeration
xlAtBottom = 2
xlAtTop = 1

# XlSummaryColumn enumeration
xlSummaryOnLeft = -4131
xlSummaryOnRight = -4152

# XlSummaryReportType enumeration
xlStandardSummary = 1
xlSummaryPivotTable = -4148

# XlSummaryRow enumeration
xlSummaryAbove = 0
xlSummaryBelow = 1

# XlTableStyleElementType enumeration
xlBlankRow = 19
xlColumnStripe1 = 7
xlColumnStripe2 = 8
xlColumnSubheading1 = 20
xlColumnSubheading2 = 21
xlColumnSubheading3 = 22
xlFirstColumn = 3
xlFirstHeaderCell = 9
xlFirstTotalCell = 11
xlGrandTotalColumn = 4
xlGrandTotalRow = 2
xlHeaderRow = 1
xlLastColumn = 4
xlLastHeaderCell = 10
xlLastTotalCell = 12
xlPageFieldLabels = 26
xlPageFieldValues = 27
xlRowStripe1 = 5
xlRowStripe2 = 6
xlRowSubheading1 = 23
xlRowSubheading2 = 24
xlRowSubheading3 = 25
xlSlicerHoveredSelectedItemWithData = 33
xlSlicerHoveredSelectedItemWithNoData = 35
xlSlicerHoveredUnselectedItemWithData = 32
xlSlicerHoveredUnselectedItemWithNoData = 34
xlSlicerSelectedItemWithData = 30
xlSlicerSelectedItemWithNoData = 31
xlSlicerUnselectedItemWithData = 28
xlSlicerUnselectedItemWithNoData = 29
xlSubtotalColumn1 = 13
xlSubtotalColumn2 = 14
xlSubtotalColumn3 = 15
xlSubtotalRow1 = 16
xlSubtotalRow2 = 17
xlSubtotalRow3 = 18
xlTimelinePeriodLabels1 = 38
xlTimelinePeriodLabels2 = 39
xlTimelineSelectedTimeBlock = 40
xlTimelineSelectedTimeBlockSpace = 42
xlTimelineSelectionLabel = 36
xlTimelineTimeLevel = 37
xlTimelineUnselectedTimeBlock = 41
xlTotalRow = 2
xlWholeTable = 0

# XlTabPosition enumeration
xlTabPositionFirst = 0
xlTabPositionLast = 1

# XlTextParsingType enumeration
xlDelimited = 1
xlFixedWidth = 2

# XlTextQualifier enumeration
xlTextQualifierDoubleQuote = 1
xlTextQualifierNone = -4142
xlTextQualifierSingleQuote = 2

# XlTextVisualLayoutType enumeration
xlTextVisualLTR = 1
xlTextVisualRTL = 2

# XlThemeColor enumeration
xlThemeColorAccent1 = 5
xlThemeColorAccent2 = 6
xlThemeColorAccent3 = 7
xlThemeColorAccent4 = 8
xlThemeColorAccent5 = 9
xlThemeColorAccent6 = 10
xlThemeColorDark1 = 1
xlThemeColorDark2 = 3
xlThemeColorFollowedHyperlink = 12
xlThemeColorHyperlink = 11
xlThemeColorLight1 = 2
xlThemeColorLight2 = 4

# XlThemeFont enumeration
xlThemeFontMajor = 2
xlThemeFontMinor = 1
xlThemeFontNone = 0

# XlThreadMode enumeration
xlThreadModeAutomatic = 0
xlThreadModeManual = 1

# XlTickLabelOrientation enumeration
xlTickLabelOrientationAutomatic = -4105
xlTickLabelOrientationDownward = -4170
xlTickLabelOrientationHorizontal = -4128
xlTickLabelOrientationUpward = -4171
xlTickLabelOrientationVertical = -4166

# XlTickLabelPosition enumeration
xlTickLabelPositionHigh = -4127
xlTickLabelPositionLow = -4134
xlTickLabelPositionNextToAxis = 4
xlTickLabelPositionNone = -4142

# XlTickMark enumeration
xlTickMarkCross = 4
xlTickMarkInside = 2
xlTickMarkNone = -4142
xlTickMarkOutside = 3

# XlTimePeriods enumeration
xlLast7Days = 2
xlLastMonth = 5
xlLastWeek = 4
xlNextMonth = 8
xlNextWeek = 7
xlThisMonth = 9
xlThisWeek = 3
xlToday = 0
xlTomorrow = 6
xlYesterday = 1

# XlTimeUnit enumeration
xlDays = 0
xlMonths = 1
xlYears = 2

# XlToolbarProtection enumeration
xlNoButtonChanges = 1
xlNoChanges = 4
xlNoDockingChanges = 3
xlNoShapeChanges = 2
xlToolbarProtectionNone = -4143

# XlTopBottom enumeration
xlTop10Bottom = 0
xlTop10Top = 1

# XlTotalsCalculation enumeration
xlTotalsCalculationAverage = 2
xlTotalsCalculationCount = 3
xlTotalsCalculationCountNums = 4
xlTotalsCalculationCustom = 9
xlTotalsCalculationMax = 6
xlTotalsCalculationMin = 5
xlTotalsCalculationNone = 0
xlTotalsCalculationStdDev = 7
xlTotalsCalculationSum = 1
xlTotalsCalculationVar = 8

# XlTrendlineType enumeration
xlExponential = 5
xlLinear = -4132
xlLogarithmic = -4133
xlMovingAvg = 6
xlPolynomial = 3
xlPower = 4

# XlUnderlineStyle enumeration
xlUnderlineStyleDouble = -4119
xlUnderlineStyleDoubleAccounting = 5
xlUnderlineStyleNone = -4142
xlUnderlineStyleSingle = 2
xlUnderlineStyleSingleAccounting = 4

# XlUpdateLinks enumeration
xlUpdateLinksAlways = 3
xlUpdateLinksNever = 2
xlUpdateLinksUserSetting = 1

# XlVAlign enumeration
xlVAlignBottom = -4107
xlVAlignCenter = -4108
xlVAlignDistributed = -4117
xlVAlignJustify = -4130
xlVAlignTop = -4160

# XlWBATemplate enumeration
xlWBATChart = -4109
xlWBATExcel4IntlMacroSheet = 4
xlWBATExcel4MacroSheet = 3
xlWBATWorksheet = -4167

# XlWebFormatting enumeration
xlWebFormattingAll = 1
xlWebFormattingNone = 3
xlWebFormattingRTF = 2

# XlWebSelectionType enumeration
xlAllTables = 2
xlEntirePage = 1
xlSpecifiedTables = 3

# XlWindowState enumeration
xlMaximized = -4137
xlMinimized = -4140
xlNormal = -4143

# XlWindowType enumeration
xlChartAsWindow = 5
xlChartInPlace = 4
xlClipboard = 3
xlInfo = -4129
xlWorkbook = 1

# XlWindowView enumeration
xlNormalView = 1
xlPageBreakPreview = 2
xlPageLayoutView = 3

# XlXLMMacroType enumeration
xlCommand = 2
xlFunction = 1
xlNotXLM = 3

# XlXmlExportResult enumeration
xlXmlExportSuccess = 0
xlXmlExportValidationFailed = 1

# XlXmlImportResult enumeration
xlXmlImportElementsTruncated = 1
xlXmlImportSuccess = 0
xlXmlImportValidationFailed = 2

# XlXmlLoadOption enumeration
xlXmlLoadImportToList = 2
xlXmlLoadMapXml = 3
xlXmlLoadOpenXml = 1
xlXmlLoadPromptUser = 0

# XlYesNoGuess enumeration
xlGuess = 0
xlNo = 2
xlYes = 1

class XmlDataBinding:

    def __init__(self, xmldatabinding=None):
        self.com_object= xmldatabinding

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def SourceUrl(self):
        return self.com_object.SourceUrl

    @property
    def sourceurl(self):
        """Alias for SourceUrl"""
        return self.SourceUrl

    @property
    def source_url(self):
        """Alias for SourceUrl"""
        return self.SourceUrl

    def ClearSettings(self):
        self.com_object.ClearSettings()

    def clearsettings(self):
        """Alias for ClearSettings"""
        return self.ClearSettings()

    def clear_settings(self):
        """Alias for ClearSettings"""
        return self.ClearSettings()

    def LoadSettings(self, Url=None):
        arguments = com_arguments([unwrap(a) for a in [Url]])
        self.com_object.LoadSettings(*arguments)

    def loadsettings(self, Url=None):
        """Alias for LoadSettings"""
        arguments = [Url]
        return self.LoadSettings(*arguments)

    def load_settings(self, Url=None):
        """Alias for LoadSettings"""
        arguments = [Url]
        return self.LoadSettings(*arguments)

    def Refresh(self):
        return XlXmlImportResult(self.com_object.Refresh())

    def refresh(self):
        """Alias for Refresh"""
        return self.Refresh()


class XmlMap:

    def __init__(self, xmlmap=None):
        self.com_object= xmlmap

    @property
    def AdjustColumnWidth(self):
        return self.com_object.AdjustColumnWidth

    @property
    def adjustcolumnwidth(self):
        """Alias for AdjustColumnWidth"""
        return self.AdjustColumnWidth

    @property
    def adjust_column_width(self):
        """Alias for AdjustColumnWidth"""
        return self.AdjustColumnWidth

    @property
    def AppendOnImport(self):
        return self.com_object.AppendOnImport

    @property
    def appendonimport(self):
        """Alias for AppendOnImport"""
        return self.AppendOnImport

    @property
    def append_on_import(self):
        """Alias for AppendOnImport"""
        return self.AppendOnImport

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def DataBinding(self):
        return XmlDataBinding(self.com_object.DataBinding)

    @property
    def databinding(self):
        """Alias for DataBinding"""
        return self.DataBinding

    @property
    def data_binding(self):
        """Alias for DataBinding"""
        return self.DataBinding

    @property
    def IsExportable(self):
        return XPath(self.com_object.IsExportable)

    @property
    def isexportable(self):
        """Alias for IsExportable"""
        return self.IsExportable

    @property
    def is_exportable(self):
        """Alias for IsExportable"""
        return self.IsExportable

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PreserveColumnFilter(self):
        return self.com_object.PreserveColumnFilter

    @PreserveColumnFilter.setter
    def PreserveColumnFilter(self, value):
        self.com_object.PreserveColumnFilter = value

    @property
    def preservecolumnfilter(self):
        """Alias for PreserveColumnFilter"""
        return self.PreserveColumnFilter

    @preservecolumnfilter.setter
    def preservecolumnfilter(self, value):
        """Alias for PreserveColumnFilter.setter"""
        self.PreserveColumnFilter = value

    @property
    def preserve_column_filter(self):
        """Alias for PreserveColumnFilter"""
        return self.PreserveColumnFilter

    @preserve_column_filter.setter
    def preserve_column_filter(self, value):
        """Alias for PreserveColumnFilter.setter"""
        self.PreserveColumnFilter = value

    @property
    def PreserveNumberFormatting(self):
        return self.com_object.PreserveNumberFormatting

    @PreserveNumberFormatting.setter
    def PreserveNumberFormatting(self, value):
        self.com_object.PreserveNumberFormatting = value

    @property
    def preservenumberformatting(self):
        """Alias for PreserveNumberFormatting"""
        return self.PreserveNumberFormatting

    @preservenumberformatting.setter
    def preservenumberformatting(self, value):
        """Alias for PreserveNumberFormatting.setter"""
        self.PreserveNumberFormatting = value

    @property
    def preserve_number_formatting(self):
        """Alias for PreserveNumberFormatting"""
        return self.PreserveNumberFormatting

    @preserve_number_formatting.setter
    def preserve_number_formatting(self, value):
        """Alias for PreserveNumberFormatting.setter"""
        self.PreserveNumberFormatting = value

    @property
    def RootElementName(self):
        return self.com_object.RootElementName

    @property
    def rootelementname(self):
        """Alias for RootElementName"""
        return self.RootElementName

    @property
    def root_element_name(self):
        """Alias for RootElementName"""
        return self.RootElementName

    @property
    def RootElementNamespace(self):
        return XmlNamespace(self.com_object.RootElementNamespace)

    @property
    def rootelementnamespace(self):
        """Alias for RootElementNamespace"""
        return self.RootElementNamespace

    @property
    def root_element_namespace(self):
        """Alias for RootElementNamespace"""
        return self.RootElementNamespace

    @property
    def SaveDataSourceDefinition(self):
        return self.com_object.SaveDataSourceDefinition

    @SaveDataSourceDefinition.setter
    def SaveDataSourceDefinition(self, value):
        self.com_object.SaveDataSourceDefinition = value

    @property
    def savedatasourcedefinition(self):
        """Alias for SaveDataSourceDefinition"""
        return self.SaveDataSourceDefinition

    @savedatasourcedefinition.setter
    def savedatasourcedefinition(self, value):
        """Alias for SaveDataSourceDefinition.setter"""
        self.SaveDataSourceDefinition = value

    @property
    def save_data_source_definition(self):
        """Alias for SaveDataSourceDefinition"""
        return self.SaveDataSourceDefinition

    @save_data_source_definition.setter
    def save_data_source_definition(self, value):
        """Alias for SaveDataSourceDefinition.setter"""
        self.SaveDataSourceDefinition = value

    @property
    def Schemas(self):
        return XmlSchemas(self.com_object.Schemas)

    @property
    def schemas(self):
        """Alias for Schemas"""
        return self.Schemas

    @property
    def ShowImportExportValidationErrors(self):
        return self.com_object.ShowImportExportValidationErrors

    @ShowImportExportValidationErrors.setter
    def ShowImportExportValidationErrors(self, value):
        self.com_object.ShowImportExportValidationErrors = value

    @property
    def showimportexportvalidationerrors(self):
        """Alias for ShowImportExportValidationErrors"""
        return self.ShowImportExportValidationErrors

    @showimportexportvalidationerrors.setter
    def showimportexportvalidationerrors(self, value):
        """Alias for ShowImportExportValidationErrors.setter"""
        self.ShowImportExportValidationErrors = value

    @property
    def show_import_export_validation_errors(self):
        """Alias for ShowImportExportValidationErrors"""
        return self.ShowImportExportValidationErrors

    @show_import_export_validation_errors.setter
    def show_import_export_validation_errors(self, value):
        """Alias for ShowImportExportValidationErrors.setter"""
        self.ShowImportExportValidationErrors = value

    @property
    def WorkbookConnection(self):
        return XMLMap(self.com_object.WorkbookConnection)

    @property
    def workbookconnection(self):
        """Alias for WorkbookConnection"""
        return self.WorkbookConnection

    @property
    def workbook_connection(self):
        """Alias for WorkbookConnection"""
        return self.WorkbookConnection

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Export(self, Url=None, Overwrite=None):
        arguments = com_arguments([unwrap(a) for a in [Url, Overwrite]])
        return XlXmlExportResult(self.com_object.Export(*arguments))

    def export(self, Url=None, Overwrite=None):
        """Alias for Export"""
        arguments = [Url, Overwrite]
        return self.Export(*arguments)

    def ExportXml(self, Data=None):
        arguments = com_arguments([unwrap(a) for a in [Data]])
        return XlXmlExportResult(self.com_object.ExportXml(*arguments))

    def exportxml(self, Data=None):
        """Alias for ExportXml"""
        arguments = [Data]
        return self.ExportXml(*arguments)

    def export_xml(self, Data=None):
        """Alias for ExportXml"""
        arguments = [Data]
        return self.ExportXml(*arguments)

    def Import(self, Url=None, Overwrite=None):
        arguments = com_arguments([unwrap(a) for a in [Url, Overwrite]])
        return XlXmlImportResult(self.com_object.Import(*arguments))

    def ImportXml(self, XmlData=None, Overwrite=None):
        arguments = com_arguments([unwrap(a) for a in [XmlData, Overwrite]])
        return XlXmlImportResult(self.com_object.ImportXml(*arguments))

    def importxml(self, XmlData=None, Overwrite=None):
        """Alias for ImportXml"""
        arguments = [XmlData, Overwrite]
        return self.ImportXml(*arguments)

    def import_xml(self, XmlData=None, Overwrite=None):
        """Alias for ImportXml"""
        arguments = [XmlData, Overwrite]
        return self.ImportXml(*arguments)


class XmlMaps:

    def __init__(self, xmlmaps=None):
        self.com_object= xmlmaps

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Schema=None, RootElementName=None):
        arguments = com_arguments([unwrap(a) for a in [Schema, RootElementName]])
        return XmlMap(self.com_object.Add(*arguments))

    def add(self, Schema=None, RootElementName=None):
        """Alias for Add"""
        arguments = [Schema, RootElementName]
        return self.Add(*arguments)


class XmlNamespace:

    def __init__(self, xmlnamespace=None):
        self.com_object= xmlnamespace

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Prefix(self):
        return self.com_object.Prefix

    @property
    def prefix(self):
        """Alias for Prefix"""
        return self.Prefix

    @property
    def Uri(self):
        return self.com_object.Uri

    @property
    def uri(self):
        """Alias for Uri"""
        return self.Uri


class XmlNamespaces:

    def __init__(self, xmlnamespaces=None):
        self.com_object= xmlnamespaces

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Value(self):
        return self.com_object.Value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    def InstallManifest(self, Path=None, InstallForAllUsers=None):
        arguments = com_arguments([unwrap(a) for a in [Path, InstallForAllUsers]])
        self.com_object.InstallManifest(*arguments)

    def installmanifest(self, Path=None, InstallForAllUsers=None):
        """Alias for InstallManifest"""
        arguments = [Path, InstallForAllUsers]
        return self.InstallManifest(*arguments)

    def install_manifest(self, Path=None, InstallForAllUsers=None):
        """Alias for InstallManifest"""
        arguments = [Path, InstallForAllUsers]
        return self.InstallManifest(*arguments)


class XmlSchema:

    def __init__(self, xmlschema=None):
        self.com_object= xmlschema

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Name(self):
        return XmlMap(self.com_object.Name)

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Namespace(self):
        return XmlNamespace(self.com_object.Namespace)

    @property
    def namespace(self):
        """Alias for Namespace"""
        return self.Namespace

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def XML(self):
        return self.com_object.XML

    @property
    def xml(self):
        """Alias for XML"""
        return self.XML

    @property
    def x_m_l(self):
        """Alias for XML"""
        return self.XML


class XmlSchemas:

    def __init__(self, xmlschemas=None):
        self.com_object= xmlschemas

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class XPath:

    def __init__(self, xpath=None):
        self.com_object= xpath

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Creator(self):
        return self.com_object.Creator

    @property
    def creator(self):
        """Alias for Creator"""
        return self.Creator

    @property
    def Map(self):
        return XmlMap(self.com_object.Map)

    @property
    def map(self):
        """Alias for Map"""
        return self.Map

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Repeating(self):
        return self.com_object.Repeating

    @property
    def repeating(self):
        """Alias for Repeating"""
        return self.Repeating

    @property
    def Value(self):
        return self.com_object.Value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    def Clear(self):
        self.com_object.Clear()

    def clear(self):
        """Alias for Clear"""
        return self.Clear()

    def SetValue(self, Map=None, XPath=None, SelectionNamespace=None, Repeating=None):
        arguments = com_arguments([unwrap(a) for a in [Map, XPath, SelectionNamespace, Repeating]])
        self.com_object.SetValue(*arguments)

    def setvalue(self, Map=None, XPath=None, SelectionNamespace=None, Repeating=None):
        """Alias for SetValue"""
        arguments = [Map, XPath, SelectionNamespace, Repeating]
        return self.SetValue(*arguments)

    def set_value(self, Map=None, XPath=None, SelectionNamespace=None, Repeating=None):
        """Alias for SetValue"""
        arguments = [Map, XPath, SelectionNamespace, Repeating]
        return self.SetValue(*arguments)

