from . import com_arguments, unwrap
from .office import *

import win32com.client

# AcAggregateType enumeration
acAggregateAverage = 2
acAggregateCount = 6
acAggregateDistinct = 5
acAggregateMaximum = 4
acAggregateMinimum = 3
acAggregateNone = 0
acAggregateSum = 1

# AcAxisRange enumeration
acAxisRangeAuto = 0
acAxisRangedFixed = 1

# AcAxisUnits enumeration
acAxisUnitsBillions = 9
acAxisUnitsHundredBillions = 11
acAxisUnitsHundredMillions = 8
acAxisUnitsHundreds = 2
acAxisUnitsHundredThousands = 5
acAxisUnitsMillions = 6
acAxisUnitsNone = 0
acAxisUnitsPercentage = 1
acAxisUnitsTenBillions = 10
acAxisUnitsTenMillions = 7
acAxisUnitsTenThousands = 4
acAxisUnitsThousands = 3
acAxisUnitsTrillions = 12

class AccessObject:

    def __init__(self, accessobject=None):
        self.com_object= accessobject

    @property
    def CurrentView(self):
        return AcCurrentView(self.com_object.CurrentView)

    @property
    def currentview(self):
        """Alias for CurrentView"""
        return self.CurrentView

    @property
    def current_view(self):
        """Alias for CurrentView"""
        return self.CurrentView

    @property
    def DateCreated(self):
        return self.com_object.DateCreated

    @property
    def datecreated(self):
        """Alias for DateCreated"""
        return self.DateCreated

    @property
    def date_created(self):
        """Alias for DateCreated"""
        return self.DateCreated

    @property
    def DateModified(self):
        return self.com_object.DateModified

    @property
    def datemodified(self):
        """Alias for DateModified"""
        return self.DateModified

    @property
    def date_modified(self):
        """Alias for DateModified"""
        return self.DateModified

    @property
    def FullName(self):
        return self.com_object.FullName

    @FullName.setter
    def FullName(self, value):
        self.com_object.FullName = value

    @property
    def fullname(self):
        """Alias for FullName"""
        return self.FullName

    @fullname.setter
    def fullname(self, value):
        """Alias for FullName.setter"""
        self.FullName = value

    @property
    def full_name(self):
        """Alias for FullName"""
        return self.FullName

    @full_name.setter
    def full_name(self, value):
        """Alias for FullName.setter"""
        self.FullName = value

    @property
    def IsLoaded(self):
        return self.com_object.IsLoaded

    @property
    def isloaded(self):
        """Alias for IsLoaded"""
        return self.IsLoaded

    @property
    def is_loaded(self):
        """Alias for IsLoaded"""
        return self.IsLoaded

    @property
    def IsWeb(self):
        return self.com_object.IsWeb

    @property
    def isweb(self):
        """Alias for IsWeb"""
        return self.IsWeb

    @property
    def is_web(self):
        """Alias for IsWeb"""
        return self.IsWeb

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Properties(self):
        return AccessObjectProperties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def Type(self):
        return AcObjectType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def GetDependencyInfo(self):
        return DependencyInfo(self.com_object.GetDependencyInfo())

    def getdependencyinfo(self):
        """Alias for GetDependencyInfo"""
        return self.GetDependencyInfo()

    def get_dependency_info(self):
        """Alias for GetDependencyInfo"""
        return self.GetDependencyInfo()

    def IsDependentUpon(self, ObjectType=None, ObjectName=None):
        arguments = com_arguments([unwrap(a) for a in [ObjectType, ObjectName]])
        return self.com_object.IsDependentUpon(*arguments)

    def isdependentupon(self, ObjectType=None, ObjectName=None):
        """Alias for IsDependentUpon"""
        arguments = [ObjectType, ObjectName]
        return self.IsDependentUpon(*arguments)

    def is_dependent_upon(self, ObjectType=None, ObjectName=None):
        """Alias for IsDependentUpon"""
        arguments = [ObjectType, ObjectName]
        return self.IsDependentUpon(*arguments)


class AccessObjectProperties:

    def __init__(self, accessobjectproperties=None):
        self.com_object= accessobjectproperties

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, PropertyName=None, Value=None):
        arguments = com_arguments([unwrap(a) for a in [PropertyName, Value]])
        self.com_object.Add(*arguments)

    def add(self, PropertyName=None, Value=None):
        """Alias for Add"""
        arguments = [PropertyName, Value]
        return self.Add(*arguments)

    def Remove(self, Item=None):
        arguments = com_arguments([unwrap(a) for a in [Item]])
        self.com_object.Remove(*arguments)

    def remove(self, Item=None):
        """Alias for Remove"""
        arguments = [Item]
        return self.Remove(*arguments)


class AccessObjectProperty:

    def __init__(self, accessobjectproperty=None):
        self.com_object= accessobjectproperty

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value


# AcChartType enumeration
acChartBarClustered = 3
acChartBarStacked = 4
acChartBarStacked100 = 5
acChartColumnClustered = 0
acChartColumnStacked = 1
acChartColumnStacked100 = 2
acChartCombo = 10
acChartLine = 6
acChartLineStacked = 7
acChartLineStacked100 = 8
acChartPie = 9
acChartArea = 11
acChartAreaStacked = 12
acChartAreaStacked100 = 13
acChartRadar = 14
acChartRadarFilled = 15
acChartBoxWhisker = 16
acChartBubble = 17
acChartDoughnut = 18
acChartFunnel = 19
acChartScatter = 20
acChartWaterfall = 21
acChartWordCloud = 22
acChartArc = 23
acChartPareto = 24

# AcCloseSave enumeration
acSaveNo = 2
acSavePrompt = 0
acSaveYes = 1

# AcColorIndex enumeration
acColorIndexAqua = 14
acColorIndexBlack = 0
acColorIndexBlue = 12
acColorIndexBrightGreen = 10
acColorIndexDarkBlue = 4
acColorIndexFuchsia = 13
acColorIndexGray = 7
acColorIndexGreen = 2
acColorIndexMaroon = 1
acColorIndexOlive = 3
acColorIndexRed = 9
acColorIndexSilver = 8
acColorIndexTeal = 6
acColorIndexViolet = 5
acColorIndexWhite = 15
acColorIndexYellow = 11

# AcCommand enumeration
acCmdAboutMicrosoftAccess = 35
acCmdAddDataMacroAfterDelete = 720
acCmdAddDataMacroAfterInsert = 718
acCmdAddDataMacroAfterUpdate = 719
acCmdAddDataMacroValidateChange = 722
acCmdAddDataMacroValidateDelete = 721
acCmdAddFromOutlook = 583
acCmdAddInManager = 526
acCmdAddNamedDataMacro = 723
acCmdAddToNewGroup = 494
acCmdAddWatch = 201
acCmdAdvancedFilterSort = 99
acCmdAlignBottom = 46
acCmdAlignCenter = 477
acCmdAlignLeft = 43
acCmdAlignmentAndSizing = 478
acCmdAlignMiddle = 476
acCmdAlignRight = 44
acCmdAlignToGrid = 47
acCmdAlignTop = 45
acCmdAlignToShortest = 153
acCmdAlignToTallest = 154
acCmdAnalyzePerformance = 283
acCmdAnalyzeTable = 284
acCmdAnchorBottomLeft = 616
acCmdAnchorBottomRight = 618
acCmdAnchorBottomStretchAcross = 617
acCmdAnchorStretchAcross = 611
acCmdAnchorStretchDown = 613
acCmdAnchorStretchDownAcross = 614
acCmdAnchorStretchDownRight = 615
acCmdAnchorTopLeft = 610
acCmdAnchorTopRight = 612
acCmdAnswerWizard = 235
acCmdApplyAutoFormat1 = 648
acCmdApplyAutoFormat10 = 657
acCmdApplyAutoFormat11 = 658
acCmdApplyAutoFormat12 = 659
acCmdApplyAutoFormat13 = 660
acCmdApplyAutoFormat14 = 661
acCmdApplyAutoFormat15 = 662
acCmdApplyAutoFormat16 = 663
acCmdApplyAutoFormat17 = 664
acCmdApplyAutoFormat18 = 665
acCmdApplyAutoFormat19 = 666
acCmdApplyAutoFormat2 = 649
acCmdApplyAutoFormat20 = 667
acCmdApplyAutoFormat21 = 668
acCmdApplyAutoFormat22 = 669
acCmdApplyAutoFormat23 = 670
acCmdApplyAutoFormat24 = 671
acCmdApplyAutoFormat25 = 672
acCmdApplyAutoFormat3 = 650
acCmdApplyAutoFormat4 = 651
acCmdApplyAutoFormat5 = 652
acCmdApplyAutoFormat6 = 653
acCmdApplyAutoFormat7 = 654
acCmdApplyAutoFormat8 = 655
acCmdApplyAutoFormat9 = 656
acCmdApplyDefault = 55
acCmdApplyFilterSort = 93
acCmdAppMaximize = 10
acCmdAppMinimize = 11
acCmdAppMove = 12
acCmdAppRestore = 9
acCmdAppSize = 13
acCmdArrangeIconsAuto = 218
acCmdArrangeIconsByCreated = 216
acCmdArrangeIconsByModified = 217
acCmdArrangeIconsByName = 214
acCmdArrangeIconsByType = 215
acCmdAutoCorrect = 261
acCmdAutoDial = 192
acCmdAutoFormat = 270
acCmdBackgroundPicture = 474
acCmdBackgroundSound = 475
acCmdBackup = 513
acCmdBookmarksClearAll = 310
acCmdBookmarksNext = 308
acCmdBookmarksPrevious = 309
acCmdBookmarksToggle = 307
acCmdBringToFront = 52
acCmdBrowseSharePointList = 621
acCmdCalculatedColumn = 698
acCmdCallStack = 172
acCmdChangeToCheckBox = 231
acCmdChangeToComboBox = 230
acCmdChangeToCommandButton = 501
acCmdChangeToImage = 234
acCmdChangeToLabel = 228
acCmdChangeToListBox = 229
acCmdChangeToOptionButton = 233
acCmdChangeToTextBox = 227
acCmdChangeToToggleButton = 232
acCmdClearAll = 146
acCmdClearAllBreakpoints = 132
acCmdClearGrid = 71
acCmdClearHyperlink = 343
acCmdClearItemDefaults = 237
acCmdClose = 58
acCmdCloseAll = 646
acCmdCloseDatabase = 538
acCmdCloseWindow = 186
acCmdCollectDataViaEmail = 608
acCmdColumnWidth = 117
acCmdCompactDatabase = 4
acCmdCompatCheckCurrentObject = 696
acCmdCompatCheckDatabase = 695
acCmdCompileAllModules = 125
acCmdCompileAndSaveAllModules = 126
acCmdCompileLoadedModules = 290
acCmdCompleteWord = 306
acCmdConditionalFormatting = 500
acCmdConnection = 383
acCmdControlMarginsMedium = 630
acCmdControlMarginsNarrow = 629
acCmdControlMarginsNone = 628
acCmdControlMarginsWide = 631
acCmdControlPaddingMedium = 634
acCmdControlPaddingNarrow = 633
acCmdControlPaddingNone = 632
acCmdControlPaddingWide = 635
acCmdControlWizardsToggle = 197
acCmdConvertDatabase = 171
acCmdConvertLinkedTableToLocal = 700
acCmdConvertMacrosToVisualBasic = 279
acCmdCopy = 190
acCmdCopyDatabaseFile = 516
acCmdCopyHyperlink = 328
acCmdCreateMenuFromMacro = 334
acCmdCreateRelationship = 150
acCmdCreateReplica = 263
acCmdCreateShortcut = 219
acCmdCreateShortcutMenuFromMacro = 336
acCmdCreateToolbarFromMacro = 335
acCmdCut = 189
acCmdDatabaseProperties = 256
acCmdDatabaseSplitter = 520
acCmdDataEntry = 78
acCmdDataOutline = 468
acCmdDatasheetView = 282
acCmdDateAndTime = 226
acCmdDebugWindow = 123
acCmdDelete = 337
acCmdDeleteGroup = 493
acCmdDeletePage = 332
acCmdDeleteQueryColumn = 81
acCmdDeleteRecord = 223
acCmdDeleteRows = 188
acCmdDeleteSharePointList = 627
acCmdDeleteTab = 255
acCmdDeleteTable = 489
acCmdDeleteTableColumn = 271
acCmdDeleteWatch = 267
acCmdDesignObject = 697
acCmdDesignView = 183
acCmdDiagramAddRelatedTables = 373
acCmdDiagramAutosizeSelectedTables = 378
acCmdDiagramDeleteRelationship = 382
acCmdDiagramLayoutDiagram = 380
acCmdDiagramLayoutSelection = 379
acCmdDiagramModifyUserDefinedView = 375
acCmdDiagramNewLabel = 372
acCmdDiagramNewTable = 381
acCmdDiagramRecalculatePageBreaks = 377
acCmdDiagramShowRelationshipLabels = 374
acCmdDiagramViewPageBreaks = 376
acCmdDiscardChanges = 639
acCmdDiscardChangesAndRefresh = 640
acCmdDocMaximize = 15
acCmdDocMinimize = 60
acCmdDocMove = 16
acCmdDocRestore = 14
acCmdDocSize = 17
acCmdDocumenter = 285
acCmdDropSQLDatabase = 517
acCmdDuplicate = 34
acCmdEditHyperlink = 325
acCmdEditingAllowed = 70
acCmdEditListItems = 607
acCmdEditRelationship = 151
acCmdEditTriggers = 384
acCmdEditWatch = 202
acCmdEncryptDecryptDatabase = 5
acCmdEnd = 198
acCmdExit = 3
acCmdExportAccess = 559
acCmdExportdBase = 565
acCmdExportExcel = 556
acCmdExportFixedFormat = 592
acCmdExportHTML = 564
acCmdExportODBC = 562
acCmdExportRTF = 558
acCmdExportSharePointList = 557
acCmdExportSnapShot = 563
acCmdExportText = 560
acCmdExportXML = 561
acCmdFavoritesAddTo = 299
acCmdFavoritesOpen = 298
acCmdFieldList = 42
acCmdFilterByForm = 207
acCmdFilterBySelection = 208
acCmdFilterExcludingSelection = 277
acCmdFilterMenu = 619
acCmdFind = 30
acCmdFindNext = 341
acCmdFindNextWordUnderCursor = 313
acCmdFindPrevious = 120
acCmdFindPrevWordUnderCursor = 312
acCmdFitToWindow = 245
acCmdFont = 19
acCmdFormatCells = 77
acCmdFormHdrFtr = 36
acCmdFormView = 281
acCmdFreezeColumn = 105
acCmdGoBack = 294
acCmdGoContinue = 127
acCmdGoForward = 295
acCmdGroupByTable = 387
acCmdGroupControls = 484
acCmdHideColumns = 79
acCmdHideMessageBar = 677
acCmdHidePane = 365
acCmdHideTable = 147
acCmdHorizontalSpacingDecrease = 158
acCmdHorizontalSpacingIncrease = 159
acCmdHorizontalSpacingMakeEqual = 157
acCmdHyperlinkDisplayText = 329
acCmdImportAttachAccess = 544
acCmdImportAttachdBase = 552
acCmdImportAttachExcel = 545
acCmdImportAttachHTML = 550
acCmdImportAttachODBC = 549
acCmdImportAttachOutlook = 551
acCmdImportAttachSharePointList = 547
acCmdImportAttachText = 546
acCmdImportAttachXML = 548
acCmdIndent = 205
acCmdIndexes = 152
acCmdInsertActiveXControl = 258
acCmdInsertChart = 293
acCmdInsertFile = 39
acCmdInsertFileIntoModule = 118
acCmdInsertHyperlink = 259
acCmdInsertLogo = 585
acCmdInsertLookupColumn = 273
acCmdInsertLookupField = 291
acCmdInsertMovieFromFile = 469
acCmdInsertNavigationButton = 724
acCmdInsertObject = 33
acCmdInsertPage = 331
acCmdInsertPicture = 222
acCmdInsertPivotTable = 470
acCmdInsertProcedure = 262
acCmdInsertQueryColumn = 82
acCmdInsertRows = 187
acCmdInsertSpreadsheet = 471
acCmdInsertSubdatasheet = 499
acCmdInsertTableColumn = 272
acCmdInsertTitle = 586
acCmdInsertUnboundSection = 472
acCmdInvokeBuilder = 178
acCmdJoinProperties = 72
acCmdLastPosition = 339
acCmdLayoutGridlinesBoth = 574
acCmdLayoutGridlinesBottom = 580
acCmdLayoutGridlinesCrossHatch = 578
acCmdLayoutGridlinesHorizontal = 576
acCmdLayoutGridlinesNone = 577
acCmdLayoutGridlinesOutline = 581
acCmdLayoutGridlinesTop = 579
acCmdLayoutGridlinesVertical = 575
acCmdLayoutInsertColumnLeft = 680
acCmdLayoutInsertColumnRight = 681
acCmdLayoutInsertRowAbove = 678
acCmdLayoutInsertRowBelow = 679
acCmdLayoutMergeCells = 682
acCmdLayoutPreview = 141
acCmdLayoutSplitColumnCell = 683
acCmdLayoutSplitRowCell = 684
acCmdLayoutView = 593
acCmdLineUpIcons = 213
acCmdLinkedTableManager = 519
acCmdLinkTables = 102
acCmdListConstants = 303
acCmdLoadFromQuery = 95
acCmdMacroAllActions = 589
acCmdMakeMDEFile = 7
acCmdManageAttachments = 673
acCmdManageReplies = 609
acCmdManageTableEvents = 717
acCmdMaximiumRecords = 508
acCmdMicrosoftAccessHelpTopics = 100
acCmdMicrosoftOnTheWeb = 236
acCmdModifySharePointList = 622
acCmdModifySharePointListAlerts = 623
acCmdModifySharePointListPermissions = 625
acCmdModifySharePointListWorkflow = 624
acCmdMoreWindows = 8
acCmdMoveColumnCellDown = 573
acCmdMoveColumnCellUp = 572
acCmdNewDatabase = 26
acCmdNewGroup = 491
acCmdNewObjectAutoForm = 193
acCmdNewObjectAutoFormWeb = 705
acCmdNewObjectAutoReport = 194
acCmdNewObjectAutoReportWeb = 706
acCmdNewObjectBlankForm = 600
acCmdNewObjectBlankFormWeb = 703
acCmdNewObjectBlankReport = 602
acCmdNewObjectBlankReportWeb = 704
acCmdNewObjectClassModule = 140
acCmdNewObjectContinuousForm = 594
acCmdNewObjectContinuousFormWeb = 701
acCmdNewObjectDatasheetForm = 598
acCmdNewObjectDatasheetFormWeb = 702
acCmdNewObjectDesignForm = 604
acCmdNewObjectDesignQuery = 603
acCmdNewObjectDesignReport = 605
acCmdNewObjectDesignTable = 606
acCmdNewObjectDiagram = 352
acCmdNewObjectForm = 136
acCmdNewObjectFunction = 394
acCmdNewObjectLabelsReport = 601
acCmdNewObjectMacro = 138
acCmdNewObjectMacroWeb = 708
acCmdNewObjectModalForm = 599
acCmdNewObjectModule = 139
acCmdNewObjectNavigationLeft = 690
acCmdNewObjectNavigationLeftWeb = 710
acCmdNewObjectNavigationRight = 691
acCmdNewObjectNavigationRightWeb = 711
acCmdNewObjectNavigationTop = 689
acCmdNewObjectNavigationTopLeft = 693
acCmdNewObjectNavigationTopLeftWeb = 713
acCmdNewObjectNavigationTopRight = 694
acCmdNewObjectNavigationTopRightWeb = 714
acCmdNewObjectNavigationTopTop = 692
acCmdNewObjectNavigationTopTopWeb = 712
acCmdNewObjectNavigationTopWeb = 709
acCmdNewObjectPivotChart = 596
acCmdNewObjectPivotTable = 597
acCmdNewObjectQuery = 135
acCmdNewObjectQueryWeb = 707
acCmdNewObjectReport = 137
acCmdNewObjectSplitForm = 595
acCmdNewObjectStoredProcedure = 351
acCmdNewObjectTable = 134
acCmdNewObjectView = 350
acCmdObjBrwFindWholeWordOnly = 314
acCmdObjBrwGroupMembers = 318
acCmdObjBrwHelp = 316
acCmdObjBrwShowHiddenMembers = 315
acCmdObjBrwViewDefinition = 317
acCmdObjectBrowser = 200
acCmdOfficeClipboard = 488
acCmdOLEDDELinks = 27
acCmdOLEObjectConvert = 167
acCmdOLEObjectDefaultVerb = 57
acCmdOpenDatabase = 25
acCmdOpenHyperlink = 326
acCmdOpenNewHyperlink = 327
acCmdOpenSearchPage = 253
acCmdOpenStartPage = 252
acCmdOpenTable = 221
acCmdOpenURL = 251
acCmdOptions = 49
acCmdOutdent = 206
acCmdOutputToExcel = 175
acCmdOutputToRTF = 176
acCmdOutputToText = 177
acCmdPageHdrFtr = 182
acCmdPageNumber = 225
acCmdPageProperties = 467
acCmdPageSetup = 32
acCmdParameterInfo = 305
acCmdPartialReplicaWizard = 524
acCmdPaste = 191
acCmdPasteAppend = 38
acCmdPasteAsHyperlink = 490
acCmdPasteFormatting = 587
acCmdPasteSpecial = 64
acCmdPivotAutoAverage = 416
acCmdPivotAutoCount = 413
acCmdPivotAutoFilter = 398
acCmdPivotAutoMax = 415
acCmdPivotAutoMin = 414
acCmdPivotAutoStdDev = 417
acCmdPivotAutoStdDevP = 419
acCmdPivotAutoSum = 412
acCmdPivotAutoVar = 418
acCmdPivotAutoVarP = 420
acCmdPivotChartByRowByColumn = 456
acCmdPivotChartDrillInto = 457
acCmdPivotChartDrillOut = 532
acCmdPivotChartMultiplePlots = 458
acCmdPivotChartMultiplePlotsUnifiedScale = 459
acCmdPivotChartShowLegend = 455
acCmdPivotChartSortAscByTotal = 534
acCmdPivotChartSortDescByTotal = 535
acCmdPivotChartType = 453
acCmdPivotChartUndo = 460
acCmdPivotChartView = 397
acCmdPivotCollapse = 400
acCmdPivotDelete = 454
acCmdPivotDropAreas = 452
acCmdPivotExpand = 401
acCmdPivotRefresh = 404
acCmdPivotShowAll = 461
acCmdPivotShowBottom1 = 432
acCmdPivotShowBottom10 = 435
acCmdPivotShowBottom10Percent = 440
acCmdPivotShowBottom1Percent = 437
acCmdPivotShowBottom2 = 433
acCmdPivotShowBottom25 = 436
acCmdPivotShowBottom25Percent = 441
acCmdPivotShowBottom2Percent = 438
acCmdPivotShowBottom5 = 434
acCmdPivotShowBottom5Percent = 439
acCmdPivotShowBottomOther = 442
acCmdPivotShowTop1 = 421
acCmdPivotShowTop10 = 424
acCmdPivotShowTop10Percent = 429
acCmdPivotShowTop1Percent = 426
acCmdPivotShowTop2 = 422
acCmdPivotShowTop25 = 425
acCmdPivotShowTop25Percent = 430
acCmdPivotShowTop2Percent = 427
acCmdPivotShowTop5 = 423
acCmdPivotShowTop5Percent = 428
acCmdPivotShowTopOther = 431
acCmdPivotTableClearCustomOrdering = 527
acCmdPivotTableCreateCalcField = 444
acCmdPivotTableCreateCalcTotal = 443
acCmdPivotTableDemote = 411
acCmdPivotTableExpandIndicators = 451
acCmdPivotTableExportToExcel = 405
acCmdPivotTableFilterBySelection = 528
acCmdPivotTableGroupItems = 530
acCmdPivotTableHideDetails = 402
acCmdPivotTableMoveToColumnArea = 407
acCmdPivotTableMoveToDetailArea = 409
acCmdPivotTableMoveToFilterArea = 408
acCmdPivotTableMoveToRowArea = 406
acCmdPivotTablePercentColumnTotal = 447
acCmdPivotTablePercentGrandTotal = 450
acCmdPivotTablePercentParentColumnItem = 449
acCmdPivotTablePercentParentRowItem = 448
acCmdPivotTablePercentRowTotal = 446
acCmdPivotTablePromote = 410
acCmdPivotTableRemove = 529
acCmdPivotTableShowAsNormal = 445
acCmdPivotTableShowDetails = 403
acCmdPivotTableSubtotal = 399
acCmdPivotTableUngroupItems = 531
acCmdPivotTableView = 396
acCmdPrepareDatabaseForWeb = 716
acCmdPreviewEightPages = 249
acCmdPreviewFourPages = 248
acCmdPreviewOnePage = 246
acCmdPreviewTwelvePages = 250
acCmdPreviewTwoPages = 247
acCmdPrimaryKey = 107
acCmdPrint = 340
acCmdPrintPreview = 54
acCmdPrintRelationships = 483
acCmdPrintSelection = 590
acCmdProcedureDefinition = 122
acCmdProperties = 287
acCmdPublishDatabase = 537
acCmdPublishDefaults = 324
acCmdPublishFixedFormat = 591
acCmdQueryAddToOutput = 362
acCmdQueryGroupBy = 361
acCmdQueryParameters = 76
acCmdQueryTotals = 73
acCmdQueryTypeAppend = 91
acCmdQueryTypeCrosstab = 74
acCmdQueryTypeDelete = 92
acCmdQueryTypeMakeTable = 94
acCmdQueryTypeSelect = 89
acCmdQueryTypeSQLDataDefinition = 168
acCmdQueryTypeSQLPassThrough = 169
acCmdQueryTypeSQLUnion = 180
acCmdQueryTypeUpdate = 90
acCmdQuickInfo = 304
acCmdQuickPrint = 278
acCmdQuickWatch = 203
acCmdRecordsGoToFirst = 67
acCmdRecordsGoToLast = 68
acCmdRecordsGoToNew = 28
acCmdRecordsGoToNext = 65
acCmdRecordsGoToPrevious = 66
acCmdRecoverDesignMaster = 265
acCmdRedo = 199
acCmdReferences = 260
acCmdRefresh = 18
acCmdRefreshData = 541
acCmdRefreshPage = 297
acCmdRefreshSharePointList = 626
acCmdRegisterActiveXControls = 254
acCmdRelationships = 133
acCmdRemove = 366
acCmdRemoveAllFilters = 644
acCmdRemoveAllSorts = 645
acCmdRemoveFilterFromCurrentColumn = 643
acCmdRemoveFilterSort = 144
acCmdRemoveFromLayout = 582
acCmdRemoveTable = 84
acCmdRename = 143
acCmdRenameColumn = 274
acCmdRenameGroup = 492
acCmdRepairDatabase = 6
acCmdReplace = 29
acCmdReportHdrFtr = 37
acCmdReportView = 539
acCmdReset = 124
acCmdResolveConflicts = 266
acCmdRestore = 514
acCmdRowHeight = 116
acCmdRun = 181
acCmdRunMacro = 31
acCmdRunOpenMacro = 338
acCmdSave = 20
acCmdSaveAllModules = 280
acCmdSaveAs = 21
acCmdSaveAsHTML = 321
acCmdSaveAsOutlookContact = 584
acCmdSaveAsQuery = 96
acCmdSaveAsReport = 142
acCmdSaveAsTemplate = 686
acCmdSaveDatabaseAsNewTemplatePart = 687
acCmdSavedExports = 555
acCmdSavedImports = 543
acCmdSaveLayout = 145
acCmdSaveModuleAsText = 119
acCmdSaveRecord = 97
acCmdSaveSelectionAsNewDataType = 688
acCmdSelectAll = 333
acCmdSelectAllRecords = 109
acCmdSelectEntireColumn = 571
acCmdSelectEntireLayout = 715
acCmdSelectEntireRow = 570
acCmdSelectForm = 40
acCmdSelectRecord = 50
acCmdSelectReport = 319
acCmdSend = 173
acCmdSendToBack = 53
acCmdServerFilterByForm = 507
acCmdServerProperties = 496
acCmdSetCaption = 637
acCmdSetControlDefaults = 56
acCmdSetDatabasePassword = 275
acCmdSetNextStatement = 129
acCmdShareOnSharePoint = 542
acCmdSharePointSiteRecycleBin = 641
acCmdShowAllRelationships = 149
acCmdShowColumnHistory = 620
acCmdShowDatePicker = 636
acCmdShowDirectRelationships = 148
acCmdShowEnvelope = 533
acCmdShowLogicCatalog = 685
acCmdShowMembers = 302
acCmdShowMessageBar = 676
acCmdShowNextStatement = 130
acCmdShowTable = 185
acCmdSingleStep = 88
acCmdSizeToFit = 59
acCmdSizeToFitForm = 69
acCmdSizeToGrid = 48
acCmdSizeToNarrowest = 155
acCmdSizeToWidest = 156
acCmdSnapToGrid = 62
acCmdSortAscending = 163
acCmdSortDescending = 164
acCmdSortingAndGrouping = 51
acCmdSpeech = 511
acCmdSpelling = 269
acCmdSQLView = 184
acCmdStackedLayout = 568
acCmdStartNewWorkflow = 675
acCmdStartupProperties = 224
acCmdStepInto = 342
acCmdStepOut = 311
acCmdStepOver = 128
acCmdStepToCursor = 204
acCmdSubdatasheetCollapseAll = 505
acCmdSubdatasheetExpandAll = 504
acCmdSubdatasheetRemove = 506
acCmdSubformDatasheet = 108
acCmdSubformDatasheetView = 463
acCmdSubformFormView = 462
acCmdSubformInNewWindow = 495
acCmdSubformPivotChartView = 465
acCmdSubformPivotTableView = 464
acCmdSwitchboardManager = 521
acCmdSynchronize = 638
acCmdSynchronizeNow = 264
acCmdSyncWebApplication = 699
acCmdTabControlPageOrder = 330
acCmdTableAddTable = 498
acCmdTableCustomView = 497
acCmdTableNames = 75
acCmdTabOrder = 41
acCmdTabularLayout = 569
acCmdTestValidationRules = 196
acCmdTileHorizontally = 286
acCmdTileVertically = 23
acCmdToggleBreakpoint = 131
acCmdToggleCacheListData = 642
acCmdToggleFilter = 220
acCmdToggleOffline = 540
acCmdToolbarControlProperties = 301
acCmdToolbarsCustomize = 165
acCmdTransferSQLDatabase = 515
acCmdTransparentBackground = 288
acCmdTransparentBorder = 289
acCmdUndo = 292
acCmdUnfreezeAllColumns = 106
acCmdUngroupControls = 485
acCmdUnhideColumns = 80
acCmdUpsizingWizard = 522
acCmdUserAndGroupAccounts = 104
acCmdUserAndGroupPermissions = 103
acCmdUserLevelSecurityWizard = 276
acCmdVerticalSpacingDecrease = 161
acCmdVerticalSpacingIncrease = 162
acCmdVerticalSpacingMakeEqual = 160
acCmdViewCode = 170
acCmdViewDetails = 210
acCmdViewDiagrams = 354
acCmdViewFieldList = 353
acCmdViewForms = 112
acCmdViewFunctions = 395
acCmdViewGrid = 63
acCmdViewLargeIcons = 209
acCmdViewList = 212
acCmdViewMacros = 114
acCmdViewModules = 115
acCmdViewObjectDependencies = 536
acCmdViewQueries = 111
acCmdViewReports = 113
acCmdViewRuler = 61
acCmdViewShowPaneDiagram = 358
acCmdViewShowPaneGrid = 359
acCmdViewShowPaneSQL = 357
acCmdViewSmallIcons = 211
acCmdViewStoredProcedures = 355
acCmdViewTableColumnNames = 363
acCmdViewTableColumnProperties = 368
acCmdViewTableKeys = 369
acCmdViewTableNameOnly = 364
acCmdViewTables = 110
acCmdViewTableUserView = 370
acCmdViewToolbox = 85
acCmdViewVerifySQL = 360
acCmdViewViews = 356
acCmdVisualBasicEditor = 525
acCmdWindowArrangeIcons = 24
acCmdWindowCascade = 22
acCmdWindowHide = 2
acCmdWindowSplit = 121
acCmdWindowUnhide = 1
acCmdWordMailMerge = 195
acCmdWorkflowTasks = 674
acCmdWorkgroupAdministrator = 391
acCmdZoom10 = 244
acCmdZoom100 = 240
acCmdZoom1000 = 482
acCmdZoom150 = 239
acCmdZoom200 = 238
acCmdZoom25 = 243
acCmdZoom50 = 242
acCmdZoom500 = 481
acCmdZoom75 = 241
acCmdZoomBox = 179
acCmdZoomSelection = 371

# AcControlType enumeration
acAttachment = 126
acBoundObjectFrame = 108
acChart = 133
acCheckBox = 106
acComboBox = 111
acCommandButton = 104
acCustomControl = 119
acEdgeBrowser = 134
acEmptyCell = 127
acImage = 103
acLabel = 100
acLine = 102
acListBox = 110
acNavigationButton = 130
acNavigationControl = 129
acObjectFrame = 114
acOptionButton = 105
acOptionGroup = 107
acPage = 124
acPageBreak = 118
acRectangle = 101
acSubForm = 112
acTabCtl = 123
acTextBox = 109
acToggleButton = 122
acWebBrowser = 128

# AcCurrentView enumeration
acCurViewDatasheet = 2
acCurViewDesign = 0
acCurViewFormBrowse = 1
acCurViewLayout = 7
acCurViewPivotChart = 4
acCurViewPivotTable = 3
acCurViewPreview = 5
acCurViewReportBrowse = 6

# AcCursorOnHover enumeration
acCursorOnHoverDefault = 0
acCursorOnHoverHyperlinkHand = 1

# AcDashType enumeration
acDashTypeDash = 1
acDashTypeDashDot = 3
acDashTypeDot = 2
acDashTypeSolid = 0

# AcDataLabelDisplayFormat enumeration
acDataLabelDisplayNone = 0
acDataLabelDisplayNumber = 1
acDataLabelDisplayPercentage = 2

# AcDataLabelPosition enumeration
acBestFit = 0
acInsideCenter = 1
acInsideEnd = 2
acOutsideCircle = 3
acOutsideEnd = 4

# AcDataObjectType enumeration
acActiveDataObject = -1
acDataForm = 2
acDataFunction = 10
acDataQuery = 1
acDataReport = 3
acDataServerView = 7
acDataStoredProcedure = 9
acDataTable = 0

# AcDataTransferType enumeration
acExport = 1
acImport = 0
acLink = 2

# AcDateGroupType enumeration
acDateGroupDay = 4
acDateGroupMonth = 3
acDateGroupNone = 0
acDateGroupQuarter = 2
acDateGroupYear = 1

# AcDefReportView enumeration
acDefViewPreview = 0
acDefViewReportBrowse = 1

# AcDefView enumeration
acDefViewContinuous = 1
acDefViewDatasheet = 2
acDefViewPivotChart = 4
acDefViewPivotTable = 3
acDefViewSingle = 0
acDefViewSplitForm = 5

# AcDisplayAs enumeration
acDisplayAsIcon = 1
acDisplayAsImageIcon = 0
acDisplayAsPaperclip = 2

# AcDisplayAsHyperlink enumeration
acDisplayAsHyperlinkAlways = 1
acDisplayAsHyperlinkIfHlink = 0
acDisplayAsHyperlinkOnScreenOnly = 2

# AcExportQuality enumeration
acExportQualityPrint = 0
acExportQualityScreen = 1

# AcExportXMLEncoding enumeration
acUTF16 = 1
acUTF8 = 0

# AcExportXMLObjectType enumeration
acExportForm = 2
acExportFunction = 10
acExportQuery = 1
acExportReport = 3
acExportServerView = 7
acExportStoredProcedure = 9
acExportTable = 0

# AcExportXMLOtherFlags enumeration
acEmbedSchema = 1
acExcludePrimaryKeyAndIndexes = 2
acExportAllTableAndFieldProperties = 32
acLiveReportSource = 8
acPersistReportML = 16
acRunFromServer = 4

# AcExportXMLSchemaFormat enumeration
acSchemaNone = 0
acSchemaXSD = 1

# AcFileFormat enumeration
acFileFormatAccess2 = 2
acFileFormatAccess95 = 7
acFileFormatAccess97 = 8
acFileFormatAccess2000 = 9
acFileFormatAccess2002 = 10
acFileFormatAccess2007 = 12

# AcFilterType enumeration
acFilterNormal = 0
acServerFilter = 1

# AcFindField enumeration
acAll = 0
acCurrent = -1

# AcFindMatch enumeration
acAnywhere = 0
acEntire = 1
acStart = 2

# AcFormatBarLimits enumeration
acAutomatic = 0
acNumber = 1
acPercent = 2

# AcFormatConditionOperator enumeration
acBetween = 0
acEqual = 2
acGreaterThan = 4
acGreaterThanOrEqual = 6
acLessThan = 5
acLessThanOrEqual = 7
acNotBetween = 1
acNotEqual = 3

# AcFormatConditionType enumeration
acDataBar = 3
acExpression = 1
acFieldHasFocus = 2
acFieldValue = 0

# AcFormOpenDataMode enumeration
acFormAdd = 0
acFormEdit = 1
acFormPropertySettings = -1
acFormReadOnly = 2

# AcFormView enumeration
acDesign = 1
acFormDS = 3
acFormPivotChart = 5
acFormPivotTable = 4
acLayout = 6
acNormal = 0
acPreview = 2

# AcGridlineType enumeration
acGridlineTypeNone = 0
acGridlineTypeMajor = 1
acGridlineTypeMinor = 2
acGridlineTypeMajorMinor = 3

# AcHorizontalAnchor enumeration
acHorizontalAnchorBoth = 2
acHorizontalAnchorLeft = 0
acHorizontalAnchorRight = 1

# AcHyperlinkPart enumeration
acAddress = 2
acDisplayedValue = 0
acDisplayText = 1
acFullAddress = 5
acScreenTip = 4
acSubAddress = 3

# AcImeMode enumeration
acImeModeAlpha = 8
acImeModeAlphaFull = 7
acImeModeDisable = 3
acImeModeHangul = 10
acImeModeHangulFull = 9
acImeModeHiragana = 4
acImeModeKatakana = 5
acImeModeKatakanaHalf = 6
acImeModeNoControl = 0
acImeModeOff = 2
acImeModeOn = 1

# AcImportXMLOption enumeration
acAppendData = 2
acStructureAndData = 1
acStructureOnly = 0

# AcLayoutType enumeration
acLayoutNone = 0
acLayoutStacked = 2
acLayoutTabular = 1

# AcLegendPosition enumeration
acLegendPositionBottom = 3
acLegendPositionLeft = 0
acLegendPositionRight = 2
acLegendPositionTop = 1

# AcMarkerType enumeration
acMarkerAsterisk = 4
acMarkerCircle = 8
acMarkerDiamond = 2
acMarkerLongDash = 7
acMarkerNone = 0
acMarkerPlus = 9
acMarkerShortDash = 6
acMarkerSquare = 1
acMarkerTriangle = 3
acMarkerX = 4

# AcMissingDataPolicy enumeration
acDoNotPlot = 1
acPlotAsInterpolated = 2
acPlotAsZero = 0

# AcModuleType enumeration
acClassModule = 1
acStandardModule = 0

# AcNavigationSpan enumeration
acHorizontal = 0
acVertical = 1

# AcNewDatabaseFormat enumeration
acNewDatabaseFormatAccess12 = 12
acNewDatabaseFormatAccess2000 = 9
acNewDatabaseFormatAccess2002 = 10
acNewDatabaseFormatUserDefault = 0

# AcObjectType enumeration
acDatabaseProperties = 11
acDefault = -1
acDiagram = 8
acForm = 2
acFunction = 10
acMacro = 4
acModule = 5
acQuery = 1
acReport = 3
acServerView = 7
acStoredProcedure = 9
acTable = 0
acTableDataMacro = 12

# AcOpenDataMode enumeration
acAdd = 0
acEdit = 1
acReadOnly = 2

# AcOutputObjectType enumeration
acOutputForm = 2
acOutputFunction = 10
acOutputModule = 5
acOutputQuery = 1
acOutputReport = 3
acOutputServerView = 7
acOutputStoredProcedure = 9
acOutputTable = 0

# AcPercentageDataLabelDecimalPlaces enumeration
acDecimalPlaces0 = 0
acDecimalPlaces1 = 1
acDecimalPlaces2 = 2
acDecimalPlaces3 = 3
acDecimalPlaces4 = 4
acDecimalPlaces5 = 5
acDecimalPlaces6 = 6
acDecimalPlaces7 = 7

# AcPictureCaptionArrangement enumeration
acBottom = 3
acGeneral = 1
acLeft = 4
acNoPictureCaption = 0
acRight = 5
acTop = 2

# AcPrintColor enumeration
acPRCMColor = 2
acPRCMMonochrome = 1

# AcPrintDuplex enumeration
acPRDPHorizontal = 2
acPRDPSimplex = 1
acPRDPVertical = 3

# AcPrintItemLayout enumeration
acPRHorizontalColumnLayout = 1953
acPRVerticalColumnLayout = 1954

# AcPrintObjQuality enumeration
acPRPQDraft = -1
acPRPQHigh = -4
acPRPQLow = -2
acPRPQMedium = -3

# AcPrintOrientation enumeration
acPRORLandscape = 2
acPRORPortrait = 1

# AcPrintPaperBin enumeration
acPRBNAuto = 7
acPRBNCassette = 14
acPRBNEnvelope = 5
acPRBNEnvManual = 6
acPRBNFormSource = 15
acPRBNLargeCapacity = 11
acPRBNLargeFmt = 10
acPRBNLower = 2
acPRBNManual = 4
acPRBNMiddle = 3
acPRBNSmallFmt = 9
acPRBNTractor = 8
acPRBNUpper = 1

# AcPrintPaperSize enumeration
acPRPS10x14 = 16
acPRPS11x17 = 17
acPRPSA3 = 8
acPRPSA4 = 9
acPRPSA4Small = 10
acPRPSA5 = 11
acPRPSB4 = 12
acPRPSB5 = 13
acPRPSCSheet = 24
acPRPSDSheet = 25
acPRPSEnv10 = 20
acPRPSEnv11 = 21
acPRPSEnv12 = 22
acPRPSEnv14 = 23
acPRPSEnv9 = 19
acPRPSEnvB4 = 33
acPRPSEnvB5 = 34
acPRPSEnvB6 = 35
acPRPSEnvC3 = 29
acPRPSEnvC4 = 30
acPRPSEnvC5 = 28
acPRPSEnvC6 = 31
acPRPSEnvC65 = 32
acPRPSEnvDL = 27
acPRPSEnvItaly = 36
acPRPSEnvMonarch = 37
acPRPSEnvPersonal = 38
acPRPSESheet = 26
acPRPSExecutive = 7
acPRPSFanfoldLglGerman = 41
acPRPSFanfoldStdGerman = 40
acPRPSFanfoldUS = 39
acPRPSFolio = 14
acPRPSLedger = 4
acPRPSLegal = 5
acPRPSLetter = 1
acPRPSLetterSmall = 2
acPRPSNote = 18
acPRPSQuarto = 15
acPRPSStatement = 6
acPRPSTabloid = 3
acPRPSUser = 256

# AcPrintQuality enumeration
acDraft = 3
acHigh = 0
acLow = 2
acMedium = 1

# AcPrintRange enumeration
acPages = 2
acPrintAll = 0
acSelection = 1

# AcProjectType enumeration
acADP = 1
acMDB = 2
acNull = 0

# AcProperty enumeration
acPropertyBackColor = 8
acPropertyCaption = 9
acPropertyEnabled = 0
acPropertyForeColor = 7
acPropertyHeight = 6
acPropertyLeft = 3
acPropertyLocked = 2
acPropertyTop = 4
acPropertyValue = 10
acPropertyVisible = 1
acPropertyWidth = 5

# AcQuitOption enumeration
acQuitPrompt = 0
acQuitSaveAll = 1
acQuitSaveNone = 2

# AcRecord enumeration
acFirst = 2
acGoTo = 4
acLast = 3
acNewRec = 5
acNext = 1
acPrevious = 0

# AcResourceType enumeration
acResourceImage = 1
acResourceTheme = 0

# AcSearchDirection enumeration
acDown = 1
acSearchAll = 2
acUp = 0

# AcSection enumeration
acDetail = 0
acFooter = 2
acGroupLevel1Footer = 6
acGroupLevel1Header = 5
acGroupLevel2Footer = 8
acGroupLevel2Header = 7
acHeader = 1
acPageFooter = 4
acPageHeader = 3

# AcSendObjectType enumeration
acSendForm = 2
acSendModule = 5
acSendNoObject = -1
acSendQuery = 1
acSendReport = 3
acSendTable = 0

# AcSeparatorCharacters enumeration
acSeparatorCharactersComma = 3
acSeparatorCharactersNewLine = 1
acSeparatorCharactersSemiColon = 2
acSeparatorCharactersSystemSeparator = 0

# AcSharePointListTransferType enumeration
acImportSharePointList = 0
acLinkSharePointList = 1

# AcShowToolbar enumeration
acToolbarNo = 2
acToolbarWhereApprop = 1
acToolbarYes = 0

# AcSortOrderType enumeration
acSortOrderTypeNone = 0
acSortOrderTypeAscending = 1
acSortOrderTypeDescending = 2

# AcSplitFormDatasheet enumeration
acDatasheetAllowEdits = 0
acDatasheetReadOnly = 1

# AcSplitFormOrientation enumeration
acDatasheetOnBottom = 1
acDatasheetOnLeft = 2
acDatasheetOnRight = 3
acDatasheetOnTop = 0

# AcSplitFormPrinting enumeration
acFormOnly = 0
acGridOnly = 1

# AcSpreadSheetType enumeration
acSpreadsheetTypeExcel3 = 0
acSpreadsheetTypeExcel4 = 6
acSpreadsheetTypeExcel5 = 5
acSpreadsheetTypeExcel7 = 5
acSpreadsheetTypeExcel8 = 8
acSpreadsheetTypeExcel9 = 8
acSpreadsheetTypeExcel12 = 9
acSpreadsheetTypeExcel12Xml = 10

# AcSysCmdAction enumeration
acSysCmdAccessDir = 9
acSysCmdAccessVer = 7
acSysCmdClearHelpTopic = 11
acSysCmdClearStatus = 5
acSysCmdGetObjectState = 10
acSysCmdGetWorkgroupFile = 13
acSysCmdIniFile = 8
acSysCmdInitMeter = 1
acSysCmdProfile = 12
acSysCmdRemoveMeter = 3
acSysCmdRuntime = 6
acSysCmdSetStatus = 4
acSysCmdUpdateMeter = 2

# AcTextFormat enumeration
acTextFormatHTMLRichText = 1
acTextFormatPlain = 0

# AcTextTransferType enumeration
acExportDelim = 2
acExportFixed = 3
acExportHTML = 8
acExportMerge = 4
acImportDelim = 0
acImportFixed = 1
acImportHTML = 7
acLinkDelim = 5
acLinkFixed = 6
acLinkHTML = 9

# AcTransformXMLScriptOption enumeration
acDisableScript = 2
acEnableScript = 0
acPromptScript = 1

# AcTrendlineOptions enumeration
acTrendlineExponential = 2
acTrendlineLinear = 1
acTrendlineLogarithmic = 3
acTrendlineMovingAverage = 6
acTrendlineNone = 0
acTrendlinePolynomial = 4
acTrendlinePower = 5

# AcValueAxis enumeration
acPrimaryAxis = 0
acSecondaryAxis = 1

# AcVerticalAnchor enumeration
acVerticalAnchorBoth = 2
acVerticalAnchorBottom = 1
acVerticalAnchorTop = 0

# AcView enumeration
acViewDesign = 1
acViewLayout = 6
acViewNormal = 0
acViewPivotChart = 4
acViewPivotTable = 3
acViewPreview = 2
acViewReport = 5

# AcWebBrowserScrollBars enumeration
acScrollAuto = 0
acScrollNo = 2
acScrollYes = 1

# AcWebBrowserState enumeration
acComplete = 4
acInteractive = 3
acLoaded = 2
acLoading = 1
acUninitialized = 0

# AcWebUserDisplay enumeration
acWebUserEmail = 3
acWebUserID = 0
acWebUserLoginName = 2
acWebUserName = 1

# AcWebUserGroupsDisplay enumeration
acWebUserGroupID = 0
acWebUserGroupName = 1

# AcWindowMode enumeration
acDialog = 3
acHidden = 1
acIcon = 2
acWindowNormal = 0

# AcWordCloudShape enumeration
acWordCloudRectangle = 0
acWordCloudOval = 1
acWordCloudHeart = 2

# AcWordCloudWordOrientation enumeration
acWordCloudHorizontalVertical = 0
acWordCloudHorizontal = 1
acWordCloudVertical = 2

class AdditionalData:

    def __init__(self, additionaldata=None):
        self.com_object= additionaldata

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    def Add(self, var=None):
        arguments = com_arguments([unwrap(a) for a in [var]])
        return AdditionalData(self.com_object.Add(*arguments))

    def add(self, var=None):
        """Alias for Add"""
        arguments = [var]
        return self.Add(*arguments)


class AllDatabaseDiagrams:

    def __init__(self, alldatabasediagrams=None):
        self.com_object= alldatabasediagrams

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, var=None):
        arguments = com_arguments([unwrap(a) for a in [var]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, var=None):
        """Alias for Item"""
        arguments = [var]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class AllForms:

    def __init__(self, allforms=None):
        self.com_object= allforms

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, var=None):
        arguments = com_arguments([unwrap(a) for a in [var]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, var=None):
        """Alias for Item"""
        arguments = [var]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class AllFunctions:

    def __init__(self, allfunctions=None):
        self.com_object= allfunctions

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, var=None):
        arguments = com_arguments([unwrap(a) for a in [var]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, var=None):
        """Alias for Item"""
        arguments = [var]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class AllMacros:

    def __init__(self, allmacros=None):
        self.com_object= allmacros

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, var=None):
        arguments = com_arguments([unwrap(a) for a in [var]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, var=None):
        """Alias for Item"""
        arguments = [var]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class AllModules:

    def __init__(self, allmodules=None):
        self.com_object= allmodules

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, var=None):
        arguments = com_arguments([unwrap(a) for a in [var]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, var=None):
        """Alias for Item"""
        arguments = [var]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class AllQueries:

    def __init__(self, allqueries=None):
        self.com_object= allqueries

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, var=None):
        arguments = com_arguments([unwrap(a) for a in [var]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, var=None):
        """Alias for Item"""
        arguments = [var]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class AllReports:

    def __init__(self, allreports=None):
        self.com_object= allreports

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, var=None):
        arguments = com_arguments([unwrap(a) for a in [var]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, var=None):
        """Alias for Item"""
        arguments = [var]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class AllStoredProcedures:

    def __init__(self, allstoredprocedures=None):
        self.com_object= allstoredprocedures

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, var=None):
        arguments = com_arguments([unwrap(a) for a in [var]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, var=None):
        """Alias for Item"""
        arguments = [var]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class AllTables:

    def __init__(self, alltables=None):
        self.com_object= alltables

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, var=None):
        arguments = com_arguments([unwrap(a) for a in [var]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, var=None):
        """Alias for Item"""
        arguments = [var]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class AllViews:

    def __init__(self, allviews=None):
        self.com_object= allviews

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, var=None):
        arguments = com_arguments([unwrap(a) for a in [var]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, var=None):
        """Alias for Item"""
        arguments = [var]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class Application:

    def __init__(self, application=None):
        if application is None:
            self.com_object = win32com.client.gencache.EnsureDispatch("Access.Application")
        else:
            self.com_object = application

    @property
    def AppIcon(self):
        return self.com_object.AppIcon

    @property
    def appicon(self):
        """Alias for AppIcon"""
        return self.AppIcon

    @property
    def app_icon(self):
        """Alias for AppIcon"""
        return self.AppIcon

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AppTitle(self):
        return self.com_object.AppTitle

    @property
    def apptitle(self):
        """Alias for AppTitle"""
        return self.AppTitle

    @property
    def app_title(self):
        """Alias for AppTitle"""
        return self.AppTitle

    @property
    def Assistance(self):
        return self.com_object.Assistance

    @property
    def assistance(self):
        """Alias for Assistance"""
        return self.Assistance

    @property
    def AutoCorrect(self):
        return AutoCorrect(self.com_object.AutoCorrect)

    @property
    def autocorrect(self):
        """Alias for AutoCorrect"""
        return self.AutoCorrect

    @property
    def auto_correct(self):
        """Alias for AutoCorrect"""
        return self.AutoCorrect

    @property
    def AutomationSecurity(self):
        return self.com_object.AutomationSecurity

    @AutomationSecurity.setter
    def AutomationSecurity(self, value):
        self.com_object.AutomationSecurity = value

    @property
    def automationsecurity(self):
        """Alias for AutomationSecurity"""
        return self.AutomationSecurity

    @automationsecurity.setter
    def automationsecurity(self, value):
        """Alias for AutomationSecurity.setter"""
        self.AutomationSecurity = value

    @property
    def automation_security(self):
        """Alias for AutomationSecurity"""
        return self.AutomationSecurity

    @automation_security.setter
    def automation_security(self, value):
        """Alias for AutomationSecurity.setter"""
        self.AutomationSecurity = value

    @property
    def BrokenReference(self):
        return self.com_object.BrokenReference

    @property
    def brokenreference(self):
        """Alias for BrokenReference"""
        return self.BrokenReference

    @property
    def broken_reference(self):
        """Alias for BrokenReference"""
        return self.BrokenReference

    @property
    def Build(self):
        return self.com_object.Build

    @property
    def build(self):
        """Alias for Build"""
        return self.Build

    @property
    def CodeContextObject(self):
        return self.com_object.CodeContextObject

    @property
    def codecontextobject(self):
        """Alias for CodeContextObject"""
        return self.CodeContextObject

    @property
    def code_context_object(self):
        """Alias for CodeContextObject"""
        return self.CodeContextObject

    @property
    def CodeData(self):
        return self.com_object.CodeData

    @property
    def codedata(self):
        """Alias for CodeData"""
        return self.CodeData

    @property
    def code_data(self):
        """Alias for CodeData"""
        return self.CodeData

    @property
    def CodeProject(self):
        return self.com_object.CodeProject

    @property
    def codeproject(self):
        """Alias for CodeProject"""
        return self.CodeProject

    @property
    def code_project(self):
        """Alias for CodeProject"""
        return self.CodeProject

    @property
    def COMAddIns(self):
        return self.com_object.COMAddIns

    @property
    def comaddins(self):
        """Alias for COMAddIns"""
        return self.COMAddIns

    @property
    def c_o_m_add_ins(self):
        """Alias for COMAddIns"""
        return self.COMAddIns

    @property
    def CommandBars(self):
        return self.com_object.CommandBars

    @property
    def commandbars(self):
        """Alias for CommandBars"""
        return self.CommandBars

    @property
    def command_bars(self):
        """Alias for CommandBars"""
        return self.CommandBars

    @property
    def CurrentData(self):
        return self.com_object.CurrentData

    @property
    def currentdata(self):
        """Alias for CurrentData"""
        return self.CurrentData

    @property
    def current_data(self):
        """Alias for CurrentData"""
        return self.CurrentData

    @property
    def CurrentObjectName(self):
        return self.com_object.CurrentObjectName

    @property
    def currentobjectname(self):
        """Alias for CurrentObjectName"""
        return self.CurrentObjectName

    @property
    def current_object_name(self):
        """Alias for CurrentObjectName"""
        return self.CurrentObjectName

    @property
    def CurrentObjectType(self):
        return self.com_object.CurrentObjectType

    @property
    def currentobjecttype(self):
        """Alias for CurrentObjectType"""
        return self.CurrentObjectType

    @property
    def current_object_type(self):
        """Alias for CurrentObjectType"""
        return self.CurrentObjectType

    @property
    def CurrentProject(self):
        return self.com_object.CurrentProject

    @property
    def currentproject(self):
        """Alias for CurrentProject"""
        return self.CurrentProject

    @property
    def current_project(self):
        """Alias for CurrentProject"""
        return self.CurrentProject

    @property
    def DBEngine(self):
        return self.com_object.DBEngine

    @property
    def dbengine(self):
        """Alias for DBEngine"""
        return self.DBEngine

    @property
    def d_b_engine(self):
        """Alias for DBEngine"""
        return self.DBEngine

    @property
    def DoCmd(self):
        return self.com_object.DoCmd

    @property
    def docmd(self):
        """Alias for DoCmd"""
        return self.DoCmd

    @property
    def do_cmd(self):
        """Alias for DoCmd"""
        return self.DoCmd

    @property
    def FeatureInstall(self):
        return self.com_object.FeatureInstall

    @FeatureInstall.setter
    def FeatureInstall(self, value):
        self.com_object.FeatureInstall = value

    @property
    def featureinstall(self):
        """Alias for FeatureInstall"""
        return self.FeatureInstall

    @featureinstall.setter
    def featureinstall(self, value):
        """Alias for FeatureInstall.setter"""
        self.FeatureInstall = value

    @property
    def feature_install(self):
        """Alias for FeatureInstall"""
        return self.FeatureInstall

    @feature_install.setter
    def feature_install(self, value):
        """Alias for FeatureInstall.setter"""
        self.FeatureInstall = value

    def FileDialog(self, dialogType=None):
        arguments = com_arguments([unwrap(a) for a in [dialogType]])
        if hasattr(self.com_object, "GetFileDialog"):
            return self.com_object.GetFileDialog(*arguments)
        else:
            return self.com_object.FileDialog(*arguments)

    def filedialog(self, dialogType=None):
        """Alias for FileDialog"""
        arguments = [dialogType]
        return self.FileDialog(*arguments)

    def file_dialog(self, dialogType=None):
        """Alias for FileDialog"""
        arguments = [dialogType]
        return self.FileDialog(*arguments)

    @property
    def Forms(self):
        return self.com_object.Forms

    @property
    def forms(self):
        """Alias for Forms"""
        return self.Forms

    @property
    def IsCompiled(self):
        return self.com_object.IsCompiled

    @property
    def iscompiled(self):
        """Alias for IsCompiled"""
        return self.IsCompiled

    @property
    def is_compiled(self):
        """Alias for IsCompiled"""
        return self.IsCompiled

    @property
    def LanguageSettings(self):
        return self.com_object.LanguageSettings

    @property
    def languagesettings(self):
        """Alias for LanguageSettings"""
        return self.LanguageSettings

    @property
    def language_settings(self):
        """Alias for LanguageSettings"""
        return self.LanguageSettings

    @property
    def MacroError(self):
        return MacroError(self.com_object.MacroError)

    @property
    def macroerror(self):
        """Alias for MacroError"""
        return self.MacroError

    @property
    def macro_error(self):
        """Alias for MacroError"""
        return self.MacroError

    @property
    def MenuBar(self):
        return self.com_object.MenuBar

    @MenuBar.setter
    def MenuBar(self, value):
        self.com_object.MenuBar = value

    @property
    def menubar(self):
        """Alias for MenuBar"""
        return self.MenuBar

    @menubar.setter
    def menubar(self, value):
        """Alias for MenuBar.setter"""
        self.MenuBar = value

    @property
    def menu_bar(self):
        """Alias for MenuBar"""
        return self.MenuBar

    @menu_bar.setter
    def menu_bar(self, value):
        """Alias for MenuBar.setter"""
        self.MenuBar = value

    @property
    def Modules(self):
        return self.com_object.Modules

    @property
    def modules(self):
        """Alias for Modules"""
        return self.Modules

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def NewFileTaskPane(self):
        return self.com_object.NewFileTaskPane

    @property
    def newfiletaskpane(self):
        """Alias for NewFileTaskPane"""
        return self.NewFileTaskPane

    @property
    def new_file_task_pane(self):
        """Alias for NewFileTaskPane"""
        return self.NewFileTaskPane

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Printer(self):
        return Printer(self.com_object.Printer)

    @Printer.setter
    def Printer(self, value):
        self.com_object.Printer = value

    @property
    def printer(self):
        """Alias for Printer"""
        return self.Printer

    @printer.setter
    def printer(self, value):
        """Alias for Printer.setter"""
        self.Printer = value

    @property
    def Printers(self):
        return Printers(self.com_object.Printers)

    @property
    def printers(self):
        """Alias for Printers"""
        return self.Printers

    @property
    def ProductCode(self):
        return self.com_object.ProductCode

    @property
    def productcode(self):
        """Alias for ProductCode"""
        return self.ProductCode

    @property
    def product_code(self):
        """Alias for ProductCode"""
        return self.ProductCode

    @property
    def References(self):
        return self.com_object.References

    @property
    def references(self):
        """Alias for References"""
        return self.References

    @property
    def Reports(self):
        return self.com_object.Reports

    @property
    def reports(self):
        """Alias for Reports"""
        return self.Reports

    @property
    def ReturnVars(self):
        return ReturnVars(self.com_object.ReturnVars)

    @property
    def returnvars(self):
        """Alias for ReturnVars"""
        return self.ReturnVars

    @property
    def return_vars(self):
        """Alias for ReturnVars"""
        return self.ReturnVars

    @property
    def Screen(self):
        return self.com_object.Screen

    @property
    def screen(self):
        """Alias for Screen"""
        return self.Screen

    @property
    def ShortcutMenuBar(self):
        return self.com_object.ShortcutMenuBar

    @ShortcutMenuBar.setter
    def ShortcutMenuBar(self, value):
        self.com_object.ShortcutMenuBar = value

    @property
    def shortcutmenubar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcutmenubar.setter
    def shortcutmenubar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def shortcut_menu_bar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcut_menu_bar.setter
    def shortcut_menu_bar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def TempVars(self):
        return TempVar(self.com_object.TempVars)

    @property
    def tempvars(self):
        """Alias for TempVars"""
        return self.TempVars

    @property
    def temp_vars(self):
        """Alias for TempVars"""
        return self.TempVars

    @property
    def UserControl(self):
        return self.com_object.UserControl

    @UserControl.setter
    def UserControl(self, value):
        self.com_object.UserControl = value

    @property
    def usercontrol(self):
        """Alias for UserControl"""
        return self.UserControl

    @usercontrol.setter
    def usercontrol(self, value):
        """Alias for UserControl.setter"""
        self.UserControl = value

    @property
    def user_control(self):
        """Alias for UserControl"""
        return self.UserControl

    @user_control.setter
    def user_control(self, value):
        """Alias for UserControl.setter"""
        self.UserControl = value

    @property
    def VBE(self):
        return self.com_object.VBE

    @property
    def vbe(self):
        """Alias for VBE"""
        return self.VBE

    @property
    def v_b_e(self):
        """Alias for VBE"""
        return self.VBE

    @property
    def Version(self):
        return self.com_object.Version

    @property
    def version(self):
        """Alias for Version"""
        return self.Version

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def WebServices(self):
        return self.com_object.WebServices

    @property
    def webservices(self):
        """Alias for WebServices"""
        return self.WebServices

    @property
    def web_services(self):
        """Alias for WebServices"""
        return self.WebServices

    def AccessError(self, ErrorNumber=None):
        arguments = com_arguments([unwrap(a) for a in [ErrorNumber]])
        return self.com_object.AccessError(*arguments)

    def accesserror(self, ErrorNumber=None):
        """Alias for AccessError"""
        arguments = [ErrorNumber]
        return self.AccessError(*arguments)

    def access_error(self, ErrorNumber=None):
        """Alias for AccessError"""
        arguments = [ErrorNumber]
        return self.AccessError(*arguments)

    def AddToFavorites(self):
        self.com_object.AddToFavorites()

    def addtofavorites(self):
        """Alias for AddToFavorites"""
        return self.AddToFavorites()

    def add_to_favorites(self):
        """Alias for AddToFavorites"""
        return self.AddToFavorites()

    def BuildCriteria(self, Field=None, FieldType=None, Expression=None):
        arguments = com_arguments([unwrap(a) for a in [Field, FieldType, Expression]])
        return self.com_object.BuildCriteria(*arguments)

    def buildcriteria(self, Field=None, FieldType=None, Expression=None):
        """Alias for BuildCriteria"""
        arguments = [Field, FieldType, Expression]
        return self.BuildCriteria(*arguments)

    def build_criteria(self, Field=None, FieldType=None, Expression=None):
        """Alias for BuildCriteria"""
        arguments = [Field, FieldType, Expression]
        return self.BuildCriteria(*arguments)

    def CloseCurrentDatabase(self):
        return self.com_object.CloseCurrentDatabase()

    def closecurrentdatabase(self):
        """Alias for CloseCurrentDatabase"""
        return self.CloseCurrentDatabase()

    def close_current_database(self):
        """Alias for CloseCurrentDatabase"""
        return self.CloseCurrentDatabase()

    def CodeDb(self):
        return self.com_object.CodeDb()

    def codedb(self):
        """Alias for CodeDb"""
        return self.CodeDb()

    def code_db(self):
        """Alias for CodeDb"""
        return self.CodeDb()

    def ColumnHistory(self, TableName=None, ColumnName=None, queryString=None):
        arguments = com_arguments([unwrap(a) for a in [TableName, ColumnName, queryString]])
        return self.com_object.ColumnHistory(*arguments)

    def columnhistory(self, TableName=None, ColumnName=None, queryString=None):
        """Alias for ColumnHistory"""
        arguments = [TableName, ColumnName, queryString]
        return self.ColumnHistory(*arguments)

    def column_history(self, TableName=None, ColumnName=None, queryString=None):
        """Alias for ColumnHistory"""
        arguments = [TableName, ColumnName, queryString]
        return self.ColumnHistory(*arguments)

    def ConvertAccessProject(self, SourceFilename=None, DestinationFilename=None, DestinationFileFormat=None):
        arguments = com_arguments([unwrap(a) for a in [SourceFilename, DestinationFilename, DestinationFileFormat]])
        return self.com_object.ConvertAccessProject(*arguments)

    def convertaccessproject(self, SourceFilename=None, DestinationFilename=None, DestinationFileFormat=None):
        """Alias for ConvertAccessProject"""
        arguments = [SourceFilename, DestinationFilename, DestinationFileFormat]
        return self.ConvertAccessProject(*arguments)

    def convert_access_project(self, SourceFilename=None, DestinationFilename=None, DestinationFileFormat=None):
        """Alias for ConvertAccessProject"""
        arguments = [SourceFilename, DestinationFilename, DestinationFileFormat]
        return self.ConvertAccessProject(*arguments)

    def CreateAccessProject(self, filepath=None, Connect=None):
        arguments = com_arguments([unwrap(a) for a in [filepath, Connect]])
        return self.com_object.CreateAccessProject(*arguments)

    def createaccessproject(self, filepath=None, Connect=None):
        """Alias for CreateAccessProject"""
        arguments = [filepath, Connect]
        return self.CreateAccessProject(*arguments)

    def create_access_project(self, filepath=None, Connect=None):
        """Alias for CreateAccessProject"""
        arguments = [filepath, Connect]
        return self.CreateAccessProject(*arguments)

    def CreateAdditionalData(self):
        return AdditionalData(self.com_object.CreateAdditionalData())

    def createadditionaldata(self):
        """Alias for CreateAdditionalData"""
        return self.CreateAdditionalData()

    def create_additional_data(self):
        """Alias for CreateAdditionalData"""
        return self.CreateAdditionalData()

    def CreateControl(self, FormName=None, ControlType=None, Section=None, Parent=None, ColumnName=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [FormName, ControlType, Section, Parent, ColumnName, Left, Top, Width, Height]])
        return Control(self.com_object.CreateControl(*arguments))

    def createcontrol(self, FormName=None, ControlType=None, Section=None, Parent=None, ColumnName=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for CreateControl"""
        arguments = [FormName, ControlType, Section, Parent, ColumnName, Left, Top, Width, Height]
        return self.CreateControl(*arguments)

    def create_control(self, FormName=None, ControlType=None, Section=None, Parent=None, ColumnName=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for CreateControl"""
        arguments = [FormName, ControlType, Section, Parent, ColumnName, Left, Top, Width, Height]
        return self.CreateControl(*arguments)

    def CreateForm(self, Database=None, FormTemplate=None):
        arguments = com_arguments([unwrap(a) for a in [Database, FormTemplate]])
        return Form(self.com_object.CreateForm(*arguments))

    def createform(self, Database=None, FormTemplate=None):
        """Alias for CreateForm"""
        arguments = [Database, FormTemplate]
        return self.CreateForm(*arguments)

    def create_form(self, Database=None, FormTemplate=None):
        """Alias for CreateForm"""
        arguments = [Database, FormTemplate]
        return self.CreateForm(*arguments)

    def CreateGroupLevel(self, ReportName=None, Expression=None, Header=None, Footer=None):
        arguments = com_arguments([unwrap(a) for a in [ReportName, Expression, Header, Footer]])
        return self.com_object.CreateGroupLevel(*arguments)

    def creategrouplevel(self, ReportName=None, Expression=None, Header=None, Footer=None):
        """Alias for CreateGroupLevel"""
        arguments = [ReportName, Expression, Header, Footer]
        return self.CreateGroupLevel(*arguments)

    def create_group_level(self, ReportName=None, Expression=None, Header=None, Footer=None):
        """Alias for CreateGroupLevel"""
        arguments = [ReportName, Expression, Header, Footer]
        return self.CreateGroupLevel(*arguments)

    def CreateReport(self, Database=None, ReportTemplate=None):
        arguments = com_arguments([unwrap(a) for a in [Database, ReportTemplate]])
        return Report(self.com_object.CreateReport(*arguments))

    def createreport(self, Database=None, ReportTemplate=None):
        """Alias for CreateReport"""
        arguments = [Database, ReportTemplate]
        return self.CreateReport(*arguments)

    def create_report(self, Database=None, ReportTemplate=None):
        """Alias for CreateReport"""
        arguments = [Database, ReportTemplate]
        return self.CreateReport(*arguments)

    def CreateReportControl(self, ReportName=None, ControlType=None, Section=None, Parent=None, ColumnName=None, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [ReportName, ControlType, Section, Parent, ColumnName, Left, Top, Width, Height]])
        return Control(self.com_object.CreateReportControl(*arguments))

    def createreportcontrol(self, ReportName=None, ControlType=None, Section=None, Parent=None, ColumnName=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for CreateReportControl"""
        arguments = [ReportName, ControlType, Section, Parent, ColumnName, Left, Top, Width, Height]
        return self.CreateReportControl(*arguments)

    def create_report_control(self, ReportName=None, ControlType=None, Section=None, Parent=None, ColumnName=None, Left=None, Top=None, Width=None, Height=None):
        """Alias for CreateReportControl"""
        arguments = [ReportName, ControlType, Section, Parent, ColumnName, Left, Top, Width, Height]
        return self.CreateReportControl(*arguments)

    def CurrentDb(self):
        return self.com_object.CurrentDb()

    def currentdb(self):
        """Alias for CurrentDb"""
        return self.CurrentDb()

    def current_db(self):
        """Alias for CurrentDb"""
        return self.CurrentDb()

    def CurrentUser(self):
        return self.com_object.CurrentUser()

    def currentuser(self):
        """Alias for CurrentUser"""
        return self.CurrentUser()

    def current_user(self):
        """Alias for CurrentUser"""
        return self.CurrentUser()

    def CurrentWebUser(self, DisplayOption=None):
        arguments = com_arguments([unwrap(a) for a in [DisplayOption]])
        return self.com_object.CurrentWebUser(*arguments)

    def currentwebuser(self, DisplayOption=None):
        """Alias for CurrentWebUser"""
        arguments = [DisplayOption]
        return self.CurrentWebUser(*arguments)

    def current_web_user(self, DisplayOption=None):
        """Alias for CurrentWebUser"""
        arguments = [DisplayOption]
        return self.CurrentWebUser(*arguments)

    def CurrentWebUserGroups(self, DisplayOption=None):
        arguments = com_arguments([unwrap(a) for a in [DisplayOption]])
        return self.com_object.CurrentWebUserGroups(*arguments)

    def currentwebusergroups(self, DisplayOption=None):
        """Alias for CurrentWebUserGroups"""
        arguments = [DisplayOption]
        return self.CurrentWebUserGroups(*arguments)

    def current_web_user_groups(self, DisplayOption=None):
        """Alias for CurrentWebUserGroups"""
        arguments = [DisplayOption]
        return self.CurrentWebUserGroups(*arguments)

    def DAvg(self, Expr=None, Domain=None, Criteria=None):
        arguments = com_arguments([unwrap(a) for a in [Expr, Domain, Criteria]])
        return self.com_object.DAvg(*arguments)

    def davg(self, Expr=None, Domain=None, Criteria=None):
        """Alias for DAvg"""
        arguments = [Expr, Domain, Criteria]
        return self.DAvg(*arguments)

    def d_avg(self, Expr=None, Domain=None, Criteria=None):
        """Alias for DAvg"""
        arguments = [Expr, Domain, Criteria]
        return self.DAvg(*arguments)

    def DCount(self, Expr=None, Domain=None, Criteria=None):
        arguments = com_arguments([unwrap(a) for a in [Expr, Domain, Criteria]])
        return self.com_object.DCount(*arguments)

    def dcount(self, Expr=None, Domain=None, Criteria=None):
        """Alias for DCount"""
        arguments = [Expr, Domain, Criteria]
        return self.DCount(*arguments)

    def d_count(self, Expr=None, Domain=None, Criteria=None):
        """Alias for DCount"""
        arguments = [Expr, Domain, Criteria]
        return self.DCount(*arguments)

    def DDEExecute(self, ChanNum=None, Command=None):
        arguments = com_arguments([unwrap(a) for a in [ChanNum, Command]])
        self.com_object.DDEExecute(*arguments)

    def ddeexecute(self, ChanNum=None, Command=None):
        """Alias for DDEExecute"""
        arguments = [ChanNum, Command]
        return self.DDEExecute(*arguments)

    def d_d_e_execute(self, ChanNum=None, Command=None):
        """Alias for DDEExecute"""
        arguments = [ChanNum, Command]
        return self.DDEExecute(*arguments)

    def DDEInitiate(self, Application=None, Topic=None):
        arguments = com_arguments([unwrap(a) for a in [Application, Topic]])
        return self.com_object.DDEInitiate(*arguments)

    def ddeinitiate(self, Application=None, Topic=None):
        """Alias for DDEInitiate"""
        arguments = [Application, Topic]
        return self.DDEInitiate(*arguments)

    def d_d_e_initiate(self, Application=None, Topic=None):
        """Alias for DDEInitiate"""
        arguments = [Application, Topic]
        return self.DDEInitiate(*arguments)

    def DDEPoke(self, ChanNum=None, Item=None, Data=None):
        arguments = com_arguments([unwrap(a) for a in [ChanNum, Item, Data]])
        self.com_object.DDEPoke(*arguments)

    def ddepoke(self, ChanNum=None, Item=None, Data=None):
        """Alias for DDEPoke"""
        arguments = [ChanNum, Item, Data]
        return self.DDEPoke(*arguments)

    def d_d_e_poke(self, ChanNum=None, Item=None, Data=None):
        """Alias for DDEPoke"""
        arguments = [ChanNum, Item, Data]
        return self.DDEPoke(*arguments)

    def DDERequest(self, ChanNum=None, Item=None):
        arguments = com_arguments([unwrap(a) for a in [ChanNum, Item]])
        return self.com_object.DDERequest(*arguments)

    def dderequest(self, ChanNum=None, Item=None):
        """Alias for DDERequest"""
        arguments = [ChanNum, Item]
        return self.DDERequest(*arguments)

    def d_d_e_request(self, ChanNum=None, Item=None):
        """Alias for DDERequest"""
        arguments = [ChanNum, Item]
        return self.DDERequest(*arguments)

    def DDETerminate(self, ChanNum=None):
        arguments = com_arguments([unwrap(a) for a in [ChanNum]])
        return self.com_object.DDETerminate(*arguments)

    def ddeterminate(self, ChanNum=None):
        """Alias for DDETerminate"""
        arguments = [ChanNum]
        return self.DDETerminate(*arguments)

    def d_d_e_terminate(self, ChanNum=None):
        """Alias for DDETerminate"""
        arguments = [ChanNum]
        return self.DDETerminate(*arguments)

    def DDETerminateAll(self):
        return self.com_object.DDETerminateAll()

    def ddeterminateall(self):
        """Alias for DDETerminateAll"""
        return self.DDETerminateAll()

    def d_d_e_terminate_all(self):
        """Alias for DDETerminateAll"""
        return self.DDETerminateAll()

    def DefaultWorkspaceClone(self):
        return self.com_object.DefaultWorkspaceClone()

    def defaultworkspaceclone(self):
        """Alias for DefaultWorkspaceClone"""
        return self.DefaultWorkspaceClone()

    def default_workspace_clone(self):
        """Alias for DefaultWorkspaceClone"""
        return self.DefaultWorkspaceClone()

    def DeleteControl(self, FormName=None, ControlName=None):
        arguments = com_arguments([unwrap(a) for a in [FormName, ControlName]])
        return self.com_object.DeleteControl(*arguments)

    def deletecontrol(self, FormName=None, ControlName=None):
        """Alias for DeleteControl"""
        arguments = [FormName, ControlName]
        return self.DeleteControl(*arguments)

    def delete_control(self, FormName=None, ControlName=None):
        """Alias for DeleteControl"""
        arguments = [FormName, ControlName]
        return self.DeleteControl(*arguments)

    def DeleteReportControl(self, ReportName=None, ControlName=None):
        arguments = com_arguments([unwrap(a) for a in [ReportName, ControlName]])
        return self.com_object.DeleteReportControl(*arguments)

    def deletereportcontrol(self, ReportName=None, ControlName=None):
        """Alias for DeleteReportControl"""
        arguments = [ReportName, ControlName]
        return self.DeleteReportControl(*arguments)

    def delete_report_control(self, ReportName=None, ControlName=None):
        """Alias for DeleteReportControl"""
        arguments = [ReportName, ControlName]
        return self.DeleteReportControl(*arguments)

    def DFirst(self, Expr=None, Domain=None, Criteria=None):
        arguments = com_arguments([unwrap(a) for a in [Expr, Domain, Criteria]])
        return self.com_object.DFirst(*arguments)

    def dfirst(self, Expr=None, Domain=None, Criteria=None):
        """Alias for DFirst"""
        arguments = [Expr, Domain, Criteria]
        return self.DFirst(*arguments)

    def d_first(self, Expr=None, Domain=None, Criteria=None):
        """Alias for DFirst"""
        arguments = [Expr, Domain, Criteria]
        return self.DFirst(*arguments)

    def DirtyObject(self, ObjectType=None, ObjectName=None):
        arguments = com_arguments([unwrap(a) for a in [ObjectType, ObjectName]])
        self.com_object.DirtyObject(*arguments)

    def dirtyobject(self, ObjectType=None, ObjectName=None):
        """Alias for DirtyObject"""
        arguments = [ObjectType, ObjectName]
        return self.DirtyObject(*arguments)

    def dirty_object(self, ObjectType=None, ObjectName=None):
        """Alias for DirtyObject"""
        arguments = [ObjectType, ObjectName]
        return self.DirtyObject(*arguments)

    def DLast(self, Expr=None, Domain=None, Criteria=None):
        arguments = com_arguments([unwrap(a) for a in [Expr, Domain, Criteria]])
        return self.com_object.DLast(*arguments)

    def dlast(self, Expr=None, Domain=None, Criteria=None):
        """Alias for DLast"""
        arguments = [Expr, Domain, Criteria]
        return self.DLast(*arguments)

    def d_last(self, Expr=None, Domain=None, Criteria=None):
        """Alias for DLast"""
        arguments = [Expr, Domain, Criteria]
        return self.DLast(*arguments)

    def DLookup(self, Expr=None, Domain=None, Criteria=None):
        arguments = com_arguments([unwrap(a) for a in [Expr, Domain, Criteria]])
        return self.com_object.DLookup(*arguments)

    def dlookup(self, Expr=None, Domain=None, Criteria=None):
        """Alias for DLookup"""
        arguments = [Expr, Domain, Criteria]
        return self.DLookup(*arguments)

    def d_lookup(self, Expr=None, Domain=None, Criteria=None):
        """Alias for DLookup"""
        arguments = [Expr, Domain, Criteria]
        return self.DLookup(*arguments)

    def DMax(self, Expr=None, Domain=None, Criteria=None):
        arguments = com_arguments([unwrap(a) for a in [Expr, Domain, Criteria]])
        return self.com_object.DMax(*arguments)

    def dmax(self, Expr=None, Domain=None, Criteria=None):
        """Alias for DMax"""
        arguments = [Expr, Domain, Criteria]
        return self.DMax(*arguments)

    def d_max(self, Expr=None, Domain=None, Criteria=None):
        """Alias for DMax"""
        arguments = [Expr, Domain, Criteria]
        return self.DMax(*arguments)

    def DMin(self, Expr=None, Domain=None, Criteria=None):
        arguments = com_arguments([unwrap(a) for a in [Expr, Domain, Criteria]])
        return self.com_object.DMin(*arguments)

    def dmin(self, Expr=None, Domain=None, Criteria=None):
        """Alias for DMin"""
        arguments = [Expr, Domain, Criteria]
        return self.DMin(*arguments)

    def d_min(self, Expr=None, Domain=None, Criteria=None):
        """Alias for DMin"""
        arguments = [Expr, Domain, Criteria]
        return self.DMin(*arguments)

    def DStDev(self, Expr=None, Domain=None, Criteria=None):
        arguments = com_arguments([unwrap(a) for a in [Expr, Domain, Criteria]])
        return self.com_object.DStDev(*arguments)

    def dstdev(self, Expr=None, Domain=None, Criteria=None):
        """Alias for DStDev"""
        arguments = [Expr, Domain, Criteria]
        return self.DStDev(*arguments)

    def d_st_dev(self, Expr=None, Domain=None, Criteria=None):
        """Alias for DStDev"""
        arguments = [Expr, Domain, Criteria]
        return self.DStDev(*arguments)

    def DStDevP(self, Expr=None, Domain=None, Criteria=None):
        arguments = com_arguments([unwrap(a) for a in [Expr, Domain, Criteria]])
        return self.com_object.DStDevP(*arguments)

    def dstdevp(self, Expr=None, Domain=None, Criteria=None):
        """Alias for DStDevP"""
        arguments = [Expr, Domain, Criteria]
        return self.DStDevP(*arguments)

    def d_st_dev_p(self, Expr=None, Domain=None, Criteria=None):
        """Alias for DStDevP"""
        arguments = [Expr, Domain, Criteria]
        return self.DStDevP(*arguments)

    def DSum(self, Expr=None, Domain=None, Criteria=None):
        arguments = com_arguments([unwrap(a) for a in [Expr, Domain, Criteria]])
        return self.com_object.DSum(*arguments)

    def dsum(self, Expr=None, Domain=None, Criteria=None):
        """Alias for DSum"""
        arguments = [Expr, Domain, Criteria]
        return self.DSum(*arguments)

    def d_sum(self, Expr=None, Domain=None, Criteria=None):
        """Alias for DSum"""
        arguments = [Expr, Domain, Criteria]
        return self.DSum(*arguments)

    def DVar(self, Expr=None, Domain=None, Criteria=None):
        arguments = com_arguments([unwrap(a) for a in [Expr, Domain, Criteria]])
        return self.com_object.DVar(*arguments)

    def dvar(self, Expr=None, Domain=None, Criteria=None):
        """Alias for DVar"""
        arguments = [Expr, Domain, Criteria]
        return self.DVar(*arguments)

    def d_var(self, Expr=None, Domain=None, Criteria=None):
        """Alias for DVar"""
        arguments = [Expr, Domain, Criteria]
        return self.DVar(*arguments)

    def DVarP(self, Expr=None, Domain=None, Criteria=None):
        arguments = com_arguments([unwrap(a) for a in [Expr, Domain, Criteria]])
        return self.com_object.DVarP(*arguments)

    def dvarp(self, Expr=None, Domain=None, Criteria=None):
        """Alias for DVarP"""
        arguments = [Expr, Domain, Criteria]
        return self.DVarP(*arguments)

    def d_var_p(self, Expr=None, Domain=None, Criteria=None):
        """Alias for DVarP"""
        arguments = [Expr, Domain, Criteria]
        return self.DVarP(*arguments)

    def Echo(self, EchoOn=None, bstrStatusBarText=None):
        arguments = com_arguments([unwrap(a) for a in [EchoOn, bstrStatusBarText]])
        self.com_object.Echo(*arguments)

    def echo(self, EchoOn=None, bstrStatusBarText=None):
        """Alias for Echo"""
        arguments = [EchoOn, bstrStatusBarText]
        return self.Echo(*arguments)

    def EuroConvert(self, Number=None, SourceCurrency=None, TargetCurrency=None, FullPrecision=None, TriangulationPrecision=None):
        arguments = com_arguments([unwrap(a) for a in [Number, SourceCurrency, TargetCurrency, FullPrecision, TriangulationPrecision]])
        return self.com_object.EuroConvert(*arguments)

    def euroconvert(self, Number=None, SourceCurrency=None, TargetCurrency=None, FullPrecision=None, TriangulationPrecision=None):
        """Alias for EuroConvert"""
        arguments = [Number, SourceCurrency, TargetCurrency, FullPrecision, TriangulationPrecision]
        return self.EuroConvert(*arguments)

    def euro_convert(self, Number=None, SourceCurrency=None, TargetCurrency=None, FullPrecision=None, TriangulationPrecision=None):
        """Alias for EuroConvert"""
        arguments = [Number, SourceCurrency, TargetCurrency, FullPrecision, TriangulationPrecision]
        return self.EuroConvert(*arguments)

    def Eval(self, StringExpr=None):
        arguments = com_arguments([unwrap(a) for a in [StringExpr]])
        return self.com_object.Eval(*arguments)

    def eval(self, StringExpr=None):
        """Alias for Eval"""
        arguments = [StringExpr]
        return self.Eval(*arguments)

    def ExportNavigationPane(self, Path=None):
        arguments = com_arguments([unwrap(a) for a in [Path]])
        self.com_object.ExportNavigationPane(*arguments)

    def exportnavigationpane(self, Path=None):
        """Alias for ExportNavigationPane"""
        arguments = [Path]
        return self.ExportNavigationPane(*arguments)

    def export_navigation_pane(self, Path=None):
        """Alias for ExportNavigationPane"""
        arguments = [Path]
        return self.ExportNavigationPane(*arguments)

    def ExportXML(self, ObjectType=None, DataSource=None, DataTarget=None, SchemaTarget=None, PresentationTarget=None, ImageTarget=None, Encoding=None, OtherFlags=None, WhereCondition=None, AdditionalData=None):
        arguments = com_arguments([unwrap(a) for a in [ObjectType, DataSource, DataTarget, SchemaTarget, PresentationTarget, ImageTarget, Encoding, OtherFlags, WhereCondition, AdditionalData]])
        return self.com_object.ExportXML(*arguments)

    def exportxml(self, ObjectType=None, DataSource=None, DataTarget=None, SchemaTarget=None, PresentationTarget=None, ImageTarget=None, Encoding=None, OtherFlags=None, WhereCondition=None, AdditionalData=None):
        """Alias for ExportXML"""
        arguments = [ObjectType, DataSource, DataTarget, SchemaTarget, PresentationTarget, ImageTarget, Encoding, OtherFlags, WhereCondition, AdditionalData]
        return self.ExportXML(*arguments)

    def export_x_m_l(self, ObjectType=None, DataSource=None, DataTarget=None, SchemaTarget=None, PresentationTarget=None, ImageTarget=None, Encoding=None, OtherFlags=None, WhereCondition=None, AdditionalData=None):
        """Alias for ExportXML"""
        arguments = [ObjectType, DataSource, DataTarget, SchemaTarget, PresentationTarget, ImageTarget, Encoding, OtherFlags, WhereCondition, AdditionalData]
        return self.ExportXML(*arguments)

    def FollowHyperlink(self, Address=None, SubAddress=None, NewWindow=None, AddHistory=None, ExtraInfo=None, Method=None, HeaderInfo=None):
        arguments = com_arguments([unwrap(a) for a in [Address, SubAddress, NewWindow, AddHistory, ExtraInfo, Method, HeaderInfo]])
        self.com_object.FollowHyperlink(*arguments)

    def followhyperlink(self, Address=None, SubAddress=None, NewWindow=None, AddHistory=None, ExtraInfo=None, Method=None, HeaderInfo=None):
        """Alias for FollowHyperlink"""
        arguments = [Address, SubAddress, NewWindow, AddHistory, ExtraInfo, Method, HeaderInfo]
        return self.FollowHyperlink(*arguments)

    def follow_hyperlink(self, Address=None, SubAddress=None, NewWindow=None, AddHistory=None, ExtraInfo=None, Method=None, HeaderInfo=None):
        """Alias for FollowHyperlink"""
        arguments = [Address, SubAddress, NewWindow, AddHistory, ExtraInfo, Method, HeaderInfo]
        return self.FollowHyperlink(*arguments)

    def GetHiddenAttribute(self, ObjectType=None, ObjectName=None):
        arguments = com_arguments([unwrap(a) for a in [ObjectType, ObjectName]])
        return self.com_object.GetHiddenAttribute(*arguments)

    def gethiddenattribute(self, ObjectType=None, ObjectName=None):
        """Alias for GetHiddenAttribute"""
        arguments = [ObjectType, ObjectName]
        return self.GetHiddenAttribute(*arguments)

    def get_hidden_attribute(self, ObjectType=None, ObjectName=None):
        """Alias for GetHiddenAttribute"""
        arguments = [ObjectType, ObjectName]
        return self.GetHiddenAttribute(*arguments)

    def GetOption(self, OptionName=None):
        arguments = com_arguments([unwrap(a) for a in [OptionName]])
        return self.com_object.GetOption(*arguments)

    def getoption(self, OptionName=None):
        """Alias for GetOption"""
        arguments = [OptionName]
        return self.GetOption(*arguments)

    def get_option(self, OptionName=None):
        """Alias for GetOption"""
        arguments = [OptionName]
        return self.GetOption(*arguments)

    def GUIDFromString(self, String=None):
        arguments = com_arguments([unwrap(a) for a in [String]])
        return self.com_object.GUIDFromString(*arguments)

    def guidfromstring(self, String=None):
        """Alias for GUIDFromString"""
        arguments = [String]
        return self.GUIDFromString(*arguments)

    def g_u_i_d_from_string(self, String=None):
        """Alias for GUIDFromString"""
        arguments = [String]
        return self.GUIDFromString(*arguments)

    def HtmlEncode(self, PlainText=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [PlainText, Length]])
        return self.com_object.HtmlEncode(*arguments)

    def htmlencode(self, PlainText=None, Length=None):
        """Alias for HtmlEncode"""
        arguments = [PlainText, Length]
        return self.HtmlEncode(*arguments)

    def html_encode(self, PlainText=None, Length=None):
        """Alias for HtmlEncode"""
        arguments = [PlainText, Length]
        return self.HtmlEncode(*arguments)

    def hWndAccessApp(self):
        return self.com_object.hWndAccessApp()

    def hwndaccessapp(self):
        """Alias for hWndAccessApp"""
        return self.hWndAccessApp()

    def h_wnd_access_app(self):
        """Alias for hWndAccessApp"""
        return self.hWndAccessApp()

    def HyperlinkPart(self, Hyperlink=None, Part=None):
        arguments = com_arguments([unwrap(a) for a in [Hyperlink, Part]])
        return self.com_object.HyperlinkPart(*arguments)

    def hyperlinkpart(self, Hyperlink=None, Part=None):
        """Alias for HyperlinkPart"""
        arguments = [Hyperlink, Part]
        return self.HyperlinkPart(*arguments)

    def hyperlink_part(self, Hyperlink=None, Part=None):
        """Alias for HyperlinkPart"""
        arguments = [Hyperlink, Part]
        return self.HyperlinkPart(*arguments)

    def ImportNavigationPane(self, Path=None, fAppendOnly=None):
        arguments = com_arguments([unwrap(a) for a in [Path, fAppendOnly]])
        self.com_object.ImportNavigationPane(*arguments)

    def importnavigationpane(self, Path=None, fAppendOnly=None):
        """Alias for ImportNavigationPane"""
        arguments = [Path, fAppendOnly]
        return self.ImportNavigationPane(*arguments)

    def import_navigation_pane(self, Path=None, fAppendOnly=None):
        """Alias for ImportNavigationPane"""
        arguments = [Path, fAppendOnly]
        return self.ImportNavigationPane(*arguments)

    def ImportXML(self, DataSource=None, ImportOptions=None):
        arguments = com_arguments([unwrap(a) for a in [DataSource, ImportOptions]])
        return self.com_object.ImportXML(*arguments)

    def importxml(self, DataSource=None, ImportOptions=None):
        """Alias for ImportXML"""
        arguments = [DataSource, ImportOptions]
        return self.ImportXML(*arguments)

    def import_x_m_l(self, DataSource=None, ImportOptions=None):
        """Alias for ImportXML"""
        arguments = [DataSource, ImportOptions]
        return self.ImportXML(*arguments)

    def InstantiateTemplate(self, Path=None):
        arguments = com_arguments([unwrap(a) for a in [Path]])
        self.com_object.InstantiateTemplate(*arguments)

    def instantiatetemplate(self, Path=None):
        """Alias for InstantiateTemplate"""
        arguments = [Path]
        return self.InstantiateTemplate(*arguments)

    def instantiate_template(self, Path=None):
        """Alias for InstantiateTemplate"""
        arguments = [Path]
        return self.InstantiateTemplate(*arguments)

    def IsCurrentWebUserInGroup(self, GroupNameOrID=None):
        arguments = com_arguments([unwrap(a) for a in [GroupNameOrID]])
        return self.com_object.IsCurrentWebUserInGroup(*arguments)

    def iscurrentwebuseringroup(self, GroupNameOrID=None):
        """Alias for IsCurrentWebUserInGroup"""
        arguments = [GroupNameOrID]
        return self.IsCurrentWebUserInGroup(*arguments)

    def is_current_web_user_in_group(self, GroupNameOrID=None):
        """Alias for IsCurrentWebUserInGroup"""
        arguments = [GroupNameOrID]
        return self.IsCurrentWebUserInGroup(*arguments)

    def LoadCustomUI(self, CustomUIName=None, CustomUIXML=None):
        arguments = com_arguments([unwrap(a) for a in [CustomUIName, CustomUIXML]])
        self.com_object.LoadCustomUI(*arguments)

    def loadcustomui(self, CustomUIName=None, CustomUIXML=None):
        """Alias for LoadCustomUI"""
        arguments = [CustomUIName, CustomUIXML]
        return self.LoadCustomUI(*arguments)

    def load_custom_u_i(self, CustomUIName=None, CustomUIXML=None):
        """Alias for LoadCustomUI"""
        arguments = [CustomUIName, CustomUIXML]
        return self.LoadCustomUI(*arguments)

    def LoadFromAXL(self, ObjectType=None, ObjectName=None, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [ObjectType, ObjectName, FileName]])
        self.com_object.LoadFromAXL(*arguments)

    def loadfromaxl(self, ObjectType=None, ObjectName=None, FileName=None):
        """Alias for LoadFromAXL"""
        arguments = [ObjectType, ObjectName, FileName]
        return self.LoadFromAXL(*arguments)

    def load_from_a_x_l(self, ObjectType=None, ObjectName=None, FileName=None):
        """Alias for LoadFromAXL"""
        arguments = [ObjectType, ObjectName, FileName]
        return self.LoadFromAXL(*arguments)

    def LoadPicture(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        return self.com_object.LoadPicture(*arguments)

    def loadpicture(self, FileName=None):
        """Alias for LoadPicture"""
        arguments = [FileName]
        return self.LoadPicture(*arguments)

    def load_picture(self, FileName=None):
        """Alias for LoadPicture"""
        arguments = [FileName]
        return self.LoadPicture(*arguments)

    def NewAccessProject(self, filepath=None, Connect=None):
        arguments = com_arguments([unwrap(a) for a in [filepath, Connect]])
        return self.com_object.NewAccessProject(*arguments)

    def newaccessproject(self, filepath=None, Connect=None):
        """Alias for NewAccessProject"""
        arguments = [filepath, Connect]
        return self.NewAccessProject(*arguments)

    def new_access_project(self, filepath=None, Connect=None):
        """Alias for NewAccessProject"""
        arguments = [filepath, Connect]
        return self.NewAccessProject(*arguments)

    def NewCurrentDatabase(self, filepath=None, FileFormat=None, Template=None, SiteAddress=None, ListID=None):
        arguments = com_arguments([unwrap(a) for a in [filepath, FileFormat, Template, SiteAddress, ListID]])
        self.com_object.NewCurrentDatabase(*arguments)

    def newcurrentdatabase(self, filepath=None, FileFormat=None, Template=None, SiteAddress=None, ListID=None):
        """Alias for NewCurrentDatabase"""
        arguments = [filepath, FileFormat, Template, SiteAddress, ListID]
        return self.NewCurrentDatabase(*arguments)

    def new_current_database(self, filepath=None, FileFormat=None, Template=None, SiteAddress=None, ListID=None):
        """Alias for NewCurrentDatabase"""
        arguments = [filepath, FileFormat, Template, SiteAddress, ListID]
        return self.NewCurrentDatabase(*arguments)

    def Nz(self, Value=None, ValueIfNull=None):
        arguments = com_arguments([unwrap(a) for a in [Value, ValueIfNull]])
        return self.com_object.Nz(*arguments)

    def nz(self, Value=None, ValueIfNull=None):
        """Alias for Nz"""
        arguments = [Value, ValueIfNull]
        return self.Nz(*arguments)

    def OpenAccessProject(self, filepath=None, Exclusive=None):
        arguments = com_arguments([unwrap(a) for a in [filepath, Exclusive]])
        return self.com_object.OpenAccessProject(*arguments)

    def openaccessproject(self, filepath=None, Exclusive=None):
        """Alias for OpenAccessProject"""
        arguments = [filepath, Exclusive]
        return self.OpenAccessProject(*arguments)

    def open_access_project(self, filepath=None, Exclusive=None):
        """Alias for OpenAccessProject"""
        arguments = [filepath, Exclusive]
        return self.OpenAccessProject(*arguments)

    def OpenCurrentDatabase(self, filepath=None, Exclusive=None, bstrPassword=None):
        arguments = com_arguments([unwrap(a) for a in [filepath, Exclusive, bstrPassword]])
        return self.com_object.OpenCurrentDatabase(*arguments)

    def opencurrentdatabase(self, filepath=None, Exclusive=None, bstrPassword=None):
        """Alias for OpenCurrentDatabase"""
        arguments = [filepath, Exclusive, bstrPassword]
        return self.OpenCurrentDatabase(*arguments)

    def open_current_database(self, filepath=None, Exclusive=None, bstrPassword=None):
        """Alias for OpenCurrentDatabase"""
        arguments = [filepath, Exclusive, bstrPassword]
        return self.OpenCurrentDatabase(*arguments)

    def PlainText(self, RichText=None, Length=None):
        arguments = com_arguments([unwrap(a) for a in [RichText, Length]])
        return self.com_object.PlainText(*arguments)

    def plaintext(self, RichText=None, Length=None):
        """Alias for PlainText"""
        arguments = [RichText, Length]
        return self.PlainText(*arguments)

    def plain_text(self, RichText=None, Length=None):
        """Alias for PlainText"""
        arguments = [RichText, Length]
        return self.PlainText(*arguments)

    def Quit(self, Option=None):
        arguments = com_arguments([unwrap(a) for a in [Option]])
        self.com_object.Quit(*arguments)

    def quit(self, Option=None):
        """Alias for Quit"""
        arguments = [Option]
        return self.Quit(*arguments)

    def RefreshDatabaseWindow(self):
        return self.com_object.RefreshDatabaseWindow()

    def refreshdatabasewindow(self):
        """Alias for RefreshDatabaseWindow"""
        return self.RefreshDatabaseWindow()

    def refresh_database_window(self):
        """Alias for RefreshDatabaseWindow"""
        return self.RefreshDatabaseWindow()

    def RefreshTitleBar(self):
        return self.com_object.RefreshTitleBar()

    def refreshtitlebar(self):
        """Alias for RefreshTitleBar"""
        return self.RefreshTitleBar()

    def refresh_title_bar(self):
        """Alias for RefreshTitleBar"""
        return self.RefreshTitleBar()

    def Run(self, Procedure=None, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        arguments = com_arguments([unwrap(a) for a in [Procedure, Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]])
        return self.com_object.Run(*arguments)

    def run(self, Procedure=None, Arg1=None, Arg2=None, Arg3=None, Arg4=None, Arg5=None, Arg6=None, Arg7=None, Arg8=None, Arg9=None, Arg10=None, Arg11=None, Arg12=None, Arg13=None, Arg14=None, Arg15=None, Arg16=None, Arg17=None, Arg18=None, Arg19=None, Arg20=None, Arg21=None, Arg22=None, Arg23=None, Arg24=None, Arg25=None, Arg26=None, Arg27=None, Arg28=None, Arg29=None, Arg30=None):
        """Alias for Run"""
        arguments = [Procedure, Arg1, Arg2, Arg3, Arg4, Arg5, Arg6, Arg7, Arg8, Arg9, Arg10, Arg11, Arg12, Arg13, Arg14, Arg15, Arg16, Arg17, Arg18, Arg19, Arg20, Arg21, Arg22, Arg23, Arg24, Arg25, Arg26, Arg27, Arg28, Arg29, Arg30]
        return self.Run(*arguments)

    def RunCommand(self, Command=None):
        arguments = com_arguments([unwrap(a) for a in [Command]])
        self.com_object.RunCommand(*arguments)

    def runcommand(self, Command=None):
        """Alias for RunCommand"""
        arguments = [Command]
        return self.RunCommand(*arguments)

    def run_command(self, Command=None):
        """Alias for RunCommand"""
        arguments = [Command]
        return self.RunCommand(*arguments)

    def SaveAsAXL(self, ObjectType=None, ObjectName=None, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [ObjectType, ObjectName, FileName]])
        self.com_object.SaveAsAXL(*arguments)

    def saveasaxl(self, ObjectType=None, ObjectName=None, FileName=None):
        """Alias for SaveAsAXL"""
        arguments = [ObjectType, ObjectName, FileName]
        return self.SaveAsAXL(*arguments)

    def save_as_a_x_l(self, ObjectType=None, ObjectName=None, FileName=None):
        """Alias for SaveAsAXL"""
        arguments = [ObjectType, ObjectName, FileName]
        return self.SaveAsAXL(*arguments)

    def SaveAsTemplate(self, Path=None, Title=None, IconPath=None, CoreTable=None, Category=None, PreviewPath=None, Description=None, InstantiationForm=None, ApplicationPart=None, IncludeData=None):
        arguments = com_arguments([unwrap(a) for a in [Path, Title, IconPath, CoreTable, Category, PreviewPath, Description, InstantiationForm, ApplicationPart, IncludeData]])
        self.com_object.SaveAsTemplate(*arguments)

    def saveastemplate(self, Path=None, Title=None, IconPath=None, CoreTable=None, Category=None, PreviewPath=None, Description=None, InstantiationForm=None, ApplicationPart=None, IncludeData=None):
        """Alias for SaveAsTemplate"""
        arguments = [Path, Title, IconPath, CoreTable, Category, PreviewPath, Description, InstantiationForm, ApplicationPart, IncludeData]
        return self.SaveAsTemplate(*arguments)

    def save_as_template(self, Path=None, Title=None, IconPath=None, CoreTable=None, Category=None, PreviewPath=None, Description=None, InstantiationForm=None, ApplicationPart=None, IncludeData=None):
        """Alias for SaveAsTemplate"""
        arguments = [Path, Title, IconPath, CoreTable, Category, PreviewPath, Description, InstantiationForm, ApplicationPart, IncludeData]
        return self.SaveAsTemplate(*arguments)

    def SetDefaultWorkgroupFile(self, Path=None):
        arguments = com_arguments([unwrap(a) for a in [Path]])
        return self.com_object.SetDefaultWorkgroupFile(*arguments)

    def setdefaultworkgroupfile(self, Path=None):
        """Alias for SetDefaultWorkgroupFile"""
        arguments = [Path]
        return self.SetDefaultWorkgroupFile(*arguments)

    def set_default_workgroup_file(self, Path=None):
        """Alias for SetDefaultWorkgroupFile"""
        arguments = [Path]
        return self.SetDefaultWorkgroupFile(*arguments)

    def SetHiddenAttribute(self, ObjectType=None, ObjectName=None, fHidden=None):
        arguments = com_arguments([unwrap(a) for a in [ObjectType, ObjectName, fHidden]])
        return self.com_object.SetHiddenAttribute(*arguments)

    def sethiddenattribute(self, ObjectType=None, ObjectName=None, fHidden=None):
        """Alias for SetHiddenAttribute"""
        arguments = [ObjectType, ObjectName, fHidden]
        return self.SetHiddenAttribute(*arguments)

    def set_hidden_attribute(self, ObjectType=None, ObjectName=None, fHidden=None):
        """Alias for SetHiddenAttribute"""
        arguments = [ObjectType, ObjectName, fHidden]
        return self.SetHiddenAttribute(*arguments)

    def SetOption(self, OptionName=None, Setting=None):
        arguments = com_arguments([unwrap(a) for a in [OptionName, Setting]])
        self.com_object.SetOption(*arguments)

    def setoption(self, OptionName=None, Setting=None):
        """Alias for SetOption"""
        arguments = [OptionName, Setting]
        return self.SetOption(*arguments)

    def set_option(self, OptionName=None, Setting=None):
        """Alias for SetOption"""
        arguments = [OptionName, Setting]
        return self.SetOption(*arguments)

    def StringFromGUID(self, Guid=None):
        arguments = com_arguments([unwrap(a) for a in [Guid]])
        return self.com_object.StringFromGUID(*arguments)

    def stringfromguid(self, Guid=None):
        """Alias for StringFromGUID"""
        arguments = [Guid]
        return self.StringFromGUID(*arguments)

    def string_from_g_u_i_d(self, Guid=None):
        """Alias for StringFromGUID"""
        arguments = [Guid]
        return self.StringFromGUID(*arguments)

    def SysCmd(self, Action=None, Argument2=None, Argument3=None):
        arguments = com_arguments([unwrap(a) for a in [Action, Argument2, Argument3]])
        return self.com_object.SysCmd(*arguments)

    def syscmd(self, Action=None, Argument2=None, Argument3=None):
        """Alias for SysCmd"""
        arguments = [Action, Argument2, Argument3]
        return self.SysCmd(*arguments)

    def sys_cmd(self, Action=None, Argument2=None, Argument3=None):
        """Alias for SysCmd"""
        arguments = [Action, Argument2, Argument3]
        return self.SysCmd(*arguments)

    def TransformXML(self, DataSource=None, TransformSource=None, OutputTarget=None, WellFormedXMLOutput=None, ScriptOption=None):
        arguments = com_arguments([unwrap(a) for a in [DataSource, TransformSource, OutputTarget, WellFormedXMLOutput, ScriptOption]])
        return self.com_object.TransformXML(*arguments)

    def transformxml(self, DataSource=None, TransformSource=None, OutputTarget=None, WellFormedXMLOutput=None, ScriptOption=None):
        """Alias for TransformXML"""
        arguments = [DataSource, TransformSource, OutputTarget, WellFormedXMLOutput, ScriptOption]
        return self.TransformXML(*arguments)

    def transform_x_m_l(self, DataSource=None, TransformSource=None, OutputTarget=None, WellFormedXMLOutput=None, ScriptOption=None):
        """Alias for TransformXML"""
        arguments = [DataSource, TransformSource, OutputTarget, WellFormedXMLOutput, ScriptOption]
        return self.TransformXML(*arguments)


class Attachment:

    def __init__(self, attachment=None):
        self.com_object= attachment

    @property
    def AddColon(self):
        return self.com_object.AddColon

    @AddColon.setter
    def AddColon(self, value):
        self.com_object.AddColon = value

    @property
    def addcolon(self):
        """Alias for AddColon"""
        return self.AddColon

    @addcolon.setter
    def addcolon(self, value):
        """Alias for AddColon.setter"""
        self.AddColon = value

    @property
    def add_colon(self):
        """Alias for AddColon"""
        return self.AddColon

    @add_colon.setter
    def add_colon(self, value):
        """Alias for AddColon.setter"""
        self.AddColon = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AttachmentCount(self):
        return self.com_object.AttachmentCount

    @property
    def attachmentcount(self):
        """Alias for AttachmentCount"""
        return self.AttachmentCount

    @property
    def attachment_count(self):
        """Alias for AttachmentCount"""
        return self.AttachmentCount

    @property
    def AutoLabel(self):
        return self.com_object.AutoLabel

    @AutoLabel.setter
    def AutoLabel(self, value):
        self.com_object.AutoLabel = value

    @property
    def autolabel(self):
        """Alias for AutoLabel"""
        return self.AutoLabel

    @autolabel.setter
    def autolabel(self, value):
        """Alias for AutoLabel.setter"""
        self.AutoLabel = value

    @property
    def auto_label(self):
        """Alias for AutoLabel"""
        return self.AutoLabel

    @auto_label.setter
    def auto_label(self, value):
        """Alias for AutoLabel.setter"""
        self.AutoLabel = value

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BackShade(self):
        return self.com_object.BackShade

    @BackShade.setter
    def BackShade(self, value):
        self.com_object.BackShade = value

    @property
    def backshade(self):
        """Alias for BackShade"""
        return self.BackShade

    @backshade.setter
    def backshade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def back_shade(self):
        """Alias for BackShade"""
        return self.BackShade

    @back_shade.setter
    def back_shade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def BackStyle(self):
        return self.com_object.BackStyle

    @BackStyle.setter
    def BackStyle(self, value):
        self.com_object.BackStyle = value

    @property
    def backstyle(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @backstyle.setter
    def backstyle(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def back_style(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @back_style.setter
    def back_style(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def BackThemeColorIndex(self):
        return self.com_object.BackThemeColorIndex

    @BackThemeColorIndex.setter
    def BackThemeColorIndex(self, value):
        self.com_object.BackThemeColorIndex = value

    @property
    def backthemecolorindex(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @backthemecolorindex.setter
    def backthemecolorindex(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def back_theme_color_index(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @back_theme_color_index.setter
    def back_theme_color_index(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def BackTint(self):
        return self.com_object.BackTint

    @BackTint.setter
    def BackTint(self, value):
        self.com_object.BackTint = value

    @property
    def backtint(self):
        """Alias for BackTint"""
        return self.BackTint

    @backtint.setter
    def backtint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def back_tint(self):
        """Alias for BackTint"""
        return self.BackTint

    @back_tint.setter
    def back_tint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def BorderColor(self):
        return self.com_object.BorderColor

    @BorderColor.setter
    def BorderColor(self, value):
        self.com_object.BorderColor = value

    @property
    def bordercolor(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @bordercolor.setter
    def bordercolor(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def border_color(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @border_color.setter
    def border_color(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def BorderShade(self):
        return self.com_object.BorderShade

    @BorderShade.setter
    def BorderShade(self, value):
        self.com_object.BorderShade = value

    @property
    def bordershade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @bordershade.setter
    def bordershade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def border_shade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @border_shade.setter
    def border_shade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def BorderStyle(self):
        return self.com_object.BorderStyle

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def BorderThemeColorIndex(self):
        return self.com_object.BorderThemeColorIndex

    @BorderThemeColorIndex.setter
    def BorderThemeColorIndex(self, value):
        self.com_object.BorderThemeColorIndex = value

    @property
    def borderthemecolorindex(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @borderthemecolorindex.setter
    def borderthemecolorindex(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def border_theme_color_index(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @border_theme_color_index.setter
    def border_theme_color_index(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def BorderTint(self):
        return self.com_object.BorderTint

    @BorderTint.setter
    def BorderTint(self, value):
        self.com_object.BorderTint = value

    @property
    def bordertint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @bordertint.setter
    def bordertint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def border_tint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @border_tint.setter
    def border_tint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def BorderWidth(self):
        return self.com_object.BorderWidth

    @BorderWidth.setter
    def BorderWidth(self, value):
        self.com_object.BorderWidth = value

    @property
    def borderwidth(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @borderwidth.setter
    def borderwidth(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def border_width(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @border_width.setter
    def border_width(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def BottomPadding(self):
        return self.com_object.BottomPadding

    @BottomPadding.setter
    def BottomPadding(self, value):
        self.com_object.BottomPadding = value

    @property
    def bottompadding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottompadding.setter
    def bottompadding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def bottom_padding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottom_padding.setter
    def bottom_padding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def ColumnHidden(self):
        return self.com_object.ColumnHidden

    @ColumnHidden.setter
    def ColumnHidden(self, value):
        self.com_object.ColumnHidden = value

    @property
    def columnhidden(self):
        """Alias for ColumnHidden"""
        return self.ColumnHidden

    @columnhidden.setter
    def columnhidden(self, value):
        """Alias for ColumnHidden.setter"""
        self.ColumnHidden = value

    @property
    def column_hidden(self):
        """Alias for ColumnHidden"""
        return self.ColumnHidden

    @column_hidden.setter
    def column_hidden(self, value):
        """Alias for ColumnHidden.setter"""
        self.ColumnHidden = value

    @property
    def ColumnOrder(self):
        return self.com_object.ColumnOrder

    @ColumnOrder.setter
    def ColumnOrder(self, value):
        self.com_object.ColumnOrder = value

    @property
    def columnorder(self):
        """Alias for ColumnOrder"""
        return self.ColumnOrder

    @columnorder.setter
    def columnorder(self, value):
        """Alias for ColumnOrder.setter"""
        self.ColumnOrder = value

    @property
    def column_order(self):
        """Alias for ColumnOrder"""
        return self.ColumnOrder

    @column_order.setter
    def column_order(self, value):
        """Alias for ColumnOrder.setter"""
        self.ColumnOrder = value

    @property
    def ColumnWidth(self):
        return self.com_object.ColumnWidth

    @ColumnWidth.setter
    def ColumnWidth(self, value):
        self.com_object.ColumnWidth = value

    @property
    def columnwidth(self):
        """Alias for ColumnWidth"""
        return self.ColumnWidth

    @columnwidth.setter
    def columnwidth(self, value):
        """Alias for ColumnWidth.setter"""
        self.ColumnWidth = value

    @property
    def column_width(self):
        """Alias for ColumnWidth"""
        return self.ColumnWidth

    @column_width.setter
    def column_width(self, value):
        """Alias for ColumnWidth.setter"""
        self.ColumnWidth = value

    @property
    def Controls(self):
        return Controls(self.com_object.Controls)

    @property
    def controls(self):
        """Alias for Controls"""
        return self.Controls

    @property
    def ControlSource(self):
        return self.com_object.ControlSource

    @ControlSource.setter
    def ControlSource(self, value):
        self.com_object.ControlSource = value

    @property
    def controlsource(self):
        """Alias for ControlSource"""
        return self.ControlSource

    @controlsource.setter
    def controlsource(self, value):
        """Alias for ControlSource.setter"""
        self.ControlSource = value

    @property
    def control_source(self):
        """Alias for ControlSource"""
        return self.ControlSource

    @control_source.setter
    def control_source(self, value):
        """Alias for ControlSource.setter"""
        self.ControlSource = value

    @property
    def ControlTipText(self):
        return self.com_object.ControlTipText

    @ControlTipText.setter
    def ControlTipText(self, value):
        self.com_object.ControlTipText = value

    @property
    def controltiptext(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @controltiptext.setter
    def controltiptext(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def control_tip_text(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @control_tip_text.setter
    def control_tip_text(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def ControlType(self):
        return self.com_object.ControlType

    @ControlType.setter
    def ControlType(self, value):
        self.com_object.ControlType = value

    @property
    def controltype(self):
        """Alias for ControlType"""
        return self.ControlType

    @controltype.setter
    def controltype(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def control_type(self):
        """Alias for ControlType"""
        return self.ControlType

    @control_type.setter
    def control_type(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def CurrentAttachment(self):
        return self.com_object.CurrentAttachment

    @CurrentAttachment.setter
    def CurrentAttachment(self, value):
        self.com_object.CurrentAttachment = value

    @property
    def currentattachment(self):
        """Alias for CurrentAttachment"""
        return self.CurrentAttachment

    @currentattachment.setter
    def currentattachment(self, value):
        """Alias for CurrentAttachment.setter"""
        self.CurrentAttachment = value

    @property
    def current_attachment(self):
        """Alias for CurrentAttachment"""
        return self.CurrentAttachment

    @current_attachment.setter
    def current_attachment(self, value):
        """Alias for CurrentAttachment.setter"""
        self.CurrentAttachment = value

    @property
    def DefaultPicture(self):
        return self.com_object.DefaultPicture

    @DefaultPicture.setter
    def DefaultPicture(self, value):
        self.com_object.DefaultPicture = value

    @property
    def defaultpicture(self):
        """Alias for DefaultPicture"""
        return self.DefaultPicture

    @defaultpicture.setter
    def defaultpicture(self, value):
        """Alias for DefaultPicture.setter"""
        self.DefaultPicture = value

    @property
    def default_picture(self):
        """Alias for DefaultPicture"""
        return self.DefaultPicture

    @default_picture.setter
    def default_picture(self, value):
        """Alias for DefaultPicture.setter"""
        self.DefaultPicture = value

    @property
    def DefaultPictureType(self):
        return self.com_object.DefaultPictureType

    @DefaultPictureType.setter
    def DefaultPictureType(self, value):
        self.com_object.DefaultPictureType = value

    @property
    def defaultpicturetype(self):
        """Alias for DefaultPictureType"""
        return self.DefaultPictureType

    @defaultpicturetype.setter
    def defaultpicturetype(self, value):
        """Alias for DefaultPictureType.setter"""
        self.DefaultPictureType = value

    @property
    def default_picture_type(self):
        """Alias for DefaultPictureType"""
        return self.DefaultPictureType

    @default_picture_type.setter
    def default_picture_type(self, value):
        """Alias for DefaultPictureType.setter"""
        self.DefaultPictureType = value

    @property
    def DisplayAs(self):
        return self.com_object.DisplayAs

    @DisplayAs.setter
    def DisplayAs(self, value):
        self.com_object.DisplayAs = value

    @property
    def displayas(self):
        """Alias for DisplayAs"""
        return self.DisplayAs

    @displayas.setter
    def displayas(self, value):
        """Alias for DisplayAs.setter"""
        self.DisplayAs = value

    @property
    def display_as(self):
        """Alias for DisplayAs"""
        return self.DisplayAs

    @display_as.setter
    def display_as(self, value):
        """Alias for DisplayAs.setter"""
        self.DisplayAs = value

    @property
    def DisplayWhen(self):
        return self.com_object.DisplayWhen

    @DisplayWhen.setter
    def DisplayWhen(self, value):
        self.com_object.DisplayWhen = value

    @property
    def displaywhen(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @displaywhen.setter
    def displaywhen(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def display_when(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @display_when.setter
    def display_when(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    def FileName(self, var=None):
        arguments = com_arguments([unwrap(a) for a in [var]])
        if hasattr(self.com_object, "GetFileName"):
            return self.com_object.GetFileName(*arguments)
        else:
            return self.com_object.FileName(*arguments)

    def filename(self, var=None):
        """Alias for FileName"""
        arguments = [var]
        return self.FileName(*arguments)

    def file_name(self, var=None):
        """Alias for FileName"""
        arguments = [var]
        return self.FileName(*arguments)

    def FileType(self, var=None):
        arguments = com_arguments([unwrap(a) for a in [var]])
        if hasattr(self.com_object, "GetFileType"):
            return self.com_object.GetFileType(*arguments)
        else:
            return self.com_object.FileType(*arguments)

    def filetype(self, var=None):
        """Alias for FileType"""
        arguments = [var]
        return self.FileType(*arguments)

    def file_type(self, var=None):
        """Alias for FileType"""
        arguments = [var]
        return self.FileType(*arguments)

    def FileURL(self, var=None):
        arguments = com_arguments([unwrap(a) for a in [var]])
        if hasattr(self.com_object, "GetFileURL"):
            return self.com_object.GetFileURL(*arguments)
        else:
            return self.com_object.FileURL(*arguments)

    def fileurl(self, var=None):
        """Alias for FileURL"""
        arguments = [var]
        return self.FileURL(*arguments)

    def file_u_r_l(self, var=None):
        """Alias for FileURL"""
        arguments = [var]
        return self.FileURL(*arguments)

    @property
    def GridlineColor(self):
        return self.com_object.GridlineColor

    @GridlineColor.setter
    def GridlineColor(self, value):
        self.com_object.GridlineColor = value

    @property
    def gridlinecolor(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridlinecolor.setter
    def gridlinecolor(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def gridline_color(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridline_color.setter
    def gridline_color(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def GridlineShade(self):
        return self.com_object.GridlineShade

    @GridlineShade.setter
    def GridlineShade(self, value):
        self.com_object.GridlineShade = value

    @property
    def gridlineshade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridlineshade.setter
    def gridlineshade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def gridline_shade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridline_shade.setter
    def gridline_shade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def GridlineStyleBottom(self):
        return self.com_object.GridlineStyleBottom

    @GridlineStyleBottom.setter
    def GridlineStyleBottom(self, value):
        self.com_object.GridlineStyleBottom = value

    @property
    def gridlinestylebottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridlinestylebottom.setter
    def gridlinestylebottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def gridline_style_bottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridline_style_bottom.setter
    def gridline_style_bottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def GridlineStyleLeft(self):
        return self.com_object.GridlineStyleLeft

    @GridlineStyleLeft.setter
    def GridlineStyleLeft(self, value):
        self.com_object.GridlineStyleLeft = value

    @property
    def gridlinestyleleft(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridlinestyleleft.setter
    def gridlinestyleleft(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def gridline_style_left(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridline_style_left.setter
    def gridline_style_left(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def GridlineStyleRight(self):
        return self.com_object.GridlineStyleRight

    @GridlineStyleRight.setter
    def GridlineStyleRight(self, value):
        self.com_object.GridlineStyleRight = value

    @property
    def gridlinestyleright(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridlinestyleright.setter
    def gridlinestyleright(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def gridline_style_right(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridline_style_right.setter
    def gridline_style_right(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def GridlineStyleTop(self):
        return self.com_object.GridlineStyleTop

    @GridlineStyleTop.setter
    def GridlineStyleTop(self, value):
        self.com_object.GridlineStyleTop = value

    @property
    def gridlinestyletop(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridlinestyletop.setter
    def gridlinestyletop(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def gridline_style_top(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridline_style_top.setter
    def gridline_style_top(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def GridlineThemeColorIndex(self):
        return self.com_object.GridlineThemeColorIndex

    @GridlineThemeColorIndex.setter
    def GridlineThemeColorIndex(self, value):
        self.com_object.GridlineThemeColorIndex = value

    @property
    def gridlinethemecolorindex(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridlinethemecolorindex.setter
    def gridlinethemecolorindex(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def gridline_theme_color_index(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridline_theme_color_index.setter
    def gridline_theme_color_index(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def GridlineTint(self):
        return self.com_object.GridlineTint

    @GridlineTint.setter
    def GridlineTint(self, value):
        self.com_object.GridlineTint = value

    @property
    def gridlinetint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridlinetint.setter
    def gridlinetint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def gridline_tint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridline_tint.setter
    def gridline_tint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def GridlineWidthBottom(self):
        return self.com_object.GridlineWidthBottom

    @GridlineWidthBottom.setter
    def GridlineWidthBottom(self, value):
        self.com_object.GridlineWidthBottom = value

    @property
    def gridlinewidthbottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridlinewidthbottom.setter
    def gridlinewidthbottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def gridline_width_bottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridline_width_bottom.setter
    def gridline_width_bottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def GridlineWidthLeft(self):
        return self.com_object.GridlineWidthLeft

    @GridlineWidthLeft.setter
    def GridlineWidthLeft(self, value):
        self.com_object.GridlineWidthLeft = value

    @property
    def gridlinewidthleft(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridlinewidthleft.setter
    def gridlinewidthleft(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def gridline_width_left(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridline_width_left.setter
    def gridline_width_left(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def GridlineWidthRight(self):
        return self.com_object.GridlineWidthRight

    @GridlineWidthRight.setter
    def GridlineWidthRight(self, value):
        self.com_object.GridlineWidthRight = value

    @property
    def gridlinewidthright(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridlinewidthright.setter
    def gridlinewidthright(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def gridline_width_right(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridline_width_right.setter
    def gridline_width_right(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def GridlineWidthTop(self):
        return self.com_object.GridlineWidthTop

    @GridlineWidthTop.setter
    def GridlineWidthTop(self, value):
        self.com_object.GridlineWidthTop = value

    @property
    def gridlinewidthtop(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridlinewidthtop.setter
    def gridlinewidthtop(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def gridline_width_top(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridline_width_top.setter
    def gridline_width_top(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HelpContextId(self):
        return self.com_object.HelpContextId

    @HelpContextId.setter
    def HelpContextId(self, value):
        self.com_object.HelpContextId = value

    @property
    def helpcontextid(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @helpcontextid.setter
    def helpcontextid(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def help_context_id(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @help_context_id.setter
    def help_context_id(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def IsVisible(self):
        return self.com_object.IsVisible

    @IsVisible.setter
    def IsVisible(self, value):
        self.com_object.IsVisible = value

    @property
    def isvisible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @isvisible.setter
    def isvisible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def is_visible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @is_visible.setter
    def is_visible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def LabelAlign(self):
        return self.com_object.LabelAlign

    @LabelAlign.setter
    def LabelAlign(self, value):
        self.com_object.LabelAlign = value

    @property
    def labelalign(self):
        """Alias for LabelAlign"""
        return self.LabelAlign

    @labelalign.setter
    def labelalign(self, value):
        """Alias for LabelAlign.setter"""
        self.LabelAlign = value

    @property
    def label_align(self):
        """Alias for LabelAlign"""
        return self.LabelAlign

    @label_align.setter
    def label_align(self, value):
        """Alias for LabelAlign.setter"""
        self.LabelAlign = value

    @property
    def LabelX(self):
        return self.com_object.LabelX

    @LabelX.setter
    def LabelX(self, value):
        self.com_object.LabelX = value

    @property
    def labelx(self):
        """Alias for LabelX"""
        return self.LabelX

    @labelx.setter
    def labelx(self, value):
        """Alias for LabelX.setter"""
        self.LabelX = value

    @property
    def label_x(self):
        """Alias for LabelX"""
        return self.LabelX

    @label_x.setter
    def label_x(self, value):
        """Alias for LabelX.setter"""
        self.LabelX = value

    @property
    def LabelY(self):
        return self.com_object.LabelY

    @LabelY.setter
    def LabelY(self, value):
        self.com_object.LabelY = value

    @property
    def labely(self):
        """Alias for LabelY"""
        return self.LabelY

    @labely.setter
    def labely(self, value):
        """Alias for LabelY.setter"""
        self.LabelY = value

    @property
    def label_y(self):
        """Alias for LabelY"""
        return self.LabelY

    @label_y.setter
    def label_y(self, value):
        """Alias for LabelY.setter"""
        self.LabelY = value

    @property
    def Layout(self):
        return AcLayoutType(self.com_object.Layout)

    @property
    def layout(self):
        """Alias for Layout"""
        return self.Layout

    @property
    def LayoutID(self):
        return self.com_object.LayoutID

    @property
    def layoutid(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def layout_i_d(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def LeftPadding(self):
        return self.com_object.LeftPadding

    @LeftPadding.setter
    def LeftPadding(self, value):
        self.com_object.LeftPadding = value

    @property
    def leftpadding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @leftpadding.setter
    def leftpadding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def left_padding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @left_padding.setter
    def left_padding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def OldBorderStyle(self):
        return self.com_object.OldBorderStyle

    @OldBorderStyle.setter
    def OldBorderStyle(self, value):
        self.com_object.OldBorderStyle = value

    @property
    def oldborderstyle(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @oldborderstyle.setter
    def oldborderstyle(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def old_border_style(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @old_border_style.setter
    def old_border_style(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def OldValue(self):
        return self.com_object.OldValue

    @property
    def oldvalue(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def old_value(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def OnAttachmentCurrent(self):
        return self.com_object.OnAttachmentCurrent

    @OnAttachmentCurrent.setter
    def OnAttachmentCurrent(self, value):
        self.com_object.OnAttachmentCurrent = value

    @property
    def onattachmentcurrent(self):
        """Alias for OnAttachmentCurrent"""
        return self.OnAttachmentCurrent

    @onattachmentcurrent.setter
    def onattachmentcurrent(self, value):
        """Alias for OnAttachmentCurrent.setter"""
        self.OnAttachmentCurrent = value

    @property
    def on_attachment_current(self):
        """Alias for OnAttachmentCurrent"""
        return self.OnAttachmentCurrent

    @on_attachment_current.setter
    def on_attachment_current(self, value):
        """Alias for OnAttachmentCurrent.setter"""
        self.OnAttachmentCurrent = value

    @property
    def OnChange(self):
        return self.com_object.OnChange

    @OnChange.setter
    def OnChange(self, value):
        self.com_object.OnChange = value

    @property
    def onchange(self):
        """Alias for OnChange"""
        return self.OnChange

    @onchange.setter
    def onchange(self, value):
        """Alias for OnChange.setter"""
        self.OnChange = value

    @property
    def on_change(self):
        """Alias for OnChange"""
        return self.OnChange

    @on_change.setter
    def on_change(self, value):
        """Alias for OnChange.setter"""
        self.OnChange = value

    @property
    def OnClick(self):
        return self.com_object.OnClick

    @OnClick.setter
    def OnClick(self, value):
        self.com_object.OnClick = value

    @property
    def onclick(self):
        """Alias for OnClick"""
        return self.OnClick

    @onclick.setter
    def onclick(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def on_click(self):
        """Alias for OnClick"""
        return self.OnClick

    @on_click.setter
    def on_click(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def OnDblClick(self):
        return self.com_object.OnDblClick

    @OnDblClick.setter
    def OnDblClick(self, value):
        self.com_object.OnDblClick = value

    @property
    def ondblclick(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @ondblclick.setter
    def ondblclick(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def on_dbl_click(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @on_dbl_click.setter
    def on_dbl_click(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def OnDirty(self):
        return self.com_object.OnDirty

    @OnDirty.setter
    def OnDirty(self, value):
        self.com_object.OnDirty = value

    @property
    def ondirty(self):
        """Alias for OnDirty"""
        return self.OnDirty

    @ondirty.setter
    def ondirty(self, value):
        """Alias for OnDirty.setter"""
        self.OnDirty = value

    @property
    def on_dirty(self):
        """Alias for OnDirty"""
        return self.OnDirty

    @on_dirty.setter
    def on_dirty(self, value):
        """Alias for OnDirty.setter"""
        self.OnDirty = value

    @property
    def OnEnter(self):
        return self.com_object.OnEnter

    @OnEnter.setter
    def OnEnter(self, value):
        self.com_object.OnEnter = value

    @property
    def onenter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @onenter.setter
    def onenter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def on_enter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @on_enter.setter
    def on_enter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def OnExit(self):
        return self.com_object.OnExit

    @OnExit.setter
    def OnExit(self, value):
        self.com_object.OnExit = value

    @property
    def onexit(self):
        """Alias for OnExit"""
        return self.OnExit

    @onexit.setter
    def onexit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def on_exit(self):
        """Alias for OnExit"""
        return self.OnExit

    @on_exit.setter
    def on_exit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def OnGotFocus(self):
        return self.com_object.OnGotFocus

    @OnGotFocus.setter
    def OnGotFocus(self, value):
        self.com_object.OnGotFocus = value

    @property
    def ongotfocus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @ongotfocus.setter
    def ongotfocus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def on_got_focus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @on_got_focus.setter
    def on_got_focus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def OnKeyDown(self):
        return self.com_object.OnKeyDown

    @OnKeyDown.setter
    def OnKeyDown(self, value):
        self.com_object.OnKeyDown = value

    @property
    def onkeydown(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @onkeydown.setter
    def onkeydown(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def on_key_down(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @on_key_down.setter
    def on_key_down(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def OnKeyPress(self):
        return self.com_object.OnKeyPress

    @OnKeyPress.setter
    def OnKeyPress(self, value):
        self.com_object.OnKeyPress = value

    @property
    def onkeypress(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @onkeypress.setter
    def onkeypress(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def on_key_press(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @on_key_press.setter
    def on_key_press(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def OnKeyUp(self):
        return self.com_object.OnKeyUp

    @OnKeyUp.setter
    def OnKeyUp(self, value):
        self.com_object.OnKeyUp = value

    @property
    def onkeyup(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @onkeyup.setter
    def onkeyup(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def on_key_up(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @on_key_up.setter
    def on_key_up(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def OnLostFocus(self):
        return self.com_object.OnLostFocus

    @OnLostFocus.setter
    def OnLostFocus(self, value):
        self.com_object.OnLostFocus = value

    @property
    def onlostfocus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @onlostfocus.setter
    def onlostfocus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def on_lost_focus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @on_lost_focus.setter
    def on_lost_focus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def OnMouseDown(self):
        return self.com_object.OnMouseDown

    @OnMouseDown.setter
    def OnMouseDown(self, value):
        self.com_object.OnMouseDown = value

    @property
    def onmousedown(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @onmousedown.setter
    def onmousedown(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def on_mouse_down(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @on_mouse_down.setter
    def on_mouse_down(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def OnMouseMove(self):
        return self.com_object.OnMouseMove

    @OnMouseMove.setter
    def OnMouseMove(self, value):
        self.com_object.OnMouseMove = value

    @property
    def onmousemove(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @onmousemove.setter
    def onmousemove(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def on_mouse_move(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @on_mouse_move.setter
    def on_mouse_move(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def OnMouseUp(self):
        return self.com_object.OnMouseUp

    @OnMouseUp.setter
    def OnMouseUp(self, value):
        self.com_object.OnMouseUp = value

    @property
    def onmouseup(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @onmouseup.setter
    def onmouseup(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def on_mouse_up(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @on_mouse_up.setter
    def on_mouse_up(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PictureAlignment(self):
        return self.com_object.PictureAlignment

    @PictureAlignment.setter
    def PictureAlignment(self, value):
        self.com_object.PictureAlignment = value

    @property
    def picturealignment(self):
        """Alias for PictureAlignment"""
        return self.PictureAlignment

    @picturealignment.setter
    def picturealignment(self, value):
        """Alias for PictureAlignment.setter"""
        self.PictureAlignment = value

    @property
    def picture_alignment(self):
        """Alias for PictureAlignment"""
        return self.PictureAlignment

    @picture_alignment.setter
    def picture_alignment(self, value):
        """Alias for PictureAlignment.setter"""
        self.PictureAlignment = value

    @property
    def PictureSizeMode(self):
        return self.com_object.PictureSizeMode

    @PictureSizeMode.setter
    def PictureSizeMode(self, value):
        self.com_object.PictureSizeMode = value

    @property
    def picturesizemode(self):
        """Alias for PictureSizeMode"""
        return self.PictureSizeMode

    @picturesizemode.setter
    def picturesizemode(self, value):
        """Alias for PictureSizeMode.setter"""
        self.PictureSizeMode = value

    @property
    def picture_size_mode(self):
        """Alias for PictureSizeMode"""
        return self.PictureSizeMode

    @picture_size_mode.setter
    def picture_size_mode(self, value):
        """Alias for PictureSizeMode.setter"""
        self.PictureSizeMode = value

    @property
    def PictureTiling(self):
        return self.com_object.PictureTiling

    @PictureTiling.setter
    def PictureTiling(self, value):
        self.com_object.PictureTiling = value

    @property
    def picturetiling(self):
        """Alias for PictureTiling"""
        return self.PictureTiling

    @picturetiling.setter
    def picturetiling(self, value):
        """Alias for PictureTiling.setter"""
        self.PictureTiling = value

    @property
    def picture_tiling(self):
        """Alias for PictureTiling"""
        return self.PictureTiling

    @picture_tiling.setter
    def picture_tiling(self, value):
        """Alias for PictureTiling.setter"""
        self.PictureTiling = value

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def RightPadding(self):
        return self.com_object.RightPadding

    @RightPadding.setter
    def RightPadding(self, value):
        self.com_object.RightPadding = value

    @property
    def rightpadding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @rightpadding.setter
    def rightpadding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def right_padding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @right_padding.setter
    def right_padding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def Section(self):
        return self.com_object.Section

    @Section.setter
    def Section(self, value):
        self.com_object.Section = value

    @property
    def section(self):
        """Alias for Section"""
        return self.Section

    @section.setter
    def section(self, value):
        """Alias for Section.setter"""
        self.Section = value

    @property
    def ShortcutMenuBar(self):
        return self.com_object.ShortcutMenuBar

    @ShortcutMenuBar.setter
    def ShortcutMenuBar(self, value):
        self.com_object.ShortcutMenuBar = value

    @property
    def shortcutmenubar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcutmenubar.setter
    def shortcutmenubar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def shortcut_menu_bar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcut_menu_bar.setter
    def shortcut_menu_bar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def SpecialEffect(self):
        return self.com_object.SpecialEffect

    @SpecialEffect.setter
    def SpecialEffect(self, value):
        self.com_object.SpecialEffect = value

    @property
    def specialeffect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @specialeffect.setter
    def specialeffect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def special_effect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @special_effect.setter
    def special_effect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def StatusBarText(self):
        return self.com_object.StatusBarText

    @StatusBarText.setter
    def StatusBarText(self, value):
        self.com_object.StatusBarText = value

    @property
    def statusbartext(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @statusbartext.setter
    def statusbartext(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def status_bar_text(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @status_bar_text.setter
    def status_bar_text(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def TabIndex(self):
        return self.com_object.TabIndex

    @TabIndex.setter
    def TabIndex(self, value):
        self.com_object.TabIndex = value

    @property
    def tabindex(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tabindex.setter
    def tabindex(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def tab_index(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tab_index.setter
    def tab_index(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def TabStop(self):
        return self.com_object.TabStop

    @TabStop.setter
    def TabStop(self, value):
        self.com_object.TabStop = value

    @property
    def tabstop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tabstop.setter
    def tabstop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def tab_stop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tab_stop.setter
    def tab_stop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TopPadding(self):
        return self.com_object.TopPadding

    @TopPadding.setter
    def TopPadding(self, value):
        self.com_object.TopPadding = value

    @property
    def toppadding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @toppadding.setter
    def toppadding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def top_padding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @top_padding.setter
    def top_padding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Back(self):
        self.com_object.Back()

    def back(self):
        """Alias for Back"""
        return self.Back()

    def Forward(self):
        self.com_object.Forward()

    def forward(self):
        """Alias for Forward"""
        return self.Forward()

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def Requery(self):
        self.com_object.Requery()

    def requery(self):
        """Alias for Requery"""
        return self.Requery()

    def SetFocus(self):
        self.com_object.SetFocus()

    def setfocus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def set_focus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()


class AutoCorrect:

    def __init__(self, autocorrect=None):
        self.com_object= autocorrect

    @property
    def DisplayAutoCorrectOptions(self):
        return self.com_object.DisplayAutoCorrectOptions

    @DisplayAutoCorrectOptions.setter
    def DisplayAutoCorrectOptions(self, value):
        self.com_object.DisplayAutoCorrectOptions = value

    @property
    def displayautocorrectoptions(self):
        """Alias for DisplayAutoCorrectOptions"""
        return self.DisplayAutoCorrectOptions

    @displayautocorrectoptions.setter
    def displayautocorrectoptions(self, value):
        """Alias for DisplayAutoCorrectOptions.setter"""
        self.DisplayAutoCorrectOptions = value

    @property
    def display_auto_correct_options(self):
        """Alias for DisplayAutoCorrectOptions"""
        return self.DisplayAutoCorrectOptions

    @display_auto_correct_options.setter
    def display_auto_correct_options(self, value):
        """Alias for DisplayAutoCorrectOptions.setter"""
        self.DisplayAutoCorrectOptions = value


class BoundObjectFrame:

    def __init__(self, boundobjectframe=None):
        self.com_object= boundobjectframe

    @property
    def Action(self):
        return self.com_object.Action

    @Action.setter
    def Action(self, value):
        self.com_object.Action = value

    @property
    def action(self):
        """Alias for Action"""
        return self.Action

    @action.setter
    def action(self, value):
        """Alias for Action.setter"""
        self.Action = value

    @property
    def AddColon(self):
        return self.com_object.AddColon

    @AddColon.setter
    def AddColon(self, value):
        self.com_object.AddColon = value

    @property
    def addcolon(self):
        """Alias for AddColon"""
        return self.AddColon

    @addcolon.setter
    def addcolon(self, value):
        """Alias for AddColon.setter"""
        self.AddColon = value

    @property
    def add_colon(self):
        """Alias for AddColon"""
        return self.AddColon

    @add_colon.setter
    def add_colon(self, value):
        """Alias for AddColon.setter"""
        self.AddColon = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoActivate(self):
        return self.com_object.AutoActivate

    @AutoActivate.setter
    def AutoActivate(self, value):
        self.com_object.AutoActivate = value

    @property
    def autoactivate(self):
        """Alias for AutoActivate"""
        return self.AutoActivate

    @autoactivate.setter
    def autoactivate(self, value):
        """Alias for AutoActivate.setter"""
        self.AutoActivate = value

    @property
    def auto_activate(self):
        """Alias for AutoActivate"""
        return self.AutoActivate

    @auto_activate.setter
    def auto_activate(self, value):
        """Alias for AutoActivate.setter"""
        self.AutoActivate = value

    @property
    def AutoLabel(self):
        return self.com_object.AutoLabel

    @AutoLabel.setter
    def AutoLabel(self, value):
        self.com_object.AutoLabel = value

    @property
    def autolabel(self):
        """Alias for AutoLabel"""
        return self.AutoLabel

    @autolabel.setter
    def autolabel(self, value):
        """Alias for AutoLabel.setter"""
        self.AutoLabel = value

    @property
    def auto_label(self):
        """Alias for AutoLabel"""
        return self.AutoLabel

    @auto_label.setter
    def auto_label(self, value):
        """Alias for AutoLabel.setter"""
        self.AutoLabel = value

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BackShade(self):
        return self.com_object.BackShade

    @BackShade.setter
    def BackShade(self, value):
        self.com_object.BackShade = value

    @property
    def backshade(self):
        """Alias for BackShade"""
        return self.BackShade

    @backshade.setter
    def backshade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def back_shade(self):
        """Alias for BackShade"""
        return self.BackShade

    @back_shade.setter
    def back_shade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def BackStyle(self):
        return self.com_object.BackStyle

    @BackStyle.setter
    def BackStyle(self, value):
        self.com_object.BackStyle = value

    @property
    def backstyle(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @backstyle.setter
    def backstyle(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def back_style(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @back_style.setter
    def back_style(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def BackThemeColorIndex(self):
        return self.com_object.BackThemeColorIndex

    @BackThemeColorIndex.setter
    def BackThemeColorIndex(self, value):
        self.com_object.BackThemeColorIndex = value

    @property
    def backthemecolorindex(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @backthemecolorindex.setter
    def backthemecolorindex(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def back_theme_color_index(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @back_theme_color_index.setter
    def back_theme_color_index(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def BackTint(self):
        return self.com_object.BackTint

    @BackTint.setter
    def BackTint(self, value):
        self.com_object.BackTint = value

    @property
    def backtint(self):
        """Alias for BackTint"""
        return self.BackTint

    @backtint.setter
    def backtint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def back_tint(self):
        """Alias for BackTint"""
        return self.BackTint

    @back_tint.setter
    def back_tint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def BorderColor(self):
        return self.com_object.BorderColor

    @BorderColor.setter
    def BorderColor(self, value):
        self.com_object.BorderColor = value

    @property
    def bordercolor(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @bordercolor.setter
    def bordercolor(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def border_color(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @border_color.setter
    def border_color(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def BorderShade(self):
        return self.com_object.BorderShade

    @BorderShade.setter
    def BorderShade(self, value):
        self.com_object.BorderShade = value

    @property
    def bordershade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @bordershade.setter
    def bordershade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def border_shade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @border_shade.setter
    def border_shade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def BorderStyle(self):
        return self.com_object.BorderStyle

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def BorderThemeColorIndex(self):
        return self.com_object.BorderThemeColorIndex

    @BorderThemeColorIndex.setter
    def BorderThemeColorIndex(self, value):
        self.com_object.BorderThemeColorIndex = value

    @property
    def borderthemecolorindex(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @borderthemecolorindex.setter
    def borderthemecolorindex(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def border_theme_color_index(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @border_theme_color_index.setter
    def border_theme_color_index(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def BorderTint(self):
        return self.com_object.BorderTint

    @BorderTint.setter
    def BorderTint(self, value):
        self.com_object.BorderTint = value

    @property
    def bordertint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @bordertint.setter
    def bordertint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def border_tint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @border_tint.setter
    def border_tint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def BorderWidth(self):
        return self.com_object.BorderWidth

    @BorderWidth.setter
    def BorderWidth(self, value):
        self.com_object.BorderWidth = value

    @property
    def borderwidth(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @borderwidth.setter
    def borderwidth(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def border_width(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @border_width.setter
    def border_width(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def BottomPadding(self):
        return self.com_object.BottomPadding

    @BottomPadding.setter
    def BottomPadding(self, value):
        self.com_object.BottomPadding = value

    @property
    def bottompadding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottompadding.setter
    def bottompadding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def bottom_padding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottom_padding.setter
    def bottom_padding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def Class(self):
        return self.com_object.Class

    @Class.setter
    def Class(self, value):
        self.com_object.Class = value

    @property
    def ColumnHidden(self):
        return self.com_object.ColumnHidden

    @ColumnHidden.setter
    def ColumnHidden(self, value):
        self.com_object.ColumnHidden = value

    @property
    def columnhidden(self):
        """Alias for ColumnHidden"""
        return self.ColumnHidden

    @columnhidden.setter
    def columnhidden(self, value):
        """Alias for ColumnHidden.setter"""
        self.ColumnHidden = value

    @property
    def column_hidden(self):
        """Alias for ColumnHidden"""
        return self.ColumnHidden

    @column_hidden.setter
    def column_hidden(self, value):
        """Alias for ColumnHidden.setter"""
        self.ColumnHidden = value

    @property
    def ColumnOrder(self):
        return self.com_object.ColumnOrder

    @ColumnOrder.setter
    def ColumnOrder(self, value):
        self.com_object.ColumnOrder = value

    @property
    def columnorder(self):
        """Alias for ColumnOrder"""
        return self.ColumnOrder

    @columnorder.setter
    def columnorder(self, value):
        """Alias for ColumnOrder.setter"""
        self.ColumnOrder = value

    @property
    def column_order(self):
        """Alias for ColumnOrder"""
        return self.ColumnOrder

    @column_order.setter
    def column_order(self, value):
        """Alias for ColumnOrder.setter"""
        self.ColumnOrder = value

    @property
    def ColumnWidth(self):
        return self.com_object.ColumnWidth

    @ColumnWidth.setter
    def ColumnWidth(self, value):
        self.com_object.ColumnWidth = value

    @property
    def columnwidth(self):
        """Alias for ColumnWidth"""
        return self.ColumnWidth

    @columnwidth.setter
    def columnwidth(self, value):
        """Alias for ColumnWidth.setter"""
        self.ColumnWidth = value

    @property
    def column_width(self):
        """Alias for ColumnWidth"""
        return self.ColumnWidth

    @column_width.setter
    def column_width(self, value):
        """Alias for ColumnWidth.setter"""
        self.ColumnWidth = value

    @property
    def Controls(self):
        return Controls(self.com_object.Controls)

    @property
    def controls(self):
        """Alias for Controls"""
        return self.Controls

    @property
    def ControlSource(self):
        return self.com_object.ControlSource

    @ControlSource.setter
    def ControlSource(self, value):
        self.com_object.ControlSource = value

    @property
    def controlsource(self):
        """Alias for ControlSource"""
        return self.ControlSource

    @controlsource.setter
    def controlsource(self, value):
        """Alias for ControlSource.setter"""
        self.ControlSource = value

    @property
    def control_source(self):
        """Alias for ControlSource"""
        return self.ControlSource

    @control_source.setter
    def control_source(self, value):
        """Alias for ControlSource.setter"""
        self.ControlSource = value

    @property
    def ControlTipText(self):
        return self.com_object.ControlTipText

    @ControlTipText.setter
    def ControlTipText(self, value):
        self.com_object.ControlTipText = value

    @property
    def controltiptext(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @controltiptext.setter
    def controltiptext(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def control_tip_text(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @control_tip_text.setter
    def control_tip_text(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def ControlType(self):
        return self.com_object.ControlType

    @ControlType.setter
    def ControlType(self, value):
        self.com_object.ControlType = value

    @property
    def controltype(self):
        """Alias for ControlType"""
        return self.ControlType

    @controltype.setter
    def controltype(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def control_type(self):
        """Alias for ControlType"""
        return self.ControlType

    @control_type.setter
    def control_type(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def DisplayType(self):
        return self.com_object.DisplayType

    @DisplayType.setter
    def DisplayType(self, value):
        self.com_object.DisplayType = value

    @property
    def displaytype(self):
        """Alias for DisplayType"""
        return self.DisplayType

    @displaytype.setter
    def displaytype(self, value):
        """Alias for DisplayType.setter"""
        self.DisplayType = value

    @property
    def display_type(self):
        """Alias for DisplayType"""
        return self.DisplayType

    @display_type.setter
    def display_type(self, value):
        """Alias for DisplayType.setter"""
        self.DisplayType = value

    @property
    def DisplayWhen(self):
        return self.com_object.DisplayWhen

    @DisplayWhen.setter
    def DisplayWhen(self, value):
        self.com_object.DisplayWhen = value

    @property
    def displaywhen(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @displaywhen.setter
    def displaywhen(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def display_when(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @display_when.setter
    def display_when(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def GridlineColor(self):
        return self.com_object.GridlineColor

    @GridlineColor.setter
    def GridlineColor(self, value):
        self.com_object.GridlineColor = value

    @property
    def gridlinecolor(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridlinecolor.setter
    def gridlinecolor(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def gridline_color(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridline_color.setter
    def gridline_color(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def GridlineShade(self):
        return self.com_object.GridlineShade

    @GridlineShade.setter
    def GridlineShade(self, value):
        self.com_object.GridlineShade = value

    @property
    def gridlineshade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridlineshade.setter
    def gridlineshade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def gridline_shade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridline_shade.setter
    def gridline_shade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def GridlineStyleBottom(self):
        return self.com_object.GridlineStyleBottom

    @GridlineStyleBottom.setter
    def GridlineStyleBottom(self, value):
        self.com_object.GridlineStyleBottom = value

    @property
    def gridlinestylebottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridlinestylebottom.setter
    def gridlinestylebottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def gridline_style_bottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridline_style_bottom.setter
    def gridline_style_bottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def GridlineStyleLeft(self):
        return self.com_object.GridlineStyleLeft

    @GridlineStyleLeft.setter
    def GridlineStyleLeft(self, value):
        self.com_object.GridlineStyleLeft = value

    @property
    def gridlinestyleleft(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridlinestyleleft.setter
    def gridlinestyleleft(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def gridline_style_left(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridline_style_left.setter
    def gridline_style_left(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def GridlineStyleRight(self):
        return self.com_object.GridlineStyleRight

    @GridlineStyleRight.setter
    def GridlineStyleRight(self, value):
        self.com_object.GridlineStyleRight = value

    @property
    def gridlinestyleright(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridlinestyleright.setter
    def gridlinestyleright(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def gridline_style_right(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridline_style_right.setter
    def gridline_style_right(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def GridlineStyleTop(self):
        return self.com_object.GridlineStyleTop

    @GridlineStyleTop.setter
    def GridlineStyleTop(self, value):
        self.com_object.GridlineStyleTop = value

    @property
    def gridlinestyletop(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridlinestyletop.setter
    def gridlinestyletop(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def gridline_style_top(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridline_style_top.setter
    def gridline_style_top(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def GridlineThemeColorIndex(self):
        return self.com_object.GridlineThemeColorIndex

    @GridlineThemeColorIndex.setter
    def GridlineThemeColorIndex(self, value):
        self.com_object.GridlineThemeColorIndex = value

    @property
    def gridlinethemecolorindex(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridlinethemecolorindex.setter
    def gridlinethemecolorindex(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def gridline_theme_color_index(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridline_theme_color_index.setter
    def gridline_theme_color_index(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def GridlineTint(self):
        return self.com_object.GridlineTint

    @GridlineTint.setter
    def GridlineTint(self, value):
        self.com_object.GridlineTint = value

    @property
    def gridlinetint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridlinetint.setter
    def gridlinetint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def gridline_tint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridline_tint.setter
    def gridline_tint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def GridlineWidthBottom(self):
        return self.com_object.GridlineWidthBottom

    @GridlineWidthBottom.setter
    def GridlineWidthBottom(self, value):
        self.com_object.GridlineWidthBottom = value

    @property
    def gridlinewidthbottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridlinewidthbottom.setter
    def gridlinewidthbottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def gridline_width_bottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridline_width_bottom.setter
    def gridline_width_bottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def GridlineWidthLeft(self):
        return self.com_object.GridlineWidthLeft

    @GridlineWidthLeft.setter
    def GridlineWidthLeft(self, value):
        self.com_object.GridlineWidthLeft = value

    @property
    def gridlinewidthleft(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridlinewidthleft.setter
    def gridlinewidthleft(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def gridline_width_left(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridline_width_left.setter
    def gridline_width_left(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def GridlineWidthRight(self):
        return self.com_object.GridlineWidthRight

    @GridlineWidthRight.setter
    def GridlineWidthRight(self, value):
        self.com_object.GridlineWidthRight = value

    @property
    def gridlinewidthright(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridlinewidthright.setter
    def gridlinewidthright(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def gridline_width_right(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridline_width_right.setter
    def gridline_width_right(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def GridlineWidthTop(self):
        return self.com_object.GridlineWidthTop

    @GridlineWidthTop.setter
    def GridlineWidthTop(self, value):
        self.com_object.GridlineWidthTop = value

    @property
    def gridlinewidthtop(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridlinewidthtop.setter
    def gridlinewidthtop(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def gridline_width_top(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridline_width_top.setter
    def gridline_width_top(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HelpContextId(self):
        return self.com_object.HelpContextId

    @HelpContextId.setter
    def HelpContextId(self, value):
        self.com_object.HelpContextId = value

    @property
    def helpcontextid(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @helpcontextid.setter
    def helpcontextid(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def help_context_id(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @help_context_id.setter
    def help_context_id(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def IsVisible(self):
        return self.com_object.IsVisible

    @IsVisible.setter
    def IsVisible(self, value):
        self.com_object.IsVisible = value

    @property
    def isvisible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @isvisible.setter
    def isvisible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def is_visible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @is_visible.setter
    def is_visible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def LabelAlign(self):
        return self.com_object.LabelAlign

    @LabelAlign.setter
    def LabelAlign(self, value):
        self.com_object.LabelAlign = value

    @property
    def labelalign(self):
        """Alias for LabelAlign"""
        return self.LabelAlign

    @labelalign.setter
    def labelalign(self, value):
        """Alias for LabelAlign.setter"""
        self.LabelAlign = value

    @property
    def label_align(self):
        """Alias for LabelAlign"""
        return self.LabelAlign

    @label_align.setter
    def label_align(self, value):
        """Alias for LabelAlign.setter"""
        self.LabelAlign = value

    @property
    def LabelX(self):
        return self.com_object.LabelX

    @LabelX.setter
    def LabelX(self, value):
        self.com_object.LabelX = value

    @property
    def labelx(self):
        """Alias for LabelX"""
        return self.LabelX

    @labelx.setter
    def labelx(self, value):
        """Alias for LabelX.setter"""
        self.LabelX = value

    @property
    def label_x(self):
        """Alias for LabelX"""
        return self.LabelX

    @label_x.setter
    def label_x(self, value):
        """Alias for LabelX.setter"""
        self.LabelX = value

    @property
    def LabelY(self):
        return self.com_object.LabelY

    @LabelY.setter
    def LabelY(self, value):
        self.com_object.LabelY = value

    @property
    def labely(self):
        """Alias for LabelY"""
        return self.LabelY

    @labely.setter
    def labely(self, value):
        """Alias for LabelY.setter"""
        self.LabelY = value

    @property
    def label_y(self):
        """Alias for LabelY"""
        return self.LabelY

    @label_y.setter
    def label_y(self, value):
        """Alias for LabelY.setter"""
        self.LabelY = value

    @property
    def Layout(self):
        return AcLayoutType(self.com_object.Layout)

    @property
    def layout(self):
        """Alias for Layout"""
        return self.Layout

    @property
    def LayoutID(self):
        return self.com_object.LayoutID

    @property
    def layoutid(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def layout_i_d(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def LeftPadding(self):
        return self.com_object.LeftPadding

    @LeftPadding.setter
    def LeftPadding(self, value):
        self.com_object.LeftPadding = value

    @property
    def leftpadding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @leftpadding.setter
    def leftpadding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def left_padding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @left_padding.setter
    def left_padding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Object(self):
        return self.com_object.Object

    @property
    def object(self):
        """Alias for Object"""
        return self.Object

    @property
    def ObjectPalette(self):
        return self.com_object.ObjectPalette

    @ObjectPalette.setter
    def ObjectPalette(self, value):
        self.com_object.ObjectPalette = value

    @property
    def objectpalette(self):
        """Alias for ObjectPalette"""
        return self.ObjectPalette

    @objectpalette.setter
    def objectpalette(self, value):
        """Alias for ObjectPalette.setter"""
        self.ObjectPalette = value

    @property
    def object_palette(self):
        """Alias for ObjectPalette"""
        return self.ObjectPalette

    @object_palette.setter
    def object_palette(self, value):
        """Alias for ObjectPalette.setter"""
        self.ObjectPalette = value

    def ObjectVerbs(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetObjectVerbs"):
            return self.com_object.GetObjectVerbs(*arguments)
        else:
            return self.com_object.ObjectVerbs(*arguments)

    def objectverbs(self, Index=None):
        """Alias for ObjectVerbs"""
        arguments = [Index]
        return self.ObjectVerbs(*arguments)

    def object_verbs(self, Index=None):
        """Alias for ObjectVerbs"""
        arguments = [Index]
        return self.ObjectVerbs(*arguments)

    @property
    def ObjectVerbsCount(self):
        return self.com_object.ObjectVerbsCount

    @property
    def objectverbscount(self):
        """Alias for ObjectVerbsCount"""
        return self.ObjectVerbsCount

    @property
    def object_verbs_count(self):
        """Alias for ObjectVerbsCount"""
        return self.ObjectVerbsCount

    @property
    def OldBorderStyle(self):
        return self.com_object.OldBorderStyle

    @OldBorderStyle.setter
    def OldBorderStyle(self, value):
        self.com_object.OldBorderStyle = value

    @property
    def oldborderstyle(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @oldborderstyle.setter
    def oldborderstyle(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def old_border_style(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @old_border_style.setter
    def old_border_style(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def OldValue(self):
        return self.com_object.OldValue

    @property
    def oldvalue(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def old_value(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def OLEType(self):
        return self.com_object.OLEType

    @OLEType.setter
    def OLEType(self, value):
        self.com_object.OLEType = value

    @property
    def oletype(self):
        """Alias for OLEType"""
        return self.OLEType

    @oletype.setter
    def oletype(self, value):
        """Alias for OLEType.setter"""
        self.OLEType = value

    @property
    def o_l_e_type(self):
        """Alias for OLEType"""
        return self.OLEType

    @o_l_e_type.setter
    def o_l_e_type(self, value):
        """Alias for OLEType.setter"""
        self.OLEType = value

    @property
    def OLETypeAllowed(self):
        return self.com_object.OLETypeAllowed

    @OLETypeAllowed.setter
    def OLETypeAllowed(self, value):
        self.com_object.OLETypeAllowed = value

    @property
    def oletypeallowed(self):
        """Alias for OLETypeAllowed"""
        return self.OLETypeAllowed

    @oletypeallowed.setter
    def oletypeallowed(self, value):
        """Alias for OLETypeAllowed.setter"""
        self.OLETypeAllowed = value

    @property
    def o_l_e_type_allowed(self):
        """Alias for OLETypeAllowed"""
        return self.OLETypeAllowed

    @o_l_e_type_allowed.setter
    def o_l_e_type_allowed(self, value):
        """Alias for OLETypeAllowed.setter"""
        self.OLETypeAllowed = value

    @property
    def OnClick(self):
        return self.com_object.OnClick

    @OnClick.setter
    def OnClick(self, value):
        self.com_object.OnClick = value

    @property
    def onclick(self):
        """Alias for OnClick"""
        return self.OnClick

    @onclick.setter
    def onclick(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def on_click(self):
        """Alias for OnClick"""
        return self.OnClick

    @on_click.setter
    def on_click(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def OnDblClick(self):
        return self.com_object.OnDblClick

    @OnDblClick.setter
    def OnDblClick(self, value):
        self.com_object.OnDblClick = value

    @property
    def ondblclick(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @ondblclick.setter
    def ondblclick(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def on_dbl_click(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @on_dbl_click.setter
    def on_dbl_click(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def OnEnter(self):
        return self.com_object.OnEnter

    @OnEnter.setter
    def OnEnter(self, value):
        self.com_object.OnEnter = value

    @property
    def onenter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @onenter.setter
    def onenter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def on_enter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @on_enter.setter
    def on_enter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def OnExit(self):
        return self.com_object.OnExit

    @OnExit.setter
    def OnExit(self, value):
        self.com_object.OnExit = value

    @property
    def onexit(self):
        """Alias for OnExit"""
        return self.OnExit

    @onexit.setter
    def onexit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def on_exit(self):
        """Alias for OnExit"""
        return self.OnExit

    @on_exit.setter
    def on_exit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def OnGotFocus(self):
        return self.com_object.OnGotFocus

    @OnGotFocus.setter
    def OnGotFocus(self, value):
        self.com_object.OnGotFocus = value

    @property
    def ongotfocus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @ongotfocus.setter
    def ongotfocus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def on_got_focus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @on_got_focus.setter
    def on_got_focus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def OnKeyDown(self):
        return self.com_object.OnKeyDown

    @OnKeyDown.setter
    def OnKeyDown(self, value):
        self.com_object.OnKeyDown = value

    @property
    def onkeydown(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @onkeydown.setter
    def onkeydown(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def on_key_down(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @on_key_down.setter
    def on_key_down(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def OnKeyPress(self):
        return self.com_object.OnKeyPress

    @OnKeyPress.setter
    def OnKeyPress(self, value):
        self.com_object.OnKeyPress = value

    @property
    def onkeypress(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @onkeypress.setter
    def onkeypress(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def on_key_press(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @on_key_press.setter
    def on_key_press(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def OnKeyUp(self):
        return self.com_object.OnKeyUp

    @OnKeyUp.setter
    def OnKeyUp(self, value):
        self.com_object.OnKeyUp = value

    @property
    def onkeyup(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @onkeyup.setter
    def onkeyup(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def on_key_up(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @on_key_up.setter
    def on_key_up(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def OnLostFocus(self):
        return self.com_object.OnLostFocus

    @OnLostFocus.setter
    def OnLostFocus(self, value):
        self.com_object.OnLostFocus = value

    @property
    def onlostfocus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @onlostfocus.setter
    def onlostfocus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def on_lost_focus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @on_lost_focus.setter
    def on_lost_focus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def OnMouseDown(self):
        return self.com_object.OnMouseDown

    @OnMouseDown.setter
    def OnMouseDown(self, value):
        self.com_object.OnMouseDown = value

    @property
    def onmousedown(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @onmousedown.setter
    def onmousedown(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def on_mouse_down(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @on_mouse_down.setter
    def on_mouse_down(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def OnMouseMove(self):
        return self.com_object.OnMouseMove

    @OnMouseMove.setter
    def OnMouseMove(self, value):
        self.com_object.OnMouseMove = value

    @property
    def onmousemove(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @onmousemove.setter
    def onmousemove(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def on_mouse_move(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @on_mouse_move.setter
    def on_mouse_move(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def OnMouseUp(self):
        return self.com_object.OnMouseUp

    @OnMouseUp.setter
    def OnMouseUp(self, value):
        self.com_object.OnMouseUp = value

    @property
    def onmouseup(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @onmouseup.setter
    def onmouseup(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def on_mouse_up(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @on_mouse_up.setter
    def on_mouse_up(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def OnUpdated(self):
        return self.com_object.OnUpdated

    @OnUpdated.setter
    def OnUpdated(self, value):
        self.com_object.OnUpdated = value

    @property
    def onupdated(self):
        """Alias for OnUpdated"""
        return self.OnUpdated

    @onupdated.setter
    def onupdated(self, value):
        """Alias for OnUpdated.setter"""
        self.OnUpdated = value

    @property
    def on_updated(self):
        """Alias for OnUpdated"""
        return self.OnUpdated

    @on_updated.setter
    def on_updated(self, value):
        """Alias for OnUpdated.setter"""
        self.OnUpdated = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def RightPadding(self):
        return self.com_object.RightPadding

    @RightPadding.setter
    def RightPadding(self, value):
        self.com_object.RightPadding = value

    @property
    def rightpadding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @rightpadding.setter
    def rightpadding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def right_padding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @right_padding.setter
    def right_padding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def Scaling(self):
        return self.com_object.Scaling

    @Scaling.setter
    def Scaling(self, value):
        self.com_object.Scaling = value

    @property
    def scaling(self):
        """Alias for Scaling"""
        return self.Scaling

    @scaling.setter
    def scaling(self, value):
        """Alias for Scaling.setter"""
        self.Scaling = value

    @property
    def Section(self):
        return self.com_object.Section

    @Section.setter
    def Section(self, value):
        self.com_object.Section = value

    @property
    def section(self):
        """Alias for Section"""
        return self.Section

    @section.setter
    def section(self, value):
        """Alias for Section.setter"""
        self.Section = value

    @property
    def ShortcutMenuBar(self):
        return self.com_object.ShortcutMenuBar

    @ShortcutMenuBar.setter
    def ShortcutMenuBar(self, value):
        self.com_object.ShortcutMenuBar = value

    @property
    def shortcutmenubar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcutmenubar.setter
    def shortcutmenubar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def shortcut_menu_bar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcut_menu_bar.setter
    def shortcut_menu_bar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def SizeMode(self):
        return self.com_object.SizeMode

    @property
    def sizemode(self):
        """Alias for SizeMode"""
        return self.SizeMode

    @property
    def size_mode(self):
        """Alias for SizeMode"""
        return self.SizeMode

    @property
    def SourceDoc(self):
        return self.com_object.SourceDoc

    @SourceDoc.setter
    def SourceDoc(self, value):
        self.com_object.SourceDoc = value

    @property
    def sourcedoc(self):
        """Alias for SourceDoc"""
        return self.SourceDoc

    @sourcedoc.setter
    def sourcedoc(self, value):
        """Alias for SourceDoc.setter"""
        self.SourceDoc = value

    @property
    def source_doc(self):
        """Alias for SourceDoc"""
        return self.SourceDoc

    @source_doc.setter
    def source_doc(self, value):
        """Alias for SourceDoc.setter"""
        self.SourceDoc = value

    @property
    def SourceItem(self):
        return self.com_object.SourceItem

    @SourceItem.setter
    def SourceItem(self, value):
        self.com_object.SourceItem = value

    @property
    def sourceitem(self):
        """Alias for SourceItem"""
        return self.SourceItem

    @sourceitem.setter
    def sourceitem(self, value):
        """Alias for SourceItem.setter"""
        self.SourceItem = value

    @property
    def source_item(self):
        """Alias for SourceItem"""
        return self.SourceItem

    @source_item.setter
    def source_item(self, value):
        """Alias for SourceItem.setter"""
        self.SourceItem = value

    @property
    def SpecialEffect(self):
        return self.com_object.SpecialEffect

    @SpecialEffect.setter
    def SpecialEffect(self, value):
        self.com_object.SpecialEffect = value

    @property
    def specialeffect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @specialeffect.setter
    def specialeffect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def special_effect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @special_effect.setter
    def special_effect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def StatusBarText(self):
        return self.com_object.StatusBarText

    @StatusBarText.setter
    def StatusBarText(self, value):
        self.com_object.StatusBarText = value

    @property
    def statusbartext(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @statusbartext.setter
    def statusbartext(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def status_bar_text(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @status_bar_text.setter
    def status_bar_text(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def TabIndex(self):
        return self.com_object.TabIndex

    @TabIndex.setter
    def TabIndex(self, value):
        self.com_object.TabIndex = value

    @property
    def tabindex(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tabindex.setter
    def tabindex(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def tab_index(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tab_index.setter
    def tab_index(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def TabStop(self):
        return self.com_object.TabStop

    @TabStop.setter
    def TabStop(self, value):
        self.com_object.TabStop = value

    @property
    def tabstop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tabstop.setter
    def tabstop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def tab_stop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tab_stop.setter
    def tab_stop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TopPadding(self):
        return self.com_object.TopPadding

    @TopPadding.setter
    def TopPadding(self, value):
        self.com_object.TopPadding = value

    @property
    def toppadding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @toppadding.setter
    def toppadding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def top_padding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @top_padding.setter
    def top_padding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def UpdateOptions(self):
        return self.com_object.UpdateOptions

    @UpdateOptions.setter
    def UpdateOptions(self, value):
        self.com_object.UpdateOptions = value

    @property
    def updateoptions(self):
        """Alias for UpdateOptions"""
        return self.UpdateOptions

    @updateoptions.setter
    def updateoptions(self, value):
        """Alias for UpdateOptions.setter"""
        self.UpdateOptions = value

    @property
    def update_options(self):
        """Alias for UpdateOptions"""
        return self.UpdateOptions

    @update_options.setter
    def update_options(self, value):
        """Alias for UpdateOptions.setter"""
        self.UpdateOptions = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    @property
    def VarOleObject(self):
        return self.com_object.VarOleObject

    @property
    def varoleobject(self):
        """Alias for VarOleObject"""
        return self.VarOleObject

    @property
    def var_ole_object(self):
        """Alias for VarOleObject"""
        return self.VarOleObject

    @property
    def Verb(self):
        return self.com_object.Verb

    @Verb.setter
    def Verb(self, value):
        self.com_object.Verb = value

    @property
    def verb(self):
        """Alias for Verb"""
        return self.Verb

    @verb.setter
    def verb(self, value):
        """Alias for Verb.setter"""
        self.Verb = value

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def Requery(self):
        self.com_object.Requery()

    def requery(self):
        """Alias for Requery"""
        return self.Requery()

    def SetFocus(self):
        return self.com_object.SetFocus()

    def setfocus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def set_focus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()


class Chart:

    def __init__(self, chart=None):
        self.com_object= chart

    @property
    def CategoryAxisFontColor(self):
        return self.com_object.CategoryAxisFontColor

    @CategoryAxisFontColor.setter
    def CategoryAxisFontColor(self, value):
        self.com_object.CategoryAxisFontColor = value

    @property
    def categoryaxisfontcolor(self):
        """Alias for CategoryAxisFontColor"""
        return self.CategoryAxisFontColor

    @categoryaxisfontcolor.setter
    def categoryaxisfontcolor(self, value):
        """Alias for CategoryAxisFontColor.setter"""
        self.CategoryAxisFontColor = value

    @property
    def category_axis_font_color(self):
        """Alias for CategoryAxisFontColor"""
        return self.CategoryAxisFontColor

    @category_axis_font_color.setter
    def category_axis_font_color(self, value):
        """Alias for CategoryAxisFontColor.setter"""
        self.CategoryAxisFontColor = value

    @property
    def CategoryAxisFontSize(self):
        return self.com_object.CategoryAxisFontSize

    @CategoryAxisFontSize.setter
    def CategoryAxisFontSize(self, value):
        self.com_object.CategoryAxisFontSize = value

    @property
    def categoryaxisfontsize(self):
        """Alias for CategoryAxisFontSize"""
        return self.CategoryAxisFontSize

    @categoryaxisfontsize.setter
    def categoryaxisfontsize(self, value):
        """Alias for CategoryAxisFontSize.setter"""
        self.CategoryAxisFontSize = value

    @property
    def category_axis_font_size(self):
        """Alias for CategoryAxisFontSize"""
        return self.CategoryAxisFontSize

    @category_axis_font_size.setter
    def category_axis_font_size(self, value):
        """Alias for CategoryAxisFontSize.setter"""
        self.CategoryAxisFontSize = value

    @property
    def CategoryAxisTitle(self):
        return self.com_object.CategoryAxisTitle

    @CategoryAxisTitle.setter
    def CategoryAxisTitle(self, value):
        self.com_object.CategoryAxisTitle = value

    @property
    def categoryaxistitle(self):
        """Alias for CategoryAxisTitle"""
        return self.CategoryAxisTitle

    @categoryaxistitle.setter
    def categoryaxistitle(self, value):
        """Alias for CategoryAxisTitle.setter"""
        self.CategoryAxisTitle = value

    @property
    def category_axis_title(self):
        """Alias for CategoryAxisTitle"""
        return self.CategoryAxisTitle

    @category_axis_title.setter
    def category_axis_title(self, value):
        """Alias for CategoryAxisTitle.setter"""
        self.CategoryAxisTitle = value

    @property
    def ChartAxis(self):
        return self.com_object.ChartAxis

    @ChartAxis.setter
    def ChartAxis(self, value):
        self.com_object.ChartAxis = value

    @property
    def chartaxis(self):
        """Alias for ChartAxis"""
        return self.ChartAxis

    @chartaxis.setter
    def chartaxis(self, value):
        """Alias for ChartAxis.setter"""
        self.ChartAxis = value

    @property
    def chart_axis(self):
        """Alias for ChartAxis"""
        return self.ChartAxis

    @chart_axis.setter
    def chart_axis(self, value):
        """Alias for ChartAxis.setter"""
        self.ChartAxis = value

    @property
    def ChartAxisCollection(self):
        return self.com_object.ChartAxisCollection

    @property
    def chartaxiscollection(self):
        """Alias for ChartAxisCollection"""
        return self.ChartAxisCollection

    @property
    def chart_axis_collection(self):
        """Alias for ChartAxisCollection"""
        return self.ChartAxisCollection

    @property
    def ChartLegend(self):
        return self.com_object.ChartLegend

    @ChartLegend.setter
    def ChartLegend(self, value):
        self.com_object.ChartLegend = value

    @property
    def chartlegend(self):
        """Alias for ChartLegend"""
        return self.ChartLegend

    @chartlegend.setter
    def chartlegend(self, value):
        """Alias for ChartLegend.setter"""
        self.ChartLegend = value

    @property
    def chart_legend(self):
        """Alias for ChartLegend"""
        return self.ChartLegend

    @chart_legend.setter
    def chart_legend(self, value):
        """Alias for ChartLegend.setter"""
        self.ChartLegend = value

    @property
    def ChartSeriesCollection(self):
        return self.com_object.ChartSeriesCollection

    @property
    def chartseriescollection(self):
        """Alias for ChartSeriesCollection"""
        return self.ChartSeriesCollection

    @property
    def chart_series_collection(self):
        """Alias for ChartSeriesCollection"""
        return self.ChartSeriesCollection

    @property
    def ChartSubtitle(self):
        return self.com_object.ChartSubtitle

    @ChartSubtitle.setter
    def ChartSubtitle(self, value):
        self.com_object.ChartSubtitle = value

    @property
    def chartsubtitle(self):
        """Alias for ChartSubtitle"""
        return self.ChartSubtitle

    @chartsubtitle.setter
    def chartsubtitle(self, value):
        """Alias for ChartSubtitle.setter"""
        self.ChartSubtitle = value

    @property
    def chart_subtitle(self):
        """Alias for ChartSubtitle"""
        return self.ChartSubtitle

    @chart_subtitle.setter
    def chart_subtitle(self, value):
        """Alias for ChartSubtitle.setter"""
        self.ChartSubtitle = value

    @property
    def ChartSubtitleFontColor(self):
        return self.com_object.ChartSubtitleFontColor

    @ChartSubtitleFontColor.setter
    def ChartSubtitleFontColor(self, value):
        self.com_object.ChartSubtitleFontColor = value

    @property
    def chartsubtitlefontcolor(self):
        """Alias for ChartSubtitleFontColor"""
        return self.ChartSubtitleFontColor

    @chartsubtitlefontcolor.setter
    def chartsubtitlefontcolor(self, value):
        """Alias for ChartSubtitleFontColor.setter"""
        self.ChartSubtitleFontColor = value

    @property
    def chart_subtitle_font_color(self):
        """Alias for ChartSubtitleFontColor"""
        return self.ChartSubtitleFontColor

    @chart_subtitle_font_color.setter
    def chart_subtitle_font_color(self, value):
        """Alias for ChartSubtitleFontColor.setter"""
        self.ChartSubtitleFontColor = value

    @property
    def ChartSubtitleFontSize(self):
        return self.com_object.ChartSubtitleFontSize

    @ChartSubtitleFontSize.setter
    def ChartSubtitleFontSize(self, value):
        self.com_object.ChartSubtitleFontSize = value

    @property
    def chartsubtitlefontsize(self):
        """Alias for ChartSubtitleFontSize"""
        return self.ChartSubtitleFontSize

    @chartsubtitlefontsize.setter
    def chartsubtitlefontsize(self, value):
        """Alias for ChartSubtitleFontSize.setter"""
        self.ChartSubtitleFontSize = value

    @property
    def chart_subtitle_font_size(self):
        """Alias for ChartSubtitleFontSize"""
        return self.ChartSubtitleFontSize

    @chart_subtitle_font_size.setter
    def chart_subtitle_font_size(self, value):
        """Alias for ChartSubtitleFontSize.setter"""
        self.ChartSubtitleFontSize = value

    @property
    def Title(self):
        return self.com_object.Title

    @Title.setter
    def Title(self, value):
        self.com_object.Title = value

    @property
    def title(self):
        """Alias for Title"""
        return self.Title

    @title.setter
    def title(self, value):
        """Alias for Title.setter"""
        self.Title = value

    @property
    def ChartTitleFontColor(self):
        return self.com_object.ChartTitleFontColor

    @ChartTitleFontColor.setter
    def ChartTitleFontColor(self, value):
        self.com_object.ChartTitleFontColor = value

    @property
    def charttitlefontcolor(self):
        """Alias for ChartTitleFontColor"""
        return self.ChartTitleFontColor

    @charttitlefontcolor.setter
    def charttitlefontcolor(self, value):
        """Alias for ChartTitleFontColor.setter"""
        self.ChartTitleFontColor = value

    @property
    def chart_title_font_color(self):
        """Alias for ChartTitleFontColor"""
        return self.ChartTitleFontColor

    @chart_title_font_color.setter
    def chart_title_font_color(self, value):
        """Alias for ChartTitleFontColor.setter"""
        self.ChartTitleFontColor = value

    @property
    def ChartTitleFontName(self):
        return self.com_object.ChartTitleFontName

    @ChartTitleFontName.setter
    def ChartTitleFontName(self, value):
        self.com_object.ChartTitleFontName = value

    @property
    def charttitlefontname(self):
        """Alias for ChartTitleFontName"""
        return self.ChartTitleFontName

    @charttitlefontname.setter
    def charttitlefontname(self, value):
        """Alias for ChartTitleFontName.setter"""
        self.ChartTitleFontName = value

    @property
    def chart_title_font_name(self):
        """Alias for ChartTitleFontName"""
        return self.ChartTitleFontName

    @chart_title_font_name.setter
    def chart_title_font_name(self, value):
        """Alias for ChartTitleFontName.setter"""
        self.ChartTitleFontName = value

    @property
    def ChartTitleFontSize(self):
        return self.com_object.ChartTitleFontSize

    @ChartTitleFontSize.setter
    def ChartTitleFontSize(self, value):
        self.com_object.ChartTitleFontSize = value

    @property
    def charttitlefontsize(self):
        """Alias for ChartTitleFontSize"""
        return self.ChartTitleFontSize

    @charttitlefontsize.setter
    def charttitlefontsize(self, value):
        """Alias for ChartTitleFontSize.setter"""
        self.ChartTitleFontSize = value

    @property
    def chart_title_font_size(self):
        """Alias for ChartTitleFontSize"""
        return self.ChartTitleFontSize

    @chart_title_font_size.setter
    def chart_title_font_size(self, value):
        """Alias for ChartTitleFontSize.setter"""
        self.ChartTitleFontSize = value

    @property
    def ChartType(self):
        return AcChartType(self.com_object.ChartType)

    @ChartType.setter
    def ChartType(self, value):
        self.com_object.ChartType = value

    @property
    def charttype(self):
        """Alias for ChartType"""
        return self.ChartType

    @charttype.setter
    def charttype(self, value):
        """Alias for ChartType.setter"""
        self.ChartType = value

    @property
    def chart_type(self):
        """Alias for ChartType"""
        return self.ChartType

    @chart_type.setter
    def chart_type(self, value):
        """Alias for ChartType.setter"""
        self.ChartType = value

    @property
    def ChartValues(self):
        return self.com_object.ChartValues

    @ChartValues.setter
    def ChartValues(self, value):
        self.com_object.ChartValues = value

    @property
    def chartvalues(self):
        """Alias for ChartValues"""
        return self.ChartValues

    @chartvalues.setter
    def chartvalues(self, value):
        """Alias for ChartValues.setter"""
        self.ChartValues = value

    @property
    def chart_values(self):
        """Alias for ChartValues"""
        return self.ChartValues

    @chart_values.setter
    def chart_values(self, value):
        """Alias for ChartValues.setter"""
        self.ChartValues = value

    @property
    def ChartValuesCollection(self):
        return self.com_object.ChartValuesCollection

    @property
    def chartvaluescollection(self):
        """Alias for ChartValuesCollection"""
        return self.ChartValuesCollection

    @property
    def chart_values_collection(self):
        """Alias for ChartValuesCollection"""
        return self.ChartValuesCollection

    @property
    def HasAxisTitles(self):
        return self.com_object.HasAxisTitles

    @HasAxisTitles.setter
    def HasAxisTitles(self, value):
        self.com_object.HasAxisTitles = value

    @property
    def hasaxistitles(self):
        """Alias for HasAxisTitles"""
        return self.HasAxisTitles

    @hasaxistitles.setter
    def hasaxistitles(self, value):
        """Alias for HasAxisTitles.setter"""
        self.HasAxisTitles = value

    @property
    def has_axis_titles(self):
        """Alias for HasAxisTitles"""
        return self.HasAxisTitles

    @has_axis_titles.setter
    def has_axis_titles(self, value):
        """Alias for HasAxisTitles.setter"""
        self.HasAxisTitles = value

    @property
    def HasLegend(self):
        return self.com_object.HasLegend

    @HasLegend.setter
    def HasLegend(self, value):
        self.com_object.HasLegend = value

    @property
    def haslegend(self):
        """Alias for HasLegend"""
        return self.HasLegend

    @haslegend.setter
    def haslegend(self, value):
        """Alias for HasLegend.setter"""
        self.HasLegend = value

    @property
    def has_legend(self):
        """Alias for HasLegend"""
        return self.HasLegend

    @has_legend.setter
    def has_legend(self, value):
        """Alias for HasLegend.setter"""
        self.HasLegend = value

    @property
    def HasSubtitle(self):
        return self.com_object.HasSubtitle

    @HasSubtitle.setter
    def HasSubtitle(self, value):
        self.com_object.HasSubtitle = value

    @property
    def hassubtitle(self):
        """Alias for HasSubtitle"""
        return self.HasSubtitle

    @hassubtitle.setter
    def hassubtitle(self, value):
        """Alias for HasSubtitle.setter"""
        self.HasSubtitle = value

    @property
    def has_subtitle(self):
        """Alias for HasSubtitle"""
        return self.HasSubtitle

    @has_subtitle.setter
    def has_subtitle(self, value):
        """Alias for HasSubtitle.setter"""
        self.HasSubtitle = value

    @property
    def HasTitle(self):
        return self.com_object.HasTitle

    @HasTitle.setter
    def HasTitle(self, value):
        self.com_object.HasTitle = value

    @property
    def hastitle(self):
        """Alias for HasTitle"""
        return self.HasTitle

    @hastitle.setter
    def hastitle(self, value):
        """Alias for HasTitle.setter"""
        self.HasTitle = value

    @property
    def has_title(self):
        """Alias for HasTitle"""
        return self.HasTitle

    @has_title.setter
    def has_title(self, value):
        """Alias for HasTitle.setter"""
        self.HasTitle = value

    @property
    def LegendPosition(self):
        return AcLegendPosition(self.com_object.LegendPosition)

    @LegendPosition.setter
    def LegendPosition(self, value):
        self.com_object.LegendPosition = value

    @property
    def legendposition(self):
        """Alias for LegendPosition"""
        return self.LegendPosition

    @legendposition.setter
    def legendposition(self, value):
        """Alias for LegendPosition.setter"""
        self.LegendPosition = value

    @property
    def legend_position(self):
        """Alias for LegendPosition"""
        return self.LegendPosition

    @legend_position.setter
    def legend_position(self, value):
        """Alias for LegendPosition.setter"""
        self.LegendPosition = value

    @property
    def LegendTextFontColor(self):
        return self.com_object.LegendTextFontColor

    @LegendTextFontColor.setter
    def LegendTextFontColor(self, value):
        self.com_object.LegendTextFontColor = value

    @property
    def legendtextfontcolor(self):
        """Alias for LegendTextFontColor"""
        return self.LegendTextFontColor

    @legendtextfontcolor.setter
    def legendtextfontcolor(self, value):
        """Alias for LegendTextFontColor.setter"""
        self.LegendTextFontColor = value

    @property
    def legend_text_font_color(self):
        """Alias for LegendTextFontColor"""
        return self.LegendTextFontColor

    @legend_text_font_color.setter
    def legend_text_font_color(self, value):
        """Alias for LegendTextFontColor.setter"""
        self.LegendTextFontColor = value

    @property
    def LegendTextFontSize(self):
        return self.com_object.LegendTextFontSize

    @LegendTextFontSize.setter
    def LegendTextFontSize(self, value):
        self.com_object.LegendTextFontSize = value

    @property
    def legendtextfontsize(self):
        """Alias for LegendTextFontSize"""
        return self.LegendTextFontSize

    @legendtextfontsize.setter
    def legendtextfontsize(self, value):
        """Alias for LegendTextFontSize.setter"""
        self.LegendTextFontSize = value

    @property
    def legend_text_font_size(self):
        """Alias for LegendTextFontSize"""
        return self.LegendTextFontSize

    @legend_text_font_size.setter
    def legend_text_font_size(self, value):
        """Alias for LegendTextFontSize.setter"""
        self.LegendTextFontSize = value

    @property
    def PrimaryValuesAxisDisplayUnits(self):
        return AcAxisUnits(self.com_object.PrimaryValuesAxisDisplayUnits)

    @PrimaryValuesAxisDisplayUnits.setter
    def PrimaryValuesAxisDisplayUnits(self, value):
        self.com_object.PrimaryValuesAxisDisplayUnits = value

    @property
    def primaryvaluesaxisdisplayunits(self):
        """Alias for PrimaryValuesAxisDisplayUnits"""
        return self.PrimaryValuesAxisDisplayUnits

    @primaryvaluesaxisdisplayunits.setter
    def primaryvaluesaxisdisplayunits(self, value):
        """Alias for PrimaryValuesAxisDisplayUnits.setter"""
        self.PrimaryValuesAxisDisplayUnits = value

    @property
    def primary_values_axis_display_units(self):
        """Alias for PrimaryValuesAxisDisplayUnits"""
        return self.PrimaryValuesAxisDisplayUnits

    @primary_values_axis_display_units.setter
    def primary_values_axis_display_units(self, value):
        """Alias for PrimaryValuesAxisDisplayUnits.setter"""
        self.PrimaryValuesAxisDisplayUnits = value

    @property
    def PrimaryValuesAxisFontColor(self):
        return self.com_object.PrimaryValuesAxisFontColor

    @PrimaryValuesAxisFontColor.setter
    def PrimaryValuesAxisFontColor(self, value):
        self.com_object.PrimaryValuesAxisFontColor = value

    @property
    def primaryvaluesaxisfontcolor(self):
        """Alias for PrimaryValuesAxisFontColor"""
        return self.PrimaryValuesAxisFontColor

    @primaryvaluesaxisfontcolor.setter
    def primaryvaluesaxisfontcolor(self, value):
        """Alias for PrimaryValuesAxisFontColor.setter"""
        self.PrimaryValuesAxisFontColor = value

    @property
    def primary_values_axis_font_color(self):
        """Alias for PrimaryValuesAxisFontColor"""
        return self.PrimaryValuesAxisFontColor

    @primary_values_axis_font_color.setter
    def primary_values_axis_font_color(self, value):
        """Alias for PrimaryValuesAxisFontColor.setter"""
        self.PrimaryValuesAxisFontColor = value

    @property
    def PrimaryValuesAxisFontSize(self):
        return self.com_object.PrimaryValuesAxisFontSize

    @PrimaryValuesAxisFontSize.setter
    def PrimaryValuesAxisFontSize(self, value):
        self.com_object.PrimaryValuesAxisFontSize = value

    @property
    def primaryvaluesaxisfontsize(self):
        """Alias for PrimaryValuesAxisFontSize"""
        return self.PrimaryValuesAxisFontSize

    @primaryvaluesaxisfontsize.setter
    def primaryvaluesaxisfontsize(self, value):
        """Alias for PrimaryValuesAxisFontSize.setter"""
        self.PrimaryValuesAxisFontSize = value

    @property
    def primary_values_axis_font_size(self):
        """Alias for PrimaryValuesAxisFontSize"""
        return self.PrimaryValuesAxisFontSize

    @primary_values_axis_font_size.setter
    def primary_values_axis_font_size(self, value):
        """Alias for PrimaryValuesAxisFontSize.setter"""
        self.PrimaryValuesAxisFontSize = value

    @property
    def PrimaryValuesAxisFormat(self):
        return self.com_object.PrimaryValuesAxisFormat

    @PrimaryValuesAxisFormat.setter
    def PrimaryValuesAxisFormat(self, value):
        self.com_object.PrimaryValuesAxisFormat = value

    @property
    def primaryvaluesaxisformat(self):
        """Alias for PrimaryValuesAxisFormat"""
        return self.PrimaryValuesAxisFormat

    @primaryvaluesaxisformat.setter
    def primaryvaluesaxisformat(self, value):
        """Alias for PrimaryValuesAxisFormat.setter"""
        self.PrimaryValuesAxisFormat = value

    @property
    def primary_values_axis_format(self):
        """Alias for PrimaryValuesAxisFormat"""
        return self.PrimaryValuesAxisFormat

    @primary_values_axis_format.setter
    def primary_values_axis_format(self, value):
        """Alias for PrimaryValuesAxisFormat.setter"""
        self.PrimaryValuesAxisFormat = value

    @property
    def PrimaryValuesAxisMaximum(self):
        return self.com_object.PrimaryValuesAxisMaximum

    @PrimaryValuesAxisMaximum.setter
    def PrimaryValuesAxisMaximum(self, value):
        self.com_object.PrimaryValuesAxisMaximum = value

    @property
    def primaryvaluesaxismaximum(self):
        """Alias for PrimaryValuesAxisMaximum"""
        return self.PrimaryValuesAxisMaximum

    @primaryvaluesaxismaximum.setter
    def primaryvaluesaxismaximum(self, value):
        """Alias for PrimaryValuesAxisMaximum.setter"""
        self.PrimaryValuesAxisMaximum = value

    @property
    def primary_values_axis_maximum(self):
        """Alias for PrimaryValuesAxisMaximum"""
        return self.PrimaryValuesAxisMaximum

    @primary_values_axis_maximum.setter
    def primary_values_axis_maximum(self, value):
        """Alias for PrimaryValuesAxisMaximum.setter"""
        self.PrimaryValuesAxisMaximum = value

    @property
    def PrimaryValuesAxisMinimum(self):
        return self.com_object.PrimaryValuesAxisMinimum

    @PrimaryValuesAxisMinimum.setter
    def PrimaryValuesAxisMinimum(self, value):
        self.com_object.PrimaryValuesAxisMinimum = value

    @property
    def primaryvaluesaxisminimum(self):
        """Alias for PrimaryValuesAxisMinimum"""
        return self.PrimaryValuesAxisMinimum

    @primaryvaluesaxisminimum.setter
    def primaryvaluesaxisminimum(self, value):
        """Alias for PrimaryValuesAxisMinimum.setter"""
        self.PrimaryValuesAxisMinimum = value

    @property
    def primary_values_axis_minimum(self):
        """Alias for PrimaryValuesAxisMinimum"""
        return self.PrimaryValuesAxisMinimum

    @primary_values_axis_minimum.setter
    def primary_values_axis_minimum(self, value):
        """Alias for PrimaryValuesAxisMinimum.setter"""
        self.PrimaryValuesAxisMinimum = value

    @property
    def PrimaryValuesAxisRange(self):
        return AcAxisRange(self.com_object.PrimaryValuesAxisRange)

    @PrimaryValuesAxisRange.setter
    def PrimaryValuesAxisRange(self, value):
        self.com_object.PrimaryValuesAxisRange = value

    @property
    def primaryvaluesaxisrange(self):
        """Alias for PrimaryValuesAxisRange"""
        return self.PrimaryValuesAxisRange

    @primaryvaluesaxisrange.setter
    def primaryvaluesaxisrange(self, value):
        """Alias for PrimaryValuesAxisRange.setter"""
        self.PrimaryValuesAxisRange = value

    @property
    def primary_values_axis_range(self):
        """Alias for PrimaryValuesAxisRange"""
        return self.PrimaryValuesAxisRange

    @primary_values_axis_range.setter
    def primary_values_axis_range(self, value):
        """Alias for PrimaryValuesAxisRange.setter"""
        self.PrimaryValuesAxisRange = value

    @property
    def PrimaryValuesAxisTitle(self):
        return self.com_object.PrimaryValuesAxisTitle

    @PrimaryValuesAxisTitle.setter
    def PrimaryValuesAxisTitle(self, value):
        self.com_object.PrimaryValuesAxisTitle = value

    @property
    def primaryvaluesaxistitle(self):
        """Alias for PrimaryValuesAxisTitle"""
        return self.PrimaryValuesAxisTitle

    @primaryvaluesaxistitle.setter
    def primaryvaluesaxistitle(self, value):
        """Alias for PrimaryValuesAxisTitle.setter"""
        self.PrimaryValuesAxisTitle = value

    @property
    def primary_values_axis_title(self):
        """Alias for PrimaryValuesAxisTitle"""
        return self.PrimaryValuesAxisTitle

    @primary_values_axis_title.setter
    def primary_values_axis_title(self, value):
        """Alias for PrimaryValuesAxisTitle.setter"""
        self.PrimaryValuesAxisTitle = value

    @property
    def RowSource(self):
        return self.com_object.RowSource

    @RowSource.setter
    def RowSource(self, value):
        self.com_object.RowSource = value

    @property
    def rowsource(self):
        """Alias for RowSource"""
        return self.RowSource

    @rowsource.setter
    def rowsource(self, value):
        """Alias for RowSource.setter"""
        self.RowSource = value

    @property
    def row_source(self):
        """Alias for RowSource"""
        return self.RowSource

    @row_source.setter
    def row_source(self, value):
        """Alias for RowSource.setter"""
        self.RowSource = value

    @property
    def SecondaryValuesAxisDisplayUnits(self):
        return AcAxisUnits(self.com_object.SecondaryValuesAxisDisplayUnits)

    @SecondaryValuesAxisDisplayUnits.setter
    def SecondaryValuesAxisDisplayUnits(self, value):
        self.com_object.SecondaryValuesAxisDisplayUnits = value

    @property
    def secondaryvaluesaxisdisplayunits(self):
        """Alias for SecondaryValuesAxisDisplayUnits"""
        return self.SecondaryValuesAxisDisplayUnits

    @secondaryvaluesaxisdisplayunits.setter
    def secondaryvaluesaxisdisplayunits(self, value):
        """Alias for SecondaryValuesAxisDisplayUnits.setter"""
        self.SecondaryValuesAxisDisplayUnits = value

    @property
    def secondary_values_axis_display_units(self):
        """Alias for SecondaryValuesAxisDisplayUnits"""
        return self.SecondaryValuesAxisDisplayUnits

    @secondary_values_axis_display_units.setter
    def secondary_values_axis_display_units(self, value):
        """Alias for SecondaryValuesAxisDisplayUnits.setter"""
        self.SecondaryValuesAxisDisplayUnits = value

    @property
    def SecondaryValuesAxisFontColor(self):
        return self.com_object.SecondaryValuesAxisFontColor

    @SecondaryValuesAxisFontColor.setter
    def SecondaryValuesAxisFontColor(self, value):
        self.com_object.SecondaryValuesAxisFontColor = value

    @property
    def secondaryvaluesaxisfontcolor(self):
        """Alias for SecondaryValuesAxisFontColor"""
        return self.SecondaryValuesAxisFontColor

    @secondaryvaluesaxisfontcolor.setter
    def secondaryvaluesaxisfontcolor(self, value):
        """Alias for SecondaryValuesAxisFontColor.setter"""
        self.SecondaryValuesAxisFontColor = value

    @property
    def secondary_values_axis_font_color(self):
        """Alias for SecondaryValuesAxisFontColor"""
        return self.SecondaryValuesAxisFontColor

    @secondary_values_axis_font_color.setter
    def secondary_values_axis_font_color(self, value):
        """Alias for SecondaryValuesAxisFontColor.setter"""
        self.SecondaryValuesAxisFontColor = value

    @property
    def SecondaryValuesAxisFontSize(self):
        return self.com_object.SecondaryValuesAxisFontSize

    @SecondaryValuesAxisFontSize.setter
    def SecondaryValuesAxisFontSize(self, value):
        self.com_object.SecondaryValuesAxisFontSize = value

    @property
    def secondaryvaluesaxisfontsize(self):
        """Alias for SecondaryValuesAxisFontSize"""
        return self.SecondaryValuesAxisFontSize

    @secondaryvaluesaxisfontsize.setter
    def secondaryvaluesaxisfontsize(self, value):
        """Alias for SecondaryValuesAxisFontSize.setter"""
        self.SecondaryValuesAxisFontSize = value

    @property
    def secondary_values_axis_font_size(self):
        """Alias for SecondaryValuesAxisFontSize"""
        return self.SecondaryValuesAxisFontSize

    @secondary_values_axis_font_size.setter
    def secondary_values_axis_font_size(self, value):
        """Alias for SecondaryValuesAxisFontSize.setter"""
        self.SecondaryValuesAxisFontSize = value

    @property
    def SecondaryValuesAxisFormat(self):
        return self.com_object.SecondaryValuesAxisFormat

    @SecondaryValuesAxisFormat.setter
    def SecondaryValuesAxisFormat(self, value):
        self.com_object.SecondaryValuesAxisFormat = value

    @property
    def secondaryvaluesaxisformat(self):
        """Alias for SecondaryValuesAxisFormat"""
        return self.SecondaryValuesAxisFormat

    @secondaryvaluesaxisformat.setter
    def secondaryvaluesaxisformat(self, value):
        """Alias for SecondaryValuesAxisFormat.setter"""
        self.SecondaryValuesAxisFormat = value

    @property
    def secondary_values_axis_format(self):
        """Alias for SecondaryValuesAxisFormat"""
        return self.SecondaryValuesAxisFormat

    @secondary_values_axis_format.setter
    def secondary_values_axis_format(self, value):
        """Alias for SecondaryValuesAxisFormat.setter"""
        self.SecondaryValuesAxisFormat = value

    @property
    def SecondaryValuesAxisMaximum(self):
        return self.com_object.SecondaryValuesAxisMaximum

    @SecondaryValuesAxisMaximum.setter
    def SecondaryValuesAxisMaximum(self, value):
        self.com_object.SecondaryValuesAxisMaximum = value

    @property
    def secondaryvaluesaxismaximum(self):
        """Alias for SecondaryValuesAxisMaximum"""
        return self.SecondaryValuesAxisMaximum

    @secondaryvaluesaxismaximum.setter
    def secondaryvaluesaxismaximum(self, value):
        """Alias for SecondaryValuesAxisMaximum.setter"""
        self.SecondaryValuesAxisMaximum = value

    @property
    def secondary_values_axis_maximum(self):
        """Alias for SecondaryValuesAxisMaximum"""
        return self.SecondaryValuesAxisMaximum

    @secondary_values_axis_maximum.setter
    def secondary_values_axis_maximum(self, value):
        """Alias for SecondaryValuesAxisMaximum.setter"""
        self.SecondaryValuesAxisMaximum = value

    @property
    def SecondaryValuesAxisMinimum(self):
        return self.com_object.SecondaryValuesAxisMinimum

    @SecondaryValuesAxisMinimum.setter
    def SecondaryValuesAxisMinimum(self, value):
        self.com_object.SecondaryValuesAxisMinimum = value

    @property
    def secondaryvaluesaxisminimum(self):
        """Alias for SecondaryValuesAxisMinimum"""
        return self.SecondaryValuesAxisMinimum

    @secondaryvaluesaxisminimum.setter
    def secondaryvaluesaxisminimum(self, value):
        """Alias for SecondaryValuesAxisMinimum.setter"""
        self.SecondaryValuesAxisMinimum = value

    @property
    def secondary_values_axis_minimum(self):
        """Alias for SecondaryValuesAxisMinimum"""
        return self.SecondaryValuesAxisMinimum

    @secondary_values_axis_minimum.setter
    def secondary_values_axis_minimum(self, value):
        """Alias for SecondaryValuesAxisMinimum.setter"""
        self.SecondaryValuesAxisMinimum = value

    @property
    def SecondaryValuesAxisRange(self):
        return AcAxisRange(self.com_object.SecondaryValuesAxisRange)

    @SecondaryValuesAxisRange.setter
    def SecondaryValuesAxisRange(self, value):
        self.com_object.SecondaryValuesAxisRange = value

    @property
    def secondaryvaluesaxisrange(self):
        """Alias for SecondaryValuesAxisRange"""
        return self.SecondaryValuesAxisRange

    @secondaryvaluesaxisrange.setter
    def secondaryvaluesaxisrange(self, value):
        """Alias for SecondaryValuesAxisRange.setter"""
        self.SecondaryValuesAxisRange = value

    @property
    def secondary_values_axis_range(self):
        """Alias for SecondaryValuesAxisRange"""
        return self.SecondaryValuesAxisRange

    @secondary_values_axis_range.setter
    def secondary_values_axis_range(self, value):
        """Alias for SecondaryValuesAxisRange.setter"""
        self.SecondaryValuesAxisRange = value

    @property
    def SecondaryValuesAxisTitle(self):
        return self.com_object.SecondaryValuesAxisTitle

    @SecondaryValuesAxisTitle.setter
    def SecondaryValuesAxisTitle(self, value):
        self.com_object.SecondaryValuesAxisTitle = value

    @property
    def secondaryvaluesaxistitle(self):
        """Alias for SecondaryValuesAxisTitle"""
        return self.SecondaryValuesAxisTitle

    @secondaryvaluesaxistitle.setter
    def secondaryvaluesaxistitle(self, value):
        """Alias for SecondaryValuesAxisTitle.setter"""
        self.SecondaryValuesAxisTitle = value

    @property
    def secondary_values_axis_title(self):
        """Alias for SecondaryValuesAxisTitle"""
        return self.SecondaryValuesAxisTitle

    @secondary_values_axis_title.setter
    def secondary_values_axis_title(self, value):
        """Alias for SecondaryValuesAxisTitle.setter"""
        self.SecondaryValuesAxisTitle = value

    @property
    def TransformedRowSource(self):
        return self.com_object.TransformedRowSource

    @property
    def transformedrowsource(self):
        """Alias for TransformedRowSource"""
        return self.TransformedRowSource

    @property
    def transformed_row_source(self):
        """Alias for TransformedRowSource"""
        return self.TransformedRowSource


class ChartAxis:

    def __init__(self, chartaxis=None):
        self.com_object= chartaxis

    @property
    def GroupType(self):
        return AcDateGroupType(self.com_object.GroupType)

    @GroupType.setter
    def GroupType(self, value):
        self.com_object.GroupType = value

    @property
    def grouptype(self):
        """Alias for GroupType"""
        return self.GroupType

    @grouptype.setter
    def grouptype(self, value):
        """Alias for GroupType.setter"""
        self.GroupType = value

    @property
    def group_type(self):
        """Alias for GroupType"""
        return self.GroupType

    @group_type.setter
    def group_type(self, value):
        """Alias for GroupType.setter"""
        self.GroupType = value

    @property
    def Name(self):
        return ChartAxis(self.com_object.Name)

    @property
    def name(self):
        """Alias for Name"""
        return self.Name


class ChartAxisCollection:

    def __init__(self, chartaxiscollection=None):
        self.com_object= chartaxiscollection

    def __call__(self, item):
        return ChartAxis(self.com_object(item))


class ChartSeries:

    def __init__(self, chartseries=None):
        self.com_object= chartseries

    @property
    def BorderColor(self):
        return self.com_object.BorderColor

    @BorderColor.setter
    def BorderColor(self, value):
        self.com_object.BorderColor = value

    @property
    def bordercolor(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @bordercolor.setter
    def bordercolor(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def border_color(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @border_color.setter
    def border_color(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def ComboChartType(self):
        return AcChartType(self.com_object.ComboChartType)

    @ComboChartType.setter
    def ComboChartType(self, value):
        self.com_object.ComboChartType = value

    @property
    def combocharttype(self):
        """Alias for ComboChartType"""
        return self.ComboChartType

    @combocharttype.setter
    def combocharttype(self, value):
        """Alias for ComboChartType.setter"""
        self.ComboChartType = value

    @property
    def combo_chart_type(self):
        """Alias for ComboChartType"""
        return self.ComboChartType

    @combo_chart_type.setter
    def combo_chart_type(self, value):
        """Alias for ComboChartType.setter"""
        self.ComboChartType = value

    @property
    def DashType(self):
        return self.com_object.DashType

    @DashType.setter
    def DashType(self, value):
        self.com_object.DashType = value

    @property
    def dashtype(self):
        """Alias for DashType"""
        return self.DashType

    @dashtype.setter
    def dashtype(self, value):
        """Alias for DashType.setter"""
        self.DashType = value

    @property
    def dash_type(self):
        """Alias for DashType"""
        return self.DashType

    @dash_type.setter
    def dash_type(self, value):
        """Alias for DashType.setter"""
        self.DashType = value

    @property
    def DataLabelDisplayFormat(self):
        return AcDataLabelDisplayFormat(self.com_object.DataLabelDisplayFormat)

    @DataLabelDisplayFormat.setter
    def DataLabelDisplayFormat(self, value):
        self.com_object.DataLabelDisplayFormat = value

    @property
    def datalabeldisplayformat(self):
        """Alias for DataLabelDisplayFormat"""
        return self.DataLabelDisplayFormat

    @datalabeldisplayformat.setter
    def datalabeldisplayformat(self, value):
        """Alias for DataLabelDisplayFormat.setter"""
        self.DataLabelDisplayFormat = value

    @property
    def data_label_display_format(self):
        """Alias for DataLabelDisplayFormat"""
        return self.DataLabelDisplayFormat

    @data_label_display_format.setter
    def data_label_display_format(self, value):
        """Alias for DataLabelDisplayFormat.setter"""
        self.DataLabelDisplayFormat = value

    @property
    def DataLabelPosition(self):
        return AcDataLabelPosition(self.com_object.DataLabelPosition)

    @DataLabelPosition.setter
    def DataLabelPosition(self, value):
        self.com_object.DataLabelPosition = value

    @property
    def datalabelposition(self):
        """Alias for DataLabelPosition"""
        return self.DataLabelPosition

    @datalabelposition.setter
    def datalabelposition(self, value):
        """Alias for DataLabelPosition.setter"""
        self.DataLabelPosition = value

    @property
    def data_label_position(self):
        """Alias for DataLabelPosition"""
        return self.DataLabelPosition

    @data_label_position.setter
    def data_label_position(self, value):
        """Alias for DataLabelPosition.setter"""
        self.DataLabelPosition = value

    @property
    def DisplayBoxWhiskerDataPoints(self):
        return self.com_object.DisplayBoxWhiskerDataPoints

    @DisplayBoxWhiskerDataPoints.setter
    def DisplayBoxWhiskerDataPoints(self, value):
        self.com_object.DisplayBoxWhiskerDataPoints = value

    @property
    def displayboxwhiskerdatapoints(self):
        """Alias for DisplayBoxWhiskerDataPoints"""
        return self.DisplayBoxWhiskerDataPoints

    @displayboxwhiskerdatapoints.setter
    def displayboxwhiskerdatapoints(self, value):
        """Alias for DisplayBoxWhiskerDataPoints.setter"""
        self.DisplayBoxWhiskerDataPoints = value

    @property
    def display_box_whisker_data_points(self):
        """Alias for DisplayBoxWhiskerDataPoints"""
        return self.DisplayBoxWhiskerDataPoints

    @display_box_whisker_data_points.setter
    def display_box_whisker_data_points(self, value):
        """Alias for DisplayBoxWhiskerDataPoints.setter"""
        self.DisplayBoxWhiskerDataPoints = value

    @property
    def DisplayBoxWhiskerMeanMarker(self):
        return self.com_object.DisplayBoxWhiskerMeanMarker

    @DisplayBoxWhiskerMeanMarker.setter
    def DisplayBoxWhiskerMeanMarker(self, value):
        self.com_object.DisplayBoxWhiskerMeanMarker = value

    @property
    def displayboxwhiskermeanmarker(self):
        """Alias for DisplayBoxWhiskerMeanMarker"""
        return self.DisplayBoxWhiskerMeanMarker

    @displayboxwhiskermeanmarker.setter
    def displayboxwhiskermeanmarker(self, value):
        """Alias for DisplayBoxWhiskerMeanMarker.setter"""
        self.DisplayBoxWhiskerMeanMarker = value

    @property
    def display_box_whisker_mean_marker(self):
        """Alias for DisplayBoxWhiskerMeanMarker"""
        return self.DisplayBoxWhiskerMeanMarker

    @display_box_whisker_mean_marker.setter
    def display_box_whisker_mean_marker(self, value):
        """Alias for DisplayBoxWhiskerMeanMarker.setter"""
        self.DisplayBoxWhiskerMeanMarker = value

    @property
    def DisplayDataLabel(self):
        return self.com_object.DisplayDataLabel

    @DisplayDataLabel.setter
    def DisplayDataLabel(self, value):
        self.com_object.DisplayDataLabel = value

    @property
    def displaydatalabel(self):
        """Alias for DisplayDataLabel"""
        return self.DisplayDataLabel

    @displaydatalabel.setter
    def displaydatalabel(self, value):
        """Alias for DisplayDataLabel.setter"""
        self.DisplayDataLabel = value

    @property
    def display_data_label(self):
        """Alias for DisplayDataLabel"""
        return self.DisplayDataLabel

    @display_data_label.setter
    def display_data_label(self, value):
        """Alias for DisplayDataLabel.setter"""
        self.DisplayDataLabel = value

    @property
    def DisplayName(self):
        return self.com_object.DisplayName

    @DisplayName.setter
    def DisplayName(self, value):
        self.com_object.DisplayName = value

    @property
    def displayname(self):
        """Alias for DisplayName"""
        return self.DisplayName

    @displayname.setter
    def displayname(self, value):
        """Alias for DisplayName.setter"""
        self.DisplayName = value

    @property
    def display_name(self):
        """Alias for DisplayName"""
        return self.DisplayName

    @display_name.setter
    def display_name(self, value):
        """Alias for DisplayName.setter"""
        self.DisplayName = value

    @property
    def FillColor(self):
        return self.com_object.FillColor

    @FillColor.setter
    def FillColor(self, value):
        self.com_object.FillColor = value

    @property
    def fillcolor(self):
        """Alias for FillColor"""
        return self.FillColor

    @fillcolor.setter
    def fillcolor(self, value):
        """Alias for FillColor.setter"""
        self.FillColor = value

    @property
    def fill_color(self):
        """Alias for FillColor"""
        return self.FillColor

    @fill_color.setter
    def fill_color(self, value):
        """Alias for FillColor.setter"""
        self.FillColor = value

    @property
    def GridlinesColor(self):
        return self.com_object.GridlinesColor

    @GridlinesColor.setter
    def GridlinesColor(self, value):
        self.com_object.GridlinesColor = value

    @property
    def gridlinescolor(self):
        """Alias for GridlinesColor"""
        return self.GridlinesColor

    @gridlinescolor.setter
    def gridlinescolor(self, value):
        """Alias for GridlinesColor.setter"""
        self.GridlinesColor = value

    @property
    def gridlines_color(self):
        """Alias for GridlinesColor"""
        return self.GridlinesColor

    @gridlines_color.setter
    def gridlines_color(self, value):
        """Alias for GridlinesColor.setter"""
        self.GridlinesColor = value

    @property
    def GridlinesType(self):
        return AcGridlineType(self.com_object.GridlinesType)

    @GridlinesType.setter
    def GridlinesType(self, value):
        self.com_object.GridlinesType = value

    @property
    def gridlinestype(self):
        """Alias for GridlinesType"""
        return self.GridlinesType

    @gridlinestype.setter
    def gridlinestype(self, value):
        """Alias for GridlinesType.setter"""
        self.GridlinesType = value

    @property
    def gridlines_type(self):
        """Alias for GridlinesType"""
        return self.GridlinesType

    @gridlines_type.setter
    def gridlines_type(self, value):
        """Alias for GridlinesType.setter"""
        self.GridlinesType = value

    @property
    def LineWeight(self):
        return self.com_object.LineWeight

    @LineWeight.setter
    def LineWeight(self, value):
        self.com_object.LineWeight = value

    @property
    def lineweight(self):
        """Alias for LineWeight"""
        return self.LineWeight

    @lineweight.setter
    def lineweight(self, value):
        """Alias for LineWeight.setter"""
        self.LineWeight = value

    @property
    def line_weight(self):
        """Alias for LineWeight"""
        return self.LineWeight

    @line_weight.setter
    def line_weight(self, value):
        """Alias for LineWeight.setter"""
        self.LineWeight = value

    @property
    def MarkerType(self):
        return AcMarkerType(self.com_object.MarkerType)

    @MarkerType.setter
    def MarkerType(self, value):
        self.com_object.MarkerType = value

    @property
    def markertype(self):
        """Alias for MarkerType"""
        return self.MarkerType

    @markertype.setter
    def markertype(self, value):
        """Alias for MarkerType.setter"""
        self.MarkerType = value

    @property
    def marker_type(self):
        """Alias for MarkerType"""
        return self.MarkerType

    @marker_type.setter
    def marker_type(self, value):
        """Alias for MarkerType.setter"""
        self.MarkerType = value

    @property
    def MissingDataPolicy(self):
        return AcMissingDataPolicy(self.com_object.MissingDataPolicy)

    @MissingDataPolicy.setter
    def MissingDataPolicy(self, value):
        self.com_object.MissingDataPolicy = value

    @property
    def missingdatapolicy(self):
        """Alias for MissingDataPolicy"""
        return self.MissingDataPolicy

    @missingdatapolicy.setter
    def missingdatapolicy(self, value):
        """Alias for MissingDataPolicy.setter"""
        self.MissingDataPolicy = value

    @property
    def missing_data_policy(self):
        """Alias for MissingDataPolicy"""
        return self.MissingDataPolicy

    @missing_data_policy.setter
    def missing_data_policy(self, value):
        """Alias for MissingDataPolicy.setter"""
        self.MissingDataPolicy = value

    @property
    def Name(self):
        return ChartSeries(self.com_object.Name)

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def ParetoLineColor(self):
        return self.com_object.ParetoLineColor

    @ParetoLineColor.setter
    def ParetoLineColor(self, value):
        self.com_object.ParetoLineColor = value

    @property
    def paretolinecolor(self):
        """Alias for ParetoLineColor"""
        return self.ParetoLineColor

    @paretolinecolor.setter
    def paretolinecolor(self, value):
        """Alias for ParetoLineColor.setter"""
        self.ParetoLineColor = value

    @property
    def pareto_line_color(self):
        """Alias for ParetoLineColor"""
        return self.ParetoLineColor

    @pareto_line_color.setter
    def pareto_line_color(self, value):
        """Alias for ParetoLineColor.setter"""
        self.ParetoLineColor = value

    @property
    def PercentageDataLabelDecimalPlaces(self):
        return AcPercentageDataLabelDecimalPlaces(self.com_object.PercentageDataLabelDecimalPlaces)

    @PercentageDataLabelDecimalPlaces.setter
    def PercentageDataLabelDecimalPlaces(self, value):
        self.com_object.PercentageDataLabelDecimalPlaces = value

    @property
    def percentagedatalabeldecimalplaces(self):
        """Alias for PercentageDataLabelDecimalPlaces"""
        return self.PercentageDataLabelDecimalPlaces

    @percentagedatalabeldecimalplaces.setter
    def percentagedatalabeldecimalplaces(self, value):
        """Alias for PercentageDataLabelDecimalPlaces.setter"""
        self.PercentageDataLabelDecimalPlaces = value

    @property
    def percentage_data_label_decimal_places(self):
        """Alias for PercentageDataLabelDecimalPlaces"""
        return self.PercentageDataLabelDecimalPlaces

    @percentage_data_label_decimal_places.setter
    def percentage_data_label_decimal_places(self, value):
        """Alias for PercentageDataLabelDecimalPlaces.setter"""
        self.PercentageDataLabelDecimalPlaces = value

    @property
    def PlotSeriesOn(self):
        return AcValueAxis(self.com_object.PlotSeriesOn)

    @PlotSeriesOn.setter
    def PlotSeriesOn(self, value):
        self.com_object.PlotSeriesOn = value

    @property
    def plotserieson(self):
        """Alias for PlotSeriesOn"""
        return self.PlotSeriesOn

    @plotserieson.setter
    def plotserieson(self, value):
        """Alias for PlotSeriesOn.setter"""
        self.PlotSeriesOn = value

    @property
    def plot_series_on(self):
        """Alias for PlotSeriesOn"""
        return self.PlotSeriesOn

    @plot_series_on.setter
    def plot_series_on(self, value):
        """Alias for PlotSeriesOn.setter"""
        self.PlotSeriesOn = value

    @property
    def ShowFunnelPercentages(self):
        return self.com_object.ShowFunnelPercentages

    @ShowFunnelPercentages.setter
    def ShowFunnelPercentages(self, value):
        self.com_object.ShowFunnelPercentages = value

    @property
    def showfunnelpercentages(self):
        """Alias for ShowFunnelPercentages"""
        return self.ShowFunnelPercentages

    @showfunnelpercentages.setter
    def showfunnelpercentages(self, value):
        """Alias for ShowFunnelPercentages.setter"""
        self.ShowFunnelPercentages = value

    @property
    def show_funnel_percentages(self):
        """Alias for ShowFunnelPercentages"""
        return self.ShowFunnelPercentages

    @show_funnel_percentages.setter
    def show_funnel_percentages(self, value):
        """Alias for ShowFunnelPercentages.setter"""
        self.ShowFunnelPercentages = value

    @property
    def ShowWaterfallConnectorLines(self):
        return self.com_object.ShowWaterfallConnectorLines

    @ShowWaterfallConnectorLines.setter
    def ShowWaterfallConnectorLines(self, value):
        self.com_object.ShowWaterfallConnectorLines = value

    @property
    def showwaterfallconnectorlines(self):
        """Alias for ShowWaterfallConnectorLines"""
        return self.ShowWaterfallConnectorLines

    @showwaterfallconnectorlines.setter
    def showwaterfallconnectorlines(self, value):
        """Alias for ShowWaterfallConnectorLines.setter"""
        self.ShowWaterfallConnectorLines = value

    @property
    def show_waterfall_connector_lines(self):
        """Alias for ShowWaterfallConnectorLines"""
        return self.ShowWaterfallConnectorLines

    @show_waterfall_connector_lines.setter
    def show_waterfall_connector_lines(self, value):
        """Alias for ShowWaterfallConnectorLines.setter"""
        self.ShowWaterfallConnectorLines = value

    @property
    def ShowWaterfallTotal(self):
        return self.com_object.ShowWaterfallTotal

    @ShowWaterfallTotal.setter
    def ShowWaterfallTotal(self, value):
        self.com_object.ShowWaterfallTotal = value

    @property
    def showwaterfalltotal(self):
        """Alias for ShowWaterfallTotal"""
        return self.ShowWaterfallTotal

    @showwaterfalltotal.setter
    def showwaterfalltotal(self, value):
        """Alias for ShowWaterfallTotal.setter"""
        self.ShowWaterfallTotal = value

    @property
    def show_waterfall_total(self):
        """Alias for ShowWaterfallTotal"""
        return self.ShowWaterfallTotal

    @show_waterfall_total.setter
    def show_waterfall_total(self, value):
        """Alias for ShowWaterfallTotal.setter"""
        self.ShowWaterfallTotal = value

    @property
    def SortOrderType(self):
        return AcSortOrderType(self.com_object.SortOrderType)

    @SortOrderType.setter
    def SortOrderType(self, value):
        self.com_object.SortOrderType = value

    @property
    def sortordertype(self):
        """Alias for SortOrderType"""
        return self.SortOrderType

    @sortordertype.setter
    def sortordertype(self, value):
        """Alias for SortOrderType.setter"""
        self.SortOrderType = value

    @property
    def sort_order_type(self):
        """Alias for SortOrderType"""
        return self.SortOrderType

    @sort_order_type.setter
    def sort_order_type(self, value):
        """Alias for SortOrderType.setter"""
        self.SortOrderType = value

    @property
    def TrendlineName(self):
        return self.com_object.TrendlineName

    @TrendlineName.setter
    def TrendlineName(self, value):
        self.com_object.TrendlineName = value

    @property
    def trendlinename(self):
        """Alias for TrendlineName"""
        return self.TrendlineName

    @trendlinename.setter
    def trendlinename(self, value):
        """Alias for TrendlineName.setter"""
        self.TrendlineName = value

    @property
    def trendline_name(self):
        """Alias for TrendlineName"""
        return self.TrendlineName

    @trendline_name.setter
    def trendline_name(self, value):
        """Alias for TrendlineName.setter"""
        self.TrendlineName = value

    @property
    def TrendlineOptions(self):
        return AcTrendlineOptions(self.com_object.TrendlineOptions)

    @TrendlineOptions.setter
    def TrendlineOptions(self, value):
        self.com_object.TrendlineOptions = value

    @property
    def trendlineoptions(self):
        """Alias for TrendlineOptions"""
        return self.TrendlineOptions

    @trendlineoptions.setter
    def trendlineoptions(self, value):
        """Alias for TrendlineOptions.setter"""
        self.TrendlineOptions = value

    @property
    def trendline_options(self):
        """Alias for TrendlineOptions"""
        return self.TrendlineOptions

    @trendline_options.setter
    def trendline_options(self, value):
        """Alias for TrendlineOptions.setter"""
        self.TrendlineOptions = value

    @property
    def WordCloudShape(self):
        return AcWordCloudShape(self.com_object.WordCloudShape)

    @WordCloudShape.setter
    def WordCloudShape(self, value):
        self.com_object.WordCloudShape = value

    @property
    def wordcloudshape(self):
        """Alias for WordCloudShape"""
        return self.WordCloudShape

    @wordcloudshape.setter
    def wordcloudshape(self, value):
        """Alias for WordCloudShape.setter"""
        self.WordCloudShape = value

    @property
    def word_cloud_shape(self):
        """Alias for WordCloudShape"""
        return self.WordCloudShape

    @word_cloud_shape.setter
    def word_cloud_shape(self, value):
        """Alias for WordCloudShape.setter"""
        self.WordCloudShape = value

    @property
    def WordCloudWordOrientation(self):
        return AcWordCloudWordOrientation(self.com_object.WordCloudWordOrientation)

    @WordCloudWordOrientation.setter
    def WordCloudWordOrientation(self, value):
        self.com_object.WordCloudWordOrientation = value

    @property
    def wordcloudwordorientation(self):
        """Alias for WordCloudWordOrientation"""
        return self.WordCloudWordOrientation

    @wordcloudwordorientation.setter
    def wordcloudwordorientation(self, value):
        """Alias for WordCloudWordOrientation.setter"""
        self.WordCloudWordOrientation = value

    @property
    def word_cloud_word_orientation(self):
        """Alias for WordCloudWordOrientation"""
        return self.WordCloudWordOrientation

    @word_cloud_word_orientation.setter
    def word_cloud_word_orientation(self, value):
        """Alias for WordCloudWordOrientation.setter"""
        self.WordCloudWordOrientation = value


class ChartSeriesCollection:

    def __init__(self, chartseriescollection=None):
        self.com_object= chartseriescollection

    def __call__(self, item):
        return ChartSeries(self.com_object(item))


class ChartValues:

    def __init__(self, chartvalues=None):
        self.com_object= chartvalues

    @property
    def AggregateType(self):
        return AcAggregateType(self.com_object.AggregateType)

    @AggregateType.setter
    def AggregateType(self, value):
        self.com_object.AggregateType = value

    @property
    def aggregatetype(self):
        """Alias for AggregateType"""
        return self.AggregateType

    @aggregatetype.setter
    def aggregatetype(self, value):
        """Alias for AggregateType.setter"""
        self.AggregateType = value

    @property
    def aggregate_type(self):
        """Alias for AggregateType"""
        return self.AggregateType

    @aggregate_type.setter
    def aggregate_type(self, value):
        """Alias for AggregateType.setter"""
        self.AggregateType = value

    @property
    def Name(self):
        return ChartValues(self.com_object.Name)

    @property
    def name(self):
        """Alias for Name"""
        return self.Name


class ChartValuesCollection:

    def __init__(self, chartvaluescollection=None):
        self.com_object= chartvaluescollection

    def __call__(self, item):
        return ChartValues(self.com_object(item))


class CheckBox:

    def __init__(self, checkbox=None):
        self.com_object= checkbox

    @property
    def AddColon(self):
        return self.com_object.AddColon

    @AddColon.setter
    def AddColon(self, value):
        self.com_object.AddColon = value

    @property
    def addcolon(self):
        """Alias for AddColon"""
        return self.AddColon

    @addcolon.setter
    def addcolon(self, value):
        """Alias for AddColon.setter"""
        self.AddColon = value

    @property
    def add_colon(self):
        """Alias for AddColon"""
        return self.AddColon

    @add_colon.setter
    def add_colon(self, value):
        """Alias for AddColon.setter"""
        self.AddColon = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoLabel(self):
        return self.com_object.AutoLabel

    @AutoLabel.setter
    def AutoLabel(self, value):
        self.com_object.AutoLabel = value

    @property
    def autolabel(self):
        """Alias for AutoLabel"""
        return self.AutoLabel

    @autolabel.setter
    def autolabel(self, value):
        """Alias for AutoLabel.setter"""
        self.AutoLabel = value

    @property
    def auto_label(self):
        """Alias for AutoLabel"""
        return self.AutoLabel

    @auto_label.setter
    def auto_label(self, value):
        """Alias for AutoLabel.setter"""
        self.AutoLabel = value

    @property
    def BorderColor(self):
        return self.com_object.BorderColor

    @BorderColor.setter
    def BorderColor(self, value):
        self.com_object.BorderColor = value

    @property
    def bordercolor(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @bordercolor.setter
    def bordercolor(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def border_color(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @border_color.setter
    def border_color(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def BorderShade(self):
        return self.com_object.BorderShade

    @BorderShade.setter
    def BorderShade(self, value):
        self.com_object.BorderShade = value

    @property
    def bordershade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @bordershade.setter
    def bordershade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def border_shade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @border_shade.setter
    def border_shade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def BorderStyle(self):
        return self.com_object.BorderStyle

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def BorderThemeColorIndex(self):
        return self.com_object.BorderThemeColorIndex

    @BorderThemeColorIndex.setter
    def BorderThemeColorIndex(self, value):
        self.com_object.BorderThemeColorIndex = value

    @property
    def borderthemecolorindex(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @borderthemecolorindex.setter
    def borderthemecolorindex(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def border_theme_color_index(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @border_theme_color_index.setter
    def border_theme_color_index(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def BorderTint(self):
        return self.com_object.BorderTint

    @BorderTint.setter
    def BorderTint(self, value):
        self.com_object.BorderTint = value

    @property
    def bordertint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @bordertint.setter
    def bordertint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def border_tint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @border_tint.setter
    def border_tint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def BorderWidth(self):
        return self.com_object.BorderWidth

    @BorderWidth.setter
    def BorderWidth(self, value):
        self.com_object.BorderWidth = value

    @property
    def borderwidth(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @borderwidth.setter
    def borderwidth(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def border_width(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @border_width.setter
    def border_width(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def BottomPadding(self):
        return self.com_object.BottomPadding

    @BottomPadding.setter
    def BottomPadding(self, value):
        self.com_object.BottomPadding = value

    @property
    def bottompadding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottompadding.setter
    def bottompadding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def bottom_padding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottom_padding.setter
    def bottom_padding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def ColumnHidden(self):
        return self.com_object.ColumnHidden

    @ColumnHidden.setter
    def ColumnHidden(self, value):
        self.com_object.ColumnHidden = value

    @property
    def columnhidden(self):
        """Alias for ColumnHidden"""
        return self.ColumnHidden

    @columnhidden.setter
    def columnhidden(self, value):
        """Alias for ColumnHidden.setter"""
        self.ColumnHidden = value

    @property
    def column_hidden(self):
        """Alias for ColumnHidden"""
        return self.ColumnHidden

    @column_hidden.setter
    def column_hidden(self, value):
        """Alias for ColumnHidden.setter"""
        self.ColumnHidden = value

    @property
    def ColumnOrder(self):
        return self.com_object.ColumnOrder

    @ColumnOrder.setter
    def ColumnOrder(self, value):
        self.com_object.ColumnOrder = value

    @property
    def columnorder(self):
        """Alias for ColumnOrder"""
        return self.ColumnOrder

    @columnorder.setter
    def columnorder(self, value):
        """Alias for ColumnOrder.setter"""
        self.ColumnOrder = value

    @property
    def column_order(self):
        """Alias for ColumnOrder"""
        return self.ColumnOrder

    @column_order.setter
    def column_order(self, value):
        """Alias for ColumnOrder.setter"""
        self.ColumnOrder = value

    @property
    def ColumnWidth(self):
        return self.com_object.ColumnWidth

    @ColumnWidth.setter
    def ColumnWidth(self, value):
        self.com_object.ColumnWidth = value

    @property
    def columnwidth(self):
        """Alias for ColumnWidth"""
        return self.ColumnWidth

    @columnwidth.setter
    def columnwidth(self, value):
        """Alias for ColumnWidth.setter"""
        self.ColumnWidth = value

    @property
    def column_width(self):
        """Alias for ColumnWidth"""
        return self.ColumnWidth

    @column_width.setter
    def column_width(self, value):
        """Alias for ColumnWidth.setter"""
        self.ColumnWidth = value

    @property
    def Controls(self):
        return Controls(self.com_object.Controls)

    @property
    def controls(self):
        """Alias for Controls"""
        return self.Controls

    @property
    def ControlSource(self):
        return self.com_object.ControlSource

    @ControlSource.setter
    def ControlSource(self, value):
        self.com_object.ControlSource = value

    @property
    def controlsource(self):
        """Alias for ControlSource"""
        return self.ControlSource

    @controlsource.setter
    def controlsource(self, value):
        """Alias for ControlSource.setter"""
        self.ControlSource = value

    @property
    def control_source(self):
        """Alias for ControlSource"""
        return self.ControlSource

    @control_source.setter
    def control_source(self, value):
        """Alias for ControlSource.setter"""
        self.ControlSource = value

    @property
    def ControlTipText(self):
        return self.com_object.ControlTipText

    @ControlTipText.setter
    def ControlTipText(self, value):
        self.com_object.ControlTipText = value

    @property
    def controltiptext(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @controltiptext.setter
    def controltiptext(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def control_tip_text(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @control_tip_text.setter
    def control_tip_text(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def ControlType(self):
        return self.com_object.ControlType

    @ControlType.setter
    def ControlType(self, value):
        self.com_object.ControlType = value

    @property
    def controltype(self):
        """Alias for ControlType"""
        return self.ControlType

    @controltype.setter
    def controltype(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def control_type(self):
        """Alias for ControlType"""
        return self.ControlType

    @control_type.setter
    def control_type(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def DefaultValue(self):
        return self.com_object.DefaultValue

    @DefaultValue.setter
    def DefaultValue(self, value):
        self.com_object.DefaultValue = value

    @property
    def defaultvalue(self):
        """Alias for DefaultValue"""
        return self.DefaultValue

    @defaultvalue.setter
    def defaultvalue(self, value):
        """Alias for DefaultValue.setter"""
        self.DefaultValue = value

    @property
    def default_value(self):
        """Alias for DefaultValue"""
        return self.DefaultValue

    @default_value.setter
    def default_value(self, value):
        """Alias for DefaultValue.setter"""
        self.DefaultValue = value

    @property
    def DisplayWhen(self):
        return self.com_object.DisplayWhen

    @DisplayWhen.setter
    def DisplayWhen(self, value):
        self.com_object.DisplayWhen = value

    @property
    def displaywhen(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @displaywhen.setter
    def displaywhen(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def display_when(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @display_when.setter
    def display_when(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def GridlineColor(self):
        return self.com_object.GridlineColor

    @GridlineColor.setter
    def GridlineColor(self, value):
        self.com_object.GridlineColor = value

    @property
    def gridlinecolor(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridlinecolor.setter
    def gridlinecolor(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def gridline_color(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridline_color.setter
    def gridline_color(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def GridlineShade(self):
        return self.com_object.GridlineShade

    @GridlineShade.setter
    def GridlineShade(self, value):
        self.com_object.GridlineShade = value

    @property
    def gridlineshade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridlineshade.setter
    def gridlineshade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def gridline_shade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridline_shade.setter
    def gridline_shade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def GridlineStyleBottom(self):
        return self.com_object.GridlineStyleBottom

    @property
    def gridlinestylebottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @property
    def gridline_style_bottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @property
    def GridlineStyleLeft(self):
        return self.com_object.GridlineStyleLeft

    @GridlineStyleLeft.setter
    def GridlineStyleLeft(self, value):
        self.com_object.GridlineStyleLeft = value

    @property
    def gridlinestyleleft(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridlinestyleleft.setter
    def gridlinestyleleft(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def gridline_style_left(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridline_style_left.setter
    def gridline_style_left(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def GridlineStyleRight(self):
        return self.com_object.GridlineStyleRight

    @GridlineStyleRight.setter
    def GridlineStyleRight(self, value):
        self.com_object.GridlineStyleRight = value

    @property
    def gridlinestyleright(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridlinestyleright.setter
    def gridlinestyleright(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def gridline_style_right(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridline_style_right.setter
    def gridline_style_right(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def GridlineStyleTop(self):
        return self.com_object.GridlineStyleTop

    @GridlineStyleTop.setter
    def GridlineStyleTop(self, value):
        self.com_object.GridlineStyleTop = value

    @property
    def gridlinestyletop(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridlinestyletop.setter
    def gridlinestyletop(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def gridline_style_top(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridline_style_top.setter
    def gridline_style_top(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def GridlineThemeColorIndex(self):
        return self.com_object.GridlineThemeColorIndex

    @GridlineThemeColorIndex.setter
    def GridlineThemeColorIndex(self, value):
        self.com_object.GridlineThemeColorIndex = value

    @property
    def gridlinethemecolorindex(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridlinethemecolorindex.setter
    def gridlinethemecolorindex(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def gridline_theme_color_index(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridline_theme_color_index.setter
    def gridline_theme_color_index(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def GridlineTint(self):
        return self.com_object.GridlineTint

    @GridlineTint.setter
    def GridlineTint(self, value):
        self.com_object.GridlineTint = value

    @property
    def gridlinetint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridlinetint.setter
    def gridlinetint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def gridline_tint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridline_tint.setter
    def gridline_tint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def GridlineWidthBottom(self):
        return self.com_object.GridlineWidthBottom

    @GridlineWidthBottom.setter
    def GridlineWidthBottom(self, value):
        self.com_object.GridlineWidthBottom = value

    @property
    def gridlinewidthbottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridlinewidthbottom.setter
    def gridlinewidthbottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def gridline_width_bottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridline_width_bottom.setter
    def gridline_width_bottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def GridlineWidthLeft(self):
        return self.com_object.GridlineWidthLeft

    @GridlineWidthLeft.setter
    def GridlineWidthLeft(self, value):
        self.com_object.GridlineWidthLeft = value

    @property
    def gridlinewidthleft(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridlinewidthleft.setter
    def gridlinewidthleft(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def gridline_width_left(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridline_width_left.setter
    def gridline_width_left(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def GridlineWidthRight(self):
        return self.com_object.GridlineWidthRight

    @GridlineWidthRight.setter
    def GridlineWidthRight(self, value):
        self.com_object.GridlineWidthRight = value

    @property
    def gridlinewidthright(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridlinewidthright.setter
    def gridlinewidthright(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def gridline_width_right(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridline_width_right.setter
    def gridline_width_right(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def GridlineWidthTop(self):
        return self.com_object.GridlineWidthTop

    @GridlineWidthTop.setter
    def GridlineWidthTop(self, value):
        self.com_object.GridlineWidthTop = value

    @property
    def gridlinewidthtop(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridlinewidthtop.setter
    def gridlinewidthtop(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def gridline_width_top(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridline_width_top.setter
    def gridline_width_top(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HelpContextId(self):
        return self.com_object.HelpContextId

    @HelpContextId.setter
    def HelpContextId(self, value):
        self.com_object.HelpContextId = value

    @property
    def helpcontextid(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @helpcontextid.setter
    def helpcontextid(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def help_context_id(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @help_context_id.setter
    def help_context_id(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def HideDuplicates(self):
        return self.com_object.HideDuplicates

    @HideDuplicates.setter
    def HideDuplicates(self, value):
        self.com_object.HideDuplicates = value

    @property
    def hideduplicates(self):
        """Alias for HideDuplicates"""
        return self.HideDuplicates

    @hideduplicates.setter
    def hideduplicates(self, value):
        """Alias for HideDuplicates.setter"""
        self.HideDuplicates = value

    @property
    def hide_duplicates(self):
        """Alias for HideDuplicates"""
        return self.HideDuplicates

    @hide_duplicates.setter
    def hide_duplicates(self, value):
        """Alias for HideDuplicates.setter"""
        self.HideDuplicates = value

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def IsVisible(self):
        return self.com_object.IsVisible

    @IsVisible.setter
    def IsVisible(self, value):
        self.com_object.IsVisible = value

    @property
    def isvisible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @isvisible.setter
    def isvisible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def is_visible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @is_visible.setter
    def is_visible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def LabelAlign(self):
        return self.com_object.LabelAlign

    @LabelAlign.setter
    def LabelAlign(self, value):
        self.com_object.LabelAlign = value

    @property
    def labelalign(self):
        """Alias for LabelAlign"""
        return self.LabelAlign

    @labelalign.setter
    def labelalign(self, value):
        """Alias for LabelAlign.setter"""
        self.LabelAlign = value

    @property
    def label_align(self):
        """Alias for LabelAlign"""
        return self.LabelAlign

    @label_align.setter
    def label_align(self, value):
        """Alias for LabelAlign.setter"""
        self.LabelAlign = value

    @property
    def LabelX(self):
        return self.com_object.LabelX

    @LabelX.setter
    def LabelX(self, value):
        self.com_object.LabelX = value

    @property
    def labelx(self):
        """Alias for LabelX"""
        return self.LabelX

    @labelx.setter
    def labelx(self, value):
        """Alias for LabelX.setter"""
        self.LabelX = value

    @property
    def label_x(self):
        """Alias for LabelX"""
        return self.LabelX

    @label_x.setter
    def label_x(self, value):
        """Alias for LabelX.setter"""
        self.LabelX = value

    @property
    def LabelY(self):
        return self.com_object.LabelY

    @LabelY.setter
    def LabelY(self, value):
        self.com_object.LabelY = value

    @property
    def labely(self):
        """Alias for LabelY"""
        return self.LabelY

    @labely.setter
    def labely(self, value):
        """Alias for LabelY.setter"""
        self.LabelY = value

    @property
    def label_y(self):
        """Alias for LabelY"""
        return self.LabelY

    @label_y.setter
    def label_y(self, value):
        """Alias for LabelY.setter"""
        self.LabelY = value

    @property
    def Layout(self):
        return AcLayoutType(self.com_object.Layout)

    @property
    def layout(self):
        """Alias for Layout"""
        return self.Layout

    @property
    def LayoutID(self):
        return self.com_object.LayoutID

    @property
    def layoutid(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def layout_i_d(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def LeftPadding(self):
        return self.com_object.LeftPadding

    @LeftPadding.setter
    def LeftPadding(self, value):
        self.com_object.LeftPadding = value

    @property
    def leftpadding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @leftpadding.setter
    def leftpadding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def left_padding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @left_padding.setter
    def left_padding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def OldBorderStyle(self):
        return self.com_object.OldBorderStyle

    @OldBorderStyle.setter
    def OldBorderStyle(self, value):
        self.com_object.OldBorderStyle = value

    @property
    def oldborderstyle(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @oldborderstyle.setter
    def oldborderstyle(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def old_border_style(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @old_border_style.setter
    def old_border_style(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def OldValue(self):
        return self.com_object.OldValue

    @property
    def oldvalue(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def old_value(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def OnClick(self):
        return self.com_object.OnClick

    @OnClick.setter
    def OnClick(self, value):
        self.com_object.OnClick = value

    @property
    def onclick(self):
        """Alias for OnClick"""
        return self.OnClick

    @onclick.setter
    def onclick(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def on_click(self):
        """Alias for OnClick"""
        return self.OnClick

    @on_click.setter
    def on_click(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def OnDblClick(self):
        return self.com_object.OnDblClick

    @OnDblClick.setter
    def OnDblClick(self, value):
        self.com_object.OnDblClick = value

    @property
    def ondblclick(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @ondblclick.setter
    def ondblclick(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def on_dbl_click(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @on_dbl_click.setter
    def on_dbl_click(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def OnEnter(self):
        return self.com_object.OnEnter

    @OnEnter.setter
    def OnEnter(self, value):
        self.com_object.OnEnter = value

    @property
    def onenter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @onenter.setter
    def onenter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def on_enter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @on_enter.setter
    def on_enter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def OnExit(self):
        return self.com_object.OnExit

    @OnExit.setter
    def OnExit(self, value):
        self.com_object.OnExit = value

    @property
    def onexit(self):
        """Alias for OnExit"""
        return self.OnExit

    @onexit.setter
    def onexit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def on_exit(self):
        """Alias for OnExit"""
        return self.OnExit

    @on_exit.setter
    def on_exit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def OnGotFocus(self):
        return self.com_object.OnGotFocus

    @OnGotFocus.setter
    def OnGotFocus(self, value):
        self.com_object.OnGotFocus = value

    @property
    def ongotfocus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @ongotfocus.setter
    def ongotfocus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def on_got_focus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @on_got_focus.setter
    def on_got_focus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def OnKeyDown(self):
        return self.com_object.OnKeyDown

    @OnKeyDown.setter
    def OnKeyDown(self, value):
        self.com_object.OnKeyDown = value

    @property
    def onkeydown(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @onkeydown.setter
    def onkeydown(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def on_key_down(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @on_key_down.setter
    def on_key_down(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def OnKeyPress(self):
        return self.com_object.OnKeyPress

    @OnKeyPress.setter
    def OnKeyPress(self, value):
        self.com_object.OnKeyPress = value

    @property
    def onkeypress(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @onkeypress.setter
    def onkeypress(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def on_key_press(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @on_key_press.setter
    def on_key_press(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def OnKeyUp(self):
        return self.com_object.OnKeyUp

    @OnKeyUp.setter
    def OnKeyUp(self, value):
        self.com_object.OnKeyUp = value

    @property
    def onkeyup(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @onkeyup.setter
    def onkeyup(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def on_key_up(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @on_key_up.setter
    def on_key_up(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def OnLostFocus(self):
        return self.com_object.OnLostFocus

    @OnLostFocus.setter
    def OnLostFocus(self, value):
        self.com_object.OnLostFocus = value

    @property
    def onlostfocus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @onlostfocus.setter
    def onlostfocus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def on_lost_focus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @on_lost_focus.setter
    def on_lost_focus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def OnMouseDown(self):
        return self.com_object.OnMouseDown

    @OnMouseDown.setter
    def OnMouseDown(self, value):
        self.com_object.OnMouseDown = value

    @property
    def onmousedown(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @onmousedown.setter
    def onmousedown(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def on_mouse_down(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @on_mouse_down.setter
    def on_mouse_down(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def OnMouseMove(self):
        return self.com_object.OnMouseMove

    @OnMouseMove.setter
    def OnMouseMove(self, value):
        self.com_object.OnMouseMove = value

    @property
    def onmousemove(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @onmousemove.setter
    def onmousemove(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def on_mouse_move(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @on_mouse_move.setter
    def on_mouse_move(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def OnMouseUp(self):
        return self.com_object.OnMouseUp

    @OnMouseUp.setter
    def OnMouseUp(self, value):
        self.com_object.OnMouseUp = value

    @property
    def onmouseup(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @onmouseup.setter
    def onmouseup(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def on_mouse_up(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @on_mouse_up.setter
    def on_mouse_up(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def OptionValue(self):
        return self.com_object.OptionValue

    @OptionValue.setter
    def OptionValue(self, value):
        self.com_object.OptionValue = value

    @property
    def optionvalue(self):
        """Alias for OptionValue"""
        return self.OptionValue

    @optionvalue.setter
    def optionvalue(self, value):
        """Alias for OptionValue.setter"""
        self.OptionValue = value

    @property
    def option_value(self):
        """Alias for OptionValue"""
        return self.OptionValue

    @option_value.setter
    def option_value(self, value):
        """Alias for OptionValue.setter"""
        self.OptionValue = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def ReadingOrder(self):
        return self.com_object.ReadingOrder

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def RightPadding(self):
        return self.com_object.RightPadding

    @RightPadding.setter
    def RightPadding(self, value):
        self.com_object.RightPadding = value

    @property
    def rightpadding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @rightpadding.setter
    def rightpadding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def right_padding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @right_padding.setter
    def right_padding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def Section(self):
        return self.com_object.Section

    @Section.setter
    def Section(self, value):
        self.com_object.Section = value

    @property
    def section(self):
        """Alias for Section"""
        return self.Section

    @section.setter
    def section(self, value):
        """Alias for Section.setter"""
        self.Section = value

    @property
    def ShortcutMenuBar(self):
        return self.com_object.ShortcutMenuBar

    @ShortcutMenuBar.setter
    def ShortcutMenuBar(self, value):
        self.com_object.ShortcutMenuBar = value

    @property
    def shortcutmenubar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcutmenubar.setter
    def shortcutmenubar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def shortcut_menu_bar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcut_menu_bar.setter
    def shortcut_menu_bar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def SpecialEffect(self):
        return self.com_object.SpecialEffect

    @SpecialEffect.setter
    def SpecialEffect(self, value):
        self.com_object.SpecialEffect = value

    @property
    def specialeffect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @specialeffect.setter
    def specialeffect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def special_effect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @special_effect.setter
    def special_effect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def StatusBarText(self):
        return self.com_object.StatusBarText

    @StatusBarText.setter
    def StatusBarText(self, value):
        self.com_object.StatusBarText = value

    @property
    def statusbartext(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @statusbartext.setter
    def statusbartext(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def status_bar_text(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @status_bar_text.setter
    def status_bar_text(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def TabIndex(self):
        return self.com_object.TabIndex

    @TabIndex.setter
    def TabIndex(self, value):
        self.com_object.TabIndex = value

    @property
    def tabindex(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tabindex.setter
    def tabindex(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def tab_index(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tab_index.setter
    def tab_index(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def TabStop(self):
        return self.com_object.TabStop

    @TabStop.setter
    def TabStop(self, value):
        self.com_object.TabStop = value

    @property
    def tabstop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tabstop.setter
    def tabstop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def tab_stop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tab_stop.setter
    def tab_stop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TopPadding(self):
        return self.com_object.TopPadding

    @TopPadding.setter
    def TopPadding(self, value):
        self.com_object.TopPadding = value

    @property
    def toppadding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @toppadding.setter
    def toppadding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def top_padding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @top_padding.setter
    def top_padding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def TripleState(self):
        return self.com_object.TripleState

    @TripleState.setter
    def TripleState(self, value):
        self.com_object.TripleState = value

    @property
    def triplestate(self):
        """Alias for TripleState"""
        return self.TripleState

    @triplestate.setter
    def triplestate(self, value):
        """Alias for TripleState.setter"""
        self.TripleState = value

    @property
    def triple_state(self):
        """Alias for TripleState"""
        return self.TripleState

    @triple_state.setter
    def triple_state(self, value):
        """Alias for TripleState.setter"""
        self.TripleState = value

    @property
    def ValidationRule(self):
        return self.com_object.ValidationRule

    @ValidationRule.setter
    def ValidationRule(self, value):
        self.com_object.ValidationRule = value

    @property
    def validationrule(self):
        """Alias for ValidationRule"""
        return self.ValidationRule

    @validationrule.setter
    def validationrule(self, value):
        """Alias for ValidationRule.setter"""
        self.ValidationRule = value

    @property
    def validation_rule(self):
        """Alias for ValidationRule"""
        return self.ValidationRule

    @validation_rule.setter
    def validation_rule(self, value):
        """Alias for ValidationRule.setter"""
        self.ValidationRule = value

    @property
    def ValidationText(self):
        return self.com_object.ValidationText

    @ValidationText.setter
    def ValidationText(self, value):
        self.com_object.ValidationText = value

    @property
    def validationtext(self):
        """Alias for ValidationText"""
        return self.ValidationText

    @validationtext.setter
    def validationtext(self, value):
        """Alias for ValidationText.setter"""
        self.ValidationText = value

    @property
    def validation_text(self):
        """Alias for ValidationText"""
        return self.ValidationText

    @validation_text.setter
    def validation_text(self, value):
        """Alias for ValidationText.setter"""
        self.ValidationText = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def Requery(self):
        self.com_object.Requery()

    def requery(self):
        """Alias for Requery"""
        return self.Requery()

    def SetFocus(self):
        return self.com_object.SetFocus()

    def setfocus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def set_focus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def Undo(self):
        self.com_object.Undo()

    def undo(self):
        """Alias for Undo"""
        return self.Undo()


class CodeData:

    def __init__(self, codedata=None):
        self.com_object= codedata

    @property
    def AllDatabaseDiagrams(self):
        return self.com_object.AllDatabaseDiagrams

    @property
    def alldatabasediagrams(self):
        """Alias for AllDatabaseDiagrams"""
        return self.AllDatabaseDiagrams

    @property
    def all_database_diagrams(self):
        """Alias for AllDatabaseDiagrams"""
        return self.AllDatabaseDiagrams

    @property
    def AllFunctions(self):
        return self.com_object.AllFunctions

    @property
    def allfunctions(self):
        """Alias for AllFunctions"""
        return self.AllFunctions

    @property
    def all_functions(self):
        """Alias for AllFunctions"""
        return self.AllFunctions

    @property
    def AllQueries(self):
        return self.com_object.AllQueries

    @property
    def allqueries(self):
        """Alias for AllQueries"""
        return self.AllQueries

    @property
    def all_queries(self):
        """Alias for AllQueries"""
        return self.AllQueries

    @property
    def AllStoredProcedures(self):
        return self.com_object.AllStoredProcedures

    @property
    def allstoredprocedures(self):
        """Alias for AllStoredProcedures"""
        return self.AllStoredProcedures

    @property
    def all_stored_procedures(self):
        """Alias for AllStoredProcedures"""
        return self.AllStoredProcedures

    @property
    def AllTables(self):
        return self.com_object.AllTables

    @property
    def alltables(self):
        """Alias for AllTables"""
        return self.AllTables

    @property
    def all_tables(self):
        """Alias for AllTables"""
        return self.AllTables

    @property
    def AllViews(self):
        return self.com_object.AllViews

    @property
    def allviews(self):
        """Alias for AllViews"""
        return self.AllViews

    @property
    def all_views(self):
        """Alias for AllViews"""
        return self.AllViews


class CodeProject:

    def __init__(self, codeproject=None):
        self.com_object= codeproject

    @property
    def AccessConnection(self):
        return self.com_object.AccessConnection

    @property
    def accessconnection(self):
        """Alias for AccessConnection"""
        return self.AccessConnection

    @property
    def access_connection(self):
        """Alias for AccessConnection"""
        return self.AccessConnection

    @property
    def AllForms(self):
        return self.com_object.AllForms

    @property
    def allforms(self):
        """Alias for AllForms"""
        return self.AllForms

    @property
    def all_forms(self):
        """Alias for AllForms"""
        return self.AllForms

    @property
    def AllMacros(self):
        return self.com_object.AllMacros

    @property
    def allmacros(self):
        """Alias for AllMacros"""
        return self.AllMacros

    @property
    def all_macros(self):
        """Alias for AllMacros"""
        return self.AllMacros

    @property
    def AllModules(self):
        return self.com_object.AllModules

    @property
    def allmodules(self):
        """Alias for AllModules"""
        return self.AllModules

    @property
    def all_modules(self):
        """Alias for AllModules"""
        return self.AllModules

    @property
    def AllReports(self):
        return self.com_object.AllReports

    @property
    def allreports(self):
        """Alias for AllReports"""
        return self.AllReports

    @property
    def all_reports(self):
        """Alias for AllReports"""
        return self.AllReports

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BaseConnectionString(self):
        return self.com_object.BaseConnectionString

    @property
    def baseconnectionstring(self):
        """Alias for BaseConnectionString"""
        return self.BaseConnectionString

    @property
    def base_connection_string(self):
        """Alias for BaseConnectionString"""
        return self.BaseConnectionString

    @property
    def Connection(self):
        return self.com_object.Connection

    @property
    def connection(self):
        """Alias for Connection"""
        return self.Connection

    @property
    def FileFormat(self):
        return AcFileFormat(self.com_object.FileFormat)

    @property
    def fileformat(self):
        """Alias for FileFormat"""
        return self.FileFormat

    @property
    def file_format(self):
        """Alias for FileFormat"""
        return self.FileFormat

    @property
    def FullName(self):
        return self.com_object.FullName

    @property
    def fullname(self):
        """Alias for FullName"""
        return self.FullName

    @property
    def full_name(self):
        """Alias for FullName"""
        return self.FullName

    @property
    def ImportExportSpecifications(self):
        return ImportExportSpecifications(self.com_object.ImportExportSpecifications)

    @property
    def importexportspecifications(self):
        """Alias for ImportExportSpecifications"""
        return self.ImportExportSpecifications

    @property
    def import_export_specifications(self):
        """Alias for ImportExportSpecifications"""
        return self.ImportExportSpecifications

    @property
    def IsConnected(self):
        return self.com_object.IsConnected

    @property
    def isconnected(self):
        """Alias for IsConnected"""
        return self.IsConnected

    @property
    def is_connected(self):
        """Alias for IsConnected"""
        return self.IsConnected

    @property
    def IsSQLBackend(self):
        return self.com_object.IsSQLBackend

    @property
    def issqlbackend(self):
        """Alias for IsSQLBackend"""
        return self.IsSQLBackend

    @property
    def is_s_q_l_backend(self):
        """Alias for IsSQLBackend"""
        return self.IsSQLBackend

    @property
    def IsTrusted(self):
        return self.com_object.IsTrusted

    @property
    def istrusted(self):
        """Alias for IsTrusted"""
        return self.IsTrusted

    @property
    def is_trusted(self):
        """Alias for IsTrusted"""
        return self.IsTrusted

    @property
    def IsWeb(self):
        return self.com_object.IsWeb

    @property
    def isweb(self):
        """Alias for IsWeb"""
        return self.IsWeb

    @property
    def is_web(self):
        """Alias for IsWeb"""
        return self.IsWeb

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Path(self):
        return self.com_object.Path

    @property
    def path(self):
        """Alias for Path"""
        return self.Path

    @property
    def ProjectType(self):
        return self.com_object.ProjectType

    @property
    def projecttype(self):
        """Alias for ProjectType"""
        return self.ProjectType

    @property
    def project_type(self):
        """Alias for ProjectType"""
        return self.ProjectType

    @property
    def Properties(self):
        return CodeProject(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def RemovePersonalInformation(self):
        return self.com_object.RemovePersonalInformation

    @RemovePersonalInformation.setter
    def RemovePersonalInformation(self, value):
        self.com_object.RemovePersonalInformation = value

    @property
    def removepersonalinformation(self):
        """Alias for RemovePersonalInformation"""
        return self.RemovePersonalInformation

    @removepersonalinformation.setter
    def removepersonalinformation(self, value):
        """Alias for RemovePersonalInformation.setter"""
        self.RemovePersonalInformation = value

    @property
    def remove_personal_information(self):
        """Alias for RemovePersonalInformation"""
        return self.RemovePersonalInformation

    @remove_personal_information.setter
    def remove_personal_information(self, value):
        """Alias for RemovePersonalInformation.setter"""
        self.RemovePersonalInformation = value

    @property
    def Resources(self):
        return self.com_object.Resources

    @property
    def resources(self):
        """Alias for Resources"""
        return self.Resources

    @property
    def WebSite(self):
        return self.com_object.WebSite

    @property
    def website(self):
        """Alias for WebSite"""
        return self.WebSite

    @property
    def web_site(self):
        """Alias for WebSite"""
        return self.WebSite

    def AddSharedImage(self, SharedImageName=None, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [SharedImageName, FileName]])
        self.com_object.AddSharedImage(*arguments)

    def addsharedimage(self, SharedImageName=None, FileName=None):
        """Alias for AddSharedImage"""
        arguments = [SharedImageName, FileName]
        return self.AddSharedImage(*arguments)

    def add_shared_image(self, SharedImageName=None, FileName=None):
        """Alias for AddSharedImage"""
        arguments = [SharedImageName, FileName]
        return self.AddSharedImage(*arguments)

    def CloseConnection(self):
        return self.com_object.CloseConnection()

    def closeconnection(self):
        """Alias for CloseConnection"""
        return self.CloseConnection()

    def close_connection(self):
        """Alias for CloseConnection"""
        return self.CloseConnection()

    def OpenConnection(self, BaseConnectionString=None, UserID=None, Password=None):
        arguments = com_arguments([unwrap(a) for a in [BaseConnectionString, UserID, Password]])
        self.com_object.OpenConnection(*arguments)

    def openconnection(self, BaseConnectionString=None, UserID=None, Password=None):
        """Alias for OpenConnection"""
        arguments = [BaseConnectionString, UserID, Password]
        return self.OpenConnection(*arguments)

    def open_connection(self, BaseConnectionString=None, UserID=None, Password=None):
        """Alias for OpenConnection"""
        arguments = [BaseConnectionString, UserID, Password]
        return self.OpenConnection(*arguments)

    def UpdateDependencyInfo(self):
        return self.com_object.UpdateDependencyInfo()

    def updatedependencyinfo(self):
        """Alias for UpdateDependencyInfo"""
        return self.UpdateDependencyInfo()

    def update_dependency_info(self):
        """Alias for UpdateDependencyInfo"""
        return self.UpdateDependencyInfo()


class ComboBoxUse:

    def __init__(self, comboboxuse=None):
        self.com_object= comboboxuse


class ComboBox:

    def __init__(self, combobox=None):
        self.com_object= combobox

    @property
    def AddColon(self):
        return self.com_object.AddColon

    @AddColon.setter
    def AddColon(self, value):
        self.com_object.AddColon = value

    @property
    def addcolon(self):
        """Alias for AddColon"""
        return self.AddColon

    @addcolon.setter
    def addcolon(self, value):
        """Alias for AddColon.setter"""
        self.AddColon = value

    @property
    def add_colon(self):
        """Alias for AddColon"""
        return self.AddColon

    @add_colon.setter
    def add_colon(self, value):
        """Alias for AddColon.setter"""
        self.AddColon = value

    @property
    def AllowAutoCorrect(self):
        return self.com_object.AllowAutoCorrect

    @AllowAutoCorrect.setter
    def AllowAutoCorrect(self, value):
        self.com_object.AllowAutoCorrect = value

    @property
    def allowautocorrect(self):
        """Alias for AllowAutoCorrect"""
        return self.AllowAutoCorrect

    @allowautocorrect.setter
    def allowautocorrect(self, value):
        """Alias for AllowAutoCorrect.setter"""
        self.AllowAutoCorrect = value

    @property
    def allow_auto_correct(self):
        """Alias for AllowAutoCorrect"""
        return self.AllowAutoCorrect

    @allow_auto_correct.setter
    def allow_auto_correct(self, value):
        """Alias for AllowAutoCorrect.setter"""
        self.AllowAutoCorrect = value

    @property
    def AllowValueListEdits(self):
        return self.com_object.AllowValueListEdits

    @AllowValueListEdits.setter
    def AllowValueListEdits(self, value):
        self.com_object.AllowValueListEdits = value

    @property
    def allowvaluelistedits(self):
        """Alias for AllowValueListEdits"""
        return self.AllowValueListEdits

    @allowvaluelistedits.setter
    def allowvaluelistedits(self, value):
        """Alias for AllowValueListEdits.setter"""
        self.AllowValueListEdits = value

    @property
    def allow_value_list_edits(self):
        """Alias for AllowValueListEdits"""
        return self.AllowValueListEdits

    @allow_value_list_edits.setter
    def allow_value_list_edits(self, value):
        """Alias for AllowValueListEdits.setter"""
        self.AllowValueListEdits = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoExpand(self):
        return self.com_object.AutoExpand

    @AutoExpand.setter
    def AutoExpand(self, value):
        self.com_object.AutoExpand = value

    @property
    def autoexpand(self):
        """Alias for AutoExpand"""
        return self.AutoExpand

    @autoexpand.setter
    def autoexpand(self, value):
        """Alias for AutoExpand.setter"""
        self.AutoExpand = value

    @property
    def auto_expand(self):
        """Alias for AutoExpand"""
        return self.AutoExpand

    @auto_expand.setter
    def auto_expand(self, value):
        """Alias for AutoExpand.setter"""
        self.AutoExpand = value

    @property
    def AutoLabel(self):
        return self.com_object.AutoLabel

    @AutoLabel.setter
    def AutoLabel(self, value):
        self.com_object.AutoLabel = value

    @property
    def autolabel(self):
        """Alias for AutoLabel"""
        return self.AutoLabel

    @autolabel.setter
    def autolabel(self, value):
        """Alias for AutoLabel.setter"""
        self.AutoLabel = value

    @property
    def auto_label(self):
        """Alias for AutoLabel"""
        return self.AutoLabel

    @auto_label.setter
    def auto_label(self, value):
        """Alias for AutoLabel.setter"""
        self.AutoLabel = value

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BackShade(self):
        return self.com_object.BackShade

    @BackShade.setter
    def BackShade(self, value):
        self.com_object.BackShade = value

    @property
    def backshade(self):
        """Alias for BackShade"""
        return self.BackShade

    @backshade.setter
    def backshade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def back_shade(self):
        """Alias for BackShade"""
        return self.BackShade

    @back_shade.setter
    def back_shade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def BackStyle(self):
        return self.com_object.BackStyle

    @BackStyle.setter
    def BackStyle(self, value):
        self.com_object.BackStyle = value

    @property
    def backstyle(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @backstyle.setter
    def backstyle(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def back_style(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @back_style.setter
    def back_style(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def BackThemeColorIndex(self):
        return self.com_object.BackThemeColorIndex

    @BackThemeColorIndex.setter
    def BackThemeColorIndex(self, value):
        self.com_object.BackThemeColorIndex = value

    @property
    def backthemecolorindex(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @backthemecolorindex.setter
    def backthemecolorindex(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def back_theme_color_index(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @back_theme_color_index.setter
    def back_theme_color_index(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def BackTint(self):
        return self.com_object.BackTint

    @BackTint.setter
    def BackTint(self, value):
        self.com_object.BackTint = value

    @property
    def backtint(self):
        """Alias for BackTint"""
        return self.BackTint

    @backtint.setter
    def backtint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def back_tint(self):
        """Alias for BackTint"""
        return self.BackTint

    @back_tint.setter
    def back_tint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def BorderColor(self):
        return self.com_object.BorderColor

    @BorderColor.setter
    def BorderColor(self, value):
        self.com_object.BorderColor = value

    @property
    def bordercolor(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @bordercolor.setter
    def bordercolor(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def border_color(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @border_color.setter
    def border_color(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def BorderShade(self):
        return self.com_object.BorderShade

    @BorderShade.setter
    def BorderShade(self, value):
        self.com_object.BorderShade = value

    @property
    def bordershade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @bordershade.setter
    def bordershade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def border_shade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @border_shade.setter
    def border_shade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def BorderStyle(self):
        return self.com_object.BorderStyle

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def BorderThemeColorIndex(self):
        return self.com_object.BorderThemeColorIndex

    @BorderThemeColorIndex.setter
    def BorderThemeColorIndex(self, value):
        self.com_object.BorderThemeColorIndex = value

    @property
    def borderthemecolorindex(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @borderthemecolorindex.setter
    def borderthemecolorindex(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def border_theme_color_index(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @border_theme_color_index.setter
    def border_theme_color_index(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def BorderTint(self):
        return self.com_object.BorderTint

    @BorderTint.setter
    def BorderTint(self, value):
        self.com_object.BorderTint = value

    @property
    def bordertint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @bordertint.setter
    def bordertint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def border_tint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @border_tint.setter
    def border_tint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def BorderWidth(self):
        return self.com_object.BorderWidth

    @BorderWidth.setter
    def BorderWidth(self, value):
        self.com_object.BorderWidth = value

    @property
    def borderwidth(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @borderwidth.setter
    def borderwidth(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def border_width(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @border_width.setter
    def border_width(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def BottomMargin(self):
        return self.com_object.BottomMargin

    @BottomMargin.setter
    def BottomMargin(self, value):
        self.com_object.BottomMargin = value

    @property
    def bottommargin(self):
        """Alias for BottomMargin"""
        return self.BottomMargin

    @bottommargin.setter
    def bottommargin(self, value):
        """Alias for BottomMargin.setter"""
        self.BottomMargin = value

    @property
    def bottom_margin(self):
        """Alias for BottomMargin"""
        return self.BottomMargin

    @bottom_margin.setter
    def bottom_margin(self, value):
        """Alias for BottomMargin.setter"""
        self.BottomMargin = value

    @property
    def BottomPadding(self):
        return self.com_object.BottomPadding

    @BottomPadding.setter
    def BottomPadding(self, value):
        self.com_object.BottomPadding = value

    @property
    def bottompadding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottompadding.setter
    def bottompadding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def bottom_padding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottom_padding.setter
    def bottom_padding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def BoundColumn(self):
        return self.com_object.BoundColumn

    @BoundColumn.setter
    def BoundColumn(self, value):
        self.com_object.BoundColumn = value

    @property
    def boundcolumn(self):
        """Alias for BoundColumn"""
        return self.BoundColumn

    @boundcolumn.setter
    def boundcolumn(self, value):
        """Alias for BoundColumn.setter"""
        self.BoundColumn = value

    @property
    def bound_column(self):
        """Alias for BoundColumn"""
        return self.BoundColumn

    @bound_column.setter
    def bound_column(self, value):
        """Alias for BoundColumn.setter"""
        self.BoundColumn = value

    @property
    def CanGrow(self):
        return self.com_object.CanGrow

    @CanGrow.setter
    def CanGrow(self, value):
        self.com_object.CanGrow = value

    @property
    def cangrow(self):
        """Alias for CanGrow"""
        return self.CanGrow

    @cangrow.setter
    def cangrow(self, value):
        """Alias for CanGrow.setter"""
        self.CanGrow = value

    @property
    def can_grow(self):
        """Alias for CanGrow"""
        return self.CanGrow

    @can_grow.setter
    def can_grow(self, value):
        """Alias for CanGrow.setter"""
        self.CanGrow = value

    @property
    def CanShrink(self):
        return self.com_object.CanShrink

    @CanShrink.setter
    def CanShrink(self, value):
        self.com_object.CanShrink = value

    @property
    def canshrink(self):
        """Alias for CanShrink"""
        return self.CanShrink

    @canshrink.setter
    def canshrink(self, value):
        """Alias for CanShrink.setter"""
        self.CanShrink = value

    @property
    def can_shrink(self):
        """Alias for CanShrink"""
        return self.CanShrink

    @can_shrink.setter
    def can_shrink(self, value):
        """Alias for CanShrink.setter"""
        self.CanShrink = value

    def Column(self, Index=None, Row=None):
        arguments = com_arguments([unwrap(a) for a in [Index, Row]])
        if hasattr(self.com_object, "GetColumn"):
            return self.com_object.GetColumn(*arguments)
        else:
            return self.com_object.Column(*arguments)

    def column(self, Index=None, Row=None):
        """Alias for Column"""
        arguments = [Index, Row]
        return self.Column(*arguments)

    @property
    def ColumnCount(self):
        return self.com_object.ColumnCount

    @ColumnCount.setter
    def ColumnCount(self, value):
        self.com_object.ColumnCount = value

    @property
    def columncount(self):
        """Alias for ColumnCount"""
        return self.ColumnCount

    @columncount.setter
    def columncount(self, value):
        """Alias for ColumnCount.setter"""
        self.ColumnCount = value

    @property
    def column_count(self):
        """Alias for ColumnCount"""
        return self.ColumnCount

    @column_count.setter
    def column_count(self, value):
        """Alias for ColumnCount.setter"""
        self.ColumnCount = value

    @property
    def ColumnHeads(self):
        return self.com_object.ColumnHeads

    @ColumnHeads.setter
    def ColumnHeads(self, value):
        self.com_object.ColumnHeads = value

    @property
    def columnheads(self):
        """Alias for ColumnHeads"""
        return self.ColumnHeads

    @columnheads.setter
    def columnheads(self, value):
        """Alias for ColumnHeads.setter"""
        self.ColumnHeads = value

    @property
    def column_heads(self):
        """Alias for ColumnHeads"""
        return self.ColumnHeads

    @column_heads.setter
    def column_heads(self, value):
        """Alias for ColumnHeads.setter"""
        self.ColumnHeads = value

    @property
    def ColumnHidden(self):
        return self.com_object.ColumnHidden

    @ColumnHidden.setter
    def ColumnHidden(self, value):
        self.com_object.ColumnHidden = value

    @property
    def columnhidden(self):
        """Alias for ColumnHidden"""
        return self.ColumnHidden

    @columnhidden.setter
    def columnhidden(self, value):
        """Alias for ColumnHidden.setter"""
        self.ColumnHidden = value

    @property
    def column_hidden(self):
        """Alias for ColumnHidden"""
        return self.ColumnHidden

    @column_hidden.setter
    def column_hidden(self, value):
        """Alias for ColumnHidden.setter"""
        self.ColumnHidden = value

    @property
    def ColumnOrder(self):
        return self.com_object.ColumnOrder

    @ColumnOrder.setter
    def ColumnOrder(self, value):
        self.com_object.ColumnOrder = value

    @property
    def columnorder(self):
        """Alias for ColumnOrder"""
        return self.ColumnOrder

    @columnorder.setter
    def columnorder(self, value):
        """Alias for ColumnOrder.setter"""
        self.ColumnOrder = value

    @property
    def column_order(self):
        """Alias for ColumnOrder"""
        return self.ColumnOrder

    @column_order.setter
    def column_order(self, value):
        """Alias for ColumnOrder.setter"""
        self.ColumnOrder = value

    @property
    def ColumnWidth(self):
        return self.com_object.ColumnWidth

    @ColumnWidth.setter
    def ColumnWidth(self, value):
        self.com_object.ColumnWidth = value

    @property
    def columnwidth(self):
        """Alias for ColumnWidth"""
        return self.ColumnWidth

    @columnwidth.setter
    def columnwidth(self, value):
        """Alias for ColumnWidth.setter"""
        self.ColumnWidth = value

    @property
    def column_width(self):
        """Alias for ColumnWidth"""
        return self.ColumnWidth

    @column_width.setter
    def column_width(self, value):
        """Alias for ColumnWidth.setter"""
        self.ColumnWidth = value

    @property
    def ColumnWidths(self):
        return self.com_object.ColumnWidths

    @ColumnWidths.setter
    def ColumnWidths(self, value):
        self.com_object.ColumnWidths = value

    @property
    def columnwidths(self):
        """Alias for ColumnWidths"""
        return self.ColumnWidths

    @columnwidths.setter
    def columnwidths(self, value):
        """Alias for ColumnWidths.setter"""
        self.ColumnWidths = value

    @property
    def column_widths(self):
        """Alias for ColumnWidths"""
        return self.ColumnWidths

    @column_widths.setter
    def column_widths(self, value):
        """Alias for ColumnWidths.setter"""
        self.ColumnWidths = value

    @property
    def Controls(self):
        return Controls(self.com_object.Controls)

    @property
    def controls(self):
        """Alias for Controls"""
        return self.Controls

    @property
    def ControlSource(self):
        return self.com_object.ControlSource

    @ControlSource.setter
    def ControlSource(self, value):
        self.com_object.ControlSource = value

    @property
    def controlsource(self):
        """Alias for ControlSource"""
        return self.ControlSource

    @controlsource.setter
    def controlsource(self, value):
        """Alias for ControlSource.setter"""
        self.ControlSource = value

    @property
    def control_source(self):
        """Alias for ControlSource"""
        return self.ControlSource

    @control_source.setter
    def control_source(self, value):
        """Alias for ControlSource.setter"""
        self.ControlSource = value

    @property
    def ControlTipText(self):
        return self.com_object.ControlTipText

    @ControlTipText.setter
    def ControlTipText(self, value):
        self.com_object.ControlTipText = value

    @property
    def controltiptext(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @controltiptext.setter
    def controltiptext(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def control_tip_text(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @control_tip_text.setter
    def control_tip_text(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def ControlType(self):
        return self.com_object.ControlType

    @ControlType.setter
    def ControlType(self, value):
        self.com_object.ControlType = value

    @property
    def controltype(self):
        """Alias for ControlType"""
        return self.ControlType

    @controltype.setter
    def controltype(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def control_type(self):
        """Alias for ControlType"""
        return self.ControlType

    @control_type.setter
    def control_type(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def DecimalPlaces(self):
        return self.com_object.DecimalPlaces

    @DecimalPlaces.setter
    def DecimalPlaces(self, value):
        self.com_object.DecimalPlaces = value

    @property
    def decimalplaces(self):
        """Alias for DecimalPlaces"""
        return self.DecimalPlaces

    @decimalplaces.setter
    def decimalplaces(self, value):
        """Alias for DecimalPlaces.setter"""
        self.DecimalPlaces = value

    @property
    def decimal_places(self):
        """Alias for DecimalPlaces"""
        return self.DecimalPlaces

    @decimal_places.setter
    def decimal_places(self, value):
        """Alias for DecimalPlaces.setter"""
        self.DecimalPlaces = value

    @property
    def DefaultValue(self):
        return self.com_object.DefaultValue

    @DefaultValue.setter
    def DefaultValue(self, value):
        self.com_object.DefaultValue = value

    @property
    def defaultvalue(self):
        """Alias for DefaultValue"""
        return self.DefaultValue

    @defaultvalue.setter
    def defaultvalue(self, value):
        """Alias for DefaultValue.setter"""
        self.DefaultValue = value

    @property
    def default_value(self):
        """Alias for DefaultValue"""
        return self.DefaultValue

    @default_value.setter
    def default_value(self, value):
        """Alias for DefaultValue.setter"""
        self.DefaultValue = value

    @property
    def DisplayAsHyperlink(self):
        return self.com_object.DisplayAsHyperlink

    @DisplayAsHyperlink.setter
    def DisplayAsHyperlink(self, value):
        self.com_object.DisplayAsHyperlink = value

    @property
    def displayashyperlink(self):
        """Alias for DisplayAsHyperlink"""
        return self.DisplayAsHyperlink

    @displayashyperlink.setter
    def displayashyperlink(self, value):
        """Alias for DisplayAsHyperlink.setter"""
        self.DisplayAsHyperlink = value

    @property
    def display_as_hyperlink(self):
        """Alias for DisplayAsHyperlink"""
        return self.DisplayAsHyperlink

    @display_as_hyperlink.setter
    def display_as_hyperlink(self, value):
        """Alias for DisplayAsHyperlink.setter"""
        self.DisplayAsHyperlink = value

    @property
    def DisplayWhen(self):
        return self.com_object.DisplayWhen

    @DisplayWhen.setter
    def DisplayWhen(self, value):
        self.com_object.DisplayWhen = value

    @property
    def displaywhen(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @displaywhen.setter
    def displaywhen(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def display_when(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @display_when.setter
    def display_when(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def FontBold(self):
        return self.com_object.FontBold

    @property
    def fontbold(self):
        """Alias for FontBold"""
        return self.FontBold

    @property
    def font_bold(self):
        """Alias for FontBold"""
        return self.FontBold

    @property
    def FontItalic(self):
        return self.com_object.FontItalic

    @property
    def fontitalic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @property
    def font_italic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @property
    def FontName(self):
        return self.com_object.FontName

    @property
    def fontname(self):
        """Alias for FontName"""
        return self.FontName

    @property
    def font_name(self):
        """Alias for FontName"""
        return self.FontName

    @property
    def FontSize(self):
        return self.com_object.FontSize

    @property
    def fontsize(self):
        """Alias for FontSize"""
        return self.FontSize

    @property
    def font_size(self):
        """Alias for FontSize"""
        return self.FontSize

    @property
    def FontUnderline(self):
        return self.com_object.FontUnderline

    @property
    def fontunderline(self):
        """Alias for FontUnderline"""
        return self.FontUnderline

    @property
    def font_underline(self):
        """Alias for FontUnderline"""
        return self.FontUnderline

    @property
    def FontWeight(self):
        return self.com_object.FontWeight

    @FontWeight.setter
    def FontWeight(self, value):
        self.com_object.FontWeight = value

    @property
    def fontweight(self):
        """Alias for FontWeight"""
        return self.FontWeight

    @fontweight.setter
    def fontweight(self, value):
        """Alias for FontWeight.setter"""
        self.FontWeight = value

    @property
    def font_weight(self):
        """Alias for FontWeight"""
        return self.FontWeight

    @font_weight.setter
    def font_weight(self, value):
        """Alias for FontWeight.setter"""
        self.FontWeight = value

    @property
    def ForeColor(self):
        return self.com_object.ForeColor

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def ForeShade(self):
        return self.com_object.ForeShade

    @ForeShade.setter
    def ForeShade(self, value):
        self.com_object.ForeShade = value

    @property
    def foreshade(self):
        """Alias for ForeShade"""
        return self.ForeShade

    @foreshade.setter
    def foreshade(self, value):
        """Alias for ForeShade.setter"""
        self.ForeShade = value

    @property
    def fore_shade(self):
        """Alias for ForeShade"""
        return self.ForeShade

    @fore_shade.setter
    def fore_shade(self, value):
        """Alias for ForeShade.setter"""
        self.ForeShade = value

    @property
    def ForeThemeColorIndex(self):
        return self.com_object.ForeThemeColorIndex

    @ForeThemeColorIndex.setter
    def ForeThemeColorIndex(self, value):
        self.com_object.ForeThemeColorIndex = value

    @property
    def forethemecolorindex(self):
        """Alias for ForeThemeColorIndex"""
        return self.ForeThemeColorIndex

    @forethemecolorindex.setter
    def forethemecolorindex(self, value):
        """Alias for ForeThemeColorIndex.setter"""
        self.ForeThemeColorIndex = value

    @property
    def fore_theme_color_index(self):
        """Alias for ForeThemeColorIndex"""
        return self.ForeThemeColorIndex

    @fore_theme_color_index.setter
    def fore_theme_color_index(self, value):
        """Alias for ForeThemeColorIndex.setter"""
        self.ForeThemeColorIndex = value

    @property
    def ForeTint(self):
        return self.com_object.ForeTint

    @ForeTint.setter
    def ForeTint(self, value):
        self.com_object.ForeTint = value

    @property
    def foretint(self):
        """Alias for ForeTint"""
        return self.ForeTint

    @foretint.setter
    def foretint(self, value):
        """Alias for ForeTint.setter"""
        self.ForeTint = value

    @property
    def fore_tint(self):
        """Alias for ForeTint"""
        return self.ForeTint

    @fore_tint.setter
    def fore_tint(self, value):
        """Alias for ForeTint.setter"""
        self.ForeTint = value

    @property
    def Format(self):
        return self.com_object.Format

    @Format.setter
    def Format(self, value):
        self.com_object.Format = value

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @format.setter
    def format(self, value):
        """Alias for Format.setter"""
        self.Format = value

    @property
    def FormatConditions(self):
        return self.com_object.FormatConditions

    @property
    def formatconditions(self):
        """Alias for FormatConditions"""
        return self.FormatConditions

    @property
    def format_conditions(self):
        """Alias for FormatConditions"""
        return self.FormatConditions

    @property
    def GridlineColor(self):
        return self.com_object.GridlineColor

    @GridlineColor.setter
    def GridlineColor(self, value):
        self.com_object.GridlineColor = value

    @property
    def gridlinecolor(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridlinecolor.setter
    def gridlinecolor(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def gridline_color(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridline_color.setter
    def gridline_color(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def GridlineShade(self):
        return self.com_object.GridlineShade

    @GridlineShade.setter
    def GridlineShade(self, value):
        self.com_object.GridlineShade = value

    @property
    def gridlineshade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridlineshade.setter
    def gridlineshade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def gridline_shade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridline_shade.setter
    def gridline_shade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def GridlineStyleBottom(self):
        return self.com_object.GridlineStyleBottom

    @GridlineStyleBottom.setter
    def GridlineStyleBottom(self, value):
        self.com_object.GridlineStyleBottom = value

    @property
    def gridlinestylebottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridlinestylebottom.setter
    def gridlinestylebottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def gridline_style_bottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridline_style_bottom.setter
    def gridline_style_bottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def GridlineStyleLeft(self):
        return self.com_object.GridlineStyleLeft

    @property
    def gridlinestyleleft(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @property
    def gridline_style_left(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @property
    def GridlineStyleRight(self):
        return self.com_object.GridlineStyleRight

    @GridlineStyleRight.setter
    def GridlineStyleRight(self, value):
        self.com_object.GridlineStyleRight = value

    @property
    def gridlinestyleright(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridlinestyleright.setter
    def gridlinestyleright(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def gridline_style_right(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridline_style_right.setter
    def gridline_style_right(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def GridlineStyleTop(self):
        return self.com_object.GridlineStyleTop

    @GridlineStyleTop.setter
    def GridlineStyleTop(self, value):
        self.com_object.GridlineStyleTop = value

    @property
    def gridlinestyletop(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridlinestyletop.setter
    def gridlinestyletop(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def gridline_style_top(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridline_style_top.setter
    def gridline_style_top(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def GridlineThemeColorIndex(self):
        return self.com_object.GridlineThemeColorIndex

    @GridlineThemeColorIndex.setter
    def GridlineThemeColorIndex(self, value):
        self.com_object.GridlineThemeColorIndex = value

    @property
    def gridlinethemecolorindex(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridlinethemecolorindex.setter
    def gridlinethemecolorindex(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def gridline_theme_color_index(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridline_theme_color_index.setter
    def gridline_theme_color_index(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def GridlineTint(self):
        return self.com_object.GridlineTint

    @GridlineTint.setter
    def GridlineTint(self, value):
        self.com_object.GridlineTint = value

    @property
    def gridlinetint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridlinetint.setter
    def gridlinetint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def gridline_tint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridline_tint.setter
    def gridline_tint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def GridlineWidthBottom(self):
        return self.com_object.GridlineWidthBottom

    @GridlineWidthBottom.setter
    def GridlineWidthBottom(self, value):
        self.com_object.GridlineWidthBottom = value

    @property
    def gridlinewidthbottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridlinewidthbottom.setter
    def gridlinewidthbottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def gridline_width_bottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridline_width_bottom.setter
    def gridline_width_bottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def GridlineWidthLeft(self):
        return self.com_object.GridlineWidthLeft

    @GridlineWidthLeft.setter
    def GridlineWidthLeft(self, value):
        self.com_object.GridlineWidthLeft = value

    @property
    def gridlinewidthleft(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridlinewidthleft.setter
    def gridlinewidthleft(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def gridline_width_left(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridline_width_left.setter
    def gridline_width_left(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def GridlineWidthRight(self):
        return self.com_object.GridlineWidthRight

    @GridlineWidthRight.setter
    def GridlineWidthRight(self, value):
        self.com_object.GridlineWidthRight = value

    @property
    def gridlinewidthright(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridlinewidthright.setter
    def gridlinewidthright(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def gridline_width_right(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridline_width_right.setter
    def gridline_width_right(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def GridlineWidthTop(self):
        return self.com_object.GridlineWidthTop

    @GridlineWidthTop.setter
    def GridlineWidthTop(self, value):
        self.com_object.GridlineWidthTop = value

    @property
    def gridlinewidthtop(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridlinewidthtop.setter
    def gridlinewidthtop(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def gridline_width_top(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridline_width_top.setter
    def gridline_width_top(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HelpContextId(self):
        return self.com_object.HelpContextId

    @HelpContextId.setter
    def HelpContextId(self, value):
        self.com_object.HelpContextId = value

    @property
    def helpcontextid(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @helpcontextid.setter
    def helpcontextid(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def help_context_id(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @help_context_id.setter
    def help_context_id(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def HideDuplicates(self):
        return self.com_object.HideDuplicates

    @HideDuplicates.setter
    def HideDuplicates(self, value):
        self.com_object.HideDuplicates = value

    @property
    def hideduplicates(self):
        """Alias for HideDuplicates"""
        return self.HideDuplicates

    @hideduplicates.setter
    def hideduplicates(self, value):
        """Alias for HideDuplicates.setter"""
        self.HideDuplicates = value

    @property
    def hide_duplicates(self):
        """Alias for HideDuplicates"""
        return self.HideDuplicates

    @hide_duplicates.setter
    def hide_duplicates(self, value):
        """Alias for HideDuplicates.setter"""
        self.HideDuplicates = value

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def IMEHold(self):
        return self.com_object.IMEHold

    @IMEHold.setter
    def IMEHold(self, value):
        self.com_object.IMEHold = value

    @property
    def imehold(self):
        """Alias for IMEHold"""
        return self.IMEHold

    @imehold.setter
    def imehold(self, value):
        """Alias for IMEHold.setter"""
        self.IMEHold = value

    @property
    def i_m_e_hold(self):
        """Alias for IMEHold"""
        return self.IMEHold

    @i_m_e_hold.setter
    def i_m_e_hold(self, value):
        """Alias for IMEHold.setter"""
        self.IMEHold = value

    @property
    def InheritValueList(self):
        return self.com_object.InheritValueList

    @InheritValueList.setter
    def InheritValueList(self, value):
        self.com_object.InheritValueList = value

    @property
    def inheritvaluelist(self):
        """Alias for InheritValueList"""
        return self.InheritValueList

    @inheritvaluelist.setter
    def inheritvaluelist(self, value):
        """Alias for InheritValueList.setter"""
        self.InheritValueList = value

    @property
    def inherit_value_list(self):
        """Alias for InheritValueList"""
        return self.InheritValueList

    @inherit_value_list.setter
    def inherit_value_list(self, value):
        """Alias for InheritValueList.setter"""
        self.InheritValueList = value

    @property
    def InputMask(self):
        return self.com_object.InputMask

    @InputMask.setter
    def InputMask(self, value):
        self.com_object.InputMask = value

    @property
    def inputmask(self):
        """Alias for InputMask"""
        return self.InputMask

    @inputmask.setter
    def inputmask(self, value):
        """Alias for InputMask.setter"""
        self.InputMask = value

    @property
    def input_mask(self):
        """Alias for InputMask"""
        return self.InputMask

    @input_mask.setter
    def input_mask(self, value):
        """Alias for InputMask.setter"""
        self.InputMask = value

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def IsHyperlink(self):
        return self.com_object.IsHyperlink

    @IsHyperlink.setter
    def IsHyperlink(self, value):
        self.com_object.IsHyperlink = value

    @property
    def ishyperlink(self):
        """Alias for IsHyperlink"""
        return self.IsHyperlink

    @ishyperlink.setter
    def ishyperlink(self, value):
        """Alias for IsHyperlink.setter"""
        self.IsHyperlink = value

    @property
    def is_hyperlink(self):
        """Alias for IsHyperlink"""
        return self.IsHyperlink

    @is_hyperlink.setter
    def is_hyperlink(self, value):
        """Alias for IsHyperlink.setter"""
        self.IsHyperlink = value

    @property
    def IsVisible(self):
        return self.com_object.IsVisible

    @IsVisible.setter
    def IsVisible(self, value):
        self.com_object.IsVisible = value

    @property
    def isvisible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @isvisible.setter
    def isvisible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def is_visible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @is_visible.setter
    def is_visible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    def ItemData(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItemData"):
            return self.com_object.GetItemData(*arguments)
        else:
            return self.com_object.ItemData(*arguments)

    def itemdata(self, Index=None):
        """Alias for ItemData"""
        arguments = [Index]
        return self.ItemData(*arguments)

    def item_data(self, Index=None):
        """Alias for ItemData"""
        arguments = [Index]
        return self.ItemData(*arguments)

    @property
    def ItemsSelected(self):
        return self.com_object.ItemsSelected

    @property
    def itemsselected(self):
        """Alias for ItemsSelected"""
        return self.ItemsSelected

    @property
    def items_selected(self):
        """Alias for ItemsSelected"""
        return self.ItemsSelected

    @property
    def LabelAlign(self):
        return self.com_object.LabelAlign

    @LabelAlign.setter
    def LabelAlign(self, value):
        self.com_object.LabelAlign = value

    @property
    def labelalign(self):
        """Alias for LabelAlign"""
        return self.LabelAlign

    @labelalign.setter
    def labelalign(self, value):
        """Alias for LabelAlign.setter"""
        self.LabelAlign = value

    @property
    def label_align(self):
        """Alias for LabelAlign"""
        return self.LabelAlign

    @label_align.setter
    def label_align(self, value):
        """Alias for LabelAlign.setter"""
        self.LabelAlign = value

    @property
    def LabelX(self):
        return self.com_object.LabelX

    @LabelX.setter
    def LabelX(self, value):
        self.com_object.LabelX = value

    @property
    def labelx(self):
        """Alias for LabelX"""
        return self.LabelX

    @labelx.setter
    def labelx(self, value):
        """Alias for LabelX.setter"""
        self.LabelX = value

    @property
    def label_x(self):
        """Alias for LabelX"""
        return self.LabelX

    @label_x.setter
    def label_x(self, value):
        """Alias for LabelX.setter"""
        self.LabelX = value

    @property
    def LabelY(self):
        return self.com_object.LabelY

    @LabelY.setter
    def LabelY(self, value):
        self.com_object.LabelY = value

    @property
    def labely(self):
        """Alias for LabelY"""
        return self.LabelY

    @labely.setter
    def labely(self, value):
        """Alias for LabelY.setter"""
        self.LabelY = value

    @property
    def label_y(self):
        """Alias for LabelY"""
        return self.LabelY

    @label_y.setter
    def label_y(self, value):
        """Alias for LabelY.setter"""
        self.LabelY = value

    @property
    def Layout(self):
        return AcLayoutType(self.com_object.Layout)

    @property
    def layout(self):
        """Alias for Layout"""
        return self.Layout

    @property
    def LayoutID(self):
        return self.com_object.LayoutID

    @property
    def layoutid(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def layout_i_d(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def LeftMargin(self):
        return self.com_object.LeftMargin

    @LeftMargin.setter
    def LeftMargin(self, value):
        self.com_object.LeftMargin = value

    @property
    def leftmargin(self):
        """Alias for LeftMargin"""
        return self.LeftMargin

    @leftmargin.setter
    def leftmargin(self, value):
        """Alias for LeftMargin.setter"""
        self.LeftMargin = value

    @property
    def left_margin(self):
        """Alias for LeftMargin"""
        return self.LeftMargin

    @left_margin.setter
    def left_margin(self, value):
        """Alias for LeftMargin.setter"""
        self.LeftMargin = value

    @property
    def LeftPadding(self):
        return self.com_object.LeftPadding

    @LeftPadding.setter
    def LeftPadding(self, value):
        self.com_object.LeftPadding = value

    @property
    def leftpadding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @leftpadding.setter
    def leftpadding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def left_padding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @left_padding.setter
    def left_padding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def LimitToList(self):
        return self.com_object.LimitToList

    @LimitToList.setter
    def LimitToList(self, value):
        self.com_object.LimitToList = value

    @property
    def limittolist(self):
        """Alias for LimitToList"""
        return self.LimitToList

    @limittolist.setter
    def limittolist(self, value):
        """Alias for LimitToList.setter"""
        self.LimitToList = value

    @property
    def limit_to_list(self):
        """Alias for LimitToList"""
        return self.LimitToList

    @limit_to_list.setter
    def limit_to_list(self, value):
        """Alias for LimitToList.setter"""
        self.LimitToList = value

    @property
    def ListCount(self):
        return self.com_object.ListCount

    @ListCount.setter
    def ListCount(self, value):
        self.com_object.ListCount = value

    @property
    def listcount(self):
        """Alias for ListCount"""
        return self.ListCount

    @listcount.setter
    def listcount(self, value):
        """Alias for ListCount.setter"""
        self.ListCount = value

    @property
    def list_count(self):
        """Alias for ListCount"""
        return self.ListCount

    @list_count.setter
    def list_count(self, value):
        """Alias for ListCount.setter"""
        self.ListCount = value

    @property
    def ListIndex(self):
        return self.com_object.ListIndex

    @property
    def listindex(self):
        """Alias for ListIndex"""
        return self.ListIndex

    @property
    def list_index(self):
        """Alias for ListIndex"""
        return self.ListIndex

    @property
    def ListItemsEditForm(self):
        return self.com_object.ListItemsEditForm

    @ListItemsEditForm.setter
    def ListItemsEditForm(self, value):
        self.com_object.ListItemsEditForm = value

    @property
    def listitemseditform(self):
        """Alias for ListItemsEditForm"""
        return self.ListItemsEditForm

    @listitemseditform.setter
    def listitemseditform(self, value):
        """Alias for ListItemsEditForm.setter"""
        self.ListItemsEditForm = value

    @property
    def list_items_edit_form(self):
        """Alias for ListItemsEditForm"""
        return self.ListItemsEditForm

    @list_items_edit_form.setter
    def list_items_edit_form(self, value):
        """Alias for ListItemsEditForm.setter"""
        self.ListItemsEditForm = value

    @property
    def ListRows(self):
        return self.com_object.ListRows

    @ListRows.setter
    def ListRows(self, value):
        self.com_object.ListRows = value

    @property
    def listrows(self):
        """Alias for ListRows"""
        return self.ListRows

    @listrows.setter
    def listrows(self, value):
        """Alias for ListRows.setter"""
        self.ListRows = value

    @property
    def list_rows(self):
        """Alias for ListRows"""
        return self.ListRows

    @list_rows.setter
    def list_rows(self, value):
        """Alias for ListRows.setter"""
        self.ListRows = value

    @property
    def ListWidth(self):
        return self.com_object.ListWidth

    @ListWidth.setter
    def ListWidth(self, value):
        self.com_object.ListWidth = value

    @property
    def listwidth(self):
        """Alias for ListWidth"""
        return self.ListWidth

    @listwidth.setter
    def listwidth(self, value):
        """Alias for ListWidth.setter"""
        self.ListWidth = value

    @property
    def list_width(self):
        """Alias for ListWidth"""
        return self.ListWidth

    @list_width.setter
    def list_width(self, value):
        """Alias for ListWidth.setter"""
        self.ListWidth = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def OldBorderStyle(self):
        return self.com_object.OldBorderStyle

    @OldBorderStyle.setter
    def OldBorderStyle(self, value):
        self.com_object.OldBorderStyle = value

    @property
    def oldborderstyle(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @oldborderstyle.setter
    def oldborderstyle(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def old_border_style(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @old_border_style.setter
    def old_border_style(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def OldValue(self):
        return self.com_object.OldValue

    @property
    def oldvalue(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def old_value(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def OnChange(self):
        return self.com_object.OnChange

    @OnChange.setter
    def OnChange(self, value):
        self.com_object.OnChange = value

    @property
    def onchange(self):
        """Alias for OnChange"""
        return self.OnChange

    @onchange.setter
    def onchange(self, value):
        """Alias for OnChange.setter"""
        self.OnChange = value

    @property
    def on_change(self):
        """Alias for OnChange"""
        return self.OnChange

    @on_change.setter
    def on_change(self, value):
        """Alias for OnChange.setter"""
        self.OnChange = value

    @property
    def OnClick(self):
        return self.com_object.OnClick

    @OnClick.setter
    def OnClick(self, value):
        self.com_object.OnClick = value

    @property
    def onclick(self):
        """Alias for OnClick"""
        return self.OnClick

    @onclick.setter
    def onclick(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def on_click(self):
        """Alias for OnClick"""
        return self.OnClick

    @on_click.setter
    def on_click(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def OnDblClick(self):
        return self.com_object.OnDblClick

    @OnDblClick.setter
    def OnDblClick(self, value):
        self.com_object.OnDblClick = value

    @property
    def ondblclick(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @ondblclick.setter
    def ondblclick(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def on_dbl_click(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @on_dbl_click.setter
    def on_dbl_click(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def OnDirty(self):
        return self.com_object.OnDirty

    @OnDirty.setter
    def OnDirty(self, value):
        self.com_object.OnDirty = value

    @property
    def ondirty(self):
        """Alias for OnDirty"""
        return self.OnDirty

    @ondirty.setter
    def ondirty(self, value):
        """Alias for OnDirty.setter"""
        self.OnDirty = value

    @property
    def on_dirty(self):
        """Alias for OnDirty"""
        return self.OnDirty

    @on_dirty.setter
    def on_dirty(self, value):
        """Alias for OnDirty.setter"""
        self.OnDirty = value

    @property
    def OnEnter(self):
        return self.com_object.OnEnter

    @OnEnter.setter
    def OnEnter(self, value):
        self.com_object.OnEnter = value

    @property
    def onenter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @onenter.setter
    def onenter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def on_enter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @on_enter.setter
    def on_enter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def OnExit(self):
        return self.com_object.OnExit

    @OnExit.setter
    def OnExit(self, value):
        self.com_object.OnExit = value

    @property
    def onexit(self):
        """Alias for OnExit"""
        return self.OnExit

    @onexit.setter
    def onexit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def on_exit(self):
        """Alias for OnExit"""
        return self.OnExit

    @on_exit.setter
    def on_exit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def OnGotFocus(self):
        return self.com_object.OnGotFocus

    @OnGotFocus.setter
    def OnGotFocus(self, value):
        self.com_object.OnGotFocus = value

    @property
    def ongotfocus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @ongotfocus.setter
    def ongotfocus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def on_got_focus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @on_got_focus.setter
    def on_got_focus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def OnKeyDown(self):
        return self.com_object.OnKeyDown

    @OnKeyDown.setter
    def OnKeyDown(self, value):
        self.com_object.OnKeyDown = value

    @property
    def onkeydown(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @onkeydown.setter
    def onkeydown(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def on_key_down(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @on_key_down.setter
    def on_key_down(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def OnKeyPress(self):
        return self.com_object.OnKeyPress

    @OnKeyPress.setter
    def OnKeyPress(self, value):
        self.com_object.OnKeyPress = value

    @property
    def onkeypress(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @onkeypress.setter
    def onkeypress(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def on_key_press(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @on_key_press.setter
    def on_key_press(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def OnKeyUp(self):
        return self.com_object.OnKeyUp

    @OnKeyUp.setter
    def OnKeyUp(self, value):
        self.com_object.OnKeyUp = value

    @property
    def onkeyup(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @onkeyup.setter
    def onkeyup(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def on_key_up(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @on_key_up.setter
    def on_key_up(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def OnLostFocus(self):
        return self.com_object.OnLostFocus

    @OnLostFocus.setter
    def OnLostFocus(self, value):
        self.com_object.OnLostFocus = value

    @property
    def onlostfocus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @onlostfocus.setter
    def onlostfocus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def on_lost_focus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @on_lost_focus.setter
    def on_lost_focus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def OnMouseDown(self):
        return self.com_object.OnMouseDown

    @OnMouseDown.setter
    def OnMouseDown(self, value):
        self.com_object.OnMouseDown = value

    @property
    def onmousedown(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @onmousedown.setter
    def onmousedown(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def on_mouse_down(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @on_mouse_down.setter
    def on_mouse_down(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def OnMouseMove(self):
        return self.com_object.OnMouseMove

    @OnMouseMove.setter
    def OnMouseMove(self, value):
        self.com_object.OnMouseMove = value

    @property
    def onmousemove(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @onmousemove.setter
    def onmousemove(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def on_mouse_move(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @on_mouse_move.setter
    def on_mouse_move(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def OnMouseUp(self):
        return self.com_object.OnMouseUp

    @OnMouseUp.setter
    def OnMouseUp(self, value):
        self.com_object.OnMouseUp = value

    @property
    def onmouseup(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @onmouseup.setter
    def onmouseup(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def on_mouse_up(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @on_mouse_up.setter
    def on_mouse_up(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def OnNotInList(self):
        return self.com_object.OnNotInList

    @OnNotInList.setter
    def OnNotInList(self, value):
        self.com_object.OnNotInList = value

    @property
    def onnotinlist(self):
        """Alias for OnNotInList"""
        return self.OnNotInList

    @onnotinlist.setter
    def onnotinlist(self, value):
        """Alias for OnNotInList.setter"""
        self.OnNotInList = value

    @property
    def on_not_in_list(self):
        """Alias for OnNotInList"""
        return self.OnNotInList

    @on_not_in_list.setter
    def on_not_in_list(self, value):
        """Alias for OnNotInList.setter"""
        self.OnNotInList = value

    @property
    def OnUndo(self):
        return self.com_object.OnUndo

    @OnUndo.setter
    def OnUndo(self, value):
        self.com_object.OnUndo = value

    @property
    def onundo(self):
        """Alias for OnUndo"""
        return self.OnUndo

    @onundo.setter
    def onundo(self, value):
        """Alias for OnUndo.setter"""
        self.OnUndo = value

    @property
    def on_undo(self):
        """Alias for OnUndo"""
        return self.OnUndo

    @on_undo.setter
    def on_undo(self, value):
        """Alias for OnUndo.setter"""
        self.OnUndo = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def ReadingOrder(self):
        return self.com_object.ReadingOrder

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def Recordset(self):
        return self.com_object.Recordset

    @Recordset.setter
    def Recordset(self, value):
        self.com_object.Recordset = value

    @property
    def recordset(self):
        """Alias for Recordset"""
        return self.Recordset

    @recordset.setter
    def recordset(self, value):
        """Alias for Recordset.setter"""
        self.Recordset = value

    @property
    def RightMargin(self):
        return self.com_object.RightMargin

    @RightMargin.setter
    def RightMargin(self, value):
        self.com_object.RightMargin = value

    @property
    def rightmargin(self):
        """Alias for RightMargin"""
        return self.RightMargin

    @rightmargin.setter
    def rightmargin(self, value):
        """Alias for RightMargin.setter"""
        self.RightMargin = value

    @property
    def right_margin(self):
        """Alias for RightMargin"""
        return self.RightMargin

    @right_margin.setter
    def right_margin(self, value):
        """Alias for RightMargin.setter"""
        self.RightMargin = value

    @property
    def RightPadding(self):
        return self.com_object.RightPadding

    @RightPadding.setter
    def RightPadding(self, value):
        self.com_object.RightPadding = value

    @property
    def rightpadding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @rightpadding.setter
    def rightpadding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def right_padding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @right_padding.setter
    def right_padding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def RowSource(self):
        return self.com_object.RowSource

    @RowSource.setter
    def RowSource(self, value):
        self.com_object.RowSource = value

    @property
    def rowsource(self):
        """Alias for RowSource"""
        return self.RowSource

    @rowsource.setter
    def rowsource(self, value):
        """Alias for RowSource.setter"""
        self.RowSource = value

    @property
    def row_source(self):
        """Alias for RowSource"""
        return self.RowSource

    @row_source.setter
    def row_source(self, value):
        """Alias for RowSource.setter"""
        self.RowSource = value

    @property
    def RowSourceType(self):
        return self.com_object.RowSourceType

    @RowSourceType.setter
    def RowSourceType(self, value):
        self.com_object.RowSourceType = value

    @property
    def rowsourcetype(self):
        """Alias for RowSourceType"""
        return self.RowSourceType

    @rowsourcetype.setter
    def rowsourcetype(self, value):
        """Alias for RowSourceType.setter"""
        self.RowSourceType = value

    @property
    def row_source_type(self):
        """Alias for RowSourceType"""
        return self.RowSourceType

    @row_source_type.setter
    def row_source_type(self, value):
        """Alias for RowSourceType.setter"""
        self.RowSourceType = value

    @property
    def ScrollBarAlign(self):
        return self.com_object.ScrollBarAlign

    @ScrollBarAlign.setter
    def ScrollBarAlign(self, value):
        self.com_object.ScrollBarAlign = value

    @property
    def scrollbaralign(self):
        """Alias for ScrollBarAlign"""
        return self.ScrollBarAlign

    @scrollbaralign.setter
    def scrollbaralign(self, value):
        """Alias for ScrollBarAlign.setter"""
        self.ScrollBarAlign = value

    @property
    def scroll_bar_align(self):
        """Alias for ScrollBarAlign"""
        return self.ScrollBarAlign

    @scroll_bar_align.setter
    def scroll_bar_align(self, value):
        """Alias for ScrollBarAlign.setter"""
        self.ScrollBarAlign = value

    @property
    def Section(self):
        return self.com_object.Section

    @Section.setter
    def Section(self, value):
        self.com_object.Section = value

    @property
    def section(self):
        """Alias for Section"""
        return self.Section

    @section.setter
    def section(self, value):
        """Alias for Section.setter"""
        self.Section = value

    @property
    def Selected(self):
        return self.com_object.Selected

    @Selected.setter
    def Selected(self, value):
        self.com_object.Selected = value

    @property
    def selected(self):
        """Alias for Selected"""
        return self.Selected

    @selected.setter
    def selected(self, value):
        """Alias for Selected.setter"""
        self.Selected = value

    @property
    def SelLength(self):
        return self.com_object.SelLength

    @SelLength.setter
    def SelLength(self, value):
        self.com_object.SelLength = value

    @property
    def sellength(self):
        """Alias for SelLength"""
        return self.SelLength

    @sellength.setter
    def sellength(self, value):
        """Alias for SelLength.setter"""
        self.SelLength = value

    @property
    def sel_length(self):
        """Alias for SelLength"""
        return self.SelLength

    @sel_length.setter
    def sel_length(self, value):
        """Alias for SelLength.setter"""
        self.SelLength = value

    @property
    def SelStart(self):
        return self.com_object.SelStart

    @SelStart.setter
    def SelStart(self, value):
        self.com_object.SelStart = value

    @property
    def selstart(self):
        """Alias for SelStart"""
        return self.SelStart

    @selstart.setter
    def selstart(self, value):
        """Alias for SelStart.setter"""
        self.SelStart = value

    @property
    def sel_start(self):
        """Alias for SelStart"""
        return self.SelStart

    @sel_start.setter
    def sel_start(self, value):
        """Alias for SelStart.setter"""
        self.SelStart = value

    @property
    def SelText(self):
        return self.com_object.SelText

    @SelText.setter
    def SelText(self, value):
        self.com_object.SelText = value

    @property
    def seltext(self):
        """Alias for SelText"""
        return self.SelText

    @seltext.setter
    def seltext(self, value):
        """Alias for SelText.setter"""
        self.SelText = value

    @property
    def sel_text(self):
        """Alias for SelText"""
        return self.SelText

    @sel_text.setter
    def sel_text(self, value):
        """Alias for SelText.setter"""
        self.SelText = value

    @property
    def SeparatorCharacters(self):
        return self.com_object.SeparatorCharacters

    @SeparatorCharacters.setter
    def SeparatorCharacters(self, value):
        self.com_object.SeparatorCharacters = value

    @property
    def separatorcharacters(self):
        """Alias for SeparatorCharacters"""
        return self.SeparatorCharacters

    @separatorcharacters.setter
    def separatorcharacters(self, value):
        """Alias for SeparatorCharacters.setter"""
        self.SeparatorCharacters = value

    @property
    def separator_characters(self):
        """Alias for SeparatorCharacters"""
        return self.SeparatorCharacters

    @separator_characters.setter
    def separator_characters(self, value):
        """Alias for SeparatorCharacters.setter"""
        self.SeparatorCharacters = value

    @property
    def ShortcutMenuBar(self):
        return self.com_object.ShortcutMenuBar

    @ShortcutMenuBar.setter
    def ShortcutMenuBar(self, value):
        self.com_object.ShortcutMenuBar = value

    @property
    def shortcutmenubar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcutmenubar.setter
    def shortcutmenubar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def shortcut_menu_bar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcut_menu_bar.setter
    def shortcut_menu_bar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def ShowOnlyRowSourceValues(self):
        return self.com_object.ShowOnlyRowSourceValues

    @ShowOnlyRowSourceValues.setter
    def ShowOnlyRowSourceValues(self, value):
        self.com_object.ShowOnlyRowSourceValues = value

    @property
    def showonlyrowsourcevalues(self):
        """Alias for ShowOnlyRowSourceValues"""
        return self.ShowOnlyRowSourceValues

    @showonlyrowsourcevalues.setter
    def showonlyrowsourcevalues(self, value):
        """Alias for ShowOnlyRowSourceValues.setter"""
        self.ShowOnlyRowSourceValues = value

    @property
    def show_only_row_source_values(self):
        """Alias for ShowOnlyRowSourceValues"""
        return self.ShowOnlyRowSourceValues

    @show_only_row_source_values.setter
    def show_only_row_source_values(self, value):
        """Alias for ShowOnlyRowSourceValues.setter"""
        self.ShowOnlyRowSourceValues = value

    @property
    def SmartTags(self):
        return SmartTags(self.com_object.SmartTags)

    @property
    def smarttags(self):
        """Alias for SmartTags"""
        return self.SmartTags

    @property
    def smart_tags(self):
        """Alias for SmartTags"""
        return self.SmartTags

    @property
    def SpecialEffect(self):
        return self.com_object.SpecialEffect

    @SpecialEffect.setter
    def SpecialEffect(self, value):
        self.com_object.SpecialEffect = value

    @property
    def specialeffect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @specialeffect.setter
    def specialeffect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def special_effect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @special_effect.setter
    def special_effect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def StatusBarText(self):
        return self.com_object.StatusBarText

    @StatusBarText.setter
    def StatusBarText(self, value):
        self.com_object.StatusBarText = value

    @property
    def statusbartext(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @statusbartext.setter
    def statusbartext(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def status_bar_text(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @status_bar_text.setter
    def status_bar_text(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def TabIndex(self):
        return self.com_object.TabIndex

    @TabIndex.setter
    def TabIndex(self, value):
        self.com_object.TabIndex = value

    @property
    def tabindex(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tabindex.setter
    def tabindex(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def tab_index(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tab_index.setter
    def tab_index(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def TabStop(self):
        return self.com_object.TabStop

    @TabStop.setter
    def TabStop(self, value):
        self.com_object.TabStop = value

    @property
    def tabstop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tabstop.setter
    def tabstop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def tab_stop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tab_stop.setter
    def tab_stop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def TextAlign(self):
        return self.com_object.TextAlign

    @TextAlign.setter
    def TextAlign(self, value):
        self.com_object.TextAlign = value

    @property
    def textalign(self):
        """Alias for TextAlign"""
        return self.TextAlign

    @textalign.setter
    def textalign(self, value):
        """Alias for TextAlign.setter"""
        self.TextAlign = value

    @property
    def text_align(self):
        """Alias for TextAlign"""
        return self.TextAlign

    @text_align.setter
    def text_align(self, value):
        """Alias for TextAlign.setter"""
        self.TextAlign = value

    @property
    def ThemeFontIndex(self):
        return self.com_object.ThemeFontIndex

    @ThemeFontIndex.setter
    def ThemeFontIndex(self, value):
        self.com_object.ThemeFontIndex = value

    @property
    def themefontindex(self):
        """Alias for ThemeFontIndex"""
        return self.ThemeFontIndex

    @themefontindex.setter
    def themefontindex(self, value):
        """Alias for ThemeFontIndex.setter"""
        self.ThemeFontIndex = value

    @property
    def theme_font_index(self):
        """Alias for ThemeFontIndex"""
        return self.ThemeFontIndex

    @theme_font_index.setter
    def theme_font_index(self, value):
        """Alias for ThemeFontIndex.setter"""
        self.ThemeFontIndex = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TopMargin(self):
        return self.com_object.TopMargin

    @TopMargin.setter
    def TopMargin(self, value):
        self.com_object.TopMargin = value

    @property
    def topmargin(self):
        """Alias for TopMargin"""
        return self.TopMargin

    @topmargin.setter
    def topmargin(self, value):
        """Alias for TopMargin.setter"""
        self.TopMargin = value

    @property
    def top_margin(self):
        """Alias for TopMargin"""
        return self.TopMargin

    @top_margin.setter
    def top_margin(self, value):
        """Alias for TopMargin.setter"""
        self.TopMargin = value

    @property
    def TopPadding(self):
        return self.com_object.TopPadding

    @TopPadding.setter
    def TopPadding(self, value):
        self.com_object.TopPadding = value

    @property
    def toppadding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @toppadding.setter
    def toppadding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def top_padding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @top_padding.setter
    def top_padding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def ValidationRule(self):
        return self.com_object.ValidationRule

    @ValidationRule.setter
    def ValidationRule(self, value):
        self.com_object.ValidationRule = value

    @property
    def validationrule(self):
        """Alias for ValidationRule"""
        return self.ValidationRule

    @validationrule.setter
    def validationrule(self, value):
        """Alias for ValidationRule.setter"""
        self.ValidationRule = value

    @property
    def validation_rule(self):
        """Alias for ValidationRule"""
        return self.ValidationRule

    @validation_rule.setter
    def validation_rule(self, value):
        """Alias for ValidationRule.setter"""
        self.ValidationRule = value

    @property
    def ValidationText(self):
        return self.com_object.ValidationText

    @ValidationText.setter
    def ValidationText(self, value):
        self.com_object.ValidationText = value

    @property
    def validationtext(self):
        """Alias for ValidationText"""
        return self.ValidationText

    @validationtext.setter
    def validationtext(self, value):
        """Alias for ValidationText.setter"""
        self.ValidationText = value

    @property
    def validation_text(self):
        """Alias for ValidationText"""
        return self.ValidationText

    @validation_text.setter
    def validation_text(self, value):
        """Alias for ValidationText.setter"""
        self.ValidationText = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def AddItem(self, Item=None, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Item, Index]])
        self.com_object.AddItem(*arguments)

    def additem(self, Item=None, Index=None):
        """Alias for AddItem"""
        arguments = [Item, Index]
        return self.AddItem(*arguments)

    def add_item(self, Item=None, Index=None):
        """Alias for AddItem"""
        arguments = [Item, Index]
        return self.AddItem(*arguments)

    def Dropdown(self):
        return self.com_object.Dropdown()

    def dropdown(self):
        """Alias for Dropdown"""
        return self.Dropdown()

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def RemoveItem(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.RemoveItem(*arguments)

    def removeitem(self, Index=None):
        """Alias for RemoveItem"""
        arguments = [Index]
        return self.RemoveItem(*arguments)

    def remove_item(self, Index=None):
        """Alias for RemoveItem"""
        arguments = [Index]
        return self.RemoveItem(*arguments)

    def Requery(self):
        self.com_object.Requery()

    def requery(self):
        """Alias for Requery"""
        return self.Requery()

    def SetFocus(self):
        return self.com_object.SetFocus()

    def setfocus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def set_focus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def Undo(self):
        self.com_object.Undo()

    def undo(self):
        """Alias for Undo"""
        return self.Undo()


class CommandButton:

    def __init__(self, commandbutton=None):
        self.com_object= commandbutton

    @property
    def AddColon(self):
        return self.com_object.AddColon

    @AddColon.setter
    def AddColon(self, value):
        self.com_object.AddColon = value

    @property
    def addcolon(self):
        """Alias for AddColon"""
        return self.AddColon

    @addcolon.setter
    def addcolon(self, value):
        """Alias for AddColon.setter"""
        self.AddColon = value

    @property
    def add_colon(self):
        """Alias for AddColon"""
        return self.AddColon

    @add_colon.setter
    def add_colon(self, value):
        """Alias for AddColon.setter"""
        self.AddColon = value

    @property
    def Alignment(self):
        return self.com_object.Alignment

    @Alignment.setter
    def Alignment(self, value):
        self.com_object.Alignment = value

    @property
    def alignment(self):
        """Alias for Alignment"""
        return self.Alignment

    @alignment.setter
    def alignment(self, value):
        """Alias for Alignment.setter"""
        self.Alignment = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoLabel(self):
        return self.com_object.AutoLabel

    @AutoLabel.setter
    def AutoLabel(self, value):
        self.com_object.AutoLabel = value

    @property
    def autolabel(self):
        """Alias for AutoLabel"""
        return self.AutoLabel

    @autolabel.setter
    def autolabel(self, value):
        """Alias for AutoLabel.setter"""
        self.AutoLabel = value

    @property
    def auto_label(self):
        """Alias for AutoLabel"""
        return self.AutoLabel

    @auto_label.setter
    def auto_label(self, value):
        """Alias for AutoLabel.setter"""
        self.AutoLabel = value

    @property
    def AutoRepeat(self):
        return self.com_object.AutoRepeat

    @AutoRepeat.setter
    def AutoRepeat(self, value):
        self.com_object.AutoRepeat = value

    @property
    def autorepeat(self):
        """Alias for AutoRepeat"""
        return self.AutoRepeat

    @autorepeat.setter
    def autorepeat(self, value):
        """Alias for AutoRepeat.setter"""
        self.AutoRepeat = value

    @property
    def auto_repeat(self):
        """Alias for AutoRepeat"""
        return self.AutoRepeat

    @auto_repeat.setter
    def auto_repeat(self, value):
        """Alias for AutoRepeat.setter"""
        self.AutoRepeat = value

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BackShade(self):
        return self.com_object.BackShade

    @BackShade.setter
    def BackShade(self, value):
        self.com_object.BackShade = value

    @property
    def backshade(self):
        """Alias for BackShade"""
        return self.BackShade

    @backshade.setter
    def backshade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def back_shade(self):
        """Alias for BackShade"""
        return self.BackShade

    @back_shade.setter
    def back_shade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def BackStyle(self):
        return self.com_object.BackStyle

    @BackStyle.setter
    def BackStyle(self, value):
        self.com_object.BackStyle = value

    @property
    def backstyle(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @backstyle.setter
    def backstyle(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def back_style(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @back_style.setter
    def back_style(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def BackThemeColorIndex(self):
        return self.com_object.BackThemeColorIndex

    @BackThemeColorIndex.setter
    def BackThemeColorIndex(self, value):
        self.com_object.BackThemeColorIndex = value

    @property
    def backthemecolorindex(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @backthemecolorindex.setter
    def backthemecolorindex(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def back_theme_color_index(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @back_theme_color_index.setter
    def back_theme_color_index(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def BackTint(self):
        return self.com_object.BackTint

    @BackTint.setter
    def BackTint(self, value):
        self.com_object.BackTint = value

    @property
    def backtint(self):
        """Alias for BackTint"""
        return self.BackTint

    @backtint.setter
    def backtint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def back_tint(self):
        """Alias for BackTint"""
        return self.BackTint

    @back_tint.setter
    def back_tint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def Bevel(self):
        return self.com_object.Bevel

    @Bevel.setter
    def Bevel(self, value):
        self.com_object.Bevel = value

    @property
    def bevel(self):
        """Alias for Bevel"""
        return self.Bevel

    @bevel.setter
    def bevel(self, value):
        """Alias for Bevel.setter"""
        self.Bevel = value

    @property
    def BorderColor(self):
        return self.com_object.BorderColor

    @BorderColor.setter
    def BorderColor(self, value):
        self.com_object.BorderColor = value

    @property
    def bordercolor(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @bordercolor.setter
    def bordercolor(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def border_color(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @border_color.setter
    def border_color(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def BorderShade(self):
        return self.com_object.BorderShade

    @BorderShade.setter
    def BorderShade(self, value):
        self.com_object.BorderShade = value

    @property
    def bordershade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @bordershade.setter
    def bordershade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def border_shade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @border_shade.setter
    def border_shade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def BorderStyle(self):
        return self.com_object.BorderStyle

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def BorderThemeColorIndex(self):
        return self.com_object.BorderThemeColorIndex

    @BorderThemeColorIndex.setter
    def BorderThemeColorIndex(self, value):
        self.com_object.BorderThemeColorIndex = value

    @property
    def borderthemecolorindex(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @borderthemecolorindex.setter
    def borderthemecolorindex(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def border_theme_color_index(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @border_theme_color_index.setter
    def border_theme_color_index(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def BorderTint(self):
        return self.com_object.BorderTint

    @BorderTint.setter
    def BorderTint(self, value):
        self.com_object.BorderTint = value

    @property
    def bordertint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @bordertint.setter
    def bordertint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def border_tint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @border_tint.setter
    def border_tint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def BorderWidth(self):
        return self.com_object.BorderWidth

    @BorderWidth.setter
    def BorderWidth(self, value):
        self.com_object.BorderWidth = value

    @property
    def borderwidth(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @borderwidth.setter
    def borderwidth(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def border_width(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @border_width.setter
    def border_width(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def BottomPadding(self):
        return self.com_object.BottomPadding

    @BottomPadding.setter
    def BottomPadding(self, value):
        self.com_object.BottomPadding = value

    @property
    def bottompadding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottompadding.setter
    def bottompadding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def bottom_padding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottom_padding.setter
    def bottom_padding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def Cancel(self):
        return self.com_object.Cancel

    @Cancel.setter
    def Cancel(self, value):
        self.com_object.Cancel = value

    @property
    def cancel(self):
        """Alias for Cancel"""
        return self.Cancel

    @cancel.setter
    def cancel(self, value):
        """Alias for Cancel.setter"""
        self.Cancel = value

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    @property
    def Controls(self):
        return Controls(self.com_object.Controls)

    @property
    def controls(self):
        """Alias for Controls"""
        return self.Controls

    @property
    def ControlTipText(self):
        return self.com_object.ControlTipText

    @ControlTipText.setter
    def ControlTipText(self, value):
        self.com_object.ControlTipText = value

    @property
    def controltiptext(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @controltiptext.setter
    def controltiptext(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def control_tip_text(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @control_tip_text.setter
    def control_tip_text(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def ControlType(self):
        return self.com_object.ControlType

    @ControlType.setter
    def ControlType(self, value):
        self.com_object.ControlType = value

    @property
    def controltype(self):
        """Alias for ControlType"""
        return self.ControlType

    @controltype.setter
    def controltype(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def control_type(self):
        """Alias for ControlType"""
        return self.ControlType

    @control_type.setter
    def control_type(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def CursorOnHover(self):
        return self.com_object.CursorOnHover

    @CursorOnHover.setter
    def CursorOnHover(self, value):
        self.com_object.CursorOnHover = value

    @property
    def cursoronhover(self):
        """Alias for CursorOnHover"""
        return self.CursorOnHover

    @cursoronhover.setter
    def cursoronhover(self, value):
        """Alias for CursorOnHover.setter"""
        self.CursorOnHover = value

    @property
    def cursor_on_hover(self):
        """Alias for CursorOnHover"""
        return self.CursorOnHover

    @cursor_on_hover.setter
    def cursor_on_hover(self, value):
        """Alias for CursorOnHover.setter"""
        self.CursorOnHover = value

    @property
    def Default(self):
        return self.com_object.Default

    @Default.setter
    def Default(self, value):
        self.com_object.Default = value

    @property
    def default(self):
        """Alias for Default"""
        return self.Default

    @default.setter
    def default(self, value):
        """Alias for Default.setter"""
        self.Default = value

    @property
    def DisplayWhen(self):
        return self.com_object.DisplayWhen

    @DisplayWhen.setter
    def DisplayWhen(self, value):
        self.com_object.DisplayWhen = value

    @property
    def displaywhen(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @displaywhen.setter
    def displaywhen(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def display_when(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @display_when.setter
    def display_when(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def FontBold(self):
        return self.com_object.FontBold

    @property
    def fontbold(self):
        """Alias for FontBold"""
        return self.FontBold

    @property
    def font_bold(self):
        """Alias for FontBold"""
        return self.FontBold

    @property
    def FontItalic(self):
        return self.com_object.FontItalic

    @property
    def fontitalic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @property
    def font_italic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @property
    def FontName(self):
        return self.com_object.FontName

    @property
    def fontname(self):
        """Alias for FontName"""
        return self.FontName

    @property
    def font_name(self):
        """Alias for FontName"""
        return self.FontName

    @property
    def FontSize(self):
        return self.com_object.FontSize

    @property
    def fontsize(self):
        """Alias for FontSize"""
        return self.FontSize

    @property
    def font_size(self):
        """Alias for FontSize"""
        return self.FontSize

    @property
    def FontUnderline(self):
        return self.com_object.FontUnderline

    @property
    def fontunderline(self):
        """Alias for FontUnderline"""
        return self.FontUnderline

    @property
    def font_underline(self):
        """Alias for FontUnderline"""
        return self.FontUnderline

    @property
    def FontWeight(self):
        return self.com_object.FontWeight

    @FontWeight.setter
    def FontWeight(self, value):
        self.com_object.FontWeight = value

    @property
    def fontweight(self):
        """Alias for FontWeight"""
        return self.FontWeight

    @fontweight.setter
    def fontweight(self, value):
        """Alias for FontWeight.setter"""
        self.FontWeight = value

    @property
    def font_weight(self):
        """Alias for FontWeight"""
        return self.FontWeight

    @font_weight.setter
    def font_weight(self, value):
        """Alias for FontWeight.setter"""
        self.FontWeight = value

    @property
    def ForeColor(self):
        return self.com_object.ForeColor

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def ForeShade(self):
        return self.com_object.ForeShade

    @ForeShade.setter
    def ForeShade(self, value):
        self.com_object.ForeShade = value

    @property
    def foreshade(self):
        """Alias for ForeShade"""
        return self.ForeShade

    @foreshade.setter
    def foreshade(self, value):
        """Alias for ForeShade.setter"""
        self.ForeShade = value

    @property
    def fore_shade(self):
        """Alias for ForeShade"""
        return self.ForeShade

    @fore_shade.setter
    def fore_shade(self, value):
        """Alias for ForeShade.setter"""
        self.ForeShade = value

    @property
    def ForeThemeColorIndex(self):
        return self.com_object.ForeThemeColorIndex

    @ForeThemeColorIndex.setter
    def ForeThemeColorIndex(self, value):
        self.com_object.ForeThemeColorIndex = value

    @property
    def forethemecolorindex(self):
        """Alias for ForeThemeColorIndex"""
        return self.ForeThemeColorIndex

    @forethemecolorindex.setter
    def forethemecolorindex(self, value):
        """Alias for ForeThemeColorIndex.setter"""
        self.ForeThemeColorIndex = value

    @property
    def fore_theme_color_index(self):
        """Alias for ForeThemeColorIndex"""
        return self.ForeThemeColorIndex

    @fore_theme_color_index.setter
    def fore_theme_color_index(self, value):
        """Alias for ForeThemeColorIndex.setter"""
        self.ForeThemeColorIndex = value

    @property
    def ForeTint(self):
        return self.com_object.ForeTint

    @ForeTint.setter
    def ForeTint(self, value):
        self.com_object.ForeTint = value

    @property
    def foretint(self):
        """Alias for ForeTint"""
        return self.ForeTint

    @foretint.setter
    def foretint(self, value):
        """Alias for ForeTint.setter"""
        self.ForeTint = value

    @property
    def fore_tint(self):
        """Alias for ForeTint"""
        return self.ForeTint

    @fore_tint.setter
    def fore_tint(self, value):
        """Alias for ForeTint.setter"""
        self.ForeTint = value

    @property
    def Glow(self):
        return self.com_object.Glow

    @Glow.setter
    def Glow(self, value):
        self.com_object.Glow = value

    @property
    def glow(self):
        """Alias for Glow"""
        return self.Glow

    @glow.setter
    def glow(self, value):
        """Alias for Glow.setter"""
        self.Glow = value

    @property
    def Gradient(self):
        return self.com_object.Gradient

    @Gradient.setter
    def Gradient(self, value):
        self.com_object.Gradient = value

    @property
    def gradient(self):
        """Alias for Gradient"""
        return self.Gradient

    @gradient.setter
    def gradient(self, value):
        """Alias for Gradient.setter"""
        self.Gradient = value

    @property
    def GridlineColor(self):
        return self.com_object.GridlineColor

    @GridlineColor.setter
    def GridlineColor(self, value):
        self.com_object.GridlineColor = value

    @property
    def gridlinecolor(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridlinecolor.setter
    def gridlinecolor(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def gridline_color(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridline_color.setter
    def gridline_color(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def GridlineShade(self):
        return self.com_object.GridlineShade

    @GridlineShade.setter
    def GridlineShade(self, value):
        self.com_object.GridlineShade = value

    @property
    def gridlineshade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridlineshade.setter
    def gridlineshade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def gridline_shade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridline_shade.setter
    def gridline_shade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def GridlineStyleBottom(self):
        return self.com_object.GridlineStyleBottom

    @GridlineStyleBottom.setter
    def GridlineStyleBottom(self, value):
        self.com_object.GridlineStyleBottom = value

    @property
    def gridlinestylebottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridlinestylebottom.setter
    def gridlinestylebottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def gridline_style_bottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridline_style_bottom.setter
    def gridline_style_bottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def GridlineStyleLeft(self):
        return self.com_object.GridlineStyleLeft

    @GridlineStyleLeft.setter
    def GridlineStyleLeft(self, value):
        self.com_object.GridlineStyleLeft = value

    @property
    def gridlinestyleleft(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridlinestyleleft.setter
    def gridlinestyleleft(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def gridline_style_left(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridline_style_left.setter
    def gridline_style_left(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def GridlineStyleRight(self):
        return self.com_object.GridlineStyleRight

    @GridlineStyleRight.setter
    def GridlineStyleRight(self, value):
        self.com_object.GridlineStyleRight = value

    @property
    def gridlinestyleright(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridlinestyleright.setter
    def gridlinestyleright(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def gridline_style_right(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridline_style_right.setter
    def gridline_style_right(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def GridlineStyleTop(self):
        return self.com_object.GridlineStyleTop

    @GridlineStyleTop.setter
    def GridlineStyleTop(self, value):
        self.com_object.GridlineStyleTop = value

    @property
    def gridlinestyletop(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridlinestyletop.setter
    def gridlinestyletop(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def gridline_style_top(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridline_style_top.setter
    def gridline_style_top(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def GridlineThemeColorIndex(self):
        return self.com_object.GridlineThemeColorIndex

    @GridlineThemeColorIndex.setter
    def GridlineThemeColorIndex(self, value):
        self.com_object.GridlineThemeColorIndex = value

    @property
    def gridlinethemecolorindex(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridlinethemecolorindex.setter
    def gridlinethemecolorindex(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def gridline_theme_color_index(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridline_theme_color_index.setter
    def gridline_theme_color_index(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def GridlineTint(self):
        return self.com_object.GridlineTint

    @GridlineTint.setter
    def GridlineTint(self, value):
        self.com_object.GridlineTint = value

    @property
    def gridlinetint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridlinetint.setter
    def gridlinetint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def gridline_tint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridline_tint.setter
    def gridline_tint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def GridlineWidthBottom(self):
        return self.com_object.GridlineWidthBottom

    @GridlineWidthBottom.setter
    def GridlineWidthBottom(self, value):
        self.com_object.GridlineWidthBottom = value

    @property
    def gridlinewidthbottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridlinewidthbottom.setter
    def gridlinewidthbottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def gridline_width_bottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridline_width_bottom.setter
    def gridline_width_bottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def GridlineWidthLeft(self):
        return self.com_object.GridlineWidthLeft

    @GridlineWidthLeft.setter
    def GridlineWidthLeft(self, value):
        self.com_object.GridlineWidthLeft = value

    @property
    def gridlinewidthleft(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridlinewidthleft.setter
    def gridlinewidthleft(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def gridline_width_left(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridline_width_left.setter
    def gridline_width_left(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def GridlineWidthRight(self):
        return self.com_object.GridlineWidthRight

    @GridlineWidthRight.setter
    def GridlineWidthRight(self, value):
        self.com_object.GridlineWidthRight = value

    @property
    def gridlinewidthright(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridlinewidthright.setter
    def gridlinewidthright(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def gridline_width_right(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridline_width_right.setter
    def gridline_width_right(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def GridlineWidthTop(self):
        return self.com_object.GridlineWidthTop

    @GridlineWidthTop.setter
    def GridlineWidthTop(self, value):
        self.com_object.GridlineWidthTop = value

    @property
    def gridlinewidthtop(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridlinewidthtop.setter
    def gridlinewidthtop(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def gridline_width_top(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridline_width_top.setter
    def gridline_width_top(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HelpContextId(self):
        return self.com_object.HelpContextId

    @HelpContextId.setter
    def HelpContextId(self, value):
        self.com_object.HelpContextId = value

    @property
    def helpcontextid(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @helpcontextid.setter
    def helpcontextid(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def help_context_id(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @help_context_id.setter
    def help_context_id(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def HoverColor(self):
        return self.com_object.HoverColor

    @HoverColor.setter
    def HoverColor(self, value):
        self.com_object.HoverColor = value

    @property
    def hovercolor(self):
        """Alias for HoverColor"""
        return self.HoverColor

    @hovercolor.setter
    def hovercolor(self, value):
        """Alias for HoverColor.setter"""
        self.HoverColor = value

    @property
    def hover_color(self):
        """Alias for HoverColor"""
        return self.HoverColor

    @hover_color.setter
    def hover_color(self, value):
        """Alias for HoverColor.setter"""
        self.HoverColor = value

    @property
    def HoverForeColor(self):
        return self.com_object.HoverForeColor

    @HoverForeColor.setter
    def HoverForeColor(self, value):
        self.com_object.HoverForeColor = value

    @property
    def hoverforecolor(self):
        """Alias for HoverForeColor"""
        return self.HoverForeColor

    @hoverforecolor.setter
    def hoverforecolor(self, value):
        """Alias for HoverForeColor.setter"""
        self.HoverForeColor = value

    @property
    def hover_fore_color(self):
        """Alias for HoverForeColor"""
        return self.HoverForeColor

    @hover_fore_color.setter
    def hover_fore_color(self, value):
        """Alias for HoverForeColor.setter"""
        self.HoverForeColor = value

    @property
    def HoverForeShade(self):
        return self.com_object.HoverForeShade

    @HoverForeShade.setter
    def HoverForeShade(self, value):
        self.com_object.HoverForeShade = value

    @property
    def hoverforeshade(self):
        """Alias for HoverForeShade"""
        return self.HoverForeShade

    @hoverforeshade.setter
    def hoverforeshade(self, value):
        """Alias for HoverForeShade.setter"""
        self.HoverForeShade = value

    @property
    def hover_fore_shade(self):
        """Alias for HoverForeShade"""
        return self.HoverForeShade

    @hover_fore_shade.setter
    def hover_fore_shade(self, value):
        """Alias for HoverForeShade.setter"""
        self.HoverForeShade = value

    @property
    def HoverForeThemeColorIndex(self):
        return self.com_object.HoverForeThemeColorIndex

    @HoverForeThemeColorIndex.setter
    def HoverForeThemeColorIndex(self, value):
        self.com_object.HoverForeThemeColorIndex = value

    @property
    def hoverforethemecolorindex(self):
        """Alias for HoverForeThemeColorIndex"""
        return self.HoverForeThemeColorIndex

    @hoverforethemecolorindex.setter
    def hoverforethemecolorindex(self, value):
        """Alias for HoverForeThemeColorIndex.setter"""
        self.HoverForeThemeColorIndex = value

    @property
    def hover_fore_theme_color_index(self):
        """Alias for HoverForeThemeColorIndex"""
        return self.HoverForeThemeColorIndex

    @hover_fore_theme_color_index.setter
    def hover_fore_theme_color_index(self, value):
        """Alias for HoverForeThemeColorIndex.setter"""
        self.HoverForeThemeColorIndex = value

    @property
    def HoverForeTint(self):
        return self.com_object.HoverForeTint

    @HoverForeTint.setter
    def HoverForeTint(self, value):
        self.com_object.HoverForeTint = value

    @property
    def hoverforetint(self):
        """Alias for HoverForeTint"""
        return self.HoverForeTint

    @hoverforetint.setter
    def hoverforetint(self, value):
        """Alias for HoverForeTint.setter"""
        self.HoverForeTint = value

    @property
    def hover_fore_tint(self):
        """Alias for HoverForeTint"""
        return self.HoverForeTint

    @hover_fore_tint.setter
    def hover_fore_tint(self, value):
        """Alias for HoverForeTint.setter"""
        self.HoverForeTint = value

    @property
    def HoverShade(self):
        return self.com_object.HoverShade

    @HoverShade.setter
    def HoverShade(self, value):
        self.com_object.HoverShade = value

    @property
    def hovershade(self):
        """Alias for HoverShade"""
        return self.HoverShade

    @hovershade.setter
    def hovershade(self, value):
        """Alias for HoverShade.setter"""
        self.HoverShade = value

    @property
    def hover_shade(self):
        """Alias for HoverShade"""
        return self.HoverShade

    @hover_shade.setter
    def hover_shade(self, value):
        """Alias for HoverShade.setter"""
        self.HoverShade = value

    @property
    def HoverThemeColorIndex(self):
        return self.com_object.HoverThemeColorIndex

    @HoverThemeColorIndex.setter
    def HoverThemeColorIndex(self, value):
        self.com_object.HoverThemeColorIndex = value

    @property
    def hoverthemecolorindex(self):
        """Alias for HoverThemeColorIndex"""
        return self.HoverThemeColorIndex

    @hoverthemecolorindex.setter
    def hoverthemecolorindex(self, value):
        """Alias for HoverThemeColorIndex.setter"""
        self.HoverThemeColorIndex = value

    @property
    def hover_theme_color_index(self):
        """Alias for HoverThemeColorIndex"""
        return self.HoverThemeColorIndex

    @hover_theme_color_index.setter
    def hover_theme_color_index(self, value):
        """Alias for HoverThemeColorIndex.setter"""
        self.HoverThemeColorIndex = value

    @property
    def HoverTint(self):
        return self.com_object.HoverTint

    @HoverTint.setter
    def HoverTint(self, value):
        self.com_object.HoverTint = value

    @property
    def hovertint(self):
        """Alias for HoverTint"""
        return self.HoverTint

    @hovertint.setter
    def hovertint(self, value):
        """Alias for HoverTint.setter"""
        self.HoverTint = value

    @property
    def hover_tint(self):
        """Alias for HoverTint"""
        return self.HoverTint

    @hover_tint.setter
    def hover_tint(self, value):
        """Alias for HoverTint.setter"""
        self.HoverTint = value

    @property
    def Hyperlink(self):
        return self.com_object.Hyperlink

    @property
    def hyperlink(self):
        """Alias for Hyperlink"""
        return self.Hyperlink

    @property
    def HyperlinkAddress(self):
        return self.com_object.HyperlinkAddress

    @HyperlinkAddress.setter
    def HyperlinkAddress(self, value):
        self.com_object.HyperlinkAddress = value

    @property
    def hyperlinkaddress(self):
        """Alias for HyperlinkAddress"""
        return self.HyperlinkAddress

    @hyperlinkaddress.setter
    def hyperlinkaddress(self, value):
        """Alias for HyperlinkAddress.setter"""
        self.HyperlinkAddress = value

    @property
    def hyperlink_address(self):
        """Alias for HyperlinkAddress"""
        return self.HyperlinkAddress

    @hyperlink_address.setter
    def hyperlink_address(self, value):
        """Alias for HyperlinkAddress.setter"""
        self.HyperlinkAddress = value

    @property
    def HyperlinkSubAddress(self):
        return self.com_object.HyperlinkSubAddress

    @HyperlinkSubAddress.setter
    def HyperlinkSubAddress(self, value):
        self.com_object.HyperlinkSubAddress = value

    @property
    def hyperlinksubaddress(self):
        """Alias for HyperlinkSubAddress"""
        return self.HyperlinkSubAddress

    @hyperlinksubaddress.setter
    def hyperlinksubaddress(self, value):
        """Alias for HyperlinkSubAddress.setter"""
        self.HyperlinkSubAddress = value

    @property
    def hyperlink_sub_address(self):
        """Alias for HyperlinkSubAddress"""
        return self.HyperlinkSubAddress

    @hyperlink_sub_address.setter
    def hyperlink_sub_address(self, value):
        """Alias for HyperlinkSubAddress.setter"""
        self.HyperlinkSubAddress = value

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def IsVisible(self):
        return self.com_object.IsVisible

    @IsVisible.setter
    def IsVisible(self, value):
        self.com_object.IsVisible = value

    @property
    def isvisible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @isvisible.setter
    def isvisible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def is_visible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @is_visible.setter
    def is_visible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def LabelAlign(self):
        return self.com_object.LabelAlign

    @LabelAlign.setter
    def LabelAlign(self, value):
        self.com_object.LabelAlign = value

    @property
    def labelalign(self):
        """Alias for LabelAlign"""
        return self.LabelAlign

    @labelalign.setter
    def labelalign(self, value):
        """Alias for LabelAlign.setter"""
        self.LabelAlign = value

    @property
    def label_align(self):
        """Alias for LabelAlign"""
        return self.LabelAlign

    @label_align.setter
    def label_align(self, value):
        """Alias for LabelAlign.setter"""
        self.LabelAlign = value

    @property
    def LabelX(self):
        return self.com_object.LabelX

    @LabelX.setter
    def LabelX(self, value):
        self.com_object.LabelX = value

    @property
    def labelx(self):
        """Alias for LabelX"""
        return self.LabelX

    @labelx.setter
    def labelx(self, value):
        """Alias for LabelX.setter"""
        self.LabelX = value

    @property
    def label_x(self):
        """Alias for LabelX"""
        return self.LabelX

    @label_x.setter
    def label_x(self, value):
        """Alias for LabelX.setter"""
        self.LabelX = value

    @property
    def LabelY(self):
        return self.com_object.LabelY

    @LabelY.setter
    def LabelY(self, value):
        self.com_object.LabelY = value

    @property
    def labely(self):
        """Alias for LabelY"""
        return self.LabelY

    @labely.setter
    def labely(self, value):
        """Alias for LabelY.setter"""
        self.LabelY = value

    @property
    def label_y(self):
        """Alias for LabelY"""
        return self.LabelY

    @label_y.setter
    def label_y(self, value):
        """Alias for LabelY.setter"""
        self.LabelY = value

    @property
    def Layout(self):
        return AcLayoutType(self.com_object.Layout)

    @property
    def layout(self):
        """Alias for Layout"""
        return self.Layout

    @property
    def LayoutID(self):
        return self.com_object.LayoutID

    @property
    def layoutid(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def layout_i_d(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def LeftPadding(self):
        return self.com_object.LeftPadding

    @LeftPadding.setter
    def LeftPadding(self, value):
        self.com_object.LeftPadding = value

    @property
    def leftpadding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @leftpadding.setter
    def leftpadding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def left_padding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @left_padding.setter
    def left_padding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def ObjectPalette(self):
        return self.com_object.ObjectPalette

    @ObjectPalette.setter
    def ObjectPalette(self, value):
        self.com_object.ObjectPalette = value

    @property
    def objectpalette(self):
        """Alias for ObjectPalette"""
        return self.ObjectPalette

    @objectpalette.setter
    def objectpalette(self, value):
        """Alias for ObjectPalette.setter"""
        self.ObjectPalette = value

    @property
    def object_palette(self):
        """Alias for ObjectPalette"""
        return self.ObjectPalette

    @object_palette.setter
    def object_palette(self, value):
        """Alias for ObjectPalette.setter"""
        self.ObjectPalette = value

    @property
    def OldValue(self):
        return self.com_object.OldValue

    @property
    def oldvalue(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def old_value(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def OnClick(self):
        return self.com_object.OnClick

    @OnClick.setter
    def OnClick(self, value):
        self.com_object.OnClick = value

    @property
    def onclick(self):
        """Alias for OnClick"""
        return self.OnClick

    @onclick.setter
    def onclick(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def on_click(self):
        """Alias for OnClick"""
        return self.OnClick

    @on_click.setter
    def on_click(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def OnDblClick(self):
        return self.com_object.OnDblClick

    @OnDblClick.setter
    def OnDblClick(self, value):
        self.com_object.OnDblClick = value

    @property
    def ondblclick(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @ondblclick.setter
    def ondblclick(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def on_dbl_click(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @on_dbl_click.setter
    def on_dbl_click(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def OnEnter(self):
        return self.com_object.OnEnter

    @OnEnter.setter
    def OnEnter(self, value):
        self.com_object.OnEnter = value

    @property
    def onenter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @onenter.setter
    def onenter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def on_enter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @on_enter.setter
    def on_enter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def OnExit(self):
        return self.com_object.OnExit

    @OnExit.setter
    def OnExit(self, value):
        self.com_object.OnExit = value

    @property
    def onexit(self):
        """Alias for OnExit"""
        return self.OnExit

    @onexit.setter
    def onexit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def on_exit(self):
        """Alias for OnExit"""
        return self.OnExit

    @on_exit.setter
    def on_exit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def OnGotFocus(self):
        return self.com_object.OnGotFocus

    @OnGotFocus.setter
    def OnGotFocus(self, value):
        self.com_object.OnGotFocus = value

    @property
    def ongotfocus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @ongotfocus.setter
    def ongotfocus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def on_got_focus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @on_got_focus.setter
    def on_got_focus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def OnKeyDown(self):
        return self.com_object.OnKeyDown

    @OnKeyDown.setter
    def OnKeyDown(self, value):
        self.com_object.OnKeyDown = value

    @property
    def onkeydown(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @onkeydown.setter
    def onkeydown(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def on_key_down(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @on_key_down.setter
    def on_key_down(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def OnKeyPress(self):
        return self.com_object.OnKeyPress

    @OnKeyPress.setter
    def OnKeyPress(self, value):
        self.com_object.OnKeyPress = value

    @property
    def onkeypress(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @onkeypress.setter
    def onkeypress(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def on_key_press(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @on_key_press.setter
    def on_key_press(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def OnKeyUp(self):
        return self.com_object.OnKeyUp

    @OnKeyUp.setter
    def OnKeyUp(self, value):
        self.com_object.OnKeyUp = value

    @property
    def onkeyup(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @onkeyup.setter
    def onkeyup(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def on_key_up(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @on_key_up.setter
    def on_key_up(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def OnLostFocus(self):
        return self.com_object.OnLostFocus

    @OnLostFocus.setter
    def OnLostFocus(self, value):
        self.com_object.OnLostFocus = value

    @property
    def onlostfocus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @onlostfocus.setter
    def onlostfocus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def on_lost_focus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @on_lost_focus.setter
    def on_lost_focus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def OnMouseDown(self):
        return self.com_object.OnMouseDown

    @OnMouseDown.setter
    def OnMouseDown(self, value):
        self.com_object.OnMouseDown = value

    @property
    def onmousedown(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @onmousedown.setter
    def onmousedown(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def on_mouse_down(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @on_mouse_down.setter
    def on_mouse_down(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def OnMouseMove(self):
        return self.com_object.OnMouseMove

    @OnMouseMove.setter
    def OnMouseMove(self, value):
        self.com_object.OnMouseMove = value

    @property
    def onmousemove(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @onmousemove.setter
    def onmousemove(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def on_mouse_move(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @on_mouse_move.setter
    def on_mouse_move(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def OnMouseUp(self):
        return self.com_object.OnMouseUp

    @OnMouseUp.setter
    def OnMouseUp(self, value):
        self.com_object.OnMouseUp = value

    @property
    def onmouseup(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @onmouseup.setter
    def onmouseup(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def on_mouse_up(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @on_mouse_up.setter
    def on_mouse_up(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def OnPush(self):
        return self.com_object.OnPush

    @OnPush.setter
    def OnPush(self, value):
        self.com_object.OnPush = value

    @property
    def onpush(self):
        """Alias for OnPush"""
        return self.OnPush

    @onpush.setter
    def onpush(self, value):
        """Alias for OnPush.setter"""
        self.OnPush = value

    @property
    def on_push(self):
        """Alias for OnPush"""
        return self.OnPush

    @on_push.setter
    def on_push(self, value):
        """Alias for OnPush.setter"""
        self.OnPush = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Picture(self):
        return self.com_object.Picture

    @Picture.setter
    def Picture(self, value):
        self.com_object.Picture = value

    @property
    def picture(self):
        """Alias for Picture"""
        return self.Picture

    @picture.setter
    def picture(self, value):
        """Alias for Picture.setter"""
        self.Picture = value

    @property
    def PictureCaptionArrangement(self):
        return self.com_object.PictureCaptionArrangement

    @PictureCaptionArrangement.setter
    def PictureCaptionArrangement(self, value):
        self.com_object.PictureCaptionArrangement = value

    @property
    def picturecaptionarrangement(self):
        """Alias for PictureCaptionArrangement"""
        return self.PictureCaptionArrangement

    @picturecaptionarrangement.setter
    def picturecaptionarrangement(self, value):
        """Alias for PictureCaptionArrangement.setter"""
        self.PictureCaptionArrangement = value

    @property
    def picture_caption_arrangement(self):
        """Alias for PictureCaptionArrangement"""
        return self.PictureCaptionArrangement

    @picture_caption_arrangement.setter
    def picture_caption_arrangement(self, value):
        """Alias for PictureCaptionArrangement.setter"""
        self.PictureCaptionArrangement = value

    @property
    def PictureData(self):
        return self.com_object.PictureData

    @PictureData.setter
    def PictureData(self, value):
        self.com_object.PictureData = value

    @property
    def picturedata(self):
        """Alias for PictureData"""
        return self.PictureData

    @picturedata.setter
    def picturedata(self, value):
        """Alias for PictureData.setter"""
        self.PictureData = value

    @property
    def picture_data(self):
        """Alias for PictureData"""
        return self.PictureData

    @picture_data.setter
    def picture_data(self, value):
        """Alias for PictureData.setter"""
        self.PictureData = value

    @property
    def PictureType(self):
        return self.com_object.PictureType

    @PictureType.setter
    def PictureType(self, value):
        self.com_object.PictureType = value

    @property
    def picturetype(self):
        """Alias for PictureType"""
        return self.PictureType

    @picturetype.setter
    def picturetype(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def picture_type(self):
        """Alias for PictureType"""
        return self.PictureType

    @picture_type.setter
    def picture_type(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def PressedColor(self):
        return self.com_object.PressedColor

    @PressedColor.setter
    def PressedColor(self, value):
        self.com_object.PressedColor = value

    @property
    def pressedcolor(self):
        """Alias for PressedColor"""
        return self.PressedColor

    @pressedcolor.setter
    def pressedcolor(self, value):
        """Alias for PressedColor.setter"""
        self.PressedColor = value

    @property
    def pressed_color(self):
        """Alias for PressedColor"""
        return self.PressedColor

    @pressed_color.setter
    def pressed_color(self, value):
        """Alias for PressedColor.setter"""
        self.PressedColor = value

    @property
    def PressedForeColor(self):
        return self.com_object.PressedForeColor

    @PressedForeColor.setter
    def PressedForeColor(self, value):
        self.com_object.PressedForeColor = value

    @property
    def pressedforecolor(self):
        """Alias for PressedForeColor"""
        return self.PressedForeColor

    @pressedforecolor.setter
    def pressedforecolor(self, value):
        """Alias for PressedForeColor.setter"""
        self.PressedForeColor = value

    @property
    def pressed_fore_color(self):
        """Alias for PressedForeColor"""
        return self.PressedForeColor

    @pressed_fore_color.setter
    def pressed_fore_color(self, value):
        """Alias for PressedForeColor.setter"""
        self.PressedForeColor = value

    @property
    def PressedForeShade(self):
        return self.com_object.PressedForeShade

    @PressedForeShade.setter
    def PressedForeShade(self, value):
        self.com_object.PressedForeShade = value

    @property
    def pressedforeshade(self):
        """Alias for PressedForeShade"""
        return self.PressedForeShade

    @pressedforeshade.setter
    def pressedforeshade(self, value):
        """Alias for PressedForeShade.setter"""
        self.PressedForeShade = value

    @property
    def pressed_fore_shade(self):
        """Alias for PressedForeShade"""
        return self.PressedForeShade

    @pressed_fore_shade.setter
    def pressed_fore_shade(self, value):
        """Alias for PressedForeShade.setter"""
        self.PressedForeShade = value

    @property
    def PressedForeThemeColorIndex(self):
        return self.com_object.PressedForeThemeColorIndex

    @PressedForeThemeColorIndex.setter
    def PressedForeThemeColorIndex(self, value):
        self.com_object.PressedForeThemeColorIndex = value

    @property
    def pressedforethemecolorindex(self):
        """Alias for PressedForeThemeColorIndex"""
        return self.PressedForeThemeColorIndex

    @pressedforethemecolorindex.setter
    def pressedforethemecolorindex(self, value):
        """Alias for PressedForeThemeColorIndex.setter"""
        self.PressedForeThemeColorIndex = value

    @property
    def pressed_fore_theme_color_index(self):
        """Alias for PressedForeThemeColorIndex"""
        return self.PressedForeThemeColorIndex

    @pressed_fore_theme_color_index.setter
    def pressed_fore_theme_color_index(self, value):
        """Alias for PressedForeThemeColorIndex.setter"""
        self.PressedForeThemeColorIndex = value

    @property
    def PressedForeTint(self):
        return self.com_object.PressedForeTint

    @PressedForeTint.setter
    def PressedForeTint(self, value):
        self.com_object.PressedForeTint = value

    @property
    def pressedforetint(self):
        """Alias for PressedForeTint"""
        return self.PressedForeTint

    @pressedforetint.setter
    def pressedforetint(self, value):
        """Alias for PressedForeTint.setter"""
        self.PressedForeTint = value

    @property
    def pressed_fore_tint(self):
        """Alias for PressedForeTint"""
        return self.PressedForeTint

    @pressed_fore_tint.setter
    def pressed_fore_tint(self, value):
        """Alias for PressedForeTint.setter"""
        self.PressedForeTint = value

    @property
    def PressedShade(self):
        return self.com_object.PressedShade

    @PressedShade.setter
    def PressedShade(self, value):
        self.com_object.PressedShade = value

    @property
    def pressedshade(self):
        """Alias for PressedShade"""
        return self.PressedShade

    @pressedshade.setter
    def pressedshade(self, value):
        """Alias for PressedShade.setter"""
        self.PressedShade = value

    @property
    def pressed_shade(self):
        """Alias for PressedShade"""
        return self.PressedShade

    @pressed_shade.setter
    def pressed_shade(self, value):
        """Alias for PressedShade.setter"""
        self.PressedShade = value

    @property
    def PressedThemeColorIndex(self):
        return self.com_object.PressedThemeColorIndex

    @PressedThemeColorIndex.setter
    def PressedThemeColorIndex(self, value):
        self.com_object.PressedThemeColorIndex = value

    @property
    def pressedthemecolorindex(self):
        """Alias for PressedThemeColorIndex"""
        return self.PressedThemeColorIndex

    @pressedthemecolorindex.setter
    def pressedthemecolorindex(self, value):
        """Alias for PressedThemeColorIndex.setter"""
        self.PressedThemeColorIndex = value

    @property
    def pressed_theme_color_index(self):
        """Alias for PressedThemeColorIndex"""
        return self.PressedThemeColorIndex

    @pressed_theme_color_index.setter
    def pressed_theme_color_index(self, value):
        """Alias for PressedThemeColorIndex.setter"""
        self.PressedThemeColorIndex = value

    @property
    def PressedTint(self):
        return self.com_object.PressedTint

    @PressedTint.setter
    def PressedTint(self, value):
        self.com_object.PressedTint = value

    @property
    def pressedtint(self):
        """Alias for PressedTint"""
        return self.PressedTint

    @pressedtint.setter
    def pressedtint(self, value):
        """Alias for PressedTint.setter"""
        self.PressedTint = value

    @property
    def pressed_tint(self):
        """Alias for PressedTint"""
        return self.PressedTint

    @pressed_tint.setter
    def pressed_tint(self, value):
        """Alias for PressedTint.setter"""
        self.PressedTint = value

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def QuickStyle(self):
        return self.com_object.QuickStyle

    @QuickStyle.setter
    def QuickStyle(self, value):
        self.com_object.QuickStyle = value

    @property
    def quickstyle(self):
        """Alias for QuickStyle"""
        return self.QuickStyle

    @quickstyle.setter
    def quickstyle(self, value):
        """Alias for QuickStyle.setter"""
        self.QuickStyle = value

    @property
    def quick_style(self):
        """Alias for QuickStyle"""
        return self.QuickStyle

    @quick_style.setter
    def quick_style(self, value):
        """Alias for QuickStyle.setter"""
        self.QuickStyle = value

    @property
    def QuickStyleMask(self):
        return self.com_object.QuickStyleMask

    @QuickStyleMask.setter
    def QuickStyleMask(self, value):
        self.com_object.QuickStyleMask = value

    @property
    def quickstylemask(self):
        """Alias for QuickStyleMask"""
        return self.QuickStyleMask

    @quickstylemask.setter
    def quickstylemask(self, value):
        """Alias for QuickStyleMask.setter"""
        self.QuickStyleMask = value

    @property
    def quick_style_mask(self):
        """Alias for QuickStyleMask"""
        return self.QuickStyleMask

    @quick_style_mask.setter
    def quick_style_mask(self, value):
        """Alias for QuickStyleMask.setter"""
        self.QuickStyleMask = value

    @property
    def ReadingOrder(self):
        return self.com_object.ReadingOrder

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def RightPadding(self):
        return self.com_object.RightPadding

    @RightPadding.setter
    def RightPadding(self, value):
        self.com_object.RightPadding = value

    @property
    def rightpadding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @rightpadding.setter
    def rightpadding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def right_padding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @right_padding.setter
    def right_padding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def Section(self):
        return self.com_object.Section

    @Section.setter
    def Section(self, value):
        self.com_object.Section = value

    @property
    def section(self):
        """Alias for Section"""
        return self.Section

    @section.setter
    def section(self, value):
        """Alias for Section.setter"""
        self.Section = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Shape(self):
        return self.com_object.Shape

    @Shape.setter
    def Shape(self, value):
        self.com_object.Shape = value

    @property
    def shape(self):
        """Alias for Shape"""
        return self.Shape

    @shape.setter
    def shape(self, value):
        """Alias for Shape.setter"""
        self.Shape = value

    @property
    def ShortcutMenuBar(self):
        return self.com_object.ShortcutMenuBar

    @ShortcutMenuBar.setter
    def ShortcutMenuBar(self, value):
        self.com_object.ShortcutMenuBar = value

    @property
    def shortcutmenubar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcutmenubar.setter
    def shortcutmenubar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def shortcut_menu_bar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcut_menu_bar.setter
    def shortcut_menu_bar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def SoftEdges(self):
        return self.com_object.SoftEdges

    @SoftEdges.setter
    def SoftEdges(self, value):
        self.com_object.SoftEdges = value

    @property
    def softedges(self):
        """Alias for SoftEdges"""
        return self.SoftEdges

    @softedges.setter
    def softedges(self, value):
        """Alias for SoftEdges.setter"""
        self.SoftEdges = value

    @property
    def soft_edges(self):
        """Alias for SoftEdges"""
        return self.SoftEdges

    @soft_edges.setter
    def soft_edges(self, value):
        """Alias for SoftEdges.setter"""
        self.SoftEdges = value

    @property
    def StatusBarText(self):
        return self.com_object.StatusBarText

    @StatusBarText.setter
    def StatusBarText(self, value):
        self.com_object.StatusBarText = value

    @property
    def statusbartext(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @statusbartext.setter
    def statusbartext(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def status_bar_text(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @status_bar_text.setter
    def status_bar_text(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def TabIndex(self):
        return self.com_object.TabIndex

    @TabIndex.setter
    def TabIndex(self, value):
        self.com_object.TabIndex = value

    @property
    def tabindex(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tabindex.setter
    def tabindex(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def tab_index(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tab_index.setter
    def tab_index(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def TabStop(self):
        return self.com_object.TabStop

    @TabStop.setter
    def TabStop(self, value):
        self.com_object.TabStop = value

    @property
    def tabstop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tabstop.setter
    def tabstop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def tab_stop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tab_stop.setter
    def tab_stop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def ThemeFontIndex(self):
        return self.com_object.ThemeFontIndex

    @ThemeFontIndex.setter
    def ThemeFontIndex(self, value):
        self.com_object.ThemeFontIndex = value

    @property
    def themefontindex(self):
        """Alias for ThemeFontIndex"""
        return self.ThemeFontIndex

    @themefontindex.setter
    def themefontindex(self, value):
        """Alias for ThemeFontIndex.setter"""
        self.ThemeFontIndex = value

    @property
    def theme_font_index(self):
        """Alias for ThemeFontIndex"""
        return self.ThemeFontIndex

    @theme_font_index.setter
    def theme_font_index(self, value):
        """Alias for ThemeFontIndex.setter"""
        self.ThemeFontIndex = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TopPadding(self):
        return self.com_object.TopPadding

    @TopPadding.setter
    def TopPadding(self, value):
        self.com_object.TopPadding = value

    @property
    def toppadding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @toppadding.setter
    def toppadding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def top_padding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @top_padding.setter
    def top_padding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def Transparent(self):
        return self.com_object.Transparent

    @Transparent.setter
    def Transparent(self, value):
        self.com_object.Transparent = value

    @property
    def transparent(self):
        """Alias for Transparent"""
        return self.Transparent

    @transparent.setter
    def transparent(self, value):
        """Alias for Transparent.setter"""
        self.Transparent = value

    @property
    def UseTheme(self):
        return self.com_object.UseTheme

    @UseTheme.setter
    def UseTheme(self, value):
        self.com_object.UseTheme = value

    @property
    def usetheme(self):
        """Alias for UseTheme"""
        return self.UseTheme

    @usetheme.setter
    def usetheme(self, value):
        """Alias for UseTheme.setter"""
        self.UseTheme = value

    @property
    def use_theme(self):
        """Alias for UseTheme"""
        return self.UseTheme

    @use_theme.setter
    def use_theme(self, value):
        """Alias for UseTheme.setter"""
        self.UseTheme = value

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def Requery(self):
        self.com_object.Requery()

    def requery(self):
        """Alias for Requery"""
        return self.Requery()

    def SetFocus(self):
        return self.com_object.SetFocus()

    def setfocus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def set_focus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()


class Control:

    def __init__(self, control=None):
        self.com_object= control

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BottomPadding(self):
        return self.com_object.BottomPadding

    @BottomPadding.setter
    def BottomPadding(self, value):
        self.com_object.BottomPadding = value

    @property
    def bottompadding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottompadding.setter
    def bottompadding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def bottom_padding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottom_padding.setter
    def bottom_padding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    def Column(self, Index=None, Row=None):
        arguments = com_arguments([unwrap(a) for a in [Index, Row]])
        if hasattr(self.com_object, "GetColumn"):
            return self.com_object.GetColumn(*arguments)
        else:
            return self.com_object.Column(*arguments)

    def column(self, Index=None, Row=None):
        """Alias for Column"""
        arguments = [Index, Row]
        return self.Column(*arguments)

    @property
    def Controls(self):
        return Controls(self.com_object.Controls)

    @property
    def controls(self):
        """Alias for Controls"""
        return self.Controls

    @property
    def Form(self):
        return self.com_object.Form

    @property
    def form(self):
        """Alias for Form"""
        return self.Form

    @property
    def GridlineColor(self):
        return self.com_object.GridlineColor

    @GridlineColor.setter
    def GridlineColor(self, value):
        self.com_object.GridlineColor = value

    @property
    def gridlinecolor(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridlinecolor.setter
    def gridlinecolor(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def gridline_color(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridline_color.setter
    def gridline_color(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def GridlineStyleBottom(self):
        return self.com_object.GridlineStyleBottom

    @GridlineStyleBottom.setter
    def GridlineStyleBottom(self, value):
        self.com_object.GridlineStyleBottom = value

    @property
    def gridlinestylebottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridlinestylebottom.setter
    def gridlinestylebottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def gridline_style_bottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridline_style_bottom.setter
    def gridline_style_bottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def GridlineStyleLeft(self):
        return self.com_object.GridlineStyleLeft

    @GridlineStyleLeft.setter
    def GridlineStyleLeft(self, value):
        self.com_object.GridlineStyleLeft = value

    @property
    def gridlinestyleleft(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridlinestyleleft.setter
    def gridlinestyleleft(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def gridline_style_left(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridline_style_left.setter
    def gridline_style_left(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def GridlineStyleRight(self):
        return self.com_object.GridlineStyleRight

    @GridlineStyleRight.setter
    def GridlineStyleRight(self, value):
        self.com_object.GridlineStyleRight = value

    @property
    def gridlinestyleright(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridlinestyleright.setter
    def gridlinestyleright(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def gridline_style_right(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridline_style_right.setter
    def gridline_style_right(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def GridlineStyleTop(self):
        return self.com_object.GridlineStyleTop

    @GridlineStyleTop.setter
    def GridlineStyleTop(self, value):
        self.com_object.GridlineStyleTop = value

    @property
    def gridlinestyletop(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridlinestyletop.setter
    def gridlinestyletop(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def gridline_style_top(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridline_style_top.setter
    def gridline_style_top(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def GridlineWidthBottom(self):
        return self.com_object.GridlineWidthBottom

    @GridlineWidthBottom.setter
    def GridlineWidthBottom(self, value):
        self.com_object.GridlineWidthBottom = value

    @property
    def gridlinewidthbottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridlinewidthbottom.setter
    def gridlinewidthbottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def gridline_width_bottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridline_width_bottom.setter
    def gridline_width_bottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def GridlineWidthLeft(self):
        return self.com_object.GridlineWidthLeft

    @GridlineWidthLeft.setter
    def GridlineWidthLeft(self, value):
        self.com_object.GridlineWidthLeft = value

    @property
    def gridlinewidthleft(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridlinewidthleft.setter
    def gridlinewidthleft(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def gridline_width_left(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridline_width_left.setter
    def gridline_width_left(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def GridlineWidthRight(self):
        return self.com_object.GridlineWidthRight

    @GridlineWidthRight.setter
    def GridlineWidthRight(self, value):
        self.com_object.GridlineWidthRight = value

    @property
    def gridlinewidthright(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridlinewidthright.setter
    def gridlinewidthright(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def gridline_width_right(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridline_width_right.setter
    def gridline_width_right(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def GridlineWidthTop(self):
        return self.com_object.GridlineWidthTop

    @GridlineWidthTop.setter
    def GridlineWidthTop(self, value):
        self.com_object.GridlineWidthTop = value

    @property
    def gridlinewidthtop(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridlinewidthtop.setter
    def gridlinewidthtop(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def gridline_width_top(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridline_width_top.setter
    def gridline_width_top(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def Hyperlink(self):
        return self.com_object.Hyperlink

    @property
    def hyperlink(self):
        """Alias for Hyperlink"""
        return self.Hyperlink

    def ItemData(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItemData"):
            return self.com_object.GetItemData(*arguments)
        else:
            return self.com_object.ItemData(*arguments)

    def itemdata(self, Index=None):
        """Alias for ItemData"""
        arguments = [Index]
        return self.ItemData(*arguments)

    def item_data(self, Index=None):
        """Alias for ItemData"""
        arguments = [Index]
        return self.ItemData(*arguments)

    @property
    def ItemsSelected(self):
        return self.com_object.ItemsSelected

    @property
    def itemsselected(self):
        """Alias for ItemsSelected"""
        return self.ItemsSelected

    @property
    def items_selected(self):
        """Alias for ItemsSelected"""
        return self.ItemsSelected

    @property
    def Layout(self):
        return AcLayoutType(self.com_object.Layout)

    @property
    def layout(self):
        """Alias for Layout"""
        return self.Layout

    @property
    def LayoutID(self):
        return self.com_object.LayoutID

    @property
    def layoutid(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def layout_i_d(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def LeftPadding(self):
        return self.com_object.LeftPadding

    @LeftPadding.setter
    def LeftPadding(self, value):
        self.com_object.LeftPadding = value

    @property
    def leftpadding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @leftpadding.setter
    def leftpadding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def left_padding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @left_padding.setter
    def left_padding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Object(self):
        return self.com_object.Object

    @property
    def object(self):
        """Alias for Object"""
        return self.Object

    def ObjectVerbs(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetObjectVerbs"):
            return self.com_object.GetObjectVerbs(*arguments)
        else:
            return self.com_object.ObjectVerbs(*arguments)

    def objectverbs(self, Index=None):
        """Alias for ObjectVerbs"""
        arguments = [Index]
        return self.ObjectVerbs(*arguments)

    def object_verbs(self, Index=None):
        """Alias for ObjectVerbs"""
        arguments = [Index]
        return self.ObjectVerbs(*arguments)

    @property
    def OldValue(self):
        return self.com_object.OldValue

    @property
    def oldvalue(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def old_value(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def Pages(self):
        return Pages(self.com_object.Pages)

    @property
    def pages(self):
        """Alias for Pages"""
        return self.Pages

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def Report(self):
        return self.com_object.Report

    @property
    def report(self):
        """Alias for Report"""
        return self.Report

    @property
    def RightPadding(self):
        return self.com_object.RightPadding

    @RightPadding.setter
    def RightPadding(self, value):
        self.com_object.RightPadding = value

    @property
    def rightpadding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @rightpadding.setter
    def rightpadding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def right_padding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @right_padding.setter
    def right_padding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def Selected(self):
        return self.com_object.Selected

    @Selected.setter
    def Selected(self, value):
        self.com_object.Selected = value

    @property
    def selected(self):
        """Alias for Selected"""
        return self.Selected

    @selected.setter
    def selected(self, value):
        """Alias for Selected.setter"""
        self.Selected = value

    @property
    def SmartTags(self):
        return SmartTags(self.com_object.SmartTags)

    @property
    def smarttags(self):
        """Alias for SmartTags"""
        return self.SmartTags

    @property
    def smart_tags(self):
        """Alias for SmartTags"""
        return self.SmartTags

    @property
    def TopPadding(self):
        return self.com_object.TopPadding

    @TopPadding.setter
    def TopPadding(self, value):
        self.com_object.TopPadding = value

    @property
    def toppadding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @toppadding.setter
    def toppadding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def top_padding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @top_padding.setter
    def top_padding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    def Dropdown(self):
        return self.com_object.Dropdown()

    def dropdown(self):
        """Alias for Dropdown"""
        return self.Dropdown()

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def Requery(self):
        self.com_object.Requery()

    def requery(self):
        """Alias for Requery"""
        return self.Requery()

    def SetFocus(self):
        return self.com_object.SetFocus()

    def setfocus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def set_focus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def Undo(self):
        self.com_object.Undo()

    def undo(self):
        """Alias for Undo"""
        return self.Undo()


class Controls:

    def __init__(self, controls=None):
        self.com_object= controls

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class CurrentData:

    def __init__(self, currentdata=None):
        self.com_object= currentdata

    @property
    def AllDatabaseDiagrams(self):
        return self.com_object.AllDatabaseDiagrams

    @property
    def alldatabasediagrams(self):
        """Alias for AllDatabaseDiagrams"""
        return self.AllDatabaseDiagrams

    @property
    def all_database_diagrams(self):
        """Alias for AllDatabaseDiagrams"""
        return self.AllDatabaseDiagrams

    @property
    def AllFunctions(self):
        return self.com_object.AllFunctions

    @property
    def allfunctions(self):
        """Alias for AllFunctions"""
        return self.AllFunctions

    @property
    def all_functions(self):
        """Alias for AllFunctions"""
        return self.AllFunctions

    @property
    def AllQueries(self):
        return self.com_object.AllQueries

    @property
    def allqueries(self):
        """Alias for AllQueries"""
        return self.AllQueries

    @property
    def all_queries(self):
        """Alias for AllQueries"""
        return self.AllQueries

    @property
    def AllStoredProcedures(self):
        return self.com_object.AllStoredProcedures

    @property
    def allstoredprocedures(self):
        """Alias for AllStoredProcedures"""
        return self.AllStoredProcedures

    @property
    def all_stored_procedures(self):
        """Alias for AllStoredProcedures"""
        return self.AllStoredProcedures

    @property
    def AllTables(self):
        return self.com_object.AllTables

    @property
    def alltables(self):
        """Alias for AllTables"""
        return self.AllTables

    @property
    def all_tables(self):
        """Alias for AllTables"""
        return self.AllTables

    @property
    def AllViews(self):
        return self.com_object.AllViews

    @property
    def allviews(self):
        """Alias for AllViews"""
        return self.AllViews

    @property
    def all_views(self):
        """Alias for AllViews"""
        return self.AllViews


class CurrentProject:

    def __init__(self, currentproject=None):
        self.com_object= currentproject

    @property
    def AccessConnection(self):
        return self.com_object.AccessConnection

    @property
    def accessconnection(self):
        """Alias for AccessConnection"""
        return self.AccessConnection

    @property
    def access_connection(self):
        """Alias for AccessConnection"""
        return self.AccessConnection

    @property
    def AllForms(self):
        return self.com_object.AllForms

    @property
    def allforms(self):
        """Alias for AllForms"""
        return self.AllForms

    @property
    def all_forms(self):
        """Alias for AllForms"""
        return self.AllForms

    @property
    def AllMacros(self):
        return self.com_object.AllMacros

    @property
    def allmacros(self):
        """Alias for AllMacros"""
        return self.AllMacros

    @property
    def all_macros(self):
        """Alias for AllMacros"""
        return self.AllMacros

    @property
    def AllModules(self):
        return self.com_object.AllModules

    @property
    def allmodules(self):
        """Alias for AllModules"""
        return self.AllModules

    @property
    def all_modules(self):
        """Alias for AllModules"""
        return self.AllModules

    @property
    def AllReports(self):
        return self.com_object.AllReports

    @property
    def allreports(self):
        """Alias for AllReports"""
        return self.AllReports

    @property
    def all_reports(self):
        """Alias for AllReports"""
        return self.AllReports

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BaseConnectionString(self):
        return self.com_object.BaseConnectionString

    @property
    def baseconnectionstring(self):
        """Alias for BaseConnectionString"""
        return self.BaseConnectionString

    @property
    def base_connection_string(self):
        """Alias for BaseConnectionString"""
        return self.BaseConnectionString

    @property
    def Connection(self):
        return self.com_object.Connection

    @property
    def connection(self):
        """Alias for Connection"""
        return self.Connection

    @property
    def FileFormat(self):
        return AcFileFormat(self.com_object.FileFormat)

    @property
    def fileformat(self):
        """Alias for FileFormat"""
        return self.FileFormat

    @property
    def file_format(self):
        """Alias for FileFormat"""
        return self.FileFormat

    @property
    def FullName(self):
        return self.com_object.FullName

    @property
    def fullname(self):
        """Alias for FullName"""
        return self.FullName

    @property
    def full_name(self):
        """Alias for FullName"""
        return self.FullName

    @property
    def ImportExportSpecifications(self):
        return ImportExportSpecifications(self.com_object.ImportExportSpecifications)

    @property
    def importexportspecifications(self):
        """Alias for ImportExportSpecifications"""
        return self.ImportExportSpecifications

    @property
    def import_export_specifications(self):
        """Alias for ImportExportSpecifications"""
        return self.ImportExportSpecifications

    @property
    def IsConnected(self):
        return self.com_object.IsConnected

    @property
    def isconnected(self):
        """Alias for IsConnected"""
        return self.IsConnected

    @property
    def is_connected(self):
        """Alias for IsConnected"""
        return self.IsConnected

    @property
    def IsTrusted(self):
        return self.com_object.IsTrusted

    @property
    def istrusted(self):
        """Alias for IsTrusted"""
        return self.IsTrusted

    @property
    def is_trusted(self):
        """Alias for IsTrusted"""
        return self.IsTrusted

    @property
    def IsWeb(self):
        return self.com_object.IsWeb

    @property
    def isweb(self):
        """Alias for IsWeb"""
        return self.IsWeb

    @property
    def is_web(self):
        """Alias for IsWeb"""
        return self.IsWeb

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Path(self):
        return self.com_object.Path

    @property
    def path(self):
        """Alias for Path"""
        return self.Path

    @property
    def ProjectType(self):
        return self.com_object.ProjectType

    @property
    def projecttype(self):
        """Alias for ProjectType"""
        return self.ProjectType

    @property
    def project_type(self):
        """Alias for ProjectType"""
        return self.ProjectType

    @property
    def Properties(self):
        return CurrentProject(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def RemovePersonalInformation(self):
        return self.com_object.RemovePersonalInformation

    @RemovePersonalInformation.setter
    def RemovePersonalInformation(self, value):
        self.com_object.RemovePersonalInformation = value

    @property
    def removepersonalinformation(self):
        """Alias for RemovePersonalInformation"""
        return self.RemovePersonalInformation

    @removepersonalinformation.setter
    def removepersonalinformation(self, value):
        """Alias for RemovePersonalInformation.setter"""
        self.RemovePersonalInformation = value

    @property
    def remove_personal_information(self):
        """Alias for RemovePersonalInformation"""
        return self.RemovePersonalInformation

    @remove_personal_information.setter
    def remove_personal_information(self, value):
        """Alias for RemovePersonalInformation.setter"""
        self.RemovePersonalInformation = value

    @property
    def Resources(self):
        return self.com_object.Resources

    @property
    def resources(self):
        """Alias for Resources"""
        return self.Resources

    @property
    def WebSite(self):
        return self.com_object.WebSite

    @property
    def website(self):
        """Alias for WebSite"""
        return self.WebSite

    @property
    def web_site(self):
        """Alias for WebSite"""
        return self.WebSite

    def AddSharedImage(self, SharedImageName=None, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [SharedImageName, FileName]])
        self.com_object.AddSharedImage(*arguments)

    def addsharedimage(self, SharedImageName=None, FileName=None):
        """Alias for AddSharedImage"""
        arguments = [SharedImageName, FileName]
        return self.AddSharedImage(*arguments)

    def add_shared_image(self, SharedImageName=None, FileName=None):
        """Alias for AddSharedImage"""
        arguments = [SharedImageName, FileName]
        return self.AddSharedImage(*arguments)

    def CloseConnection(self):
        return self.com_object.CloseConnection()

    def closeconnection(self):
        """Alias for CloseConnection"""
        return self.CloseConnection()

    def close_connection(self):
        """Alias for CloseConnection"""
        return self.CloseConnection()

    def OpenConnection(self, BaseConnectionString=None, UserID=None, Password=None):
        arguments = com_arguments([unwrap(a) for a in [BaseConnectionString, UserID, Password]])
        self.com_object.OpenConnection(*arguments)

    def openconnection(self, BaseConnectionString=None, UserID=None, Password=None):
        """Alias for OpenConnection"""
        arguments = [BaseConnectionString, UserID, Password]
        return self.OpenConnection(*arguments)

    def open_connection(self, BaseConnectionString=None, UserID=None, Password=None):
        """Alias for OpenConnection"""
        arguments = [BaseConnectionString, UserID, Password]
        return self.OpenConnection(*arguments)

    def UpdateDependencyInfo(self):
        self.com_object.UpdateDependencyInfo()

    def updatedependencyinfo(self):
        """Alias for UpdateDependencyInfo"""
        return self.UpdateDependencyInfo()

    def update_dependency_info(self):
        """Alias for UpdateDependencyInfo"""
        return self.UpdateDependencyInfo()


class CustomControl:

    def __init__(self, customcontrol=None):
        self.com_object= customcontrol

    @property
    def About(self):
        return self.com_object.About

    @About.setter
    def About(self, value):
        self.com_object.About = value

    @property
    def about(self):
        """Alias for About"""
        return self.About

    @about.setter
    def about(self, value):
        """Alias for About.setter"""
        self.About = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BorderColor(self):
        return self.com_object.BorderColor

    @BorderColor.setter
    def BorderColor(self, value):
        self.com_object.BorderColor = value

    @property
    def bordercolor(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @bordercolor.setter
    def bordercolor(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def border_color(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @border_color.setter
    def border_color(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def BorderShade(self):
        return self.com_object.BorderShade

    @BorderShade.setter
    def BorderShade(self, value):
        self.com_object.BorderShade = value

    @property
    def bordershade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @bordershade.setter
    def bordershade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def border_shade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @border_shade.setter
    def border_shade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def BorderStyle(self):
        return self.com_object.BorderStyle

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def BorderThemeColorIndex(self):
        return self.com_object.BorderThemeColorIndex

    @BorderThemeColorIndex.setter
    def BorderThemeColorIndex(self, value):
        self.com_object.BorderThemeColorIndex = value

    @property
    def borderthemecolorindex(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @borderthemecolorindex.setter
    def borderthemecolorindex(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def border_theme_color_index(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @border_theme_color_index.setter
    def border_theme_color_index(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def BorderTint(self):
        return self.com_object.BorderTint

    @BorderTint.setter
    def BorderTint(self, value):
        self.com_object.BorderTint = value

    @property
    def bordertint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @bordertint.setter
    def bordertint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def border_tint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @border_tint.setter
    def border_tint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def BorderWidth(self):
        return self.com_object.BorderWidth

    @BorderWidth.setter
    def BorderWidth(self, value):
        self.com_object.BorderWidth = value

    @property
    def borderwidth(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @borderwidth.setter
    def borderwidth(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def border_width(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @border_width.setter
    def border_width(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def BottomPadding(self):
        return self.com_object.BottomPadding

    @BottomPadding.setter
    def BottomPadding(self, value):
        self.com_object.BottomPadding = value

    @property
    def bottompadding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottompadding.setter
    def bottompadding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def bottom_padding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottom_padding.setter
    def bottom_padding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def Cancel(self):
        return self.com_object.Cancel

    @Cancel.setter
    def Cancel(self, value):
        self.com_object.Cancel = value

    @property
    def cancel(self):
        """Alias for Cancel"""
        return self.Cancel

    @cancel.setter
    def cancel(self, value):
        """Alias for Cancel.setter"""
        self.Cancel = value

    @property
    def Class(self):
        return self.com_object.Class

    @Class.setter
    def Class(self, value):
        self.com_object.Class = value

    @property
    def Controls(self):
        return Controls(self.com_object.Controls)

    @property
    def controls(self):
        """Alias for Controls"""
        return self.Controls

    @property
    def ControlSource(self):
        return self.com_object.ControlSource

    @ControlSource.setter
    def ControlSource(self, value):
        self.com_object.ControlSource = value

    @property
    def controlsource(self):
        """Alias for ControlSource"""
        return self.ControlSource

    @controlsource.setter
    def controlsource(self, value):
        """Alias for ControlSource.setter"""
        self.ControlSource = value

    @property
    def control_source(self):
        """Alias for ControlSource"""
        return self.ControlSource

    @control_source.setter
    def control_source(self, value):
        """Alias for ControlSource.setter"""
        self.ControlSource = value

    @property
    def ControlTipText(self):
        return self.com_object.ControlTipText

    @ControlTipText.setter
    def ControlTipText(self, value):
        self.com_object.ControlTipText = value

    @property
    def controltiptext(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @controltiptext.setter
    def controltiptext(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def control_tip_text(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @control_tip_text.setter
    def control_tip_text(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def ControlType(self):
        return self.com_object.ControlType

    @ControlType.setter
    def ControlType(self, value):
        self.com_object.ControlType = value

    @property
    def controltype(self):
        """Alias for ControlType"""
        return self.ControlType

    @controltype.setter
    def controltype(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def control_type(self):
        """Alias for ControlType"""
        return self.ControlType

    @control_type.setter
    def control_type(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def Custom(self):
        return self.com_object.Custom

    @Custom.setter
    def Custom(self, value):
        self.com_object.Custom = value

    @property
    def custom(self):
        """Alias for Custom"""
        return self.Custom

    @custom.setter
    def custom(self, value):
        """Alias for Custom.setter"""
        self.Custom = value

    @property
    def Default(self):
        return self.com_object.Default

    @Default.setter
    def Default(self, value):
        self.com_object.Default = value

    @property
    def default(self):
        """Alias for Default"""
        return self.Default

    @default.setter
    def default(self, value):
        """Alias for Default.setter"""
        self.Default = value

    @property
    def DisplayWhen(self):
        return self.com_object.DisplayWhen

    @DisplayWhen.setter
    def DisplayWhen(self, value):
        self.com_object.DisplayWhen = value

    @property
    def displaywhen(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @displaywhen.setter
    def displaywhen(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def display_when(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @display_when.setter
    def display_when(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def GridlineColor(self):
        return self.com_object.GridlineColor

    @GridlineColor.setter
    def GridlineColor(self, value):
        self.com_object.GridlineColor = value

    @property
    def gridlinecolor(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridlinecolor.setter
    def gridlinecolor(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def gridline_color(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridline_color.setter
    def gridline_color(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def GridlineStyleBottom(self):
        return self.com_object.GridlineStyleBottom

    @GridlineStyleBottom.setter
    def GridlineStyleBottom(self, value):
        self.com_object.GridlineStyleBottom = value

    @property
    def gridlinestylebottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridlinestylebottom.setter
    def gridlinestylebottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def gridline_style_bottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridline_style_bottom.setter
    def gridline_style_bottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def GridlineStyleLeft(self):
        return self.com_object.GridlineStyleLeft

    @GridlineStyleLeft.setter
    def GridlineStyleLeft(self, value):
        self.com_object.GridlineStyleLeft = value

    @property
    def gridlinestyleleft(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridlinestyleleft.setter
    def gridlinestyleleft(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def gridline_style_left(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridline_style_left.setter
    def gridline_style_left(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def GridlineStyleRight(self):
        return self.com_object.GridlineStyleRight

    @GridlineStyleRight.setter
    def GridlineStyleRight(self, value):
        self.com_object.GridlineStyleRight = value

    @property
    def gridlinestyleright(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridlinestyleright.setter
    def gridlinestyleright(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def gridline_style_right(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridline_style_right.setter
    def gridline_style_right(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def GridlineStyleTop(self):
        return self.com_object.GridlineStyleTop

    @GridlineStyleTop.setter
    def GridlineStyleTop(self, value):
        self.com_object.GridlineStyleTop = value

    @property
    def gridlinestyletop(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridlinestyletop.setter
    def gridlinestyletop(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def gridline_style_top(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridline_style_top.setter
    def gridline_style_top(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def GridlineWidthBottom(self):
        return self.com_object.GridlineWidthBottom

    @GridlineWidthBottom.setter
    def GridlineWidthBottom(self, value):
        self.com_object.GridlineWidthBottom = value

    @property
    def gridlinewidthbottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridlinewidthbottom.setter
    def gridlinewidthbottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def gridline_width_bottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridline_width_bottom.setter
    def gridline_width_bottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def GridlineWidthLeft(self):
        return self.com_object.GridlineWidthLeft

    @GridlineWidthLeft.setter
    def GridlineWidthLeft(self, value):
        self.com_object.GridlineWidthLeft = value

    @property
    def gridlinewidthleft(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridlinewidthleft.setter
    def gridlinewidthleft(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def gridline_width_left(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridline_width_left.setter
    def gridline_width_left(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def GridlineWidthRight(self):
        return self.com_object.GridlineWidthRight

    @GridlineWidthRight.setter
    def GridlineWidthRight(self, value):
        self.com_object.GridlineWidthRight = value

    @property
    def gridlinewidthright(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridlinewidthright.setter
    def gridlinewidthright(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def gridline_width_right(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridline_width_right.setter
    def gridline_width_right(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def GridlineWidthTop(self):
        return self.com_object.GridlineWidthTop

    @GridlineWidthTop.setter
    def GridlineWidthTop(self, value):
        self.com_object.GridlineWidthTop = value

    @property
    def gridlinewidthtop(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridlinewidthtop.setter
    def gridlinewidthtop(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def gridline_width_top(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridline_width_top.setter
    def gridline_width_top(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HelpContextId(self):
        return self.com_object.HelpContextId

    @HelpContextId.setter
    def HelpContextId(self, value):
        self.com_object.HelpContextId = value

    @property
    def helpcontextid(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @helpcontextid.setter
    def helpcontextid(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def help_context_id(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @help_context_id.setter
    def help_context_id(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def IsVisible(self):
        return self.com_object.IsVisible

    @IsVisible.setter
    def IsVisible(self, value):
        self.com_object.IsVisible = value

    @property
    def isvisible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @isvisible.setter
    def isvisible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def is_visible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @is_visible.setter
    def is_visible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def Layout(self):
        return AcLayoutType(self.com_object.Layout)

    @property
    def layout(self):
        """Alias for Layout"""
        return self.Layout

    @property
    def LayoutID(self):
        return self.com_object.LayoutID

    @property
    def layoutid(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def layout_i_d(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def LeftPadding(self):
        return self.com_object.LeftPadding

    @LeftPadding.setter
    def LeftPadding(self, value):
        self.com_object.LeftPadding = value

    @property
    def leftpadding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @leftpadding.setter
    def leftpadding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def left_padding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @left_padding.setter
    def left_padding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Object(self):
        return self.com_object.Object

    @property
    def object(self):
        """Alias for Object"""
        return self.Object

    @property
    def ObjectPalette(self):
        return self.com_object.ObjectPalette

    @ObjectPalette.setter
    def ObjectPalette(self, value):
        self.com_object.ObjectPalette = value

    @property
    def objectpalette(self):
        """Alias for ObjectPalette"""
        return self.ObjectPalette

    @objectpalette.setter
    def objectpalette(self, value):
        """Alias for ObjectPalette.setter"""
        self.ObjectPalette = value

    @property
    def object_palette(self):
        """Alias for ObjectPalette"""
        return self.ObjectPalette

    @object_palette.setter
    def object_palette(self, value):
        """Alias for ObjectPalette.setter"""
        self.ObjectPalette = value

    def ObjectVerbs(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetObjectVerbs"):
            return self.com_object.GetObjectVerbs(*arguments)
        else:
            return self.com_object.ObjectVerbs(*arguments)

    def objectverbs(self, Index=None):
        """Alias for ObjectVerbs"""
        arguments = [Index]
        return self.ObjectVerbs(*arguments)

    def object_verbs(self, Index=None):
        """Alias for ObjectVerbs"""
        arguments = [Index]
        return self.ObjectVerbs(*arguments)

    @property
    def ObjectVerbsCount(self):
        return self.com_object.ObjectVerbsCount

    @property
    def objectverbscount(self):
        """Alias for ObjectVerbsCount"""
        return self.ObjectVerbsCount

    @property
    def object_verbs_count(self):
        """Alias for ObjectVerbsCount"""
        return self.ObjectVerbsCount

    @property
    def OldBorderStyle(self):
        return self.com_object.OldBorderStyle

    @OldBorderStyle.setter
    def OldBorderStyle(self, value):
        self.com_object.OldBorderStyle = value

    @property
    def oldborderstyle(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @oldborderstyle.setter
    def oldborderstyle(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def old_border_style(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @old_border_style.setter
    def old_border_style(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def OldValue(self):
        return self.com_object.OldValue

    @property
    def oldvalue(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def old_value(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def OLEClass(self):
        return self.com_object.OLEClass

    @property
    def oleclass(self):
        """Alias for OLEClass"""
        return self.OLEClass

    @property
    def o_l_e_class(self):
        """Alias for OLEClass"""
        return self.OLEClass

    @property
    def OnEnter(self):
        return self.com_object.OnEnter

    @OnEnter.setter
    def OnEnter(self, value):
        self.com_object.OnEnter = value

    @property
    def onenter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @onenter.setter
    def onenter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def on_enter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @on_enter.setter
    def on_enter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def OnExit(self):
        return self.com_object.OnExit

    @OnExit.setter
    def OnExit(self, value):
        self.com_object.OnExit = value

    @property
    def onexit(self):
        """Alias for OnExit"""
        return self.OnExit

    @onexit.setter
    def onexit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def on_exit(self):
        """Alias for OnExit"""
        return self.OnExit

    @on_exit.setter
    def on_exit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def OnGotFocus(self):
        return self.com_object.OnGotFocus

    @OnGotFocus.setter
    def OnGotFocus(self, value):
        self.com_object.OnGotFocus = value

    @property
    def ongotfocus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @ongotfocus.setter
    def ongotfocus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def on_got_focus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @on_got_focus.setter
    def on_got_focus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def OnLostFocus(self):
        return self.com_object.OnLostFocus

    @OnLostFocus.setter
    def OnLostFocus(self, value):
        self.com_object.OnLostFocus = value

    @property
    def onlostfocus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @onlostfocus.setter
    def onlostfocus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def on_lost_focus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @on_lost_focus.setter
    def on_lost_focus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def OnUpdated(self):
        return self.com_object.OnUpdated

    @OnUpdated.setter
    def OnUpdated(self, value):
        self.com_object.OnUpdated = value

    @property
    def onupdated(self):
        """Alias for OnUpdated"""
        return self.OnUpdated

    @onupdated.setter
    def onupdated(self, value):
        """Alias for OnUpdated.setter"""
        self.OnUpdated = value

    @property
    def on_updated(self):
        """Alias for OnUpdated"""
        return self.OnUpdated

    @on_updated.setter
    def on_updated(self, value):
        """Alias for OnUpdated.setter"""
        self.OnUpdated = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def RightPadding(self):
        return self.com_object.RightPadding

    @RightPadding.setter
    def RightPadding(self, value):
        self.com_object.RightPadding = value

    @property
    def rightpadding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @rightpadding.setter
    def rightpadding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def right_padding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @right_padding.setter
    def right_padding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def Section(self):
        return self.com_object.Section

    @Section.setter
    def Section(self, value):
        self.com_object.Section = value

    @property
    def section(self):
        """Alias for Section"""
        return self.Section

    @section.setter
    def section(self, value):
        """Alias for Section.setter"""
        self.Section = value

    @property
    def SpecialEffect(self):
        return self.com_object.SpecialEffect

    @SpecialEffect.setter
    def SpecialEffect(self, value):
        self.com_object.SpecialEffect = value

    @property
    def specialeffect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @specialeffect.setter
    def specialeffect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def special_effect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @special_effect.setter
    def special_effect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def TabIndex(self):
        return self.com_object.TabIndex

    @TabIndex.setter
    def TabIndex(self, value):
        self.com_object.TabIndex = value

    @property
    def tabindex(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tabindex.setter
    def tabindex(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def tab_index(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tab_index.setter
    def tab_index(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def TabStop(self):
        return self.com_object.TabStop

    @TabStop.setter
    def TabStop(self, value):
        self.com_object.TabStop = value

    @property
    def tabstop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tabstop.setter
    def tabstop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def tab_stop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tab_stop.setter
    def tab_stop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TopPadding(self):
        return self.com_object.TopPadding

    @TopPadding.setter
    def TopPadding(self, value):
        self.com_object.TopPadding = value

    @property
    def toppadding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @toppadding.setter
    def toppadding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def top_padding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @top_padding.setter
    def top_padding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    @property
    def VarOleObject(self):
        return self.com_object.VarOleObject

    @property
    def varoleobject(self):
        """Alias for VarOleObject"""
        return self.VarOleObject

    @property
    def var_ole_object(self):
        """Alias for VarOleObject"""
        return self.VarOleObject

    @property
    def Verb(self):
        return self.com_object.Verb

    @Verb.setter
    def Verb(self, value):
        self.com_object.Verb = value

    @property
    def verb(self):
        """Alias for Verb"""
        return self.Verb

    @verb.setter
    def verb(self, value):
        """Alias for Verb.setter"""
        self.Verb = value

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def Requery(self):
        self.com_object.Requery()

    def requery(self):
        """Alias for Requery"""
        return self.Requery()

    def SetFocus(self):
        return self.com_object.SetFocus()

    def setfocus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def set_focus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()


class DependencyInfo:

    def __init__(self, dependencyinfo=None):
        self.com_object= dependencyinfo

    @property
    def Dependants(self):
        return DependencyObjects(self.com_object.Dependants)

    @property
    def dependants(self):
        """Alias for Dependants"""
        return self.Dependants

    @property
    def Dependencies(self):
        return DependencyObjects(self.com_object.Dependencies)

    @property
    def dependencies(self):
        """Alias for Dependencies"""
        return self.Dependencies

    @property
    def InsufficientPermissions(self):
        return DependencyObjects(self.com_object.InsufficientPermissions)

    @property
    def insufficientpermissions(self):
        """Alias for InsufficientPermissions"""
        return self.InsufficientPermissions

    @property
    def insufficient_permissions(self):
        """Alias for InsufficientPermissions"""
        return self.InsufficientPermissions

    @property
    def OutOfDateObjects(self):
        return DependencyObjects(self.com_object.OutOfDateObjects)

    @property
    def outofdateobjects(self):
        """Alias for OutOfDateObjects"""
        return self.OutOfDateObjects

    @property
    def out_of_date_objects(self):
        """Alias for OutOfDateObjects"""
        return self.OutOfDateObjects

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def UnsupportedObjects(self):
        return DependencyObjects(self.com_object.UnsupportedObjects)

    @property
    def unsupportedobjects(self):
        """Alias for UnsupportedObjects"""
        return self.UnsupportedObjects

    @property
    def unsupported_objects(self):
        """Alias for UnsupportedObjects"""
        return self.UnsupportedObjects


class DependencyObjects:

    def __init__(self, dependencyobjects=None):
        self.com_object= dependencyobjects

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class DoCmd:

    def __init__(self, docmd=None):
        self.com_object= docmd

    def AddMenu(self, MenuName=None, MenuMacroName=None, StatusBarText=None):
        arguments = com_arguments([unwrap(a) for a in [MenuName, MenuMacroName, StatusBarText]])
        self.com_object.AddMenu(*arguments)

    def addmenu(self, MenuName=None, MenuMacroName=None, StatusBarText=None):
        """Alias for AddMenu"""
        arguments = [MenuName, MenuMacroName, StatusBarText]
        return self.AddMenu(*arguments)

    def add_menu(self, MenuName=None, MenuMacroName=None, StatusBarText=None):
        """Alias for AddMenu"""
        arguments = [MenuName, MenuMacroName, StatusBarText]
        return self.AddMenu(*arguments)

    def ApplyFilter(self, FilterName=None, WhereCondition=None, ControlName=None):
        arguments = com_arguments([unwrap(a) for a in [FilterName, WhereCondition, ControlName]])
        self.com_object.ApplyFilter(*arguments)

    def applyfilter(self, FilterName=None, WhereCondition=None, ControlName=None):
        """Alias for ApplyFilter"""
        arguments = [FilterName, WhereCondition, ControlName]
        return self.ApplyFilter(*arguments)

    def apply_filter(self, FilterName=None, WhereCondition=None, ControlName=None):
        """Alias for ApplyFilter"""
        arguments = [FilterName, WhereCondition, ControlName]
        return self.ApplyFilter(*arguments)

    def Beep(self):
        self.com_object.Beep()

    def beep(self):
        """Alias for Beep"""
        return self.Beep()

    def BrowseTo(self, ObjectType=None, ObjectName=None, PathtoSubformControl=None, WhereCondition=None, Page=None, DataMode=None):
        arguments = com_arguments([unwrap(a) for a in [ObjectType, ObjectName, PathtoSubformControl, WhereCondition, Page, DataMode]])
        self.com_object.BrowseTo(*arguments)

    def browseto(self, ObjectType=None, ObjectName=None, PathtoSubformControl=None, WhereCondition=None, Page=None, DataMode=None):
        """Alias for BrowseTo"""
        arguments = [ObjectType, ObjectName, PathtoSubformControl, WhereCondition, Page, DataMode]
        return self.BrowseTo(*arguments)

    def browse_to(self, ObjectType=None, ObjectName=None, PathtoSubformControl=None, WhereCondition=None, Page=None, DataMode=None):
        """Alias for BrowseTo"""
        arguments = [ObjectType, ObjectName, PathtoSubformControl, WhereCondition, Page, DataMode]
        return self.BrowseTo(*arguments)

    def CancelEvent(self):
        self.com_object.CancelEvent()

    def cancelevent(self):
        """Alias for CancelEvent"""
        return self.CancelEvent()

    def cancel_event(self):
        """Alias for CancelEvent"""
        return self.CancelEvent()

    def ClearMacroError(self):
        self.com_object.ClearMacroError()

    def clearmacroerror(self):
        """Alias for ClearMacroError"""
        return self.ClearMacroError()

    def clear_macro_error(self):
        """Alias for ClearMacroError"""
        return self.ClearMacroError()

    def Close(self, ObjectType=None, ObjectName=None, Save=None):
        arguments = com_arguments([unwrap(a) for a in [ObjectType, ObjectName, Save]])
        self.com_object.Close(*arguments)

    def close(self, ObjectType=None, ObjectName=None, Save=None):
        """Alias for Close"""
        arguments = [ObjectType, ObjectName, Save]
        return self.Close(*arguments)

    def CloseDatabase(self):
        self.com_object.CloseDatabase()

    def closedatabase(self):
        """Alias for CloseDatabase"""
        return self.CloseDatabase()

    def close_database(self):
        """Alias for CloseDatabase"""
        return self.CloseDatabase()

    def CopyDatabaseFile(self, DatabaseFileName=None, OverwriteExistingFile=None, DisconnectAllUsers=None):
        arguments = com_arguments([unwrap(a) for a in [DatabaseFileName, OverwriteExistingFile, DisconnectAllUsers]])
        self.com_object.CopyDatabaseFile(*arguments)

    def copydatabasefile(self, DatabaseFileName=None, OverwriteExistingFile=None, DisconnectAllUsers=None):
        """Alias for CopyDatabaseFile"""
        arguments = [DatabaseFileName, OverwriteExistingFile, DisconnectAllUsers]
        return self.CopyDatabaseFile(*arguments)

    def copy_database_file(self, DatabaseFileName=None, OverwriteExistingFile=None, DisconnectAllUsers=None):
        """Alias for CopyDatabaseFile"""
        arguments = [DatabaseFileName, OverwriteExistingFile, DisconnectAllUsers]
        return self.CopyDatabaseFile(*arguments)

    def CopyObject(self, DestinationDatabase=None, NewName=None, SourceObjectType=None, SourceObjectName=None):
        arguments = com_arguments([unwrap(a) for a in [DestinationDatabase, NewName, SourceObjectType, SourceObjectName]])
        self.com_object.CopyObject(*arguments)

    def copyobject(self, DestinationDatabase=None, NewName=None, SourceObjectType=None, SourceObjectName=None):
        """Alias for CopyObject"""
        arguments = [DestinationDatabase, NewName, SourceObjectType, SourceObjectName]
        return self.CopyObject(*arguments)

    def copy_object(self, DestinationDatabase=None, NewName=None, SourceObjectType=None, SourceObjectName=None):
        """Alias for CopyObject"""
        arguments = [DestinationDatabase, NewName, SourceObjectType, SourceObjectName]
        return self.CopyObject(*arguments)

    def DeleteObject(self, ObjectType=None, ObjectName=None):
        arguments = com_arguments([unwrap(a) for a in [ObjectType, ObjectName]])
        self.com_object.DeleteObject(*arguments)

    def deleteobject(self, ObjectType=None, ObjectName=None):
        """Alias for DeleteObject"""
        arguments = [ObjectType, ObjectName]
        return self.DeleteObject(*arguments)

    def delete_object(self, ObjectType=None, ObjectName=None):
        """Alias for DeleteObject"""
        arguments = [ObjectType, ObjectName]
        return self.DeleteObject(*arguments)

    def DoMenuItem(self, MenuBar=None, MenuName=None, Command=None, Subcommand=None, Version=None):
        arguments = com_arguments([unwrap(a) for a in [MenuBar, MenuName, Command, Subcommand, Version]])
        self.com_object.DoMenuItem(*arguments)

    def domenuitem(self, MenuBar=None, MenuName=None, Command=None, Subcommand=None, Version=None):
        """Alias for DoMenuItem"""
        arguments = [MenuBar, MenuName, Command, Subcommand, Version]
        return self.DoMenuItem(*arguments)

    def do_menu_item(self, MenuBar=None, MenuName=None, Command=None, Subcommand=None, Version=None):
        """Alias for DoMenuItem"""
        arguments = [MenuBar, MenuName, Command, Subcommand, Version]
        return self.DoMenuItem(*arguments)

    def Echo(self, EchoOn=None, StatusBarText=None):
        arguments = com_arguments([unwrap(a) for a in [EchoOn, StatusBarText]])
        self.com_object.Echo(*arguments)

    def echo(self, EchoOn=None, StatusBarText=None):
        """Alias for Echo"""
        arguments = [EchoOn, StatusBarText]
        return self.Echo(*arguments)

    def FindNext(self):
        self.com_object.FindNext()

    def findnext(self):
        """Alias for FindNext"""
        return self.FindNext()

    def find_next(self):
        """Alias for FindNext"""
        return self.FindNext()

    def FindRecord(self, FindWhat=None, Match=None, MatchCase=None, Search=None, SearchAsFormatted=None, OnlyCurrentField=None, FindFirst=None):
        arguments = com_arguments([unwrap(a) for a in [FindWhat, Match, MatchCase, Search, SearchAsFormatted, OnlyCurrentField, FindFirst]])
        self.com_object.FindRecord(*arguments)

    def findrecord(self, FindWhat=None, Match=None, MatchCase=None, Search=None, SearchAsFormatted=None, OnlyCurrentField=None, FindFirst=None):
        """Alias for FindRecord"""
        arguments = [FindWhat, Match, MatchCase, Search, SearchAsFormatted, OnlyCurrentField, FindFirst]
        return self.FindRecord(*arguments)

    def find_record(self, FindWhat=None, Match=None, MatchCase=None, Search=None, SearchAsFormatted=None, OnlyCurrentField=None, FindFirst=None):
        """Alias for FindRecord"""
        arguments = [FindWhat, Match, MatchCase, Search, SearchAsFormatted, OnlyCurrentField, FindFirst]
        return self.FindRecord(*arguments)

    def GoToControl(self, ControlName=None):
        arguments = com_arguments([unwrap(a) for a in [ControlName]])
        self.com_object.GoToControl(*arguments)

    def gotocontrol(self, ControlName=None):
        """Alias for GoToControl"""
        arguments = [ControlName]
        return self.GoToControl(*arguments)

    def go_to_control(self, ControlName=None):
        """Alias for GoToControl"""
        arguments = [ControlName]
        return self.GoToControl(*arguments)

    def GoToPage(self, PageNumber=None, Right=None, Down=None):
        arguments = com_arguments([unwrap(a) for a in [PageNumber, Right, Down]])
        return self.com_object.GoToPage(*arguments)

    def gotopage(self, PageNumber=None, Right=None, Down=None):
        """Alias for GoToPage"""
        arguments = [PageNumber, Right, Down]
        return self.GoToPage(*arguments)

    def go_to_page(self, PageNumber=None, Right=None, Down=None):
        """Alias for GoToPage"""
        arguments = [PageNumber, Right, Down]
        return self.GoToPage(*arguments)

    def GoToRecord(self, ObjectType=None, ObjectName=None, Record=None, Offset=None):
        arguments = com_arguments([unwrap(a) for a in [ObjectType, ObjectName, Record, Offset]])
        self.com_object.GoToRecord(*arguments)

    def gotorecord(self, ObjectType=None, ObjectName=None, Record=None, Offset=None):
        """Alias for GoToRecord"""
        arguments = [ObjectType, ObjectName, Record, Offset]
        return self.GoToRecord(*arguments)

    def go_to_record(self, ObjectType=None, ObjectName=None, Record=None, Offset=None):
        """Alias for GoToRecord"""
        arguments = [ObjectType, ObjectName, Record, Offset]
        return self.GoToRecord(*arguments)

    def Hourglass(self, HourglassOn=None):
        arguments = com_arguments([unwrap(a) for a in [HourglassOn]])
        self.com_object.Hourglass(*arguments)

    def hourglass(self, HourglassOn=None):
        """Alias for Hourglass"""
        arguments = [HourglassOn]
        return self.Hourglass(*arguments)

    def LockNavigationPane(self, Lock=None):
        arguments = com_arguments([unwrap(a) for a in [Lock]])
        self.com_object.LockNavigationPane(*arguments)

    def locknavigationpane(self, Lock=None):
        """Alias for LockNavigationPane"""
        arguments = [Lock]
        return self.LockNavigationPane(*arguments)

    def lock_navigation_pane(self, Lock=None):
        """Alias for LockNavigationPane"""
        arguments = [Lock]
        return self.LockNavigationPane(*arguments)

    def Maximize(self):
        self.com_object.Maximize()

    def maximize(self):
        """Alias for Maximize"""
        return self.Maximize()

    def Minimize(self):
        self.com_object.Minimize()

    def minimize(self):
        """Alias for Minimize"""
        return self.Minimize()

    def MoveSize(self, Right=None, Down=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Right, Down, Width, Height]])
        self.com_object.MoveSize(*arguments)

    def movesize(self, Right=None, Down=None, Width=None, Height=None):
        """Alias for MoveSize"""
        arguments = [Right, Down, Width, Height]
        return self.MoveSize(*arguments)

    def move_size(self, Right=None, Down=None, Width=None, Height=None):
        """Alias for MoveSize"""
        arguments = [Right, Down, Width, Height]
        return self.MoveSize(*arguments)

    def NavigateTo(self, Category=None, Group=None):
        arguments = com_arguments([unwrap(a) for a in [Category, Group]])
        self.com_object.NavigateTo(*arguments)

    def navigateto(self, Category=None, Group=None):
        """Alias for NavigateTo"""
        arguments = [Category, Group]
        return self.NavigateTo(*arguments)

    def navigate_to(self, Category=None, Group=None):
        """Alias for NavigateTo"""
        arguments = [Category, Group]
        return self.NavigateTo(*arguments)

    def OpenDataAccessPage(self, DataAccessPageName=None, View=None):
        arguments = com_arguments([unwrap(a) for a in [DataAccessPageName, View]])
        self.com_object.OpenDataAccessPage(*arguments)

    def opendataaccesspage(self, DataAccessPageName=None, View=None):
        """Alias for OpenDataAccessPage"""
        arguments = [DataAccessPageName, View]
        return self.OpenDataAccessPage(*arguments)

    def open_data_access_page(self, DataAccessPageName=None, View=None):
        """Alias for OpenDataAccessPage"""
        arguments = [DataAccessPageName, View]
        return self.OpenDataAccessPage(*arguments)

    def OpenDiagram(self, DiagramName=None):
        arguments = com_arguments([unwrap(a) for a in [DiagramName]])
        self.com_object.OpenDiagram(*arguments)

    def opendiagram(self, DiagramName=None):
        """Alias for OpenDiagram"""
        arguments = [DiagramName]
        return self.OpenDiagram(*arguments)

    def open_diagram(self, DiagramName=None):
        """Alias for OpenDiagram"""
        arguments = [DiagramName]
        return self.OpenDiagram(*arguments)

    def OpenForm(self, FormName=None, View=None, FilterName=None, WhereCondition=None, DataMode=None, WindowMode=None, OpenArgs=None):
        arguments = com_arguments([unwrap(a) for a in [FormName, View, FilterName, WhereCondition, DataMode, WindowMode, OpenArgs]])
        self.com_object.OpenForm(*arguments)

    def openform(self, FormName=None, View=None, FilterName=None, WhereCondition=None, DataMode=None, WindowMode=None, OpenArgs=None):
        """Alias for OpenForm"""
        arguments = [FormName, View, FilterName, WhereCondition, DataMode, WindowMode, OpenArgs]
        return self.OpenForm(*arguments)

    def open_form(self, FormName=None, View=None, FilterName=None, WhereCondition=None, DataMode=None, WindowMode=None, OpenArgs=None):
        """Alias for OpenForm"""
        arguments = [FormName, View, FilterName, WhereCondition, DataMode, WindowMode, OpenArgs]
        return self.OpenForm(*arguments)

    def OpenFunction(self, FunctionName=None, View=None, DataMode=None):
        arguments = com_arguments([unwrap(a) for a in [FunctionName, View, DataMode]])
        self.com_object.OpenFunction(*arguments)

    def openfunction(self, FunctionName=None, View=None, DataMode=None):
        """Alias for OpenFunction"""
        arguments = [FunctionName, View, DataMode]
        return self.OpenFunction(*arguments)

    def open_function(self, FunctionName=None, View=None, DataMode=None):
        """Alias for OpenFunction"""
        arguments = [FunctionName, View, DataMode]
        return self.OpenFunction(*arguments)

    def OpenModule(self, ModuleName=None, ProcedureName=None):
        arguments = com_arguments([unwrap(a) for a in [ModuleName, ProcedureName]])
        self.com_object.OpenModule(*arguments)

    def openmodule(self, ModuleName=None, ProcedureName=None):
        """Alias for OpenModule"""
        arguments = [ModuleName, ProcedureName]
        return self.OpenModule(*arguments)

    def open_module(self, ModuleName=None, ProcedureName=None):
        """Alias for OpenModule"""
        arguments = [ModuleName, ProcedureName]
        return self.OpenModule(*arguments)

    def OpenQuery(self, QueryName=None, View=None, DataMode=None):
        arguments = com_arguments([unwrap(a) for a in [QueryName, View, DataMode]])
        self.com_object.OpenQuery(*arguments)

    def openquery(self, QueryName=None, View=None, DataMode=None):
        """Alias for OpenQuery"""
        arguments = [QueryName, View, DataMode]
        return self.OpenQuery(*arguments)

    def open_query(self, QueryName=None, View=None, DataMode=None):
        """Alias for OpenQuery"""
        arguments = [QueryName, View, DataMode]
        return self.OpenQuery(*arguments)

    def OpenReport(self, ReportName=None, View=None, FilterName=None, WhereCondition=None, WindowMode=None, OpenArgs=None):
        arguments = com_arguments([unwrap(a) for a in [ReportName, View, FilterName, WhereCondition, WindowMode, OpenArgs]])
        self.com_object.OpenReport(*arguments)

    def openreport(self, ReportName=None, View=None, FilterName=None, WhereCondition=None, WindowMode=None, OpenArgs=None):
        """Alias for OpenReport"""
        arguments = [ReportName, View, FilterName, WhereCondition, WindowMode, OpenArgs]
        return self.OpenReport(*arguments)

    def open_report(self, ReportName=None, View=None, FilterName=None, WhereCondition=None, WindowMode=None, OpenArgs=None):
        """Alias for OpenReport"""
        arguments = [ReportName, View, FilterName, WhereCondition, WindowMode, OpenArgs]
        return self.OpenReport(*arguments)

    def OpenStoredProcedure(self, ProcedureName=None, View=None, DataMode=None):
        arguments = com_arguments([unwrap(a) for a in [ProcedureName, View, DataMode]])
        self.com_object.OpenStoredProcedure(*arguments)

    def openstoredprocedure(self, ProcedureName=None, View=None, DataMode=None):
        """Alias for OpenStoredProcedure"""
        arguments = [ProcedureName, View, DataMode]
        return self.OpenStoredProcedure(*arguments)

    def open_stored_procedure(self, ProcedureName=None, View=None, DataMode=None):
        """Alias for OpenStoredProcedure"""
        arguments = [ProcedureName, View, DataMode]
        return self.OpenStoredProcedure(*arguments)

    def OpenTable(self, TableName=None, View=None, DataMode=None):
        arguments = com_arguments([unwrap(a) for a in [TableName, View, DataMode]])
        self.com_object.OpenTable(*arguments)

    def opentable(self, TableName=None, View=None, DataMode=None):
        """Alias for OpenTable"""
        arguments = [TableName, View, DataMode]
        return self.OpenTable(*arguments)

    def open_table(self, TableName=None, View=None, DataMode=None):
        """Alias for OpenTable"""
        arguments = [TableName, View, DataMode]
        return self.OpenTable(*arguments)

    def OpenView(self, ViewName=None, View=None, DataMode=None):
        arguments = com_arguments([unwrap(a) for a in [ViewName, View, DataMode]])
        self.com_object.OpenView(*arguments)

    def openview(self, ViewName=None, View=None, DataMode=None):
        """Alias for OpenView"""
        arguments = [ViewName, View, DataMode]
        return self.OpenView(*arguments)

    def open_view(self, ViewName=None, View=None, DataMode=None):
        """Alias for OpenView"""
        arguments = [ViewName, View, DataMode]
        return self.OpenView(*arguments)

    def OutputTo(self, ObjectType=None, ObjectName=None, OutputFormat=None, OutputFile=None, AutoStart=None, TemplateFile=None, Encoding=None, OutputQuality=None):
        arguments = com_arguments([unwrap(a) for a in [ObjectType, ObjectName, OutputFormat, OutputFile, AutoStart, TemplateFile, Encoding, OutputQuality]])
        self.com_object.OutputTo(*arguments)

    def outputto(self, ObjectType=None, ObjectName=None, OutputFormat=None, OutputFile=None, AutoStart=None, TemplateFile=None, Encoding=None, OutputQuality=None):
        """Alias for OutputTo"""
        arguments = [ObjectType, ObjectName, OutputFormat, OutputFile, AutoStart, TemplateFile, Encoding, OutputQuality]
        return self.OutputTo(*arguments)

    def output_to(self, ObjectType=None, ObjectName=None, OutputFormat=None, OutputFile=None, AutoStart=None, TemplateFile=None, Encoding=None, OutputQuality=None):
        """Alias for OutputTo"""
        arguments = [ObjectType, ObjectName, OutputFormat, OutputFile, AutoStart, TemplateFile, Encoding, OutputQuality]
        return self.OutputTo(*arguments)

    def PrintOut(self, PrintRange=None, PageFrom=None, PageTo=None, PrintQuality=None, Copies=None, CollateCopies=None):
        arguments = com_arguments([unwrap(a) for a in [PrintRange, PageFrom, PageTo, PrintQuality, Copies, CollateCopies]])
        self.com_object.PrintOut(*arguments)

    def printout(self, PrintRange=None, PageFrom=None, PageTo=None, PrintQuality=None, Copies=None, CollateCopies=None):
        """Alias for PrintOut"""
        arguments = [PrintRange, PageFrom, PageTo, PrintQuality, Copies, CollateCopies]
        return self.PrintOut(*arguments)

    def print_out(self, PrintRange=None, PageFrom=None, PageTo=None, PrintQuality=None, Copies=None, CollateCopies=None):
        """Alias for PrintOut"""
        arguments = [PrintRange, PageFrom, PageTo, PrintQuality, Copies, CollateCopies]
        return self.PrintOut(*arguments)

    def Quit(self, Options=None):
        arguments = com_arguments([unwrap(a) for a in [Options]])
        self.com_object.Quit(*arguments)

    def quit(self, Options=None):
        """Alias for Quit"""
        arguments = [Options]
        return self.Quit(*arguments)

    def RefreshRecord(self):
        self.com_object.RefreshRecord()

    def refreshrecord(self):
        """Alias for RefreshRecord"""
        return self.RefreshRecord()

    def refresh_record(self):
        """Alias for RefreshRecord"""
        return self.RefreshRecord()

    def Rename(self, NewName=None, ObjectType=None, OldName=None):
        arguments = com_arguments([unwrap(a) for a in [NewName, ObjectType, OldName]])
        self.com_object.Rename(*arguments)

    def rename(self, NewName=None, ObjectType=None, OldName=None):
        """Alias for Rename"""
        arguments = [NewName, ObjectType, OldName]
        return self.Rename(*arguments)

    def RepaintObject(self, ObjectType=None, ObjectName=None):
        arguments = com_arguments([unwrap(a) for a in [ObjectType, ObjectName]])
        self.com_object.RepaintObject(*arguments)

    def repaintobject(self, ObjectType=None, ObjectName=None):
        """Alias for RepaintObject"""
        arguments = [ObjectType, ObjectName]
        return self.RepaintObject(*arguments)

    def repaint_object(self, ObjectType=None, ObjectName=None):
        """Alias for RepaintObject"""
        arguments = [ObjectType, ObjectName]
        return self.RepaintObject(*arguments)

    def Requery(self, ControlName=None):
        arguments = com_arguments([unwrap(a) for a in [ControlName]])
        self.com_object.Requery(*arguments)

    def requery(self, ControlName=None):
        """Alias for Requery"""
        arguments = [ControlName]
        return self.Requery(*arguments)

    def Restore(self):
        self.com_object.Restore()

    def restore(self):
        """Alias for Restore"""
        return self.Restore()

    def RunCommand(self, Command=None):
        arguments = com_arguments([unwrap(a) for a in [Command]])
        self.com_object.RunCommand(*arguments)

    def runcommand(self, Command=None):
        """Alias for RunCommand"""
        arguments = [Command]
        return self.RunCommand(*arguments)

    def run_command(self, Command=None):
        """Alias for RunCommand"""
        arguments = [Command]
        return self.RunCommand(*arguments)

    def RunDataMacro(self, MacroName=None):
        arguments = com_arguments([unwrap(a) for a in [MacroName]])
        self.com_object.RunDataMacro(*arguments)

    def rundatamacro(self, MacroName=None):
        """Alias for RunDataMacro"""
        arguments = [MacroName]
        return self.RunDataMacro(*arguments)

    def run_data_macro(self, MacroName=None):
        """Alias for RunDataMacro"""
        arguments = [MacroName]
        return self.RunDataMacro(*arguments)

    def RunMacro(self, MacroName=None, RepeatCount=None, RepeatExpression=None):
        arguments = com_arguments([unwrap(a) for a in [MacroName, RepeatCount, RepeatExpression]])
        self.com_object.RunMacro(*arguments)

    def runmacro(self, MacroName=None, RepeatCount=None, RepeatExpression=None):
        """Alias for RunMacro"""
        arguments = [MacroName, RepeatCount, RepeatExpression]
        return self.RunMacro(*arguments)

    def run_macro(self, MacroName=None, RepeatCount=None, RepeatExpression=None):
        """Alias for RunMacro"""
        arguments = [MacroName, RepeatCount, RepeatExpression]
        return self.RunMacro(*arguments)

    def RunSavedImportExport(self, SavedImportExportName=None):
        arguments = com_arguments([unwrap(a) for a in [SavedImportExportName]])
        self.com_object.RunSavedImportExport(*arguments)

    def runsavedimportexport(self, SavedImportExportName=None):
        """Alias for RunSavedImportExport"""
        arguments = [SavedImportExportName]
        return self.RunSavedImportExport(*arguments)

    def run_saved_import_export(self, SavedImportExportName=None):
        """Alias for RunSavedImportExport"""
        arguments = [SavedImportExportName]
        return self.RunSavedImportExport(*arguments)

    def RunSQL(self, SQLStatement=None, UseTransaction=None):
        arguments = com_arguments([unwrap(a) for a in [SQLStatement, UseTransaction]])
        self.com_object.RunSQL(*arguments)

    def runsql(self, SQLStatement=None, UseTransaction=None):
        """Alias for RunSQL"""
        arguments = [SQLStatement, UseTransaction]
        return self.RunSQL(*arguments)

    def run_s_q_l(self, SQLStatement=None, UseTransaction=None):
        """Alias for RunSQL"""
        arguments = [SQLStatement, UseTransaction]
        return self.RunSQL(*arguments)

    def Save(self, ObjectType=None, ObjectName=None):
        arguments = com_arguments([unwrap(a) for a in [ObjectType, ObjectName]])
        self.com_object.Save(*arguments)

    def save(self, ObjectType=None, ObjectName=None):
        """Alias for Save"""
        arguments = [ObjectType, ObjectName]
        return self.Save(*arguments)

    def SearchForRecord(self, ObjectType=None, ObjectName=None, Record=None, WhereCondition=None):
        arguments = com_arguments([unwrap(a) for a in [ObjectType, ObjectName, Record, WhereCondition]])
        self.com_object.SearchForRecord(*arguments)

    def searchforrecord(self, ObjectType=None, ObjectName=None, Record=None, WhereCondition=None):
        """Alias for SearchForRecord"""
        arguments = [ObjectType, ObjectName, Record, WhereCondition]
        return self.SearchForRecord(*arguments)

    def search_for_record(self, ObjectType=None, ObjectName=None, Record=None, WhereCondition=None):
        """Alias for SearchForRecord"""
        arguments = [ObjectType, ObjectName, Record, WhereCondition]
        return self.SearchForRecord(*arguments)

    def SelectObject(self, ObjectType=None, ObjectName=None, InNavigationPane=None):
        arguments = com_arguments([unwrap(a) for a in [ObjectType, ObjectName, InNavigationPane]])
        self.com_object.SelectObject(*arguments)

    def selectobject(self, ObjectType=None, ObjectName=None, InNavigationPane=None):
        """Alias for SelectObject"""
        arguments = [ObjectType, ObjectName, InNavigationPane]
        return self.SelectObject(*arguments)

    def select_object(self, ObjectType=None, ObjectName=None, InNavigationPane=None):
        """Alias for SelectObject"""
        arguments = [ObjectType, ObjectName, InNavigationPane]
        return self.SelectObject(*arguments)

    def SendObject(self, ObjectType=None, ObjectName=None, OutputFormat=None, To=None, Cc=None, Bcc=None, Subject=None, MessageText=None, EditMessage=None, TemplateFile=None):
        arguments = com_arguments([unwrap(a) for a in [ObjectType, ObjectName, OutputFormat, To, Cc, Bcc, Subject, MessageText, EditMessage, TemplateFile]])
        self.com_object.SendObject(*arguments)

    def sendobject(self, ObjectType=None, ObjectName=None, OutputFormat=None, To=None, Cc=None, Bcc=None, Subject=None, MessageText=None, EditMessage=None, TemplateFile=None):
        """Alias for SendObject"""
        arguments = [ObjectType, ObjectName, OutputFormat, To, Cc, Bcc, Subject, MessageText, EditMessage, TemplateFile]
        return self.SendObject(*arguments)

    def send_object(self, ObjectType=None, ObjectName=None, OutputFormat=None, To=None, Cc=None, Bcc=None, Subject=None, MessageText=None, EditMessage=None, TemplateFile=None):
        """Alias for SendObject"""
        arguments = [ObjectType, ObjectName, OutputFormat, To, Cc, Bcc, Subject, MessageText, EditMessage, TemplateFile]
        return self.SendObject(*arguments)

    def SetDisplayedCategories(self, Show=None, Category=None):
        arguments = com_arguments([unwrap(a) for a in [Show, Category]])
        self.com_object.SetDisplayedCategories(*arguments)

    def setdisplayedcategories(self, Show=None, Category=None):
        """Alias for SetDisplayedCategories"""
        arguments = [Show, Category]
        return self.SetDisplayedCategories(*arguments)

    def set_displayed_categories(self, Show=None, Category=None):
        """Alias for SetDisplayedCategories"""
        arguments = [Show, Category]
        return self.SetDisplayedCategories(*arguments)

    def SetFilter(self, FilterName=None, WhereCondition=None, ControlName=None):
        arguments = com_arguments([unwrap(a) for a in [FilterName, WhereCondition, ControlName]])
        self.com_object.SetFilter(*arguments)

    def setfilter(self, FilterName=None, WhereCondition=None, ControlName=None):
        """Alias for SetFilter"""
        arguments = [FilterName, WhereCondition, ControlName]
        return self.SetFilter(*arguments)

    def set_filter(self, FilterName=None, WhereCondition=None, ControlName=None):
        """Alias for SetFilter"""
        arguments = [FilterName, WhereCondition, ControlName]
        return self.SetFilter(*arguments)

    def SetMenuItem(self, MenuIndex=None, CommandIndex=None, SubcommandIndex=None, Flag=None):
        arguments = com_arguments([unwrap(a) for a in [MenuIndex, CommandIndex, SubcommandIndex, Flag]])
        self.com_object.SetMenuItem(*arguments)

    def setmenuitem(self, MenuIndex=None, CommandIndex=None, SubcommandIndex=None, Flag=None):
        """Alias for SetMenuItem"""
        arguments = [MenuIndex, CommandIndex, SubcommandIndex, Flag]
        return self.SetMenuItem(*arguments)

    def set_menu_item(self, MenuIndex=None, CommandIndex=None, SubcommandIndex=None, Flag=None):
        """Alias for SetMenuItem"""
        arguments = [MenuIndex, CommandIndex, SubcommandIndex, Flag]
        return self.SetMenuItem(*arguments)

    def SetOrderBy(self, OrderBy=None, ControlName=None):
        arguments = com_arguments([unwrap(a) for a in [OrderBy, ControlName]])
        self.com_object.SetOrderBy(*arguments)

    def setorderby(self, OrderBy=None, ControlName=None):
        """Alias for SetOrderBy"""
        arguments = [OrderBy, ControlName]
        return self.SetOrderBy(*arguments)

    def set_order_by(self, OrderBy=None, ControlName=None):
        """Alias for SetOrderBy"""
        arguments = [OrderBy, ControlName]
        return self.SetOrderBy(*arguments)

    def SetParameter(self, Name=None, Expression=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Expression]])
        self.com_object.SetParameter(*arguments)

    def setparameter(self, Name=None, Expression=None):
        """Alias for SetParameter"""
        arguments = [Name, Expression]
        return self.SetParameter(*arguments)

    def set_parameter(self, Name=None, Expression=None):
        """Alias for SetParameter"""
        arguments = [Name, Expression]
        return self.SetParameter(*arguments)

    def SetProperty(self, ControlName=None, Property=None, Value=None):
        arguments = com_arguments([unwrap(a) for a in [ControlName, Property, Value]])
        self.com_object.SetProperty(*arguments)

    def setproperty(self, ControlName=None, Property=None, Value=None):
        """Alias for SetProperty"""
        arguments = [ControlName, Property, Value]
        return self.SetProperty(*arguments)

    def set_property(self, ControlName=None, Property=None, Value=None):
        """Alias for SetProperty"""
        arguments = [ControlName, Property, Value]
        return self.SetProperty(*arguments)

    def SetWarnings(self, WarningsOn=None):
        arguments = com_arguments([unwrap(a) for a in [WarningsOn]])
        self.com_object.SetWarnings(*arguments)

    def setwarnings(self, WarningsOn=None):
        """Alias for SetWarnings"""
        arguments = [WarningsOn]
        return self.SetWarnings(*arguments)

    def set_warnings(self, WarningsOn=None):
        """Alias for SetWarnings"""
        arguments = [WarningsOn]
        return self.SetWarnings(*arguments)

    def ShowAllRecords(self):
        self.com_object.ShowAllRecords()

    def showallrecords(self):
        """Alias for ShowAllRecords"""
        return self.ShowAllRecords()

    def show_all_records(self):
        """Alias for ShowAllRecords"""
        return self.ShowAllRecords()

    def ShowToolbar(self, ToolbarName=None, Show=None):
        arguments = com_arguments([unwrap(a) for a in [ToolbarName, Show]])
        self.com_object.ShowToolbar(*arguments)

    def showtoolbar(self, ToolbarName=None, Show=None):
        """Alias for ShowToolbar"""
        arguments = [ToolbarName, Show]
        return self.ShowToolbar(*arguments)

    def show_toolbar(self, ToolbarName=None, Show=None):
        """Alias for ShowToolbar"""
        arguments = [ToolbarName, Show]
        return self.ShowToolbar(*arguments)

    def SingleStep(self):
        self.com_object.SingleStep()

    def singlestep(self):
        """Alias for SingleStep"""
        return self.SingleStep()

    def single_step(self):
        """Alias for SingleStep"""
        return self.SingleStep()

    def TransferDatabase(self, TransferType=None, DatabaseType=None, DatabaseName=None, ObjectType=None, Source=None, Destination=None, StructureOnly=None, StoreLogin=None):
        arguments = com_arguments([unwrap(a) for a in [TransferType, DatabaseType, DatabaseName, ObjectType, Source, Destination, StructureOnly, StoreLogin]])
        self.com_object.TransferDatabase(*arguments)

    def transferdatabase(self, TransferType=None, DatabaseType=None, DatabaseName=None, ObjectType=None, Source=None, Destination=None, StructureOnly=None, StoreLogin=None):
        """Alias for TransferDatabase"""
        arguments = [TransferType, DatabaseType, DatabaseName, ObjectType, Source, Destination, StructureOnly, StoreLogin]
        return self.TransferDatabase(*arguments)

    def transfer_database(self, TransferType=None, DatabaseType=None, DatabaseName=None, ObjectType=None, Source=None, Destination=None, StructureOnly=None, StoreLogin=None):
        """Alias for TransferDatabase"""
        arguments = [TransferType, DatabaseType, DatabaseName, ObjectType, Source, Destination, StructureOnly, StoreLogin]
        return self.TransferDatabase(*arguments)

    def TransferSharePointList(self, TransferType=None, SiteAddress=None, ListID=None, ViewID=None, TableName=None, GetLookupDisplayValues=None):
        arguments = com_arguments([unwrap(a) for a in [TransferType, SiteAddress, ListID, ViewID, TableName, GetLookupDisplayValues]])
        self.com_object.TransferSharePointList(*arguments)

    def transfersharepointlist(self, TransferType=None, SiteAddress=None, ListID=None, ViewID=None, TableName=None, GetLookupDisplayValues=None):
        """Alias for TransferSharePointList"""
        arguments = [TransferType, SiteAddress, ListID, ViewID, TableName, GetLookupDisplayValues]
        return self.TransferSharePointList(*arguments)

    def transfer_share_point_list(self, TransferType=None, SiteAddress=None, ListID=None, ViewID=None, TableName=None, GetLookupDisplayValues=None):
        """Alias for TransferSharePointList"""
        arguments = [TransferType, SiteAddress, ListID, ViewID, TableName, GetLookupDisplayValues]
        return self.TransferSharePointList(*arguments)

    def TransferSpreadsheet(self, TransferType=None, SpreadsheetType=None, TableName=None, FileName=None, HasFieldNames=None, Range=None, UseOA=None):
        arguments = com_arguments([unwrap(a) for a in [TransferType, SpreadsheetType, TableName, FileName, HasFieldNames, Range, UseOA]])
        self.com_object.TransferSpreadsheet(*arguments)

    def transferspreadsheet(self, TransferType=None, SpreadsheetType=None, TableName=None, FileName=None, HasFieldNames=None, Range=None, UseOA=None):
        """Alias for TransferSpreadsheet"""
        arguments = [TransferType, SpreadsheetType, TableName, FileName, HasFieldNames, Range, UseOA]
        return self.TransferSpreadsheet(*arguments)

    def transfer_spreadsheet(self, TransferType=None, SpreadsheetType=None, TableName=None, FileName=None, HasFieldNames=None, Range=None, UseOA=None):
        """Alias for TransferSpreadsheet"""
        arguments = [TransferType, SpreadsheetType, TableName, FileName, HasFieldNames, Range, UseOA]
        return self.TransferSpreadsheet(*arguments)

    def TransferSQLDatabase(self, Server=None, Database=None, UseTrustedConnection=None, Login=None, Password=None, TransferCopyData=None):
        arguments = com_arguments([unwrap(a) for a in [Server, Database, UseTrustedConnection, Login, Password, TransferCopyData]])
        self.com_object.TransferSQLDatabase(*arguments)

    def transfersqldatabase(self, Server=None, Database=None, UseTrustedConnection=None, Login=None, Password=None, TransferCopyData=None):
        """Alias for TransferSQLDatabase"""
        arguments = [Server, Database, UseTrustedConnection, Login, Password, TransferCopyData]
        return self.TransferSQLDatabase(*arguments)

    def transfer_s_q_l_database(self, Server=None, Database=None, UseTrustedConnection=None, Login=None, Password=None, TransferCopyData=None):
        """Alias for TransferSQLDatabase"""
        arguments = [Server, Database, UseTrustedConnection, Login, Password, TransferCopyData]
        return self.TransferSQLDatabase(*arguments)

    def TransferText(self, TransferType=None, SpecificationName=None, TableName=None, FileName=None, HasFieldNames=None, HTMLTableName=None, CodePage=None):
        arguments = com_arguments([unwrap(a) for a in [TransferType, SpecificationName, TableName, FileName, HasFieldNames, HTMLTableName, CodePage]])
        self.com_object.TransferText(*arguments)

    def transfertext(self, TransferType=None, SpecificationName=None, TableName=None, FileName=None, HasFieldNames=None, HTMLTableName=None, CodePage=None):
        """Alias for TransferText"""
        arguments = [TransferType, SpecificationName, TableName, FileName, HasFieldNames, HTMLTableName, CodePage]
        return self.TransferText(*arguments)

    def transfer_text(self, TransferType=None, SpecificationName=None, TableName=None, FileName=None, HasFieldNames=None, HTMLTableName=None, CodePage=None):
        """Alias for TransferText"""
        arguments = [TransferType, SpecificationName, TableName, FileName, HasFieldNames, HTMLTableName, CodePage]
        return self.TransferText(*arguments)


class EdgeBrowserControl:

    def __init__(self, edgebrowsercontrol=None):
        self.com_object= edgebrowsercontrol

    @property
    def TrustedDomains(self):
        return self.com_object.TrustedDomains

    @TrustedDomains.setter
    def TrustedDomains(self, value):
        self.com_object.TrustedDomains = value

    @property
    def trusteddomains(self):
        """Alias for TrustedDomains"""
        return self.TrustedDomains

    @trusteddomains.setter
    def trusteddomains(self, value):
        """Alias for TrustedDomains.setter"""
        self.TrustedDomains = value

    @property
    def trusted_domains(self):
        """Alias for TrustedDomains"""
        return self.TrustedDomains

    @trusted_domains.setter
    def trusted_domains(self, value):
        """Alias for TrustedDomains.setter"""
        self.TrustedDomains = value

    def ExecuteJavascript(self, script=None):
        arguments = com_arguments([unwrap(a) for a in [script]])
        self.com_object.ExecuteJavascript(*arguments)

    def executejavascript(self, script=None):
        """Alias for ExecuteJavascript"""
        arguments = [script]
        return self.ExecuteJavascript(*arguments)

    def execute_javascript(self, script=None):
        """Alias for ExecuteJavascript"""
        arguments = [script]
        return self.ExecuteJavascript(*arguments)

    def Navigate(self, url=None):
        arguments = com_arguments([unwrap(a) for a in [url]])
        self.com_object.Navigate(*arguments)

    def navigate(self, url=None):
        """Alias for Navigate"""
        arguments = [url]
        return self.Navigate(*arguments)

    def Refresh(self):
        self.com_object.Refresh()

    def refresh(self):
        """Alias for Refresh"""
        return self.Refresh()

    def RetrieveJavascriptValue(self, expression=None):
        arguments = com_arguments([unwrap(a) for a in [expression]])
        self.com_object.RetrieveJavascriptValue(*arguments)

    def retrievejavascriptvalue(self, expression=None):
        """Alias for RetrieveJavascriptValue"""
        arguments = [expression]
        return self.RetrieveJavascriptValue(*arguments)

    def retrieve_javascript_value(self, expression=None):
        """Alias for RetrieveJavascriptValue"""
        arguments = [expression]
        return self.RetrieveJavascriptValue(*arguments)


class EmptyCell:

    def __init__(self, emptycell=None):
        self.com_object= emptycell

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BackShade(self):
        return self.com_object.BackShade

    @BackShade.setter
    def BackShade(self, value):
        self.com_object.BackShade = value

    @property
    def backshade(self):
        """Alias for BackShade"""
        return self.BackShade

    @backshade.setter
    def backshade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def back_shade(self):
        """Alias for BackShade"""
        return self.BackShade

    @back_shade.setter
    def back_shade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def BackStyle(self):
        return self.com_object.BackStyle

    @BackStyle.setter
    def BackStyle(self, value):
        self.com_object.BackStyle = value

    @property
    def backstyle(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @backstyle.setter
    def backstyle(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def back_style(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @back_style.setter
    def back_style(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def BackThemeColorIndex(self):
        return self.com_object.BackThemeColorIndex

    @BackThemeColorIndex.setter
    def BackThemeColorIndex(self, value):
        self.com_object.BackThemeColorIndex = value

    @property
    def backthemecolorindex(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @backthemecolorindex.setter
    def backthemecolorindex(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def back_theme_color_index(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @back_theme_color_index.setter
    def back_theme_color_index(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def BackTint(self):
        return self.com_object.BackTint

    @BackTint.setter
    def BackTint(self, value):
        self.com_object.BackTint = value

    @property
    def backtint(self):
        """Alias for BackTint"""
        return self.BackTint

    @backtint.setter
    def backtint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def back_tint(self):
        """Alias for BackTint"""
        return self.BackTint

    @back_tint.setter
    def back_tint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def BottomPadding(self):
        return self.com_object.BottomPadding

    @BottomPadding.setter
    def BottomPadding(self, value):
        self.com_object.BottomPadding = value

    @property
    def bottompadding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottompadding.setter
    def bottompadding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def bottom_padding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottom_padding.setter
    def bottom_padding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def ControlType(self):
        return self.com_object.ControlType

    @ControlType.setter
    def ControlType(self, value):
        self.com_object.ControlType = value

    @property
    def controltype(self):
        """Alias for ControlType"""
        return self.ControlType

    @controltype.setter
    def controltype(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def control_type(self):
        """Alias for ControlType"""
        return self.ControlType

    @control_type.setter
    def control_type(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def DisplayWhen(self):
        return self.com_object.DisplayWhen

    @DisplayWhen.setter
    def DisplayWhen(self, value):
        self.com_object.DisplayWhen = value

    @property
    def displaywhen(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @displaywhen.setter
    def displaywhen(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def display_when(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @display_when.setter
    def display_when(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def GridlineColor(self):
        return self.com_object.GridlineColor

    @GridlineColor.setter
    def GridlineColor(self, value):
        self.com_object.GridlineColor = value

    @property
    def gridlinecolor(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridlinecolor.setter
    def gridlinecolor(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def gridline_color(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridline_color.setter
    def gridline_color(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def GridlineShade(self):
        return self.com_object.GridlineShade

    @GridlineShade.setter
    def GridlineShade(self, value):
        self.com_object.GridlineShade = value

    @property
    def gridlineshade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridlineshade.setter
    def gridlineshade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def gridline_shade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridline_shade.setter
    def gridline_shade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def GridlineStyleBottom(self):
        return self.com_object.GridlineStyleBottom

    @GridlineStyleBottom.setter
    def GridlineStyleBottom(self, value):
        self.com_object.GridlineStyleBottom = value

    @property
    def gridlinestylebottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridlinestylebottom.setter
    def gridlinestylebottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def gridline_style_bottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridline_style_bottom.setter
    def gridline_style_bottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def GridlineStyleLeft(self):
        return self.com_object.GridlineStyleLeft

    @GridlineStyleLeft.setter
    def GridlineStyleLeft(self, value):
        self.com_object.GridlineStyleLeft = value

    @property
    def gridlinestyleleft(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridlinestyleleft.setter
    def gridlinestyleleft(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def gridline_style_left(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridline_style_left.setter
    def gridline_style_left(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def GridlineStyleRight(self):
        return self.com_object.GridlineStyleRight

    @GridlineStyleRight.setter
    def GridlineStyleRight(self, value):
        self.com_object.GridlineStyleRight = value

    @property
    def gridlinestyleright(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridlinestyleright.setter
    def gridlinestyleright(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def gridline_style_right(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridline_style_right.setter
    def gridline_style_right(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def GridlineStyleTop(self):
        return self.com_object.GridlineStyleTop

    @GridlineStyleTop.setter
    def GridlineStyleTop(self, value):
        self.com_object.GridlineStyleTop = value

    @property
    def gridlinestyletop(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridlinestyletop.setter
    def gridlinestyletop(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def gridline_style_top(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridline_style_top.setter
    def gridline_style_top(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def GridlineThemeColorIndex(self):
        return self.com_object.GridlineThemeColorIndex

    @GridlineThemeColorIndex.setter
    def GridlineThemeColorIndex(self, value):
        self.com_object.GridlineThemeColorIndex = value

    @property
    def gridlinethemecolorindex(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridlinethemecolorindex.setter
    def gridlinethemecolorindex(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def gridline_theme_color_index(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridline_theme_color_index.setter
    def gridline_theme_color_index(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def GridlineTint(self):
        return self.com_object.GridlineTint

    @GridlineTint.setter
    def GridlineTint(self, value):
        self.com_object.GridlineTint = value

    @property
    def gridlinetint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridlinetint.setter
    def gridlinetint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def gridline_tint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridline_tint.setter
    def gridline_tint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def GridlineWidthBottom(self):
        return self.com_object.GridlineWidthBottom

    @GridlineWidthBottom.setter
    def GridlineWidthBottom(self, value):
        self.com_object.GridlineWidthBottom = value

    @property
    def gridlinewidthbottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridlinewidthbottom.setter
    def gridlinewidthbottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def gridline_width_bottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridline_width_bottom.setter
    def gridline_width_bottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def GridlineWidthLeft(self):
        return self.com_object.GridlineWidthLeft

    @GridlineWidthLeft.setter
    def GridlineWidthLeft(self, value):
        self.com_object.GridlineWidthLeft = value

    @property
    def gridlinewidthleft(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridlinewidthleft.setter
    def gridlinewidthleft(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def gridline_width_left(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridline_width_left.setter
    def gridline_width_left(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def GridlineWidthRight(self):
        return self.com_object.GridlineWidthRight

    @GridlineWidthRight.setter
    def GridlineWidthRight(self, value):
        self.com_object.GridlineWidthRight = value

    @property
    def gridlinewidthright(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridlinewidthright.setter
    def gridlinewidthright(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def gridline_width_right(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridline_width_right.setter
    def gridline_width_right(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def GridlineWidthTop(self):
        return self.com_object.GridlineWidthTop

    @GridlineWidthTop.setter
    def GridlineWidthTop(self, value):
        self.com_object.GridlineWidthTop = value

    @property
    def gridlinewidthtop(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridlinewidthtop.setter
    def gridlinewidthtop(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def gridline_width_top(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridline_width_top.setter
    def gridline_width_top(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HelpContextId(self):
        return self.com_object.HelpContextId

    @HelpContextId.setter
    def HelpContextId(self, value):
        self.com_object.HelpContextId = value

    @property
    def helpcontextid(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @helpcontextid.setter
    def helpcontextid(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def help_context_id(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @help_context_id.setter
    def help_context_id(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def IsVisible(self):
        return self.com_object.IsVisible

    @IsVisible.setter
    def IsVisible(self, value):
        self.com_object.IsVisible = value

    @property
    def isvisible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @isvisible.setter
    def isvisible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def is_visible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @is_visible.setter
    def is_visible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def Layout(self):
        return AcLayoutType(self.com_object.Layout)

    @property
    def layout(self):
        """Alias for Layout"""
        return self.Layout

    @property
    def LayoutID(self):
        return self.com_object.LayoutID

    @property
    def layoutid(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def layout_i_d(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def LeftPadding(self):
        return self.com_object.LeftPadding

    @LeftPadding.setter
    def LeftPadding(self, value):
        self.com_object.LeftPadding = value

    @property
    def leftpadding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @leftpadding.setter
    def leftpadding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def left_padding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @left_padding.setter
    def left_padding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def RightPadding(self):
        return self.com_object.RightPadding

    @RightPadding.setter
    def RightPadding(self, value):
        self.com_object.RightPadding = value

    @property
    def rightpadding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @rightpadding.setter
    def rightpadding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def right_padding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @right_padding.setter
    def right_padding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def Section(self):
        return self.com_object.Section

    @Section.setter
    def Section(self, value):
        self.com_object.Section = value

    @property
    def section(self):
        """Alias for Section"""
        return self.Section

    @section.setter
    def section(self, value):
        """Alias for Section.setter"""
        self.Section = value

    @property
    def ShortcutMenuBar(self):
        return self.com_object.ShortcutMenuBar

    @ShortcutMenuBar.setter
    def ShortcutMenuBar(self, value):
        self.com_object.ShortcutMenuBar = value

    @property
    def shortcutmenubar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcutmenubar.setter
    def shortcutmenubar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def shortcut_menu_bar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcut_menu_bar.setter
    def shortcut_menu_bar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def SpecialEffect(self):
        return self.com_object.SpecialEffect

    @SpecialEffect.setter
    def SpecialEffect(self, value):
        self.com_object.SpecialEffect = value

    @property
    def specialeffect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @specialeffect.setter
    def specialeffect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def special_effect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @special_effect.setter
    def special_effect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def StatusBarText(self):
        return self.com_object.StatusBarText

    @StatusBarText.setter
    def StatusBarText(self, value):
        self.com_object.StatusBarText = value

    @property
    def statusbartext(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @statusbartext.setter
    def statusbartext(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def status_bar_text(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @status_bar_text.setter
    def status_bar_text(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TopPadding(self):
        return self.com_object.TopPadding

    @TopPadding.setter
    def TopPadding(self, value):
        self.com_object.TopPadding = value

    @property
    def toppadding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @toppadding.setter
    def toppadding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def top_padding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @top_padding.setter
    def top_padding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()


class Entities:

    def __init__(self, entities=None):
        self.com_object= entities

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class Entity:

    def __init__(self, entity=None):
        self.com_object= entity

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Operations(self):
        return self.com_object.Operations

    @property
    def operations(self):
        """Alias for Operations"""
        return self.Operations

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class Form:

    def __init__(self, form=None):
        self.com_object= form

    @property
    def ActiveControl(self):
        return self.com_object.ActiveControl

    @property
    def activecontrol(self):
        """Alias for ActiveControl"""
        return self.ActiveControl

    @property
    def active_control(self):
        """Alias for ActiveControl"""
        return self.ActiveControl

    @property
    def AfterDelConfirm(self):
        return self.com_object.AfterDelConfirm

    @AfterDelConfirm.setter
    def AfterDelConfirm(self, value):
        self.com_object.AfterDelConfirm = value

    @property
    def afterdelconfirm(self):
        """Alias for AfterDelConfirm"""
        return self.AfterDelConfirm

    @afterdelconfirm.setter
    def afterdelconfirm(self, value):
        """Alias for AfterDelConfirm.setter"""
        self.AfterDelConfirm = value

    @property
    def after_del_confirm(self):
        """Alias for AfterDelConfirm"""
        return self.AfterDelConfirm

    @after_del_confirm.setter
    def after_del_confirm(self, value):
        """Alias for AfterDelConfirm.setter"""
        self.AfterDelConfirm = value

    @property
    def AfterFinalRender(self):
        return self.com_object.AfterFinalRender

    @AfterFinalRender.setter
    def AfterFinalRender(self, value):
        self.com_object.AfterFinalRender = value

    @property
    def afterfinalrender(self):
        """Alias for AfterFinalRender"""
        return self.AfterFinalRender

    @afterfinalrender.setter
    def afterfinalrender(self, value):
        """Alias for AfterFinalRender.setter"""
        self.AfterFinalRender = value

    @property
    def after_final_render(self):
        """Alias for AfterFinalRender"""
        return self.AfterFinalRender

    @after_final_render.setter
    def after_final_render(self, value):
        """Alias for AfterFinalRender.setter"""
        self.AfterFinalRender = value

    @property
    def AfterInsert(self):
        return self.com_object.AfterInsert

    @AfterInsert.setter
    def AfterInsert(self, value):
        self.com_object.AfterInsert = value

    @property
    def afterinsert(self):
        """Alias for AfterInsert"""
        return self.AfterInsert

    @afterinsert.setter
    def afterinsert(self, value):
        """Alias for AfterInsert.setter"""
        self.AfterInsert = value

    @property
    def after_insert(self):
        """Alias for AfterInsert"""
        return self.AfterInsert

    @after_insert.setter
    def after_insert(self, value):
        """Alias for AfterInsert.setter"""
        self.AfterInsert = value

    @property
    def AfterLayout(self):
        return self.com_object.AfterLayout

    @AfterLayout.setter
    def AfterLayout(self, value):
        self.com_object.AfterLayout = value

    @property
    def afterlayout(self):
        """Alias for AfterLayout"""
        return self.AfterLayout

    @afterlayout.setter
    def afterlayout(self, value):
        """Alias for AfterLayout.setter"""
        self.AfterLayout = value

    @property
    def after_layout(self):
        """Alias for AfterLayout"""
        return self.AfterLayout

    @after_layout.setter
    def after_layout(self, value):
        """Alias for AfterLayout.setter"""
        self.AfterLayout = value

    @property
    def AfterRender(self):
        return self.com_object.AfterRender

    @AfterRender.setter
    def AfterRender(self, value):
        self.com_object.AfterRender = value

    @property
    def afterrender(self):
        """Alias for AfterRender"""
        return self.AfterRender

    @afterrender.setter
    def afterrender(self, value):
        """Alias for AfterRender.setter"""
        self.AfterRender = value

    @property
    def after_render(self):
        """Alias for AfterRender"""
        return self.AfterRender

    @after_render.setter
    def after_render(self, value):
        """Alias for AfterRender.setter"""
        self.AfterRender = value

    @property
    def AllowAdditions(self):
        return self.com_object.AllowAdditions

    @AllowAdditions.setter
    def AllowAdditions(self, value):
        self.com_object.AllowAdditions = value

    @property
    def allowadditions(self):
        """Alias for AllowAdditions"""
        return self.AllowAdditions

    @allowadditions.setter
    def allowadditions(self, value):
        """Alias for AllowAdditions.setter"""
        self.AllowAdditions = value

    @property
    def allow_additions(self):
        """Alias for AllowAdditions"""
        return self.AllowAdditions

    @allow_additions.setter
    def allow_additions(self, value):
        """Alias for AllowAdditions.setter"""
        self.AllowAdditions = value

    @property
    def AllowDatasheetView(self):
        return self.com_object.AllowDatasheetView

    @AllowDatasheetView.setter
    def AllowDatasheetView(self, value):
        self.com_object.AllowDatasheetView = value

    @property
    def allowdatasheetview(self):
        """Alias for AllowDatasheetView"""
        return self.AllowDatasheetView

    @allowdatasheetview.setter
    def allowdatasheetview(self, value):
        """Alias for AllowDatasheetView.setter"""
        self.AllowDatasheetView = value

    @property
    def allow_datasheet_view(self):
        """Alias for AllowDatasheetView"""
        return self.AllowDatasheetView

    @allow_datasheet_view.setter
    def allow_datasheet_view(self, value):
        """Alias for AllowDatasheetView.setter"""
        self.AllowDatasheetView = value

    @property
    def AllowDeletions(self):
        return self.com_object.AllowDeletions

    @AllowDeletions.setter
    def AllowDeletions(self, value):
        self.com_object.AllowDeletions = value

    @property
    def allowdeletions(self):
        """Alias for AllowDeletions"""
        return self.AllowDeletions

    @allowdeletions.setter
    def allowdeletions(self, value):
        """Alias for AllowDeletions.setter"""
        self.AllowDeletions = value

    @property
    def allow_deletions(self):
        """Alias for AllowDeletions"""
        return self.AllowDeletions

    @allow_deletions.setter
    def allow_deletions(self, value):
        """Alias for AllowDeletions.setter"""
        self.AllowDeletions = value

    @property
    def AllowEdits(self):
        return self.com_object.AllowEdits

    @AllowEdits.setter
    def AllowEdits(self, value):
        self.com_object.AllowEdits = value

    @property
    def allowedits(self):
        """Alias for AllowEdits"""
        return self.AllowEdits

    @allowedits.setter
    def allowedits(self, value):
        """Alias for AllowEdits.setter"""
        self.AllowEdits = value

    @property
    def allow_edits(self):
        """Alias for AllowEdits"""
        return self.AllowEdits

    @allow_edits.setter
    def allow_edits(self, value):
        """Alias for AllowEdits.setter"""
        self.AllowEdits = value

    @property
    def AllowFilters(self):
        return self.com_object.AllowFilters

    @AllowFilters.setter
    def AllowFilters(self, value):
        self.com_object.AllowFilters = value

    @property
    def allowfilters(self):
        """Alias for AllowFilters"""
        return self.AllowFilters

    @allowfilters.setter
    def allowfilters(self, value):
        """Alias for AllowFilters.setter"""
        self.AllowFilters = value

    @property
    def allow_filters(self):
        """Alias for AllowFilters"""
        return self.AllowFilters

    @allow_filters.setter
    def allow_filters(self, value):
        """Alias for AllowFilters.setter"""
        self.AllowFilters = value

    @property
    def AllowFormView(self):
        return self.com_object.AllowFormView

    @AllowFormView.setter
    def AllowFormView(self, value):
        self.com_object.AllowFormView = value

    @property
    def allowformview(self):
        """Alias for AllowFormView"""
        return self.AllowFormView

    @allowformview.setter
    def allowformview(self, value):
        """Alias for AllowFormView.setter"""
        self.AllowFormView = value

    @property
    def allow_form_view(self):
        """Alias for AllowFormView"""
        return self.AllowFormView

    @allow_form_view.setter
    def allow_form_view(self, value):
        """Alias for AllowFormView.setter"""
        self.AllowFormView = value

    @property
    def AllowLayoutView(self):
        return self.com_object.AllowLayoutView

    @AllowLayoutView.setter
    def AllowLayoutView(self, value):
        self.com_object.AllowLayoutView = value

    @property
    def allowlayoutview(self):
        """Alias for AllowLayoutView"""
        return self.AllowLayoutView

    @allowlayoutview.setter
    def allowlayoutview(self, value):
        """Alias for AllowLayoutView.setter"""
        self.AllowLayoutView = value

    @property
    def allow_layout_view(self):
        """Alias for AllowLayoutView"""
        return self.AllowLayoutView

    @allow_layout_view.setter
    def allow_layout_view(self, value):
        """Alias for AllowLayoutView.setter"""
        self.AllowLayoutView = value

    @property
    def AllowPivotChartView(self):
        return self.com_object.AllowPivotChartView

    @AllowPivotChartView.setter
    def AllowPivotChartView(self, value):
        self.com_object.AllowPivotChartView = value

    @property
    def allowpivotchartview(self):
        """Alias for AllowPivotChartView"""
        return self.AllowPivotChartView

    @allowpivotchartview.setter
    def allowpivotchartview(self, value):
        """Alias for AllowPivotChartView.setter"""
        self.AllowPivotChartView = value

    @property
    def allow_pivot_chart_view(self):
        """Alias for AllowPivotChartView"""
        return self.AllowPivotChartView

    @allow_pivot_chart_view.setter
    def allow_pivot_chart_view(self, value):
        """Alias for AllowPivotChartView.setter"""
        self.AllowPivotChartView = value

    @property
    def AllowPivotTableView(self):
        return self.com_object.AllowPivotTableView

    @AllowPivotTableView.setter
    def AllowPivotTableView(self, value):
        self.com_object.AllowPivotTableView = value

    @property
    def allowpivottableview(self):
        """Alias for AllowPivotTableView"""
        return self.AllowPivotTableView

    @allowpivottableview.setter
    def allowpivottableview(self, value):
        """Alias for AllowPivotTableView.setter"""
        self.AllowPivotTableView = value

    @property
    def allow_pivot_table_view(self):
        """Alias for AllowPivotTableView"""
        return self.AllowPivotTableView

    @allow_pivot_table_view.setter
    def allow_pivot_table_view(self, value):
        """Alias for AllowPivotTableView.setter"""
        self.AllowPivotTableView = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoCenter(self):
        return self.com_object.AutoCenter

    @AutoCenter.setter
    def AutoCenter(self, value):
        self.com_object.AutoCenter = value

    @property
    def autocenter(self):
        """Alias for AutoCenter"""
        return self.AutoCenter

    @autocenter.setter
    def autocenter(self, value):
        """Alias for AutoCenter.setter"""
        self.AutoCenter = value

    @property
    def auto_center(self):
        """Alias for AutoCenter"""
        return self.AutoCenter

    @auto_center.setter
    def auto_center(self, value):
        """Alias for AutoCenter.setter"""
        self.AutoCenter = value

    @property
    def AutoResize(self):
        return self.com_object.AutoResize

    @AutoResize.setter
    def AutoResize(self, value):
        self.com_object.AutoResize = value

    @property
    def autoresize(self):
        """Alias for AutoResize"""
        return self.AutoResize

    @autoresize.setter
    def autoresize(self, value):
        """Alias for AutoResize.setter"""
        self.AutoResize = value

    @property
    def auto_resize(self):
        """Alias for AutoResize"""
        return self.AutoResize

    @auto_resize.setter
    def auto_resize(self, value):
        """Alias for AutoResize.setter"""
        self.AutoResize = value

    @property
    def BeforeDelConfirm(self):
        return self.com_object.BeforeDelConfirm

    @BeforeDelConfirm.setter
    def BeforeDelConfirm(self, value):
        self.com_object.BeforeDelConfirm = value

    @property
    def beforedelconfirm(self):
        """Alias for BeforeDelConfirm"""
        return self.BeforeDelConfirm

    @beforedelconfirm.setter
    def beforedelconfirm(self, value):
        """Alias for BeforeDelConfirm.setter"""
        self.BeforeDelConfirm = value

    @property
    def before_del_confirm(self):
        """Alias for BeforeDelConfirm"""
        return self.BeforeDelConfirm

    @before_del_confirm.setter
    def before_del_confirm(self, value):
        """Alias for BeforeDelConfirm.setter"""
        self.BeforeDelConfirm = value

    @property
    def BeforeInsert(self):
        return self.com_object.BeforeInsert

    @BeforeInsert.setter
    def BeforeInsert(self, value):
        self.com_object.BeforeInsert = value

    @property
    def beforeinsert(self):
        """Alias for BeforeInsert"""
        return self.BeforeInsert

    @beforeinsert.setter
    def beforeinsert(self, value):
        """Alias for BeforeInsert.setter"""
        self.BeforeInsert = value

    @property
    def before_insert(self):
        """Alias for BeforeInsert"""
        return self.BeforeInsert

    @before_insert.setter
    def before_insert(self, value):
        """Alias for BeforeInsert.setter"""
        self.BeforeInsert = value

    @property
    def BeforeQuery(self):
        return self.com_object.BeforeQuery

    @BeforeQuery.setter
    def BeforeQuery(self, value):
        self.com_object.BeforeQuery = value

    @property
    def beforequery(self):
        """Alias for BeforeQuery"""
        return self.BeforeQuery

    @beforequery.setter
    def beforequery(self, value):
        """Alias for BeforeQuery.setter"""
        self.BeforeQuery = value

    @property
    def before_query(self):
        """Alias for BeforeQuery"""
        return self.BeforeQuery

    @before_query.setter
    def before_query(self, value):
        """Alias for BeforeQuery.setter"""
        self.BeforeQuery = value

    @property
    def BeforeRender(self):
        return self.com_object.BeforeRender

    @BeforeRender.setter
    def BeforeRender(self, value):
        self.com_object.BeforeRender = value

    @property
    def beforerender(self):
        """Alias for BeforeRender"""
        return self.BeforeRender

    @beforerender.setter
    def beforerender(self, value):
        """Alias for BeforeRender.setter"""
        self.BeforeRender = value

    @property
    def before_render(self):
        """Alias for BeforeRender"""
        return self.BeforeRender

    @before_render.setter
    def before_render(self, value):
        """Alias for BeforeRender.setter"""
        self.BeforeRender = value

    @property
    def BeforeScreenTip(self):
        return self.com_object.BeforeScreenTip

    @BeforeScreenTip.setter
    def BeforeScreenTip(self, value):
        self.com_object.BeforeScreenTip = value

    @property
    def beforescreentip(self):
        """Alias for BeforeScreenTip"""
        return self.BeforeScreenTip

    @beforescreentip.setter
    def beforescreentip(self, value):
        """Alias for BeforeScreenTip.setter"""
        self.BeforeScreenTip = value

    @property
    def before_screen_tip(self):
        """Alias for BeforeScreenTip"""
        return self.BeforeScreenTip

    @before_screen_tip.setter
    def before_screen_tip(self, value):
        """Alias for BeforeScreenTip.setter"""
        self.BeforeScreenTip = value

    @property
    def Bookmark(self):
        return self.com_object.Bookmark

    @Bookmark.setter
    def Bookmark(self, value):
        self.com_object.Bookmark = value

    @property
    def bookmark(self):
        """Alias for Bookmark"""
        return self.Bookmark

    @bookmark.setter
    def bookmark(self, value):
        """Alias for Bookmark.setter"""
        self.Bookmark = value

    @property
    def BorderStyle(self):
        return self.com_object.BorderStyle

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    @property
    def ChartSpace(self):
        return self.com_object.ChartSpace

    @property
    def chartspace(self):
        """Alias for ChartSpace"""
        return self.ChartSpace

    @property
    def chart_space(self):
        """Alias for ChartSpace"""
        return self.ChartSpace

    @property
    def CloseButton(self):
        return self.com_object.CloseButton

    @CloseButton.setter
    def CloseButton(self, value):
        self.com_object.CloseButton = value

    @property
    def closebutton(self):
        """Alias for CloseButton"""
        return self.CloseButton

    @closebutton.setter
    def closebutton(self, value):
        """Alias for CloseButton.setter"""
        self.CloseButton = value

    @property
    def close_button(self):
        """Alias for CloseButton"""
        return self.CloseButton

    @close_button.setter
    def close_button(self, value):
        """Alias for CloseButton.setter"""
        self.CloseButton = value

    @property
    def CommandBeforeExecute(self):
        return self.com_object.CommandBeforeExecute

    @CommandBeforeExecute.setter
    def CommandBeforeExecute(self, value):
        self.com_object.CommandBeforeExecute = value

    @property
    def commandbeforeexecute(self):
        """Alias for CommandBeforeExecute"""
        return self.CommandBeforeExecute

    @commandbeforeexecute.setter
    def commandbeforeexecute(self, value):
        """Alias for CommandBeforeExecute.setter"""
        self.CommandBeforeExecute = value

    @property
    def command_before_execute(self):
        """Alias for CommandBeforeExecute"""
        return self.CommandBeforeExecute

    @command_before_execute.setter
    def command_before_execute(self, value):
        """Alias for CommandBeforeExecute.setter"""
        self.CommandBeforeExecute = value

    @property
    def CommandChecked(self):
        return self.com_object.CommandChecked

    @CommandChecked.setter
    def CommandChecked(self, value):
        self.com_object.CommandChecked = value

    @property
    def commandchecked(self):
        """Alias for CommandChecked"""
        return self.CommandChecked

    @commandchecked.setter
    def commandchecked(self, value):
        """Alias for CommandChecked.setter"""
        self.CommandChecked = value

    @property
    def command_checked(self):
        """Alias for CommandChecked"""
        return self.CommandChecked

    @command_checked.setter
    def command_checked(self, value):
        """Alias for CommandChecked.setter"""
        self.CommandChecked = value

    @property
    def CommandEnabled(self):
        return self.com_object.CommandEnabled

    @CommandEnabled.setter
    def CommandEnabled(self, value):
        self.com_object.CommandEnabled = value

    @property
    def commandenabled(self):
        """Alias for CommandEnabled"""
        return self.CommandEnabled

    @commandenabled.setter
    def commandenabled(self, value):
        """Alias for CommandEnabled.setter"""
        self.CommandEnabled = value

    @property
    def command_enabled(self):
        """Alias for CommandEnabled"""
        return self.CommandEnabled

    @command_enabled.setter
    def command_enabled(self, value):
        """Alias for CommandEnabled.setter"""
        self.CommandEnabled = value

    @property
    def CommandExecute(self):
        return self.com_object.CommandExecute

    @CommandExecute.setter
    def CommandExecute(self, value):
        self.com_object.CommandExecute = value

    @property
    def commandexecute(self):
        """Alias for CommandExecute"""
        return self.CommandExecute

    @commandexecute.setter
    def commandexecute(self, value):
        """Alias for CommandExecute.setter"""
        self.CommandExecute = value

    @property
    def command_execute(self):
        """Alias for CommandExecute"""
        return self.CommandExecute

    @command_execute.setter
    def command_execute(self, value):
        """Alias for CommandExecute.setter"""
        self.CommandExecute = value

    @property
    def ControlBox(self):
        return self.com_object.ControlBox

    @ControlBox.setter
    def ControlBox(self, value):
        self.com_object.ControlBox = value

    @property
    def controlbox(self):
        """Alias for ControlBox"""
        return self.ControlBox

    @controlbox.setter
    def controlbox(self, value):
        """Alias for ControlBox.setter"""
        self.ControlBox = value

    @property
    def control_box(self):
        """Alias for ControlBox"""
        return self.ControlBox

    @control_box.setter
    def control_box(self, value):
        """Alias for ControlBox.setter"""
        self.ControlBox = value

    @property
    def Controls(self):
        return Controls(self.com_object.Controls)

    @property
    def controls(self):
        """Alias for Controls"""
        return self.Controls

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def CurrentRecord(self):
        return self.com_object.CurrentRecord

    @CurrentRecord.setter
    def CurrentRecord(self, value):
        self.com_object.CurrentRecord = value

    @property
    def currentrecord(self):
        """Alias for CurrentRecord"""
        return self.CurrentRecord

    @currentrecord.setter
    def currentrecord(self, value):
        """Alias for CurrentRecord.setter"""
        self.CurrentRecord = value

    @property
    def current_record(self):
        """Alias for CurrentRecord"""
        return self.CurrentRecord

    @current_record.setter
    def current_record(self, value):
        """Alias for CurrentRecord.setter"""
        self.CurrentRecord = value

    @property
    def CurrentSectionLeft(self):
        return self.com_object.CurrentSectionLeft

    @CurrentSectionLeft.setter
    def CurrentSectionLeft(self, value):
        self.com_object.CurrentSectionLeft = value

    @property
    def currentsectionleft(self):
        """Alias for CurrentSectionLeft"""
        return self.CurrentSectionLeft

    @currentsectionleft.setter
    def currentsectionleft(self, value):
        """Alias for CurrentSectionLeft.setter"""
        self.CurrentSectionLeft = value

    @property
    def current_section_left(self):
        """Alias for CurrentSectionLeft"""
        return self.CurrentSectionLeft

    @current_section_left.setter
    def current_section_left(self, value):
        """Alias for CurrentSectionLeft.setter"""
        self.CurrentSectionLeft = value

    @property
    def CurrentSectionTop(self):
        return self.com_object.CurrentSectionTop

    @CurrentSectionTop.setter
    def CurrentSectionTop(self, value):
        self.com_object.CurrentSectionTop = value

    @property
    def currentsectiontop(self):
        """Alias for CurrentSectionTop"""
        return self.CurrentSectionTop

    @currentsectiontop.setter
    def currentsectiontop(self, value):
        """Alias for CurrentSectionTop.setter"""
        self.CurrentSectionTop = value

    @property
    def current_section_top(self):
        """Alias for CurrentSectionTop"""
        return self.CurrentSectionTop

    @current_section_top.setter
    def current_section_top(self, value):
        """Alias for CurrentSectionTop.setter"""
        self.CurrentSectionTop = value

    @property
    def CurrentView(self):
        return self.com_object.CurrentView

    @CurrentView.setter
    def CurrentView(self, value):
        self.com_object.CurrentView = value

    @property
    def currentview(self):
        """Alias for CurrentView"""
        return self.CurrentView

    @currentview.setter
    def currentview(self, value):
        """Alias for CurrentView.setter"""
        self.CurrentView = value

    @property
    def current_view(self):
        """Alias for CurrentView"""
        return self.CurrentView

    @current_view.setter
    def current_view(self, value):
        """Alias for CurrentView.setter"""
        self.CurrentView = value

    @property
    def Cycle(self):
        return self.com_object.Cycle

    @Cycle.setter
    def Cycle(self, value):
        self.com_object.Cycle = value

    @property
    def cycle(self):
        """Alias for Cycle"""
        return self.Cycle

    @cycle.setter
    def cycle(self, value):
        """Alias for Cycle.setter"""
        self.Cycle = value

    @property
    def DataChange(self):
        return self.com_object.DataChange

    @DataChange.setter
    def DataChange(self, value):
        self.com_object.DataChange = value

    @property
    def datachange(self):
        """Alias for DataChange"""
        return self.DataChange

    @datachange.setter
    def datachange(self, value):
        """Alias for DataChange.setter"""
        self.DataChange = value

    @property
    def data_change(self):
        """Alias for DataChange"""
        return self.DataChange

    @data_change.setter
    def data_change(self, value):
        """Alias for DataChange.setter"""
        self.DataChange = value

    @property
    def DataEntry(self):
        return self.com_object.DataEntry

    @DataEntry.setter
    def DataEntry(self, value):
        self.com_object.DataEntry = value

    @property
    def dataentry(self):
        """Alias for DataEntry"""
        return self.DataEntry

    @dataentry.setter
    def dataentry(self, value):
        """Alias for DataEntry.setter"""
        self.DataEntry = value

    @property
    def data_entry(self):
        """Alias for DataEntry"""
        return self.DataEntry

    @data_entry.setter
    def data_entry(self, value):
        """Alias for DataEntry.setter"""
        self.DataEntry = value

    @property
    def DataSetChange(self):
        return self.com_object.DataSetChange

    @DataSetChange.setter
    def DataSetChange(self, value):
        self.com_object.DataSetChange = value

    @property
    def datasetchange(self):
        """Alias for DataSetChange"""
        return self.DataSetChange

    @datasetchange.setter
    def datasetchange(self, value):
        """Alias for DataSetChange.setter"""
        self.DataSetChange = value

    @property
    def data_set_change(self):
        """Alias for DataSetChange"""
        return self.DataSetChange

    @data_set_change.setter
    def data_set_change(self, value):
        """Alias for DataSetChange.setter"""
        self.DataSetChange = value

    @property
    def DatasheetAlternateBackColor(self):
        return self.com_object.DatasheetAlternateBackColor

    @DatasheetAlternateBackColor.setter
    def DatasheetAlternateBackColor(self, value):
        self.com_object.DatasheetAlternateBackColor = value

    @property
    def datasheetalternatebackcolor(self):
        """Alias for DatasheetAlternateBackColor"""
        return self.DatasheetAlternateBackColor

    @datasheetalternatebackcolor.setter
    def datasheetalternatebackcolor(self, value):
        """Alias for DatasheetAlternateBackColor.setter"""
        self.DatasheetAlternateBackColor = value

    @property
    def datasheet_alternate_back_color(self):
        """Alias for DatasheetAlternateBackColor"""
        return self.DatasheetAlternateBackColor

    @datasheet_alternate_back_color.setter
    def datasheet_alternate_back_color(self, value):
        """Alias for DatasheetAlternateBackColor.setter"""
        self.DatasheetAlternateBackColor = value

    @property
    def DatasheetBackColor(self):
        return self.com_object.DatasheetBackColor

    @DatasheetBackColor.setter
    def DatasheetBackColor(self, value):
        self.com_object.DatasheetBackColor = value

    @property
    def datasheetbackcolor(self):
        """Alias for DatasheetBackColor"""
        return self.DatasheetBackColor

    @datasheetbackcolor.setter
    def datasheetbackcolor(self, value):
        """Alias for DatasheetBackColor.setter"""
        self.DatasheetBackColor = value

    @property
    def datasheet_back_color(self):
        """Alias for DatasheetBackColor"""
        return self.DatasheetBackColor

    @datasheet_back_color.setter
    def datasheet_back_color(self, value):
        """Alias for DatasheetBackColor.setter"""
        self.DatasheetBackColor = value

    @property
    def DatasheetBorderLineStyle(self):
        return self.com_object.DatasheetBorderLineStyle

    @DatasheetBorderLineStyle.setter
    def DatasheetBorderLineStyle(self, value):
        self.com_object.DatasheetBorderLineStyle = value

    @property
    def datasheetborderlinestyle(self):
        """Alias for DatasheetBorderLineStyle"""
        return self.DatasheetBorderLineStyle

    @datasheetborderlinestyle.setter
    def datasheetborderlinestyle(self, value):
        """Alias for DatasheetBorderLineStyle.setter"""
        self.DatasheetBorderLineStyle = value

    @property
    def datasheet_border_line_style(self):
        """Alias for DatasheetBorderLineStyle"""
        return self.DatasheetBorderLineStyle

    @datasheet_border_line_style.setter
    def datasheet_border_line_style(self, value):
        """Alias for DatasheetBorderLineStyle.setter"""
        self.DatasheetBorderLineStyle = value

    @property
    def DatasheetCellsEffect(self):
        return self.com_object.DatasheetCellsEffect

    @DatasheetCellsEffect.setter
    def DatasheetCellsEffect(self, value):
        self.com_object.DatasheetCellsEffect = value

    @property
    def datasheetcellseffect(self):
        """Alias for DatasheetCellsEffect"""
        return self.DatasheetCellsEffect

    @datasheetcellseffect.setter
    def datasheetcellseffect(self, value):
        """Alias for DatasheetCellsEffect.setter"""
        self.DatasheetCellsEffect = value

    @property
    def datasheet_cells_effect(self):
        """Alias for DatasheetCellsEffect"""
        return self.DatasheetCellsEffect

    @datasheet_cells_effect.setter
    def datasheet_cells_effect(self, value):
        """Alias for DatasheetCellsEffect.setter"""
        self.DatasheetCellsEffect = value

    @property
    def DatasheetColumnHeaderUnderlineStyle(self):
        return self.com_object.DatasheetColumnHeaderUnderlineStyle

    @DatasheetColumnHeaderUnderlineStyle.setter
    def DatasheetColumnHeaderUnderlineStyle(self, value):
        self.com_object.DatasheetColumnHeaderUnderlineStyle = value

    @property
    def datasheetcolumnheaderunderlinestyle(self):
        """Alias for DatasheetColumnHeaderUnderlineStyle"""
        return self.DatasheetColumnHeaderUnderlineStyle

    @datasheetcolumnheaderunderlinestyle.setter
    def datasheetcolumnheaderunderlinestyle(self, value):
        """Alias for DatasheetColumnHeaderUnderlineStyle.setter"""
        self.DatasheetColumnHeaderUnderlineStyle = value

    @property
    def datasheet_column_header_underline_style(self):
        """Alias for DatasheetColumnHeaderUnderlineStyle"""
        return self.DatasheetColumnHeaderUnderlineStyle

    @datasheet_column_header_underline_style.setter
    def datasheet_column_header_underline_style(self, value):
        """Alias for DatasheetColumnHeaderUnderlineStyle.setter"""
        self.DatasheetColumnHeaderUnderlineStyle = value

    @property
    def DatasheetFontHeight(self):
        return self.com_object.DatasheetFontHeight

    @DatasheetFontHeight.setter
    def DatasheetFontHeight(self, value):
        self.com_object.DatasheetFontHeight = value

    @property
    def datasheetfontheight(self):
        """Alias for DatasheetFontHeight"""
        return self.DatasheetFontHeight

    @datasheetfontheight.setter
    def datasheetfontheight(self, value):
        """Alias for DatasheetFontHeight.setter"""
        self.DatasheetFontHeight = value

    @property
    def datasheet_font_height(self):
        """Alias for DatasheetFontHeight"""
        return self.DatasheetFontHeight

    @datasheet_font_height.setter
    def datasheet_font_height(self, value):
        """Alias for DatasheetFontHeight.setter"""
        self.DatasheetFontHeight = value

    @property
    def DatasheetFontItalic(self):
        return self.com_object.DatasheetFontItalic

    @DatasheetFontItalic.setter
    def DatasheetFontItalic(self, value):
        self.com_object.DatasheetFontItalic = value

    @property
    def datasheetfontitalic(self):
        """Alias for DatasheetFontItalic"""
        return self.DatasheetFontItalic

    @datasheetfontitalic.setter
    def datasheetfontitalic(self, value):
        """Alias for DatasheetFontItalic.setter"""
        self.DatasheetFontItalic = value

    @property
    def datasheet_font_italic(self):
        """Alias for DatasheetFontItalic"""
        return self.DatasheetFontItalic

    @datasheet_font_italic.setter
    def datasheet_font_italic(self, value):
        """Alias for DatasheetFontItalic.setter"""
        self.DatasheetFontItalic = value

    @property
    def DatasheetFontName(self):
        return self.com_object.DatasheetFontName

    @DatasheetFontName.setter
    def DatasheetFontName(self, value):
        self.com_object.DatasheetFontName = value

    @property
    def datasheetfontname(self):
        """Alias for DatasheetFontName"""
        return self.DatasheetFontName

    @datasheetfontname.setter
    def datasheetfontname(self, value):
        """Alias for DatasheetFontName.setter"""
        self.DatasheetFontName = value

    @property
    def datasheet_font_name(self):
        """Alias for DatasheetFontName"""
        return self.DatasheetFontName

    @datasheet_font_name.setter
    def datasheet_font_name(self, value):
        """Alias for DatasheetFontName.setter"""
        self.DatasheetFontName = value

    @property
    def DatasheetFontUnderline(self):
        return self.com_object.DatasheetFontUnderline

    @DatasheetFontUnderline.setter
    def DatasheetFontUnderline(self, value):
        self.com_object.DatasheetFontUnderline = value

    @property
    def datasheetfontunderline(self):
        """Alias for DatasheetFontUnderline"""
        return self.DatasheetFontUnderline

    @datasheetfontunderline.setter
    def datasheetfontunderline(self, value):
        """Alias for DatasheetFontUnderline.setter"""
        self.DatasheetFontUnderline = value

    @property
    def datasheet_font_underline(self):
        """Alias for DatasheetFontUnderline"""
        return self.DatasheetFontUnderline

    @datasheet_font_underline.setter
    def datasheet_font_underline(self, value):
        """Alias for DatasheetFontUnderline.setter"""
        self.DatasheetFontUnderline = value

    @property
    def DatasheetFontWeight(self):
        return self.com_object.DatasheetFontWeight

    @DatasheetFontWeight.setter
    def DatasheetFontWeight(self, value):
        self.com_object.DatasheetFontWeight = value

    @property
    def datasheetfontweight(self):
        """Alias for DatasheetFontWeight"""
        return self.DatasheetFontWeight

    @datasheetfontweight.setter
    def datasheetfontweight(self, value):
        """Alias for DatasheetFontWeight.setter"""
        self.DatasheetFontWeight = value

    @property
    def datasheet_font_weight(self):
        """Alias for DatasheetFontWeight"""
        return self.DatasheetFontWeight

    @datasheet_font_weight.setter
    def datasheet_font_weight(self, value):
        """Alias for DatasheetFontWeight.setter"""
        self.DatasheetFontWeight = value

    @property
    def DatasheetForeColor(self):
        return self.com_object.DatasheetForeColor

    @DatasheetForeColor.setter
    def DatasheetForeColor(self, value):
        self.com_object.DatasheetForeColor = value

    @property
    def datasheetforecolor(self):
        """Alias for DatasheetForeColor"""
        return self.DatasheetForeColor

    @datasheetforecolor.setter
    def datasheetforecolor(self, value):
        """Alias for DatasheetForeColor.setter"""
        self.DatasheetForeColor = value

    @property
    def datasheet_fore_color(self):
        """Alias for DatasheetForeColor"""
        return self.DatasheetForeColor

    @datasheet_fore_color.setter
    def datasheet_fore_color(self, value):
        """Alias for DatasheetForeColor.setter"""
        self.DatasheetForeColor = value

    @property
    def DatasheetGridlinesBehavior(self):
        return self.com_object.DatasheetGridlinesBehavior

    @DatasheetGridlinesBehavior.setter
    def DatasheetGridlinesBehavior(self, value):
        self.com_object.DatasheetGridlinesBehavior = value

    @property
    def datasheetgridlinesbehavior(self):
        """Alias for DatasheetGridlinesBehavior"""
        return self.DatasheetGridlinesBehavior

    @datasheetgridlinesbehavior.setter
    def datasheetgridlinesbehavior(self, value):
        """Alias for DatasheetGridlinesBehavior.setter"""
        self.DatasheetGridlinesBehavior = value

    @property
    def datasheet_gridlines_behavior(self):
        """Alias for DatasheetGridlinesBehavior"""
        return self.DatasheetGridlinesBehavior

    @datasheet_gridlines_behavior.setter
    def datasheet_gridlines_behavior(self, value):
        """Alias for DatasheetGridlinesBehavior.setter"""
        self.DatasheetGridlinesBehavior = value

    @property
    def DatasheetGridlinesColor(self):
        return self.com_object.DatasheetGridlinesColor

    @DatasheetGridlinesColor.setter
    def DatasheetGridlinesColor(self, value):
        self.com_object.DatasheetGridlinesColor = value

    @property
    def datasheetgridlinescolor(self):
        """Alias for DatasheetGridlinesColor"""
        return self.DatasheetGridlinesColor

    @datasheetgridlinescolor.setter
    def datasheetgridlinescolor(self, value):
        """Alias for DatasheetGridlinesColor.setter"""
        self.DatasheetGridlinesColor = value

    @property
    def datasheet_gridlines_color(self):
        """Alias for DatasheetGridlinesColor"""
        return self.DatasheetGridlinesColor

    @datasheet_gridlines_color.setter
    def datasheet_gridlines_color(self, value):
        """Alias for DatasheetGridlinesColor.setter"""
        self.DatasheetGridlinesColor = value

    def DefaultControl(self, ControlType=None):
        arguments = com_arguments([unwrap(a) for a in [ControlType]])
        if hasattr(self.com_object, "GetDefaultControl"):
            return self.com_object.GetDefaultControl(*arguments)
        else:
            return self.com_object.DefaultControl(*arguments)

    def defaultcontrol(self, ControlType=None):
        """Alias for DefaultControl"""
        arguments = [ControlType]
        return self.DefaultControl(*arguments)

    def default_control(self, ControlType=None):
        """Alias for DefaultControl"""
        arguments = [ControlType]
        return self.DefaultControl(*arguments)

    @property
    def DefaultView(self):
        return self.com_object.DefaultView

    @DefaultView.setter
    def DefaultView(self, value):
        self.com_object.DefaultView = value

    @property
    def defaultview(self):
        """Alias for DefaultView"""
        return self.DefaultView

    @defaultview.setter
    def defaultview(self, value):
        """Alias for DefaultView.setter"""
        self.DefaultView = value

    @property
    def default_view(self):
        """Alias for DefaultView"""
        return self.DefaultView

    @default_view.setter
    def default_view(self, value):
        """Alias for DefaultView.setter"""
        self.DefaultView = value

    @property
    def Dirty(self):
        return self.com_object.Dirty

    @Dirty.setter
    def Dirty(self, value):
        self.com_object.Dirty = value

    @property
    def dirty(self):
        """Alias for Dirty"""
        return self.Dirty

    @dirty.setter
    def dirty(self, value):
        """Alias for Dirty.setter"""
        self.Dirty = value

    @property
    def DisplayOnSharePointSite(self):
        return self.com_object.DisplayOnSharePointSite

    @DisplayOnSharePointSite.setter
    def DisplayOnSharePointSite(self, value):
        self.com_object.DisplayOnSharePointSite = value

    @property
    def displayonsharepointsite(self):
        """Alias for DisplayOnSharePointSite"""
        return self.DisplayOnSharePointSite

    @displayonsharepointsite.setter
    def displayonsharepointsite(self, value):
        """Alias for DisplayOnSharePointSite.setter"""
        self.DisplayOnSharePointSite = value

    @property
    def display_on_share_point_site(self):
        """Alias for DisplayOnSharePointSite"""
        return self.DisplayOnSharePointSite

    @display_on_share_point_site.setter
    def display_on_share_point_site(self, value):
        """Alias for DisplayOnSharePointSite.setter"""
        self.DisplayOnSharePointSite = value

    @property
    def DividingLines(self):
        return self.com_object.DividingLines

    @DividingLines.setter
    def DividingLines(self, value):
        self.com_object.DividingLines = value

    @property
    def dividinglines(self):
        """Alias for DividingLines"""
        return self.DividingLines

    @dividinglines.setter
    def dividinglines(self, value):
        """Alias for DividingLines.setter"""
        self.DividingLines = value

    @property
    def dividing_lines(self):
        """Alias for DividingLines"""
        return self.DividingLines

    @dividing_lines.setter
    def dividing_lines(self, value):
        """Alias for DividingLines.setter"""
        self.DividingLines = value

    @property
    def FastLaserPrinting(self):
        return self.com_object.FastLaserPrinting

    @FastLaserPrinting.setter
    def FastLaserPrinting(self, value):
        self.com_object.FastLaserPrinting = value

    @property
    def fastlaserprinting(self):
        """Alias for FastLaserPrinting"""
        return self.FastLaserPrinting

    @fastlaserprinting.setter
    def fastlaserprinting(self, value):
        """Alias for FastLaserPrinting.setter"""
        self.FastLaserPrinting = value

    @property
    def fast_laser_printing(self):
        """Alias for FastLaserPrinting"""
        return self.FastLaserPrinting

    @fast_laser_printing.setter
    def fast_laser_printing(self, value):
        """Alias for FastLaserPrinting.setter"""
        self.FastLaserPrinting = value

    @property
    def FetchDefaults(self):
        return self.com_object.FetchDefaults

    @FetchDefaults.setter
    def FetchDefaults(self, value):
        self.com_object.FetchDefaults = value

    @property
    def fetchdefaults(self):
        """Alias for FetchDefaults"""
        return self.FetchDefaults

    @fetchdefaults.setter
    def fetchdefaults(self, value):
        """Alias for FetchDefaults.setter"""
        self.FetchDefaults = value

    @property
    def fetch_defaults(self):
        """Alias for FetchDefaults"""
        return self.FetchDefaults

    @fetch_defaults.setter
    def fetch_defaults(self, value):
        """Alias for FetchDefaults.setter"""
        self.FetchDefaults = value

    @property
    def Filter(self):
        return self.com_object.Filter

    @Filter.setter
    def Filter(self, value):
        self.com_object.Filter = value

    @property
    def filter(self):
        """Alias for Filter"""
        return self.Filter

    @filter.setter
    def filter(self, value):
        """Alias for Filter.setter"""
        self.Filter = value

    @property
    def FilterOn(self):
        return self.com_object.FilterOn

    @FilterOn.setter
    def FilterOn(self, value):
        self.com_object.FilterOn = value

    @property
    def filteron(self):
        """Alias for FilterOn"""
        return self.FilterOn

    @filteron.setter
    def filteron(self, value):
        """Alias for FilterOn.setter"""
        self.FilterOn = value

    @property
    def filter_on(self):
        """Alias for FilterOn"""
        return self.FilterOn

    @filter_on.setter
    def filter_on(self, value):
        """Alias for FilterOn.setter"""
        self.FilterOn = value

    @property
    def FilterOnLoad(self):
        return self.com_object.FilterOnLoad

    @FilterOnLoad.setter
    def FilterOnLoad(self, value):
        self.com_object.FilterOnLoad = value

    @property
    def filteronload(self):
        """Alias for FilterOnLoad"""
        return self.FilterOnLoad

    @filteronload.setter
    def filteronload(self, value):
        """Alias for FilterOnLoad.setter"""
        self.FilterOnLoad = value

    @property
    def filter_on_load(self):
        """Alias for FilterOnLoad"""
        return self.FilterOnLoad

    @filter_on_load.setter
    def filter_on_load(self, value):
        """Alias for FilterOnLoad.setter"""
        self.FilterOnLoad = value

    @property
    def FitToScreen(self):
        return self.com_object.FitToScreen

    @FitToScreen.setter
    def FitToScreen(self, value):
        self.com_object.FitToScreen = value

    @property
    def fittoscreen(self):
        """Alias for FitToScreen"""
        return self.FitToScreen

    @fittoscreen.setter
    def fittoscreen(self, value):
        """Alias for FitToScreen.setter"""
        self.FitToScreen = value

    @property
    def fit_to_screen(self):
        """Alias for FitToScreen"""
        return self.FitToScreen

    @fit_to_screen.setter
    def fit_to_screen(self, value):
        """Alias for FitToScreen.setter"""
        self.FitToScreen = value

    @property
    def Form(self):
        return self.com_object.Form

    @property
    def form(self):
        """Alias for Form"""
        return self.Form

    @property
    def FrozenColumns(self):
        return self.com_object.FrozenColumns

    @FrozenColumns.setter
    def FrozenColumns(self, value):
        self.com_object.FrozenColumns = value

    @property
    def frozencolumns(self):
        """Alias for FrozenColumns"""
        return self.FrozenColumns

    @frozencolumns.setter
    def frozencolumns(self, value):
        """Alias for FrozenColumns.setter"""
        self.FrozenColumns = value

    @property
    def frozen_columns(self):
        """Alias for FrozenColumns"""
        return self.FrozenColumns

    @frozen_columns.setter
    def frozen_columns(self, value):
        """Alias for FrozenColumns.setter"""
        self.FrozenColumns = value

    @property
    def GridX(self):
        return self.com_object.GridX

    @GridX.setter
    def GridX(self, value):
        self.com_object.GridX = value

    @property
    def gridx(self):
        """Alias for GridX"""
        return self.GridX

    @gridx.setter
    def gridx(self, value):
        """Alias for GridX.setter"""
        self.GridX = value

    @property
    def grid_x(self):
        """Alias for GridX"""
        return self.GridX

    @grid_x.setter
    def grid_x(self, value):
        """Alias for GridX.setter"""
        self.GridX = value

    @property
    def GridY(self):
        return self.com_object.GridY

    @GridY.setter
    def GridY(self, value):
        self.com_object.GridY = value

    @property
    def gridy(self):
        """Alias for GridY"""
        return self.GridY

    @gridy.setter
    def gridy(self, value):
        """Alias for GridY.setter"""
        self.GridY = value

    @property
    def grid_y(self):
        """Alias for GridY"""
        return self.GridY

    @grid_y.setter
    def grid_y(self, value):
        """Alias for GridY.setter"""
        self.GridY = value

    @property
    def HasModule(self):
        return self.com_object.HasModule

    @HasModule.setter
    def HasModule(self, value):
        self.com_object.HasModule = value

    @property
    def hasmodule(self):
        """Alias for HasModule"""
        return self.HasModule

    @hasmodule.setter
    def hasmodule(self, value):
        """Alias for HasModule.setter"""
        self.HasModule = value

    @property
    def has_module(self):
        """Alias for HasModule"""
        return self.HasModule

    @has_module.setter
    def has_module(self, value):
        """Alias for HasModule.setter"""
        self.HasModule = value

    @property
    def HelpContextId(self):
        return self.com_object.HelpContextId

    @HelpContextId.setter
    def HelpContextId(self, value):
        self.com_object.HelpContextId = value

    @property
    def helpcontextid(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @helpcontextid.setter
    def helpcontextid(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def help_context_id(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @help_context_id.setter
    def help_context_id(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def HelpFile(self):
        return self.com_object.HelpFile

    @HelpFile.setter
    def HelpFile(self, value):
        self.com_object.HelpFile = value

    @property
    def helpfile(self):
        """Alias for HelpFile"""
        return self.HelpFile

    @helpfile.setter
    def helpfile(self, value):
        """Alias for HelpFile.setter"""
        self.HelpFile = value

    @property
    def help_file(self):
        """Alias for HelpFile"""
        return self.HelpFile

    @help_file.setter
    def help_file(self, value):
        """Alias for HelpFile.setter"""
        self.HelpFile = value

    @property
    def HorizontalDatasheetGridlineStyle(self):
        return self.com_object.HorizontalDatasheetGridlineStyle

    @HorizontalDatasheetGridlineStyle.setter
    def HorizontalDatasheetGridlineStyle(self, value):
        self.com_object.HorizontalDatasheetGridlineStyle = value

    @property
    def horizontaldatasheetgridlinestyle(self):
        """Alias for HorizontalDatasheetGridlineStyle"""
        return self.HorizontalDatasheetGridlineStyle

    @horizontaldatasheetgridlinestyle.setter
    def horizontaldatasheetgridlinestyle(self, value):
        """Alias for HorizontalDatasheetGridlineStyle.setter"""
        self.HorizontalDatasheetGridlineStyle = value

    @property
    def horizontal_datasheet_gridline_style(self):
        """Alias for HorizontalDatasheetGridlineStyle"""
        return self.HorizontalDatasheetGridlineStyle

    @horizontal_datasheet_gridline_style.setter
    def horizontal_datasheet_gridline_style(self, value):
        """Alias for HorizontalDatasheetGridlineStyle.setter"""
        self.HorizontalDatasheetGridlineStyle = value

    @property
    def hWnd(self):
        return self.com_object.hWnd

    @hWnd.setter
    def hWnd(self, value):
        self.com_object.hWnd = value

    @property
    def hwnd(self):
        """Alias for hWnd"""
        return self.hWnd

    @hwnd.setter
    def hwnd(self, value):
        """Alias for hWnd.setter"""
        self.hWnd = value

    @property
    def h_wnd(self):
        """Alias for hWnd"""
        return self.hWnd

    @h_wnd.setter
    def h_wnd(self, value):
        """Alias for hWnd.setter"""
        self.hWnd = value

    @property
    def InsideHeight(self):
        return self.com_object.InsideHeight

    @InsideHeight.setter
    def InsideHeight(self, value):
        self.com_object.InsideHeight = value

    @property
    def insideheight(self):
        """Alias for InsideHeight"""
        return self.InsideHeight

    @insideheight.setter
    def insideheight(self, value):
        """Alias for InsideHeight.setter"""
        self.InsideHeight = value

    @property
    def inside_height(self):
        """Alias for InsideHeight"""
        return self.InsideHeight

    @inside_height.setter
    def inside_height(self, value):
        """Alias for InsideHeight.setter"""
        self.InsideHeight = value

    @property
    def InsideWidth(self):
        return self.com_object.InsideWidth

    @InsideWidth.setter
    def InsideWidth(self, value):
        self.com_object.InsideWidth = value

    @property
    def insidewidth(self):
        """Alias for InsideWidth"""
        return self.InsideWidth

    @insidewidth.setter
    def insidewidth(self, value):
        """Alias for InsideWidth.setter"""
        self.InsideWidth = value

    @property
    def inside_width(self):
        """Alias for InsideWidth"""
        return self.InsideWidth

    @inside_width.setter
    def inside_width(self, value):
        """Alias for InsideWidth.setter"""
        self.InsideWidth = value

    @property
    def KeyPreview(self):
        return self.com_object.KeyPreview

    @KeyPreview.setter
    def KeyPreview(self, value):
        self.com_object.KeyPreview = value

    @property
    def keypreview(self):
        """Alias for KeyPreview"""
        return self.KeyPreview

    @keypreview.setter
    def keypreview(self, value):
        """Alias for KeyPreview.setter"""
        self.KeyPreview = value

    @property
    def key_preview(self):
        """Alias for KeyPreview"""
        return self.KeyPreview

    @key_preview.setter
    def key_preview(self, value):
        """Alias for KeyPreview.setter"""
        self.KeyPreview = value

    @property
    def LayoutForPrint(self):
        return self.com_object.LayoutForPrint

    @LayoutForPrint.setter
    def LayoutForPrint(self, value):
        self.com_object.LayoutForPrint = value

    @property
    def layoutforprint(self):
        """Alias for LayoutForPrint"""
        return self.LayoutForPrint

    @layoutforprint.setter
    def layoutforprint(self, value):
        """Alias for LayoutForPrint.setter"""
        self.LayoutForPrint = value

    @property
    def layout_for_print(self):
        """Alias for LayoutForPrint"""
        return self.LayoutForPrint

    @layout_for_print.setter
    def layout_for_print(self, value):
        """Alias for LayoutForPrint.setter"""
        self.LayoutForPrint = value

    @property
    def MaxRecButton(self):
        return self.com_object.MaxRecButton

    @MaxRecButton.setter
    def MaxRecButton(self, value):
        self.com_object.MaxRecButton = value

    @property
    def maxrecbutton(self):
        """Alias for MaxRecButton"""
        return self.MaxRecButton

    @maxrecbutton.setter
    def maxrecbutton(self, value):
        """Alias for MaxRecButton.setter"""
        self.MaxRecButton = value

    @property
    def max_rec_button(self):
        """Alias for MaxRecButton"""
        return self.MaxRecButton

    @max_rec_button.setter
    def max_rec_button(self, value):
        """Alias for MaxRecButton.setter"""
        self.MaxRecButton = value

    @property
    def MaxRecords(self):
        return self.com_object.MaxRecords

    @MaxRecords.setter
    def MaxRecords(self, value):
        self.com_object.MaxRecords = value

    @property
    def maxrecords(self):
        """Alias for MaxRecords"""
        return self.MaxRecords

    @maxrecords.setter
    def maxrecords(self, value):
        """Alias for MaxRecords.setter"""
        self.MaxRecords = value

    @property
    def max_records(self):
        """Alias for MaxRecords"""
        return self.MaxRecords

    @max_records.setter
    def max_records(self, value):
        """Alias for MaxRecords.setter"""
        self.MaxRecords = value

    @property
    def MenuBar(self):
        return self.com_object.MenuBar

    @MenuBar.setter
    def MenuBar(self, value):
        self.com_object.MenuBar = value

    @property
    def menubar(self):
        """Alias for MenuBar"""
        return self.MenuBar

    @menubar.setter
    def menubar(self, value):
        """Alias for MenuBar.setter"""
        self.MenuBar = value

    @property
    def menu_bar(self):
        """Alias for MenuBar"""
        return self.MenuBar

    @menu_bar.setter
    def menu_bar(self, value):
        """Alias for MenuBar.setter"""
        self.MenuBar = value

    @property
    def MinMaxButtons(self):
        return self.com_object.MinMaxButtons

    @MinMaxButtons.setter
    def MinMaxButtons(self, value):
        self.com_object.MinMaxButtons = value

    @property
    def minmaxbuttons(self):
        """Alias for MinMaxButtons"""
        return self.MinMaxButtons

    @minmaxbuttons.setter
    def minmaxbuttons(self, value):
        """Alias for MinMaxButtons.setter"""
        self.MinMaxButtons = value

    @property
    def min_max_buttons(self):
        """Alias for MinMaxButtons"""
        return self.MinMaxButtons

    @min_max_buttons.setter
    def min_max_buttons(self, value):
        """Alias for MinMaxButtons.setter"""
        self.MinMaxButtons = value

    @property
    def Modal(self):
        return self.com_object.Modal

    @Modal.setter
    def Modal(self, value):
        self.com_object.Modal = value

    @property
    def modal(self):
        """Alias for Modal"""
        return self.Modal

    @modal.setter
    def modal(self, value):
        """Alias for Modal.setter"""
        self.Modal = value

    @property
    def Module(self):
        return self.com_object.Module

    @property
    def module(self):
        """Alias for Module"""
        return self.Module

    @property
    def MouseWheel(self):
        return self.com_object.MouseWheel

    @MouseWheel.setter
    def MouseWheel(self, value):
        self.com_object.MouseWheel = value

    @property
    def mousewheel(self):
        """Alias for MouseWheel"""
        return self.MouseWheel

    @mousewheel.setter
    def mousewheel(self, value):
        """Alias for MouseWheel.setter"""
        self.MouseWheel = value

    @property
    def mouse_wheel(self):
        """Alias for MouseWheel"""
        return self.MouseWheel

    @mouse_wheel.setter
    def mouse_wheel(self, value):
        """Alias for MouseWheel.setter"""
        self.MouseWheel = value

    @property
    def Moveable(self):
        return self.com_object.Moveable

    @Moveable.setter
    def Moveable(self, value):
        self.com_object.Moveable = value

    @property
    def moveable(self):
        """Alias for Moveable"""
        return self.Moveable

    @moveable.setter
    def moveable(self, value):
        """Alias for Moveable.setter"""
        self.Moveable = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def NavigationButtons(self):
        return self.com_object.NavigationButtons

    @NavigationButtons.setter
    def NavigationButtons(self, value):
        self.com_object.NavigationButtons = value

    @property
    def navigationbuttons(self):
        """Alias for NavigationButtons"""
        return self.NavigationButtons

    @navigationbuttons.setter
    def navigationbuttons(self, value):
        """Alias for NavigationButtons.setter"""
        self.NavigationButtons = value

    @property
    def navigation_buttons(self):
        """Alias for NavigationButtons"""
        return self.NavigationButtons

    @navigation_buttons.setter
    def navigation_buttons(self, value):
        """Alias for NavigationButtons.setter"""
        self.NavigationButtons = value

    @property
    def NavigationCaption(self):
        return self.com_object.NavigationCaption

    @NavigationCaption.setter
    def NavigationCaption(self, value):
        self.com_object.NavigationCaption = value

    @property
    def navigationcaption(self):
        """Alias for NavigationCaption"""
        return self.NavigationCaption

    @navigationcaption.setter
    def navigationcaption(self, value):
        """Alias for NavigationCaption.setter"""
        self.NavigationCaption = value

    @property
    def navigation_caption(self):
        """Alias for NavigationCaption"""
        return self.NavigationCaption

    @navigation_caption.setter
    def navigation_caption(self, value):
        """Alias for NavigationCaption.setter"""
        self.NavigationCaption = value

    @property
    def NewRecord(self):
        return self.com_object.NewRecord

    @property
    def newrecord(self):
        """Alias for NewRecord"""
        return self.NewRecord

    @property
    def new_record(self):
        """Alias for NewRecord"""
        return self.NewRecord

    @property
    def OnActivate(self):
        return self.com_object.OnActivate

    @OnActivate.setter
    def OnActivate(self, value):
        self.com_object.OnActivate = value

    @property
    def onactivate(self):
        """Alias for OnActivate"""
        return self.OnActivate

    @onactivate.setter
    def onactivate(self, value):
        """Alias for OnActivate.setter"""
        self.OnActivate = value

    @property
    def on_activate(self):
        """Alias for OnActivate"""
        return self.OnActivate

    @on_activate.setter
    def on_activate(self, value):
        """Alias for OnActivate.setter"""
        self.OnActivate = value

    @property
    def OnApplyFilter(self):
        return self.com_object.OnApplyFilter

    @OnApplyFilter.setter
    def OnApplyFilter(self, value):
        self.com_object.OnApplyFilter = value

    @property
    def onapplyfilter(self):
        """Alias for OnApplyFilter"""
        return self.OnApplyFilter

    @onapplyfilter.setter
    def onapplyfilter(self, value):
        """Alias for OnApplyFilter.setter"""
        self.OnApplyFilter = value

    @property
    def on_apply_filter(self):
        """Alias for OnApplyFilter"""
        return self.OnApplyFilter

    @on_apply_filter.setter
    def on_apply_filter(self, value):
        """Alias for OnApplyFilter.setter"""
        self.OnApplyFilter = value

    @property
    def OnClick(self):
        return self.com_object.OnClick

    @OnClick.setter
    def OnClick(self, value):
        self.com_object.OnClick = value

    @property
    def onclick(self):
        """Alias for OnClick"""
        return self.OnClick

    @onclick.setter
    def onclick(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def on_click(self):
        """Alias for OnClick"""
        return self.OnClick

    @on_click.setter
    def on_click(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def OnClose(self):
        return self.com_object.OnClose

    @OnClose.setter
    def OnClose(self, value):
        self.com_object.OnClose = value

    @property
    def onclose(self):
        """Alias for OnClose"""
        return self.OnClose

    @onclose.setter
    def onclose(self, value):
        """Alias for OnClose.setter"""
        self.OnClose = value

    @property
    def on_close(self):
        """Alias for OnClose"""
        return self.OnClose

    @on_close.setter
    def on_close(self, value):
        """Alias for OnClose.setter"""
        self.OnClose = value

    @property
    def OnConnect(self):
        return self.com_object.OnConnect

    @OnConnect.setter
    def OnConnect(self, value):
        self.com_object.OnConnect = value

    @property
    def onconnect(self):
        """Alias for OnConnect"""
        return self.OnConnect

    @onconnect.setter
    def onconnect(self, value):
        """Alias for OnConnect.setter"""
        self.OnConnect = value

    @property
    def on_connect(self):
        """Alias for OnConnect"""
        return self.OnConnect

    @on_connect.setter
    def on_connect(self, value):
        """Alias for OnConnect.setter"""
        self.OnConnect = value

    @property
    def OnCurrent(self):
        return self.com_object.OnCurrent

    @OnCurrent.setter
    def OnCurrent(self, value):
        self.com_object.OnCurrent = value

    @property
    def oncurrent(self):
        """Alias for OnCurrent"""
        return self.OnCurrent

    @oncurrent.setter
    def oncurrent(self, value):
        """Alias for OnCurrent.setter"""
        self.OnCurrent = value

    @property
    def on_current(self):
        """Alias for OnCurrent"""
        return self.OnCurrent

    @on_current.setter
    def on_current(self, value):
        """Alias for OnCurrent.setter"""
        self.OnCurrent = value

    @property
    def OnDblClick(self):
        return self.com_object.OnDblClick

    @OnDblClick.setter
    def OnDblClick(self, value):
        self.com_object.OnDblClick = value

    @property
    def ondblclick(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @ondblclick.setter
    def ondblclick(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def on_dbl_click(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @on_dbl_click.setter
    def on_dbl_click(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def OnDeactivate(self):
        return self.com_object.OnDeactivate

    @OnDeactivate.setter
    def OnDeactivate(self, value):
        self.com_object.OnDeactivate = value

    @property
    def ondeactivate(self):
        """Alias for OnDeactivate"""
        return self.OnDeactivate

    @ondeactivate.setter
    def ondeactivate(self, value):
        """Alias for OnDeactivate.setter"""
        self.OnDeactivate = value

    @property
    def on_deactivate(self):
        """Alias for OnDeactivate"""
        return self.OnDeactivate

    @on_deactivate.setter
    def on_deactivate(self, value):
        """Alias for OnDeactivate.setter"""
        self.OnDeactivate = value

    @property
    def OnDelete(self):
        return self.com_object.OnDelete

    @OnDelete.setter
    def OnDelete(self, value):
        self.com_object.OnDelete = value

    @property
    def ondelete(self):
        """Alias for OnDelete"""
        return self.OnDelete

    @ondelete.setter
    def ondelete(self, value):
        """Alias for OnDelete.setter"""
        self.OnDelete = value

    @property
    def on_delete(self):
        """Alias for OnDelete"""
        return self.OnDelete

    @on_delete.setter
    def on_delete(self, value):
        """Alias for OnDelete.setter"""
        self.OnDelete = value

    @property
    def OnDirty(self):
        return self.com_object.OnDirty

    @OnDirty.setter
    def OnDirty(self, value):
        self.com_object.OnDirty = value

    @property
    def ondirty(self):
        """Alias for OnDirty"""
        return self.OnDirty

    @ondirty.setter
    def ondirty(self, value):
        """Alias for OnDirty.setter"""
        self.OnDirty = value

    @property
    def on_dirty(self):
        """Alias for OnDirty"""
        return self.OnDirty

    @on_dirty.setter
    def on_dirty(self, value):
        """Alias for OnDirty.setter"""
        self.OnDirty = value

    @property
    def OnDisconnect(self):
        return self.com_object.OnDisconnect

    @OnDisconnect.setter
    def OnDisconnect(self, value):
        self.com_object.OnDisconnect = value

    @property
    def ondisconnect(self):
        """Alias for OnDisconnect"""
        return self.OnDisconnect

    @ondisconnect.setter
    def ondisconnect(self, value):
        """Alias for OnDisconnect.setter"""
        self.OnDisconnect = value

    @property
    def on_disconnect(self):
        """Alias for OnDisconnect"""
        return self.OnDisconnect

    @on_disconnect.setter
    def on_disconnect(self, value):
        """Alias for OnDisconnect.setter"""
        self.OnDisconnect = value

    @property
    def OnError(self):
        return self.com_object.OnError

    @OnError.setter
    def OnError(self, value):
        self.com_object.OnError = value

    @property
    def onerror(self):
        """Alias for OnError"""
        return self.OnError

    @onerror.setter
    def onerror(self, value):
        """Alias for OnError.setter"""
        self.OnError = value

    @property
    def on_error(self):
        """Alias for OnError"""
        return self.OnError

    @on_error.setter
    def on_error(self, value):
        """Alias for OnError.setter"""
        self.OnError = value

    @property
    def OnFilter(self):
        return self.com_object.OnFilter

    @OnFilter.setter
    def OnFilter(self, value):
        self.com_object.OnFilter = value

    @property
    def onfilter(self):
        """Alias for OnFilter"""
        return self.OnFilter

    @onfilter.setter
    def onfilter(self, value):
        """Alias for OnFilter.setter"""
        self.OnFilter = value

    @property
    def on_filter(self):
        """Alias for OnFilter"""
        return self.OnFilter

    @on_filter.setter
    def on_filter(self, value):
        """Alias for OnFilter.setter"""
        self.OnFilter = value

    @property
    def OnGotFocus(self):
        return self.com_object.OnGotFocus

    @OnGotFocus.setter
    def OnGotFocus(self, value):
        self.com_object.OnGotFocus = value

    @property
    def ongotfocus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @ongotfocus.setter
    def ongotfocus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def on_got_focus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @on_got_focus.setter
    def on_got_focus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def OnInsert(self):
        return self.com_object.OnInsert

    @OnInsert.setter
    def OnInsert(self, value):
        self.com_object.OnInsert = value

    @property
    def oninsert(self):
        """Alias for OnInsert"""
        return self.OnInsert

    @oninsert.setter
    def oninsert(self, value):
        """Alias for OnInsert.setter"""
        self.OnInsert = value

    @property
    def on_insert(self):
        """Alias for OnInsert"""
        return self.OnInsert

    @on_insert.setter
    def on_insert(self, value):
        """Alias for OnInsert.setter"""
        self.OnInsert = value

    @property
    def OnKeyDown(self):
        return self.com_object.OnKeyDown

    @OnKeyDown.setter
    def OnKeyDown(self, value):
        self.com_object.OnKeyDown = value

    @property
    def onkeydown(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @onkeydown.setter
    def onkeydown(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def on_key_down(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @on_key_down.setter
    def on_key_down(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def OnKeyPress(self):
        return self.com_object.OnKeyPress

    @OnKeyPress.setter
    def OnKeyPress(self, value):
        self.com_object.OnKeyPress = value

    @property
    def onkeypress(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @onkeypress.setter
    def onkeypress(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def on_key_press(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @on_key_press.setter
    def on_key_press(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def OnKeyUp(self):
        return self.com_object.OnKeyUp

    @OnKeyUp.setter
    def OnKeyUp(self, value):
        self.com_object.OnKeyUp = value

    @property
    def onkeyup(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @onkeyup.setter
    def onkeyup(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def on_key_up(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @on_key_up.setter
    def on_key_up(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def OnLoad(self):
        return self.com_object.OnLoad

    @OnLoad.setter
    def OnLoad(self, value):
        self.com_object.OnLoad = value

    @property
    def onload(self):
        """Alias for OnLoad"""
        return self.OnLoad

    @onload.setter
    def onload(self, value):
        """Alias for OnLoad.setter"""
        self.OnLoad = value

    @property
    def on_load(self):
        """Alias for OnLoad"""
        return self.OnLoad

    @on_load.setter
    def on_load(self, value):
        """Alias for OnLoad.setter"""
        self.OnLoad = value

    @property
    def OnLostFocus(self):
        return self.com_object.OnLostFocus

    @OnLostFocus.setter
    def OnLostFocus(self, value):
        self.com_object.OnLostFocus = value

    @property
    def onlostfocus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @onlostfocus.setter
    def onlostfocus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def on_lost_focus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @on_lost_focus.setter
    def on_lost_focus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def OnMouseDown(self):
        return self.com_object.OnMouseDown

    @OnMouseDown.setter
    def OnMouseDown(self, value):
        self.com_object.OnMouseDown = value

    @property
    def onmousedown(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @onmousedown.setter
    def onmousedown(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def on_mouse_down(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @on_mouse_down.setter
    def on_mouse_down(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def OnMouseMove(self):
        return self.com_object.OnMouseMove

    @OnMouseMove.setter
    def OnMouseMove(self, value):
        self.com_object.OnMouseMove = value

    @property
    def onmousemove(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @onmousemove.setter
    def onmousemove(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def on_mouse_move(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @on_mouse_move.setter
    def on_mouse_move(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def OnMouseUp(self):
        return self.com_object.OnMouseUp

    @OnMouseUp.setter
    def OnMouseUp(self, value):
        self.com_object.OnMouseUp = value

    @property
    def onmouseup(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @onmouseup.setter
    def onmouseup(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def on_mouse_up(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @on_mouse_up.setter
    def on_mouse_up(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def OnOpen(self):
        return self.com_object.OnOpen

    @OnOpen.setter
    def OnOpen(self, value):
        self.com_object.OnOpen = value

    @property
    def onopen(self):
        """Alias for OnOpen"""
        return self.OnOpen

    @onopen.setter
    def onopen(self, value):
        """Alias for OnOpen.setter"""
        self.OnOpen = value

    @property
    def on_open(self):
        """Alias for OnOpen"""
        return self.OnOpen

    @on_open.setter
    def on_open(self, value):
        """Alias for OnOpen.setter"""
        self.OnOpen = value

    @property
    def OnResize(self):
        return self.com_object.OnResize

    @OnResize.setter
    def OnResize(self, value):
        self.com_object.OnResize = value

    @property
    def onresize(self):
        """Alias for OnResize"""
        return self.OnResize

    @onresize.setter
    def onresize(self, value):
        """Alias for OnResize.setter"""
        self.OnResize = value

    @property
    def on_resize(self):
        """Alias for OnResize"""
        return self.OnResize

    @on_resize.setter
    def on_resize(self, value):
        """Alias for OnResize.setter"""
        self.OnResize = value

    @property
    def OnTimer(self):
        return self.com_object.OnTimer

    @OnTimer.setter
    def OnTimer(self, value):
        self.com_object.OnTimer = value

    @property
    def ontimer(self):
        """Alias for OnTimer"""
        return self.OnTimer

    @ontimer.setter
    def ontimer(self, value):
        """Alias for OnTimer.setter"""
        self.OnTimer = value

    @property
    def on_timer(self):
        """Alias for OnTimer"""
        return self.OnTimer

    @on_timer.setter
    def on_timer(self, value):
        """Alias for OnTimer.setter"""
        self.OnTimer = value

    @property
    def OnUndo(self):
        return self.com_object.OnUndo

    @OnUndo.setter
    def OnUndo(self, value):
        self.com_object.OnUndo = value

    @property
    def onundo(self):
        """Alias for OnUndo"""
        return self.OnUndo

    @onundo.setter
    def onundo(self, value):
        """Alias for OnUndo.setter"""
        self.OnUndo = value

    @property
    def on_undo(self):
        """Alias for OnUndo"""
        return self.OnUndo

    @on_undo.setter
    def on_undo(self, value):
        """Alias for OnUndo.setter"""
        self.OnUndo = value

    @property
    def OnUnload(self):
        return self.com_object.OnUnload

    @OnUnload.setter
    def OnUnload(self, value):
        self.com_object.OnUnload = value

    @property
    def onunload(self):
        """Alias for OnUnload"""
        return self.OnUnload

    @onunload.setter
    def onunload(self, value):
        """Alias for OnUnload.setter"""
        self.OnUnload = value

    @property
    def on_unload(self):
        """Alias for OnUnload"""
        return self.OnUnload

    @on_unload.setter
    def on_unload(self, value):
        """Alias for OnUnload.setter"""
        self.OnUnload = value

    @property
    def OpenArgs(self):
        return self.com_object.OpenArgs

    @OpenArgs.setter
    def OpenArgs(self, value):
        self.com_object.OpenArgs = value

    @property
    def openargs(self):
        """Alias for OpenArgs"""
        return self.OpenArgs

    @openargs.setter
    def openargs(self, value):
        """Alias for OpenArgs.setter"""
        self.OpenArgs = value

    @property
    def open_args(self):
        """Alias for OpenArgs"""
        return self.OpenArgs

    @open_args.setter
    def open_args(self, value):
        """Alias for OpenArgs.setter"""
        self.OpenArgs = value

    @property
    def OrderBy(self):
        return self.com_object.OrderBy

    @OrderBy.setter
    def OrderBy(self, value):
        self.com_object.OrderBy = value

    @property
    def orderby(self):
        """Alias for OrderBy"""
        return self.OrderBy

    @orderby.setter
    def orderby(self, value):
        """Alias for OrderBy.setter"""
        self.OrderBy = value

    @property
    def order_by(self):
        """Alias for OrderBy"""
        return self.OrderBy

    @order_by.setter
    def order_by(self, value):
        """Alias for OrderBy.setter"""
        self.OrderBy = value

    @property
    def OrderByOn(self):
        return self.com_object.OrderByOn

    @OrderByOn.setter
    def OrderByOn(self, value):
        self.com_object.OrderByOn = value

    @property
    def orderbyon(self):
        """Alias for OrderByOn"""
        return self.OrderByOn

    @orderbyon.setter
    def orderbyon(self, value):
        """Alias for OrderByOn.setter"""
        self.OrderByOn = value

    @property
    def order_by_on(self):
        """Alias for OrderByOn"""
        return self.OrderByOn

    @order_by_on.setter
    def order_by_on(self, value):
        """Alias for OrderByOn.setter"""
        self.OrderByOn = value

    @property
    def OrderByOnLoad(self):
        return self.com_object.OrderByOnLoad

    @OrderByOnLoad.setter
    def OrderByOnLoad(self, value):
        self.com_object.OrderByOnLoad = value

    @property
    def orderbyonload(self):
        """Alias for OrderByOnLoad"""
        return self.OrderByOnLoad

    @orderbyonload.setter
    def orderbyonload(self, value):
        """Alias for OrderByOnLoad.setter"""
        self.OrderByOnLoad = value

    @property
    def order_by_on_load(self):
        """Alias for OrderByOnLoad"""
        return self.OrderByOnLoad

    @order_by_on_load.setter
    def order_by_on_load(self, value):
        """Alias for OrderByOnLoad.setter"""
        self.OrderByOnLoad = value

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Page(self):
        return self.com_object.Page

    @Page.setter
    def Page(self, value):
        self.com_object.Page = value

    @property
    def page(self):
        """Alias for Page"""
        return self.Page

    @page.setter
    def page(self, value):
        """Alias for Page.setter"""
        self.Page = value

    @property
    def Pages(self):
        return self.com_object.Pages

    @Pages.setter
    def Pages(self, value):
        self.com_object.Pages = value

    @property
    def pages(self):
        """Alias for Pages"""
        return self.Pages

    @pages.setter
    def pages(self, value):
        """Alias for Pages.setter"""
        self.Pages = value

    @property
    def Painting(self):
        return self.com_object.Painting

    @Painting.setter
    def Painting(self, value):
        self.com_object.Painting = value

    @property
    def painting(self):
        """Alias for Painting"""
        return self.Painting

    @painting.setter
    def painting(self, value):
        """Alias for Painting.setter"""
        self.Painting = value

    @property
    def PaintPalette(self):
        return self.com_object.PaintPalette

    @PaintPalette.setter
    def PaintPalette(self, value):
        self.com_object.PaintPalette = value

    @property
    def paintpalette(self):
        """Alias for PaintPalette"""
        return self.PaintPalette

    @paintpalette.setter
    def paintpalette(self, value):
        """Alias for PaintPalette.setter"""
        self.PaintPalette = value

    @property
    def paint_palette(self):
        """Alias for PaintPalette"""
        return self.PaintPalette

    @paint_palette.setter
    def paint_palette(self, value):
        """Alias for PaintPalette.setter"""
        self.PaintPalette = value

    @property
    def PaletteSource(self):
        return self.com_object.PaletteSource

    @PaletteSource.setter
    def PaletteSource(self, value):
        self.com_object.PaletteSource = value

    @property
    def palettesource(self):
        """Alias for PaletteSource"""
        return self.PaletteSource

    @palettesource.setter
    def palettesource(self, value):
        """Alias for PaletteSource.setter"""
        self.PaletteSource = value

    @property
    def palette_source(self):
        """Alias for PaletteSource"""
        return self.PaletteSource

    @palette_source.setter
    def palette_source(self, value):
        """Alias for PaletteSource.setter"""
        self.PaletteSource = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Picture(self):
        return self.com_object.Picture

    @Picture.setter
    def Picture(self, value):
        self.com_object.Picture = value

    @property
    def picture(self):
        """Alias for Picture"""
        return self.Picture

    @picture.setter
    def picture(self, value):
        """Alias for Picture.setter"""
        self.Picture = value

    @property
    def PictureAlignment(self):
        return self.com_object.PictureAlignment

    @PictureAlignment.setter
    def PictureAlignment(self, value):
        self.com_object.PictureAlignment = value

    @property
    def picturealignment(self):
        """Alias for PictureAlignment"""
        return self.PictureAlignment

    @picturealignment.setter
    def picturealignment(self, value):
        """Alias for PictureAlignment.setter"""
        self.PictureAlignment = value

    @property
    def picture_alignment(self):
        """Alias for PictureAlignment"""
        return self.PictureAlignment

    @picture_alignment.setter
    def picture_alignment(self, value):
        """Alias for PictureAlignment.setter"""
        self.PictureAlignment = value

    @property
    def PictureData(self):
        return self.com_object.PictureData

    @PictureData.setter
    def PictureData(self, value):
        self.com_object.PictureData = value

    @property
    def picturedata(self):
        """Alias for PictureData"""
        return self.PictureData

    @picturedata.setter
    def picturedata(self, value):
        """Alias for PictureData.setter"""
        self.PictureData = value

    @property
    def picture_data(self):
        """Alias for PictureData"""
        return self.PictureData

    @picture_data.setter
    def picture_data(self, value):
        """Alias for PictureData.setter"""
        self.PictureData = value

    @property
    def PicturePalette(self):
        return self.com_object.PicturePalette

    @PicturePalette.setter
    def PicturePalette(self, value):
        self.com_object.PicturePalette = value

    @property
    def picturepalette(self):
        """Alias for PicturePalette"""
        return self.PicturePalette

    @picturepalette.setter
    def picturepalette(self, value):
        """Alias for PicturePalette.setter"""
        self.PicturePalette = value

    @property
    def picture_palette(self):
        """Alias for PicturePalette"""
        return self.PicturePalette

    @picture_palette.setter
    def picture_palette(self, value):
        """Alias for PicturePalette.setter"""
        self.PicturePalette = value

    @property
    def PictureSizeMode(self):
        return self.com_object.PictureSizeMode

    @PictureSizeMode.setter
    def PictureSizeMode(self, value):
        self.com_object.PictureSizeMode = value

    @property
    def picturesizemode(self):
        """Alias for PictureSizeMode"""
        return self.PictureSizeMode

    @picturesizemode.setter
    def picturesizemode(self, value):
        """Alias for PictureSizeMode.setter"""
        self.PictureSizeMode = value

    @property
    def picture_size_mode(self):
        """Alias for PictureSizeMode"""
        return self.PictureSizeMode

    @picture_size_mode.setter
    def picture_size_mode(self, value):
        """Alias for PictureSizeMode.setter"""
        self.PictureSizeMode = value

    @property
    def PictureTiling(self):
        return self.com_object.PictureTiling

    @PictureTiling.setter
    def PictureTiling(self, value):
        self.com_object.PictureTiling = value

    @property
    def picturetiling(self):
        """Alias for PictureTiling"""
        return self.PictureTiling

    @picturetiling.setter
    def picturetiling(self, value):
        """Alias for PictureTiling.setter"""
        self.PictureTiling = value

    @property
    def picture_tiling(self):
        """Alias for PictureTiling"""
        return self.PictureTiling

    @picture_tiling.setter
    def picture_tiling(self, value):
        """Alias for PictureTiling.setter"""
        self.PictureTiling = value

    @property
    def PictureType(self):
        return self.com_object.PictureType

    @PictureType.setter
    def PictureType(self, value):
        self.com_object.PictureType = value

    @property
    def picturetype(self):
        """Alias for PictureType"""
        return self.PictureType

    @picturetype.setter
    def picturetype(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def picture_type(self):
        """Alias for PictureType"""
        return self.PictureType

    @picture_type.setter
    def picture_type(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def PivotTable(self):
        return self.com_object.PivotTable

    @property
    def pivottable(self):
        """Alias for PivotTable"""
        return self.PivotTable

    @property
    def pivot_table(self):
        """Alias for PivotTable"""
        return self.PivotTable

    @property
    def PivotTableChange(self):
        return self.com_object.PivotTableChange

    @PivotTableChange.setter
    def PivotTableChange(self, value):
        self.com_object.PivotTableChange = value

    @property
    def pivottablechange(self):
        """Alias for PivotTableChange"""
        return self.PivotTableChange

    @pivottablechange.setter
    def pivottablechange(self, value):
        """Alias for PivotTableChange.setter"""
        self.PivotTableChange = value

    @property
    def pivot_table_change(self):
        """Alias for PivotTableChange"""
        return self.PivotTableChange

    @pivot_table_change.setter
    def pivot_table_change(self, value):
        """Alias for PivotTableChange.setter"""
        self.PivotTableChange = value

    @property
    def PopUp(self):
        return self.com_object.PopUp

    @PopUp.setter
    def PopUp(self, value):
        self.com_object.PopUp = value

    @property
    def popup(self):
        """Alias for PopUp"""
        return self.PopUp

    @popup.setter
    def popup(self, value):
        """Alias for PopUp.setter"""
        self.PopUp = value

    @property
    def pop_up(self):
        """Alias for PopUp"""
        return self.PopUp

    @pop_up.setter
    def pop_up(self, value):
        """Alias for PopUp.setter"""
        self.PopUp = value

    @property
    def Printer(self):
        return Printer(self.com_object.Printer)

    @Printer.setter
    def Printer(self, value):
        self.com_object.Printer = value

    @property
    def printer(self):
        """Alias for Printer"""
        return self.Printer

    @printer.setter
    def printer(self, value):
        """Alias for Printer.setter"""
        self.Printer = value

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def PrtDevMode(self):
        return self.com_object.PrtDevMode

    @PrtDevMode.setter
    def PrtDevMode(self, value):
        self.com_object.PrtDevMode = value

    @property
    def prtdevmode(self):
        """Alias for PrtDevMode"""
        return self.PrtDevMode

    @prtdevmode.setter
    def prtdevmode(self, value):
        """Alias for PrtDevMode.setter"""
        self.PrtDevMode = value

    @property
    def prt_dev_mode(self):
        """Alias for PrtDevMode"""
        return self.PrtDevMode

    @prt_dev_mode.setter
    def prt_dev_mode(self, value):
        """Alias for PrtDevMode.setter"""
        self.PrtDevMode = value

    @property
    def PrtDevNames(self):
        return self.com_object.PrtDevNames

    @PrtDevNames.setter
    def PrtDevNames(self, value):
        self.com_object.PrtDevNames = value

    @property
    def prtdevnames(self):
        """Alias for PrtDevNames"""
        return self.PrtDevNames

    @prtdevnames.setter
    def prtdevnames(self, value):
        """Alias for PrtDevNames.setter"""
        self.PrtDevNames = value

    @property
    def prt_dev_names(self):
        """Alias for PrtDevNames"""
        return self.PrtDevNames

    @prt_dev_names.setter
    def prt_dev_names(self, value):
        """Alias for PrtDevNames.setter"""
        self.PrtDevNames = value

    @property
    def PrtMip(self):
        return self.com_object.PrtMip

    @property
    def prtmip(self):
        """Alias for PrtMip"""
        return self.PrtMip

    @property
    def prt_mip(self):
        """Alias for PrtMip"""
        return self.PrtMip

    @property
    def Query(self):
        return self.com_object.Query

    @Query.setter
    def Query(self, value):
        self.com_object.Query = value

    @property
    def query(self):
        """Alias for Query"""
        return self.Query

    @query.setter
    def query(self, value):
        """Alias for Query.setter"""
        self.Query = value

    @property
    def RecordLocks(self):
        return self.com_object.RecordLocks

    @RecordLocks.setter
    def RecordLocks(self, value):
        self.com_object.RecordLocks = value

    @property
    def recordlocks(self):
        """Alias for RecordLocks"""
        return self.RecordLocks

    @recordlocks.setter
    def recordlocks(self, value):
        """Alias for RecordLocks.setter"""
        self.RecordLocks = value

    @property
    def record_locks(self):
        """Alias for RecordLocks"""
        return self.RecordLocks

    @record_locks.setter
    def record_locks(self, value):
        """Alias for RecordLocks.setter"""
        self.RecordLocks = value

    @property
    def RecordSelectors(self):
        return self.com_object.RecordSelectors

    @RecordSelectors.setter
    def RecordSelectors(self, value):
        self.com_object.RecordSelectors = value

    @property
    def recordselectors(self):
        """Alias for RecordSelectors"""
        return self.RecordSelectors

    @recordselectors.setter
    def recordselectors(self, value):
        """Alias for RecordSelectors.setter"""
        self.RecordSelectors = value

    @property
    def record_selectors(self):
        """Alias for RecordSelectors"""
        return self.RecordSelectors

    @record_selectors.setter
    def record_selectors(self, value):
        """Alias for RecordSelectors.setter"""
        self.RecordSelectors = value

    @property
    def Recordset(self):
        return self.com_object.Recordset

    @Recordset.setter
    def Recordset(self, value):
        self.com_object.Recordset = value

    @property
    def recordset(self):
        """Alias for Recordset"""
        return self.Recordset

    @recordset.setter
    def recordset(self, value):
        """Alias for Recordset.setter"""
        self.Recordset = value

    @property
    def RecordsetClone(self):
        return self.com_object.RecordsetClone

    @property
    def recordsetclone(self):
        """Alias for RecordsetClone"""
        return self.RecordsetClone

    @property
    def recordset_clone(self):
        """Alias for RecordsetClone"""
        return self.RecordsetClone

    @property
    def RecordsetType(self):
        return self.com_object.RecordsetType

    @RecordsetType.setter
    def RecordsetType(self, value):
        self.com_object.RecordsetType = value

    @property
    def recordsettype(self):
        """Alias for RecordsetType"""
        return self.RecordsetType

    @recordsettype.setter
    def recordsettype(self, value):
        """Alias for RecordsetType.setter"""
        self.RecordsetType = value

    @property
    def recordset_type(self):
        """Alias for RecordsetType"""
        return self.RecordsetType

    @recordset_type.setter
    def recordset_type(self, value):
        """Alias for RecordsetType.setter"""
        self.RecordsetType = value

    @property
    def RecordSource(self):
        return self.com_object.RecordSource

    @RecordSource.setter
    def RecordSource(self, value):
        self.com_object.RecordSource = value

    @property
    def recordsource(self):
        """Alias for RecordSource"""
        return self.RecordSource

    @recordsource.setter
    def recordsource(self, value):
        """Alias for RecordSource.setter"""
        self.RecordSource = value

    @property
    def record_source(self):
        """Alias for RecordSource"""
        return self.RecordSource

    @record_source.setter
    def record_source(self, value):
        """Alias for RecordSource.setter"""
        self.RecordSource = value

    @property
    def RecordSourceQualifier(self):
        return self.com_object.RecordSourceQualifier

    @RecordSourceQualifier.setter
    def RecordSourceQualifier(self, value):
        self.com_object.RecordSourceQualifier = value

    @property
    def recordsourcequalifier(self):
        """Alias for RecordSourceQualifier"""
        return self.RecordSourceQualifier

    @recordsourcequalifier.setter
    def recordsourcequalifier(self, value):
        """Alias for RecordSourceQualifier.setter"""
        self.RecordSourceQualifier = value

    @property
    def record_source_qualifier(self):
        """Alias for RecordSourceQualifier"""
        return self.RecordSourceQualifier

    @record_source_qualifier.setter
    def record_source_qualifier(self, value):
        """Alias for RecordSourceQualifier.setter"""
        self.RecordSourceQualifier = value

    @property
    def ResyncCommand(self):
        return self.com_object.ResyncCommand

    @ResyncCommand.setter
    def ResyncCommand(self, value):
        self.com_object.ResyncCommand = value

    @property
    def resynccommand(self):
        """Alias for ResyncCommand"""
        return self.ResyncCommand

    @resynccommand.setter
    def resynccommand(self, value):
        """Alias for ResyncCommand.setter"""
        self.ResyncCommand = value

    @property
    def resync_command(self):
        """Alias for ResyncCommand"""
        return self.ResyncCommand

    @resync_command.setter
    def resync_command(self, value):
        """Alias for ResyncCommand.setter"""
        self.ResyncCommand = value

    @property
    def RibbonName(self):
        return self.com_object.RibbonName

    @RibbonName.setter
    def RibbonName(self, value):
        self.com_object.RibbonName = value

    @property
    def ribbonname(self):
        """Alias for RibbonName"""
        return self.RibbonName

    @ribbonname.setter
    def ribbonname(self, value):
        """Alias for RibbonName.setter"""
        self.RibbonName = value

    @property
    def ribbon_name(self):
        """Alias for RibbonName"""
        return self.RibbonName

    @ribbon_name.setter
    def ribbon_name(self, value):
        """Alias for RibbonName.setter"""
        self.RibbonName = value

    @property
    def RowHeight(self):
        return self.com_object.RowHeight

    @RowHeight.setter
    def RowHeight(self, value):
        self.com_object.RowHeight = value

    @property
    def rowheight(self):
        """Alias for RowHeight"""
        return self.RowHeight

    @rowheight.setter
    def rowheight(self, value):
        """Alias for RowHeight.setter"""
        self.RowHeight = value

    @property
    def row_height(self):
        """Alias for RowHeight"""
        return self.RowHeight

    @row_height.setter
    def row_height(self, value):
        """Alias for RowHeight.setter"""
        self.RowHeight = value

    @property
    def ScrollBars(self):
        return self.com_object.ScrollBars

    @ScrollBars.setter
    def ScrollBars(self, value):
        self.com_object.ScrollBars = value

    @property
    def scrollbars(self):
        """Alias for ScrollBars"""
        return self.ScrollBars

    @scrollbars.setter
    def scrollbars(self, value):
        """Alias for ScrollBars.setter"""
        self.ScrollBars = value

    @property
    def scroll_bars(self):
        """Alias for ScrollBars"""
        return self.ScrollBars

    @scroll_bars.setter
    def scroll_bars(self, value):
        """Alias for ScrollBars.setter"""
        self.ScrollBars = value

    def Section(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetSection"):
            return self.com_object.GetSection(*arguments)
        else:
            return self.com_object.Section(*arguments)

    def section(self, Index=None):
        """Alias for Section"""
        arguments = [Index]
        return self.Section(*arguments)

    @property
    def SelectionChange(self):
        return self.com_object.SelectionChange

    @SelectionChange.setter
    def SelectionChange(self, value):
        self.com_object.SelectionChange = value

    @property
    def selectionchange(self):
        """Alias for SelectionChange"""
        return self.SelectionChange

    @selectionchange.setter
    def selectionchange(self, value):
        """Alias for SelectionChange.setter"""
        self.SelectionChange = value

    @property
    def selection_change(self):
        """Alias for SelectionChange"""
        return self.SelectionChange

    @selection_change.setter
    def selection_change(self, value):
        """Alias for SelectionChange.setter"""
        self.SelectionChange = value

    @property
    def SelHeight(self):
        return self.com_object.SelHeight

    @SelHeight.setter
    def SelHeight(self, value):
        self.com_object.SelHeight = value

    @property
    def selheight(self):
        """Alias for SelHeight"""
        return self.SelHeight

    @selheight.setter
    def selheight(self, value):
        """Alias for SelHeight.setter"""
        self.SelHeight = value

    @property
    def sel_height(self):
        """Alias for SelHeight"""
        return self.SelHeight

    @sel_height.setter
    def sel_height(self, value):
        """Alias for SelHeight.setter"""
        self.SelHeight = value

    @property
    def SelLeft(self):
        return self.com_object.SelLeft

    @SelLeft.setter
    def SelLeft(self, value):
        self.com_object.SelLeft = value

    @property
    def selleft(self):
        """Alias for SelLeft"""
        return self.SelLeft

    @selleft.setter
    def selleft(self, value):
        """Alias for SelLeft.setter"""
        self.SelLeft = value

    @property
    def sel_left(self):
        """Alias for SelLeft"""
        return self.SelLeft

    @sel_left.setter
    def sel_left(self, value):
        """Alias for SelLeft.setter"""
        self.SelLeft = value

    @property
    def SelTop(self):
        return self.com_object.SelTop

    @SelTop.setter
    def SelTop(self, value):
        self.com_object.SelTop = value

    @property
    def seltop(self):
        """Alias for SelTop"""
        return self.SelTop

    @seltop.setter
    def seltop(self, value):
        """Alias for SelTop.setter"""
        self.SelTop = value

    @property
    def sel_top(self):
        """Alias for SelTop"""
        return self.SelTop

    @sel_top.setter
    def sel_top(self, value):
        """Alias for SelTop.setter"""
        self.SelTop = value

    @property
    def SelWidth(self):
        return self.com_object.SelWidth

    @SelWidth.setter
    def SelWidth(self, value):
        self.com_object.SelWidth = value

    @property
    def selwidth(self):
        """Alias for SelWidth"""
        return self.SelWidth

    @selwidth.setter
    def selwidth(self, value):
        """Alias for SelWidth.setter"""
        self.SelWidth = value

    @property
    def sel_width(self):
        """Alias for SelWidth"""
        return self.SelWidth

    @sel_width.setter
    def sel_width(self, value):
        """Alias for SelWidth.setter"""
        self.SelWidth = value

    @property
    def ServerFilter(self):
        return self.com_object.ServerFilter

    @ServerFilter.setter
    def ServerFilter(self, value):
        self.com_object.ServerFilter = value

    @property
    def serverfilter(self):
        """Alias for ServerFilter"""
        return self.ServerFilter

    @serverfilter.setter
    def serverfilter(self, value):
        """Alias for ServerFilter.setter"""
        self.ServerFilter = value

    @property
    def server_filter(self):
        """Alias for ServerFilter"""
        return self.ServerFilter

    @server_filter.setter
    def server_filter(self, value):
        """Alias for ServerFilter.setter"""
        self.ServerFilter = value

    @property
    def ServerFilterByForm(self):
        return self.com_object.ServerFilterByForm

    @ServerFilterByForm.setter
    def ServerFilterByForm(self, value):
        self.com_object.ServerFilterByForm = value

    @property
    def serverfilterbyform(self):
        """Alias for ServerFilterByForm"""
        return self.ServerFilterByForm

    @serverfilterbyform.setter
    def serverfilterbyform(self, value):
        """Alias for ServerFilterByForm.setter"""
        self.ServerFilterByForm = value

    @property
    def server_filter_by_form(self):
        """Alias for ServerFilterByForm"""
        return self.ServerFilterByForm

    @server_filter_by_form.setter
    def server_filter_by_form(self, value):
        """Alias for ServerFilterByForm.setter"""
        self.ServerFilterByForm = value

    @property
    def ShortcutMenu(self):
        return self.com_object.ShortcutMenu

    @ShortcutMenu.setter
    def ShortcutMenu(self, value):
        self.com_object.ShortcutMenu = value

    @property
    def shortcutmenu(self):
        """Alias for ShortcutMenu"""
        return self.ShortcutMenu

    @shortcutmenu.setter
    def shortcutmenu(self, value):
        """Alias for ShortcutMenu.setter"""
        self.ShortcutMenu = value

    @property
    def shortcut_menu(self):
        """Alias for ShortcutMenu"""
        return self.ShortcutMenu

    @shortcut_menu.setter
    def shortcut_menu(self, value):
        """Alias for ShortcutMenu.setter"""
        self.ShortcutMenu = value

    @property
    def ShortcutMenuBar(self):
        return self.com_object.ShortcutMenuBar

    @ShortcutMenuBar.setter
    def ShortcutMenuBar(self, value):
        self.com_object.ShortcutMenuBar = value

    @property
    def shortcutmenubar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcutmenubar.setter
    def shortcutmenubar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def shortcut_menu_bar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcut_menu_bar.setter
    def shortcut_menu_bar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def SplitFormDatasheet(self):
        return self.com_object.SplitFormDatasheet

    @SplitFormDatasheet.setter
    def SplitFormDatasheet(self, value):
        self.com_object.SplitFormDatasheet = value

    @property
    def splitformdatasheet(self):
        """Alias for SplitFormDatasheet"""
        return self.SplitFormDatasheet

    @splitformdatasheet.setter
    def splitformdatasheet(self, value):
        """Alias for SplitFormDatasheet.setter"""
        self.SplitFormDatasheet = value

    @property
    def split_form_datasheet(self):
        """Alias for SplitFormDatasheet"""
        return self.SplitFormDatasheet

    @split_form_datasheet.setter
    def split_form_datasheet(self, value):
        """Alias for SplitFormDatasheet.setter"""
        self.SplitFormDatasheet = value

    @property
    def SplitFormOrientation(self):
        return self.com_object.SplitFormOrientation

    @SplitFormOrientation.setter
    def SplitFormOrientation(self, value):
        self.com_object.SplitFormOrientation = value

    @property
    def splitformorientation(self):
        """Alias for SplitFormOrientation"""
        return self.SplitFormOrientation

    @splitformorientation.setter
    def splitformorientation(self, value):
        """Alias for SplitFormOrientation.setter"""
        self.SplitFormOrientation = value

    @property
    def split_form_orientation(self):
        """Alias for SplitFormOrientation"""
        return self.SplitFormOrientation

    @split_form_orientation.setter
    def split_form_orientation(self, value):
        """Alias for SplitFormOrientation.setter"""
        self.SplitFormOrientation = value

    @property
    def SplitFormPrinting(self):
        return self.com_object.SplitFormPrinting

    @SplitFormPrinting.setter
    def SplitFormPrinting(self, value):
        self.com_object.SplitFormPrinting = value

    @property
    def splitformprinting(self):
        """Alias for SplitFormPrinting"""
        return self.SplitFormPrinting

    @splitformprinting.setter
    def splitformprinting(self, value):
        """Alias for SplitFormPrinting.setter"""
        self.SplitFormPrinting = value

    @property
    def split_form_printing(self):
        """Alias for SplitFormPrinting"""
        return self.SplitFormPrinting

    @split_form_printing.setter
    def split_form_printing(self, value):
        """Alias for SplitFormPrinting.setter"""
        self.SplitFormPrinting = value

    @property
    def SplitFormSize(self):
        return self.com_object.SplitFormSize

    @SplitFormSize.setter
    def SplitFormSize(self, value):
        self.com_object.SplitFormSize = value

    @property
    def splitformsize(self):
        """Alias for SplitFormSize"""
        return self.SplitFormSize

    @splitformsize.setter
    def splitformsize(self, value):
        """Alias for SplitFormSize.setter"""
        self.SplitFormSize = value

    @property
    def split_form_size(self):
        """Alias for SplitFormSize"""
        return self.SplitFormSize

    @split_form_size.setter
    def split_form_size(self, value):
        """Alias for SplitFormSize.setter"""
        self.SplitFormSize = value

    @property
    def SplitFormSplitterBar(self):
        return self.com_object.SplitFormSplitterBar

    @SplitFormSplitterBar.setter
    def SplitFormSplitterBar(self, value):
        self.com_object.SplitFormSplitterBar = value

    @property
    def splitformsplitterbar(self):
        """Alias for SplitFormSplitterBar"""
        return self.SplitFormSplitterBar

    @splitformsplitterbar.setter
    def splitformsplitterbar(self, value):
        """Alias for SplitFormSplitterBar.setter"""
        self.SplitFormSplitterBar = value

    @property
    def split_form_splitter_bar(self):
        """Alias for SplitFormSplitterBar"""
        return self.SplitFormSplitterBar

    @split_form_splitter_bar.setter
    def split_form_splitter_bar(self, value):
        """Alias for SplitFormSplitterBar.setter"""
        self.SplitFormSplitterBar = value

    @property
    def SplitFormSplitterBarSave(self):
        return self.com_object.SplitFormSplitterBarSave

    @SplitFormSplitterBarSave.setter
    def SplitFormSplitterBarSave(self, value):
        self.com_object.SplitFormSplitterBarSave = value

    @property
    def splitformsplitterbarsave(self):
        """Alias for SplitFormSplitterBarSave"""
        return self.SplitFormSplitterBarSave

    @splitformsplitterbarsave.setter
    def splitformsplitterbarsave(self, value):
        """Alias for SplitFormSplitterBarSave.setter"""
        self.SplitFormSplitterBarSave = value

    @property
    def split_form_splitter_bar_save(self):
        """Alias for SplitFormSplitterBarSave"""
        return self.SplitFormSplitterBarSave

    @split_form_splitter_bar_save.setter
    def split_form_splitter_bar_save(self, value):
        """Alias for SplitFormSplitterBarSave.setter"""
        self.SplitFormSplitterBarSave = value

    @property
    def SubdatasheetExpanded(self):
        return self.com_object.SubdatasheetExpanded

    @SubdatasheetExpanded.setter
    def SubdatasheetExpanded(self, value):
        self.com_object.SubdatasheetExpanded = value

    @property
    def subdatasheetexpanded(self):
        """Alias for SubdatasheetExpanded"""
        return self.SubdatasheetExpanded

    @subdatasheetexpanded.setter
    def subdatasheetexpanded(self, value):
        """Alias for SubdatasheetExpanded.setter"""
        self.SubdatasheetExpanded = value

    @property
    def subdatasheet_expanded(self):
        """Alias for SubdatasheetExpanded"""
        return self.SubdatasheetExpanded

    @subdatasheet_expanded.setter
    def subdatasheet_expanded(self, value):
        """Alias for SubdatasheetExpanded.setter"""
        self.SubdatasheetExpanded = value

    @property
    def SubdatasheetHeight(self):
        return self.com_object.SubdatasheetHeight

    @SubdatasheetHeight.setter
    def SubdatasheetHeight(self, value):
        self.com_object.SubdatasheetHeight = value

    @property
    def subdatasheetheight(self):
        """Alias for SubdatasheetHeight"""
        return self.SubdatasheetHeight

    @subdatasheetheight.setter
    def subdatasheetheight(self, value):
        """Alias for SubdatasheetHeight.setter"""
        self.SubdatasheetHeight = value

    @property
    def subdatasheet_height(self):
        """Alias for SubdatasheetHeight"""
        return self.SubdatasheetHeight

    @subdatasheet_height.setter
    def subdatasheet_height(self, value):
        """Alias for SubdatasheetHeight.setter"""
        self.SubdatasheetHeight = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def TimerInterval(self):
        return self.com_object.TimerInterval

    @TimerInterval.setter
    def TimerInterval(self, value):
        self.com_object.TimerInterval = value

    @property
    def timerinterval(self):
        """Alias for TimerInterval"""
        return self.TimerInterval

    @timerinterval.setter
    def timerinterval(self, value):
        """Alias for TimerInterval.setter"""
        self.TimerInterval = value

    @property
    def timer_interval(self):
        """Alias for TimerInterval"""
        return self.TimerInterval

    @timer_interval.setter
    def timer_interval(self, value):
        """Alias for TimerInterval.setter"""
        self.TimerInterval = value

    @property
    def Toolbar(self):
        return self.com_object.Toolbar

    @Toolbar.setter
    def Toolbar(self, value):
        self.com_object.Toolbar = value

    @property
    def toolbar(self):
        """Alias for Toolbar"""
        return self.Toolbar

    @toolbar.setter
    def toolbar(self, value):
        """Alias for Toolbar.setter"""
        self.Toolbar = value

    @property
    def UniqueTable(self):
        return self.com_object.UniqueTable

    @property
    def uniquetable(self):
        """Alias for UniqueTable"""
        return self.UniqueTable

    @property
    def unique_table(self):
        """Alias for UniqueTable"""
        return self.UniqueTable

    @property
    def UseDefaultPrinter(self):
        return self.com_object.UseDefaultPrinter

    @UseDefaultPrinter.setter
    def UseDefaultPrinter(self, value):
        self.com_object.UseDefaultPrinter = value

    @property
    def usedefaultprinter(self):
        """Alias for UseDefaultPrinter"""
        return self.UseDefaultPrinter

    @usedefaultprinter.setter
    def usedefaultprinter(self, value):
        """Alias for UseDefaultPrinter.setter"""
        self.UseDefaultPrinter = value

    @property
    def use_default_printer(self):
        """Alias for UseDefaultPrinter"""
        return self.UseDefaultPrinter

    @use_default_printer.setter
    def use_default_printer(self, value):
        """Alias for UseDefaultPrinter.setter"""
        self.UseDefaultPrinter = value

    @property
    def VerticalDatasheetGridlineStyle(self):
        return self.com_object.VerticalDatasheetGridlineStyle

    @VerticalDatasheetGridlineStyle.setter
    def VerticalDatasheetGridlineStyle(self, value):
        self.com_object.VerticalDatasheetGridlineStyle = value

    @property
    def verticaldatasheetgridlinestyle(self):
        """Alias for VerticalDatasheetGridlineStyle"""
        return self.VerticalDatasheetGridlineStyle

    @verticaldatasheetgridlinestyle.setter
    def verticaldatasheetgridlinestyle(self, value):
        """Alias for VerticalDatasheetGridlineStyle.setter"""
        self.VerticalDatasheetGridlineStyle = value

    @property
    def vertical_datasheet_gridline_style(self):
        """Alias for VerticalDatasheetGridlineStyle"""
        return self.VerticalDatasheetGridlineStyle

    @vertical_datasheet_gridline_style.setter
    def vertical_datasheet_gridline_style(self, value):
        """Alias for VerticalDatasheetGridlineStyle.setter"""
        self.VerticalDatasheetGridlineStyle = value

    @property
    def ViewChange(self):
        return self.com_object.ViewChange

    @ViewChange.setter
    def ViewChange(self, value):
        self.com_object.ViewChange = value

    @property
    def viewchange(self):
        """Alias for ViewChange"""
        return self.ViewChange

    @viewchange.setter
    def viewchange(self, value):
        """Alias for ViewChange.setter"""
        self.ViewChange = value

    @property
    def view_change(self):
        """Alias for ViewChange"""
        return self.ViewChange

    @view_change.setter
    def view_change(self, value):
        """Alias for ViewChange.setter"""
        self.ViewChange = value

    @property
    def ViewsAllowed(self):
        return self.com_object.ViewsAllowed

    @ViewsAllowed.setter
    def ViewsAllowed(self, value):
        self.com_object.ViewsAllowed = value

    @property
    def viewsallowed(self):
        """Alias for ViewsAllowed"""
        return self.ViewsAllowed

    @viewsallowed.setter
    def viewsallowed(self, value):
        """Alias for ViewsAllowed.setter"""
        self.ViewsAllowed = value

    @property
    def views_allowed(self):
        """Alias for ViewsAllowed"""
        return self.ViewsAllowed

    @views_allowed.setter
    def views_allowed(self, value):
        """Alias for ViewsAllowed.setter"""
        self.ViewsAllowed = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def WindowHeight(self):
        return self.com_object.WindowHeight

    @property
    def windowheight(self):
        """Alias for WindowHeight"""
        return self.WindowHeight

    @property
    def window_height(self):
        """Alias for WindowHeight"""
        return self.WindowHeight

    @property
    def WindowLeft(self):
        return self.com_object.WindowLeft

    @property
    def windowleft(self):
        """Alias for WindowLeft"""
        return self.WindowLeft

    @property
    def window_left(self):
        """Alias for WindowLeft"""
        return self.WindowLeft

    @property
    def WindowTop(self):
        return self.com_object.WindowTop

    @property
    def windowtop(self):
        """Alias for WindowTop"""
        return self.WindowTop

    @property
    def window_top(self):
        """Alias for WindowTop"""
        return self.WindowTop

    @property
    def WindowWidth(self):
        return self.com_object.WindowWidth

    @property
    def windowwidth(self):
        """Alias for WindowWidth"""
        return self.WindowWidth

    @property
    def window_width(self):
        """Alias for WindowWidth"""
        return self.WindowWidth

    def GoToPage(self, PageNumber=None, Right=None, Down=None):
        arguments = com_arguments([unwrap(a) for a in [PageNumber, Right, Down]])
        self.com_object.GoToPage(*arguments)

    def gotopage(self, PageNumber=None, Right=None, Down=None):
        """Alias for GoToPage"""
        arguments = [PageNumber, Right, Down]
        return self.GoToPage(*arguments)

    def go_to_page(self, PageNumber=None, Right=None, Down=None):
        """Alias for GoToPage"""
        arguments = [PageNumber, Right, Down]
        return self.GoToPage(*arguments)

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def Recalc(self):
        return self.com_object.Recalc()

    def recalc(self):
        """Alias for Recalc"""
        return self.Recalc()

    def Refresh(self):
        return self.com_object.Refresh()

    def refresh(self):
        """Alias for Refresh"""
        return self.Refresh()

    def Repaint(self):
        return self.com_object.Repaint()

    def repaint(self):
        """Alias for Repaint"""
        return self.Repaint()

    def Requery(self):
        self.com_object.Requery()

    def requery(self):
        """Alias for Requery"""
        return self.Requery()

    def SetFocus(self):
        self.com_object.SetFocus()

    def setfocus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def set_focus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def Undo(self):
        self.com_object.Undo()

    def undo(self):
        """Alias for Undo"""
        return self.Undo()


class FormatCondition:

    def __init__(self, formatcondition=None):
        self.com_object= formatcondition

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def Expression1(self):
        return self.com_object.Expression1

    @property
    def expression1(self):
        """Alias for Expression1"""
        return self.Expression1

    @property
    def Expression2(self):
        return self.com_object.Expression2

    @property
    def expression2(self):
        """Alias for Expression2"""
        return self.Expression2

    @property
    def FontBold(self):
        return self.com_object.FontBold

    @property
    def fontbold(self):
        """Alias for FontBold"""
        return self.FontBold

    @property
    def font_bold(self):
        """Alias for FontBold"""
        return self.FontBold

    @property
    def FontItalic(self):
        return self.com_object.FontItalic

    @property
    def fontitalic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @property
    def font_italic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @property
    def FontUnderline(self):
        return self.com_object.FontUnderline

    @property
    def fontunderline(self):
        """Alias for FontUnderline"""
        return self.FontUnderline

    @property
    def font_underline(self):
        """Alias for FontUnderline"""
        return self.FontUnderline

    @property
    def ForeColor(self):
        return self.com_object.ForeColor

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def LongestBarLimit(self):
        return self.com_object.LongestBarLimit

    @LongestBarLimit.setter
    def LongestBarLimit(self, value):
        self.com_object.LongestBarLimit = value

    @property
    def longestbarlimit(self):
        """Alias for LongestBarLimit"""
        return self.LongestBarLimit

    @longestbarlimit.setter
    def longestbarlimit(self, value):
        """Alias for LongestBarLimit.setter"""
        self.LongestBarLimit = value

    @property
    def longest_bar_limit(self):
        """Alias for LongestBarLimit"""
        return self.LongestBarLimit

    @longest_bar_limit.setter
    def longest_bar_limit(self, value):
        """Alias for LongestBarLimit.setter"""
        self.LongestBarLimit = value

    @property
    def LongestBarValue(self):
        return self.com_object.LongestBarValue

    @LongestBarValue.setter
    def LongestBarValue(self, value):
        self.com_object.LongestBarValue = value

    @property
    def longestbarvalue(self):
        """Alias for LongestBarValue"""
        return self.LongestBarValue

    @longestbarvalue.setter
    def longestbarvalue(self, value):
        """Alias for LongestBarValue.setter"""
        self.LongestBarValue = value

    @property
    def longest_bar_value(self):
        """Alias for LongestBarValue"""
        return self.LongestBarValue

    @longest_bar_value.setter
    def longest_bar_value(self, value):
        """Alias for LongestBarValue.setter"""
        self.LongestBarValue = value

    @property
    def Operator(self):
        return self.com_object.Operator

    @property
    def operator(self):
        """Alias for Operator"""
        return self.Operator

    @property
    def ShortestBarLimit(self):
        return self.com_object.ShortestBarLimit

    @ShortestBarLimit.setter
    def ShortestBarLimit(self, value):
        self.com_object.ShortestBarLimit = value

    @property
    def shortestbarlimit(self):
        """Alias for ShortestBarLimit"""
        return self.ShortestBarLimit

    @shortestbarlimit.setter
    def shortestbarlimit(self, value):
        """Alias for ShortestBarLimit.setter"""
        self.ShortestBarLimit = value

    @property
    def shortest_bar_limit(self):
        """Alias for ShortestBarLimit"""
        return self.ShortestBarLimit

    @shortest_bar_limit.setter
    def shortest_bar_limit(self, value):
        """Alias for ShortestBarLimit.setter"""
        self.ShortestBarLimit = value

    @property
    def ShortestBarValue(self):
        return self.com_object.ShortestBarValue

    @ShortestBarValue.setter
    def ShortestBarValue(self, value):
        self.com_object.ShortestBarValue = value

    @property
    def shortestbarvalue(self):
        """Alias for ShortestBarValue"""
        return self.ShortestBarValue

    @shortestbarvalue.setter
    def shortestbarvalue(self, value):
        """Alias for ShortestBarValue.setter"""
        self.ShortestBarValue = value

    @property
    def shortest_bar_value(self):
        """Alias for ShortestBarValue"""
        return self.ShortestBarValue

    @shortest_bar_value.setter
    def shortest_bar_value(self, value):
        """Alias for ShortestBarValue.setter"""
        self.ShortestBarValue = value

    @property
    def ShowBarOnly(self):
        return self.com_object.ShowBarOnly

    @ShowBarOnly.setter
    def ShowBarOnly(self, value):
        self.com_object.ShowBarOnly = value

    @property
    def showbaronly(self):
        """Alias for ShowBarOnly"""
        return self.ShowBarOnly

    @showbaronly.setter
    def showbaronly(self, value):
        """Alias for ShowBarOnly.setter"""
        self.ShowBarOnly = value

    @property
    def show_bar_only(self):
        """Alias for ShowBarOnly"""
        return self.ShowBarOnly

    @show_bar_only.setter
    def show_bar_only(self, value):
        """Alias for ShowBarOnly.setter"""
        self.ShowBarOnly = value

    @property
    def Type(self):
        return AcFormatConditionType(self.com_object.Type)

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Modify(self, Type=None, Operator=None, Expression1=None, Expression2=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Operator, Expression1, Expression2]])
        return self.com_object.Modify(*arguments)

    def modify(self, Type=None, Operator=None, Expression1=None, Expression2=None):
        """Alias for Modify"""
        arguments = [Type, Operator, Expression1, Expression2]
        return self.Modify(*arguments)


class FormatConditions:

    def __init__(self, formatconditions=None):
        self.com_object= formatconditions

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Type=None, Operator=None, Expression1=None, Expression2=None):
        arguments = com_arguments([unwrap(a) for a in [Type, Operator, Expression1, Expression2]])
        return FormatCondition(self.com_object.Add(*arguments))

    def add(self, Type=None, Operator=None, Expression1=None, Expression2=None):
        """Alias for Add"""
        arguments = [Type, Operator, Expression1, Expression2]
        return self.Add(*arguments)

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class Forms:

    def __init__(self, forms=None):
        self.com_object= forms

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class GroupLevel:

    def __init__(self, grouplevel=None):
        self.com_object= grouplevel

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ControlSource(self):
        return self.com_object.ControlSource

    @ControlSource.setter
    def ControlSource(self, value):
        self.com_object.ControlSource = value

    @property
    def controlsource(self):
        """Alias for ControlSource"""
        return self.ControlSource

    @controlsource.setter
    def controlsource(self, value):
        """Alias for ControlSource.setter"""
        self.ControlSource = value

    @property
    def control_source(self):
        """Alias for ControlSource"""
        return self.ControlSource

    @control_source.setter
    def control_source(self, value):
        """Alias for ControlSource.setter"""
        self.ControlSource = value

    @property
    def GroupFooter(self):
        return self.com_object.GroupFooter

    @GroupFooter.setter
    def GroupFooter(self, value):
        self.com_object.GroupFooter = value

    @property
    def groupfooter(self):
        """Alias for GroupFooter"""
        return self.GroupFooter

    @groupfooter.setter
    def groupfooter(self, value):
        """Alias for GroupFooter.setter"""
        self.GroupFooter = value

    @property
    def group_footer(self):
        """Alias for GroupFooter"""
        return self.GroupFooter

    @group_footer.setter
    def group_footer(self, value):
        """Alias for GroupFooter.setter"""
        self.GroupFooter = value

    @property
    def GroupHeader(self):
        return self.com_object.GroupHeader

    @GroupHeader.setter
    def GroupHeader(self, value):
        self.com_object.GroupHeader = value

    @property
    def groupheader(self):
        """Alias for GroupHeader"""
        return self.GroupHeader

    @groupheader.setter
    def groupheader(self, value):
        """Alias for GroupHeader.setter"""
        self.GroupHeader = value

    @property
    def group_header(self):
        """Alias for GroupHeader"""
        return self.GroupHeader

    @group_header.setter
    def group_header(self, value):
        """Alias for GroupHeader.setter"""
        self.GroupHeader = value

    @property
    def GroupInterval(self):
        return self.com_object.GroupInterval

    @GroupInterval.setter
    def GroupInterval(self, value):
        self.com_object.GroupInterval = value

    @property
    def groupinterval(self):
        """Alias for GroupInterval"""
        return self.GroupInterval

    @groupinterval.setter
    def groupinterval(self, value):
        """Alias for GroupInterval.setter"""
        self.GroupInterval = value

    @property
    def group_interval(self):
        """Alias for GroupInterval"""
        return self.GroupInterval

    @group_interval.setter
    def group_interval(self, value):
        """Alias for GroupInterval.setter"""
        self.GroupInterval = value

    @property
    def GroupOn(self):
        return self.com_object.GroupOn

    @GroupOn.setter
    def GroupOn(self, value):
        self.com_object.GroupOn = value

    @property
    def groupon(self):
        """Alias for GroupOn"""
        return self.GroupOn

    @groupon.setter
    def groupon(self, value):
        """Alias for GroupOn.setter"""
        self.GroupOn = value

    @property
    def group_on(self):
        """Alias for GroupOn"""
        return self.GroupOn

    @group_on.setter
    def group_on(self, value):
        """Alias for GroupOn.setter"""
        self.GroupOn = value

    @property
    def KeepTogether(self):
        return self.com_object.KeepTogether

    @KeepTogether.setter
    def KeepTogether(self, value):
        self.com_object.KeepTogether = value

    @property
    def keeptogether(self):
        """Alias for KeepTogether"""
        return self.KeepTogether

    @keeptogether.setter
    def keeptogether(self, value):
        """Alias for KeepTogether.setter"""
        self.KeepTogether = value

    @property
    def keep_together(self):
        """Alias for KeepTogether"""
        return self.KeepTogether

    @keep_together.setter
    def keep_together(self, value):
        """Alias for KeepTogether.setter"""
        self.KeepTogether = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def SortOrder(self):
        return self.com_object.SortOrder

    @SortOrder.setter
    def SortOrder(self, value):
        self.com_object.SortOrder = value

    @property
    def sortorder(self):
        """Alias for SortOrder"""
        return self.SortOrder

    @sortorder.setter
    def sortorder(self, value):
        """Alias for SortOrder.setter"""
        self.SortOrder = value

    @property
    def sort_order(self):
        """Alias for SortOrder"""
        return self.SortOrder

    @sort_order.setter
    def sort_order(self, value):
        """Alias for SortOrder.setter"""
        self.SortOrder = value


class Hyperlink:

    def __init__(self, hyperlink=None):
        self.com_object= hyperlink

    @property
    def Address(self):
        return self.com_object.Address

    @Address.setter
    def Address(self, value):
        self.com_object.Address = value

    @property
    def address(self):
        """Alias for Address"""
        return self.Address

    @address.setter
    def address(self, value):
        """Alias for Address.setter"""
        self.Address = value

    @property
    def EmailSubject(self):
        return self.com_object.EmailSubject

    @EmailSubject.setter
    def EmailSubject(self, value):
        self.com_object.EmailSubject = value

    @property
    def emailsubject(self):
        """Alias for EmailSubject"""
        return self.EmailSubject

    @emailsubject.setter
    def emailsubject(self, value):
        """Alias for EmailSubject.setter"""
        self.EmailSubject = value

    @property
    def email_subject(self):
        """Alias for EmailSubject"""
        return self.EmailSubject

    @email_subject.setter
    def email_subject(self, value):
        """Alias for EmailSubject.setter"""
        self.EmailSubject = value

    @property
    def ScreenTip(self):
        return self.com_object.ScreenTip

    @ScreenTip.setter
    def ScreenTip(self, value):
        self.com_object.ScreenTip = value

    @property
    def screentip(self):
        """Alias for ScreenTip"""
        return self.ScreenTip

    @screentip.setter
    def screentip(self, value):
        """Alias for ScreenTip.setter"""
        self.ScreenTip = value

    @property
    def screen_tip(self):
        """Alias for ScreenTip"""
        return self.ScreenTip

    @screen_tip.setter
    def screen_tip(self, value):
        """Alias for ScreenTip.setter"""
        self.ScreenTip = value

    @property
    def SubAddress(self):
        return self.com_object.SubAddress

    @SubAddress.setter
    def SubAddress(self, value):
        self.com_object.SubAddress = value

    @property
    def subaddress(self):
        """Alias for SubAddress"""
        return self.SubAddress

    @subaddress.setter
    def subaddress(self, value):
        """Alias for SubAddress.setter"""
        self.SubAddress = value

    @property
    def sub_address(self):
        """Alias for SubAddress"""
        return self.SubAddress

    @sub_address.setter
    def sub_address(self, value):
        """Alias for SubAddress.setter"""
        self.SubAddress = value

    @property
    def TextToDisplay(self):
        return self.com_object.TextToDisplay

    @TextToDisplay.setter
    def TextToDisplay(self, value):
        self.com_object.TextToDisplay = value

    @property
    def texttodisplay(self):
        """Alias for TextToDisplay"""
        return self.TextToDisplay

    @texttodisplay.setter
    def texttodisplay(self, value):
        """Alias for TextToDisplay.setter"""
        self.TextToDisplay = value

    @property
    def text_to_display(self):
        """Alias for TextToDisplay"""
        return self.TextToDisplay

    @text_to_display.setter
    def text_to_display(self, value):
        """Alias for TextToDisplay.setter"""
        self.TextToDisplay = value

    def AddToFavorites(self):
        return self.com_object.AddToFavorites()

    def addtofavorites(self):
        """Alias for AddToFavorites"""
        return self.AddToFavorites()

    def add_to_favorites(self):
        """Alias for AddToFavorites"""
        return self.AddToFavorites()

    def CreateNewDocument(self, FileName=None, EditNow=None, Overwrite=None):
        arguments = com_arguments([unwrap(a) for a in [FileName, EditNow, Overwrite]])
        return self.com_object.CreateNewDocument(*arguments)

    def createnewdocument(self, FileName=None, EditNow=None, Overwrite=None):
        """Alias for CreateNewDocument"""
        arguments = [FileName, EditNow, Overwrite]
        return self.CreateNewDocument(*arguments)

    def create_new_document(self, FileName=None, EditNow=None, Overwrite=None):
        """Alias for CreateNewDocument"""
        arguments = [FileName, EditNow, Overwrite]
        return self.CreateNewDocument(*arguments)

    def Follow(self, NewWindow=None, AddHistory=None, ExtraInfo=None, Method=None, HeaderInfo=None):
        arguments = com_arguments([unwrap(a) for a in [NewWindow, AddHistory, ExtraInfo, Method, HeaderInfo]])
        self.com_object.Follow(*arguments)

    def follow(self, NewWindow=None, AddHistory=None, ExtraInfo=None, Method=None, HeaderInfo=None):
        """Alias for Follow"""
        arguments = [NewWindow, AddHistory, ExtraInfo, Method, HeaderInfo]
        return self.Follow(*arguments)


class Image:

    def __init__(self, image=None):
        self.com_object= image

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BackShade(self):
        return self.com_object.BackShade

    @BackShade.setter
    def BackShade(self, value):
        self.com_object.BackShade = value

    @property
    def backshade(self):
        """Alias for BackShade"""
        return self.BackShade

    @backshade.setter
    def backshade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def back_shade(self):
        """Alias for BackShade"""
        return self.BackShade

    @back_shade.setter
    def back_shade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def BackStyle(self):
        return self.com_object.BackStyle

    @BackStyle.setter
    def BackStyle(self, value):
        self.com_object.BackStyle = value

    @property
    def backstyle(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @backstyle.setter
    def backstyle(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def back_style(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @back_style.setter
    def back_style(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def BackThemeColorIndex(self):
        return self.com_object.BackThemeColorIndex

    @BackThemeColorIndex.setter
    def BackThemeColorIndex(self, value):
        self.com_object.BackThemeColorIndex = value

    @property
    def backthemecolorindex(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @backthemecolorindex.setter
    def backthemecolorindex(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def back_theme_color_index(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @back_theme_color_index.setter
    def back_theme_color_index(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def BackTint(self):
        return self.com_object.BackTint

    @BackTint.setter
    def BackTint(self, value):
        self.com_object.BackTint = value

    @property
    def backtint(self):
        """Alias for BackTint"""
        return self.BackTint

    @backtint.setter
    def backtint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def back_tint(self):
        """Alias for BackTint"""
        return self.BackTint

    @back_tint.setter
    def back_tint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def BorderColor(self):
        return self.com_object.BorderColor

    @BorderColor.setter
    def BorderColor(self, value):
        self.com_object.BorderColor = value

    @property
    def bordercolor(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @bordercolor.setter
    def bordercolor(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def border_color(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @border_color.setter
    def border_color(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def BorderShade(self):
        return self.com_object.BorderShade

    @BorderShade.setter
    def BorderShade(self, value):
        self.com_object.BorderShade = value

    @property
    def bordershade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @bordershade.setter
    def bordershade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def border_shade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @border_shade.setter
    def border_shade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def BorderStyle(self):
        return self.com_object.BorderStyle

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def BorderThemeColorIndex(self):
        return self.com_object.BorderThemeColorIndex

    @BorderThemeColorIndex.setter
    def BorderThemeColorIndex(self, value):
        self.com_object.BorderThemeColorIndex = value

    @property
    def borderthemecolorindex(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @borderthemecolorindex.setter
    def borderthemecolorindex(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def border_theme_color_index(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @border_theme_color_index.setter
    def border_theme_color_index(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def BorderTint(self):
        return self.com_object.BorderTint

    @BorderTint.setter
    def BorderTint(self, value):
        self.com_object.BorderTint = value

    @property
    def bordertint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @bordertint.setter
    def bordertint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def border_tint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @border_tint.setter
    def border_tint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def BorderWidth(self):
        return self.com_object.BorderWidth

    @BorderWidth.setter
    def BorderWidth(self, value):
        self.com_object.BorderWidth = value

    @property
    def borderwidth(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @borderwidth.setter
    def borderwidth(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def border_width(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @border_width.setter
    def border_width(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def BottomPadding(self):
        return self.com_object.BottomPadding

    @BottomPadding.setter
    def BottomPadding(self, value):
        self.com_object.BottomPadding = value

    @property
    def bottompadding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottompadding.setter
    def bottompadding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def bottom_padding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottom_padding.setter
    def bottom_padding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def Controls(self):
        return Controls(self.com_object.Controls)

    @property
    def controls(self):
        """Alias for Controls"""
        return self.Controls

    @property
    def ControlTipText(self):
        return self.com_object.ControlTipText

    @ControlTipText.setter
    def ControlTipText(self, value):
        self.com_object.ControlTipText = value

    @property
    def controltiptext(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @controltiptext.setter
    def controltiptext(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def control_tip_text(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @control_tip_text.setter
    def control_tip_text(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def ControlType(self):
        return self.com_object.ControlType

    @ControlType.setter
    def ControlType(self, value):
        self.com_object.ControlType = value

    @property
    def controltype(self):
        """Alias for ControlType"""
        return self.ControlType

    @controltype.setter
    def controltype(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def control_type(self):
        """Alias for ControlType"""
        return self.ControlType

    @control_type.setter
    def control_type(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def DisplayWhen(self):
        return self.com_object.DisplayWhen

    @DisplayWhen.setter
    def DisplayWhen(self, value):
        self.com_object.DisplayWhen = value

    @property
    def displaywhen(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @displaywhen.setter
    def displaywhen(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def display_when(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @display_when.setter
    def display_when(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def GridlineColor(self):
        return self.com_object.GridlineColor

    @GridlineColor.setter
    def GridlineColor(self, value):
        self.com_object.GridlineColor = value

    @property
    def gridlinecolor(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridlinecolor.setter
    def gridlinecolor(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def gridline_color(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridline_color.setter
    def gridline_color(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def GridlineShade(self):
        return self.com_object.GridlineShade

    @GridlineShade.setter
    def GridlineShade(self, value):
        self.com_object.GridlineShade = value

    @property
    def gridlineshade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridlineshade.setter
    def gridlineshade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def gridline_shade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridline_shade.setter
    def gridline_shade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def GridlineStyleBottom(self):
        return self.com_object.GridlineStyleBottom

    @GridlineStyleBottom.setter
    def GridlineStyleBottom(self, value):
        self.com_object.GridlineStyleBottom = value

    @property
    def gridlinestylebottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridlinestylebottom.setter
    def gridlinestylebottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def gridline_style_bottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridline_style_bottom.setter
    def gridline_style_bottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def GridlineStyleLeft(self):
        return self.com_object.GridlineStyleLeft

    @GridlineStyleLeft.setter
    def GridlineStyleLeft(self, value):
        self.com_object.GridlineStyleLeft = value

    @property
    def gridlinestyleleft(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridlinestyleleft.setter
    def gridlinestyleleft(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def gridline_style_left(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridline_style_left.setter
    def gridline_style_left(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def GridlineStyleRight(self):
        return self.com_object.GridlineStyleRight

    @GridlineStyleRight.setter
    def GridlineStyleRight(self, value):
        self.com_object.GridlineStyleRight = value

    @property
    def gridlinestyleright(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridlinestyleright.setter
    def gridlinestyleright(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def gridline_style_right(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridline_style_right.setter
    def gridline_style_right(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def GridlineStyleTop(self):
        return self.com_object.GridlineStyleTop

    @GridlineStyleTop.setter
    def GridlineStyleTop(self, value):
        self.com_object.GridlineStyleTop = value

    @property
    def gridlinestyletop(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridlinestyletop.setter
    def gridlinestyletop(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def gridline_style_top(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridline_style_top.setter
    def gridline_style_top(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def GridlineThemeColorIndex(self):
        return self.com_object.GridlineThemeColorIndex

    @GridlineThemeColorIndex.setter
    def GridlineThemeColorIndex(self, value):
        self.com_object.GridlineThemeColorIndex = value

    @property
    def gridlinethemecolorindex(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridlinethemecolorindex.setter
    def gridlinethemecolorindex(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def gridline_theme_color_index(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridline_theme_color_index.setter
    def gridline_theme_color_index(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def GridlineTint(self):
        return self.com_object.GridlineTint

    @GridlineTint.setter
    def GridlineTint(self, value):
        self.com_object.GridlineTint = value

    @property
    def gridlinetint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridlinetint.setter
    def gridlinetint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def gridline_tint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridline_tint.setter
    def gridline_tint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def GridlineWidthBottom(self):
        return self.com_object.GridlineWidthBottom

    @GridlineWidthBottom.setter
    def GridlineWidthBottom(self, value):
        self.com_object.GridlineWidthBottom = value

    @property
    def gridlinewidthbottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridlinewidthbottom.setter
    def gridlinewidthbottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def gridline_width_bottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridline_width_bottom.setter
    def gridline_width_bottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def GridlineWidthLeft(self):
        return self.com_object.GridlineWidthLeft

    @GridlineWidthLeft.setter
    def GridlineWidthLeft(self, value):
        self.com_object.GridlineWidthLeft = value

    @property
    def gridlinewidthleft(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridlinewidthleft.setter
    def gridlinewidthleft(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def gridline_width_left(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridline_width_left.setter
    def gridline_width_left(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def GridlineWidthRight(self):
        return self.com_object.GridlineWidthRight

    @GridlineWidthRight.setter
    def GridlineWidthRight(self, value):
        self.com_object.GridlineWidthRight = value

    @property
    def gridlinewidthright(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridlinewidthright.setter
    def gridlinewidthright(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def gridline_width_right(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridline_width_right.setter
    def gridline_width_right(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def GridlineWidthTop(self):
        return self.com_object.GridlineWidthTop

    @GridlineWidthTop.setter
    def GridlineWidthTop(self, value):
        self.com_object.GridlineWidthTop = value

    @property
    def gridlinewidthtop(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridlinewidthtop.setter
    def gridlinewidthtop(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def gridline_width_top(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridline_width_top.setter
    def gridline_width_top(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HelpContextId(self):
        return self.com_object.HelpContextId

    @HelpContextId.setter
    def HelpContextId(self, value):
        self.com_object.HelpContextId = value

    @property
    def helpcontextid(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @helpcontextid.setter
    def helpcontextid(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def help_context_id(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @help_context_id.setter
    def help_context_id(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def Hyperlink(self):
        return self.com_object.Hyperlink

    @property
    def hyperlink(self):
        """Alias for Hyperlink"""
        return self.Hyperlink

    @property
    def HyperlinkAddress(self):
        return self.com_object.HyperlinkAddress

    @HyperlinkAddress.setter
    def HyperlinkAddress(self, value):
        self.com_object.HyperlinkAddress = value

    @property
    def hyperlinkaddress(self):
        """Alias for HyperlinkAddress"""
        return self.HyperlinkAddress

    @hyperlinkaddress.setter
    def hyperlinkaddress(self, value):
        """Alias for HyperlinkAddress.setter"""
        self.HyperlinkAddress = value

    @property
    def hyperlink_address(self):
        """Alias for HyperlinkAddress"""
        return self.HyperlinkAddress

    @hyperlink_address.setter
    def hyperlink_address(self, value):
        """Alias for HyperlinkAddress.setter"""
        self.HyperlinkAddress = value

    @property
    def HyperlinkSubAddress(self):
        return self.com_object.HyperlinkSubAddress

    @HyperlinkSubAddress.setter
    def HyperlinkSubAddress(self, value):
        self.com_object.HyperlinkSubAddress = value

    @property
    def hyperlinksubaddress(self):
        """Alias for HyperlinkSubAddress"""
        return self.HyperlinkSubAddress

    @hyperlinksubaddress.setter
    def hyperlinksubaddress(self, value):
        """Alias for HyperlinkSubAddress.setter"""
        self.HyperlinkSubAddress = value

    @property
    def hyperlink_sub_address(self):
        """Alias for HyperlinkSubAddress"""
        return self.HyperlinkSubAddress

    @hyperlink_sub_address.setter
    def hyperlink_sub_address(self, value):
        """Alias for HyperlinkSubAddress.setter"""
        self.HyperlinkSubAddress = value

    @property
    def ImageHeight(self):
        return self.com_object.ImageHeight

    @ImageHeight.setter
    def ImageHeight(self, value):
        self.com_object.ImageHeight = value

    @property
    def imageheight(self):
        """Alias for ImageHeight"""
        return self.ImageHeight

    @imageheight.setter
    def imageheight(self, value):
        """Alias for ImageHeight.setter"""
        self.ImageHeight = value

    @property
    def image_height(self):
        """Alias for ImageHeight"""
        return self.ImageHeight

    @image_height.setter
    def image_height(self, value):
        """Alias for ImageHeight.setter"""
        self.ImageHeight = value

    @property
    def ImageWidth(self):
        return self.com_object.ImageWidth

    @ImageWidth.setter
    def ImageWidth(self, value):
        self.com_object.ImageWidth = value

    @property
    def imagewidth(self):
        """Alias for ImageWidth"""
        return self.ImageWidth

    @imagewidth.setter
    def imagewidth(self, value):
        """Alias for ImageWidth.setter"""
        self.ImageWidth = value

    @property
    def image_width(self):
        """Alias for ImageWidth"""
        return self.ImageWidth

    @image_width.setter
    def image_width(self, value):
        """Alias for ImageWidth.setter"""
        self.ImageWidth = value

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def IsVisible(self):
        return self.com_object.IsVisible

    @IsVisible.setter
    def IsVisible(self, value):
        self.com_object.IsVisible = value

    @property
    def isvisible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @isvisible.setter
    def isvisible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def is_visible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @is_visible.setter
    def is_visible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def Layout(self):
        return AcLayoutType(self.com_object.Layout)

    @property
    def layout(self):
        """Alias for Layout"""
        return self.Layout

    @property
    def LayoutID(self):
        return self.com_object.LayoutID

    @property
    def layoutid(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def layout_i_d(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def LeftPadding(self):
        return self.com_object.LeftPadding

    @LeftPadding.setter
    def LeftPadding(self, value):
        self.com_object.LeftPadding = value

    @property
    def leftpadding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @leftpadding.setter
    def leftpadding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def left_padding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @left_padding.setter
    def left_padding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def ObjectPalette(self):
        return self.com_object.ObjectPalette

    @ObjectPalette.setter
    def ObjectPalette(self, value):
        self.com_object.ObjectPalette = value

    @property
    def objectpalette(self):
        """Alias for ObjectPalette"""
        return self.ObjectPalette

    @objectpalette.setter
    def objectpalette(self, value):
        """Alias for ObjectPalette.setter"""
        self.ObjectPalette = value

    @property
    def object_palette(self):
        """Alias for ObjectPalette"""
        return self.ObjectPalette

    @object_palette.setter
    def object_palette(self, value):
        """Alias for ObjectPalette.setter"""
        self.ObjectPalette = value

    @property
    def OldBorderStyle(self):
        return self.com_object.OldBorderStyle

    @OldBorderStyle.setter
    def OldBorderStyle(self, value):
        self.com_object.OldBorderStyle = value

    @property
    def oldborderstyle(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @oldborderstyle.setter
    def oldborderstyle(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def old_border_style(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @old_border_style.setter
    def old_border_style(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def OldValue(self):
        return self.com_object.OldValue

    @property
    def oldvalue(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def old_value(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def OnClick(self):
        return self.com_object.OnClick

    @OnClick.setter
    def OnClick(self, value):
        self.com_object.OnClick = value

    @property
    def onclick(self):
        """Alias for OnClick"""
        return self.OnClick

    @onclick.setter
    def onclick(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def on_click(self):
        """Alias for OnClick"""
        return self.OnClick

    @on_click.setter
    def on_click(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def OnDblClick(self):
        return self.com_object.OnDblClick

    @OnDblClick.setter
    def OnDblClick(self, value):
        self.com_object.OnDblClick = value

    @property
    def ondblclick(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @ondblclick.setter
    def ondblclick(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def on_dbl_click(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @on_dbl_click.setter
    def on_dbl_click(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def OnMouseDown(self):
        return self.com_object.OnMouseDown

    @OnMouseDown.setter
    def OnMouseDown(self, value):
        self.com_object.OnMouseDown = value

    @property
    def onmousedown(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @onmousedown.setter
    def onmousedown(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def on_mouse_down(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @on_mouse_down.setter
    def on_mouse_down(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def OnMouseMove(self):
        return self.com_object.OnMouseMove

    @OnMouseMove.setter
    def OnMouseMove(self, value):
        self.com_object.OnMouseMove = value

    @property
    def onmousemove(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @onmousemove.setter
    def onmousemove(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def on_mouse_move(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @on_mouse_move.setter
    def on_mouse_move(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def OnMouseUp(self):
        return self.com_object.OnMouseUp

    @OnMouseUp.setter
    def OnMouseUp(self, value):
        self.com_object.OnMouseUp = value

    @property
    def onmouseup(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @onmouseup.setter
    def onmouseup(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def on_mouse_up(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @on_mouse_up.setter
    def on_mouse_up(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Picture(self):
        return self.com_object.Picture

    @Picture.setter
    def Picture(self, value):
        self.com_object.Picture = value

    @property
    def picture(self):
        """Alias for Picture"""
        return self.Picture

    @picture.setter
    def picture(self, value):
        """Alias for Picture.setter"""
        self.Picture = value

    @property
    def PictureAlignment(self):
        return self.com_object.PictureAlignment

    @PictureAlignment.setter
    def PictureAlignment(self, value):
        self.com_object.PictureAlignment = value

    @property
    def picturealignment(self):
        """Alias for PictureAlignment"""
        return self.PictureAlignment

    @picturealignment.setter
    def picturealignment(self, value):
        """Alias for PictureAlignment.setter"""
        self.PictureAlignment = value

    @property
    def picture_alignment(self):
        """Alias for PictureAlignment"""
        return self.PictureAlignment

    @picture_alignment.setter
    def picture_alignment(self, value):
        """Alias for PictureAlignment.setter"""
        self.PictureAlignment = value

    @property
    def PictureData(self):
        return self.com_object.PictureData

    @PictureData.setter
    def PictureData(self, value):
        self.com_object.PictureData = value

    @property
    def picturedata(self):
        """Alias for PictureData"""
        return self.PictureData

    @picturedata.setter
    def picturedata(self, value):
        """Alias for PictureData.setter"""
        self.PictureData = value

    @property
    def picture_data(self):
        """Alias for PictureData"""
        return self.PictureData

    @picture_data.setter
    def picture_data(self, value):
        """Alias for PictureData.setter"""
        self.PictureData = value

    @property
    def PictureTiling(self):
        return self.com_object.PictureTiling

    @PictureTiling.setter
    def PictureTiling(self, value):
        self.com_object.PictureTiling = value

    @property
    def picturetiling(self):
        """Alias for PictureTiling"""
        return self.PictureTiling

    @picturetiling.setter
    def picturetiling(self, value):
        """Alias for PictureTiling.setter"""
        self.PictureTiling = value

    @property
    def picture_tiling(self):
        """Alias for PictureTiling"""
        return self.PictureTiling

    @picture_tiling.setter
    def picture_tiling(self, value):
        """Alias for PictureTiling.setter"""
        self.PictureTiling = value

    @property
    def PictureType(self):
        return self.com_object.PictureType

    @PictureType.setter
    def PictureType(self, value):
        self.com_object.PictureType = value

    @property
    def picturetype(self):
        """Alias for PictureType"""
        return self.PictureType

    @picturetype.setter
    def picturetype(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def picture_type(self):
        """Alias for PictureType"""
        return self.PictureType

    @picture_type.setter
    def picture_type(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def RightPadding(self):
        return self.com_object.RightPadding

    @RightPadding.setter
    def RightPadding(self, value):
        self.com_object.RightPadding = value

    @property
    def rightpadding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @rightpadding.setter
    def rightpadding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def right_padding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @right_padding.setter
    def right_padding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def Section(self):
        return self.com_object.Section

    @Section.setter
    def Section(self, value):
        self.com_object.Section = value

    @property
    def section(self):
        """Alias for Section"""
        return self.Section

    @section.setter
    def section(self, value):
        """Alias for Section.setter"""
        self.Section = value

    @property
    def ShortcutMenuBar(self):
        return self.com_object.ShortcutMenuBar

    @ShortcutMenuBar.setter
    def ShortcutMenuBar(self, value):
        self.com_object.ShortcutMenuBar = value

    @property
    def shortcutmenubar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcutmenubar.setter
    def shortcutmenubar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def shortcut_menu_bar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcut_menu_bar.setter
    def shortcut_menu_bar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def SizeMode(self):
        return self.com_object.SizeMode

    @property
    def sizemode(self):
        """Alias for SizeMode"""
        return self.SizeMode

    @property
    def size_mode(self):
        """Alias for SizeMode"""
        return self.SizeMode

    @property
    def SpecialEffect(self):
        return self.com_object.SpecialEffect

    @SpecialEffect.setter
    def SpecialEffect(self, value):
        self.com_object.SpecialEffect = value

    @property
    def specialeffect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @specialeffect.setter
    def specialeffect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def special_effect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @special_effect.setter
    def special_effect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TopPadding(self):
        return self.com_object.TopPadding

    @TopPadding.setter
    def TopPadding(self, value):
        self.com_object.TopPadding = value

    @property
    def toppadding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @toppadding.setter
    def toppadding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def top_padding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @top_padding.setter
    def top_padding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def Requery(self):
        self.com_object.Requery()

    def requery(self):
        """Alias for Requery"""
        return self.Requery()

    def SetFocus(self):
        return self.com_object.SetFocus()

    def setfocus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def set_focus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()


class ImportExportSpecification:

    def __init__(self, importexportspecification=None):
        self.com_object= importexportspecification

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Description(self):
        return self.com_object.Description

    @Description.setter
    def Description(self, value):
        self.com_object.Description = value

    @property
    def description(self):
        """Alias for Description"""
        return self.Description

    @description.setter
    def description(self, value):
        """Alias for Description.setter"""
        self.Description = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def XML(self):
        return self.com_object.XML

    @XML.setter
    def XML(self, value):
        self.com_object.XML = value

    @property
    def xml(self):
        """Alias for XML"""
        return self.XML

    @xml.setter
    def xml(self, value):
        """Alias for XML.setter"""
        self.XML = value

    @property
    def x_m_l(self):
        """Alias for XML"""
        return self.XML

    @x_m_l.setter
    def x_m_l(self, value):
        """Alias for XML.setter"""
        self.XML = value

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()

    def Execute(self, OverwritePrompt=None):
        arguments = com_arguments([unwrap(a) for a in [OverwritePrompt]])
        self.com_object.Execute(*arguments)

    def execute(self, OverwritePrompt=None):
        """Alias for Execute"""
        arguments = [OverwritePrompt]
        return self.Execute(*arguments)


class ImportExportSpecifications:

    def __init__(self, importexportspecifications=None):
        self.com_object= importexportspecifications

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, SpecificationDefinition=None):
        arguments = com_arguments([unwrap(a) for a in [Name, SpecificationDefinition]])
        return ImportExportSpecification(self.com_object.Add(*arguments))

    def add(self, Name=None, SpecificationDefinition=None):
        """Alias for Add"""
        arguments = [Name, SpecificationDefinition]
        return self.Add(*arguments)


class Label:

    def __init__(self, label=None):
        self.com_object= label

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BackShade(self):
        return self.com_object.BackShade

    @BackShade.setter
    def BackShade(self, value):
        self.com_object.BackShade = value

    @property
    def backshade(self):
        """Alias for BackShade"""
        return self.BackShade

    @backshade.setter
    def backshade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def back_shade(self):
        """Alias for BackShade"""
        return self.BackShade

    @back_shade.setter
    def back_shade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def BackStyle(self):
        return self.com_object.BackStyle

    @BackStyle.setter
    def BackStyle(self, value):
        self.com_object.BackStyle = value

    @property
    def backstyle(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @backstyle.setter
    def backstyle(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def back_style(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @back_style.setter
    def back_style(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def BackThemeColorIndex(self):
        return self.com_object.BackThemeColorIndex

    @BackThemeColorIndex.setter
    def BackThemeColorIndex(self, value):
        self.com_object.BackThemeColorIndex = value

    @property
    def backthemecolorindex(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @backthemecolorindex.setter
    def backthemecolorindex(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def back_theme_color_index(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @back_theme_color_index.setter
    def back_theme_color_index(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def BackTint(self):
        return self.com_object.BackTint

    @BackTint.setter
    def BackTint(self, value):
        self.com_object.BackTint = value

    @property
    def backtint(self):
        """Alias for BackTint"""
        return self.BackTint

    @backtint.setter
    def backtint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def back_tint(self):
        """Alias for BackTint"""
        return self.BackTint

    @back_tint.setter
    def back_tint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def BorderColor(self):
        return self.com_object.BorderColor

    @BorderColor.setter
    def BorderColor(self, value):
        self.com_object.BorderColor = value

    @property
    def bordercolor(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @bordercolor.setter
    def bordercolor(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def border_color(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @border_color.setter
    def border_color(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def BorderShade(self):
        return self.com_object.BorderShade

    @BorderShade.setter
    def BorderShade(self, value):
        self.com_object.BorderShade = value

    @property
    def bordershade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @bordershade.setter
    def bordershade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def border_shade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @border_shade.setter
    def border_shade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def BorderStyle(self):
        return self.com_object.BorderStyle

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def BorderThemeColorIndex(self):
        return self.com_object.BorderThemeColorIndex

    @BorderThemeColorIndex.setter
    def BorderThemeColorIndex(self, value):
        self.com_object.BorderThemeColorIndex = value

    @property
    def borderthemecolorindex(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @borderthemecolorindex.setter
    def borderthemecolorindex(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def border_theme_color_index(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @border_theme_color_index.setter
    def border_theme_color_index(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def BorderTint(self):
        return self.com_object.BorderTint

    @BorderTint.setter
    def BorderTint(self, value):
        self.com_object.BorderTint = value

    @property
    def bordertint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @bordertint.setter
    def bordertint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def border_tint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @border_tint.setter
    def border_tint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def BorderWidth(self):
        return self.com_object.BorderWidth

    @BorderWidth.setter
    def BorderWidth(self, value):
        self.com_object.BorderWidth = value

    @property
    def borderwidth(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @borderwidth.setter
    def borderwidth(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def border_width(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @border_width.setter
    def border_width(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def BottomMargin(self):
        return self.com_object.BottomMargin

    @BottomMargin.setter
    def BottomMargin(self, value):
        self.com_object.BottomMargin = value

    @property
    def bottommargin(self):
        """Alias for BottomMargin"""
        return self.BottomMargin

    @bottommargin.setter
    def bottommargin(self, value):
        """Alias for BottomMargin.setter"""
        self.BottomMargin = value

    @property
    def bottom_margin(self):
        """Alias for BottomMargin"""
        return self.BottomMargin

    @bottom_margin.setter
    def bottom_margin(self, value):
        """Alias for BottomMargin.setter"""
        self.BottomMargin = value

    @property
    def BottomPadding(self):
        return self.com_object.BottomPadding

    @BottomPadding.setter
    def BottomPadding(self, value):
        self.com_object.BottomPadding = value

    @property
    def bottompadding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottompadding.setter
    def bottompadding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def bottom_padding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottom_padding.setter
    def bottom_padding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    @property
    def ControlTipText(self):
        return self.com_object.ControlTipText

    @ControlTipText.setter
    def ControlTipText(self, value):
        self.com_object.ControlTipText = value

    @property
    def controltiptext(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @controltiptext.setter
    def controltiptext(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def control_tip_text(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @control_tip_text.setter
    def control_tip_text(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def ControlType(self):
        return self.com_object.ControlType

    @ControlType.setter
    def ControlType(self, value):
        self.com_object.ControlType = value

    @property
    def controltype(self):
        """Alias for ControlType"""
        return self.ControlType

    @controltype.setter
    def controltype(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def control_type(self):
        """Alias for ControlType"""
        return self.ControlType

    @control_type.setter
    def control_type(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def DisplayWhen(self):
        return self.com_object.DisplayWhen

    @DisplayWhen.setter
    def DisplayWhen(self, value):
        self.com_object.DisplayWhen = value

    @property
    def displaywhen(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @displaywhen.setter
    def displaywhen(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def display_when(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @display_when.setter
    def display_when(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def FontBold(self):
        return self.com_object.FontBold

    @property
    def fontbold(self):
        """Alias for FontBold"""
        return self.FontBold

    @property
    def font_bold(self):
        """Alias for FontBold"""
        return self.FontBold

    @property
    def FontItalic(self):
        return self.com_object.FontItalic

    @property
    def fontitalic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @property
    def font_italic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @property
    def FontName(self):
        return self.com_object.FontName

    @property
    def fontname(self):
        """Alias for FontName"""
        return self.FontName

    @property
    def font_name(self):
        """Alias for FontName"""
        return self.FontName

    @property
    def FontSize(self):
        return self.com_object.FontSize

    @property
    def fontsize(self):
        """Alias for FontSize"""
        return self.FontSize

    @property
    def font_size(self):
        """Alias for FontSize"""
        return self.FontSize

    @property
    def FontUnderline(self):
        return self.com_object.FontUnderline

    @property
    def fontunderline(self):
        """Alias for FontUnderline"""
        return self.FontUnderline

    @property
    def font_underline(self):
        """Alias for FontUnderline"""
        return self.FontUnderline

    @property
    def FontWeight(self):
        return self.com_object.FontWeight

    @FontWeight.setter
    def FontWeight(self, value):
        self.com_object.FontWeight = value

    @property
    def fontweight(self):
        """Alias for FontWeight"""
        return self.FontWeight

    @fontweight.setter
    def fontweight(self, value):
        """Alias for FontWeight.setter"""
        self.FontWeight = value

    @property
    def font_weight(self):
        """Alias for FontWeight"""
        return self.FontWeight

    @font_weight.setter
    def font_weight(self, value):
        """Alias for FontWeight.setter"""
        self.FontWeight = value

    @property
    def ForeColor(self):
        return self.com_object.ForeColor

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def ForeShade(self):
        return self.com_object.ForeShade

    @ForeShade.setter
    def ForeShade(self, value):
        self.com_object.ForeShade = value

    @property
    def foreshade(self):
        """Alias for ForeShade"""
        return self.ForeShade

    @foreshade.setter
    def foreshade(self, value):
        """Alias for ForeShade.setter"""
        self.ForeShade = value

    @property
    def fore_shade(self):
        """Alias for ForeShade"""
        return self.ForeShade

    @fore_shade.setter
    def fore_shade(self, value):
        """Alias for ForeShade.setter"""
        self.ForeShade = value

    @property
    def ForeThemeColorIndex(self):
        return self.com_object.ForeThemeColorIndex

    @ForeThemeColorIndex.setter
    def ForeThemeColorIndex(self, value):
        self.com_object.ForeThemeColorIndex = value

    @property
    def forethemecolorindex(self):
        """Alias for ForeThemeColorIndex"""
        return self.ForeThemeColorIndex

    @forethemecolorindex.setter
    def forethemecolorindex(self, value):
        """Alias for ForeThemeColorIndex.setter"""
        self.ForeThemeColorIndex = value

    @property
    def fore_theme_color_index(self):
        """Alias for ForeThemeColorIndex"""
        return self.ForeThemeColorIndex

    @fore_theme_color_index.setter
    def fore_theme_color_index(self, value):
        """Alias for ForeThemeColorIndex.setter"""
        self.ForeThemeColorIndex = value

    @property
    def ForeTint(self):
        return self.com_object.ForeTint

    @ForeTint.setter
    def ForeTint(self, value):
        self.com_object.ForeTint = value

    @property
    def foretint(self):
        """Alias for ForeTint"""
        return self.ForeTint

    @foretint.setter
    def foretint(self, value):
        """Alias for ForeTint.setter"""
        self.ForeTint = value

    @property
    def fore_tint(self):
        """Alias for ForeTint"""
        return self.ForeTint

    @fore_tint.setter
    def fore_tint(self, value):
        """Alias for ForeTint.setter"""
        self.ForeTint = value

    @property
    def GridlineColor(self):
        return self.com_object.GridlineColor

    @GridlineColor.setter
    def GridlineColor(self, value):
        self.com_object.GridlineColor = value

    @property
    def gridlinecolor(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridlinecolor.setter
    def gridlinecolor(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def gridline_color(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridline_color.setter
    def gridline_color(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def GridlineShade(self):
        return self.com_object.GridlineShade

    @GridlineShade.setter
    def GridlineShade(self, value):
        self.com_object.GridlineShade = value

    @property
    def gridlineshade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridlineshade.setter
    def gridlineshade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def gridline_shade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridline_shade.setter
    def gridline_shade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def GridlineStyleBottom(self):
        return self.com_object.GridlineStyleBottom

    @GridlineStyleBottom.setter
    def GridlineStyleBottom(self, value):
        self.com_object.GridlineStyleBottom = value

    @property
    def gridlinestylebottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridlinestylebottom.setter
    def gridlinestylebottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def gridline_style_bottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridline_style_bottom.setter
    def gridline_style_bottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def GridlineStyleLeft(self):
        return self.com_object.GridlineStyleLeft

    @GridlineStyleLeft.setter
    def GridlineStyleLeft(self, value):
        self.com_object.GridlineStyleLeft = value

    @property
    def gridlinestyleleft(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridlinestyleleft.setter
    def gridlinestyleleft(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def gridline_style_left(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridline_style_left.setter
    def gridline_style_left(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def GridlineStyleRight(self):
        return self.com_object.GridlineStyleRight

    @GridlineStyleRight.setter
    def GridlineStyleRight(self, value):
        self.com_object.GridlineStyleRight = value

    @property
    def gridlinestyleright(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridlinestyleright.setter
    def gridlinestyleright(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def gridline_style_right(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridline_style_right.setter
    def gridline_style_right(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def GridlineStyleTop(self):
        return self.com_object.GridlineStyleTop

    @GridlineStyleTop.setter
    def GridlineStyleTop(self, value):
        self.com_object.GridlineStyleTop = value

    @property
    def gridlinestyletop(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridlinestyletop.setter
    def gridlinestyletop(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def gridline_style_top(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridline_style_top.setter
    def gridline_style_top(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def GridlineThemeColorIndex(self):
        return self.com_object.GridlineThemeColorIndex

    @GridlineThemeColorIndex.setter
    def GridlineThemeColorIndex(self, value):
        self.com_object.GridlineThemeColorIndex = value

    @property
    def gridlinethemecolorindex(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridlinethemecolorindex.setter
    def gridlinethemecolorindex(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def gridline_theme_color_index(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridline_theme_color_index.setter
    def gridline_theme_color_index(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def GridlineTint(self):
        return self.com_object.GridlineTint

    @GridlineTint.setter
    def GridlineTint(self, value):
        self.com_object.GridlineTint = value

    @property
    def gridlinetint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridlinetint.setter
    def gridlinetint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def gridline_tint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridline_tint.setter
    def gridline_tint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def GridlineWidthBottom(self):
        return self.com_object.GridlineWidthBottom

    @GridlineWidthBottom.setter
    def GridlineWidthBottom(self, value):
        self.com_object.GridlineWidthBottom = value

    @property
    def gridlinewidthbottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridlinewidthbottom.setter
    def gridlinewidthbottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def gridline_width_bottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridline_width_bottom.setter
    def gridline_width_bottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def GridlineWidthLeft(self):
        return self.com_object.GridlineWidthLeft

    @GridlineWidthLeft.setter
    def GridlineWidthLeft(self, value):
        self.com_object.GridlineWidthLeft = value

    @property
    def gridlinewidthleft(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridlinewidthleft.setter
    def gridlinewidthleft(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def gridline_width_left(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridline_width_left.setter
    def gridline_width_left(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def GridlineWidthRight(self):
        return self.com_object.GridlineWidthRight

    @GridlineWidthRight.setter
    def GridlineWidthRight(self, value):
        self.com_object.GridlineWidthRight = value

    @property
    def gridlinewidthright(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridlinewidthright.setter
    def gridlinewidthright(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def gridline_width_right(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridline_width_right.setter
    def gridline_width_right(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def GridlineWidthTop(self):
        return self.com_object.GridlineWidthTop

    @GridlineWidthTop.setter
    def GridlineWidthTop(self, value):
        self.com_object.GridlineWidthTop = value

    @property
    def gridlinewidthtop(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridlinewidthtop.setter
    def gridlinewidthtop(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def gridline_width_top(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridline_width_top.setter
    def gridline_width_top(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HelpContextId(self):
        return self.com_object.HelpContextId

    @HelpContextId.setter
    def HelpContextId(self, value):
        self.com_object.HelpContextId = value

    @property
    def helpcontextid(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @helpcontextid.setter
    def helpcontextid(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def help_context_id(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @help_context_id.setter
    def help_context_id(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def Hyperlink(self):
        return self.com_object.Hyperlink

    @property
    def hyperlink(self):
        """Alias for Hyperlink"""
        return self.Hyperlink

    @property
    def HyperlinkAddress(self):
        return self.com_object.HyperlinkAddress

    @HyperlinkAddress.setter
    def HyperlinkAddress(self, value):
        self.com_object.HyperlinkAddress = value

    @property
    def hyperlinkaddress(self):
        """Alias for HyperlinkAddress"""
        return self.HyperlinkAddress

    @hyperlinkaddress.setter
    def hyperlinkaddress(self, value):
        """Alias for HyperlinkAddress.setter"""
        self.HyperlinkAddress = value

    @property
    def hyperlink_address(self):
        """Alias for HyperlinkAddress"""
        return self.HyperlinkAddress

    @hyperlink_address.setter
    def hyperlink_address(self, value):
        """Alias for HyperlinkAddress.setter"""
        self.HyperlinkAddress = value

    @property
    def HyperlinkSubAddress(self):
        return self.com_object.HyperlinkSubAddress

    @HyperlinkSubAddress.setter
    def HyperlinkSubAddress(self, value):
        self.com_object.HyperlinkSubAddress = value

    @property
    def hyperlinksubaddress(self):
        """Alias for HyperlinkSubAddress"""
        return self.HyperlinkSubAddress

    @hyperlinksubaddress.setter
    def hyperlinksubaddress(self, value):
        """Alias for HyperlinkSubAddress.setter"""
        self.HyperlinkSubAddress = value

    @property
    def hyperlink_sub_address(self):
        """Alias for HyperlinkSubAddress"""
        return self.HyperlinkSubAddress

    @hyperlink_sub_address.setter
    def hyperlink_sub_address(self, value):
        """Alias for HyperlinkSubAddress.setter"""
        self.HyperlinkSubAddress = value

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def IsVisible(self):
        return self.com_object.IsVisible

    @IsVisible.setter
    def IsVisible(self, value):
        self.com_object.IsVisible = value

    @property
    def isvisible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @isvisible.setter
    def isvisible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def is_visible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @is_visible.setter
    def is_visible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def Layout(self):
        return AcLayoutType(self.com_object.Layout)

    @property
    def layout(self):
        """Alias for Layout"""
        return self.Layout

    @property
    def LayoutID(self):
        return self.com_object.LayoutID

    @property
    def layoutid(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def layout_i_d(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def LeftMargin(self):
        return self.com_object.LeftMargin

    @LeftMargin.setter
    def LeftMargin(self, value):
        self.com_object.LeftMargin = value

    @property
    def leftmargin(self):
        """Alias for LeftMargin"""
        return self.LeftMargin

    @leftmargin.setter
    def leftmargin(self, value):
        """Alias for LeftMargin.setter"""
        self.LeftMargin = value

    @property
    def left_margin(self):
        """Alias for LeftMargin"""
        return self.LeftMargin

    @left_margin.setter
    def left_margin(self, value):
        """Alias for LeftMargin.setter"""
        self.LeftMargin = value

    @property
    def LeftPadding(self):
        return self.com_object.LeftPadding

    @LeftPadding.setter
    def LeftPadding(self, value):
        self.com_object.LeftPadding = value

    @property
    def leftpadding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @leftpadding.setter
    def leftpadding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def left_padding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @left_padding.setter
    def left_padding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def LineSpacing(self):
        return self.com_object.LineSpacing

    @LineSpacing.setter
    def LineSpacing(self, value):
        self.com_object.LineSpacing = value

    @property
    def linespacing(self):
        """Alias for LineSpacing"""
        return self.LineSpacing

    @linespacing.setter
    def linespacing(self, value):
        """Alias for LineSpacing.setter"""
        self.LineSpacing = value

    @property
    def line_spacing(self):
        """Alias for LineSpacing"""
        return self.LineSpacing

    @line_spacing.setter
    def line_spacing(self, value):
        """Alias for LineSpacing.setter"""
        self.LineSpacing = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def OldBorderStyle(self):
        return self.com_object.OldBorderStyle

    @OldBorderStyle.setter
    def OldBorderStyle(self, value):
        self.com_object.OldBorderStyle = value

    @property
    def oldborderstyle(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @oldborderstyle.setter
    def oldborderstyle(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def old_border_style(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @old_border_style.setter
    def old_border_style(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def OnClick(self):
        return self.com_object.OnClick

    @OnClick.setter
    def OnClick(self, value):
        self.com_object.OnClick = value

    @property
    def onclick(self):
        """Alias for OnClick"""
        return self.OnClick

    @onclick.setter
    def onclick(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def on_click(self):
        """Alias for OnClick"""
        return self.OnClick

    @on_click.setter
    def on_click(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def OnDblClick(self):
        return self.com_object.OnDblClick

    @OnDblClick.setter
    def OnDblClick(self, value):
        self.com_object.OnDblClick = value

    @property
    def ondblclick(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @ondblclick.setter
    def ondblclick(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def on_dbl_click(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @on_dbl_click.setter
    def on_dbl_click(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def OnMouseDown(self):
        return self.com_object.OnMouseDown

    @OnMouseDown.setter
    def OnMouseDown(self, value):
        self.com_object.OnMouseDown = value

    @property
    def onmousedown(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @onmousedown.setter
    def onmousedown(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def on_mouse_down(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @on_mouse_down.setter
    def on_mouse_down(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def OnMouseMove(self):
        return self.com_object.OnMouseMove

    @OnMouseMove.setter
    def OnMouseMove(self, value):
        self.com_object.OnMouseMove = value

    @property
    def onmousemove(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @onmousemove.setter
    def onmousemove(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def on_mouse_move(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @on_mouse_move.setter
    def on_mouse_move(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def OnMouseUp(self):
        return self.com_object.OnMouseUp

    @OnMouseUp.setter
    def OnMouseUp(self, value):
        self.com_object.OnMouseUp = value

    @property
    def onmouseup(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @onmouseup.setter
    def onmouseup(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def on_mouse_up(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @on_mouse_up.setter
    def on_mouse_up(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def ReadingOrder(self):
        return self.com_object.ReadingOrder

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def RightMargin(self):
        return self.com_object.RightMargin

    @RightMargin.setter
    def RightMargin(self, value):
        self.com_object.RightMargin = value

    @property
    def rightmargin(self):
        """Alias for RightMargin"""
        return self.RightMargin

    @rightmargin.setter
    def rightmargin(self, value):
        """Alias for RightMargin.setter"""
        self.RightMargin = value

    @property
    def right_margin(self):
        """Alias for RightMargin"""
        return self.RightMargin

    @right_margin.setter
    def right_margin(self, value):
        """Alias for RightMargin.setter"""
        self.RightMargin = value

    @property
    def RightPadding(self):
        return self.com_object.RightPadding

    @RightPadding.setter
    def RightPadding(self, value):
        self.com_object.RightPadding = value

    @property
    def rightpadding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @rightpadding.setter
    def rightpadding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def right_padding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @right_padding.setter
    def right_padding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def Section(self):
        return self.com_object.Section

    @Section.setter
    def Section(self, value):
        self.com_object.Section = value

    @property
    def section(self):
        """Alias for Section"""
        return self.Section

    @section.setter
    def section(self, value):
        """Alias for Section.setter"""
        self.Section = value

    @property
    def ShortcutMenuBar(self):
        return self.com_object.ShortcutMenuBar

    @ShortcutMenuBar.setter
    def ShortcutMenuBar(self, value):
        self.com_object.ShortcutMenuBar = value

    @property
    def shortcutmenubar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcutmenubar.setter
    def shortcutmenubar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def shortcut_menu_bar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcut_menu_bar.setter
    def shortcut_menu_bar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def SmartTags(self):
        return SmartTags(self.com_object.SmartTags)

    @property
    def smarttags(self):
        """Alias for SmartTags"""
        return self.SmartTags

    @property
    def smart_tags(self):
        """Alias for SmartTags"""
        return self.SmartTags

    @property
    def SpecialEffect(self):
        return self.com_object.SpecialEffect

    @SpecialEffect.setter
    def SpecialEffect(self, value):
        self.com_object.SpecialEffect = value

    @property
    def specialeffect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @specialeffect.setter
    def specialeffect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def special_effect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @special_effect.setter
    def special_effect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def TextAlign(self):
        return self.com_object.TextAlign

    @TextAlign.setter
    def TextAlign(self, value):
        self.com_object.TextAlign = value

    @property
    def textalign(self):
        """Alias for TextAlign"""
        return self.TextAlign

    @textalign.setter
    def textalign(self, value):
        """Alias for TextAlign.setter"""
        self.TextAlign = value

    @property
    def text_align(self):
        """Alias for TextAlign"""
        return self.TextAlign

    @text_align.setter
    def text_align(self, value):
        """Alias for TextAlign.setter"""
        self.TextAlign = value

    @property
    def ThemeFontIndex(self):
        return self.com_object.ThemeFontIndex

    @ThemeFontIndex.setter
    def ThemeFontIndex(self, value):
        self.com_object.ThemeFontIndex = value

    @property
    def themefontindex(self):
        """Alias for ThemeFontIndex"""
        return self.ThemeFontIndex

    @themefontindex.setter
    def themefontindex(self, value):
        """Alias for ThemeFontIndex.setter"""
        self.ThemeFontIndex = value

    @property
    def theme_font_index(self):
        """Alias for ThemeFontIndex"""
        return self.ThemeFontIndex

    @theme_font_index.setter
    def theme_font_index(self, value):
        """Alias for ThemeFontIndex.setter"""
        self.ThemeFontIndex = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TopMargin(self):
        return self.com_object.TopMargin

    @TopMargin.setter
    def TopMargin(self, value):
        self.com_object.TopMargin = value

    @property
    def topmargin(self):
        """Alias for TopMargin"""
        return self.TopMargin

    @topmargin.setter
    def topmargin(self, value):
        """Alias for TopMargin.setter"""
        self.TopMargin = value

    @property
    def top_margin(self):
        """Alias for TopMargin"""
        return self.TopMargin

    @top_margin.setter
    def top_margin(self, value):
        """Alias for TopMargin.setter"""
        self.TopMargin = value

    @property
    def TopPadding(self):
        return self.com_object.TopPadding

    @TopPadding.setter
    def TopPadding(self, value):
        self.com_object.TopPadding = value

    @property
    def toppadding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @toppadding.setter
    def toppadding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def top_padding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @top_padding.setter
    def top_padding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def Vertical(self):
        return self.com_object.Vertical

    @Vertical.setter
    def Vertical(self, value):
        self.com_object.Vertical = value

    @property
    def vertical(self):
        """Alias for Vertical"""
        return self.Vertical

    @vertical.setter
    def vertical(self, value):
        """Alias for Vertical.setter"""
        self.Vertical = value

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()


class Line:

    def __init__(self, line=None):
        self.com_object= line

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BorderColor(self):
        return self.com_object.BorderColor

    @BorderColor.setter
    def BorderColor(self, value):
        self.com_object.BorderColor = value

    @property
    def bordercolor(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @bordercolor.setter
    def bordercolor(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def border_color(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @border_color.setter
    def border_color(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def BorderShade(self):
        return self.com_object.BorderShade

    @BorderShade.setter
    def BorderShade(self, value):
        self.com_object.BorderShade = value

    @property
    def bordershade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @bordershade.setter
    def bordershade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def border_shade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @border_shade.setter
    def border_shade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def BorderStyle(self):
        return self.com_object.BorderStyle

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def BorderThemeColorIndex(self):
        return self.com_object.BorderThemeColorIndex

    @BorderThemeColorIndex.setter
    def BorderThemeColorIndex(self, value):
        self.com_object.BorderThemeColorIndex = value

    @property
    def borderthemecolorindex(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @borderthemecolorindex.setter
    def borderthemecolorindex(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def border_theme_color_index(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @border_theme_color_index.setter
    def border_theme_color_index(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def BorderTint(self):
        return self.com_object.BorderTint

    @BorderTint.setter
    def BorderTint(self, value):
        self.com_object.BorderTint = value

    @property
    def bordertint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @bordertint.setter
    def bordertint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def border_tint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @border_tint.setter
    def border_tint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def BorderWidth(self):
        return self.com_object.BorderWidth

    @BorderWidth.setter
    def BorderWidth(self, value):
        self.com_object.BorderWidth = value

    @property
    def borderwidth(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @borderwidth.setter
    def borderwidth(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def border_width(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @border_width.setter
    def border_width(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def ControlType(self):
        return self.com_object.ControlType

    @ControlType.setter
    def ControlType(self, value):
        self.com_object.ControlType = value

    @property
    def controltype(self):
        """Alias for ControlType"""
        return self.ControlType

    @controltype.setter
    def controltype(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def control_type(self):
        """Alias for ControlType"""
        return self.ControlType

    @control_type.setter
    def control_type(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def DisplayWhen(self):
        return self.com_object.DisplayWhen

    @DisplayWhen.setter
    def DisplayWhen(self, value):
        self.com_object.DisplayWhen = value

    @property
    def displaywhen(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @displaywhen.setter
    def displaywhen(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def display_when(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @display_when.setter
    def display_when(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def IsVisible(self):
        return self.com_object.IsVisible

    @IsVisible.setter
    def IsVisible(self, value):
        self.com_object.IsVisible = value

    @property
    def isvisible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @isvisible.setter
    def isvisible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def is_visible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @is_visible.setter
    def is_visible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def LineSlant(self):
        return self.com_object.LineSlant

    @LineSlant.setter
    def LineSlant(self, value):
        self.com_object.LineSlant = value

    @property
    def lineslant(self):
        """Alias for LineSlant"""
        return self.LineSlant

    @lineslant.setter
    def lineslant(self, value):
        """Alias for LineSlant.setter"""
        self.LineSlant = value

    @property
    def line_slant(self):
        """Alias for LineSlant"""
        return self.LineSlant

    @line_slant.setter
    def line_slant(self, value):
        """Alias for LineSlant.setter"""
        self.LineSlant = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def OldBorderStyle(self):
        return self.com_object.OldBorderStyle

    @OldBorderStyle.setter
    def OldBorderStyle(self, value):
        self.com_object.OldBorderStyle = value

    @property
    def oldborderstyle(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @oldborderstyle.setter
    def oldborderstyle(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def old_border_style(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @old_border_style.setter
    def old_border_style(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def Section(self):
        return self.com_object.Section

    @Section.setter
    def Section(self, value):
        self.com_object.Section = value

    @property
    def section(self):
        """Alias for Section"""
        return self.Section

    @section.setter
    def section(self, value):
        """Alias for Section.setter"""
        self.Section = value

    @property
    def SpecialEffect(self):
        return self.com_object.SpecialEffect

    @SpecialEffect.setter
    def SpecialEffect(self, value):
        self.com_object.SpecialEffect = value

    @property
    def specialeffect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @specialeffect.setter
    def specialeffect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def special_effect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @special_effect.setter
    def special_effect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()


class ListBox:

    def __init__(self, listbox=None):
        self.com_object= listbox

    @property
    def AddColon(self):
        return self.com_object.AddColon

    @AddColon.setter
    def AddColon(self, value):
        self.com_object.AddColon = value

    @property
    def addcolon(self):
        """Alias for AddColon"""
        return self.AddColon

    @addcolon.setter
    def addcolon(self, value):
        """Alias for AddColon.setter"""
        self.AddColon = value

    @property
    def add_colon(self):
        """Alias for AddColon"""
        return self.AddColon

    @add_colon.setter
    def add_colon(self, value):
        """Alias for AddColon.setter"""
        self.AddColon = value

    @property
    def AllowValueListEdits(self):
        return self.com_object.AllowValueListEdits

    @AllowValueListEdits.setter
    def AllowValueListEdits(self, value):
        self.com_object.AllowValueListEdits = value

    @property
    def allowvaluelistedits(self):
        """Alias for AllowValueListEdits"""
        return self.AllowValueListEdits

    @allowvaluelistedits.setter
    def allowvaluelistedits(self, value):
        """Alias for AllowValueListEdits.setter"""
        self.AllowValueListEdits = value

    @property
    def allow_value_list_edits(self):
        """Alias for AllowValueListEdits"""
        return self.AllowValueListEdits

    @allow_value_list_edits.setter
    def allow_value_list_edits(self, value):
        """Alias for AllowValueListEdits.setter"""
        self.AllowValueListEdits = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoLabel(self):
        return self.com_object.AutoLabel

    @AutoLabel.setter
    def AutoLabel(self, value):
        self.com_object.AutoLabel = value

    @property
    def autolabel(self):
        """Alias for AutoLabel"""
        return self.AutoLabel

    @autolabel.setter
    def autolabel(self, value):
        """Alias for AutoLabel.setter"""
        self.AutoLabel = value

    @property
    def auto_label(self):
        """Alias for AutoLabel"""
        return self.AutoLabel

    @auto_label.setter
    def auto_label(self, value):
        """Alias for AutoLabel.setter"""
        self.AutoLabel = value

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BackShade(self):
        return self.com_object.BackShade

    @BackShade.setter
    def BackShade(self, value):
        self.com_object.BackShade = value

    @property
    def backshade(self):
        """Alias for BackShade"""
        return self.BackShade

    @backshade.setter
    def backshade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def back_shade(self):
        """Alias for BackShade"""
        return self.BackShade

    @back_shade.setter
    def back_shade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def BackThemeColorIndex(self):
        return self.com_object.BackThemeColorIndex

    @BackThemeColorIndex.setter
    def BackThemeColorIndex(self, value):
        self.com_object.BackThemeColorIndex = value

    @property
    def backthemecolorindex(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @backthemecolorindex.setter
    def backthemecolorindex(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def back_theme_color_index(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @back_theme_color_index.setter
    def back_theme_color_index(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def BackTint(self):
        return self.com_object.BackTint

    @BackTint.setter
    def BackTint(self, value):
        self.com_object.BackTint = value

    @property
    def backtint(self):
        """Alias for BackTint"""
        return self.BackTint

    @backtint.setter
    def backtint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def back_tint(self):
        """Alias for BackTint"""
        return self.BackTint

    @back_tint.setter
    def back_tint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def BorderColor(self):
        return self.com_object.BorderColor

    @BorderColor.setter
    def BorderColor(self, value):
        self.com_object.BorderColor = value

    @property
    def bordercolor(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @bordercolor.setter
    def bordercolor(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def border_color(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @border_color.setter
    def border_color(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def BorderShade(self):
        return self.com_object.BorderShade

    @BorderShade.setter
    def BorderShade(self, value):
        self.com_object.BorderShade = value

    @property
    def bordershade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @bordershade.setter
    def bordershade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def border_shade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @border_shade.setter
    def border_shade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def BorderStyle(self):
        return self.com_object.BorderStyle

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def BorderThemeColorIndex(self):
        return self.com_object.BorderThemeColorIndex

    @BorderThemeColorIndex.setter
    def BorderThemeColorIndex(self, value):
        self.com_object.BorderThemeColorIndex = value

    @property
    def borderthemecolorindex(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @borderthemecolorindex.setter
    def borderthemecolorindex(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def border_theme_color_index(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @border_theme_color_index.setter
    def border_theme_color_index(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def BorderTint(self):
        return self.com_object.BorderTint

    @BorderTint.setter
    def BorderTint(self, value):
        self.com_object.BorderTint = value

    @property
    def bordertint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @bordertint.setter
    def bordertint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def border_tint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @border_tint.setter
    def border_tint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def BorderWidth(self):
        return self.com_object.BorderWidth

    @BorderWidth.setter
    def BorderWidth(self, value):
        self.com_object.BorderWidth = value

    @property
    def borderwidth(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @borderwidth.setter
    def borderwidth(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def border_width(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @border_width.setter
    def border_width(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def BottomPadding(self):
        return self.com_object.BottomPadding

    @BottomPadding.setter
    def BottomPadding(self, value):
        self.com_object.BottomPadding = value

    @property
    def bottompadding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottompadding.setter
    def bottompadding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def bottom_padding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottom_padding.setter
    def bottom_padding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def BoundColumn(self):
        return self.com_object.BoundColumn

    @BoundColumn.setter
    def BoundColumn(self, value):
        self.com_object.BoundColumn = value

    @property
    def boundcolumn(self):
        """Alias for BoundColumn"""
        return self.BoundColumn

    @boundcolumn.setter
    def boundcolumn(self, value):
        """Alias for BoundColumn.setter"""
        self.BoundColumn = value

    @property
    def bound_column(self):
        """Alias for BoundColumn"""
        return self.BoundColumn

    @bound_column.setter
    def bound_column(self, value):
        """Alias for BoundColumn.setter"""
        self.BoundColumn = value

    def Column(self, Index=None, Row=None):
        arguments = com_arguments([unwrap(a) for a in [Index, Row]])
        if hasattr(self.com_object, "GetColumn"):
            return self.com_object.GetColumn(*arguments)
        else:
            return self.com_object.Column(*arguments)

    def column(self, Index=None, Row=None):
        """Alias for Column"""
        arguments = [Index, Row]
        return self.Column(*arguments)

    @property
    def ColumnCount(self):
        return self.com_object.ColumnCount

    @ColumnCount.setter
    def ColumnCount(self, value):
        self.com_object.ColumnCount = value

    @property
    def columncount(self):
        """Alias for ColumnCount"""
        return self.ColumnCount

    @columncount.setter
    def columncount(self, value):
        """Alias for ColumnCount.setter"""
        self.ColumnCount = value

    @property
    def column_count(self):
        """Alias for ColumnCount"""
        return self.ColumnCount

    @column_count.setter
    def column_count(self, value):
        """Alias for ColumnCount.setter"""
        self.ColumnCount = value

    @property
    def ColumnHeads(self):
        return self.com_object.ColumnHeads

    @ColumnHeads.setter
    def ColumnHeads(self, value):
        self.com_object.ColumnHeads = value

    @property
    def columnheads(self):
        """Alias for ColumnHeads"""
        return self.ColumnHeads

    @columnheads.setter
    def columnheads(self, value):
        """Alias for ColumnHeads.setter"""
        self.ColumnHeads = value

    @property
    def column_heads(self):
        """Alias for ColumnHeads"""
        return self.ColumnHeads

    @column_heads.setter
    def column_heads(self, value):
        """Alias for ColumnHeads.setter"""
        self.ColumnHeads = value

    @property
    def ColumnHidden(self):
        return self.com_object.ColumnHidden

    @ColumnHidden.setter
    def ColumnHidden(self, value):
        self.com_object.ColumnHidden = value

    @property
    def columnhidden(self):
        """Alias for ColumnHidden"""
        return self.ColumnHidden

    @columnhidden.setter
    def columnhidden(self, value):
        """Alias for ColumnHidden.setter"""
        self.ColumnHidden = value

    @property
    def column_hidden(self):
        """Alias for ColumnHidden"""
        return self.ColumnHidden

    @column_hidden.setter
    def column_hidden(self, value):
        """Alias for ColumnHidden.setter"""
        self.ColumnHidden = value

    @property
    def ColumnOrder(self):
        return self.com_object.ColumnOrder

    @ColumnOrder.setter
    def ColumnOrder(self, value):
        self.com_object.ColumnOrder = value

    @property
    def columnorder(self):
        """Alias for ColumnOrder"""
        return self.ColumnOrder

    @columnorder.setter
    def columnorder(self, value):
        """Alias for ColumnOrder.setter"""
        self.ColumnOrder = value

    @property
    def column_order(self):
        """Alias for ColumnOrder"""
        return self.ColumnOrder

    @column_order.setter
    def column_order(self, value):
        """Alias for ColumnOrder.setter"""
        self.ColumnOrder = value

    @property
    def ColumnWidth(self):
        return self.com_object.ColumnWidth

    @ColumnWidth.setter
    def ColumnWidth(self, value):
        self.com_object.ColumnWidth = value

    @property
    def columnwidth(self):
        """Alias for ColumnWidth"""
        return self.ColumnWidth

    @columnwidth.setter
    def columnwidth(self, value):
        """Alias for ColumnWidth.setter"""
        self.ColumnWidth = value

    @property
    def column_width(self):
        """Alias for ColumnWidth"""
        return self.ColumnWidth

    @column_width.setter
    def column_width(self, value):
        """Alias for ColumnWidth.setter"""
        self.ColumnWidth = value

    @property
    def ColumnWidths(self):
        return self.com_object.ColumnWidths

    @ColumnWidths.setter
    def ColumnWidths(self, value):
        self.com_object.ColumnWidths = value

    @property
    def columnwidths(self):
        """Alias for ColumnWidths"""
        return self.ColumnWidths

    @columnwidths.setter
    def columnwidths(self, value):
        """Alias for ColumnWidths.setter"""
        self.ColumnWidths = value

    @property
    def column_widths(self):
        """Alias for ColumnWidths"""
        return self.ColumnWidths

    @column_widths.setter
    def column_widths(self, value):
        """Alias for ColumnWidths.setter"""
        self.ColumnWidths = value

    @property
    def Controls(self):
        return Controls(self.com_object.Controls)

    @property
    def controls(self):
        """Alias for Controls"""
        return self.Controls

    @property
    def ControlSource(self):
        return self.com_object.ControlSource

    @ControlSource.setter
    def ControlSource(self, value):
        self.com_object.ControlSource = value

    @property
    def controlsource(self):
        """Alias for ControlSource"""
        return self.ControlSource

    @controlsource.setter
    def controlsource(self, value):
        """Alias for ControlSource.setter"""
        self.ControlSource = value

    @property
    def control_source(self):
        """Alias for ControlSource"""
        return self.ControlSource

    @control_source.setter
    def control_source(self, value):
        """Alias for ControlSource.setter"""
        self.ControlSource = value

    @property
    def ControlTipText(self):
        return self.com_object.ControlTipText

    @ControlTipText.setter
    def ControlTipText(self, value):
        self.com_object.ControlTipText = value

    @property
    def controltiptext(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @controltiptext.setter
    def controltiptext(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def control_tip_text(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @control_tip_text.setter
    def control_tip_text(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def ControlType(self):
        return self.com_object.ControlType

    @ControlType.setter
    def ControlType(self, value):
        self.com_object.ControlType = value

    @property
    def controltype(self):
        """Alias for ControlType"""
        return self.ControlType

    @controltype.setter
    def controltype(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def control_type(self):
        """Alias for ControlType"""
        return self.ControlType

    @control_type.setter
    def control_type(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def DefaultValue(self):
        return self.com_object.DefaultValue

    @DefaultValue.setter
    def DefaultValue(self, value):
        self.com_object.DefaultValue = value

    @property
    def defaultvalue(self):
        """Alias for DefaultValue"""
        return self.DefaultValue

    @defaultvalue.setter
    def defaultvalue(self, value):
        """Alias for DefaultValue.setter"""
        self.DefaultValue = value

    @property
    def default_value(self):
        """Alias for DefaultValue"""
        return self.DefaultValue

    @default_value.setter
    def default_value(self, value):
        """Alias for DefaultValue.setter"""
        self.DefaultValue = value

    @property
    def DisplayWhen(self):
        return self.com_object.DisplayWhen

    @DisplayWhen.setter
    def DisplayWhen(self, value):
        self.com_object.DisplayWhen = value

    @property
    def displaywhen(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @displaywhen.setter
    def displaywhen(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def display_when(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @display_when.setter
    def display_when(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def FontBold(self):
        return self.com_object.FontBold

    @property
    def fontbold(self):
        """Alias for FontBold"""
        return self.FontBold

    @property
    def font_bold(self):
        """Alias for FontBold"""
        return self.FontBold

    @property
    def FontItalic(self):
        return self.com_object.FontItalic

    @property
    def fontitalic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @property
    def font_italic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @property
    def FontName(self):
        return self.com_object.FontName

    @property
    def fontname(self):
        """Alias for FontName"""
        return self.FontName

    @property
    def font_name(self):
        """Alias for FontName"""
        return self.FontName

    @property
    def FontSize(self):
        return self.com_object.FontSize

    @property
    def fontsize(self):
        """Alias for FontSize"""
        return self.FontSize

    @property
    def font_size(self):
        """Alias for FontSize"""
        return self.FontSize

    @property
    def FontUnderline(self):
        return self.com_object.FontUnderline

    @property
    def fontunderline(self):
        """Alias for FontUnderline"""
        return self.FontUnderline

    @property
    def font_underline(self):
        """Alias for FontUnderline"""
        return self.FontUnderline

    @property
    def FontWeight(self):
        return self.com_object.FontWeight

    @FontWeight.setter
    def FontWeight(self, value):
        self.com_object.FontWeight = value

    @property
    def fontweight(self):
        """Alias for FontWeight"""
        return self.FontWeight

    @fontweight.setter
    def fontweight(self, value):
        """Alias for FontWeight.setter"""
        self.FontWeight = value

    @property
    def font_weight(self):
        """Alias for FontWeight"""
        return self.FontWeight

    @font_weight.setter
    def font_weight(self, value):
        """Alias for FontWeight.setter"""
        self.FontWeight = value

    @property
    def ForeColor(self):
        return self.com_object.ForeColor

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def ForeShade(self):
        return self.com_object.ForeShade

    @ForeShade.setter
    def ForeShade(self, value):
        self.com_object.ForeShade = value

    @property
    def foreshade(self):
        """Alias for ForeShade"""
        return self.ForeShade

    @foreshade.setter
    def foreshade(self, value):
        """Alias for ForeShade.setter"""
        self.ForeShade = value

    @property
    def fore_shade(self):
        """Alias for ForeShade"""
        return self.ForeShade

    @fore_shade.setter
    def fore_shade(self, value):
        """Alias for ForeShade.setter"""
        self.ForeShade = value

    @property
    def ForeThemeColorIndex(self):
        return self.com_object.ForeThemeColorIndex

    @ForeThemeColorIndex.setter
    def ForeThemeColorIndex(self, value):
        self.com_object.ForeThemeColorIndex = value

    @property
    def forethemecolorindex(self):
        """Alias for ForeThemeColorIndex"""
        return self.ForeThemeColorIndex

    @forethemecolorindex.setter
    def forethemecolorindex(self, value):
        """Alias for ForeThemeColorIndex.setter"""
        self.ForeThemeColorIndex = value

    @property
    def fore_theme_color_index(self):
        """Alias for ForeThemeColorIndex"""
        return self.ForeThemeColorIndex

    @fore_theme_color_index.setter
    def fore_theme_color_index(self, value):
        """Alias for ForeThemeColorIndex.setter"""
        self.ForeThemeColorIndex = value

    @property
    def ForeTint(self):
        return self.com_object.ForeTint

    @ForeTint.setter
    def ForeTint(self, value):
        self.com_object.ForeTint = value

    @property
    def foretint(self):
        """Alias for ForeTint"""
        return self.ForeTint

    @foretint.setter
    def foretint(self, value):
        """Alias for ForeTint.setter"""
        self.ForeTint = value

    @property
    def fore_tint(self):
        """Alias for ForeTint"""
        return self.ForeTint

    @fore_tint.setter
    def fore_tint(self, value):
        """Alias for ForeTint.setter"""
        self.ForeTint = value

    @property
    def GridlineColor(self):
        return self.com_object.GridlineColor

    @GridlineColor.setter
    def GridlineColor(self, value):
        self.com_object.GridlineColor = value

    @property
    def gridlinecolor(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridlinecolor.setter
    def gridlinecolor(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def gridline_color(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridline_color.setter
    def gridline_color(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def GridlineShade(self):
        return self.com_object.GridlineShade

    @GridlineShade.setter
    def GridlineShade(self, value):
        self.com_object.GridlineShade = value

    @property
    def gridlineshade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridlineshade.setter
    def gridlineshade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def gridline_shade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridline_shade.setter
    def gridline_shade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def GridlineStyleBottom(self):
        return self.com_object.GridlineStyleBottom

    @GridlineStyleBottom.setter
    def GridlineStyleBottom(self, value):
        self.com_object.GridlineStyleBottom = value

    @property
    def gridlinestylebottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridlinestylebottom.setter
    def gridlinestylebottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def gridline_style_bottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridline_style_bottom.setter
    def gridline_style_bottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def GridlineStyleLeft(self):
        return self.com_object.GridlineStyleLeft

    @GridlineStyleLeft.setter
    def GridlineStyleLeft(self, value):
        self.com_object.GridlineStyleLeft = value

    @property
    def gridlinestyleleft(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridlinestyleleft.setter
    def gridlinestyleleft(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def gridline_style_left(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridline_style_left.setter
    def gridline_style_left(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def GridlineStyleRight(self):
        return self.com_object.GridlineStyleRight

    @GridlineStyleRight.setter
    def GridlineStyleRight(self, value):
        self.com_object.GridlineStyleRight = value

    @property
    def gridlinestyleright(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridlinestyleright.setter
    def gridlinestyleright(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def gridline_style_right(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridline_style_right.setter
    def gridline_style_right(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def GridlineStyleTop(self):
        return self.com_object.GridlineStyleTop

    @GridlineStyleTop.setter
    def GridlineStyleTop(self, value):
        self.com_object.GridlineStyleTop = value

    @property
    def gridlinestyletop(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridlinestyletop.setter
    def gridlinestyletop(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def gridline_style_top(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridline_style_top.setter
    def gridline_style_top(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def GridlineThemeColorIndex(self):
        return self.com_object.GridlineThemeColorIndex

    @GridlineThemeColorIndex.setter
    def GridlineThemeColorIndex(self, value):
        self.com_object.GridlineThemeColorIndex = value

    @property
    def gridlinethemecolorindex(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridlinethemecolorindex.setter
    def gridlinethemecolorindex(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def gridline_theme_color_index(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridline_theme_color_index.setter
    def gridline_theme_color_index(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def GridlineTint(self):
        return self.com_object.GridlineTint

    @GridlineTint.setter
    def GridlineTint(self, value):
        self.com_object.GridlineTint = value

    @property
    def gridlinetint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridlinetint.setter
    def gridlinetint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def gridline_tint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridline_tint.setter
    def gridline_tint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def GridlineWidthBottom(self):
        return self.com_object.GridlineWidthBottom

    @GridlineWidthBottom.setter
    def GridlineWidthBottom(self, value):
        self.com_object.GridlineWidthBottom = value

    @property
    def gridlinewidthbottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridlinewidthbottom.setter
    def gridlinewidthbottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def gridline_width_bottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridline_width_bottom.setter
    def gridline_width_bottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def GridlineWidthLeft(self):
        return self.com_object.GridlineWidthLeft

    @GridlineWidthLeft.setter
    def GridlineWidthLeft(self, value):
        self.com_object.GridlineWidthLeft = value

    @property
    def gridlinewidthleft(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridlinewidthleft.setter
    def gridlinewidthleft(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def gridline_width_left(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridline_width_left.setter
    def gridline_width_left(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def GridlineWidthRight(self):
        return self.com_object.GridlineWidthRight

    @GridlineWidthRight.setter
    def GridlineWidthRight(self, value):
        self.com_object.GridlineWidthRight = value

    @property
    def gridlinewidthright(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridlinewidthright.setter
    def gridlinewidthright(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def gridline_width_right(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridline_width_right.setter
    def gridline_width_right(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def GridlineWidthTop(self):
        return self.com_object.GridlineWidthTop

    @GridlineWidthTop.setter
    def GridlineWidthTop(self, value):
        self.com_object.GridlineWidthTop = value

    @property
    def gridlinewidthtop(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridlinewidthtop.setter
    def gridlinewidthtop(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def gridline_width_top(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridline_width_top.setter
    def gridline_width_top(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HelpContextId(self):
        return self.com_object.HelpContextId

    @HelpContextId.setter
    def HelpContextId(self, value):
        self.com_object.HelpContextId = value

    @property
    def helpcontextid(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @helpcontextid.setter
    def helpcontextid(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def help_context_id(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @help_context_id.setter
    def help_context_id(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def HideDuplicates(self):
        return self.com_object.HideDuplicates

    @HideDuplicates.setter
    def HideDuplicates(self, value):
        self.com_object.HideDuplicates = value

    @property
    def hideduplicates(self):
        """Alias for HideDuplicates"""
        return self.HideDuplicates

    @hideduplicates.setter
    def hideduplicates(self, value):
        """Alias for HideDuplicates.setter"""
        self.HideDuplicates = value

    @property
    def hide_duplicates(self):
        """Alias for HideDuplicates"""
        return self.HideDuplicates

    @hide_duplicates.setter
    def hide_duplicates(self, value):
        """Alias for HideDuplicates.setter"""
        self.HideDuplicates = value

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def Hyperlink(self):
        return self.com_object.Hyperlink

    @property
    def hyperlink(self):
        """Alias for Hyperlink"""
        return self.Hyperlink

    @property
    def IMEHold(self):
        return self.com_object.IMEHold

    @IMEHold.setter
    def IMEHold(self, value):
        self.com_object.IMEHold = value

    @property
    def imehold(self):
        """Alias for IMEHold"""
        return self.IMEHold

    @imehold.setter
    def imehold(self, value):
        """Alias for IMEHold.setter"""
        self.IMEHold = value

    @property
    def i_m_e_hold(self):
        """Alias for IMEHold"""
        return self.IMEHold

    @i_m_e_hold.setter
    def i_m_e_hold(self, value):
        """Alias for IMEHold.setter"""
        self.IMEHold = value

    @property
    def InheritValueList(self):
        return self.com_object.InheritValueList

    @InheritValueList.setter
    def InheritValueList(self, value):
        self.com_object.InheritValueList = value

    @property
    def inheritvaluelist(self):
        """Alias for InheritValueList"""
        return self.InheritValueList

    @inheritvaluelist.setter
    def inheritvaluelist(self, value):
        """Alias for InheritValueList.setter"""
        self.InheritValueList = value

    @property
    def inherit_value_list(self):
        """Alias for InheritValueList"""
        return self.InheritValueList

    @inherit_value_list.setter
    def inherit_value_list(self, value):
        """Alias for InheritValueList.setter"""
        self.InheritValueList = value

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def IsVisible(self):
        return self.com_object.IsVisible

    @IsVisible.setter
    def IsVisible(self, value):
        self.com_object.IsVisible = value

    @property
    def isvisible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @isvisible.setter
    def isvisible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def is_visible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @is_visible.setter
    def is_visible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    def ItemData(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItemData"):
            return self.com_object.GetItemData(*arguments)
        else:
            return self.com_object.ItemData(*arguments)

    def itemdata(self, Index=None):
        """Alias for ItemData"""
        arguments = [Index]
        return self.ItemData(*arguments)

    def item_data(self, Index=None):
        """Alias for ItemData"""
        arguments = [Index]
        return self.ItemData(*arguments)

    @property
    def ItemsSelected(self):
        return self.com_object.ItemsSelected

    @property
    def itemsselected(self):
        """Alias for ItemsSelected"""
        return self.ItemsSelected

    @property
    def items_selected(self):
        """Alias for ItemsSelected"""
        return self.ItemsSelected

    @property
    def LabelAlign(self):
        return self.com_object.LabelAlign

    @LabelAlign.setter
    def LabelAlign(self, value):
        self.com_object.LabelAlign = value

    @property
    def labelalign(self):
        """Alias for LabelAlign"""
        return self.LabelAlign

    @labelalign.setter
    def labelalign(self, value):
        """Alias for LabelAlign.setter"""
        self.LabelAlign = value

    @property
    def label_align(self):
        """Alias for LabelAlign"""
        return self.LabelAlign

    @label_align.setter
    def label_align(self, value):
        """Alias for LabelAlign.setter"""
        self.LabelAlign = value

    @property
    def LabelX(self):
        return self.com_object.LabelX

    @LabelX.setter
    def LabelX(self, value):
        self.com_object.LabelX = value

    @property
    def labelx(self):
        """Alias for LabelX"""
        return self.LabelX

    @labelx.setter
    def labelx(self, value):
        """Alias for LabelX.setter"""
        self.LabelX = value

    @property
    def label_x(self):
        """Alias for LabelX"""
        return self.LabelX

    @label_x.setter
    def label_x(self, value):
        """Alias for LabelX.setter"""
        self.LabelX = value

    @property
    def LabelY(self):
        return self.com_object.LabelY

    @LabelY.setter
    def LabelY(self, value):
        self.com_object.LabelY = value

    @property
    def labely(self):
        """Alias for LabelY"""
        return self.LabelY

    @labely.setter
    def labely(self, value):
        """Alias for LabelY.setter"""
        self.LabelY = value

    @property
    def label_y(self):
        """Alias for LabelY"""
        return self.LabelY

    @label_y.setter
    def label_y(self, value):
        """Alias for LabelY.setter"""
        self.LabelY = value

    @property
    def Layout(self):
        return AcLayoutType(self.com_object.Layout)

    @property
    def layout(self):
        """Alias for Layout"""
        return self.Layout

    @property
    def LayoutID(self):
        return self.com_object.LayoutID

    @property
    def layoutid(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def layout_i_d(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def LeftPadding(self):
        return self.com_object.LeftPadding

    @LeftPadding.setter
    def LeftPadding(self, value):
        self.com_object.LeftPadding = value

    @property
    def leftpadding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @leftpadding.setter
    def leftpadding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def left_padding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @left_padding.setter
    def left_padding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def ListCount(self):
        return self.com_object.ListCount

    @ListCount.setter
    def ListCount(self, value):
        self.com_object.ListCount = value

    @property
    def listcount(self):
        """Alias for ListCount"""
        return self.ListCount

    @listcount.setter
    def listcount(self, value):
        """Alias for ListCount.setter"""
        self.ListCount = value

    @property
    def list_count(self):
        """Alias for ListCount"""
        return self.ListCount

    @list_count.setter
    def list_count(self, value):
        """Alias for ListCount.setter"""
        self.ListCount = value

    @property
    def ListIndex(self):
        return self.com_object.ListIndex

    @ListIndex.setter
    def ListIndex(self, value):
        self.com_object.ListIndex = value

    @property
    def listindex(self):
        """Alias for ListIndex"""
        return self.ListIndex

    @listindex.setter
    def listindex(self, value):
        """Alias for ListIndex.setter"""
        self.ListIndex = value

    @property
    def list_index(self):
        """Alias for ListIndex"""
        return self.ListIndex

    @list_index.setter
    def list_index(self, value):
        """Alias for ListIndex.setter"""
        self.ListIndex = value

    @property
    def ListItemsEditForm(self):
        return self.com_object.ListItemsEditForm

    @ListItemsEditForm.setter
    def ListItemsEditForm(self, value):
        self.com_object.ListItemsEditForm = value

    @property
    def listitemseditform(self):
        """Alias for ListItemsEditForm"""
        return self.ListItemsEditForm

    @listitemseditform.setter
    def listitemseditform(self, value):
        """Alias for ListItemsEditForm.setter"""
        self.ListItemsEditForm = value

    @property
    def list_items_edit_form(self):
        """Alias for ListItemsEditForm"""
        return self.ListItemsEditForm

    @list_items_edit_form.setter
    def list_items_edit_form(self, value):
        """Alias for ListItemsEditForm.setter"""
        self.ListItemsEditForm = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def MultiSelect(self):
        return self.com_object.MultiSelect

    @MultiSelect.setter
    def MultiSelect(self, value):
        self.com_object.MultiSelect = value

    @property
    def multiselect(self):
        """Alias for MultiSelect"""
        return self.MultiSelect

    @multiselect.setter
    def multiselect(self, value):
        """Alias for MultiSelect.setter"""
        self.MultiSelect = value

    @property
    def multi_select(self):
        """Alias for MultiSelect"""
        return self.MultiSelect

    @multi_select.setter
    def multi_select(self, value):
        """Alias for MultiSelect.setter"""
        self.MultiSelect = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def OldBorderStyle(self):
        return self.com_object.OldBorderStyle

    @OldBorderStyle.setter
    def OldBorderStyle(self, value):
        self.com_object.OldBorderStyle = value

    @property
    def oldborderstyle(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @oldborderstyle.setter
    def oldborderstyle(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def old_border_style(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @old_border_style.setter
    def old_border_style(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def OldValue(self):
        return self.com_object.OldValue

    @property
    def oldvalue(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def old_value(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def OnClick(self):
        return self.com_object.OnClick

    @OnClick.setter
    def OnClick(self, value):
        self.com_object.OnClick = value

    @property
    def onclick(self):
        """Alias for OnClick"""
        return self.OnClick

    @onclick.setter
    def onclick(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def on_click(self):
        """Alias for OnClick"""
        return self.OnClick

    @on_click.setter
    def on_click(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def OnDblClick(self):
        return self.com_object.OnDblClick

    @OnDblClick.setter
    def OnDblClick(self, value):
        self.com_object.OnDblClick = value

    @property
    def ondblclick(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @ondblclick.setter
    def ondblclick(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def on_dbl_click(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @on_dbl_click.setter
    def on_dbl_click(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def OnEnter(self):
        return self.com_object.OnEnter

    @OnEnter.setter
    def OnEnter(self, value):
        self.com_object.OnEnter = value

    @property
    def onenter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @onenter.setter
    def onenter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def on_enter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @on_enter.setter
    def on_enter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def OnExit(self):
        return self.com_object.OnExit

    @OnExit.setter
    def OnExit(self, value):
        self.com_object.OnExit = value

    @property
    def onexit(self):
        """Alias for OnExit"""
        return self.OnExit

    @onexit.setter
    def onexit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def on_exit(self):
        """Alias for OnExit"""
        return self.OnExit

    @on_exit.setter
    def on_exit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def OnGotFocus(self):
        return self.com_object.OnGotFocus

    @OnGotFocus.setter
    def OnGotFocus(self, value):
        self.com_object.OnGotFocus = value

    @property
    def ongotfocus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @ongotfocus.setter
    def ongotfocus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def on_got_focus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @on_got_focus.setter
    def on_got_focus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def OnKeyDown(self):
        return self.com_object.OnKeyDown

    @OnKeyDown.setter
    def OnKeyDown(self, value):
        self.com_object.OnKeyDown = value

    @property
    def onkeydown(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @onkeydown.setter
    def onkeydown(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def on_key_down(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @on_key_down.setter
    def on_key_down(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def OnKeyPress(self):
        return self.com_object.OnKeyPress

    @OnKeyPress.setter
    def OnKeyPress(self, value):
        self.com_object.OnKeyPress = value

    @property
    def onkeypress(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @onkeypress.setter
    def onkeypress(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def on_key_press(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @on_key_press.setter
    def on_key_press(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def OnKeyUp(self):
        return self.com_object.OnKeyUp

    @OnKeyUp.setter
    def OnKeyUp(self, value):
        self.com_object.OnKeyUp = value

    @property
    def onkeyup(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @onkeyup.setter
    def onkeyup(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def on_key_up(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @on_key_up.setter
    def on_key_up(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def OnLostFocus(self):
        return self.com_object.OnLostFocus

    @OnLostFocus.setter
    def OnLostFocus(self, value):
        self.com_object.OnLostFocus = value

    @property
    def onlostfocus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @onlostfocus.setter
    def onlostfocus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def on_lost_focus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @on_lost_focus.setter
    def on_lost_focus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def OnMouseDown(self):
        return self.com_object.OnMouseDown

    @OnMouseDown.setter
    def OnMouseDown(self, value):
        self.com_object.OnMouseDown = value

    @property
    def onmousedown(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @onmousedown.setter
    def onmousedown(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def on_mouse_down(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @on_mouse_down.setter
    def on_mouse_down(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def OnMouseMove(self):
        return self.com_object.OnMouseMove

    @OnMouseMove.setter
    def OnMouseMove(self, value):
        self.com_object.OnMouseMove = value

    @property
    def onmousemove(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @onmousemove.setter
    def onmousemove(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def on_mouse_move(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @on_mouse_move.setter
    def on_mouse_move(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def OnMouseUp(self):
        return self.com_object.OnMouseUp

    @OnMouseUp.setter
    def OnMouseUp(self, value):
        self.com_object.OnMouseUp = value

    @property
    def onmouseup(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @onmouseup.setter
    def onmouseup(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def on_mouse_up(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @on_mouse_up.setter
    def on_mouse_up(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def ReadingOrder(self):
        return self.com_object.ReadingOrder

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def Recordset(self):
        return self.com_object.Recordset

    @Recordset.setter
    def Recordset(self, value):
        self.com_object.Recordset = value

    @property
    def recordset(self):
        """Alias for Recordset"""
        return self.Recordset

    @recordset.setter
    def recordset(self, value):
        """Alias for Recordset.setter"""
        self.Recordset = value

    @property
    def RightPadding(self):
        return self.com_object.RightPadding

    @RightPadding.setter
    def RightPadding(self, value):
        self.com_object.RightPadding = value

    @property
    def rightpadding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @rightpadding.setter
    def rightpadding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def right_padding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @right_padding.setter
    def right_padding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def RowSource(self):
        return self.com_object.RowSource

    @RowSource.setter
    def RowSource(self, value):
        self.com_object.RowSource = value

    @property
    def rowsource(self):
        """Alias for RowSource"""
        return self.RowSource

    @rowsource.setter
    def rowsource(self, value):
        """Alias for RowSource.setter"""
        self.RowSource = value

    @property
    def row_source(self):
        """Alias for RowSource"""
        return self.RowSource

    @row_source.setter
    def row_source(self, value):
        """Alias for RowSource.setter"""
        self.RowSource = value

    @property
    def RowSourceType(self):
        return self.com_object.RowSourceType

    @RowSourceType.setter
    def RowSourceType(self, value):
        self.com_object.RowSourceType = value

    @property
    def rowsourcetype(self):
        """Alias for RowSourceType"""
        return self.RowSourceType

    @rowsourcetype.setter
    def rowsourcetype(self, value):
        """Alias for RowSourceType.setter"""
        self.RowSourceType = value

    @property
    def row_source_type(self):
        """Alias for RowSourceType"""
        return self.RowSourceType

    @row_source_type.setter
    def row_source_type(self, value):
        """Alias for RowSourceType.setter"""
        self.RowSourceType = value

    @property
    def ScrollBarAlign(self):
        return self.com_object.ScrollBarAlign

    @ScrollBarAlign.setter
    def ScrollBarAlign(self, value):
        self.com_object.ScrollBarAlign = value

    @property
    def scrollbaralign(self):
        """Alias for ScrollBarAlign"""
        return self.ScrollBarAlign

    @scrollbaralign.setter
    def scrollbaralign(self, value):
        """Alias for ScrollBarAlign.setter"""
        self.ScrollBarAlign = value

    @property
    def scroll_bar_align(self):
        """Alias for ScrollBarAlign"""
        return self.ScrollBarAlign

    @scroll_bar_align.setter
    def scroll_bar_align(self, value):
        """Alias for ScrollBarAlign.setter"""
        self.ScrollBarAlign = value

    @property
    def Section(self):
        return self.com_object.Section

    @Section.setter
    def Section(self, value):
        self.com_object.Section = value

    @property
    def section(self):
        """Alias for Section"""
        return self.Section

    @section.setter
    def section(self, value):
        """Alias for Section.setter"""
        self.Section = value

    @property
    def Selected(self):
        return self.com_object.Selected

    @Selected.setter
    def Selected(self, value):
        self.com_object.Selected = value

    @property
    def selected(self):
        """Alias for Selected"""
        return self.Selected

    @selected.setter
    def selected(self, value):
        """Alias for Selected.setter"""
        self.Selected = value

    @property
    def ShortcutMenuBar(self):
        return self.com_object.ShortcutMenuBar

    @ShortcutMenuBar.setter
    def ShortcutMenuBar(self, value):
        self.com_object.ShortcutMenuBar = value

    @property
    def shortcutmenubar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcutmenubar.setter
    def shortcutmenubar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def shortcut_menu_bar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcut_menu_bar.setter
    def shortcut_menu_bar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def ShowOnlyRowSourceValues(self):
        return self.com_object.ShowOnlyRowSourceValues

    @ShowOnlyRowSourceValues.setter
    def ShowOnlyRowSourceValues(self, value):
        self.com_object.ShowOnlyRowSourceValues = value

    @property
    def showonlyrowsourcevalues(self):
        """Alias for ShowOnlyRowSourceValues"""
        return self.ShowOnlyRowSourceValues

    @showonlyrowsourcevalues.setter
    def showonlyrowsourcevalues(self, value):
        """Alias for ShowOnlyRowSourceValues.setter"""
        self.ShowOnlyRowSourceValues = value

    @property
    def show_only_row_source_values(self):
        """Alias for ShowOnlyRowSourceValues"""
        return self.ShowOnlyRowSourceValues

    @show_only_row_source_values.setter
    def show_only_row_source_values(self, value):
        """Alias for ShowOnlyRowSourceValues.setter"""
        self.ShowOnlyRowSourceValues = value

    @property
    def SmartTags(self):
        return SmartTags(self.com_object.SmartTags)

    @property
    def smarttags(self):
        """Alias for SmartTags"""
        return self.SmartTags

    @property
    def smart_tags(self):
        """Alias for SmartTags"""
        return self.SmartTags

    @property
    def SpecialEffect(self):
        return self.com_object.SpecialEffect

    @SpecialEffect.setter
    def SpecialEffect(self, value):
        self.com_object.SpecialEffect = value

    @property
    def specialeffect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @specialeffect.setter
    def specialeffect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def special_effect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @special_effect.setter
    def special_effect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def StatusBarText(self):
        return self.com_object.StatusBarText

    @StatusBarText.setter
    def StatusBarText(self, value):
        self.com_object.StatusBarText = value

    @property
    def statusbartext(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @statusbartext.setter
    def statusbartext(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def status_bar_text(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @status_bar_text.setter
    def status_bar_text(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def TabIndex(self):
        return self.com_object.TabIndex

    @TabIndex.setter
    def TabIndex(self, value):
        self.com_object.TabIndex = value

    @property
    def tabindex(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tabindex.setter
    def tabindex(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def tab_index(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tab_index.setter
    def tab_index(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def TabStop(self):
        return self.com_object.TabStop

    @TabStop.setter
    def TabStop(self, value):
        self.com_object.TabStop = value

    @property
    def tabstop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tabstop.setter
    def tabstop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def tab_stop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tab_stop.setter
    def tab_stop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def ThemeFontIndex(self):
        return self.com_object.ThemeFontIndex

    @ThemeFontIndex.setter
    def ThemeFontIndex(self, value):
        self.com_object.ThemeFontIndex = value

    @property
    def themefontindex(self):
        """Alias for ThemeFontIndex"""
        return self.ThemeFontIndex

    @themefontindex.setter
    def themefontindex(self, value):
        """Alias for ThemeFontIndex.setter"""
        self.ThemeFontIndex = value

    @property
    def theme_font_index(self):
        """Alias for ThemeFontIndex"""
        return self.ThemeFontIndex

    @theme_font_index.setter
    def theme_font_index(self, value):
        """Alias for ThemeFontIndex.setter"""
        self.ThemeFontIndex = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TopPadding(self):
        return self.com_object.TopPadding

    @TopPadding.setter
    def TopPadding(self, value):
        self.com_object.TopPadding = value

    @property
    def toppadding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @toppadding.setter
    def toppadding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def top_padding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @top_padding.setter
    def top_padding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def ValidationRule(self):
        return self.com_object.ValidationRule

    @ValidationRule.setter
    def ValidationRule(self, value):
        self.com_object.ValidationRule = value

    @property
    def validationrule(self):
        """Alias for ValidationRule"""
        return self.ValidationRule

    @validationrule.setter
    def validationrule(self, value):
        """Alias for ValidationRule.setter"""
        self.ValidationRule = value

    @property
    def validation_rule(self):
        """Alias for ValidationRule"""
        return self.ValidationRule

    @validation_rule.setter
    def validation_rule(self, value):
        """Alias for ValidationRule.setter"""
        self.ValidationRule = value

    @property
    def ValidationText(self):
        return self.com_object.ValidationText

    @ValidationText.setter
    def ValidationText(self, value):
        self.com_object.ValidationText = value

    @property
    def validationtext(self):
        """Alias for ValidationText"""
        return self.ValidationText

    @validationtext.setter
    def validationtext(self, value):
        """Alias for ValidationText.setter"""
        self.ValidationText = value

    @property
    def validation_text(self):
        """Alias for ValidationText"""
        return self.ValidationText

    @validation_text.setter
    def validation_text(self, value):
        """Alias for ValidationText.setter"""
        self.ValidationText = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def AddItem(self, Item=None, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Item, Index]])
        self.com_object.AddItem(*arguments)

    def additem(self, Item=None, Index=None):
        """Alias for AddItem"""
        arguments = [Item, Index]
        return self.AddItem(*arguments)

    def add_item(self, Item=None, Index=None):
        """Alias for AddItem"""
        arguments = [Item, Index]
        return self.AddItem(*arguments)

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def RemoveItem(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        self.com_object.RemoveItem(*arguments)

    def removeitem(self, Index=None):
        """Alias for RemoveItem"""
        arguments = [Index]
        return self.RemoveItem(*arguments)

    def remove_item(self, Index=None):
        """Alias for RemoveItem"""
        arguments = [Index]
        return self.RemoveItem(*arguments)

    def Requery(self):
        self.com_object.Requery()

    def requery(self):
        """Alias for Requery"""
        return self.Requery()

    def SetFocus(self):
        return self.com_object.SetFocus()

    def setfocus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def set_focus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def Undo(self):
        self.com_object.Undo()

    def undo(self):
        """Alias for Undo"""
        return self.Undo()


class MacroError:

    def __init__(self, macroerror=None):
        self.com_object= macroerror

    @property
    def ActionName(self):
        return self.com_object.ActionName

    @property
    def actionname(self):
        """Alias for ActionName"""
        return self.ActionName

    @property
    def action_name(self):
        """Alias for ActionName"""
        return self.ActionName

    @property
    def Arguments(self):
        return self.com_object.Arguments

    @property
    def arguments(self):
        """Alias for Arguments"""
        return self.Arguments

    @property
    def Condition(self):
        return self.com_object.Condition

    @property
    def condition(self):
        """Alias for Condition"""
        return self.Condition

    @property
    def Description(self):
        return self.com_object.Description

    @property
    def description(self):
        """Alias for Description"""
        return self.Description

    @property
    def MacroName(self):
        return self.com_object.MacroName

    @property
    def macroname(self):
        """Alias for MacroName"""
        return self.MacroName

    @property
    def macro_name(self):
        """Alias for MacroName"""
        return self.MacroName

    @property
    def Number(self):
        return self.com_object.Number

    @property
    def number(self):
        """Alias for Number"""
        return self.Number


class Module:

    def __init__(self, module=None):
        self.com_object= module

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def CountOfDeclarationLines(self):
        return self.com_object.CountOfDeclarationLines

    @property
    def countofdeclarationlines(self):
        """Alias for CountOfDeclarationLines"""
        return self.CountOfDeclarationLines

    @property
    def count_of_declaration_lines(self):
        """Alias for CountOfDeclarationLines"""
        return self.CountOfDeclarationLines

    @property
    def CountOfLines(self):
        return self.com_object.CountOfLines

    @property
    def countoflines(self):
        """Alias for CountOfLines"""
        return self.CountOfLines

    @property
    def count_of_lines(self):
        """Alias for CountOfLines"""
        return self.CountOfLines

    def Lines(self, Line=None, NumLines=None):
        arguments = com_arguments([unwrap(a) for a in [Line, NumLines]])
        if hasattr(self.com_object, "GetLines"):
            return self.com_object.GetLines(*arguments)
        else:
            return self.com_object.Lines(*arguments)

    def lines(self, Line=None, NumLines=None):
        """Alias for Lines"""
        arguments = [Line, NumLines]
        return self.Lines(*arguments)

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def ProcBodyLine(self, ProcName=None, ProcKind=None):
        arguments = com_arguments([unwrap(a) for a in [ProcName, ProcKind]])
        if hasattr(self.com_object, "GetProcBodyLine"):
            return self.com_object.GetProcBodyLine(*arguments)
        else:
            return self.com_object.ProcBodyLine(*arguments)

    def procbodyline(self, ProcName=None, ProcKind=None):
        """Alias for ProcBodyLine"""
        arguments = [ProcName, ProcKind]
        return self.ProcBodyLine(*arguments)

    def proc_body_line(self, ProcName=None, ProcKind=None):
        """Alias for ProcBodyLine"""
        arguments = [ProcName, ProcKind]
        return self.ProcBodyLine(*arguments)

    def ProcCountLines(self, ProcName=None, ProcKind=None):
        arguments = com_arguments([unwrap(a) for a in [ProcName, ProcKind]])
        if hasattr(self.com_object, "GetProcCountLines"):
            return self.com_object.GetProcCountLines(*arguments)
        else:
            return self.com_object.ProcCountLines(*arguments)

    def proccountlines(self, ProcName=None, ProcKind=None):
        """Alias for ProcCountLines"""
        arguments = [ProcName, ProcKind]
        return self.ProcCountLines(*arguments)

    def proc_count_lines(self, ProcName=None, ProcKind=None):
        """Alias for ProcCountLines"""
        arguments = [ProcName, ProcKind]
        return self.ProcCountLines(*arguments)

    def ProcOfLine(self, Line=None, ProcKind=None):
        arguments = com_arguments([unwrap(a) for a in [Line, ProcKind]])
        if hasattr(self.com_object, "GetProcOfLine"):
            return self.com_object.GetProcOfLine(*arguments)
        else:
            return self.com_object.ProcOfLine(*arguments)

    def procofline(self, Line=None, ProcKind=None):
        """Alias for ProcOfLine"""
        arguments = [Line, ProcKind]
        return self.ProcOfLine(*arguments)

    def proc_of_line(self, Line=None, ProcKind=None):
        """Alias for ProcOfLine"""
        arguments = [Line, ProcKind]
        return self.ProcOfLine(*arguments)

    def ProcStartLine(self, ProcName=None, ProcKind=None):
        arguments = com_arguments([unwrap(a) for a in [ProcName, ProcKind]])
        if hasattr(self.com_object, "GetProcStartLine"):
            return self.com_object.GetProcStartLine(*arguments)
        else:
            return self.com_object.ProcStartLine(*arguments)

    def procstartline(self, ProcName=None, ProcKind=None):
        """Alias for ProcStartLine"""
        arguments = [ProcName, ProcKind]
        return self.ProcStartLine(*arguments)

    def proc_start_line(self, ProcName=None, ProcKind=None):
        """Alias for ProcStartLine"""
        arguments = [ProcName, ProcKind]
        return self.ProcStartLine(*arguments)

    @property
    def Type(self):
        return self.com_object.Type

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def AddFromFile(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        self.com_object.AddFromFile(*arguments)

    def addfromfile(self, FileName=None):
        """Alias for AddFromFile"""
        arguments = [FileName]
        return self.AddFromFile(*arguments)

    def add_from_file(self, FileName=None):
        """Alias for AddFromFile"""
        arguments = [FileName]
        return self.AddFromFile(*arguments)

    def AddFromString(self, String=None):
        arguments = com_arguments([unwrap(a) for a in [String]])
        return self.com_object.AddFromString(*arguments)

    def addfromstring(self, String=None):
        """Alias for AddFromString"""
        arguments = [String]
        return self.AddFromString(*arguments)

    def add_from_string(self, String=None):
        """Alias for AddFromString"""
        arguments = [String]
        return self.AddFromString(*arguments)

    def CreateEventProc(self, EventName=None, ObjectName=None):
        arguments = com_arguments([unwrap(a) for a in [EventName, ObjectName]])
        return self.com_object.CreateEventProc(*arguments)

    def createeventproc(self, EventName=None, ObjectName=None):
        """Alias for CreateEventProc"""
        arguments = [EventName, ObjectName]
        return self.CreateEventProc(*arguments)

    def create_event_proc(self, EventName=None, ObjectName=None):
        """Alias for CreateEventProc"""
        arguments = [EventName, ObjectName]
        return self.CreateEventProc(*arguments)

    def DeleteLines(self, StartLine=None, Count=None):
        arguments = com_arguments([unwrap(a) for a in [StartLine, Count]])
        return self.com_object.DeleteLines(*arguments)

    def deletelines(self, StartLine=None, Count=None):
        """Alias for DeleteLines"""
        arguments = [StartLine, Count]
        return self.DeleteLines(*arguments)

    def delete_lines(self, StartLine=None, Count=None):
        """Alias for DeleteLines"""
        arguments = [StartLine, Count]
        return self.DeleteLines(*arguments)

    def Find(self, Target=None, StartLine=None, StartColumn=None, EndLine=None, EndColumn=None, WholeWord=None, MatchCase=None, PatternSearch=None):
        arguments = com_arguments([unwrap(a) for a in [Target, StartLine, StartColumn, EndLine, EndColumn, WholeWord, MatchCase, PatternSearch]])
        return self.com_object.Find(*arguments)

    def find(self, Target=None, StartLine=None, StartColumn=None, EndLine=None, EndColumn=None, WholeWord=None, MatchCase=None, PatternSearch=None):
        """Alias for Find"""
        arguments = [Target, StartLine, StartColumn, EndLine, EndColumn, WholeWord, MatchCase, PatternSearch]
        return self.Find(*arguments)

    def InsertLines(self, Line=None, String=None):
        arguments = com_arguments([unwrap(a) for a in [Line, String]])
        return self.com_object.InsertLines(*arguments)

    def insertlines(self, Line=None, String=None):
        """Alias for InsertLines"""
        arguments = [Line, String]
        return self.InsertLines(*arguments)

    def insert_lines(self, Line=None, String=None):
        """Alias for InsertLines"""
        arguments = [Line, String]
        return self.InsertLines(*arguments)

    def InsertText(self, Text=None):
        arguments = com_arguments([unwrap(a) for a in [Text]])
        return self.com_object.InsertText(*arguments)

    def inserttext(self, Text=None):
        """Alias for InsertText"""
        arguments = [Text]
        return self.InsertText(*arguments)

    def insert_text(self, Text=None):
        """Alias for InsertText"""
        arguments = [Text]
        return self.InsertText(*arguments)

    def ReplaceLine(self, Line=None, String=None):
        arguments = com_arguments([unwrap(a) for a in [Line, String]])
        return self.com_object.ReplaceLine(*arguments)

    def replaceline(self, Line=None, String=None):
        """Alias for ReplaceLine"""
        arguments = [Line, String]
        return self.ReplaceLine(*arguments)

    def replace_line(self, Line=None, String=None):
        """Alias for ReplaceLine"""
        arguments = [Line, String]
        return self.ReplaceLine(*arguments)


class Modules:

    def __init__(self, modules=None):
        self.com_object= modules

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class NavigationButton:

    def __init__(self, navigationbutton=None):
        self.com_object= navigationbutton

    @property
    def AddColon(self):
        return self.com_object.AddColon

    @AddColon.setter
    def AddColon(self, value):
        self.com_object.AddColon = value

    @property
    def addcolon(self):
        """Alias for AddColon"""
        return self.AddColon

    @addcolon.setter
    def addcolon(self, value):
        """Alias for AddColon.setter"""
        self.AddColon = value

    @property
    def add_colon(self):
        """Alias for AddColon"""
        return self.AddColon

    @add_colon.setter
    def add_colon(self, value):
        """Alias for AddColon.setter"""
        self.AddColon = value

    @property
    def Alignment(self):
        return self.com_object.Alignment

    @Alignment.setter
    def Alignment(self, value):
        self.com_object.Alignment = value

    @property
    def alignment(self):
        """Alias for Alignment"""
        return self.Alignment

    @alignment.setter
    def alignment(self, value):
        """Alias for Alignment.setter"""
        self.Alignment = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoLabel(self):
        return self.com_object.AutoLabel

    @AutoLabel.setter
    def AutoLabel(self, value):
        self.com_object.AutoLabel = value

    @property
    def autolabel(self):
        """Alias for AutoLabel"""
        return self.AutoLabel

    @autolabel.setter
    def autolabel(self, value):
        """Alias for AutoLabel.setter"""
        self.AutoLabel = value

    @property
    def auto_label(self):
        """Alias for AutoLabel"""
        return self.AutoLabel

    @auto_label.setter
    def auto_label(self, value):
        """Alias for AutoLabel.setter"""
        self.AutoLabel = value

    @property
    def AutoRepeat(self):
        return self.com_object.AutoRepeat

    @AutoRepeat.setter
    def AutoRepeat(self, value):
        self.com_object.AutoRepeat = value

    @property
    def autorepeat(self):
        """Alias for AutoRepeat"""
        return self.AutoRepeat

    @autorepeat.setter
    def autorepeat(self, value):
        """Alias for AutoRepeat.setter"""
        self.AutoRepeat = value

    @property
    def auto_repeat(self):
        """Alias for AutoRepeat"""
        return self.AutoRepeat

    @auto_repeat.setter
    def auto_repeat(self, value):
        """Alias for AutoRepeat.setter"""
        self.AutoRepeat = value

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BackShade(self):
        return self.com_object.BackShade

    @BackShade.setter
    def BackShade(self, value):
        self.com_object.BackShade = value

    @property
    def backshade(self):
        """Alias for BackShade"""
        return self.BackShade

    @backshade.setter
    def backshade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def back_shade(self):
        """Alias for BackShade"""
        return self.BackShade

    @back_shade.setter
    def back_shade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def BackStyle(self):
        return self.com_object.BackStyle

    @BackStyle.setter
    def BackStyle(self, value):
        self.com_object.BackStyle = value

    @property
    def backstyle(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @backstyle.setter
    def backstyle(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def back_style(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @back_style.setter
    def back_style(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def BackThemeColorIndex(self):
        return self.com_object.BackThemeColorIndex

    @BackThemeColorIndex.setter
    def BackThemeColorIndex(self, value):
        self.com_object.BackThemeColorIndex = value

    @property
    def backthemecolorindex(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @backthemecolorindex.setter
    def backthemecolorindex(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def back_theme_color_index(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @back_theme_color_index.setter
    def back_theme_color_index(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def BackTint(self):
        return self.com_object.BackTint

    @BackTint.setter
    def BackTint(self, value):
        self.com_object.BackTint = value

    @property
    def backtint(self):
        """Alias for BackTint"""
        return self.BackTint

    @backtint.setter
    def backtint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def back_tint(self):
        """Alias for BackTint"""
        return self.BackTint

    @back_tint.setter
    def back_tint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def Bevel(self):
        return self.com_object.Bevel

    @Bevel.setter
    def Bevel(self, value):
        self.com_object.Bevel = value

    @property
    def bevel(self):
        """Alias for Bevel"""
        return self.Bevel

    @bevel.setter
    def bevel(self, value):
        """Alias for Bevel.setter"""
        self.Bevel = value

    @property
    def BorderColor(self):
        return self.com_object.BorderColor

    @BorderColor.setter
    def BorderColor(self, value):
        self.com_object.BorderColor = value

    @property
    def bordercolor(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @bordercolor.setter
    def bordercolor(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def border_color(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @border_color.setter
    def border_color(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def BorderShade(self):
        return self.com_object.BorderShade

    @BorderShade.setter
    def BorderShade(self, value):
        self.com_object.BorderShade = value

    @property
    def bordershade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @bordershade.setter
    def bordershade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def border_shade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @border_shade.setter
    def border_shade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def BorderStyle(self):
        return self.com_object.BorderStyle

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def BorderThemeColorIndex(self):
        return self.com_object.BorderThemeColorIndex

    @BorderThemeColorIndex.setter
    def BorderThemeColorIndex(self, value):
        self.com_object.BorderThemeColorIndex = value

    @property
    def borderthemecolorindex(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @borderthemecolorindex.setter
    def borderthemecolorindex(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def border_theme_color_index(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @border_theme_color_index.setter
    def border_theme_color_index(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def BorderTint(self):
        return self.com_object.BorderTint

    @BorderTint.setter
    def BorderTint(self, value):
        self.com_object.BorderTint = value

    @property
    def bordertint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @bordertint.setter
    def bordertint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def border_tint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @border_tint.setter
    def border_tint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def BorderWidth(self):
        return self.com_object.BorderWidth

    @BorderWidth.setter
    def BorderWidth(self, value):
        self.com_object.BorderWidth = value

    @property
    def borderwidth(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @borderwidth.setter
    def borderwidth(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def border_width(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @border_width.setter
    def border_width(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def BottomPadding(self):
        return self.com_object.BottomPadding

    @BottomPadding.setter
    def BottomPadding(self, value):
        self.com_object.BottomPadding = value

    @property
    def bottompadding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottompadding.setter
    def bottompadding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def bottom_padding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottom_padding.setter
    def bottom_padding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    @property
    def Controls(self):
        return Controls(self.com_object.Controls)

    @property
    def controls(self):
        """Alias for Controls"""
        return self.Controls

    @property
    def ControlTipText(self):
        return self.com_object.ControlTipText

    @ControlTipText.setter
    def ControlTipText(self, value):
        self.com_object.ControlTipText = value

    @property
    def controltiptext(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @controltiptext.setter
    def controltiptext(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def control_tip_text(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @control_tip_text.setter
    def control_tip_text(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def ControlType(self):
        return self.com_object.ControlType

    @ControlType.setter
    def ControlType(self, value):
        self.com_object.ControlType = value

    @property
    def controltype(self):
        """Alias for ControlType"""
        return self.ControlType

    @controltype.setter
    def controltype(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def control_type(self):
        """Alias for ControlType"""
        return self.ControlType

    @control_type.setter
    def control_type(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def CursorOnHover(self):
        return self.com_object.CursorOnHover

    @CursorOnHover.setter
    def CursorOnHover(self, value):
        self.com_object.CursorOnHover = value

    @property
    def cursoronhover(self):
        """Alias for CursorOnHover"""
        return self.CursorOnHover

    @cursoronhover.setter
    def cursoronhover(self, value):
        """Alias for CursorOnHover.setter"""
        self.CursorOnHover = value

    @property
    def cursor_on_hover(self):
        """Alias for CursorOnHover"""
        return self.CursorOnHover

    @cursor_on_hover.setter
    def cursor_on_hover(self, value):
        """Alias for CursorOnHover.setter"""
        self.CursorOnHover = value

    @property
    def DisplayWhen(self):
        return self.com_object.DisplayWhen

    @DisplayWhen.setter
    def DisplayWhen(self, value):
        self.com_object.DisplayWhen = value

    @property
    def displaywhen(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @displaywhen.setter
    def displaywhen(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def display_when(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @display_when.setter
    def display_when(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def FontBold(self):
        return self.com_object.FontBold

    @property
    def fontbold(self):
        """Alias for FontBold"""
        return self.FontBold

    @property
    def font_bold(self):
        """Alias for FontBold"""
        return self.FontBold

    @property
    def FontItalic(self):
        return self.com_object.FontItalic

    @property
    def fontitalic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @property
    def font_italic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @property
    def FontName(self):
        return self.com_object.FontName

    @property
    def fontname(self):
        """Alias for FontName"""
        return self.FontName

    @property
    def font_name(self):
        """Alias for FontName"""
        return self.FontName

    @property
    def FontSize(self):
        return self.com_object.FontSize

    @property
    def fontsize(self):
        """Alias for FontSize"""
        return self.FontSize

    @property
    def font_size(self):
        """Alias for FontSize"""
        return self.FontSize

    @property
    def FontUnderline(self):
        return self.com_object.FontUnderline

    @property
    def fontunderline(self):
        """Alias for FontUnderline"""
        return self.FontUnderline

    @property
    def font_underline(self):
        """Alias for FontUnderline"""
        return self.FontUnderline

    @property
    def FontWeight(self):
        return self.com_object.FontWeight

    @FontWeight.setter
    def FontWeight(self, value):
        self.com_object.FontWeight = value

    @property
    def fontweight(self):
        """Alias for FontWeight"""
        return self.FontWeight

    @fontweight.setter
    def fontweight(self, value):
        """Alias for FontWeight.setter"""
        self.FontWeight = value

    @property
    def font_weight(self):
        """Alias for FontWeight"""
        return self.FontWeight

    @font_weight.setter
    def font_weight(self, value):
        """Alias for FontWeight.setter"""
        self.FontWeight = value

    @property
    def ForeColor(self):
        return self.com_object.ForeColor

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def ForeShade(self):
        return self.com_object.ForeShade

    @ForeShade.setter
    def ForeShade(self, value):
        self.com_object.ForeShade = value

    @property
    def foreshade(self):
        """Alias for ForeShade"""
        return self.ForeShade

    @foreshade.setter
    def foreshade(self, value):
        """Alias for ForeShade.setter"""
        self.ForeShade = value

    @property
    def fore_shade(self):
        """Alias for ForeShade"""
        return self.ForeShade

    @fore_shade.setter
    def fore_shade(self, value):
        """Alias for ForeShade.setter"""
        self.ForeShade = value

    @property
    def ForeThemeColorIndex(self):
        return self.com_object.ForeThemeColorIndex

    @ForeThemeColorIndex.setter
    def ForeThemeColorIndex(self, value):
        self.com_object.ForeThemeColorIndex = value

    @property
    def forethemecolorindex(self):
        """Alias for ForeThemeColorIndex"""
        return self.ForeThemeColorIndex

    @forethemecolorindex.setter
    def forethemecolorindex(self, value):
        """Alias for ForeThemeColorIndex.setter"""
        self.ForeThemeColorIndex = value

    @property
    def fore_theme_color_index(self):
        """Alias for ForeThemeColorIndex"""
        return self.ForeThemeColorIndex

    @fore_theme_color_index.setter
    def fore_theme_color_index(self, value):
        """Alias for ForeThemeColorIndex.setter"""
        self.ForeThemeColorIndex = value

    @property
    def ForeTint(self):
        return self.com_object.ForeTint

    @ForeTint.setter
    def ForeTint(self, value):
        self.com_object.ForeTint = value

    @property
    def foretint(self):
        """Alias for ForeTint"""
        return self.ForeTint

    @foretint.setter
    def foretint(self, value):
        """Alias for ForeTint.setter"""
        self.ForeTint = value

    @property
    def fore_tint(self):
        """Alias for ForeTint"""
        return self.ForeTint

    @fore_tint.setter
    def fore_tint(self, value):
        """Alias for ForeTint.setter"""
        self.ForeTint = value

    @property
    def Glow(self):
        return self.com_object.Glow

    @Glow.setter
    def Glow(self, value):
        self.com_object.Glow = value

    @property
    def glow(self):
        """Alias for Glow"""
        return self.Glow

    @glow.setter
    def glow(self, value):
        """Alias for Glow.setter"""
        self.Glow = value

    @property
    def Gradient(self):
        return self.com_object.Gradient

    @Gradient.setter
    def Gradient(self, value):
        self.com_object.Gradient = value

    @property
    def gradient(self):
        """Alias for Gradient"""
        return self.Gradient

    @gradient.setter
    def gradient(self, value):
        """Alias for Gradient.setter"""
        self.Gradient = value

    @property
    def GridlineColor(self):
        return self.com_object.GridlineColor

    @GridlineColor.setter
    def GridlineColor(self, value):
        self.com_object.GridlineColor = value

    @property
    def gridlinecolor(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridlinecolor.setter
    def gridlinecolor(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def gridline_color(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridline_color.setter
    def gridline_color(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def GridlineShade(self):
        return self.com_object.GridlineShade

    @GridlineShade.setter
    def GridlineShade(self, value):
        self.com_object.GridlineShade = value

    @property
    def gridlineshade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridlineshade.setter
    def gridlineshade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def gridline_shade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridline_shade.setter
    def gridline_shade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def GridlineStyleBottom(self):
        return self.com_object.GridlineStyleBottom

    @GridlineStyleBottom.setter
    def GridlineStyleBottom(self, value):
        self.com_object.GridlineStyleBottom = value

    @property
    def gridlinestylebottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridlinestylebottom.setter
    def gridlinestylebottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def gridline_style_bottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridline_style_bottom.setter
    def gridline_style_bottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def GridlineStyleLeft(self):
        return self.com_object.GridlineStyleLeft

    @GridlineStyleLeft.setter
    def GridlineStyleLeft(self, value):
        self.com_object.GridlineStyleLeft = value

    @property
    def gridlinestyleleft(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridlinestyleleft.setter
    def gridlinestyleleft(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def gridline_style_left(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridline_style_left.setter
    def gridline_style_left(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def GridlineStyleRight(self):
        return self.com_object.GridlineStyleRight

    @GridlineStyleRight.setter
    def GridlineStyleRight(self, value):
        self.com_object.GridlineStyleRight = value

    @property
    def gridlinestyleright(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridlinestyleright.setter
    def gridlinestyleright(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def gridline_style_right(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridline_style_right.setter
    def gridline_style_right(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def GridlineStyleTop(self):
        return self.com_object.GridlineStyleTop

    @GridlineStyleTop.setter
    def GridlineStyleTop(self, value):
        self.com_object.GridlineStyleTop = value

    @property
    def gridlinestyletop(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridlinestyletop.setter
    def gridlinestyletop(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def gridline_style_top(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridline_style_top.setter
    def gridline_style_top(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def GridlineThemeColorIndex(self):
        return self.com_object.GridlineThemeColorIndex

    @GridlineThemeColorIndex.setter
    def GridlineThemeColorIndex(self, value):
        self.com_object.GridlineThemeColorIndex = value

    @property
    def gridlinethemecolorindex(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridlinethemecolorindex.setter
    def gridlinethemecolorindex(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def gridline_theme_color_index(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridline_theme_color_index.setter
    def gridline_theme_color_index(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def GridlineTint(self):
        return self.com_object.GridlineTint

    @GridlineTint.setter
    def GridlineTint(self, value):
        self.com_object.GridlineTint = value

    @property
    def gridlinetint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridlinetint.setter
    def gridlinetint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def gridline_tint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridline_tint.setter
    def gridline_tint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def GridlineWidthBottom(self):
        return self.com_object.GridlineWidthBottom

    @GridlineWidthBottom.setter
    def GridlineWidthBottom(self, value):
        self.com_object.GridlineWidthBottom = value

    @property
    def gridlinewidthbottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridlinewidthbottom.setter
    def gridlinewidthbottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def gridline_width_bottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridline_width_bottom.setter
    def gridline_width_bottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def GridlineWidthLeft(self):
        return self.com_object.GridlineWidthLeft

    @GridlineWidthLeft.setter
    def GridlineWidthLeft(self, value):
        self.com_object.GridlineWidthLeft = value

    @property
    def gridlinewidthleft(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridlinewidthleft.setter
    def gridlinewidthleft(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def gridline_width_left(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridline_width_left.setter
    def gridline_width_left(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def GridlineWidthRight(self):
        return self.com_object.GridlineWidthRight

    @GridlineWidthRight.setter
    def GridlineWidthRight(self, value):
        self.com_object.GridlineWidthRight = value

    @property
    def gridlinewidthright(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridlinewidthright.setter
    def gridlinewidthright(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def gridline_width_right(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridline_width_right.setter
    def gridline_width_right(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def GridlineWidthTop(self):
        return self.com_object.GridlineWidthTop

    @GridlineWidthTop.setter
    def GridlineWidthTop(self, value):
        self.com_object.GridlineWidthTop = value

    @property
    def gridlinewidthtop(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridlinewidthtop.setter
    def gridlinewidthtop(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def gridline_width_top(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridline_width_top.setter
    def gridline_width_top(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HelpContextId(self):
        return self.com_object.HelpContextId

    @HelpContextId.setter
    def HelpContextId(self, value):
        self.com_object.HelpContextId = value

    @property
    def helpcontextid(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @helpcontextid.setter
    def helpcontextid(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def help_context_id(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @help_context_id.setter
    def help_context_id(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def HoverColor(self):
        return self.com_object.HoverColor

    @HoverColor.setter
    def HoverColor(self, value):
        self.com_object.HoverColor = value

    @property
    def hovercolor(self):
        """Alias for HoverColor"""
        return self.HoverColor

    @hovercolor.setter
    def hovercolor(self, value):
        """Alias for HoverColor.setter"""
        self.HoverColor = value

    @property
    def hover_color(self):
        """Alias for HoverColor"""
        return self.HoverColor

    @hover_color.setter
    def hover_color(self, value):
        """Alias for HoverColor.setter"""
        self.HoverColor = value

    @property
    def HoverForeColor(self):
        return self.com_object.HoverForeColor

    @HoverForeColor.setter
    def HoverForeColor(self, value):
        self.com_object.HoverForeColor = value

    @property
    def hoverforecolor(self):
        """Alias for HoverForeColor"""
        return self.HoverForeColor

    @hoverforecolor.setter
    def hoverforecolor(self, value):
        """Alias for HoverForeColor.setter"""
        self.HoverForeColor = value

    @property
    def hover_fore_color(self):
        """Alias for HoverForeColor"""
        return self.HoverForeColor

    @hover_fore_color.setter
    def hover_fore_color(self, value):
        """Alias for HoverForeColor.setter"""
        self.HoverForeColor = value

    @property
    def HoverForeShade(self):
        return self.com_object.HoverForeShade

    @HoverForeShade.setter
    def HoverForeShade(self, value):
        self.com_object.HoverForeShade = value

    @property
    def hoverforeshade(self):
        """Alias for HoverForeShade"""
        return self.HoverForeShade

    @hoverforeshade.setter
    def hoverforeshade(self, value):
        """Alias for HoverForeShade.setter"""
        self.HoverForeShade = value

    @property
    def hover_fore_shade(self):
        """Alias for HoverForeShade"""
        return self.HoverForeShade

    @hover_fore_shade.setter
    def hover_fore_shade(self, value):
        """Alias for HoverForeShade.setter"""
        self.HoverForeShade = value

    @property
    def HoverForeThemeColorIndex(self):
        return self.com_object.HoverForeThemeColorIndex

    @HoverForeThemeColorIndex.setter
    def HoverForeThemeColorIndex(self, value):
        self.com_object.HoverForeThemeColorIndex = value

    @property
    def hoverforethemecolorindex(self):
        """Alias for HoverForeThemeColorIndex"""
        return self.HoverForeThemeColorIndex

    @hoverforethemecolorindex.setter
    def hoverforethemecolorindex(self, value):
        """Alias for HoverForeThemeColorIndex.setter"""
        self.HoverForeThemeColorIndex = value

    @property
    def hover_fore_theme_color_index(self):
        """Alias for HoverForeThemeColorIndex"""
        return self.HoverForeThemeColorIndex

    @hover_fore_theme_color_index.setter
    def hover_fore_theme_color_index(self, value):
        """Alias for HoverForeThemeColorIndex.setter"""
        self.HoverForeThemeColorIndex = value

    @property
    def HoverForeTint(self):
        return self.com_object.HoverForeTint

    @HoverForeTint.setter
    def HoverForeTint(self, value):
        self.com_object.HoverForeTint = value

    @property
    def hoverforetint(self):
        """Alias for HoverForeTint"""
        return self.HoverForeTint

    @hoverforetint.setter
    def hoverforetint(self, value):
        """Alias for HoverForeTint.setter"""
        self.HoverForeTint = value

    @property
    def hover_fore_tint(self):
        """Alias for HoverForeTint"""
        return self.HoverForeTint

    @hover_fore_tint.setter
    def hover_fore_tint(self, value):
        """Alias for HoverForeTint.setter"""
        self.HoverForeTint = value

    @property
    def HoverShade(self):
        return self.com_object.HoverShade

    @HoverShade.setter
    def HoverShade(self, value):
        self.com_object.HoverShade = value

    @property
    def hovershade(self):
        """Alias for HoverShade"""
        return self.HoverShade

    @hovershade.setter
    def hovershade(self, value):
        """Alias for HoverShade.setter"""
        self.HoverShade = value

    @property
    def hover_shade(self):
        """Alias for HoverShade"""
        return self.HoverShade

    @hover_shade.setter
    def hover_shade(self, value):
        """Alias for HoverShade.setter"""
        self.HoverShade = value

    @property
    def HoverThemeColorIndex(self):
        return self.com_object.HoverThemeColorIndex

    @HoverThemeColorIndex.setter
    def HoverThemeColorIndex(self, value):
        self.com_object.HoverThemeColorIndex = value

    @property
    def hoverthemecolorindex(self):
        """Alias for HoverThemeColorIndex"""
        return self.HoverThemeColorIndex

    @hoverthemecolorindex.setter
    def hoverthemecolorindex(self, value):
        """Alias for HoverThemeColorIndex.setter"""
        self.HoverThemeColorIndex = value

    @property
    def hover_theme_color_index(self):
        """Alias for HoverThemeColorIndex"""
        return self.HoverThemeColorIndex

    @hover_theme_color_index.setter
    def hover_theme_color_index(self, value):
        """Alias for HoverThemeColorIndex.setter"""
        self.HoverThemeColorIndex = value

    @property
    def HoverTint(self):
        return self.com_object.HoverTint

    @HoverTint.setter
    def HoverTint(self, value):
        self.com_object.HoverTint = value

    @property
    def hovertint(self):
        """Alias for HoverTint"""
        return self.HoverTint

    @hovertint.setter
    def hovertint(self, value):
        """Alias for HoverTint.setter"""
        self.HoverTint = value

    @property
    def hover_tint(self):
        """Alias for HoverTint"""
        return self.HoverTint

    @hover_tint.setter
    def hover_tint(self, value):
        """Alias for HoverTint.setter"""
        self.HoverTint = value

    @property
    def Hyperlink(self):
        return self.com_object.Hyperlink

    @property
    def hyperlink(self):
        """Alias for Hyperlink"""
        return self.Hyperlink

    @property
    def HyperlinkAddress(self):
        return self.com_object.HyperlinkAddress

    @HyperlinkAddress.setter
    def HyperlinkAddress(self, value):
        self.com_object.HyperlinkAddress = value

    @property
    def hyperlinkaddress(self):
        """Alias for HyperlinkAddress"""
        return self.HyperlinkAddress

    @hyperlinkaddress.setter
    def hyperlinkaddress(self, value):
        """Alias for HyperlinkAddress.setter"""
        self.HyperlinkAddress = value

    @property
    def hyperlink_address(self):
        """Alias for HyperlinkAddress"""
        return self.HyperlinkAddress

    @hyperlink_address.setter
    def hyperlink_address(self, value):
        """Alias for HyperlinkAddress.setter"""
        self.HyperlinkAddress = value

    @property
    def HyperlinkSubAddress(self):
        return self.com_object.HyperlinkSubAddress

    @HyperlinkSubAddress.setter
    def HyperlinkSubAddress(self, value):
        self.com_object.HyperlinkSubAddress = value

    @property
    def hyperlinksubaddress(self):
        """Alias for HyperlinkSubAddress"""
        return self.HyperlinkSubAddress

    @hyperlinksubaddress.setter
    def hyperlinksubaddress(self, value):
        """Alias for HyperlinkSubAddress.setter"""
        self.HyperlinkSubAddress = value

    @property
    def hyperlink_sub_address(self):
        """Alias for HyperlinkSubAddress"""
        return self.HyperlinkSubAddress

    @hyperlink_sub_address.setter
    def hyperlink_sub_address(self, value):
        """Alias for HyperlinkSubAddress.setter"""
        self.HyperlinkSubAddress = value

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def IsVisible(self):
        return self.com_object.IsVisible

    @IsVisible.setter
    def IsVisible(self, value):
        self.com_object.IsVisible = value

    @property
    def isvisible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @isvisible.setter
    def isvisible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def is_visible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @is_visible.setter
    def is_visible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def LabelAlign(self):
        return self.com_object.LabelAlign

    @LabelAlign.setter
    def LabelAlign(self, value):
        self.com_object.LabelAlign = value

    @property
    def labelalign(self):
        """Alias for LabelAlign"""
        return self.LabelAlign

    @labelalign.setter
    def labelalign(self, value):
        """Alias for LabelAlign.setter"""
        self.LabelAlign = value

    @property
    def label_align(self):
        """Alias for LabelAlign"""
        return self.LabelAlign

    @label_align.setter
    def label_align(self, value):
        """Alias for LabelAlign.setter"""
        self.LabelAlign = value

    @property
    def LabelX(self):
        return self.com_object.LabelX

    @LabelX.setter
    def LabelX(self, value):
        self.com_object.LabelX = value

    @property
    def labelx(self):
        """Alias for LabelX"""
        return self.LabelX

    @labelx.setter
    def labelx(self, value):
        """Alias for LabelX.setter"""
        self.LabelX = value

    @property
    def label_x(self):
        """Alias for LabelX"""
        return self.LabelX

    @label_x.setter
    def label_x(self, value):
        """Alias for LabelX.setter"""
        self.LabelX = value

    @property
    def LabelY(self):
        return self.com_object.LabelY

    @LabelY.setter
    def LabelY(self, value):
        self.com_object.LabelY = value

    @property
    def labely(self):
        """Alias for LabelY"""
        return self.LabelY

    @labely.setter
    def labely(self, value):
        """Alias for LabelY.setter"""
        self.LabelY = value

    @property
    def label_y(self):
        """Alias for LabelY"""
        return self.LabelY

    @label_y.setter
    def label_y(self, value):
        """Alias for LabelY.setter"""
        self.LabelY = value

    @property
    def Layout(self):
        return AcLayoutType(self.com_object.Layout)

    @property
    def layout(self):
        """Alias for Layout"""
        return self.Layout

    @property
    def LayoutID(self):
        return self.com_object.LayoutID

    @property
    def layoutid(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def layout_i_d(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def LeftPadding(self):
        return self.com_object.LeftPadding

    @LeftPadding.setter
    def LeftPadding(self, value):
        self.com_object.LeftPadding = value

    @property
    def leftpadding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @leftpadding.setter
    def leftpadding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def left_padding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @left_padding.setter
    def left_padding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def NavigationTargetName(self):
        return self.com_object.NavigationTargetName

    @NavigationTargetName.setter
    def NavigationTargetName(self, value):
        self.com_object.NavigationTargetName = value

    @property
    def navigationtargetname(self):
        """Alias for NavigationTargetName"""
        return self.NavigationTargetName

    @navigationtargetname.setter
    def navigationtargetname(self, value):
        """Alias for NavigationTargetName.setter"""
        self.NavigationTargetName = value

    @property
    def navigation_target_name(self):
        """Alias for NavigationTargetName"""
        return self.NavigationTargetName

    @navigation_target_name.setter
    def navigation_target_name(self, value):
        """Alias for NavigationTargetName.setter"""
        self.NavigationTargetName = value

    @property
    def NavigationWhereClause(self):
        return self.com_object.NavigationWhereClause

    @NavigationWhereClause.setter
    def NavigationWhereClause(self, value):
        self.com_object.NavigationWhereClause = value

    @property
    def navigationwhereclause(self):
        """Alias for NavigationWhereClause"""
        return self.NavigationWhereClause

    @navigationwhereclause.setter
    def navigationwhereclause(self, value):
        """Alias for NavigationWhereClause.setter"""
        self.NavigationWhereClause = value

    @property
    def navigation_where_clause(self):
        """Alias for NavigationWhereClause"""
        return self.NavigationWhereClause

    @navigation_where_clause.setter
    def navigation_where_clause(self, value):
        """Alias for NavigationWhereClause.setter"""
        self.NavigationWhereClause = value

    @property
    def ObjectPalette(self):
        return self.com_object.ObjectPalette

    @ObjectPalette.setter
    def ObjectPalette(self, value):
        self.com_object.ObjectPalette = value

    @property
    def objectpalette(self):
        """Alias for ObjectPalette"""
        return self.ObjectPalette

    @objectpalette.setter
    def objectpalette(self, value):
        """Alias for ObjectPalette.setter"""
        self.ObjectPalette = value

    @property
    def object_palette(self):
        """Alias for ObjectPalette"""
        return self.ObjectPalette

    @object_palette.setter
    def object_palette(self, value):
        """Alias for ObjectPalette.setter"""
        self.ObjectPalette = value

    @property
    def OldValue(self):
        return self.com_object.OldValue

    @property
    def oldvalue(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def old_value(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def OnClick(self):
        return self.com_object.OnClick

    @OnClick.setter
    def OnClick(self, value):
        self.com_object.OnClick = value

    @property
    def onclick(self):
        """Alias for OnClick"""
        return self.OnClick

    @onclick.setter
    def onclick(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def on_click(self):
        """Alias for OnClick"""
        return self.OnClick

    @on_click.setter
    def on_click(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def OnDblClick(self):
        return self.com_object.OnDblClick

    @OnDblClick.setter
    def OnDblClick(self, value):
        self.com_object.OnDblClick = value

    @property
    def ondblclick(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @ondblclick.setter
    def ondblclick(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def on_dbl_click(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @on_dbl_click.setter
    def on_dbl_click(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def OnEnter(self):
        return self.com_object.OnEnter

    @OnEnter.setter
    def OnEnter(self, value):
        self.com_object.OnEnter = value

    @property
    def onenter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @onenter.setter
    def onenter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def on_enter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @on_enter.setter
    def on_enter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def OnExit(self):
        return self.com_object.OnExit

    @OnExit.setter
    def OnExit(self, value):
        self.com_object.OnExit = value

    @property
    def onexit(self):
        """Alias for OnExit"""
        return self.OnExit

    @onexit.setter
    def onexit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def on_exit(self):
        """Alias for OnExit"""
        return self.OnExit

    @on_exit.setter
    def on_exit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def OnGotFocus(self):
        return self.com_object.OnGotFocus

    @OnGotFocus.setter
    def OnGotFocus(self, value):
        self.com_object.OnGotFocus = value

    @property
    def ongotfocus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @ongotfocus.setter
    def ongotfocus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def on_got_focus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @on_got_focus.setter
    def on_got_focus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def OnKeyDown(self):
        return self.com_object.OnKeyDown

    @OnKeyDown.setter
    def OnKeyDown(self, value):
        self.com_object.OnKeyDown = value

    @property
    def onkeydown(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @onkeydown.setter
    def onkeydown(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def on_key_down(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @on_key_down.setter
    def on_key_down(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def OnKeyPress(self):
        return self.com_object.OnKeyPress

    @OnKeyPress.setter
    def OnKeyPress(self, value):
        self.com_object.OnKeyPress = value

    @property
    def onkeypress(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @onkeypress.setter
    def onkeypress(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def on_key_press(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @on_key_press.setter
    def on_key_press(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def OnKeyUp(self):
        return self.com_object.OnKeyUp

    @OnKeyUp.setter
    def OnKeyUp(self, value):
        self.com_object.OnKeyUp = value

    @property
    def onkeyup(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @onkeyup.setter
    def onkeyup(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def on_key_up(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @on_key_up.setter
    def on_key_up(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def OnLostFocus(self):
        return self.com_object.OnLostFocus

    @OnLostFocus.setter
    def OnLostFocus(self, value):
        self.com_object.OnLostFocus = value

    @property
    def onlostfocus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @onlostfocus.setter
    def onlostfocus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def on_lost_focus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @on_lost_focus.setter
    def on_lost_focus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def OnMouseDown(self):
        return self.com_object.OnMouseDown

    @OnMouseDown.setter
    def OnMouseDown(self, value):
        self.com_object.OnMouseDown = value

    @property
    def onmousedown(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @onmousedown.setter
    def onmousedown(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def on_mouse_down(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @on_mouse_down.setter
    def on_mouse_down(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def OnMouseMove(self):
        return self.com_object.OnMouseMove

    @OnMouseMove.setter
    def OnMouseMove(self, value):
        self.com_object.OnMouseMove = value

    @property
    def onmousemove(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @onmousemove.setter
    def onmousemove(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def on_mouse_move(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @on_mouse_move.setter
    def on_mouse_move(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def OnMouseUp(self):
        return self.com_object.OnMouseUp

    @OnMouseUp.setter
    def OnMouseUp(self, value):
        self.com_object.OnMouseUp = value

    @property
    def onmouseup(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @onmouseup.setter
    def onmouseup(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def on_mouse_up(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @on_mouse_up.setter
    def on_mouse_up(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def OnPush(self):
        return self.com_object.OnPush

    @OnPush.setter
    def OnPush(self, value):
        self.com_object.OnPush = value

    @property
    def onpush(self):
        """Alias for OnPush"""
        return self.OnPush

    @onpush.setter
    def onpush(self, value):
        """Alias for OnPush.setter"""
        self.OnPush = value

    @property
    def on_push(self):
        """Alias for OnPush"""
        return self.OnPush

    @on_push.setter
    def on_push(self, value):
        """Alias for OnPush.setter"""
        self.OnPush = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def ParentTab(self):
        return self.com_object.ParentTab

    @property
    def parenttab(self):
        """Alias for ParentTab"""
        return self.ParentTab

    @property
    def parent_tab(self):
        """Alias for ParentTab"""
        return self.ParentTab

    @property
    def Picture(self):
        return self.com_object.Picture

    @Picture.setter
    def Picture(self, value):
        self.com_object.Picture = value

    @property
    def picture(self):
        """Alias for Picture"""
        return self.Picture

    @picture.setter
    def picture(self, value):
        """Alias for Picture.setter"""
        self.Picture = value

    @property
    def PictureCaptionArrangement(self):
        return self.com_object.PictureCaptionArrangement

    @PictureCaptionArrangement.setter
    def PictureCaptionArrangement(self, value):
        self.com_object.PictureCaptionArrangement = value

    @property
    def picturecaptionarrangement(self):
        """Alias for PictureCaptionArrangement"""
        return self.PictureCaptionArrangement

    @picturecaptionarrangement.setter
    def picturecaptionarrangement(self, value):
        """Alias for PictureCaptionArrangement.setter"""
        self.PictureCaptionArrangement = value

    @property
    def picture_caption_arrangement(self):
        """Alias for PictureCaptionArrangement"""
        return self.PictureCaptionArrangement

    @picture_caption_arrangement.setter
    def picture_caption_arrangement(self, value):
        """Alias for PictureCaptionArrangement.setter"""
        self.PictureCaptionArrangement = value

    @property
    def PictureData(self):
        return self.com_object.PictureData

    @PictureData.setter
    def PictureData(self, value):
        self.com_object.PictureData = value

    @property
    def picturedata(self):
        """Alias for PictureData"""
        return self.PictureData

    @picturedata.setter
    def picturedata(self, value):
        """Alias for PictureData.setter"""
        self.PictureData = value

    @property
    def picture_data(self):
        """Alias for PictureData"""
        return self.PictureData

    @picture_data.setter
    def picture_data(self, value):
        """Alias for PictureData.setter"""
        self.PictureData = value

    @property
    def PictureType(self):
        return self.com_object.PictureType

    @PictureType.setter
    def PictureType(self, value):
        self.com_object.PictureType = value

    @property
    def picturetype(self):
        """Alias for PictureType"""
        return self.PictureType

    @picturetype.setter
    def picturetype(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def picture_type(self):
        """Alias for PictureType"""
        return self.PictureType

    @picture_type.setter
    def picture_type(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def PressedColor(self):
        return self.com_object.PressedColor

    @PressedColor.setter
    def PressedColor(self, value):
        self.com_object.PressedColor = value

    @property
    def pressedcolor(self):
        """Alias for PressedColor"""
        return self.PressedColor

    @pressedcolor.setter
    def pressedcolor(self, value):
        """Alias for PressedColor.setter"""
        self.PressedColor = value

    @property
    def pressed_color(self):
        """Alias for PressedColor"""
        return self.PressedColor

    @pressed_color.setter
    def pressed_color(self, value):
        """Alias for PressedColor.setter"""
        self.PressedColor = value

    @property
    def PressedForeColor(self):
        return self.com_object.PressedForeColor

    @PressedForeColor.setter
    def PressedForeColor(self, value):
        self.com_object.PressedForeColor = value

    @property
    def pressedforecolor(self):
        """Alias for PressedForeColor"""
        return self.PressedForeColor

    @pressedforecolor.setter
    def pressedforecolor(self, value):
        """Alias for PressedForeColor.setter"""
        self.PressedForeColor = value

    @property
    def pressed_fore_color(self):
        """Alias for PressedForeColor"""
        return self.PressedForeColor

    @pressed_fore_color.setter
    def pressed_fore_color(self, value):
        """Alias for PressedForeColor.setter"""
        self.PressedForeColor = value

    @property
    def PressedForeShade(self):
        return self.com_object.PressedForeShade

    @PressedForeShade.setter
    def PressedForeShade(self, value):
        self.com_object.PressedForeShade = value

    @property
    def pressedforeshade(self):
        """Alias for PressedForeShade"""
        return self.PressedForeShade

    @pressedforeshade.setter
    def pressedforeshade(self, value):
        """Alias for PressedForeShade.setter"""
        self.PressedForeShade = value

    @property
    def pressed_fore_shade(self):
        """Alias for PressedForeShade"""
        return self.PressedForeShade

    @pressed_fore_shade.setter
    def pressed_fore_shade(self, value):
        """Alias for PressedForeShade.setter"""
        self.PressedForeShade = value

    @property
    def PressedForeThemeColorIndex(self):
        return self.com_object.PressedForeThemeColorIndex

    @PressedForeThemeColorIndex.setter
    def PressedForeThemeColorIndex(self, value):
        self.com_object.PressedForeThemeColorIndex = value

    @property
    def pressedforethemecolorindex(self):
        """Alias for PressedForeThemeColorIndex"""
        return self.PressedForeThemeColorIndex

    @pressedforethemecolorindex.setter
    def pressedforethemecolorindex(self, value):
        """Alias for PressedForeThemeColorIndex.setter"""
        self.PressedForeThemeColorIndex = value

    @property
    def pressed_fore_theme_color_index(self):
        """Alias for PressedForeThemeColorIndex"""
        return self.PressedForeThemeColorIndex

    @pressed_fore_theme_color_index.setter
    def pressed_fore_theme_color_index(self, value):
        """Alias for PressedForeThemeColorIndex.setter"""
        self.PressedForeThemeColorIndex = value

    @property
    def PressedForeTint(self):
        return self.com_object.PressedForeTint

    @PressedForeTint.setter
    def PressedForeTint(self, value):
        self.com_object.PressedForeTint = value

    @property
    def pressedforetint(self):
        """Alias for PressedForeTint"""
        return self.PressedForeTint

    @pressedforetint.setter
    def pressedforetint(self, value):
        """Alias for PressedForeTint.setter"""
        self.PressedForeTint = value

    @property
    def pressed_fore_tint(self):
        """Alias for PressedForeTint"""
        return self.PressedForeTint

    @pressed_fore_tint.setter
    def pressed_fore_tint(self, value):
        """Alias for PressedForeTint.setter"""
        self.PressedForeTint = value

    @property
    def PressedShade(self):
        return self.com_object.PressedShade

    @PressedShade.setter
    def PressedShade(self, value):
        self.com_object.PressedShade = value

    @property
    def pressedshade(self):
        """Alias for PressedShade"""
        return self.PressedShade

    @pressedshade.setter
    def pressedshade(self, value):
        """Alias for PressedShade.setter"""
        self.PressedShade = value

    @property
    def pressed_shade(self):
        """Alias for PressedShade"""
        return self.PressedShade

    @pressed_shade.setter
    def pressed_shade(self, value):
        """Alias for PressedShade.setter"""
        self.PressedShade = value

    @property
    def PressedThemeColorIndex(self):
        return self.com_object.PressedThemeColorIndex

    @PressedThemeColorIndex.setter
    def PressedThemeColorIndex(self, value):
        self.com_object.PressedThemeColorIndex = value

    @property
    def pressedthemecolorindex(self):
        """Alias for PressedThemeColorIndex"""
        return self.PressedThemeColorIndex

    @pressedthemecolorindex.setter
    def pressedthemecolorindex(self, value):
        """Alias for PressedThemeColorIndex.setter"""
        self.PressedThemeColorIndex = value

    @property
    def pressed_theme_color_index(self):
        """Alias for PressedThemeColorIndex"""
        return self.PressedThemeColorIndex

    @pressed_theme_color_index.setter
    def pressed_theme_color_index(self, value):
        """Alias for PressedThemeColorIndex.setter"""
        self.PressedThemeColorIndex = value

    @property
    def PressedTint(self):
        return self.com_object.PressedTint

    @PressedTint.setter
    def PressedTint(self, value):
        self.com_object.PressedTint = value

    @property
    def pressedtint(self):
        """Alias for PressedTint"""
        return self.PressedTint

    @pressedtint.setter
    def pressedtint(self, value):
        """Alias for PressedTint.setter"""
        self.PressedTint = value

    @property
    def pressed_tint(self):
        """Alias for PressedTint"""
        return self.PressedTint

    @pressed_tint.setter
    def pressed_tint(self, value):
        """Alias for PressedTint.setter"""
        self.PressedTint = value

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def QuickStyle(self):
        return self.com_object.QuickStyle

    @QuickStyle.setter
    def QuickStyle(self, value):
        self.com_object.QuickStyle = value

    @property
    def quickstyle(self):
        """Alias for QuickStyle"""
        return self.QuickStyle

    @quickstyle.setter
    def quickstyle(self, value):
        """Alias for QuickStyle.setter"""
        self.QuickStyle = value

    @property
    def quick_style(self):
        """Alias for QuickStyle"""
        return self.QuickStyle

    @quick_style.setter
    def quick_style(self, value):
        """Alias for QuickStyle.setter"""
        self.QuickStyle = value

    @property
    def QuickStyleMask(self):
        return self.com_object.QuickStyleMask

    @QuickStyleMask.setter
    def QuickStyleMask(self, value):
        self.com_object.QuickStyleMask = value

    @property
    def quickstylemask(self):
        """Alias for QuickStyleMask"""
        return self.QuickStyleMask

    @quickstylemask.setter
    def quickstylemask(self, value):
        """Alias for QuickStyleMask.setter"""
        self.QuickStyleMask = value

    @property
    def quick_style_mask(self):
        """Alias for QuickStyleMask"""
        return self.QuickStyleMask

    @quick_style_mask.setter
    def quick_style_mask(self, value):
        """Alias for QuickStyleMask.setter"""
        self.QuickStyleMask = value

    @property
    def ReadingOrder(self):
        return self.com_object.ReadingOrder

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def RightPadding(self):
        return self.com_object.RightPadding

    @RightPadding.setter
    def RightPadding(self, value):
        self.com_object.RightPadding = value

    @property
    def rightpadding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @rightpadding.setter
    def rightpadding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def right_padding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @right_padding.setter
    def right_padding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def Section(self):
        return self.com_object.Section

    @Section.setter
    def Section(self, value):
        self.com_object.Section = value

    @property
    def section(self):
        """Alias for Section"""
        return self.Section

    @section.setter
    def section(self, value):
        """Alias for Section.setter"""
        self.Section = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Shape(self):
        return self.com_object.Shape

    @Shape.setter
    def Shape(self, value):
        self.com_object.Shape = value

    @property
    def shape(self):
        """Alias for Shape"""
        return self.Shape

    @shape.setter
    def shape(self, value):
        """Alias for Shape.setter"""
        self.Shape = value

    @property
    def ShortcutMenuBar(self):
        return self.com_object.ShortcutMenuBar

    @ShortcutMenuBar.setter
    def ShortcutMenuBar(self, value):
        self.com_object.ShortcutMenuBar = value

    @property
    def shortcutmenubar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcutmenubar.setter
    def shortcutmenubar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def shortcut_menu_bar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcut_menu_bar.setter
    def shortcut_menu_bar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def SoftEdges(self):
        return self.com_object.SoftEdges

    @SoftEdges.setter
    def SoftEdges(self, value):
        self.com_object.SoftEdges = value

    @property
    def softedges(self):
        """Alias for SoftEdges"""
        return self.SoftEdges

    @softedges.setter
    def softedges(self, value):
        """Alias for SoftEdges.setter"""
        self.SoftEdges = value

    @property
    def soft_edges(self):
        """Alias for SoftEdges"""
        return self.SoftEdges

    @soft_edges.setter
    def soft_edges(self, value):
        """Alias for SoftEdges.setter"""
        self.SoftEdges = value

    @property
    def StatusBarText(self):
        return self.com_object.StatusBarText

    @StatusBarText.setter
    def StatusBarText(self, value):
        self.com_object.StatusBarText = value

    @property
    def statusbartext(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @statusbartext.setter
    def statusbartext(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def status_bar_text(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @status_bar_text.setter
    def status_bar_text(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def TabIndex(self):
        return self.com_object.TabIndex

    @TabIndex.setter
    def TabIndex(self, value):
        self.com_object.TabIndex = value

    @property
    def tabindex(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tabindex.setter
    def tabindex(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def tab_index(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tab_index.setter
    def tab_index(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def TabStop(self):
        return self.com_object.TabStop

    @TabStop.setter
    def TabStop(self, value):
        self.com_object.TabStop = value

    @property
    def tabstop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tabstop.setter
    def tabstop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def tab_stop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tab_stop.setter
    def tab_stop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def ThemeFontIndex(self):
        return self.com_object.ThemeFontIndex

    @ThemeFontIndex.setter
    def ThemeFontIndex(self, value):
        self.com_object.ThemeFontIndex = value

    @property
    def themefontindex(self):
        """Alias for ThemeFontIndex"""
        return self.ThemeFontIndex

    @themefontindex.setter
    def themefontindex(self, value):
        """Alias for ThemeFontIndex.setter"""
        self.ThemeFontIndex = value

    @property
    def theme_font_index(self):
        """Alias for ThemeFontIndex"""
        return self.ThemeFontIndex

    @theme_font_index.setter
    def theme_font_index(self, value):
        """Alias for ThemeFontIndex.setter"""
        self.ThemeFontIndex = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TopPadding(self):
        return self.com_object.TopPadding

    @TopPadding.setter
    def TopPadding(self, value):
        self.com_object.TopPadding = value

    @property
    def toppadding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @toppadding.setter
    def toppadding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def top_padding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @top_padding.setter
    def top_padding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def Transparent(self):
        return self.com_object.Transparent

    @Transparent.setter
    def Transparent(self, value):
        self.com_object.Transparent = value

    @property
    def transparent(self):
        """Alias for Transparent"""
        return self.Transparent

    @transparent.setter
    def transparent(self, value):
        """Alias for Transparent.setter"""
        self.Transparent = value

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def Requery(self):
        self.com_object.Requery()

    def requery(self):
        """Alias for Requery"""
        return self.Requery()

    def SetFocus(self):
        self.com_object.SetFocus()

    def setfocus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def set_focus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()


class NavigationControl:

    def __init__(self, navigationcontrol=None):
        self.com_object= navigationcontrol

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoTab(self):
        return self.com_object.AutoTab

    @AutoTab.setter
    def AutoTab(self, value):
        self.com_object.AutoTab = value

    @property
    def autotab(self):
        """Alias for AutoTab"""
        return self.AutoTab

    @autotab.setter
    def autotab(self, value):
        """Alias for AutoTab.setter"""
        self.AutoTab = value

    @property
    def auto_tab(self):
        """Alias for AutoTab"""
        return self.AutoTab

    @auto_tab.setter
    def auto_tab(self, value):
        """Alias for AutoTab.setter"""
        self.AutoTab = value

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BackShade(self):
        return self.com_object.BackShade

    @BackShade.setter
    def BackShade(self, value):
        self.com_object.BackShade = value

    @property
    def backshade(self):
        """Alias for BackShade"""
        return self.BackShade

    @backshade.setter
    def backshade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def back_shade(self):
        """Alias for BackShade"""
        return self.BackShade

    @back_shade.setter
    def back_shade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def BackStyle(self):
        return self.com_object.BackStyle

    @BackStyle.setter
    def BackStyle(self, value):
        self.com_object.BackStyle = value

    @property
    def backstyle(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @backstyle.setter
    def backstyle(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def back_style(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @back_style.setter
    def back_style(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def BackThemeColorIndex(self):
        return self.com_object.BackThemeColorIndex

    @BackThemeColorIndex.setter
    def BackThemeColorIndex(self, value):
        self.com_object.BackThemeColorIndex = value

    @property
    def backthemecolorindex(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @backthemecolorindex.setter
    def backthemecolorindex(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def back_theme_color_index(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @back_theme_color_index.setter
    def back_theme_color_index(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def BackTint(self):
        return self.com_object.BackTint

    @BackTint.setter
    def BackTint(self, value):
        self.com_object.BackTint = value

    @property
    def backtint(self):
        """Alias for BackTint"""
        return self.BackTint

    @backtint.setter
    def backtint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def back_tint(self):
        """Alias for BackTint"""
        return self.BackTint

    @back_tint.setter
    def back_tint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def BorderColor(self):
        return self.com_object.BorderColor

    @BorderColor.setter
    def BorderColor(self, value):
        self.com_object.BorderColor = value

    @property
    def bordercolor(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @bordercolor.setter
    def bordercolor(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def border_color(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @border_color.setter
    def border_color(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def BorderShade(self):
        return self.com_object.BorderShade

    @BorderShade.setter
    def BorderShade(self, value):
        self.com_object.BorderShade = value

    @property
    def bordershade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @bordershade.setter
    def bordershade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def border_shade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @border_shade.setter
    def border_shade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def BorderStyle(self):
        return self.com_object.BorderStyle

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def BorderThemeColorIndex(self):
        return self.com_object.BorderThemeColorIndex

    @BorderThemeColorIndex.setter
    def BorderThemeColorIndex(self, value):
        self.com_object.BorderThemeColorIndex = value

    @property
    def borderthemecolorindex(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @borderthemecolorindex.setter
    def borderthemecolorindex(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def border_theme_color_index(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @border_theme_color_index.setter
    def border_theme_color_index(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def BorderTint(self):
        return self.com_object.BorderTint

    @BorderTint.setter
    def BorderTint(self, value):
        self.com_object.BorderTint = value

    @property
    def bordertint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @bordertint.setter
    def bordertint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def border_tint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @border_tint.setter
    def border_tint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def BorderWidth(self):
        return self.com_object.BorderWidth

    @BorderWidth.setter
    def BorderWidth(self, value):
        self.com_object.BorderWidth = value

    @property
    def borderwidth(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @borderwidth.setter
    def borderwidth(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def border_width(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @border_width.setter
    def border_width(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def BottomPadding(self):
        return self.com_object.BottomPadding

    @BottomPadding.setter
    def BottomPadding(self, value):
        self.com_object.BottomPadding = value

    @property
    def bottompadding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottompadding.setter
    def bottompadding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def bottom_padding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottom_padding.setter
    def bottom_padding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def Controls(self):
        return Controls(self.com_object.Controls)

    @property
    def controls(self):
        """Alias for Controls"""
        return self.Controls

    @property
    def ControlTipText(self):
        return self.com_object.ControlTipText

    @ControlTipText.setter
    def ControlTipText(self, value):
        self.com_object.ControlTipText = value

    @property
    def controltiptext(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @controltiptext.setter
    def controltiptext(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def control_tip_text(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @control_tip_text.setter
    def control_tip_text(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def ControlType(self):
        return self.com_object.ControlType

    @ControlType.setter
    def ControlType(self, value):
        self.com_object.ControlType = value

    @property
    def controltype(self):
        """Alias for ControlType"""
        return self.ControlType

    @controltype.setter
    def controltype(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def control_type(self):
        """Alias for ControlType"""
        return self.ControlType

    @control_type.setter
    def control_type(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def DisplayWhen(self):
        return self.com_object.DisplayWhen

    @DisplayWhen.setter
    def DisplayWhen(self, value):
        self.com_object.DisplayWhen = value

    @property
    def displaywhen(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @displaywhen.setter
    def displaywhen(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def display_when(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @display_when.setter
    def display_when(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def FilterLookup(self):
        return self.com_object.FilterLookup

    @FilterLookup.setter
    def FilterLookup(self, value):
        self.com_object.FilterLookup = value

    @property
    def filterlookup(self):
        """Alias for FilterLookup"""
        return self.FilterLookup

    @filterlookup.setter
    def filterlookup(self, value):
        """Alias for FilterLookup.setter"""
        self.FilterLookup = value

    @property
    def filter_lookup(self):
        """Alias for FilterLookup"""
        return self.FilterLookup

    @filter_lookup.setter
    def filter_lookup(self, value):
        """Alias for FilterLookup.setter"""
        self.FilterLookup = value

    @property
    def FormatConditions(self):
        return self.com_object.FormatConditions

    @property
    def formatconditions(self):
        """Alias for FormatConditions"""
        return self.FormatConditions

    @property
    def format_conditions(self):
        """Alias for FormatConditions"""
        return self.FormatConditions

    @property
    def GridlineColor(self):
        return self.com_object.GridlineColor

    @GridlineColor.setter
    def GridlineColor(self, value):
        self.com_object.GridlineColor = value

    @property
    def gridlinecolor(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridlinecolor.setter
    def gridlinecolor(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def gridline_color(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridline_color.setter
    def gridline_color(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def GridlineShade(self):
        return self.com_object.GridlineShade

    @GridlineShade.setter
    def GridlineShade(self, value):
        self.com_object.GridlineShade = value

    @property
    def gridlineshade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridlineshade.setter
    def gridlineshade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def gridline_shade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridline_shade.setter
    def gridline_shade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def GridlineStyleBottom(self):
        return self.com_object.GridlineStyleBottom

    @GridlineStyleBottom.setter
    def GridlineStyleBottom(self, value):
        self.com_object.GridlineStyleBottom = value

    @property
    def gridlinestylebottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridlinestylebottom.setter
    def gridlinestylebottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def gridline_style_bottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridline_style_bottom.setter
    def gridline_style_bottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def GridlineStyleLeft(self):
        return self.com_object.GridlineStyleLeft

    @GridlineStyleLeft.setter
    def GridlineStyleLeft(self, value):
        self.com_object.GridlineStyleLeft = value

    @property
    def gridlinestyleleft(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridlinestyleleft.setter
    def gridlinestyleleft(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def gridline_style_left(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridline_style_left.setter
    def gridline_style_left(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def GridlineStyleRight(self):
        return self.com_object.GridlineStyleRight

    @GridlineStyleRight.setter
    def GridlineStyleRight(self, value):
        self.com_object.GridlineStyleRight = value

    @property
    def gridlinestyleright(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridlinestyleright.setter
    def gridlinestyleright(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def gridline_style_right(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridline_style_right.setter
    def gridline_style_right(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def GridlineStyleTop(self):
        return self.com_object.GridlineStyleTop

    @GridlineStyleTop.setter
    def GridlineStyleTop(self, value):
        self.com_object.GridlineStyleTop = value

    @property
    def gridlinestyletop(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridlinestyletop.setter
    def gridlinestyletop(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def gridline_style_top(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridline_style_top.setter
    def gridline_style_top(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def GridlineThemeColorIndex(self):
        return self.com_object.GridlineThemeColorIndex

    @GridlineThemeColorIndex.setter
    def GridlineThemeColorIndex(self, value):
        self.com_object.GridlineThemeColorIndex = value

    @property
    def gridlinethemecolorindex(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridlinethemecolorindex.setter
    def gridlinethemecolorindex(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def gridline_theme_color_index(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridline_theme_color_index.setter
    def gridline_theme_color_index(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def GridlineTint(self):
        return self.com_object.GridlineTint

    @GridlineTint.setter
    def GridlineTint(self, value):
        self.com_object.GridlineTint = value

    @property
    def gridlinetint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridlinetint.setter
    def gridlinetint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def gridline_tint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridline_tint.setter
    def gridline_tint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def GridlineWidthBottom(self):
        return self.com_object.GridlineWidthBottom

    @GridlineWidthBottom.setter
    def GridlineWidthBottom(self, value):
        self.com_object.GridlineWidthBottom = value

    @property
    def gridlinewidthbottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridlinewidthbottom.setter
    def gridlinewidthbottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def gridline_width_bottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridline_width_bottom.setter
    def gridline_width_bottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def GridlineWidthLeft(self):
        return self.com_object.GridlineWidthLeft

    @GridlineWidthLeft.setter
    def GridlineWidthLeft(self, value):
        self.com_object.GridlineWidthLeft = value

    @property
    def gridlinewidthleft(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridlinewidthleft.setter
    def gridlinewidthleft(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def gridline_width_left(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridline_width_left.setter
    def gridline_width_left(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def GridlineWidthRight(self):
        return self.com_object.GridlineWidthRight

    @GridlineWidthRight.setter
    def GridlineWidthRight(self, value):
        self.com_object.GridlineWidthRight = value

    @property
    def gridlinewidthright(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridlinewidthright.setter
    def gridlinewidthright(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def gridline_width_right(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridline_width_right.setter
    def gridline_width_right(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def GridlineWidthTop(self):
        return self.com_object.GridlineWidthTop

    @GridlineWidthTop.setter
    def GridlineWidthTop(self, value):
        self.com_object.GridlineWidthTop = value

    @property
    def gridlinewidthtop(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridlinewidthtop.setter
    def gridlinewidthtop(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def gridline_width_top(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridline_width_top.setter
    def gridline_width_top(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HelpContextId(self):
        return self.com_object.HelpContextId

    @HelpContextId.setter
    def HelpContextId(self, value):
        self.com_object.HelpContextId = value

    @property
    def helpcontextid(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @helpcontextid.setter
    def helpcontextid(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def help_context_id(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @help_context_id.setter
    def help_context_id(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def Hyperlink(self):
        return self.com_object.Hyperlink

    @property
    def hyperlink(self):
        """Alias for Hyperlink"""
        return self.Hyperlink

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def IsVisible(self):
        return self.com_object.IsVisible

    @IsVisible.setter
    def IsVisible(self, value):
        self.com_object.IsVisible = value

    @property
    def isvisible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @isvisible.setter
    def isvisible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def is_visible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @is_visible.setter
    def is_visible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def Layout(self):
        return AcLayoutType(self.com_object.Layout)

    @property
    def layout(self):
        """Alias for Layout"""
        return self.Layout

    @property
    def LayoutID(self):
        return self.com_object.LayoutID

    @property
    def layoutid(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def layout_i_d(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def LeftPadding(self):
        return self.com_object.LeftPadding

    @LeftPadding.setter
    def LeftPadding(self, value):
        self.com_object.LeftPadding = value

    @property
    def leftpadding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @leftpadding.setter
    def leftpadding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def left_padding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @left_padding.setter
    def left_padding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def LineSpacing(self):
        return self.com_object.LineSpacing

    @LineSpacing.setter
    def LineSpacing(self, value):
        self.com_object.LineSpacing = value

    @property
    def linespacing(self):
        """Alias for LineSpacing"""
        return self.LineSpacing

    @linespacing.setter
    def linespacing(self, value):
        """Alias for LineSpacing.setter"""
        self.LineSpacing = value

    @property
    def line_spacing(self):
        """Alias for LineSpacing"""
        return self.LineSpacing

    @line_spacing.setter
    def line_spacing(self, value):
        """Alias for LineSpacing.setter"""
        self.LineSpacing = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def OldBorderStyle(self):
        return self.com_object.OldBorderStyle

    @OldBorderStyle.setter
    def OldBorderStyle(self, value):
        self.com_object.OldBorderStyle = value

    @property
    def oldborderstyle(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @oldborderstyle.setter
    def oldborderstyle(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def old_border_style(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @old_border_style.setter
    def old_border_style(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def OldValue(self):
        return self.com_object.OldValue

    @property
    def oldvalue(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def old_value(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def OnClick(self):
        return self.com_object.OnClick

    @OnClick.setter
    def OnClick(self, value):
        self.com_object.OnClick = value

    @property
    def onclick(self):
        """Alias for OnClick"""
        return self.OnClick

    @onclick.setter
    def onclick(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def on_click(self):
        """Alias for OnClick"""
        return self.OnClick

    @on_click.setter
    def on_click(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def OnDblClick(self):
        return self.com_object.OnDblClick

    @OnDblClick.setter
    def OnDblClick(self, value):
        self.com_object.OnDblClick = value

    @property
    def ondblclick(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @ondblclick.setter
    def ondblclick(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def on_dbl_click(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @on_dbl_click.setter
    def on_dbl_click(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def OnGotFocus(self):
        return self.com_object.OnGotFocus

    @OnGotFocus.setter
    def OnGotFocus(self, value):
        self.com_object.OnGotFocus = value

    @property
    def ongotfocus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @ongotfocus.setter
    def ongotfocus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def on_got_focus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @on_got_focus.setter
    def on_got_focus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def OnKeyDown(self):
        return self.com_object.OnKeyDown

    @OnKeyDown.setter
    def OnKeyDown(self, value):
        self.com_object.OnKeyDown = value

    @property
    def onkeydown(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @onkeydown.setter
    def onkeydown(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def on_key_down(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @on_key_down.setter
    def on_key_down(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def OnKeyPress(self):
        return self.com_object.OnKeyPress

    @OnKeyPress.setter
    def OnKeyPress(self, value):
        self.com_object.OnKeyPress = value

    @property
    def onkeypress(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @onkeypress.setter
    def onkeypress(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def on_key_press(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @on_key_press.setter
    def on_key_press(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def OnKeyUp(self):
        return self.com_object.OnKeyUp

    @OnKeyUp.setter
    def OnKeyUp(self, value):
        self.com_object.OnKeyUp = value

    @property
    def onkeyup(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @onkeyup.setter
    def onkeyup(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def on_key_up(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @on_key_up.setter
    def on_key_up(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def OnLostFocus(self):
        return self.com_object.OnLostFocus

    @OnLostFocus.setter
    def OnLostFocus(self, value):
        self.com_object.OnLostFocus = value

    @property
    def onlostfocus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @onlostfocus.setter
    def onlostfocus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def on_lost_focus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @on_lost_focus.setter
    def on_lost_focus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def OnMouseDown(self):
        return self.com_object.OnMouseDown

    @OnMouseDown.setter
    def OnMouseDown(self, value):
        self.com_object.OnMouseDown = value

    @property
    def onmousedown(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @onmousedown.setter
    def onmousedown(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def on_mouse_down(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @on_mouse_down.setter
    def on_mouse_down(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def OnMouseMove(self):
        return self.com_object.OnMouseMove

    @OnMouseMove.setter
    def OnMouseMove(self, value):
        self.com_object.OnMouseMove = value

    @property
    def onmousemove(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @onmousemove.setter
    def onmousemove(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def on_mouse_move(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @on_mouse_move.setter
    def on_mouse_move(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def OnMouseUp(self):
        return self.com_object.OnMouseUp

    @OnMouseUp.setter
    def OnMouseUp(self, value):
        self.com_object.OnMouseUp = value

    @property
    def onmouseup(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @onmouseup.setter
    def onmouseup(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def on_mouse_up(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @on_mouse_up.setter
    def on_mouse_up(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def ReadingOrder(self):
        return self.com_object.ReadingOrder

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def RightPadding(self):
        return self.com_object.RightPadding

    @RightPadding.setter
    def RightPadding(self, value):
        self.com_object.RightPadding = value

    @property
    def rightpadding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @rightpadding.setter
    def rightpadding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def right_padding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @right_padding.setter
    def right_padding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def ScrollBarAlign(self):
        return self.com_object.ScrollBarAlign

    @ScrollBarAlign.setter
    def ScrollBarAlign(self, value):
        self.com_object.ScrollBarAlign = value

    @property
    def scrollbaralign(self):
        """Alias for ScrollBarAlign"""
        return self.ScrollBarAlign

    @scrollbaralign.setter
    def scrollbaralign(self, value):
        """Alias for ScrollBarAlign.setter"""
        self.ScrollBarAlign = value

    @property
    def scroll_bar_align(self):
        """Alias for ScrollBarAlign"""
        return self.ScrollBarAlign

    @scroll_bar_align.setter
    def scroll_bar_align(self, value):
        """Alias for ScrollBarAlign.setter"""
        self.ScrollBarAlign = value

    @property
    def Section(self):
        return self.com_object.Section

    @Section.setter
    def Section(self, value):
        self.com_object.Section = value

    @property
    def section(self):
        """Alias for Section"""
        return self.Section

    @section.setter
    def section(self, value):
        """Alias for Section.setter"""
        self.Section = value

    @property
    def SelectedTab(self):
        return self.com_object.SelectedTab

    @property
    def selectedtab(self):
        """Alias for SelectedTab"""
        return self.SelectedTab

    @property
    def selected_tab(self):
        """Alias for SelectedTab"""
        return self.SelectedTab

    @property
    def ShortcutMenuBar(self):
        return self.com_object.ShortcutMenuBar

    @ShortcutMenuBar.setter
    def ShortcutMenuBar(self, value):
        self.com_object.ShortcutMenuBar = value

    @property
    def shortcutmenubar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcutmenubar.setter
    def shortcutmenubar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def shortcut_menu_bar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcut_menu_bar.setter
    def shortcut_menu_bar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def SmartTags(self):
        return SmartTags(self.com_object.SmartTags)

    @property
    def smarttags(self):
        """Alias for SmartTags"""
        return self.SmartTags

    @property
    def smart_tags(self):
        """Alias for SmartTags"""
        return self.SmartTags

    @property
    def Span(self):
        return self.com_object.Span

    @Span.setter
    def Span(self, value):
        self.com_object.Span = value

    @property
    def span(self):
        """Alias for Span"""
        return self.Span

    @span.setter
    def span(self, value):
        """Alias for Span.setter"""
        self.Span = value

    @property
    def SpecialEffect(self):
        return self.com_object.SpecialEffect

    @SpecialEffect.setter
    def SpecialEffect(self, value):
        self.com_object.SpecialEffect = value

    @property
    def specialeffect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @specialeffect.setter
    def specialeffect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def special_effect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @special_effect.setter
    def special_effect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def StatusBarText(self):
        return self.com_object.StatusBarText

    @StatusBarText.setter
    def StatusBarText(self, value):
        self.com_object.StatusBarText = value

    @property
    def statusbartext(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @statusbartext.setter
    def statusbartext(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def status_bar_text(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @status_bar_text.setter
    def status_bar_text(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def SubForm(self):
        return self.com_object.SubForm

    @SubForm.setter
    def SubForm(self, value):
        self.com_object.SubForm = value

    @property
    def subform(self):
        """Alias for SubForm"""
        return self.SubForm

    @subform.setter
    def subform(self, value):
        """Alias for SubForm.setter"""
        self.SubForm = value

    @property
    def sub_form(self):
        """Alias for SubForm"""
        return self.SubForm

    @sub_form.setter
    def sub_form(self, value):
        """Alias for SubForm.setter"""
        self.SubForm = value

    @property
    def TabIndex(self):
        return self.com_object.TabIndex

    @TabIndex.setter
    def TabIndex(self, value):
        self.com_object.TabIndex = value

    @property
    def tabindex(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tabindex.setter
    def tabindex(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def tab_index(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tab_index.setter
    def tab_index(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def Tabs(self):
        return self.com_object.Tabs

    @property
    def tabs(self):
        """Alias for Tabs"""
        return self.Tabs

    @property
    def TabStop(self):
        return self.com_object.TabStop

    @TabStop.setter
    def TabStop(self, value):
        self.com_object.TabStop = value

    @property
    def tabstop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tabstop.setter
    def tabstop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def tab_stop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tab_stop.setter
    def tab_stop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TopPadding(self):
        return self.com_object.TopPadding

    @TopPadding.setter
    def TopPadding(self, value):
        self.com_object.TopPadding = value

    @property
    def toppadding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @toppadding.setter
    def toppadding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def top_padding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @top_padding.setter
    def top_padding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def Requery(self):
        self.com_object.Requery()

    def requery(self):
        """Alias for Requery"""
        return self.Requery()

    def SetFocus(self):
        self.com_object.SetFocus()

    def setfocus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def set_focus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def Undo(self):
        self.com_object.Undo()

    def undo(self):
        """Alias for Undo"""
        return self.Undo()


class ObjectFrame:

    def __init__(self, objectframe=None):
        self.com_object= objectframe

    @property
    def Action(self):
        return self.com_object.Action

    @Action.setter
    def Action(self, value):
        self.com_object.Action = value

    @property
    def action(self):
        """Alias for Action"""
        return self.Action

    @action.setter
    def action(self, value):
        """Alias for Action.setter"""
        self.Action = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoActivate(self):
        return self.com_object.AutoActivate

    @AutoActivate.setter
    def AutoActivate(self, value):
        self.com_object.AutoActivate = value

    @property
    def autoactivate(self):
        """Alias for AutoActivate"""
        return self.AutoActivate

    @autoactivate.setter
    def autoactivate(self, value):
        """Alias for AutoActivate.setter"""
        self.AutoActivate = value

    @property
    def auto_activate(self):
        """Alias for AutoActivate"""
        return self.AutoActivate

    @auto_activate.setter
    def auto_activate(self, value):
        """Alias for AutoActivate.setter"""
        self.AutoActivate = value

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BackShade(self):
        return self.com_object.BackShade

    @BackShade.setter
    def BackShade(self, value):
        self.com_object.BackShade = value

    @property
    def backshade(self):
        """Alias for BackShade"""
        return self.BackShade

    @backshade.setter
    def backshade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def back_shade(self):
        """Alias for BackShade"""
        return self.BackShade

    @back_shade.setter
    def back_shade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def BackStyle(self):
        return self.com_object.BackStyle

    @BackStyle.setter
    def BackStyle(self, value):
        self.com_object.BackStyle = value

    @property
    def backstyle(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @backstyle.setter
    def backstyle(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def back_style(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @back_style.setter
    def back_style(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def BackThemeColorIndex(self):
        return self.com_object.BackThemeColorIndex

    @BackThemeColorIndex.setter
    def BackThemeColorIndex(self, value):
        self.com_object.BackThemeColorIndex = value

    @property
    def backthemecolorindex(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @backthemecolorindex.setter
    def backthemecolorindex(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def back_theme_color_index(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @back_theme_color_index.setter
    def back_theme_color_index(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def BackTint(self):
        return self.com_object.BackTint

    @BackTint.setter
    def BackTint(self, value):
        self.com_object.BackTint = value

    @property
    def backtint(self):
        """Alias for BackTint"""
        return self.BackTint

    @backtint.setter
    def backtint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def back_tint(self):
        """Alias for BackTint"""
        return self.BackTint

    @back_tint.setter
    def back_tint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def BorderColor(self):
        return self.com_object.BorderColor

    @BorderColor.setter
    def BorderColor(self, value):
        self.com_object.BorderColor = value

    @property
    def bordercolor(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @bordercolor.setter
    def bordercolor(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def border_color(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @border_color.setter
    def border_color(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def BorderShade(self):
        return self.com_object.BorderShade

    @BorderShade.setter
    def BorderShade(self, value):
        self.com_object.BorderShade = value

    @property
    def bordershade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @bordershade.setter
    def bordershade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def border_shade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @border_shade.setter
    def border_shade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def BorderStyle(self):
        return self.com_object.BorderStyle

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def BorderThemeColorIndex(self):
        return self.com_object.BorderThemeColorIndex

    @BorderThemeColorIndex.setter
    def BorderThemeColorIndex(self, value):
        self.com_object.BorderThemeColorIndex = value

    @property
    def borderthemecolorindex(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @borderthemecolorindex.setter
    def borderthemecolorindex(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def border_theme_color_index(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @border_theme_color_index.setter
    def border_theme_color_index(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def BorderTint(self):
        return self.com_object.BorderTint

    @BorderTint.setter
    def BorderTint(self, value):
        self.com_object.BorderTint = value

    @property
    def bordertint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @bordertint.setter
    def bordertint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def border_tint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @border_tint.setter
    def border_tint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def BorderWidth(self):
        return self.com_object.BorderWidth

    @BorderWidth.setter
    def BorderWidth(self, value):
        self.com_object.BorderWidth = value

    @property
    def borderwidth(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @borderwidth.setter
    def borderwidth(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def border_width(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @border_width.setter
    def border_width(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def BottomPadding(self):
        return self.com_object.BottomPadding

    @BottomPadding.setter
    def BottomPadding(self, value):
        self.com_object.BottomPadding = value

    @property
    def bottompadding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottompadding.setter
    def bottompadding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def bottom_padding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottom_padding.setter
    def bottom_padding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def Class(self):
        return self.com_object.Class

    @Class.setter
    def Class(self, value):
        self.com_object.Class = value

    @property
    def ColumnCount(self):
        return self.com_object.ColumnCount

    @ColumnCount.setter
    def ColumnCount(self, value):
        self.com_object.ColumnCount = value

    @property
    def columncount(self):
        """Alias for ColumnCount"""
        return self.ColumnCount

    @columncount.setter
    def columncount(self, value):
        """Alias for ColumnCount.setter"""
        self.ColumnCount = value

    @property
    def column_count(self):
        """Alias for ColumnCount"""
        return self.ColumnCount

    @column_count.setter
    def column_count(self, value):
        """Alias for ColumnCount.setter"""
        self.ColumnCount = value

    @property
    def ColumnHeads(self):
        return self.com_object.ColumnHeads

    @ColumnHeads.setter
    def ColumnHeads(self, value):
        self.com_object.ColumnHeads = value

    @property
    def columnheads(self):
        """Alias for ColumnHeads"""
        return self.ColumnHeads

    @columnheads.setter
    def columnheads(self, value):
        """Alias for ColumnHeads.setter"""
        self.ColumnHeads = value

    @property
    def column_heads(self):
        """Alias for ColumnHeads"""
        return self.ColumnHeads

    @column_heads.setter
    def column_heads(self, value):
        """Alias for ColumnHeads.setter"""
        self.ColumnHeads = value

    @property
    def Controls(self):
        return Controls(self.com_object.Controls)

    @property
    def controls(self):
        """Alias for Controls"""
        return self.Controls

    @property
    def ControlTipText(self):
        return self.com_object.ControlTipText

    @ControlTipText.setter
    def ControlTipText(self, value):
        self.com_object.ControlTipText = value

    @property
    def controltiptext(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @controltiptext.setter
    def controltiptext(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def control_tip_text(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @control_tip_text.setter
    def control_tip_text(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def ControlType(self):
        return self.com_object.ControlType

    @ControlType.setter
    def ControlType(self, value):
        self.com_object.ControlType = value

    @property
    def controltype(self):
        """Alias for ControlType"""
        return self.ControlType

    @controltype.setter
    def controltype(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def control_type(self):
        """Alias for ControlType"""
        return self.ControlType

    @control_type.setter
    def control_type(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def DisplayType(self):
        return self.com_object.DisplayType

    @DisplayType.setter
    def DisplayType(self, value):
        self.com_object.DisplayType = value

    @property
    def displaytype(self):
        """Alias for DisplayType"""
        return self.DisplayType

    @displaytype.setter
    def displaytype(self, value):
        """Alias for DisplayType.setter"""
        self.DisplayType = value

    @property
    def display_type(self):
        """Alias for DisplayType"""
        return self.DisplayType

    @display_type.setter
    def display_type(self, value):
        """Alias for DisplayType.setter"""
        self.DisplayType = value

    @property
    def DisplayWhen(self):
        return self.com_object.DisplayWhen

    @DisplayWhen.setter
    def DisplayWhen(self, value):
        self.com_object.DisplayWhen = value

    @property
    def displaywhen(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @displaywhen.setter
    def displaywhen(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def display_when(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @display_when.setter
    def display_when(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def GridlineColor(self):
        return self.com_object.GridlineColor

    @GridlineColor.setter
    def GridlineColor(self, value):
        self.com_object.GridlineColor = value

    @property
    def gridlinecolor(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridlinecolor.setter
    def gridlinecolor(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def gridline_color(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridline_color.setter
    def gridline_color(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def GridlineShade(self):
        return self.com_object.GridlineShade

    @GridlineShade.setter
    def GridlineShade(self, value):
        self.com_object.GridlineShade = value

    @property
    def gridlineshade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridlineshade.setter
    def gridlineshade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def gridline_shade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridline_shade.setter
    def gridline_shade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def GridlineStyleBottom(self):
        return self.com_object.GridlineStyleBottom

    @GridlineStyleBottom.setter
    def GridlineStyleBottom(self, value):
        self.com_object.GridlineStyleBottom = value

    @property
    def gridlinestylebottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridlinestylebottom.setter
    def gridlinestylebottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def gridline_style_bottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridline_style_bottom.setter
    def gridline_style_bottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def GridlineStyleLeft(self):
        return self.com_object.GridlineStyleLeft

    @GridlineStyleLeft.setter
    def GridlineStyleLeft(self, value):
        self.com_object.GridlineStyleLeft = value

    @property
    def gridlinestyleleft(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridlinestyleleft.setter
    def gridlinestyleleft(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def gridline_style_left(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridline_style_left.setter
    def gridline_style_left(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def GridlineStyleRight(self):
        return self.com_object.GridlineStyleRight

    @GridlineStyleRight.setter
    def GridlineStyleRight(self, value):
        self.com_object.GridlineStyleRight = value

    @property
    def gridlinestyleright(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridlinestyleright.setter
    def gridlinestyleright(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def gridline_style_right(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridline_style_right.setter
    def gridline_style_right(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def GridlineStyleTop(self):
        return self.com_object.GridlineStyleTop

    @GridlineStyleTop.setter
    def GridlineStyleTop(self, value):
        self.com_object.GridlineStyleTop = value

    @property
    def gridlinestyletop(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridlinestyletop.setter
    def gridlinestyletop(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def gridline_style_top(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridline_style_top.setter
    def gridline_style_top(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def GridlineThemeColorIndex(self):
        return self.com_object.GridlineThemeColorIndex

    @GridlineThemeColorIndex.setter
    def GridlineThemeColorIndex(self, value):
        self.com_object.GridlineThemeColorIndex = value

    @property
    def gridlinethemecolorindex(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridlinethemecolorindex.setter
    def gridlinethemecolorindex(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def gridline_theme_color_index(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridline_theme_color_index.setter
    def gridline_theme_color_index(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def GridlineTint(self):
        return self.com_object.GridlineTint

    @GridlineTint.setter
    def GridlineTint(self, value):
        self.com_object.GridlineTint = value

    @property
    def gridlinetint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridlinetint.setter
    def gridlinetint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def gridline_tint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridline_tint.setter
    def gridline_tint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def GridlineWidthBottom(self):
        return self.com_object.GridlineWidthBottom

    @GridlineWidthBottom.setter
    def GridlineWidthBottom(self, value):
        self.com_object.GridlineWidthBottom = value

    @property
    def gridlinewidthbottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridlinewidthbottom.setter
    def gridlinewidthbottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def gridline_width_bottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridline_width_bottom.setter
    def gridline_width_bottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def GridlineWidthLeft(self):
        return self.com_object.GridlineWidthLeft

    @GridlineWidthLeft.setter
    def GridlineWidthLeft(self, value):
        self.com_object.GridlineWidthLeft = value

    @property
    def gridlinewidthleft(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridlinewidthleft.setter
    def gridlinewidthleft(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def gridline_width_left(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridline_width_left.setter
    def gridline_width_left(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def GridlineWidthRight(self):
        return self.com_object.GridlineWidthRight

    @GridlineWidthRight.setter
    def GridlineWidthRight(self, value):
        self.com_object.GridlineWidthRight = value

    @property
    def gridlinewidthright(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridlinewidthright.setter
    def gridlinewidthright(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def gridline_width_right(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridline_width_right.setter
    def gridline_width_right(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def GridlineWidthTop(self):
        return self.com_object.GridlineWidthTop

    @GridlineWidthTop.setter
    def GridlineWidthTop(self, value):
        self.com_object.GridlineWidthTop = value

    @property
    def gridlinewidthtop(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridlinewidthtop.setter
    def gridlinewidthtop(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def gridline_width_top(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridline_width_top.setter
    def gridline_width_top(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HelpContextId(self):
        return self.com_object.HelpContextId

    @HelpContextId.setter
    def HelpContextId(self, value):
        self.com_object.HelpContextId = value

    @property
    def helpcontextid(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @helpcontextid.setter
    def helpcontextid(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def help_context_id(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @help_context_id.setter
    def help_context_id(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def IsVisible(self):
        return self.com_object.IsVisible

    @IsVisible.setter
    def IsVisible(self, value):
        self.com_object.IsVisible = value

    @property
    def isvisible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @isvisible.setter
    def isvisible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def is_visible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @is_visible.setter
    def is_visible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def Item(self):
        return self.com_object.Item

    @Item.setter
    def Item(self, value):
        self.com_object.Item = value

    @property
    def item(self):
        """Alias for Item"""
        return self.Item

    @item.setter
    def item(self, value):
        """Alias for Item.setter"""
        self.Item = value

    @property
    def Layout(self):
        return AcLayoutType(self.com_object.Layout)

    @property
    def layout(self):
        """Alias for Layout"""
        return self.Layout

    @property
    def LayoutID(self):
        return self.com_object.LayoutID

    @property
    def layoutid(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def layout_i_d(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def LeftPadding(self):
        return self.com_object.LeftPadding

    @LeftPadding.setter
    def LeftPadding(self, value):
        self.com_object.LeftPadding = value

    @property
    def leftpadding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @leftpadding.setter
    def leftpadding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def left_padding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @left_padding.setter
    def left_padding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def LinkChildFields(self):
        return self.com_object.LinkChildFields

    @LinkChildFields.setter
    def LinkChildFields(self, value):
        self.com_object.LinkChildFields = value

    @property
    def linkchildfields(self):
        """Alias for LinkChildFields"""
        return self.LinkChildFields

    @linkchildfields.setter
    def linkchildfields(self, value):
        """Alias for LinkChildFields.setter"""
        self.LinkChildFields = value

    @property
    def link_child_fields(self):
        """Alias for LinkChildFields"""
        return self.LinkChildFields

    @link_child_fields.setter
    def link_child_fields(self, value):
        """Alias for LinkChildFields.setter"""
        self.LinkChildFields = value

    @property
    def LinkMasterFields(self):
        return self.com_object.LinkMasterFields

    @LinkMasterFields.setter
    def LinkMasterFields(self, value):
        self.com_object.LinkMasterFields = value

    @property
    def linkmasterfields(self):
        """Alias for LinkMasterFields"""
        return self.LinkMasterFields

    @linkmasterfields.setter
    def linkmasterfields(self, value):
        """Alias for LinkMasterFields.setter"""
        self.LinkMasterFields = value

    @property
    def link_master_fields(self):
        """Alias for LinkMasterFields"""
        return self.LinkMasterFields

    @link_master_fields.setter
    def link_master_fields(self, value):
        """Alias for LinkMasterFields.setter"""
        self.LinkMasterFields = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Object(self):
        return self.com_object.Object

    @property
    def object(self):
        """Alias for Object"""
        return self.Object

    @property
    def ObjectPalette(self):
        return self.com_object.ObjectPalette

    @ObjectPalette.setter
    def ObjectPalette(self, value):
        self.com_object.ObjectPalette = value

    @property
    def objectpalette(self):
        """Alias for ObjectPalette"""
        return self.ObjectPalette

    @objectpalette.setter
    def objectpalette(self, value):
        """Alias for ObjectPalette.setter"""
        self.ObjectPalette = value

    @property
    def object_palette(self):
        """Alias for ObjectPalette"""
        return self.ObjectPalette

    @object_palette.setter
    def object_palette(self, value):
        """Alias for ObjectPalette.setter"""
        self.ObjectPalette = value

    def ObjectVerbs(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetObjectVerbs"):
            return self.com_object.GetObjectVerbs(*arguments)
        else:
            return self.com_object.ObjectVerbs(*arguments)

    def objectverbs(self, Index=None):
        """Alias for ObjectVerbs"""
        arguments = [Index]
        return self.ObjectVerbs(*arguments)

    def object_verbs(self, Index=None):
        """Alias for ObjectVerbs"""
        arguments = [Index]
        return self.ObjectVerbs(*arguments)

    @property
    def ObjectVerbsCount(self):
        return self.com_object.ObjectVerbsCount

    @property
    def objectverbscount(self):
        """Alias for ObjectVerbsCount"""
        return self.ObjectVerbsCount

    @property
    def object_verbs_count(self):
        """Alias for ObjectVerbsCount"""
        return self.ObjectVerbsCount

    @property
    def OldBorderStyle(self):
        return self.com_object.OldBorderStyle

    @OldBorderStyle.setter
    def OldBorderStyle(self, value):
        self.com_object.OldBorderStyle = value

    @property
    def oldborderstyle(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @oldborderstyle.setter
    def oldborderstyle(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def old_border_style(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @old_border_style.setter
    def old_border_style(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def OldValue(self):
        return self.com_object.OldValue

    @property
    def oldvalue(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def old_value(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def OLEClass(self):
        return self.com_object.OLEClass

    @property
    def oleclass(self):
        """Alias for OLEClass"""
        return self.OLEClass

    @property
    def o_l_e_class(self):
        """Alias for OLEClass"""
        return self.OLEClass

    @property
    def OLEType(self):
        return self.com_object.OLEType

    @OLEType.setter
    def OLEType(self, value):
        self.com_object.OLEType = value

    @property
    def oletype(self):
        """Alias for OLEType"""
        return self.OLEType

    @oletype.setter
    def oletype(self, value):
        """Alias for OLEType.setter"""
        self.OLEType = value

    @property
    def o_l_e_type(self):
        """Alias for OLEType"""
        return self.OLEType

    @o_l_e_type.setter
    def o_l_e_type(self, value):
        """Alias for OLEType.setter"""
        self.OLEType = value

    @property
    def OLETypeAllowed(self):
        return self.com_object.OLETypeAllowed

    @OLETypeAllowed.setter
    def OLETypeAllowed(self, value):
        self.com_object.OLETypeAllowed = value

    @property
    def oletypeallowed(self):
        """Alias for OLETypeAllowed"""
        return self.OLETypeAllowed

    @oletypeallowed.setter
    def oletypeallowed(self, value):
        """Alias for OLETypeAllowed.setter"""
        self.OLETypeAllowed = value

    @property
    def o_l_e_type_allowed(self):
        """Alias for OLETypeAllowed"""
        return self.OLETypeAllowed

    @o_l_e_type_allowed.setter
    def o_l_e_type_allowed(self, value):
        """Alias for OLETypeAllowed.setter"""
        self.OLETypeAllowed = value

    @property
    def OnClick(self):
        return self.com_object.OnClick

    @OnClick.setter
    def OnClick(self, value):
        self.com_object.OnClick = value

    @property
    def onclick(self):
        """Alias for OnClick"""
        return self.OnClick

    @onclick.setter
    def onclick(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def on_click(self):
        """Alias for OnClick"""
        return self.OnClick

    @on_click.setter
    def on_click(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def OnDblClick(self):
        return self.com_object.OnDblClick

    @OnDblClick.setter
    def OnDblClick(self, value):
        self.com_object.OnDblClick = value

    @property
    def ondblclick(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @ondblclick.setter
    def ondblclick(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def on_dbl_click(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @on_dbl_click.setter
    def on_dbl_click(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def OnEnter(self):
        return self.com_object.OnEnter

    @OnEnter.setter
    def OnEnter(self, value):
        self.com_object.OnEnter = value

    @property
    def onenter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @onenter.setter
    def onenter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def on_enter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @on_enter.setter
    def on_enter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def OnExit(self):
        return self.com_object.OnExit

    @OnExit.setter
    def OnExit(self, value):
        self.com_object.OnExit = value

    @property
    def onexit(self):
        """Alias for OnExit"""
        return self.OnExit

    @onexit.setter
    def onexit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def on_exit(self):
        """Alias for OnExit"""
        return self.OnExit

    @on_exit.setter
    def on_exit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def OnGotFocus(self):
        return self.com_object.OnGotFocus

    @OnGotFocus.setter
    def OnGotFocus(self, value):
        self.com_object.OnGotFocus = value

    @property
    def ongotfocus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @ongotfocus.setter
    def ongotfocus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def on_got_focus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @on_got_focus.setter
    def on_got_focus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def OnLostFocus(self):
        return self.com_object.OnLostFocus

    @OnLostFocus.setter
    def OnLostFocus(self, value):
        self.com_object.OnLostFocus = value

    @property
    def onlostfocus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @onlostfocus.setter
    def onlostfocus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def on_lost_focus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @on_lost_focus.setter
    def on_lost_focus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def OnMouseDown(self):
        return self.com_object.OnMouseDown

    @OnMouseDown.setter
    def OnMouseDown(self, value):
        self.com_object.OnMouseDown = value

    @property
    def onmousedown(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @onmousedown.setter
    def onmousedown(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def on_mouse_down(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @on_mouse_down.setter
    def on_mouse_down(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def OnMouseMove(self):
        return self.com_object.OnMouseMove

    @OnMouseMove.setter
    def OnMouseMove(self, value):
        self.com_object.OnMouseMove = value

    @property
    def onmousemove(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @onmousemove.setter
    def onmousemove(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def on_mouse_move(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @on_mouse_move.setter
    def on_mouse_move(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def OnMouseUp(self):
        return self.com_object.OnMouseUp

    @OnMouseUp.setter
    def OnMouseUp(self, value):
        self.com_object.OnMouseUp = value

    @property
    def onmouseup(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @onmouseup.setter
    def onmouseup(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def on_mouse_up(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @on_mouse_up.setter
    def on_mouse_up(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def OnUpdated(self):
        return self.com_object.OnUpdated

    @OnUpdated.setter
    def OnUpdated(self, value):
        self.com_object.OnUpdated = value

    @property
    def onupdated(self):
        """Alias for OnUpdated"""
        return self.OnUpdated

    @onupdated.setter
    def onupdated(self, value):
        """Alias for OnUpdated.setter"""
        self.OnUpdated = value

    @property
    def on_updated(self):
        """Alias for OnUpdated"""
        return self.OnUpdated

    @on_updated.setter
    def on_updated(self, value):
        """Alias for OnUpdated.setter"""
        self.OnUpdated = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def RightPadding(self):
        return self.com_object.RightPadding

    @RightPadding.setter
    def RightPadding(self, value):
        self.com_object.RightPadding = value

    @property
    def rightpadding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @rightpadding.setter
    def rightpadding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def right_padding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @right_padding.setter
    def right_padding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def RowSource(self):
        return self.com_object.RowSource

    @RowSource.setter
    def RowSource(self, value):
        self.com_object.RowSource = value

    @property
    def rowsource(self):
        """Alias for RowSource"""
        return self.RowSource

    @rowsource.setter
    def rowsource(self, value):
        """Alias for RowSource.setter"""
        self.RowSource = value

    @property
    def row_source(self):
        """Alias for RowSource"""
        return self.RowSource

    @row_source.setter
    def row_source(self, value):
        """Alias for RowSource.setter"""
        self.RowSource = value

    @property
    def RowSourceType(self):
        return self.com_object.RowSourceType

    @RowSourceType.setter
    def RowSourceType(self, value):
        self.com_object.RowSourceType = value

    @property
    def rowsourcetype(self):
        """Alias for RowSourceType"""
        return self.RowSourceType

    @rowsourcetype.setter
    def rowsourcetype(self, value):
        """Alias for RowSourceType.setter"""
        self.RowSourceType = value

    @property
    def row_source_type(self):
        """Alias for RowSourceType"""
        return self.RowSourceType

    @row_source_type.setter
    def row_source_type(self, value):
        """Alias for RowSourceType.setter"""
        self.RowSourceType = value

    @property
    def Scaling(self):
        return self.com_object.Scaling

    @Scaling.setter
    def Scaling(self, value):
        self.com_object.Scaling = value

    @property
    def scaling(self):
        """Alias for Scaling"""
        return self.Scaling

    @scaling.setter
    def scaling(self, value):
        """Alias for Scaling.setter"""
        self.Scaling = value

    @property
    def Section(self):
        return self.com_object.Section

    @Section.setter
    def Section(self, value):
        self.com_object.Section = value

    @property
    def section(self):
        """Alias for Section"""
        return self.Section

    @section.setter
    def section(self, value):
        """Alias for Section.setter"""
        self.Section = value

    @property
    def ShortcutMenuBar(self):
        return self.com_object.ShortcutMenuBar

    @ShortcutMenuBar.setter
    def ShortcutMenuBar(self, value):
        self.com_object.ShortcutMenuBar = value

    @property
    def shortcutmenubar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcutmenubar.setter
    def shortcutmenubar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def shortcut_menu_bar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcut_menu_bar.setter
    def shortcut_menu_bar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def SizeMode(self):
        return self.com_object.SizeMode

    @property
    def sizemode(self):
        """Alias for SizeMode"""
        return self.SizeMode

    @property
    def size_mode(self):
        """Alias for SizeMode"""
        return self.SizeMode

    @property
    def SourceDoc(self):
        return self.com_object.SourceDoc

    @SourceDoc.setter
    def SourceDoc(self, value):
        self.com_object.SourceDoc = value

    @property
    def sourcedoc(self):
        """Alias for SourceDoc"""
        return self.SourceDoc

    @sourcedoc.setter
    def sourcedoc(self, value):
        """Alias for SourceDoc.setter"""
        self.SourceDoc = value

    @property
    def source_doc(self):
        """Alias for SourceDoc"""
        return self.SourceDoc

    @source_doc.setter
    def source_doc(self, value):
        """Alias for SourceDoc.setter"""
        self.SourceDoc = value

    @property
    def SourceItem(self):
        return self.com_object.SourceItem

    @SourceItem.setter
    def SourceItem(self, value):
        self.com_object.SourceItem = value

    @property
    def sourceitem(self):
        """Alias for SourceItem"""
        return self.SourceItem

    @sourceitem.setter
    def sourceitem(self, value):
        """Alias for SourceItem.setter"""
        self.SourceItem = value

    @property
    def source_item(self):
        """Alias for SourceItem"""
        return self.SourceItem

    @source_item.setter
    def source_item(self, value):
        """Alias for SourceItem.setter"""
        self.SourceItem = value

    @property
    def SourceObject(self):
        return self.com_object.SourceObject

    @property
    def sourceobject(self):
        """Alias for SourceObject"""
        return self.SourceObject

    @property
    def source_object(self):
        """Alias for SourceObject"""
        return self.SourceObject

    @property
    def SpecialEffect(self):
        return self.com_object.SpecialEffect

    @SpecialEffect.setter
    def SpecialEffect(self, value):
        self.com_object.SpecialEffect = value

    @property
    def specialeffect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @specialeffect.setter
    def specialeffect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def special_effect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @special_effect.setter
    def special_effect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def StatusBarText(self):
        return self.com_object.StatusBarText

    @StatusBarText.setter
    def StatusBarText(self, value):
        self.com_object.StatusBarText = value

    @property
    def statusbartext(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @statusbartext.setter
    def statusbartext(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def status_bar_text(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @status_bar_text.setter
    def status_bar_text(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def TabIndex(self):
        return self.com_object.TabIndex

    @TabIndex.setter
    def TabIndex(self, value):
        self.com_object.TabIndex = value

    @property
    def tabindex(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tabindex.setter
    def tabindex(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def tab_index(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tab_index.setter
    def tab_index(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def TabStop(self):
        return self.com_object.TabStop

    @TabStop.setter
    def TabStop(self, value):
        self.com_object.TabStop = value

    @property
    def tabstop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tabstop.setter
    def tabstop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def tab_stop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tab_stop.setter
    def tab_stop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TopPadding(self):
        return self.com_object.TopPadding

    @TopPadding.setter
    def TopPadding(self, value):
        self.com_object.TopPadding = value

    @property
    def toppadding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @toppadding.setter
    def toppadding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def top_padding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @top_padding.setter
    def top_padding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def UpdateMethod(self):
        return self.com_object.UpdateMethod

    @property
    def updatemethod(self):
        """Alias for UpdateMethod"""
        return self.UpdateMethod

    @property
    def update_method(self):
        """Alias for UpdateMethod"""
        return self.UpdateMethod

    @property
    def UpdateOptions(self):
        return self.com_object.UpdateOptions

    @UpdateOptions.setter
    def UpdateOptions(self, value):
        self.com_object.UpdateOptions = value

    @property
    def updateoptions(self):
        """Alias for UpdateOptions"""
        return self.UpdateOptions

    @updateoptions.setter
    def updateoptions(self, value):
        """Alias for UpdateOptions.setter"""
        self.UpdateOptions = value

    @property
    def update_options(self):
        """Alias for UpdateOptions"""
        return self.UpdateOptions

    @update_options.setter
    def update_options(self, value):
        """Alias for UpdateOptions.setter"""
        self.UpdateOptions = value

    @property
    def VarOleObject(self):
        return self.com_object.VarOleObject

    @property
    def varoleobject(self):
        """Alias for VarOleObject"""
        return self.VarOleObject

    @property
    def var_ole_object(self):
        """Alias for VarOleObject"""
        return self.VarOleObject

    @property
    def Verb(self):
        return self.com_object.Verb

    @Verb.setter
    def Verb(self, value):
        self.com_object.Verb = value

    @property
    def verb(self):
        """Alias for Verb"""
        return self.Verb

    @verb.setter
    def verb(self, value):
        """Alias for Verb.setter"""
        self.Verb = value

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def Requery(self):
        self.com_object.Requery()

    def requery(self):
        """Alias for Requery"""
        return self.Requery()

    def SetFocus(self):
        return self.com_object.SetFocus()

    def setfocus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def set_focus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()


class Operation:

    def __init__(self, operation=None):
        self.com_object= operation

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def WSParameters(self):
        return self.com_object.WSParameters

    @property
    def wsparameters(self):
        """Alias for WSParameters"""
        return self.WSParameters

    @property
    def w_s_parameters(self):
        """Alias for WSParameters"""
        return self.WSParameters

    def Execute(self, bstrParameters=None):
        arguments = com_arguments([unwrap(a) for a in [bstrParameters]])
        return self.com_object.Execute(*arguments)

    def execute(self, bstrParameters=None):
        """Alias for Execute"""
        arguments = [bstrParameters]
        return self.Execute(*arguments)


class Operations:

    def __init__(self, operations=None):
        self.com_object= operations

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class OptionButton:

    def __init__(self, optionbutton=None):
        self.com_object= optionbutton

    @property
    def AddColon(self):
        return self.com_object.AddColon

    @AddColon.setter
    def AddColon(self, value):
        self.com_object.AddColon = value

    @property
    def addcolon(self):
        """Alias for AddColon"""
        return self.AddColon

    @addcolon.setter
    def addcolon(self, value):
        """Alias for AddColon.setter"""
        self.AddColon = value

    @property
    def add_colon(self):
        """Alias for AddColon"""
        return self.AddColon

    @add_colon.setter
    def add_colon(self, value):
        """Alias for AddColon.setter"""
        self.AddColon = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoLabel(self):
        return self.com_object.AutoLabel

    @AutoLabel.setter
    def AutoLabel(self, value):
        self.com_object.AutoLabel = value

    @property
    def autolabel(self):
        """Alias for AutoLabel"""
        return self.AutoLabel

    @autolabel.setter
    def autolabel(self, value):
        """Alias for AutoLabel.setter"""
        self.AutoLabel = value

    @property
    def auto_label(self):
        """Alias for AutoLabel"""
        return self.AutoLabel

    @auto_label.setter
    def auto_label(self, value):
        """Alias for AutoLabel.setter"""
        self.AutoLabel = value

    @property
    def BorderColor(self):
        return self.com_object.BorderColor

    @BorderColor.setter
    def BorderColor(self, value):
        self.com_object.BorderColor = value

    @property
    def bordercolor(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @bordercolor.setter
    def bordercolor(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def border_color(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @border_color.setter
    def border_color(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def BorderShade(self):
        return self.com_object.BorderShade

    @BorderShade.setter
    def BorderShade(self, value):
        self.com_object.BorderShade = value

    @property
    def bordershade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @bordershade.setter
    def bordershade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def border_shade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @border_shade.setter
    def border_shade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def BorderStyle(self):
        return self.com_object.BorderStyle

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def BorderThemeColorIndex(self):
        return self.com_object.BorderThemeColorIndex

    @BorderThemeColorIndex.setter
    def BorderThemeColorIndex(self, value):
        self.com_object.BorderThemeColorIndex = value

    @property
    def borderthemecolorindex(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @borderthemecolorindex.setter
    def borderthemecolorindex(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def border_theme_color_index(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @border_theme_color_index.setter
    def border_theme_color_index(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def BorderTint(self):
        return self.com_object.BorderTint

    @BorderTint.setter
    def BorderTint(self, value):
        self.com_object.BorderTint = value

    @property
    def bordertint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @bordertint.setter
    def bordertint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def border_tint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @border_tint.setter
    def border_tint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def BorderWidth(self):
        return self.com_object.BorderWidth

    @BorderWidth.setter
    def BorderWidth(self, value):
        self.com_object.BorderWidth = value

    @property
    def borderwidth(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @borderwidth.setter
    def borderwidth(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def border_width(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @border_width.setter
    def border_width(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def BottomPadding(self):
        return self.com_object.BottomPadding

    @BottomPadding.setter
    def BottomPadding(self, value):
        self.com_object.BottomPadding = value

    @property
    def bottompadding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottompadding.setter
    def bottompadding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def bottom_padding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottom_padding.setter
    def bottom_padding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def ColumnHidden(self):
        return self.com_object.ColumnHidden

    @ColumnHidden.setter
    def ColumnHidden(self, value):
        self.com_object.ColumnHidden = value

    @property
    def columnhidden(self):
        """Alias for ColumnHidden"""
        return self.ColumnHidden

    @columnhidden.setter
    def columnhidden(self, value):
        """Alias for ColumnHidden.setter"""
        self.ColumnHidden = value

    @property
    def column_hidden(self):
        """Alias for ColumnHidden"""
        return self.ColumnHidden

    @column_hidden.setter
    def column_hidden(self, value):
        """Alias for ColumnHidden.setter"""
        self.ColumnHidden = value

    @property
    def ColumnOrder(self):
        return self.com_object.ColumnOrder

    @ColumnOrder.setter
    def ColumnOrder(self, value):
        self.com_object.ColumnOrder = value

    @property
    def columnorder(self):
        """Alias for ColumnOrder"""
        return self.ColumnOrder

    @columnorder.setter
    def columnorder(self, value):
        """Alias for ColumnOrder.setter"""
        self.ColumnOrder = value

    @property
    def column_order(self):
        """Alias for ColumnOrder"""
        return self.ColumnOrder

    @column_order.setter
    def column_order(self, value):
        """Alias for ColumnOrder.setter"""
        self.ColumnOrder = value

    @property
    def ColumnWidth(self):
        return self.com_object.ColumnWidth

    @ColumnWidth.setter
    def ColumnWidth(self, value):
        self.com_object.ColumnWidth = value

    @property
    def columnwidth(self):
        """Alias for ColumnWidth"""
        return self.ColumnWidth

    @columnwidth.setter
    def columnwidth(self, value):
        """Alias for ColumnWidth.setter"""
        self.ColumnWidth = value

    @property
    def column_width(self):
        """Alias for ColumnWidth"""
        return self.ColumnWidth

    @column_width.setter
    def column_width(self, value):
        """Alias for ColumnWidth.setter"""
        self.ColumnWidth = value

    @property
    def Controls(self):
        return Controls(self.com_object.Controls)

    @property
    def controls(self):
        """Alias for Controls"""
        return self.Controls

    @property
    def ControlSource(self):
        return self.com_object.ControlSource

    @ControlSource.setter
    def ControlSource(self, value):
        self.com_object.ControlSource = value

    @property
    def controlsource(self):
        """Alias for ControlSource"""
        return self.ControlSource

    @controlsource.setter
    def controlsource(self, value):
        """Alias for ControlSource.setter"""
        self.ControlSource = value

    @property
    def control_source(self):
        """Alias for ControlSource"""
        return self.ControlSource

    @control_source.setter
    def control_source(self, value):
        """Alias for ControlSource.setter"""
        self.ControlSource = value

    @property
    def ControlTipText(self):
        return self.com_object.ControlTipText

    @ControlTipText.setter
    def ControlTipText(self, value):
        self.com_object.ControlTipText = value

    @property
    def controltiptext(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @controltiptext.setter
    def controltiptext(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def control_tip_text(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @control_tip_text.setter
    def control_tip_text(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def ControlType(self):
        return self.com_object.ControlType

    @ControlType.setter
    def ControlType(self, value):
        self.com_object.ControlType = value

    @property
    def controltype(self):
        """Alias for ControlType"""
        return self.ControlType

    @controltype.setter
    def controltype(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def control_type(self):
        """Alias for ControlType"""
        return self.ControlType

    @control_type.setter
    def control_type(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def DefaultValue(self):
        return self.com_object.DefaultValue

    @DefaultValue.setter
    def DefaultValue(self, value):
        self.com_object.DefaultValue = value

    @property
    def defaultvalue(self):
        """Alias for DefaultValue"""
        return self.DefaultValue

    @defaultvalue.setter
    def defaultvalue(self, value):
        """Alias for DefaultValue.setter"""
        self.DefaultValue = value

    @property
    def default_value(self):
        """Alias for DefaultValue"""
        return self.DefaultValue

    @default_value.setter
    def default_value(self, value):
        """Alias for DefaultValue.setter"""
        self.DefaultValue = value

    @property
    def DisplayWhen(self):
        return self.com_object.DisplayWhen

    @DisplayWhen.setter
    def DisplayWhen(self, value):
        self.com_object.DisplayWhen = value

    @property
    def displaywhen(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @displaywhen.setter
    def displaywhen(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def display_when(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @display_when.setter
    def display_when(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def GridlineColor(self):
        return self.com_object.GridlineColor

    @GridlineColor.setter
    def GridlineColor(self, value):
        self.com_object.GridlineColor = value

    @property
    def gridlinecolor(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridlinecolor.setter
    def gridlinecolor(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def gridline_color(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridline_color.setter
    def gridline_color(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def GridlineShade(self):
        return self.com_object.GridlineShade

    @GridlineShade.setter
    def GridlineShade(self, value):
        self.com_object.GridlineShade = value

    @property
    def gridlineshade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridlineshade.setter
    def gridlineshade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def gridline_shade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridline_shade.setter
    def gridline_shade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def GridlineStyleBottom(self):
        return self.com_object.GridlineStyleBottom

    @GridlineStyleBottom.setter
    def GridlineStyleBottom(self, value):
        self.com_object.GridlineStyleBottom = value

    @property
    def gridlinestylebottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridlinestylebottom.setter
    def gridlinestylebottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def gridline_style_bottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridline_style_bottom.setter
    def gridline_style_bottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def GridlineStyleLeft(self):
        return self.com_object.GridlineStyleLeft

    @GridlineStyleLeft.setter
    def GridlineStyleLeft(self, value):
        self.com_object.GridlineStyleLeft = value

    @property
    def gridlinestyleleft(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridlinestyleleft.setter
    def gridlinestyleleft(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def gridline_style_left(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridline_style_left.setter
    def gridline_style_left(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def GridlineStyleRight(self):
        return self.com_object.GridlineStyleRight

    @GridlineStyleRight.setter
    def GridlineStyleRight(self, value):
        self.com_object.GridlineStyleRight = value

    @property
    def gridlinestyleright(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridlinestyleright.setter
    def gridlinestyleright(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def gridline_style_right(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridline_style_right.setter
    def gridline_style_right(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def GridlineStyleTop(self):
        return self.com_object.GridlineStyleTop

    @GridlineStyleTop.setter
    def GridlineStyleTop(self, value):
        self.com_object.GridlineStyleTop = value

    @property
    def gridlinestyletop(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridlinestyletop.setter
    def gridlinestyletop(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def gridline_style_top(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridline_style_top.setter
    def gridline_style_top(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def GridlineThemeColorIndex(self):
        return self.com_object.GridlineThemeColorIndex

    @GridlineThemeColorIndex.setter
    def GridlineThemeColorIndex(self, value):
        self.com_object.GridlineThemeColorIndex = value

    @property
    def gridlinethemecolorindex(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridlinethemecolorindex.setter
    def gridlinethemecolorindex(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def gridline_theme_color_index(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridline_theme_color_index.setter
    def gridline_theme_color_index(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def GridlineTint(self):
        return self.com_object.GridlineTint

    @GridlineTint.setter
    def GridlineTint(self, value):
        self.com_object.GridlineTint = value

    @property
    def gridlinetint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridlinetint.setter
    def gridlinetint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def gridline_tint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridline_tint.setter
    def gridline_tint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def GridlineWidthBottom(self):
        return self.com_object.GridlineWidthBottom

    @GridlineWidthBottom.setter
    def GridlineWidthBottom(self, value):
        self.com_object.GridlineWidthBottom = value

    @property
    def gridlinewidthbottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridlinewidthbottom.setter
    def gridlinewidthbottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def gridline_width_bottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridline_width_bottom.setter
    def gridline_width_bottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def GridlineWidthLeft(self):
        return self.com_object.GridlineWidthLeft

    @GridlineWidthLeft.setter
    def GridlineWidthLeft(self, value):
        self.com_object.GridlineWidthLeft = value

    @property
    def gridlinewidthleft(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridlinewidthleft.setter
    def gridlinewidthleft(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def gridline_width_left(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridline_width_left.setter
    def gridline_width_left(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def GridlineWidthRight(self):
        return self.com_object.GridlineWidthRight

    @GridlineWidthRight.setter
    def GridlineWidthRight(self, value):
        self.com_object.GridlineWidthRight = value

    @property
    def gridlinewidthright(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridlinewidthright.setter
    def gridlinewidthright(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def gridline_width_right(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridline_width_right.setter
    def gridline_width_right(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def GridlineWidthTop(self):
        return self.com_object.GridlineWidthTop

    @GridlineWidthTop.setter
    def GridlineWidthTop(self, value):
        self.com_object.GridlineWidthTop = value

    @property
    def gridlinewidthtop(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridlinewidthtop.setter
    def gridlinewidthtop(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def gridline_width_top(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridline_width_top.setter
    def gridline_width_top(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HelpContextId(self):
        return self.com_object.HelpContextId

    @HelpContextId.setter
    def HelpContextId(self, value):
        self.com_object.HelpContextId = value

    @property
    def helpcontextid(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @helpcontextid.setter
    def helpcontextid(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def help_context_id(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @help_context_id.setter
    def help_context_id(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def HideDuplicates(self):
        return self.com_object.HideDuplicates

    @HideDuplicates.setter
    def HideDuplicates(self, value):
        self.com_object.HideDuplicates = value

    @property
    def hideduplicates(self):
        """Alias for HideDuplicates"""
        return self.HideDuplicates

    @hideduplicates.setter
    def hideduplicates(self, value):
        """Alias for HideDuplicates.setter"""
        self.HideDuplicates = value

    @property
    def hide_duplicates(self):
        """Alias for HideDuplicates"""
        return self.HideDuplicates

    @hide_duplicates.setter
    def hide_duplicates(self, value):
        """Alias for HideDuplicates.setter"""
        self.HideDuplicates = value

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def IsVisible(self):
        return self.com_object.IsVisible

    @IsVisible.setter
    def IsVisible(self, value):
        self.com_object.IsVisible = value

    @property
    def isvisible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @isvisible.setter
    def isvisible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def is_visible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @is_visible.setter
    def is_visible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def LabelAlign(self):
        return self.com_object.LabelAlign

    @LabelAlign.setter
    def LabelAlign(self, value):
        self.com_object.LabelAlign = value

    @property
    def labelalign(self):
        """Alias for LabelAlign"""
        return self.LabelAlign

    @labelalign.setter
    def labelalign(self, value):
        """Alias for LabelAlign.setter"""
        self.LabelAlign = value

    @property
    def label_align(self):
        """Alias for LabelAlign"""
        return self.LabelAlign

    @label_align.setter
    def label_align(self, value):
        """Alias for LabelAlign.setter"""
        self.LabelAlign = value

    @property
    def LabelX(self):
        return self.com_object.LabelX

    @LabelX.setter
    def LabelX(self, value):
        self.com_object.LabelX = value

    @property
    def labelx(self):
        """Alias for LabelX"""
        return self.LabelX

    @labelx.setter
    def labelx(self, value):
        """Alias for LabelX.setter"""
        self.LabelX = value

    @property
    def label_x(self):
        """Alias for LabelX"""
        return self.LabelX

    @label_x.setter
    def label_x(self, value):
        """Alias for LabelX.setter"""
        self.LabelX = value

    @property
    def LabelY(self):
        return self.com_object.LabelY

    @LabelY.setter
    def LabelY(self, value):
        self.com_object.LabelY = value

    @property
    def labely(self):
        """Alias for LabelY"""
        return self.LabelY

    @labely.setter
    def labely(self, value):
        """Alias for LabelY.setter"""
        self.LabelY = value

    @property
    def label_y(self):
        """Alias for LabelY"""
        return self.LabelY

    @label_y.setter
    def label_y(self, value):
        """Alias for LabelY.setter"""
        self.LabelY = value

    @property
    def Layout(self):
        return AcLayoutType(self.com_object.Layout)

    @property
    def layout(self):
        """Alias for Layout"""
        return self.Layout

    @property
    def LayoutID(self):
        return self.com_object.LayoutID

    @property
    def layoutid(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def layout_i_d(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def LeftPadding(self):
        return self.com_object.LeftPadding

    @LeftPadding.setter
    def LeftPadding(self, value):
        self.com_object.LeftPadding = value

    @property
    def leftpadding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @leftpadding.setter
    def leftpadding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def left_padding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @left_padding.setter
    def left_padding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def OldBorderStyle(self):
        return self.com_object.OldBorderStyle

    @OldBorderStyle.setter
    def OldBorderStyle(self, value):
        self.com_object.OldBorderStyle = value

    @property
    def oldborderstyle(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @oldborderstyle.setter
    def oldborderstyle(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def old_border_style(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @old_border_style.setter
    def old_border_style(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def OldValue(self):
        return self.com_object.OldValue

    @property
    def oldvalue(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def old_value(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def OnClick(self):
        return self.com_object.OnClick

    @OnClick.setter
    def OnClick(self, value):
        self.com_object.OnClick = value

    @property
    def onclick(self):
        """Alias for OnClick"""
        return self.OnClick

    @onclick.setter
    def onclick(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def on_click(self):
        """Alias for OnClick"""
        return self.OnClick

    @on_click.setter
    def on_click(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def OnDblClick(self):
        return self.com_object.OnDblClick

    @OnDblClick.setter
    def OnDblClick(self, value):
        self.com_object.OnDblClick = value

    @property
    def ondblclick(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @ondblclick.setter
    def ondblclick(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def on_dbl_click(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @on_dbl_click.setter
    def on_dbl_click(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def OnEnter(self):
        return self.com_object.OnEnter

    @OnEnter.setter
    def OnEnter(self, value):
        self.com_object.OnEnter = value

    @property
    def onenter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @onenter.setter
    def onenter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def on_enter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @on_enter.setter
    def on_enter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def OnExit(self):
        return self.com_object.OnExit

    @OnExit.setter
    def OnExit(self, value):
        self.com_object.OnExit = value

    @property
    def onexit(self):
        """Alias for OnExit"""
        return self.OnExit

    @onexit.setter
    def onexit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def on_exit(self):
        """Alias for OnExit"""
        return self.OnExit

    @on_exit.setter
    def on_exit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def OnGotFocus(self):
        return self.com_object.OnGotFocus

    @OnGotFocus.setter
    def OnGotFocus(self, value):
        self.com_object.OnGotFocus = value

    @property
    def ongotfocus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @ongotfocus.setter
    def ongotfocus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def on_got_focus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @on_got_focus.setter
    def on_got_focus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def OnKeyDown(self):
        return self.com_object.OnKeyDown

    @OnKeyDown.setter
    def OnKeyDown(self, value):
        self.com_object.OnKeyDown = value

    @property
    def onkeydown(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @onkeydown.setter
    def onkeydown(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def on_key_down(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @on_key_down.setter
    def on_key_down(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def OnKeyPress(self):
        return self.com_object.OnKeyPress

    @OnKeyPress.setter
    def OnKeyPress(self, value):
        self.com_object.OnKeyPress = value

    @property
    def onkeypress(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @onkeypress.setter
    def onkeypress(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def on_key_press(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @on_key_press.setter
    def on_key_press(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def OnKeyUp(self):
        return self.com_object.OnKeyUp

    @OnKeyUp.setter
    def OnKeyUp(self, value):
        self.com_object.OnKeyUp = value

    @property
    def onkeyup(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @onkeyup.setter
    def onkeyup(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def on_key_up(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @on_key_up.setter
    def on_key_up(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def OnLostFocus(self):
        return self.com_object.OnLostFocus

    @OnLostFocus.setter
    def OnLostFocus(self, value):
        self.com_object.OnLostFocus = value

    @property
    def onlostfocus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @onlostfocus.setter
    def onlostfocus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def on_lost_focus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @on_lost_focus.setter
    def on_lost_focus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def OnMouseDown(self):
        return self.com_object.OnMouseDown

    @OnMouseDown.setter
    def OnMouseDown(self, value):
        self.com_object.OnMouseDown = value

    @property
    def onmousedown(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @onmousedown.setter
    def onmousedown(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def on_mouse_down(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @on_mouse_down.setter
    def on_mouse_down(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def OnMouseMove(self):
        return self.com_object.OnMouseMove

    @OnMouseMove.setter
    def OnMouseMove(self, value):
        self.com_object.OnMouseMove = value

    @property
    def onmousemove(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @onmousemove.setter
    def onmousemove(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def on_mouse_move(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @on_mouse_move.setter
    def on_mouse_move(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def OnMouseUp(self):
        return self.com_object.OnMouseUp

    @OnMouseUp.setter
    def OnMouseUp(self, value):
        self.com_object.OnMouseUp = value

    @property
    def onmouseup(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @onmouseup.setter
    def onmouseup(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def on_mouse_up(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @on_mouse_up.setter
    def on_mouse_up(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def OptionValue(self):
        return self.com_object.OptionValue

    @OptionValue.setter
    def OptionValue(self, value):
        self.com_object.OptionValue = value

    @property
    def optionvalue(self):
        """Alias for OptionValue"""
        return self.OptionValue

    @optionvalue.setter
    def optionvalue(self, value):
        """Alias for OptionValue.setter"""
        self.OptionValue = value

    @property
    def option_value(self):
        """Alias for OptionValue"""
        return self.OptionValue

    @option_value.setter
    def option_value(self, value):
        """Alias for OptionValue.setter"""
        self.OptionValue = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def ReadingOrder(self):
        return self.com_object.ReadingOrder

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def RightPadding(self):
        return self.com_object.RightPadding

    @RightPadding.setter
    def RightPadding(self, value):
        self.com_object.RightPadding = value

    @property
    def rightpadding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @rightpadding.setter
    def rightpadding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def right_padding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @right_padding.setter
    def right_padding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def Section(self):
        return self.com_object.Section

    @Section.setter
    def Section(self, value):
        self.com_object.Section = value

    @property
    def section(self):
        """Alias for Section"""
        return self.Section

    @section.setter
    def section(self, value):
        """Alias for Section.setter"""
        self.Section = value

    @property
    def ShortcutMenuBar(self):
        return self.com_object.ShortcutMenuBar

    @ShortcutMenuBar.setter
    def ShortcutMenuBar(self, value):
        self.com_object.ShortcutMenuBar = value

    @property
    def shortcutmenubar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcutmenubar.setter
    def shortcutmenubar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def shortcut_menu_bar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcut_menu_bar.setter
    def shortcut_menu_bar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def SpecialEffect(self):
        return self.com_object.SpecialEffect

    @SpecialEffect.setter
    def SpecialEffect(self, value):
        self.com_object.SpecialEffect = value

    @property
    def specialeffect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @specialeffect.setter
    def specialeffect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def special_effect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @special_effect.setter
    def special_effect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def StatusBarText(self):
        return self.com_object.StatusBarText

    @StatusBarText.setter
    def StatusBarText(self, value):
        self.com_object.StatusBarText = value

    @property
    def statusbartext(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @statusbartext.setter
    def statusbartext(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def status_bar_text(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @status_bar_text.setter
    def status_bar_text(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def TabIndex(self):
        return self.com_object.TabIndex

    @TabIndex.setter
    def TabIndex(self, value):
        self.com_object.TabIndex = value

    @property
    def tabindex(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tabindex.setter
    def tabindex(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def tab_index(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tab_index.setter
    def tab_index(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def TabStop(self):
        return self.com_object.TabStop

    @TabStop.setter
    def TabStop(self, value):
        self.com_object.TabStop = value

    @property
    def tabstop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tabstop.setter
    def tabstop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def tab_stop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tab_stop.setter
    def tab_stop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TopPadding(self):
        return self.com_object.TopPadding

    @TopPadding.setter
    def TopPadding(self, value):
        self.com_object.TopPadding = value

    @property
    def toppadding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @toppadding.setter
    def toppadding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def top_padding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @top_padding.setter
    def top_padding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def TripleState(self):
        return self.com_object.TripleState

    @TripleState.setter
    def TripleState(self, value):
        self.com_object.TripleState = value

    @property
    def triplestate(self):
        """Alias for TripleState"""
        return self.TripleState

    @triplestate.setter
    def triplestate(self, value):
        """Alias for TripleState.setter"""
        self.TripleState = value

    @property
    def triple_state(self):
        """Alias for TripleState"""
        return self.TripleState

    @triple_state.setter
    def triple_state(self, value):
        """Alias for TripleState.setter"""
        self.TripleState = value

    @property
    def ValidationRule(self):
        return self.com_object.ValidationRule

    @ValidationRule.setter
    def ValidationRule(self, value):
        self.com_object.ValidationRule = value

    @property
    def validationrule(self):
        """Alias for ValidationRule"""
        return self.ValidationRule

    @validationrule.setter
    def validationrule(self, value):
        """Alias for ValidationRule.setter"""
        self.ValidationRule = value

    @property
    def validation_rule(self):
        """Alias for ValidationRule"""
        return self.ValidationRule

    @validation_rule.setter
    def validation_rule(self, value):
        """Alias for ValidationRule.setter"""
        self.ValidationRule = value

    @property
    def ValidationText(self):
        return self.com_object.ValidationText

    @ValidationText.setter
    def ValidationText(self, value):
        self.com_object.ValidationText = value

    @property
    def validationtext(self):
        """Alias for ValidationText"""
        return self.ValidationText

    @validationtext.setter
    def validationtext(self, value):
        """Alias for ValidationText.setter"""
        self.ValidationText = value

    @property
    def validation_text(self):
        """Alias for ValidationText"""
        return self.ValidationText

    @validation_text.setter
    def validation_text(self, value):
        """Alias for ValidationText.setter"""
        self.ValidationText = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def Requery(self):
        self.com_object.Requery()

    def requery(self):
        """Alias for Requery"""
        return self.Requery()

    def SetFocus(self):
        return self.com_object.SetFocus()

    def setfocus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def set_focus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()


class OptionGroup:

    def __init__(self, optiongroup=None):
        self.com_object= optiongroup

    @property
    def AddColon(self):
        return self.com_object.AddColon

    @AddColon.setter
    def AddColon(self, value):
        self.com_object.AddColon = value

    @property
    def addcolon(self):
        """Alias for AddColon"""
        return self.AddColon

    @addcolon.setter
    def addcolon(self, value):
        """Alias for AddColon.setter"""
        self.AddColon = value

    @property
    def add_colon(self):
        """Alias for AddColon"""
        return self.AddColon

    @add_colon.setter
    def add_colon(self, value):
        """Alias for AddColon.setter"""
        self.AddColon = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoLabel(self):
        return self.com_object.AutoLabel

    @AutoLabel.setter
    def AutoLabel(self, value):
        self.com_object.AutoLabel = value

    @property
    def autolabel(self):
        """Alias for AutoLabel"""
        return self.AutoLabel

    @autolabel.setter
    def autolabel(self, value):
        """Alias for AutoLabel.setter"""
        self.AutoLabel = value

    @property
    def auto_label(self):
        """Alias for AutoLabel"""
        return self.AutoLabel

    @auto_label.setter
    def auto_label(self, value):
        """Alias for AutoLabel.setter"""
        self.AutoLabel = value

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BackShade(self):
        return self.com_object.BackShade

    @BackShade.setter
    def BackShade(self, value):
        self.com_object.BackShade = value

    @property
    def backshade(self):
        """Alias for BackShade"""
        return self.BackShade

    @backshade.setter
    def backshade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def back_shade(self):
        """Alias for BackShade"""
        return self.BackShade

    @back_shade.setter
    def back_shade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def BackStyle(self):
        return self.com_object.BackStyle

    @BackStyle.setter
    def BackStyle(self, value):
        self.com_object.BackStyle = value

    @property
    def backstyle(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @backstyle.setter
    def backstyle(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def back_style(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @back_style.setter
    def back_style(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def BackThemeColorIndex(self):
        return self.com_object.BackThemeColorIndex

    @BackThemeColorIndex.setter
    def BackThemeColorIndex(self, value):
        self.com_object.BackThemeColorIndex = value

    @property
    def backthemecolorindex(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @backthemecolorindex.setter
    def backthemecolorindex(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def back_theme_color_index(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @back_theme_color_index.setter
    def back_theme_color_index(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def BackTint(self):
        return self.com_object.BackTint

    @BackTint.setter
    def BackTint(self, value):
        self.com_object.BackTint = value

    @property
    def backtint(self):
        """Alias for BackTint"""
        return self.BackTint

    @backtint.setter
    def backtint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def back_tint(self):
        """Alias for BackTint"""
        return self.BackTint

    @back_tint.setter
    def back_tint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def BorderColor(self):
        return self.com_object.BorderColor

    @BorderColor.setter
    def BorderColor(self, value):
        self.com_object.BorderColor = value

    @property
    def bordercolor(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @bordercolor.setter
    def bordercolor(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def border_color(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @border_color.setter
    def border_color(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def BorderShade(self):
        return self.com_object.BorderShade

    @BorderShade.setter
    def BorderShade(self, value):
        self.com_object.BorderShade = value

    @property
    def bordershade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @bordershade.setter
    def bordershade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def border_shade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @border_shade.setter
    def border_shade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def BorderStyle(self):
        return self.com_object.BorderStyle

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def BorderThemeColorIndex(self):
        return self.com_object.BorderThemeColorIndex

    @BorderThemeColorIndex.setter
    def BorderThemeColorIndex(self, value):
        self.com_object.BorderThemeColorIndex = value

    @property
    def borderthemecolorindex(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @borderthemecolorindex.setter
    def borderthemecolorindex(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def border_theme_color_index(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @border_theme_color_index.setter
    def border_theme_color_index(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def BorderTint(self):
        return self.com_object.BorderTint

    @BorderTint.setter
    def BorderTint(self, value):
        self.com_object.BorderTint = value

    @property
    def bordertint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @bordertint.setter
    def bordertint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def border_tint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @border_tint.setter
    def border_tint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def BorderWidth(self):
        return self.com_object.BorderWidth

    @BorderWidth.setter
    def BorderWidth(self, value):
        self.com_object.BorderWidth = value

    @property
    def borderwidth(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @borderwidth.setter
    def borderwidth(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def border_width(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @border_width.setter
    def border_width(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def ColumnHidden(self):
        return self.com_object.ColumnHidden

    @ColumnHidden.setter
    def ColumnHidden(self, value):
        self.com_object.ColumnHidden = value

    @property
    def columnhidden(self):
        """Alias for ColumnHidden"""
        return self.ColumnHidden

    @columnhidden.setter
    def columnhidden(self, value):
        """Alias for ColumnHidden.setter"""
        self.ColumnHidden = value

    @property
    def column_hidden(self):
        """Alias for ColumnHidden"""
        return self.ColumnHidden

    @column_hidden.setter
    def column_hidden(self, value):
        """Alias for ColumnHidden.setter"""
        self.ColumnHidden = value

    @property
    def ColumnOrder(self):
        return self.com_object.ColumnOrder

    @ColumnOrder.setter
    def ColumnOrder(self, value):
        self.com_object.ColumnOrder = value

    @property
    def columnorder(self):
        """Alias for ColumnOrder"""
        return self.ColumnOrder

    @columnorder.setter
    def columnorder(self, value):
        """Alias for ColumnOrder.setter"""
        self.ColumnOrder = value

    @property
    def column_order(self):
        """Alias for ColumnOrder"""
        return self.ColumnOrder

    @column_order.setter
    def column_order(self, value):
        """Alias for ColumnOrder.setter"""
        self.ColumnOrder = value

    @property
    def ColumnWidth(self):
        return self.com_object.ColumnWidth

    @ColumnWidth.setter
    def ColumnWidth(self, value):
        self.com_object.ColumnWidth = value

    @property
    def columnwidth(self):
        """Alias for ColumnWidth"""
        return self.ColumnWidth

    @columnwidth.setter
    def columnwidth(self, value):
        """Alias for ColumnWidth.setter"""
        self.ColumnWidth = value

    @property
    def column_width(self):
        """Alias for ColumnWidth"""
        return self.ColumnWidth

    @column_width.setter
    def column_width(self, value):
        """Alias for ColumnWidth.setter"""
        self.ColumnWidth = value

    @property
    def Controls(self):
        return Controls(self.com_object.Controls)

    @property
    def controls(self):
        """Alias for Controls"""
        return self.Controls

    @property
    def ControlSource(self):
        return self.com_object.ControlSource

    @ControlSource.setter
    def ControlSource(self, value):
        self.com_object.ControlSource = value

    @property
    def controlsource(self):
        """Alias for ControlSource"""
        return self.ControlSource

    @controlsource.setter
    def controlsource(self, value):
        """Alias for ControlSource.setter"""
        self.ControlSource = value

    @property
    def control_source(self):
        """Alias for ControlSource"""
        return self.ControlSource

    @control_source.setter
    def control_source(self, value):
        """Alias for ControlSource.setter"""
        self.ControlSource = value

    @property
    def ControlTipText(self):
        return self.com_object.ControlTipText

    @ControlTipText.setter
    def ControlTipText(self, value):
        self.com_object.ControlTipText = value

    @property
    def controltiptext(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @controltiptext.setter
    def controltiptext(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def control_tip_text(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @control_tip_text.setter
    def control_tip_text(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def ControlType(self):
        return self.com_object.ControlType

    @ControlType.setter
    def ControlType(self, value):
        self.com_object.ControlType = value

    @property
    def controltype(self):
        """Alias for ControlType"""
        return self.ControlType

    @controltype.setter
    def controltype(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def control_type(self):
        """Alias for ControlType"""
        return self.ControlType

    @control_type.setter
    def control_type(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def DefaultValue(self):
        return self.com_object.DefaultValue

    @DefaultValue.setter
    def DefaultValue(self, value):
        self.com_object.DefaultValue = value

    @property
    def defaultvalue(self):
        """Alias for DefaultValue"""
        return self.DefaultValue

    @defaultvalue.setter
    def defaultvalue(self, value):
        """Alias for DefaultValue.setter"""
        self.DefaultValue = value

    @property
    def default_value(self):
        """Alias for DefaultValue"""
        return self.DefaultValue

    @default_value.setter
    def default_value(self, value):
        """Alias for DefaultValue.setter"""
        self.DefaultValue = value

    @property
    def DisplayWhen(self):
        return self.com_object.DisplayWhen

    @DisplayWhen.setter
    def DisplayWhen(self, value):
        self.com_object.DisplayWhen = value

    @property
    def displaywhen(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @displaywhen.setter
    def displaywhen(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def display_when(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @display_when.setter
    def display_when(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HelpContextId(self):
        return self.com_object.HelpContextId

    @HelpContextId.setter
    def HelpContextId(self, value):
        self.com_object.HelpContextId = value

    @property
    def helpcontextid(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @helpcontextid.setter
    def helpcontextid(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def help_context_id(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @help_context_id.setter
    def help_context_id(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def HideDuplicates(self):
        return self.com_object.HideDuplicates

    @HideDuplicates.setter
    def HideDuplicates(self, value):
        self.com_object.HideDuplicates = value

    @property
    def hideduplicates(self):
        """Alias for HideDuplicates"""
        return self.HideDuplicates

    @hideduplicates.setter
    def hideduplicates(self, value):
        """Alias for HideDuplicates.setter"""
        self.HideDuplicates = value

    @property
    def hide_duplicates(self):
        """Alias for HideDuplicates"""
        return self.HideDuplicates

    @hide_duplicates.setter
    def hide_duplicates(self, value):
        """Alias for HideDuplicates.setter"""
        self.HideDuplicates = value

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def IsVisible(self):
        return self.com_object.IsVisible

    @IsVisible.setter
    def IsVisible(self, value):
        self.com_object.IsVisible = value

    @property
    def isvisible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @isvisible.setter
    def isvisible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def is_visible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @is_visible.setter
    def is_visible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def LabelAlign(self):
        return self.com_object.LabelAlign

    @LabelAlign.setter
    def LabelAlign(self, value):
        self.com_object.LabelAlign = value

    @property
    def labelalign(self):
        """Alias for LabelAlign"""
        return self.LabelAlign

    @labelalign.setter
    def labelalign(self, value):
        """Alias for LabelAlign.setter"""
        self.LabelAlign = value

    @property
    def label_align(self):
        """Alias for LabelAlign"""
        return self.LabelAlign

    @label_align.setter
    def label_align(self, value):
        """Alias for LabelAlign.setter"""
        self.LabelAlign = value

    @property
    def LabelX(self):
        return self.com_object.LabelX

    @LabelX.setter
    def LabelX(self, value):
        self.com_object.LabelX = value

    @property
    def labelx(self):
        """Alias for LabelX"""
        return self.LabelX

    @labelx.setter
    def labelx(self, value):
        """Alias for LabelX.setter"""
        self.LabelX = value

    @property
    def label_x(self):
        """Alias for LabelX"""
        return self.LabelX

    @label_x.setter
    def label_x(self, value):
        """Alias for LabelX.setter"""
        self.LabelX = value

    @property
    def LabelY(self):
        return self.com_object.LabelY

    @LabelY.setter
    def LabelY(self, value):
        self.com_object.LabelY = value

    @property
    def labely(self):
        """Alias for LabelY"""
        return self.LabelY

    @labely.setter
    def labely(self, value):
        """Alias for LabelY.setter"""
        self.LabelY = value

    @property
    def label_y(self):
        """Alias for LabelY"""
        return self.LabelY

    @label_y.setter
    def label_y(self, value):
        """Alias for LabelY.setter"""
        self.LabelY = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def OldBorderStyle(self):
        return self.com_object.OldBorderStyle

    @OldBorderStyle.setter
    def OldBorderStyle(self, value):
        self.com_object.OldBorderStyle = value

    @property
    def oldborderstyle(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @oldborderstyle.setter
    def oldborderstyle(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def old_border_style(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @old_border_style.setter
    def old_border_style(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def OldValue(self):
        return self.com_object.OldValue

    @property
    def oldvalue(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def old_value(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def OnClick(self):
        return self.com_object.OnClick

    @OnClick.setter
    def OnClick(self, value):
        self.com_object.OnClick = value

    @property
    def onclick(self):
        """Alias for OnClick"""
        return self.OnClick

    @onclick.setter
    def onclick(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def on_click(self):
        """Alias for OnClick"""
        return self.OnClick

    @on_click.setter
    def on_click(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def OnDblClick(self):
        return self.com_object.OnDblClick

    @OnDblClick.setter
    def OnDblClick(self, value):
        self.com_object.OnDblClick = value

    @property
    def ondblclick(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @ondblclick.setter
    def ondblclick(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def on_dbl_click(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @on_dbl_click.setter
    def on_dbl_click(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def OnEnter(self):
        return self.com_object.OnEnter

    @OnEnter.setter
    def OnEnter(self, value):
        self.com_object.OnEnter = value

    @property
    def onenter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @onenter.setter
    def onenter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def on_enter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @on_enter.setter
    def on_enter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def OnExit(self):
        return self.com_object.OnExit

    @OnExit.setter
    def OnExit(self, value):
        self.com_object.OnExit = value

    @property
    def onexit(self):
        """Alias for OnExit"""
        return self.OnExit

    @onexit.setter
    def onexit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def on_exit(self):
        """Alias for OnExit"""
        return self.OnExit

    @on_exit.setter
    def on_exit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def OnMouseDown(self):
        return self.com_object.OnMouseDown

    @OnMouseDown.setter
    def OnMouseDown(self, value):
        self.com_object.OnMouseDown = value

    @property
    def onmousedown(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @onmousedown.setter
    def onmousedown(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def on_mouse_down(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @on_mouse_down.setter
    def on_mouse_down(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def OnMouseMove(self):
        return self.com_object.OnMouseMove

    @OnMouseMove.setter
    def OnMouseMove(self, value):
        self.com_object.OnMouseMove = value

    @property
    def onmousemove(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @onmousemove.setter
    def onmousemove(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def on_mouse_move(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @on_mouse_move.setter
    def on_mouse_move(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def OnMouseUp(self):
        return self.com_object.OnMouseUp

    @OnMouseUp.setter
    def OnMouseUp(self, value):
        self.com_object.OnMouseUp = value

    @property
    def onmouseup(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @onmouseup.setter
    def onmouseup(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def on_mouse_up(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @on_mouse_up.setter
    def on_mouse_up(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def Section(self):
        return self.com_object.Section

    @Section.setter
    def Section(self, value):
        self.com_object.Section = value

    @property
    def section(self):
        """Alias for Section"""
        return self.Section

    @section.setter
    def section(self, value):
        """Alias for Section.setter"""
        self.Section = value

    @property
    def ShortcutMenuBar(self):
        return self.com_object.ShortcutMenuBar

    @ShortcutMenuBar.setter
    def ShortcutMenuBar(self, value):
        self.com_object.ShortcutMenuBar = value

    @property
    def shortcutmenubar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcutmenubar.setter
    def shortcutmenubar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def shortcut_menu_bar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcut_menu_bar.setter
    def shortcut_menu_bar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def SpecialEffect(self):
        return self.com_object.SpecialEffect

    @SpecialEffect.setter
    def SpecialEffect(self, value):
        self.com_object.SpecialEffect = value

    @property
    def specialeffect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @specialeffect.setter
    def specialeffect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def special_effect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @special_effect.setter
    def special_effect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def StatusBarText(self):
        return self.com_object.StatusBarText

    @StatusBarText.setter
    def StatusBarText(self, value):
        self.com_object.StatusBarText = value

    @property
    def statusbartext(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @statusbartext.setter
    def statusbartext(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def status_bar_text(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @status_bar_text.setter
    def status_bar_text(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def TabIndex(self):
        return self.com_object.TabIndex

    @TabIndex.setter
    def TabIndex(self, value):
        self.com_object.TabIndex = value

    @property
    def tabindex(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tabindex.setter
    def tabindex(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def tab_index(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tab_index.setter
    def tab_index(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def TabStop(self):
        return self.com_object.TabStop

    @TabStop.setter
    def TabStop(self, value):
        self.com_object.TabStop = value

    @property
    def tabstop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tabstop.setter
    def tabstop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def tab_stop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tab_stop.setter
    def tab_stop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def ValidationRule(self):
        return self.com_object.ValidationRule

    @ValidationRule.setter
    def ValidationRule(self, value):
        self.com_object.ValidationRule = value

    @property
    def validationrule(self):
        """Alias for ValidationRule"""
        return self.ValidationRule

    @validationrule.setter
    def validationrule(self, value):
        """Alias for ValidationRule.setter"""
        self.ValidationRule = value

    @property
    def validation_rule(self):
        """Alias for ValidationRule"""
        return self.ValidationRule

    @validation_rule.setter
    def validation_rule(self, value):
        """Alias for ValidationRule.setter"""
        self.ValidationRule = value

    @property
    def ValidationText(self):
        return self.com_object.ValidationText

    @ValidationText.setter
    def ValidationText(self, value):
        self.com_object.ValidationText = value

    @property
    def validationtext(self):
        """Alias for ValidationText"""
        return self.ValidationText

    @validationtext.setter
    def validationtext(self, value):
        """Alias for ValidationText.setter"""
        self.ValidationText = value

    @property
    def validation_text(self):
        """Alias for ValidationText"""
        return self.ValidationText

    @validation_text.setter
    def validation_text(self, value):
        """Alias for ValidationText.setter"""
        self.ValidationText = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def Requery(self):
        self.com_object.Requery()

    def requery(self):
        """Alias for Requery"""
        return self.Requery()

    def SetFocus(self):
        return self.com_object.SetFocus()

    def setfocus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def set_focus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def Undo(self):
        self.com_object.Undo()

    def undo(self):
        """Alias for Undo"""
        return self.Undo()


class Page:

    def __init__(self, page=None):
        self.com_object= page

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    @property
    def Controls(self):
        return Controls(self.com_object.Controls)

    @property
    def controls(self):
        """Alias for Controls"""
        return self.Controls

    @property
    def ControlTipText(self):
        return self.com_object.ControlTipText

    @ControlTipText.setter
    def ControlTipText(self, value):
        self.com_object.ControlTipText = value

    @property
    def controltiptext(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @controltiptext.setter
    def controltiptext(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def control_tip_text(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @control_tip_text.setter
    def control_tip_text(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def ControlType(self):
        return self.com_object.ControlType

    @ControlType.setter
    def ControlType(self, value):
        self.com_object.ControlType = value

    @property
    def controltype(self):
        """Alias for ControlType"""
        return self.ControlType

    @controltype.setter
    def controltype(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def control_type(self):
        """Alias for ControlType"""
        return self.ControlType

    @control_type.setter
    def control_type(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HelpContextId(self):
        return self.com_object.HelpContextId

    @HelpContextId.setter
    def HelpContextId(self, value):
        self.com_object.HelpContextId = value

    @property
    def helpcontextid(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @helpcontextid.setter
    def helpcontextid(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def help_context_id(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @help_context_id.setter
    def help_context_id(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def IsVisible(self):
        return self.com_object.IsVisible

    @IsVisible.setter
    def IsVisible(self, value):
        self.com_object.IsVisible = value

    @property
    def isvisible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @isvisible.setter
    def isvisible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def is_visible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @is_visible.setter
    def is_visible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def OnClick(self):
        return self.com_object.OnClick

    @OnClick.setter
    def OnClick(self, value):
        self.com_object.OnClick = value

    @property
    def onclick(self):
        """Alias for OnClick"""
        return self.OnClick

    @onclick.setter
    def onclick(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def on_click(self):
        """Alias for OnClick"""
        return self.OnClick

    @on_click.setter
    def on_click(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def OnDblClick(self):
        return self.com_object.OnDblClick

    @OnDblClick.setter
    def OnDblClick(self, value):
        self.com_object.OnDblClick = value

    @property
    def ondblclick(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @ondblclick.setter
    def ondblclick(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def on_dbl_click(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @on_dbl_click.setter
    def on_dbl_click(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def OnMouseDown(self):
        return self.com_object.OnMouseDown

    @OnMouseDown.setter
    def OnMouseDown(self, value):
        self.com_object.OnMouseDown = value

    @property
    def onmousedown(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @onmousedown.setter
    def onmousedown(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def on_mouse_down(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @on_mouse_down.setter
    def on_mouse_down(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def OnMouseMove(self):
        return self.com_object.OnMouseMove

    @OnMouseMove.setter
    def OnMouseMove(self, value):
        self.com_object.OnMouseMove = value

    @property
    def onmousemove(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @onmousemove.setter
    def onmousemove(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def on_mouse_move(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @on_mouse_move.setter
    def on_mouse_move(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def OnMouseUp(self):
        return self.com_object.OnMouseUp

    @OnMouseUp.setter
    def OnMouseUp(self, value):
        self.com_object.OnMouseUp = value

    @property
    def onmouseup(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @onmouseup.setter
    def onmouseup(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def on_mouse_up(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @on_mouse_up.setter
    def on_mouse_up(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def PageIndex(self):
        return self.com_object.PageIndex

    @PageIndex.setter
    def PageIndex(self, value):
        self.com_object.PageIndex = value

    @property
    def pageindex(self):
        """Alias for PageIndex"""
        return self.PageIndex

    @pageindex.setter
    def pageindex(self, value):
        """Alias for PageIndex.setter"""
        self.PageIndex = value

    @property
    def page_index(self):
        """Alias for PageIndex"""
        return self.PageIndex

    @page_index.setter
    def page_index(self, value):
        """Alias for PageIndex.setter"""
        self.PageIndex = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Picture(self):
        return self.com_object.Picture

    @Picture.setter
    def Picture(self, value):
        self.com_object.Picture = value

    @property
    def picture(self):
        """Alias for Picture"""
        return self.Picture

    @picture.setter
    def picture(self, value):
        """Alias for Picture.setter"""
        self.Picture = value

    @property
    def PictureData(self):
        return self.com_object.PictureData

    @PictureData.setter
    def PictureData(self, value):
        self.com_object.PictureData = value

    @property
    def picturedata(self):
        """Alias for PictureData"""
        return self.PictureData

    @picturedata.setter
    def picturedata(self, value):
        """Alias for PictureData.setter"""
        self.PictureData = value

    @property
    def picture_data(self):
        """Alias for PictureData"""
        return self.PictureData

    @picture_data.setter
    def picture_data(self, value):
        """Alias for PictureData.setter"""
        self.PictureData = value

    @property
    def PictureType(self):
        return self.com_object.PictureType

    @PictureType.setter
    def PictureType(self, value):
        self.com_object.PictureType = value

    @property
    def picturetype(self):
        """Alias for PictureType"""
        return self.PictureType

    @picturetype.setter
    def picturetype(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def picture_type(self):
        """Alias for PictureType"""
        return self.PictureType

    @picture_type.setter
    def picture_type(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def Section(self):
        return self.com_object.Section

    @Section.setter
    def Section(self, value):
        self.com_object.Section = value

    @property
    def section(self):
        """Alias for Section"""
        return self.Section

    @section.setter
    def section(self, value):
        """Alias for Section.setter"""
        self.Section = value

    @property
    def ShortcutMenuBar(self):
        return self.com_object.ShortcutMenuBar

    @ShortcutMenuBar.setter
    def ShortcutMenuBar(self, value):
        self.com_object.ShortcutMenuBar = value

    @property
    def shortcutmenubar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcutmenubar.setter
    def shortcutmenubar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def shortcut_menu_bar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcut_menu_bar.setter
    def shortcut_menu_bar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def StatusBarText(self):
        return self.com_object.StatusBarText

    @StatusBarText.setter
    def StatusBarText(self, value):
        self.com_object.StatusBarText = value

    @property
    def statusbartext(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @statusbartext.setter
    def statusbartext(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def status_bar_text(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @status_bar_text.setter
    def status_bar_text(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def Requery(self):
        self.com_object.Requery()

    def requery(self):
        """Alias for Requery"""
        return self.Requery()

    def SetFocus(self):
        return self.com_object.SetFocus()

    def setfocus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def set_focus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def SetTabOrder(self):
        self.com_object.SetTabOrder()

    def settaborder(self):
        """Alias for SetTabOrder"""
        return self.SetTabOrder()

    def set_tab_order(self):
        """Alias for SetTabOrder"""
        return self.SetTabOrder()

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()


class PageBreak:

    def __init__(self, pagebreak=None):
        self.com_object= pagebreak

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def ControlType(self):
        return self.com_object.ControlType

    @ControlType.setter
    def ControlType(self, value):
        self.com_object.ControlType = value

    @property
    def controltype(self):
        """Alias for ControlType"""
        return self.ControlType

    @controltype.setter
    def controltype(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def control_type(self):
        """Alias for ControlType"""
        return self.ControlType

    @control_type.setter
    def control_type(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def IsVisible(self):
        return self.com_object.IsVisible

    @IsVisible.setter
    def IsVisible(self, value):
        self.com_object.IsVisible = value

    @property
    def isvisible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @isvisible.setter
    def isvisible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def is_visible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @is_visible.setter
    def is_visible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def Section(self):
        return self.com_object.Section

    @Section.setter
    def Section(self, value):
        self.com_object.Section = value

    @property
    def section(self):
        """Alias for Section"""
        return self.Section

    @section.setter
    def section(self, value):
        """Alias for Section.setter"""
        self.Section = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()


class Pages:

    def __init__(self, pages=None):
        self.com_object= pages

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    def Add(self, Before=None):
        arguments = com_arguments([unwrap(a) for a in [Before]])
        return Page(self.com_object.Add(*arguments))

    def add(self, Before=None):
        """Alias for Add"""
        arguments = [Before]
        return self.Add(*arguments)

    def Remove(self, Item=None):
        arguments = com_arguments([unwrap(a) for a in [Item]])
        self.com_object.Remove(*arguments)

    def remove(self, Item=None):
        """Alias for Remove"""
        arguments = [Item]
        return self.Remove(*arguments)


class Printer:

    def __init__(self, printer=None):
        self.com_object= printer

    @property
    def BottomMargin(self):
        return self.com_object.BottomMargin

    @BottomMargin.setter
    def BottomMargin(self, value):
        self.com_object.BottomMargin = value

    @property
    def bottommargin(self):
        """Alias for BottomMargin"""
        return self.BottomMargin

    @bottommargin.setter
    def bottommargin(self, value):
        """Alias for BottomMargin.setter"""
        self.BottomMargin = value

    @property
    def bottom_margin(self):
        """Alias for BottomMargin"""
        return self.BottomMargin

    @bottom_margin.setter
    def bottom_margin(self, value):
        """Alias for BottomMargin.setter"""
        self.BottomMargin = value

    @property
    def ColorMode(self):
        return AcPrintColor(self.com_object.ColorMode)

    @ColorMode.setter
    def ColorMode(self, value):
        self.com_object.ColorMode = value

    @property
    def colormode(self):
        """Alias for ColorMode"""
        return self.ColorMode

    @colormode.setter
    def colormode(self, value):
        """Alias for ColorMode.setter"""
        self.ColorMode = value

    @property
    def color_mode(self):
        """Alias for ColorMode"""
        return self.ColorMode

    @color_mode.setter
    def color_mode(self, value):
        """Alias for ColorMode.setter"""
        self.ColorMode = value

    @property
    def ColumnSpacing(self):
        return self.com_object.ColumnSpacing

    @ColumnSpacing.setter
    def ColumnSpacing(self, value):
        self.com_object.ColumnSpacing = value

    @property
    def columnspacing(self):
        """Alias for ColumnSpacing"""
        return self.ColumnSpacing

    @columnspacing.setter
    def columnspacing(self, value):
        """Alias for ColumnSpacing.setter"""
        self.ColumnSpacing = value

    @property
    def column_spacing(self):
        """Alias for ColumnSpacing"""
        return self.ColumnSpacing

    @column_spacing.setter
    def column_spacing(self, value):
        """Alias for ColumnSpacing.setter"""
        self.ColumnSpacing = value

    @property
    def Copies(self):
        return self.com_object.Copies

    @Copies.setter
    def Copies(self, value):
        self.com_object.Copies = value

    @property
    def copies(self):
        """Alias for Copies"""
        return self.Copies

    @copies.setter
    def copies(self, value):
        """Alias for Copies.setter"""
        self.Copies = value

    @property
    def DataOnly(self):
        return self.com_object.DataOnly

    @DataOnly.setter
    def DataOnly(self, value):
        self.com_object.DataOnly = value

    @property
    def dataonly(self):
        """Alias for DataOnly"""
        return self.DataOnly

    @dataonly.setter
    def dataonly(self, value):
        """Alias for DataOnly.setter"""
        self.DataOnly = value

    @property
    def data_only(self):
        """Alias for DataOnly"""
        return self.DataOnly

    @data_only.setter
    def data_only(self, value):
        """Alias for DataOnly.setter"""
        self.DataOnly = value

    @property
    def DefaultSize(self):
        return self.com_object.DefaultSize

    @DefaultSize.setter
    def DefaultSize(self, value):
        self.com_object.DefaultSize = value

    @property
    def defaultsize(self):
        """Alias for DefaultSize"""
        return self.DefaultSize

    @defaultsize.setter
    def defaultsize(self, value):
        """Alias for DefaultSize.setter"""
        self.DefaultSize = value

    @property
    def default_size(self):
        """Alias for DefaultSize"""
        return self.DefaultSize

    @default_size.setter
    def default_size(self, value):
        """Alias for DefaultSize.setter"""
        self.DefaultSize = value

    @property
    def DeviceName(self):
        return self.com_object.DeviceName

    @property
    def devicename(self):
        """Alias for DeviceName"""
        return self.DeviceName

    @property
    def device_name(self):
        """Alias for DeviceName"""
        return self.DeviceName

    @property
    def DriverName(self):
        return self.com_object.DriverName

    @property
    def drivername(self):
        """Alias for DriverName"""
        return self.DriverName

    @property
    def driver_name(self):
        """Alias for DriverName"""
        return self.DriverName

    @property
    def Duplex(self):
        return AcPrintDuplex(self.com_object.Duplex)

    @Duplex.setter
    def Duplex(self, value):
        self.com_object.Duplex = value

    @property
    def duplex(self):
        """Alias for Duplex"""
        return self.Duplex

    @duplex.setter
    def duplex(self, value):
        """Alias for Duplex.setter"""
        self.Duplex = value

    @property
    def ItemLayout(self):
        return AcPrintItemLayout(self.com_object.ItemLayout)

    @ItemLayout.setter
    def ItemLayout(self, value):
        self.com_object.ItemLayout = value

    @property
    def itemlayout(self):
        """Alias for ItemLayout"""
        return self.ItemLayout

    @itemlayout.setter
    def itemlayout(self, value):
        """Alias for ItemLayout.setter"""
        self.ItemLayout = value

    @property
    def item_layout(self):
        """Alias for ItemLayout"""
        return self.ItemLayout

    @item_layout.setter
    def item_layout(self, value):
        """Alias for ItemLayout.setter"""
        self.ItemLayout = value

    @property
    def ItemsAcross(self):
        return self.com_object.ItemsAcross

    @ItemsAcross.setter
    def ItemsAcross(self, value):
        self.com_object.ItemsAcross = value

    @property
    def itemsacross(self):
        """Alias for ItemsAcross"""
        return self.ItemsAcross

    @itemsacross.setter
    def itemsacross(self, value):
        """Alias for ItemsAcross.setter"""
        self.ItemsAcross = value

    @property
    def items_across(self):
        """Alias for ItemsAcross"""
        return self.ItemsAcross

    @items_across.setter
    def items_across(self, value):
        """Alias for ItemsAcross.setter"""
        self.ItemsAcross = value

    @property
    def ItemSizeHeight(self):
        return self.com_object.ItemSizeHeight

    @ItemSizeHeight.setter
    def ItemSizeHeight(self, value):
        self.com_object.ItemSizeHeight = value

    @property
    def itemsizeheight(self):
        """Alias for ItemSizeHeight"""
        return self.ItemSizeHeight

    @itemsizeheight.setter
    def itemsizeheight(self, value):
        """Alias for ItemSizeHeight.setter"""
        self.ItemSizeHeight = value

    @property
    def item_size_height(self):
        """Alias for ItemSizeHeight"""
        return self.ItemSizeHeight

    @item_size_height.setter
    def item_size_height(self, value):
        """Alias for ItemSizeHeight.setter"""
        self.ItemSizeHeight = value

    @property
    def ItemSizeWidth(self):
        return self.com_object.ItemSizeWidth

    @ItemSizeWidth.setter
    def ItemSizeWidth(self, value):
        self.com_object.ItemSizeWidth = value

    @property
    def itemsizewidth(self):
        """Alias for ItemSizeWidth"""
        return self.ItemSizeWidth

    @itemsizewidth.setter
    def itemsizewidth(self, value):
        """Alias for ItemSizeWidth.setter"""
        self.ItemSizeWidth = value

    @property
    def item_size_width(self):
        """Alias for ItemSizeWidth"""
        return self.ItemSizeWidth

    @item_size_width.setter
    def item_size_width(self, value):
        """Alias for ItemSizeWidth.setter"""
        self.ItemSizeWidth = value

    @property
    def LeftMargin(self):
        return self.com_object.LeftMargin

    @LeftMargin.setter
    def LeftMargin(self, value):
        self.com_object.LeftMargin = value

    @property
    def leftmargin(self):
        """Alias for LeftMargin"""
        return self.LeftMargin

    @leftmargin.setter
    def leftmargin(self, value):
        """Alias for LeftMargin.setter"""
        self.LeftMargin = value

    @property
    def left_margin(self):
        """Alias for LeftMargin"""
        return self.LeftMargin

    @left_margin.setter
    def left_margin(self, value):
        """Alias for LeftMargin.setter"""
        self.LeftMargin = value

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def PaperBin(self):
        return AcPrintPaperBin(self.com_object.PaperBin)

    @PaperBin.setter
    def PaperBin(self, value):
        self.com_object.PaperBin = value

    @property
    def paperbin(self):
        """Alias for PaperBin"""
        return self.PaperBin

    @paperbin.setter
    def paperbin(self, value):
        """Alias for PaperBin.setter"""
        self.PaperBin = value

    @property
    def paper_bin(self):
        """Alias for PaperBin"""
        return self.PaperBin

    @paper_bin.setter
    def paper_bin(self, value):
        """Alias for PaperBin.setter"""
        self.PaperBin = value

    @property
    def PaperSize(self):
        return AcPrintPaperSize(self.com_object.PaperSize)

    @PaperSize.setter
    def PaperSize(self, value):
        self.com_object.PaperSize = value

    @property
    def papersize(self):
        """Alias for PaperSize"""
        return self.PaperSize

    @papersize.setter
    def papersize(self, value):
        """Alias for PaperSize.setter"""
        self.PaperSize = value

    @property
    def paper_size(self):
        """Alias for PaperSize"""
        return self.PaperSize

    @paper_size.setter
    def paper_size(self, value):
        """Alias for PaperSize.setter"""
        self.PaperSize = value

    @property
    def Port(self):
        return self.com_object.Port

    @property
    def port(self):
        """Alias for Port"""
        return self.Port

    @property
    def PrintQuality(self):
        return AcPrintObjQuality(self.com_object.PrintQuality)

    @PrintQuality.setter
    def PrintQuality(self, value):
        self.com_object.PrintQuality = value

    @property
    def printquality(self):
        """Alias for PrintQuality"""
        return self.PrintQuality

    @printquality.setter
    def printquality(self, value):
        """Alias for PrintQuality.setter"""
        self.PrintQuality = value

    @property
    def print_quality(self):
        """Alias for PrintQuality"""
        return self.PrintQuality

    @print_quality.setter
    def print_quality(self, value):
        """Alias for PrintQuality.setter"""
        self.PrintQuality = value

    @property
    def RightMargin(self):
        return self.com_object.RightMargin

    @RightMargin.setter
    def RightMargin(self, value):
        self.com_object.RightMargin = value

    @property
    def rightmargin(self):
        """Alias for RightMargin"""
        return self.RightMargin

    @rightmargin.setter
    def rightmargin(self, value):
        """Alias for RightMargin.setter"""
        self.RightMargin = value

    @property
    def right_margin(self):
        """Alias for RightMargin"""
        return self.RightMargin

    @right_margin.setter
    def right_margin(self, value):
        """Alias for RightMargin.setter"""
        self.RightMargin = value

    @property
    def RowSpacing(self):
        return self.com_object.RowSpacing

    @RowSpacing.setter
    def RowSpacing(self, value):
        self.com_object.RowSpacing = value

    @property
    def rowspacing(self):
        """Alias for RowSpacing"""
        return self.RowSpacing

    @rowspacing.setter
    def rowspacing(self, value):
        """Alias for RowSpacing.setter"""
        self.RowSpacing = value

    @property
    def row_spacing(self):
        """Alias for RowSpacing"""
        return self.RowSpacing

    @row_spacing.setter
    def row_spacing(self, value):
        """Alias for RowSpacing.setter"""
        self.RowSpacing = value

    @property
    def TopMargin(self):
        return self.com_object.TopMargin

    @TopMargin.setter
    def TopMargin(self, value):
        self.com_object.TopMargin = value

    @property
    def topmargin(self):
        """Alias for TopMargin"""
        return self.TopMargin

    @topmargin.setter
    def topmargin(self, value):
        """Alias for TopMargin.setter"""
        self.TopMargin = value

    @property
    def top_margin(self):
        """Alias for TopMargin"""
        return self.TopMargin

    @top_margin.setter
    def top_margin(self, value):
        """Alias for TopMargin.setter"""
        self.TopMargin = value


class Printers:

    def __init__(self, printers=None):
        self.com_object= printers

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class Properties:

    def __init__(self, properties=None):
        self.com_object= properties

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class Rectangle:

    def __init__(self, rectangle=None):
        self.com_object= rectangle

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BackShade(self):
        return self.com_object.BackShade

    @BackShade.setter
    def BackShade(self, value):
        self.com_object.BackShade = value

    @property
    def backshade(self):
        """Alias for BackShade"""
        return self.BackShade

    @backshade.setter
    def backshade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def back_shade(self):
        """Alias for BackShade"""
        return self.BackShade

    @back_shade.setter
    def back_shade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def BackStyle(self):
        return self.com_object.BackStyle

    @BackStyle.setter
    def BackStyle(self, value):
        self.com_object.BackStyle = value

    @property
    def backstyle(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @backstyle.setter
    def backstyle(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def back_style(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @back_style.setter
    def back_style(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def BackThemeColorIndex(self):
        return self.com_object.BackThemeColorIndex

    @BackThemeColorIndex.setter
    def BackThemeColorIndex(self, value):
        self.com_object.BackThemeColorIndex = value

    @property
    def backthemecolorindex(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @backthemecolorindex.setter
    def backthemecolorindex(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def back_theme_color_index(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @back_theme_color_index.setter
    def back_theme_color_index(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def BackTint(self):
        return self.com_object.BackTint

    @BackTint.setter
    def BackTint(self, value):
        self.com_object.BackTint = value

    @property
    def backtint(self):
        """Alias for BackTint"""
        return self.BackTint

    @backtint.setter
    def backtint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def back_tint(self):
        """Alias for BackTint"""
        return self.BackTint

    @back_tint.setter
    def back_tint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def BorderColor(self):
        return self.com_object.BorderColor

    @BorderColor.setter
    def BorderColor(self, value):
        self.com_object.BorderColor = value

    @property
    def bordercolor(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @bordercolor.setter
    def bordercolor(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def border_color(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @border_color.setter
    def border_color(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def BorderShade(self):
        return self.com_object.BorderShade

    @BorderShade.setter
    def BorderShade(self, value):
        self.com_object.BorderShade = value

    @property
    def bordershade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @bordershade.setter
    def bordershade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def border_shade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @border_shade.setter
    def border_shade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def BorderStyle(self):
        return self.com_object.BorderStyle

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def BorderThemeColorIndex(self):
        return self.com_object.BorderThemeColorIndex

    @BorderThemeColorIndex.setter
    def BorderThemeColorIndex(self, value):
        self.com_object.BorderThemeColorIndex = value

    @property
    def borderthemecolorindex(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @borderthemecolorindex.setter
    def borderthemecolorindex(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def border_theme_color_index(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @border_theme_color_index.setter
    def border_theme_color_index(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def BorderTint(self):
        return self.com_object.BorderTint

    @BorderTint.setter
    def BorderTint(self, value):
        self.com_object.BorderTint = value

    @property
    def bordertint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @bordertint.setter
    def bordertint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def border_tint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @border_tint.setter
    def border_tint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def BorderWidth(self):
        return self.com_object.BorderWidth

    @BorderWidth.setter
    def BorderWidth(self, value):
        self.com_object.BorderWidth = value

    @property
    def borderwidth(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @borderwidth.setter
    def borderwidth(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def border_width(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @border_width.setter
    def border_width(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def ControlType(self):
        return self.com_object.ControlType

    @ControlType.setter
    def ControlType(self, value):
        self.com_object.ControlType = value

    @property
    def controltype(self):
        """Alias for ControlType"""
        return self.ControlType

    @controltype.setter
    def controltype(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def control_type(self):
        """Alias for ControlType"""
        return self.ControlType

    @control_type.setter
    def control_type(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def DisplayWhen(self):
        return self.com_object.DisplayWhen

    @DisplayWhen.setter
    def DisplayWhen(self, value):
        self.com_object.DisplayWhen = value

    @property
    def displaywhen(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @displaywhen.setter
    def displaywhen(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def display_when(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @display_when.setter
    def display_when(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def IsVisible(self):
        return self.com_object.IsVisible

    @IsVisible.setter
    def IsVisible(self, value):
        self.com_object.IsVisible = value

    @property
    def isvisible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @isvisible.setter
    def isvisible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def is_visible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @is_visible.setter
    def is_visible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def OldBorderStyle(self):
        return self.com_object.OldBorderStyle

    @OldBorderStyle.setter
    def OldBorderStyle(self, value):
        self.com_object.OldBorderStyle = value

    @property
    def oldborderstyle(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @oldborderstyle.setter
    def oldborderstyle(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def old_border_style(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @old_border_style.setter
    def old_border_style(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def OnClick(self):
        return self.com_object.OnClick

    @OnClick.setter
    def OnClick(self, value):
        self.com_object.OnClick = value

    @property
    def onclick(self):
        """Alias for OnClick"""
        return self.OnClick

    @onclick.setter
    def onclick(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def on_click(self):
        """Alias for OnClick"""
        return self.OnClick

    @on_click.setter
    def on_click(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def OnDblClick(self):
        return self.com_object.OnDblClick

    @OnDblClick.setter
    def OnDblClick(self, value):
        self.com_object.OnDblClick = value

    @property
    def ondblclick(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @ondblclick.setter
    def ondblclick(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def on_dbl_click(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @on_dbl_click.setter
    def on_dbl_click(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def OnMouseDown(self):
        return self.com_object.OnMouseDown

    @OnMouseDown.setter
    def OnMouseDown(self, value):
        self.com_object.OnMouseDown = value

    @property
    def onmousedown(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @onmousedown.setter
    def onmousedown(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def on_mouse_down(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @on_mouse_down.setter
    def on_mouse_down(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def OnMouseMove(self):
        return self.com_object.OnMouseMove

    @OnMouseMove.setter
    def OnMouseMove(self, value):
        self.com_object.OnMouseMove = value

    @property
    def onmousemove(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @onmousemove.setter
    def onmousemove(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def on_mouse_move(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @on_mouse_move.setter
    def on_mouse_move(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def OnMouseUp(self):
        return self.com_object.OnMouseUp

    @OnMouseUp.setter
    def OnMouseUp(self, value):
        self.com_object.OnMouseUp = value

    @property
    def onmouseup(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @onmouseup.setter
    def onmouseup(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def on_mouse_up(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @on_mouse_up.setter
    def on_mouse_up(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def Section(self):
        return self.com_object.Section

    @Section.setter
    def Section(self, value):
        self.com_object.Section = value

    @property
    def section(self):
        """Alias for Section"""
        return self.Section

    @section.setter
    def section(self, value):
        """Alias for Section.setter"""
        self.Section = value

    @property
    def SpecialEffect(self):
        return self.com_object.SpecialEffect

    @SpecialEffect.setter
    def SpecialEffect(self, value):
        self.com_object.SpecialEffect = value

    @property
    def specialeffect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @specialeffect.setter
    def specialeffect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def special_effect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @special_effect.setter
    def special_effect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()


class Reference:

    def __init__(self, reference=None):
        self.com_object= reference

    @property
    def BuiltIn(self):
        return self.com_object.BuiltIn

    @property
    def builtin(self):
        """Alias for BuiltIn"""
        return self.BuiltIn

    @property
    def built_in(self):
        """Alias for BuiltIn"""
        return self.BuiltIn

    @property
    def Collection(self):
        return self.com_object.Collection

    @property
    def collection(self):
        """Alias for Collection"""
        return self.Collection

    @property
    def FullPath(self):
        return self.com_object.FullPath

    @property
    def fullpath(self):
        """Alias for FullPath"""
        return self.FullPath

    @property
    def full_path(self):
        """Alias for FullPath"""
        return self.FullPath

    @property
    def GUID(self):
        return self.com_object.GUID

    @property
    def guid(self):
        """Alias for GUID"""
        return self.GUID

    @property
    def g_u_i_d(self):
        """Alias for GUID"""
        return self.GUID

    @property
    def IsBroken(self):
        return self.com_object.IsBroken

    @property
    def isbroken(self):
        """Alias for IsBroken"""
        return self.IsBroken

    @property
    def is_broken(self):
        """Alias for IsBroken"""
        return self.IsBroken

    @property
    def Kind(self):
        return self.com_object.Kind

    @property
    def kind(self):
        """Alias for Kind"""
        return self.Kind

    @property
    def Major(self):
        return self.com_object.Major

    @property
    def major(self):
        """Alias for Major"""
        return self.Major

    @property
    def Minor(self):
        return self.com_object.Minor

    @property
    def minor(self):
        """Alias for Minor"""
        return self.Minor

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name


class References:

    def __init__(self, references=None):
        self.com_object= references

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def AddFromFile(self, FileName=None):
        arguments = com_arguments([unwrap(a) for a in [FileName]])
        return Reference(self.com_object.AddFromFile(*arguments))

    def addfromfile(self, FileName=None):
        """Alias for AddFromFile"""
        arguments = [FileName]
        return self.AddFromFile(*arguments)

    def add_from_file(self, FileName=None):
        """Alias for AddFromFile"""
        arguments = [FileName]
        return self.AddFromFile(*arguments)

    def AddFromGUID(self, Guid=None, Major=None, Minor=None):
        arguments = com_arguments([unwrap(a) for a in [Guid, Major, Minor]])
        return Reference(self.com_object.AddFromGUID(*arguments))

    def addfromguid(self, Guid=None, Major=None, Minor=None):
        """Alias for AddFromGUID"""
        arguments = [Guid, Major, Minor]
        return self.AddFromGUID(*arguments)

    def add_from_g_u_i_d(self, Guid=None, Major=None, Minor=None):
        """Alias for AddFromGUID"""
        arguments = [Guid, Major, Minor]
        return self.AddFromGUID(*arguments)

    def Item(self, var=None):
        arguments = com_arguments([unwrap(a) for a in [var]])
        return Reference(self.com_object.Item(*arguments))

    def item(self, var=None):
        """Alias for Item"""
        arguments = [var]
        return self.Item(*arguments)

    def Remove(self, Reference=None):
        arguments = com_arguments([unwrap(a) for a in [Reference]])
        self.com_object.Remove(*arguments)

    def remove(self, Reference=None):
        """Alias for Remove"""
        arguments = [Reference]
        return self.Remove(*arguments)


class Report:

    def __init__(self, report=None):
        self.com_object= report

    @property
    def ActiveControl(self):
        return self.com_object.ActiveControl

    @property
    def activecontrol(self):
        """Alias for ActiveControl"""
        return self.ActiveControl

    @property
    def active_control(self):
        """Alias for ActiveControl"""
        return self.ActiveControl

    @property
    def AllowLayoutView(self):
        return self.com_object.AllowLayoutView

    @AllowLayoutView.setter
    def AllowLayoutView(self, value):
        self.com_object.AllowLayoutView = value

    @property
    def allowlayoutview(self):
        """Alias for AllowLayoutView"""
        return self.AllowLayoutView

    @allowlayoutview.setter
    def allowlayoutview(self, value):
        """Alias for AllowLayoutView.setter"""
        self.AllowLayoutView = value

    @property
    def allow_layout_view(self):
        """Alias for AllowLayoutView"""
        return self.AllowLayoutView

    @allow_layout_view.setter
    def allow_layout_view(self, value):
        """Alias for AllowLayoutView.setter"""
        self.AllowLayoutView = value

    @property
    def AllowReportView(self):
        return self.com_object.AllowReportView

    @AllowReportView.setter
    def AllowReportView(self, value):
        self.com_object.AllowReportView = value

    @property
    def allowreportview(self):
        """Alias for AllowReportView"""
        return self.AllowReportView

    @allowreportview.setter
    def allowreportview(self, value):
        """Alias for AllowReportView.setter"""
        self.AllowReportView = value

    @property
    def allow_report_view(self):
        """Alias for AllowReportView"""
        return self.AllowReportView

    @allow_report_view.setter
    def allow_report_view(self, value):
        """Alias for AllowReportView.setter"""
        self.AllowReportView = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoCenter(self):
        return self.com_object.AutoCenter

    @AutoCenter.setter
    def AutoCenter(self, value):
        self.com_object.AutoCenter = value

    @property
    def autocenter(self):
        """Alias for AutoCenter"""
        return self.AutoCenter

    @autocenter.setter
    def autocenter(self, value):
        """Alias for AutoCenter.setter"""
        self.AutoCenter = value

    @property
    def auto_center(self):
        """Alias for AutoCenter"""
        return self.AutoCenter

    @auto_center.setter
    def auto_center(self, value):
        """Alias for AutoCenter.setter"""
        self.AutoCenter = value

    @property
    def AutoResize(self):
        return self.com_object.AutoResize

    @AutoResize.setter
    def AutoResize(self, value):
        self.com_object.AutoResize = value

    @property
    def autoresize(self):
        """Alias for AutoResize"""
        return self.AutoResize

    @autoresize.setter
    def autoresize(self, value):
        """Alias for AutoResize.setter"""
        self.AutoResize = value

    @property
    def auto_resize(self):
        """Alias for AutoResize"""
        return self.AutoResize

    @auto_resize.setter
    def auto_resize(self, value):
        """Alias for AutoResize.setter"""
        self.AutoResize = value

    @property
    def BorderStyle(self):
        return self.com_object.BorderStyle

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    @property
    def CloseButton(self):
        return self.com_object.CloseButton

    @CloseButton.setter
    def CloseButton(self, value):
        self.com_object.CloseButton = value

    @property
    def closebutton(self):
        """Alias for CloseButton"""
        return self.CloseButton

    @closebutton.setter
    def closebutton(self, value):
        """Alias for CloseButton.setter"""
        self.CloseButton = value

    @property
    def close_button(self):
        """Alias for CloseButton"""
        return self.CloseButton

    @close_button.setter
    def close_button(self, value):
        """Alias for CloseButton.setter"""
        self.CloseButton = value

    @property
    def ControlBox(self):
        return self.com_object.ControlBox

    @ControlBox.setter
    def ControlBox(self, value):
        self.com_object.ControlBox = value

    @property
    def controlbox(self):
        """Alias for ControlBox"""
        return self.ControlBox

    @controlbox.setter
    def controlbox(self, value):
        """Alias for ControlBox.setter"""
        self.ControlBox = value

    @property
    def control_box(self):
        """Alias for ControlBox"""
        return self.ControlBox

    @control_box.setter
    def control_box(self, value):
        """Alias for ControlBox.setter"""
        self.ControlBox = value

    @property
    def Controls(self):
        return Controls(self.com_object.Controls)

    @property
    def controls(self):
        """Alias for Controls"""
        return self.Controls

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    @property
    def CurrentRecord(self):
        return self.com_object.CurrentRecord

    @CurrentRecord.setter
    def CurrentRecord(self, value):
        self.com_object.CurrentRecord = value

    @property
    def currentrecord(self):
        """Alias for CurrentRecord"""
        return self.CurrentRecord

    @currentrecord.setter
    def currentrecord(self, value):
        """Alias for CurrentRecord.setter"""
        self.CurrentRecord = value

    @property
    def current_record(self):
        """Alias for CurrentRecord"""
        return self.CurrentRecord

    @current_record.setter
    def current_record(self, value):
        """Alias for CurrentRecord.setter"""
        self.CurrentRecord = value

    @property
    def CurrentView(self):
        return self.com_object.CurrentView

    @CurrentView.setter
    def CurrentView(self, value):
        self.com_object.CurrentView = value

    @property
    def currentview(self):
        """Alias for CurrentView"""
        return self.CurrentView

    @currentview.setter
    def currentview(self, value):
        """Alias for CurrentView.setter"""
        self.CurrentView = value

    @property
    def current_view(self):
        """Alias for CurrentView"""
        return self.CurrentView

    @current_view.setter
    def current_view(self, value):
        """Alias for CurrentView.setter"""
        self.CurrentView = value

    @property
    def CurrentX(self):
        return self.com_object.CurrentX

    @CurrentX.setter
    def CurrentX(self, value):
        self.com_object.CurrentX = value

    @property
    def currentx(self):
        """Alias for CurrentX"""
        return self.CurrentX

    @currentx.setter
    def currentx(self, value):
        """Alias for CurrentX.setter"""
        self.CurrentX = value

    @property
    def current_x(self):
        """Alias for CurrentX"""
        return self.CurrentX

    @current_x.setter
    def current_x(self, value):
        """Alias for CurrentX.setter"""
        self.CurrentX = value

    @property
    def CurrentY(self):
        return self.com_object.CurrentY

    @CurrentY.setter
    def CurrentY(self, value):
        self.com_object.CurrentY = value

    @property
    def currenty(self):
        """Alias for CurrentY"""
        return self.CurrentY

    @currenty.setter
    def currenty(self, value):
        """Alias for CurrentY.setter"""
        self.CurrentY = value

    @property
    def current_y(self):
        """Alias for CurrentY"""
        return self.CurrentY

    @current_y.setter
    def current_y(self, value):
        """Alias for CurrentY.setter"""
        self.CurrentY = value

    @property
    def Cycle(self):
        return self.com_object.Cycle

    @Cycle.setter
    def Cycle(self, value):
        self.com_object.Cycle = value

    @property
    def cycle(self):
        """Alias for Cycle"""
        return self.Cycle

    @cycle.setter
    def cycle(self, value):
        """Alias for Cycle.setter"""
        self.Cycle = value

    @property
    def DateGrouping(self):
        return self.com_object.DateGrouping

    @DateGrouping.setter
    def DateGrouping(self, value):
        self.com_object.DateGrouping = value

    @property
    def dategrouping(self):
        """Alias for DateGrouping"""
        return self.DateGrouping

    @dategrouping.setter
    def dategrouping(self, value):
        """Alias for DateGrouping.setter"""
        self.DateGrouping = value

    @property
    def date_grouping(self):
        """Alias for DateGrouping"""
        return self.DateGrouping

    @date_grouping.setter
    def date_grouping(self, value):
        """Alias for DateGrouping.setter"""
        self.DateGrouping = value

    def DefaultControl(self, ControlType=None):
        arguments = com_arguments([unwrap(a) for a in [ControlType]])
        if hasattr(self.com_object, "GetDefaultControl"):
            return self.com_object.GetDefaultControl(*arguments)
        else:
            return self.com_object.DefaultControl(*arguments)

    def defaultcontrol(self, ControlType=None):
        """Alias for DefaultControl"""
        arguments = [ControlType]
        return self.DefaultControl(*arguments)

    def default_control(self, ControlType=None):
        """Alias for DefaultControl"""
        arguments = [ControlType]
        return self.DefaultControl(*arguments)

    @property
    def DefaultView(self):
        return self.com_object.DefaultView

    @DefaultView.setter
    def DefaultView(self, value):
        self.com_object.DefaultView = value

    @property
    def defaultview(self):
        """Alias for DefaultView"""
        return self.DefaultView

    @defaultview.setter
    def defaultview(self, value):
        """Alias for DefaultView.setter"""
        self.DefaultView = value

    @property
    def default_view(self):
        """Alias for DefaultView"""
        return self.DefaultView

    @default_view.setter
    def default_view(self, value):
        """Alias for DefaultView.setter"""
        self.DefaultView = value

    @property
    def Dirty(self):
        return self.com_object.Dirty

    @Dirty.setter
    def Dirty(self, value):
        self.com_object.Dirty = value

    @property
    def dirty(self):
        """Alias for Dirty"""
        return self.Dirty

    @dirty.setter
    def dirty(self, value):
        """Alias for Dirty.setter"""
        self.Dirty = value

    @property
    def DisplayOnSharePointSite(self):
        return self.com_object.DisplayOnSharePointSite

    @DisplayOnSharePointSite.setter
    def DisplayOnSharePointSite(self, value):
        self.com_object.DisplayOnSharePointSite = value

    @property
    def displayonsharepointsite(self):
        """Alias for DisplayOnSharePointSite"""
        return self.DisplayOnSharePointSite

    @displayonsharepointsite.setter
    def displayonsharepointsite(self, value):
        """Alias for DisplayOnSharePointSite.setter"""
        self.DisplayOnSharePointSite = value

    @property
    def display_on_share_point_site(self):
        """Alias for DisplayOnSharePointSite"""
        return self.DisplayOnSharePointSite

    @display_on_share_point_site.setter
    def display_on_share_point_site(self, value):
        """Alias for DisplayOnSharePointSite.setter"""
        self.DisplayOnSharePointSite = value

    @property
    def DrawMode(self):
        return self.com_object.DrawMode

    @DrawMode.setter
    def DrawMode(self, value):
        self.com_object.DrawMode = value

    @property
    def drawmode(self):
        """Alias for DrawMode"""
        return self.DrawMode

    @drawmode.setter
    def drawmode(self, value):
        """Alias for DrawMode.setter"""
        self.DrawMode = value

    @property
    def draw_mode(self):
        """Alias for DrawMode"""
        return self.DrawMode

    @draw_mode.setter
    def draw_mode(self, value):
        """Alias for DrawMode.setter"""
        self.DrawMode = value

    @property
    def DrawStyle(self):
        return self.com_object.DrawStyle

    @DrawStyle.setter
    def DrawStyle(self, value):
        self.com_object.DrawStyle = value

    @property
    def drawstyle(self):
        """Alias for DrawStyle"""
        return self.DrawStyle

    @drawstyle.setter
    def drawstyle(self, value):
        """Alias for DrawStyle.setter"""
        self.DrawStyle = value

    @property
    def draw_style(self):
        """Alias for DrawStyle"""
        return self.DrawStyle

    @draw_style.setter
    def draw_style(self, value):
        """Alias for DrawStyle.setter"""
        self.DrawStyle = value

    @property
    def DrawWidth(self):
        return self.com_object.DrawWidth

    @DrawWidth.setter
    def DrawWidth(self, value):
        self.com_object.DrawWidth = value

    @property
    def drawwidth(self):
        """Alias for DrawWidth"""
        return self.DrawWidth

    @drawwidth.setter
    def drawwidth(self, value):
        """Alias for DrawWidth.setter"""
        self.DrawWidth = value

    @property
    def draw_width(self):
        """Alias for DrawWidth"""
        return self.DrawWidth

    @draw_width.setter
    def draw_width(self, value):
        """Alias for DrawWidth.setter"""
        self.DrawWidth = value

    @property
    def FastLaserPrinting(self):
        return self.com_object.FastLaserPrinting

    @FastLaserPrinting.setter
    def FastLaserPrinting(self, value):
        self.com_object.FastLaserPrinting = value

    @property
    def fastlaserprinting(self):
        """Alias for FastLaserPrinting"""
        return self.FastLaserPrinting

    @fastlaserprinting.setter
    def fastlaserprinting(self, value):
        """Alias for FastLaserPrinting.setter"""
        self.FastLaserPrinting = value

    @property
    def fast_laser_printing(self):
        """Alias for FastLaserPrinting"""
        return self.FastLaserPrinting

    @fast_laser_printing.setter
    def fast_laser_printing(self, value):
        """Alias for FastLaserPrinting.setter"""
        self.FastLaserPrinting = value

    @property
    def FillColor(self):
        return self.com_object.FillColor

    @FillColor.setter
    def FillColor(self, value):
        self.com_object.FillColor = value

    @property
    def fillcolor(self):
        """Alias for FillColor"""
        return self.FillColor

    @fillcolor.setter
    def fillcolor(self, value):
        """Alias for FillColor.setter"""
        self.FillColor = value

    @property
    def fill_color(self):
        """Alias for FillColor"""
        return self.FillColor

    @fill_color.setter
    def fill_color(self, value):
        """Alias for FillColor.setter"""
        self.FillColor = value

    @property
    def FillStyle(self):
        return self.com_object.FillStyle

    @FillStyle.setter
    def FillStyle(self, value):
        self.com_object.FillStyle = value

    @property
    def fillstyle(self):
        """Alias for FillStyle"""
        return self.FillStyle

    @fillstyle.setter
    def fillstyle(self, value):
        """Alias for FillStyle.setter"""
        self.FillStyle = value

    @property
    def fill_style(self):
        """Alias for FillStyle"""
        return self.FillStyle

    @fill_style.setter
    def fill_style(self, value):
        """Alias for FillStyle.setter"""
        self.FillStyle = value

    @property
    def Filter(self):
        return self.com_object.Filter

    @Filter.setter
    def Filter(self, value):
        self.com_object.Filter = value

    @property
    def filter(self):
        """Alias for Filter"""
        return self.Filter

    @filter.setter
    def filter(self, value):
        """Alias for Filter.setter"""
        self.Filter = value

    @property
    def FilterOn(self):
        return self.com_object.FilterOn

    @FilterOn.setter
    def FilterOn(self, value):
        self.com_object.FilterOn = value

    @property
    def filteron(self):
        """Alias for FilterOn"""
        return self.FilterOn

    @filteron.setter
    def filteron(self, value):
        """Alias for FilterOn.setter"""
        self.FilterOn = value

    @property
    def filter_on(self):
        """Alias for FilterOn"""
        return self.FilterOn

    @filter_on.setter
    def filter_on(self, value):
        """Alias for FilterOn.setter"""
        self.FilterOn = value

    @property
    def FilterOnLoad(self):
        return self.com_object.FilterOnLoad

    @FilterOnLoad.setter
    def FilterOnLoad(self, value):
        self.com_object.FilterOnLoad = value

    @property
    def filteronload(self):
        """Alias for FilterOnLoad"""
        return self.FilterOnLoad

    @filteronload.setter
    def filteronload(self, value):
        """Alias for FilterOnLoad.setter"""
        self.FilterOnLoad = value

    @property
    def filter_on_load(self):
        """Alias for FilterOnLoad"""
        return self.FilterOnLoad

    @filter_on_load.setter
    def filter_on_load(self, value):
        """Alias for FilterOnLoad.setter"""
        self.FilterOnLoad = value

    @property
    def FitToPage(self):
        return self.com_object.FitToPage

    @FitToPage.setter
    def FitToPage(self, value):
        self.com_object.FitToPage = value

    @property
    def fittopage(self):
        """Alias for FitToPage"""
        return self.FitToPage

    @fittopage.setter
    def fittopage(self, value):
        """Alias for FitToPage.setter"""
        self.FitToPage = value

    @property
    def fit_to_page(self):
        """Alias for FitToPage"""
        return self.FitToPage

    @fit_to_page.setter
    def fit_to_page(self, value):
        """Alias for FitToPage.setter"""
        self.FitToPage = value

    @property
    def FontBold(self):
        return self.com_object.FontBold

    @property
    def fontbold(self):
        """Alias for FontBold"""
        return self.FontBold

    @property
    def font_bold(self):
        """Alias for FontBold"""
        return self.FontBold

    @property
    def FontItalic(self):
        return self.com_object.FontItalic

    @property
    def fontitalic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @property
    def font_italic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @property
    def FontName(self):
        return self.com_object.FontName

    @property
    def fontname(self):
        """Alias for FontName"""
        return self.FontName

    @property
    def font_name(self):
        """Alias for FontName"""
        return self.FontName

    @property
    def FontSize(self):
        return self.com_object.FontSize

    @property
    def fontsize(self):
        """Alias for FontSize"""
        return self.FontSize

    @property
    def font_size(self):
        """Alias for FontSize"""
        return self.FontSize

    @property
    def FontUnderline(self):
        return self.com_object.FontUnderline

    @property
    def fontunderline(self):
        """Alias for FontUnderline"""
        return self.FontUnderline

    @property
    def font_underline(self):
        """Alias for FontUnderline"""
        return self.FontUnderline

    @property
    def ForeColor(self):
        return self.com_object.ForeColor

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def FormatCount(self):
        return self.com_object.FormatCount

    @FormatCount.setter
    def FormatCount(self, value):
        self.com_object.FormatCount = value

    @property
    def formatcount(self):
        """Alias for FormatCount"""
        return self.FormatCount

    @formatcount.setter
    def formatcount(self, value):
        """Alias for FormatCount.setter"""
        self.FormatCount = value

    @property
    def format_count(self):
        """Alias for FormatCount"""
        return self.FormatCount

    @format_count.setter
    def format_count(self, value):
        """Alias for FormatCount.setter"""
        self.FormatCount = value

    @property
    def GridX(self):
        return self.com_object.GridX

    @GridX.setter
    def GridX(self, value):
        self.com_object.GridX = value

    @property
    def gridx(self):
        """Alias for GridX"""
        return self.GridX

    @gridx.setter
    def gridx(self, value):
        """Alias for GridX.setter"""
        self.GridX = value

    @property
    def grid_x(self):
        """Alias for GridX"""
        return self.GridX

    @grid_x.setter
    def grid_x(self, value):
        """Alias for GridX.setter"""
        self.GridX = value

    @property
    def GridY(self):
        return self.com_object.GridY

    @GridY.setter
    def GridY(self, value):
        self.com_object.GridY = value

    @property
    def gridy(self):
        """Alias for GridY"""
        return self.GridY

    @gridy.setter
    def gridy(self, value):
        """Alias for GridY.setter"""
        self.GridY = value

    @property
    def grid_y(self):
        """Alias for GridY"""
        return self.GridY

    @grid_y.setter
    def grid_y(self, value):
        """Alias for GridY.setter"""
        self.GridY = value

    def GroupLevel(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetGroupLevel"):
            return self.com_object.GetGroupLevel(*arguments)
        else:
            return self.com_object.GroupLevel(*arguments)

    def grouplevel(self, Index=None):
        """Alias for GroupLevel"""
        arguments = [Index]
        return self.GroupLevel(*arguments)

    def group_level(self, Index=None):
        """Alias for GroupLevel"""
        arguments = [Index]
        return self.GroupLevel(*arguments)

    @property
    def GrpKeepTogether(self):
        return self.com_object.GrpKeepTogether

    @GrpKeepTogether.setter
    def GrpKeepTogether(self, value):
        self.com_object.GrpKeepTogether = value

    @property
    def grpkeeptogether(self):
        """Alias for GrpKeepTogether"""
        return self.GrpKeepTogether

    @grpkeeptogether.setter
    def grpkeeptogether(self, value):
        """Alias for GrpKeepTogether.setter"""
        self.GrpKeepTogether = value

    @property
    def grp_keep_together(self):
        """Alias for GrpKeepTogether"""
        return self.GrpKeepTogether

    @grp_keep_together.setter
    def grp_keep_together(self, value):
        """Alias for GrpKeepTogether.setter"""
        self.GrpKeepTogether = value

    @property
    def HasData(self):
        return self.com_object.HasData

    @HasData.setter
    def HasData(self, value):
        self.com_object.HasData = value

    @property
    def hasdata(self):
        """Alias for HasData"""
        return self.HasData

    @hasdata.setter
    def hasdata(self, value):
        """Alias for HasData.setter"""
        self.HasData = value

    @property
    def has_data(self):
        """Alias for HasData"""
        return self.HasData

    @has_data.setter
    def has_data(self, value):
        """Alias for HasData.setter"""
        self.HasData = value

    @property
    def HasModule(self):
        return self.com_object.HasModule

    @HasModule.setter
    def HasModule(self, value):
        self.com_object.HasModule = value

    @property
    def hasmodule(self):
        """Alias for HasModule"""
        return self.HasModule

    @hasmodule.setter
    def hasmodule(self, value):
        """Alias for HasModule.setter"""
        self.HasModule = value

    @property
    def has_module(self):
        """Alias for HasModule"""
        return self.HasModule

    @has_module.setter
    def has_module(self, value):
        """Alias for HasModule.setter"""
        self.HasModule = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HelpContextId(self):
        return self.com_object.HelpContextId

    @HelpContextId.setter
    def HelpContextId(self, value):
        self.com_object.HelpContextId = value

    @property
    def helpcontextid(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @helpcontextid.setter
    def helpcontextid(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def help_context_id(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @help_context_id.setter
    def help_context_id(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def HelpFile(self):
        return self.com_object.HelpFile

    @HelpFile.setter
    def HelpFile(self, value):
        self.com_object.HelpFile = value

    @property
    def helpfile(self):
        """Alias for HelpFile"""
        return self.HelpFile

    @helpfile.setter
    def helpfile(self, value):
        """Alias for HelpFile.setter"""
        self.HelpFile = value

    @property
    def help_file(self):
        """Alias for HelpFile"""
        return self.HelpFile

    @help_file.setter
    def help_file(self, value):
        """Alias for HelpFile.setter"""
        self.HelpFile = value

    @property
    def hWnd(self):
        return self.com_object.hWnd

    @hWnd.setter
    def hWnd(self, value):
        self.com_object.hWnd = value

    @property
    def hwnd(self):
        """Alias for hWnd"""
        return self.hWnd

    @hwnd.setter
    def hwnd(self, value):
        """Alias for hWnd.setter"""
        self.hWnd = value

    @property
    def h_wnd(self):
        """Alias for hWnd"""
        return self.hWnd

    @h_wnd.setter
    def h_wnd(self, value):
        """Alias for hWnd.setter"""
        self.hWnd = value

    @property
    def KeyPreview(self):
        return self.com_object.KeyPreview

    @KeyPreview.setter
    def KeyPreview(self, value):
        self.com_object.KeyPreview = value

    @property
    def keypreview(self):
        """Alias for KeyPreview"""
        return self.KeyPreview

    @keypreview.setter
    def keypreview(self, value):
        """Alias for KeyPreview.setter"""
        self.KeyPreview = value

    @property
    def key_preview(self):
        """Alias for KeyPreview"""
        return self.KeyPreview

    @key_preview.setter
    def key_preview(self, value):
        """Alias for KeyPreview.setter"""
        self.KeyPreview = value

    @property
    def LayoutForPrint(self):
        return self.com_object.LayoutForPrint

    @LayoutForPrint.setter
    def LayoutForPrint(self, value):
        self.com_object.LayoutForPrint = value

    @property
    def layoutforprint(self):
        """Alias for LayoutForPrint"""
        return self.LayoutForPrint

    @layoutforprint.setter
    def layoutforprint(self, value):
        """Alias for LayoutForPrint.setter"""
        self.LayoutForPrint = value

    @property
    def layout_for_print(self):
        """Alias for LayoutForPrint"""
        return self.LayoutForPrint

    @layout_for_print.setter
    def layout_for_print(self, value):
        """Alias for LayoutForPrint.setter"""
        self.LayoutForPrint = value

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def MenuBar(self):
        return self.com_object.MenuBar

    @MenuBar.setter
    def MenuBar(self, value):
        self.com_object.MenuBar = value

    @property
    def menubar(self):
        """Alias for MenuBar"""
        return self.MenuBar

    @menubar.setter
    def menubar(self, value):
        """Alias for MenuBar.setter"""
        self.MenuBar = value

    @property
    def menu_bar(self):
        """Alias for MenuBar"""
        return self.MenuBar

    @menu_bar.setter
    def menu_bar(self, value):
        """Alias for MenuBar.setter"""
        self.MenuBar = value

    @property
    def MinMaxButtons(self):
        return self.com_object.MinMaxButtons

    @MinMaxButtons.setter
    def MinMaxButtons(self, value):
        self.com_object.MinMaxButtons = value

    @property
    def minmaxbuttons(self):
        """Alias for MinMaxButtons"""
        return self.MinMaxButtons

    @minmaxbuttons.setter
    def minmaxbuttons(self, value):
        """Alias for MinMaxButtons.setter"""
        self.MinMaxButtons = value

    @property
    def min_max_buttons(self):
        """Alias for MinMaxButtons"""
        return self.MinMaxButtons

    @min_max_buttons.setter
    def min_max_buttons(self, value):
        """Alias for MinMaxButtons.setter"""
        self.MinMaxButtons = value

    @property
    def Modal(self):
        return self.com_object.Modal

    @Modal.setter
    def Modal(self, value):
        self.com_object.Modal = value

    @property
    def modal(self):
        """Alias for Modal"""
        return self.Modal

    @modal.setter
    def modal(self, value):
        """Alias for Modal.setter"""
        self.Modal = value

    @property
    def Module(self):
        return self.com_object.Module

    @property
    def module(self):
        """Alias for Module"""
        return self.Module

    @property
    def MouseWheel(self):
        return self.com_object.MouseWheel

    @MouseWheel.setter
    def MouseWheel(self, value):
        self.com_object.MouseWheel = value

    @property
    def mousewheel(self):
        """Alias for MouseWheel"""
        return self.MouseWheel

    @mousewheel.setter
    def mousewheel(self, value):
        """Alias for MouseWheel.setter"""
        self.MouseWheel = value

    @property
    def mouse_wheel(self):
        """Alias for MouseWheel"""
        return self.MouseWheel

    @mouse_wheel.setter
    def mouse_wheel(self, value):
        """Alias for MouseWheel.setter"""
        self.MouseWheel = value

    @property
    def Moveable(self):
        return self.com_object.Moveable

    @Moveable.setter
    def Moveable(self, value):
        self.com_object.Moveable = value

    @property
    def moveable(self):
        """Alias for Moveable"""
        return self.Moveable

    @moveable.setter
    def moveable(self, value):
        """Alias for Moveable.setter"""
        self.Moveable = value

    @property
    def MoveLayout(self):
        return self.com_object.MoveLayout

    @MoveLayout.setter
    def MoveLayout(self, value):
        self.com_object.MoveLayout = value

    @property
    def movelayout(self):
        """Alias for MoveLayout"""
        return self.MoveLayout

    @movelayout.setter
    def movelayout(self, value):
        """Alias for MoveLayout.setter"""
        self.MoveLayout = value

    @property
    def move_layout(self):
        """Alias for MoveLayout"""
        return self.MoveLayout

    @move_layout.setter
    def move_layout(self, value):
        """Alias for MoveLayout.setter"""
        self.MoveLayout = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def NextRecord(self):
        return self.com_object.NextRecord

    @NextRecord.setter
    def NextRecord(self, value):
        self.com_object.NextRecord = value

    @property
    def nextrecord(self):
        """Alias for NextRecord"""
        return self.NextRecord

    @nextrecord.setter
    def nextrecord(self, value):
        """Alias for NextRecord.setter"""
        self.NextRecord = value

    @property
    def next_record(self):
        """Alias for NextRecord"""
        return self.NextRecord

    @next_record.setter
    def next_record(self, value):
        """Alias for NextRecord.setter"""
        self.NextRecord = value

    @property
    def OnActivate(self):
        return self.com_object.OnActivate

    @OnActivate.setter
    def OnActivate(self, value):
        self.com_object.OnActivate = value

    @property
    def onactivate(self):
        """Alias for OnActivate"""
        return self.OnActivate

    @onactivate.setter
    def onactivate(self, value):
        """Alias for OnActivate.setter"""
        self.OnActivate = value

    @property
    def on_activate(self):
        """Alias for OnActivate"""
        return self.OnActivate

    @on_activate.setter
    def on_activate(self, value):
        """Alias for OnActivate.setter"""
        self.OnActivate = value

    @property
    def OnApplyFilter(self):
        return self.com_object.OnApplyFilter

    @OnApplyFilter.setter
    def OnApplyFilter(self, value):
        self.com_object.OnApplyFilter = value

    @property
    def onapplyfilter(self):
        """Alias for OnApplyFilter"""
        return self.OnApplyFilter

    @onapplyfilter.setter
    def onapplyfilter(self, value):
        """Alias for OnApplyFilter.setter"""
        self.OnApplyFilter = value

    @property
    def on_apply_filter(self):
        """Alias for OnApplyFilter"""
        return self.OnApplyFilter

    @on_apply_filter.setter
    def on_apply_filter(self, value):
        """Alias for OnApplyFilter.setter"""
        self.OnApplyFilter = value

    @property
    def OnClick(self):
        return self.com_object.OnClick

    @OnClick.setter
    def OnClick(self, value):
        self.com_object.OnClick = value

    @property
    def onclick(self):
        """Alias for OnClick"""
        return self.OnClick

    @onclick.setter
    def onclick(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def on_click(self):
        """Alias for OnClick"""
        return self.OnClick

    @on_click.setter
    def on_click(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def OnClose(self):
        return self.com_object.OnClose

    @OnClose.setter
    def OnClose(self, value):
        self.com_object.OnClose = value

    @property
    def onclose(self):
        """Alias for OnClose"""
        return self.OnClose

    @onclose.setter
    def onclose(self, value):
        """Alias for OnClose.setter"""
        self.OnClose = value

    @property
    def on_close(self):
        """Alias for OnClose"""
        return self.OnClose

    @on_close.setter
    def on_close(self, value):
        """Alias for OnClose.setter"""
        self.OnClose = value

    @property
    def OnCurrent(self):
        return self.com_object.OnCurrent

    @OnCurrent.setter
    def OnCurrent(self, value):
        self.com_object.OnCurrent = value

    @property
    def oncurrent(self):
        """Alias for OnCurrent"""
        return self.OnCurrent

    @oncurrent.setter
    def oncurrent(self, value):
        """Alias for OnCurrent.setter"""
        self.OnCurrent = value

    @property
    def on_current(self):
        """Alias for OnCurrent"""
        return self.OnCurrent

    @on_current.setter
    def on_current(self, value):
        """Alias for OnCurrent.setter"""
        self.OnCurrent = value

    @property
    def OnDblClick(self):
        return self.com_object.OnDblClick

    @OnDblClick.setter
    def OnDblClick(self, value):
        self.com_object.OnDblClick = value

    @property
    def ondblclick(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @ondblclick.setter
    def ondblclick(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def on_dbl_click(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @on_dbl_click.setter
    def on_dbl_click(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def OnDeactivate(self):
        return self.com_object.OnDeactivate

    @OnDeactivate.setter
    def OnDeactivate(self, value):
        self.com_object.OnDeactivate = value

    @property
    def ondeactivate(self):
        """Alias for OnDeactivate"""
        return self.OnDeactivate

    @ondeactivate.setter
    def ondeactivate(self, value):
        """Alias for OnDeactivate.setter"""
        self.OnDeactivate = value

    @property
    def on_deactivate(self):
        """Alias for OnDeactivate"""
        return self.OnDeactivate

    @on_deactivate.setter
    def on_deactivate(self, value):
        """Alias for OnDeactivate.setter"""
        self.OnDeactivate = value

    @property
    def OnError(self):
        return self.com_object.OnError

    @OnError.setter
    def OnError(self, value):
        self.com_object.OnError = value

    @property
    def onerror(self):
        """Alias for OnError"""
        return self.OnError

    @onerror.setter
    def onerror(self, value):
        """Alias for OnError.setter"""
        self.OnError = value

    @property
    def on_error(self):
        """Alias for OnError"""
        return self.OnError

    @on_error.setter
    def on_error(self, value):
        """Alias for OnError.setter"""
        self.OnError = value

    @property
    def OnFilter(self):
        return self.com_object.OnFilter

    @OnFilter.setter
    def OnFilter(self, value):
        self.com_object.OnFilter = value

    @property
    def onfilter(self):
        """Alias for OnFilter"""
        return self.OnFilter

    @onfilter.setter
    def onfilter(self, value):
        """Alias for OnFilter.setter"""
        self.OnFilter = value

    @property
    def on_filter(self):
        """Alias for OnFilter"""
        return self.OnFilter

    @on_filter.setter
    def on_filter(self, value):
        """Alias for OnFilter.setter"""
        self.OnFilter = value

    @property
    def OnGotFocus(self):
        return self.com_object.OnGotFocus

    @OnGotFocus.setter
    def OnGotFocus(self, value):
        self.com_object.OnGotFocus = value

    @property
    def ongotfocus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @ongotfocus.setter
    def ongotfocus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def on_got_focus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @on_got_focus.setter
    def on_got_focus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def OnKeyDown(self):
        return self.com_object.OnKeyDown

    @OnKeyDown.setter
    def OnKeyDown(self, value):
        self.com_object.OnKeyDown = value

    @property
    def onkeydown(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @onkeydown.setter
    def onkeydown(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def on_key_down(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @on_key_down.setter
    def on_key_down(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def OnKeyPress(self):
        return self.com_object.OnKeyPress

    @OnKeyPress.setter
    def OnKeyPress(self, value):
        self.com_object.OnKeyPress = value

    @property
    def onkeypress(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @onkeypress.setter
    def onkeypress(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def on_key_press(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @on_key_press.setter
    def on_key_press(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def OnKeyUp(self):
        return self.com_object.OnKeyUp

    @OnKeyUp.setter
    def OnKeyUp(self, value):
        self.com_object.OnKeyUp = value

    @property
    def onkeyup(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @onkeyup.setter
    def onkeyup(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def on_key_up(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @on_key_up.setter
    def on_key_up(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def OnLoad(self):
        return self.com_object.OnLoad

    @OnLoad.setter
    def OnLoad(self, value):
        self.com_object.OnLoad = value

    @property
    def onload(self):
        """Alias for OnLoad"""
        return self.OnLoad

    @onload.setter
    def onload(self, value):
        """Alias for OnLoad.setter"""
        self.OnLoad = value

    @property
    def on_load(self):
        """Alias for OnLoad"""
        return self.OnLoad

    @on_load.setter
    def on_load(self, value):
        """Alias for OnLoad.setter"""
        self.OnLoad = value

    @property
    def OnLostFocus(self):
        return self.com_object.OnLostFocus

    @OnLostFocus.setter
    def OnLostFocus(self, value):
        self.com_object.OnLostFocus = value

    @property
    def onlostfocus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @onlostfocus.setter
    def onlostfocus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def on_lost_focus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @on_lost_focus.setter
    def on_lost_focus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def OnMouseDown(self):
        return self.com_object.OnMouseDown

    @OnMouseDown.setter
    def OnMouseDown(self, value):
        self.com_object.OnMouseDown = value

    @property
    def onmousedown(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @onmousedown.setter
    def onmousedown(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def on_mouse_down(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @on_mouse_down.setter
    def on_mouse_down(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def OnMouseMove(self):
        return self.com_object.OnMouseMove

    @OnMouseMove.setter
    def OnMouseMove(self, value):
        self.com_object.OnMouseMove = value

    @property
    def onmousemove(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @onmousemove.setter
    def onmousemove(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def on_mouse_move(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @on_mouse_move.setter
    def on_mouse_move(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def OnMouseUp(self):
        return self.com_object.OnMouseUp

    @OnMouseUp.setter
    def OnMouseUp(self, value):
        self.com_object.OnMouseUp = value

    @property
    def onmouseup(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @onmouseup.setter
    def onmouseup(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def on_mouse_up(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @on_mouse_up.setter
    def on_mouse_up(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def OnNoData(self):
        return self.com_object.OnNoData

    @OnNoData.setter
    def OnNoData(self, value):
        self.com_object.OnNoData = value

    @property
    def onnodata(self):
        """Alias for OnNoData"""
        return self.OnNoData

    @onnodata.setter
    def onnodata(self, value):
        """Alias for OnNoData.setter"""
        self.OnNoData = value

    @property
    def on_no_data(self):
        """Alias for OnNoData"""
        return self.OnNoData

    @on_no_data.setter
    def on_no_data(self, value):
        """Alias for OnNoData.setter"""
        self.OnNoData = value

    @property
    def OnOpen(self):
        return self.com_object.OnOpen

    @OnOpen.setter
    def OnOpen(self, value):
        self.com_object.OnOpen = value

    @property
    def onopen(self):
        """Alias for OnOpen"""
        return self.OnOpen

    @onopen.setter
    def onopen(self, value):
        """Alias for OnOpen.setter"""
        self.OnOpen = value

    @property
    def on_open(self):
        """Alias for OnOpen"""
        return self.OnOpen

    @on_open.setter
    def on_open(self, value):
        """Alias for OnOpen.setter"""
        self.OnOpen = value

    @property
    def OnPage(self):
        return self.com_object.OnPage

    @OnPage.setter
    def OnPage(self, value):
        self.com_object.OnPage = value

    @property
    def onpage(self):
        """Alias for OnPage"""
        return self.OnPage

    @onpage.setter
    def onpage(self, value):
        """Alias for OnPage.setter"""
        self.OnPage = value

    @property
    def on_page(self):
        """Alias for OnPage"""
        return self.OnPage

    @on_page.setter
    def on_page(self, value):
        """Alias for OnPage.setter"""
        self.OnPage = value

    @property
    def OnResize(self):
        return self.com_object.OnResize

    @OnResize.setter
    def OnResize(self, value):
        self.com_object.OnResize = value

    @property
    def onresize(self):
        """Alias for OnResize"""
        return self.OnResize

    @onresize.setter
    def onresize(self, value):
        """Alias for OnResize.setter"""
        self.OnResize = value

    @property
    def on_resize(self):
        """Alias for OnResize"""
        return self.OnResize

    @on_resize.setter
    def on_resize(self, value):
        """Alias for OnResize.setter"""
        self.OnResize = value

    @property
    def OnTimer(self):
        return self.com_object.OnTimer

    @OnTimer.setter
    def OnTimer(self, value):
        self.com_object.OnTimer = value

    @property
    def ontimer(self):
        """Alias for OnTimer"""
        return self.OnTimer

    @ontimer.setter
    def ontimer(self, value):
        """Alias for OnTimer.setter"""
        self.OnTimer = value

    @property
    def on_timer(self):
        """Alias for OnTimer"""
        return self.OnTimer

    @on_timer.setter
    def on_timer(self, value):
        """Alias for OnTimer.setter"""
        self.OnTimer = value

    @property
    def OnUnload(self):
        return self.com_object.OnUnload

    @OnUnload.setter
    def OnUnload(self, value):
        self.com_object.OnUnload = value

    @property
    def onunload(self):
        """Alias for OnUnload"""
        return self.OnUnload

    @onunload.setter
    def onunload(self, value):
        """Alias for OnUnload.setter"""
        self.OnUnload = value

    @property
    def on_unload(self):
        """Alias for OnUnload"""
        return self.OnUnload

    @on_unload.setter
    def on_unload(self, value):
        """Alias for OnUnload.setter"""
        self.OnUnload = value

    @property
    def OpenArgs(self):
        return self.com_object.OpenArgs

    @OpenArgs.setter
    def OpenArgs(self, value):
        self.com_object.OpenArgs = value

    @property
    def openargs(self):
        """Alias for OpenArgs"""
        return self.OpenArgs

    @openargs.setter
    def openargs(self, value):
        """Alias for OpenArgs.setter"""
        self.OpenArgs = value

    @property
    def open_args(self):
        """Alias for OpenArgs"""
        return self.OpenArgs

    @open_args.setter
    def open_args(self, value):
        """Alias for OpenArgs.setter"""
        self.OpenArgs = value

    @property
    def OrderBy(self):
        return self.com_object.OrderBy

    @OrderBy.setter
    def OrderBy(self, value):
        self.com_object.OrderBy = value

    @property
    def orderby(self):
        """Alias for OrderBy"""
        return self.OrderBy

    @orderby.setter
    def orderby(self, value):
        """Alias for OrderBy.setter"""
        self.OrderBy = value

    @property
    def order_by(self):
        """Alias for OrderBy"""
        return self.OrderBy

    @order_by.setter
    def order_by(self, value):
        """Alias for OrderBy.setter"""
        self.OrderBy = value

    @property
    def OrderByOn(self):
        return self.com_object.OrderByOn

    @OrderByOn.setter
    def OrderByOn(self, value):
        self.com_object.OrderByOn = value

    @property
    def orderbyon(self):
        """Alias for OrderByOn"""
        return self.OrderByOn

    @orderbyon.setter
    def orderbyon(self, value):
        """Alias for OrderByOn.setter"""
        self.OrderByOn = value

    @property
    def order_by_on(self):
        """Alias for OrderByOn"""
        return self.OrderByOn

    @order_by_on.setter
    def order_by_on(self, value):
        """Alias for OrderByOn.setter"""
        self.OrderByOn = value

    @property
    def OrderByOnLoad(self):
        return self.com_object.OrderByOnLoad

    @OrderByOnLoad.setter
    def OrderByOnLoad(self, value):
        self.com_object.OrderByOnLoad = value

    @property
    def orderbyonload(self):
        """Alias for OrderByOnLoad"""
        return self.OrderByOnLoad

    @orderbyonload.setter
    def orderbyonload(self, value):
        """Alias for OrderByOnLoad.setter"""
        self.OrderByOnLoad = value

    @property
    def order_by_on_load(self):
        """Alias for OrderByOnLoad"""
        return self.OrderByOnLoad

    @order_by_on_load.setter
    def order_by_on_load(self, value):
        """Alias for OrderByOnLoad.setter"""
        self.OrderByOnLoad = value

    @property
    def Orientation(self):
        return self.com_object.Orientation

    @Orientation.setter
    def Orientation(self, value):
        self.com_object.Orientation = value

    @property
    def orientation(self):
        """Alias for Orientation"""
        return self.Orientation

    @orientation.setter
    def orientation(self, value):
        """Alias for Orientation.setter"""
        self.Orientation = value

    @property
    def Page(self):
        return self.com_object.Page

    @Page.setter
    def Page(self, value):
        self.com_object.Page = value

    @property
    def page(self):
        """Alias for Page"""
        return self.Page

    @page.setter
    def page(self, value):
        """Alias for Page.setter"""
        self.Page = value

    @property
    def PageFooter(self):
        return self.com_object.PageFooter

    @PageFooter.setter
    def PageFooter(self, value):
        self.com_object.PageFooter = value

    @property
    def pagefooter(self):
        """Alias for PageFooter"""
        return self.PageFooter

    @pagefooter.setter
    def pagefooter(self, value):
        """Alias for PageFooter.setter"""
        self.PageFooter = value

    @property
    def page_footer(self):
        """Alias for PageFooter"""
        return self.PageFooter

    @page_footer.setter
    def page_footer(self, value):
        """Alias for PageFooter.setter"""
        self.PageFooter = value

    @property
    def PageHeader(self):
        return self.com_object.PageHeader

    @PageHeader.setter
    def PageHeader(self, value):
        self.com_object.PageHeader = value

    @property
    def pageheader(self):
        """Alias for PageHeader"""
        return self.PageHeader

    @pageheader.setter
    def pageheader(self, value):
        """Alias for PageHeader.setter"""
        self.PageHeader = value

    @property
    def page_header(self):
        """Alias for PageHeader"""
        return self.PageHeader

    @page_header.setter
    def page_header(self, value):
        """Alias for PageHeader.setter"""
        self.PageHeader = value

    @property
    def Pages(self):
        return self.com_object.Pages

    @Pages.setter
    def Pages(self, value):
        self.com_object.Pages = value

    @property
    def pages(self):
        """Alias for Pages"""
        return self.Pages

    @pages.setter
    def pages(self, value):
        """Alias for Pages.setter"""
        self.Pages = value

    @property
    def Painting(self):
        return self.com_object.Painting

    @Painting.setter
    def Painting(self, value):
        self.com_object.Painting = value

    @property
    def painting(self):
        """Alias for Painting"""
        return self.Painting

    @painting.setter
    def painting(self, value):
        """Alias for Painting.setter"""
        self.Painting = value

    @property
    def PaintPalette(self):
        return self.com_object.PaintPalette

    @PaintPalette.setter
    def PaintPalette(self, value):
        self.com_object.PaintPalette = value

    @property
    def paintpalette(self):
        """Alias for PaintPalette"""
        return self.PaintPalette

    @paintpalette.setter
    def paintpalette(self, value):
        """Alias for PaintPalette.setter"""
        self.PaintPalette = value

    @property
    def paint_palette(self):
        """Alias for PaintPalette"""
        return self.PaintPalette

    @paint_palette.setter
    def paint_palette(self, value):
        """Alias for PaintPalette.setter"""
        self.PaintPalette = value

    @property
    def PaletteSource(self):
        return self.com_object.PaletteSource

    @PaletteSource.setter
    def PaletteSource(self, value):
        self.com_object.PaletteSource = value

    @property
    def palettesource(self):
        """Alias for PaletteSource"""
        return self.PaletteSource

    @palettesource.setter
    def palettesource(self, value):
        """Alias for PaletteSource.setter"""
        self.PaletteSource = value

    @property
    def palette_source(self):
        """Alias for PaletteSource"""
        return self.PaletteSource

    @palette_source.setter
    def palette_source(self, value):
        """Alias for PaletteSource.setter"""
        self.PaletteSource = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Picture(self):
        return self.com_object.Picture

    @Picture.setter
    def Picture(self, value):
        self.com_object.Picture = value

    @property
    def picture(self):
        """Alias for Picture"""
        return self.Picture

    @picture.setter
    def picture(self, value):
        """Alias for Picture.setter"""
        self.Picture = value

    @property
    def PictureAlignment(self):
        return self.com_object.PictureAlignment

    @PictureAlignment.setter
    def PictureAlignment(self, value):
        self.com_object.PictureAlignment = value

    @property
    def picturealignment(self):
        """Alias for PictureAlignment"""
        return self.PictureAlignment

    @picturealignment.setter
    def picturealignment(self, value):
        """Alias for PictureAlignment.setter"""
        self.PictureAlignment = value

    @property
    def picture_alignment(self):
        """Alias for PictureAlignment"""
        return self.PictureAlignment

    @picture_alignment.setter
    def picture_alignment(self, value):
        """Alias for PictureAlignment.setter"""
        self.PictureAlignment = value

    @property
    def PictureData(self):
        return self.com_object.PictureData

    @PictureData.setter
    def PictureData(self, value):
        self.com_object.PictureData = value

    @property
    def picturedata(self):
        """Alias for PictureData"""
        return self.PictureData

    @picturedata.setter
    def picturedata(self, value):
        """Alias for PictureData.setter"""
        self.PictureData = value

    @property
    def picture_data(self):
        """Alias for PictureData"""
        return self.PictureData

    @picture_data.setter
    def picture_data(self, value):
        """Alias for PictureData.setter"""
        self.PictureData = value

    @property
    def PicturePages(self):
        return self.com_object.PicturePages

    @PicturePages.setter
    def PicturePages(self, value):
        self.com_object.PicturePages = value

    @property
    def picturepages(self):
        """Alias for PicturePages"""
        return self.PicturePages

    @picturepages.setter
    def picturepages(self, value):
        """Alias for PicturePages.setter"""
        self.PicturePages = value

    @property
    def picture_pages(self):
        """Alias for PicturePages"""
        return self.PicturePages

    @picture_pages.setter
    def picture_pages(self, value):
        """Alias for PicturePages.setter"""
        self.PicturePages = value

    @property
    def PicturePalette(self):
        return self.com_object.PicturePalette

    @PicturePalette.setter
    def PicturePalette(self, value):
        self.com_object.PicturePalette = value

    @property
    def picturepalette(self):
        """Alias for PicturePalette"""
        return self.PicturePalette

    @picturepalette.setter
    def picturepalette(self, value):
        """Alias for PicturePalette.setter"""
        self.PicturePalette = value

    @property
    def picture_palette(self):
        """Alias for PicturePalette"""
        return self.PicturePalette

    @picture_palette.setter
    def picture_palette(self, value):
        """Alias for PicturePalette.setter"""
        self.PicturePalette = value

    @property
    def PictureSizeMode(self):
        return self.com_object.PictureSizeMode

    @PictureSizeMode.setter
    def PictureSizeMode(self, value):
        self.com_object.PictureSizeMode = value

    @property
    def picturesizemode(self):
        """Alias for PictureSizeMode"""
        return self.PictureSizeMode

    @picturesizemode.setter
    def picturesizemode(self, value):
        """Alias for PictureSizeMode.setter"""
        self.PictureSizeMode = value

    @property
    def picture_size_mode(self):
        """Alias for PictureSizeMode"""
        return self.PictureSizeMode

    @picture_size_mode.setter
    def picture_size_mode(self, value):
        """Alias for PictureSizeMode.setter"""
        self.PictureSizeMode = value

    @property
    def PictureTiling(self):
        return self.com_object.PictureTiling

    @PictureTiling.setter
    def PictureTiling(self, value):
        self.com_object.PictureTiling = value

    @property
    def picturetiling(self):
        """Alias for PictureTiling"""
        return self.PictureTiling

    @picturetiling.setter
    def picturetiling(self, value):
        """Alias for PictureTiling.setter"""
        self.PictureTiling = value

    @property
    def picture_tiling(self):
        """Alias for PictureTiling"""
        return self.PictureTiling

    @picture_tiling.setter
    def picture_tiling(self, value):
        """Alias for PictureTiling.setter"""
        self.PictureTiling = value

    @property
    def PictureType(self):
        return self.com_object.PictureType

    @PictureType.setter
    def PictureType(self, value):
        self.com_object.PictureType = value

    @property
    def picturetype(self):
        """Alias for PictureType"""
        return self.PictureType

    @picturetype.setter
    def picturetype(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def picture_type(self):
        """Alias for PictureType"""
        return self.PictureType

    @picture_type.setter
    def picture_type(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def PopUp(self):
        return self.com_object.PopUp

    @PopUp.setter
    def PopUp(self, value):
        self.com_object.PopUp = value

    @property
    def popup(self):
        """Alias for PopUp"""
        return self.PopUp

    @popup.setter
    def popup(self, value):
        """Alias for PopUp.setter"""
        self.PopUp = value

    @property
    def pop_up(self):
        """Alias for PopUp"""
        return self.PopUp

    @pop_up.setter
    def pop_up(self, value):
        """Alias for PopUp.setter"""
        self.PopUp = value

    @property
    def PrintCount(self):
        return self.com_object.PrintCount

    @PrintCount.setter
    def PrintCount(self, value):
        self.com_object.PrintCount = value

    @property
    def printcount(self):
        """Alias for PrintCount"""
        return self.PrintCount

    @printcount.setter
    def printcount(self, value):
        """Alias for PrintCount.setter"""
        self.PrintCount = value

    @property
    def print_count(self):
        """Alias for PrintCount"""
        return self.PrintCount

    @print_count.setter
    def print_count(self, value):
        """Alias for PrintCount.setter"""
        self.PrintCount = value

    @property
    def Printer(self):
        return Printer(self.com_object.Printer)

    @Printer.setter
    def Printer(self, value):
        self.com_object.Printer = value

    @property
    def printer(self):
        """Alias for Printer"""
        return self.Printer

    @printer.setter
    def printer(self, value):
        """Alias for Printer.setter"""
        self.Printer = value

    @property
    def PrintSection(self):
        return self.com_object.PrintSection

    @PrintSection.setter
    def PrintSection(self, value):
        self.com_object.PrintSection = value

    @property
    def printsection(self):
        """Alias for PrintSection"""
        return self.PrintSection

    @printsection.setter
    def printsection(self, value):
        """Alias for PrintSection.setter"""
        self.PrintSection = value

    @property
    def print_section(self):
        """Alias for PrintSection"""
        return self.PrintSection

    @print_section.setter
    def print_section(self, value):
        """Alias for PrintSection.setter"""
        self.PrintSection = value

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def PrtDevMode(self):
        return self.com_object.PrtDevMode

    @PrtDevMode.setter
    def PrtDevMode(self, value):
        self.com_object.PrtDevMode = value

    @property
    def prtdevmode(self):
        """Alias for PrtDevMode"""
        return self.PrtDevMode

    @prtdevmode.setter
    def prtdevmode(self, value):
        """Alias for PrtDevMode.setter"""
        self.PrtDevMode = value

    @property
    def prt_dev_mode(self):
        """Alias for PrtDevMode"""
        return self.PrtDevMode

    @prt_dev_mode.setter
    def prt_dev_mode(self, value):
        """Alias for PrtDevMode.setter"""
        self.PrtDevMode = value

    @property
    def PrtDevNames(self):
        return self.com_object.PrtDevNames

    @PrtDevNames.setter
    def PrtDevNames(self, value):
        self.com_object.PrtDevNames = value

    @property
    def prtdevnames(self):
        """Alias for PrtDevNames"""
        return self.PrtDevNames

    @prtdevnames.setter
    def prtdevnames(self, value):
        """Alias for PrtDevNames.setter"""
        self.PrtDevNames = value

    @property
    def prt_dev_names(self):
        """Alias for PrtDevNames"""
        return self.PrtDevNames

    @prt_dev_names.setter
    def prt_dev_names(self, value):
        """Alias for PrtDevNames.setter"""
        self.PrtDevNames = value

    @property
    def PrtMip(self):
        return self.com_object.PrtMip

    @property
    def prtmip(self):
        """Alias for PrtMip"""
        return self.PrtMip

    @property
    def prt_mip(self):
        """Alias for PrtMip"""
        return self.PrtMip

    @property
    def RecordLocks(self):
        return self.com_object.RecordLocks

    @RecordLocks.setter
    def RecordLocks(self, value):
        self.com_object.RecordLocks = value

    @property
    def recordlocks(self):
        """Alias for RecordLocks"""
        return self.RecordLocks

    @recordlocks.setter
    def recordlocks(self, value):
        """Alias for RecordLocks.setter"""
        self.RecordLocks = value

    @property
    def record_locks(self):
        """Alias for RecordLocks"""
        return self.RecordLocks

    @record_locks.setter
    def record_locks(self, value):
        """Alias for RecordLocks.setter"""
        self.RecordLocks = value

    @property
    def Recordset(self):
        return self.com_object.Recordset

    @Recordset.setter
    def Recordset(self, value):
        self.com_object.Recordset = value

    @property
    def recordset(self):
        """Alias for Recordset"""
        return self.Recordset

    @recordset.setter
    def recordset(self, value):
        """Alias for Recordset.setter"""
        self.Recordset = value

    @property
    def RecordSource(self):
        return self.com_object.RecordSource

    @RecordSource.setter
    def RecordSource(self, value):
        self.com_object.RecordSource = value

    @property
    def recordsource(self):
        """Alias for RecordSource"""
        return self.RecordSource

    @recordsource.setter
    def recordsource(self, value):
        """Alias for RecordSource.setter"""
        self.RecordSource = value

    @property
    def record_source(self):
        """Alias for RecordSource"""
        return self.RecordSource

    @record_source.setter
    def record_source(self, value):
        """Alias for RecordSource.setter"""
        self.RecordSource = value

    @property
    def RecordSourceQualifier(self):
        return self.com_object.RecordSourceQualifier

    @RecordSourceQualifier.setter
    def RecordSourceQualifier(self, value):
        self.com_object.RecordSourceQualifier = value

    @property
    def recordsourcequalifier(self):
        """Alias for RecordSourceQualifier"""
        return self.RecordSourceQualifier

    @recordsourcequalifier.setter
    def recordsourcequalifier(self, value):
        """Alias for RecordSourceQualifier.setter"""
        self.RecordSourceQualifier = value

    @property
    def record_source_qualifier(self):
        """Alias for RecordSourceQualifier"""
        return self.RecordSourceQualifier

    @record_source_qualifier.setter
    def record_source_qualifier(self, value):
        """Alias for RecordSourceQualifier.setter"""
        self.RecordSourceQualifier = value

    @property
    def Report(self):
        return self.com_object.Report

    @property
    def report(self):
        """Alias for Report"""
        return self.Report

    @property
    def RibbonName(self):
        return self.com_object.RibbonName

    @RibbonName.setter
    def RibbonName(self, value):
        self.com_object.RibbonName = value

    @property
    def ribbonname(self):
        """Alias for RibbonName"""
        return self.RibbonName

    @ribbonname.setter
    def ribbonname(self, value):
        """Alias for RibbonName.setter"""
        self.RibbonName = value

    @property
    def ribbon_name(self):
        """Alias for RibbonName"""
        return self.RibbonName

    @ribbon_name.setter
    def ribbon_name(self, value):
        """Alias for RibbonName.setter"""
        self.RibbonName = value

    @property
    def ScaleHeight(self):
        return self.com_object.ScaleHeight

    @ScaleHeight.setter
    def ScaleHeight(self, value):
        self.com_object.ScaleHeight = value

    @property
    def scaleheight(self):
        """Alias for ScaleHeight"""
        return self.ScaleHeight

    @scaleheight.setter
    def scaleheight(self, value):
        """Alias for ScaleHeight.setter"""
        self.ScaleHeight = value

    @property
    def scale_height(self):
        """Alias for ScaleHeight"""
        return self.ScaleHeight

    @scale_height.setter
    def scale_height(self, value):
        """Alias for ScaleHeight.setter"""
        self.ScaleHeight = value

    @property
    def ScaleLeft(self):
        return self.com_object.ScaleLeft

    @ScaleLeft.setter
    def ScaleLeft(self, value):
        self.com_object.ScaleLeft = value

    @property
    def scaleleft(self):
        """Alias for ScaleLeft"""
        return self.ScaleLeft

    @scaleleft.setter
    def scaleleft(self, value):
        """Alias for ScaleLeft.setter"""
        self.ScaleLeft = value

    @property
    def scale_left(self):
        """Alias for ScaleLeft"""
        return self.ScaleLeft

    @scale_left.setter
    def scale_left(self, value):
        """Alias for ScaleLeft.setter"""
        self.ScaleLeft = value

    @property
    def ScaleMode(self):
        return self.com_object.ScaleMode

    @ScaleMode.setter
    def ScaleMode(self, value):
        self.com_object.ScaleMode = value

    @property
    def scalemode(self):
        """Alias for ScaleMode"""
        return self.ScaleMode

    @scalemode.setter
    def scalemode(self, value):
        """Alias for ScaleMode.setter"""
        self.ScaleMode = value

    @property
    def scale_mode(self):
        """Alias for ScaleMode"""
        return self.ScaleMode

    @scale_mode.setter
    def scale_mode(self, value):
        """Alias for ScaleMode.setter"""
        self.ScaleMode = value

    @property
    def ScaleTop(self):
        return self.com_object.ScaleTop

    @ScaleTop.setter
    def ScaleTop(self, value):
        self.com_object.ScaleTop = value

    @property
    def scaletop(self):
        """Alias for ScaleTop"""
        return self.ScaleTop

    @scaletop.setter
    def scaletop(self, value):
        """Alias for ScaleTop.setter"""
        self.ScaleTop = value

    @property
    def scale_top(self):
        """Alias for ScaleTop"""
        return self.ScaleTop

    @scale_top.setter
    def scale_top(self, value):
        """Alias for ScaleTop.setter"""
        self.ScaleTop = value

    @property
    def ScaleWidth(self):
        return self.com_object.ScaleWidth

    @ScaleWidth.setter
    def ScaleWidth(self, value):
        self.com_object.ScaleWidth = value

    @property
    def scalewidth(self):
        """Alias for ScaleWidth"""
        return self.ScaleWidth

    @scalewidth.setter
    def scalewidth(self, value):
        """Alias for ScaleWidth.setter"""
        self.ScaleWidth = value

    @property
    def scale_width(self):
        """Alias for ScaleWidth"""
        return self.ScaleWidth

    @scale_width.setter
    def scale_width(self, value):
        """Alias for ScaleWidth.setter"""
        self.ScaleWidth = value

    @property
    def ScrollBars(self):
        return self.com_object.ScrollBars

    @ScrollBars.setter
    def ScrollBars(self, value):
        self.com_object.ScrollBars = value

    @property
    def scrollbars(self):
        """Alias for ScrollBars"""
        return self.ScrollBars

    @scrollbars.setter
    def scrollbars(self, value):
        """Alias for ScrollBars.setter"""
        self.ScrollBars = value

    @property
    def scroll_bars(self):
        """Alias for ScrollBars"""
        return self.ScrollBars

    @scroll_bars.setter
    def scroll_bars(self, value):
        """Alias for ScrollBars.setter"""
        self.ScrollBars = value

    def Section(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetSection"):
            return self.com_object.GetSection(*arguments)
        else:
            return self.com_object.Section(*arguments)

    def section(self, Index=None):
        """Alias for Section"""
        arguments = [Index]
        return self.Section(*arguments)

    @property
    def ServerFilter(self):
        return self.com_object.ServerFilter

    @ServerFilter.setter
    def ServerFilter(self, value):
        self.com_object.ServerFilter = value

    @property
    def serverfilter(self):
        """Alias for ServerFilter"""
        return self.ServerFilter

    @serverfilter.setter
    def serverfilter(self, value):
        """Alias for ServerFilter.setter"""
        self.ServerFilter = value

    @property
    def server_filter(self):
        """Alias for ServerFilter"""
        return self.ServerFilter

    @server_filter.setter
    def server_filter(self, value):
        """Alias for ServerFilter.setter"""
        self.ServerFilter = value

    @property
    def Shape(self):
        return self.com_object.Shape

    @property
    def shape(self):
        """Alias for Shape"""
        return self.Shape

    @property
    def ShortcutMenuBar(self):
        return self.com_object.ShortcutMenuBar

    @ShortcutMenuBar.setter
    def ShortcutMenuBar(self, value):
        self.com_object.ShortcutMenuBar = value

    @property
    def shortcutmenubar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcutmenubar.setter
    def shortcutmenubar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def shortcut_menu_bar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcut_menu_bar.setter
    def shortcut_menu_bar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def ShowPageMargins(self):
        return self.com_object.ShowPageMargins

    @ShowPageMargins.setter
    def ShowPageMargins(self, value):
        self.com_object.ShowPageMargins = value

    @property
    def showpagemargins(self):
        """Alias for ShowPageMargins"""
        return self.ShowPageMargins

    @showpagemargins.setter
    def showpagemargins(self, value):
        """Alias for ShowPageMargins.setter"""
        self.ShowPageMargins = value

    @property
    def show_page_margins(self):
        """Alias for ShowPageMargins"""
        return self.ShowPageMargins

    @show_page_margins.setter
    def show_page_margins(self, value):
        """Alias for ShowPageMargins.setter"""
        self.ShowPageMargins = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def TimerInterval(self):
        return self.com_object.TimerInterval

    @TimerInterval.setter
    def TimerInterval(self, value):
        self.com_object.TimerInterval = value

    @property
    def timerinterval(self):
        """Alias for TimerInterval"""
        return self.TimerInterval

    @timerinterval.setter
    def timerinterval(self, value):
        """Alias for TimerInterval.setter"""
        self.TimerInterval = value

    @property
    def timer_interval(self):
        """Alias for TimerInterval"""
        return self.TimerInterval

    @timer_interval.setter
    def timer_interval(self, value):
        """Alias for TimerInterval.setter"""
        self.TimerInterval = value

    @property
    def Toolbar(self):
        return self.com_object.Toolbar

    @Toolbar.setter
    def Toolbar(self, value):
        self.com_object.Toolbar = value

    @property
    def toolbar(self):
        """Alias for Toolbar"""
        return self.Toolbar

    @toolbar.setter
    def toolbar(self, value):
        """Alias for Toolbar.setter"""
        self.Toolbar = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def UseDefaultPrinter(self):
        return self.com_object.UseDefaultPrinter

    @UseDefaultPrinter.setter
    def UseDefaultPrinter(self, value):
        self.com_object.UseDefaultPrinter = value

    @property
    def usedefaultprinter(self):
        """Alias for UseDefaultPrinter"""
        return self.UseDefaultPrinter

    @usedefaultprinter.setter
    def usedefaultprinter(self, value):
        """Alias for UseDefaultPrinter.setter"""
        self.UseDefaultPrinter = value

    @property
    def use_default_printer(self):
        """Alias for UseDefaultPrinter"""
        return self.UseDefaultPrinter

    @use_default_printer.setter
    def use_default_printer(self, value):
        """Alias for UseDefaultPrinter.setter"""
        self.UseDefaultPrinter = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    @property
    def WindowHeight(self):
        return self.com_object.WindowHeight

    @property
    def windowheight(self):
        """Alias for WindowHeight"""
        return self.WindowHeight

    @property
    def window_height(self):
        """Alias for WindowHeight"""
        return self.WindowHeight

    @property
    def WindowLeft(self):
        return self.com_object.WindowLeft

    @property
    def windowleft(self):
        """Alias for WindowLeft"""
        return self.WindowLeft

    @property
    def window_left(self):
        """Alias for WindowLeft"""
        return self.WindowLeft

    @property
    def WindowTop(self):
        return self.com_object.WindowTop

    @property
    def windowtop(self):
        """Alias for WindowTop"""
        return self.WindowTop

    @property
    def window_top(self):
        """Alias for WindowTop"""
        return self.WindowTop

    @property
    def WindowWidth(self):
        return self.com_object.WindowWidth

    @property
    def windowwidth(self):
        """Alias for WindowWidth"""
        return self.WindowWidth

    @property
    def window_width(self):
        """Alias for WindowWidth"""
        return self.WindowWidth

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def Print(self, Expr=None):
        arguments = com_arguments([unwrap(a) for a in [Expr]])
        return self.com_object.Print(*arguments)

    def print(self, Expr=None):
        """Alias for Print"""
        arguments = [Expr]
        return self.Print(*arguments)

    def PSet(self, Flags=None, x=None, y=None, Color=None):
        arguments = com_arguments([unwrap(a) for a in [Flags, x, y, Color]])
        return self.com_object.PSet(*arguments)

    def pset(self, Flags=None, x=None, y=None, Color=None):
        """Alias for PSet"""
        arguments = [Flags, x, y, Color]
        return self.PSet(*arguments)

    def p_set(self, Flags=None, x=None, y=None, Color=None):
        """Alias for PSet"""
        arguments = [Flags, x, y, Color]
        return self.PSet(*arguments)

    def Requery(self):
        self.com_object.Requery()

    def requery(self):
        """Alias for Requery"""
        return self.Requery()

    def Scale(self, Flags=None, x1=None, y1=None, x2=None, y2=None):
        arguments = com_arguments([unwrap(a) for a in [Flags, x1, y1, x2, y2]])
        return self.com_object.Scale(*arguments)

    def scale(self, Flags=None, x1=None, y1=None, x2=None, y2=None):
        """Alias for Scale"""
        arguments = [Flags, x1, y1, x2, y2]
        return self.Scale(*arguments)

    def TextHeight(self, Expr=None):
        arguments = com_arguments([unwrap(a) for a in [Expr]])
        return self.com_object.TextHeight(*arguments)

    def textheight(self, Expr=None):
        """Alias for TextHeight"""
        arguments = [Expr]
        return self.TextHeight(*arguments)

    def text_height(self, Expr=None):
        """Alias for TextHeight"""
        arguments = [Expr]
        return self.TextHeight(*arguments)

    def TextWidth(self, Expr=None):
        arguments = com_arguments([unwrap(a) for a in [Expr]])
        return self.com_object.TextWidth(*arguments)

    def textwidth(self, Expr=None):
        """Alias for TextWidth"""
        arguments = [Expr]
        return self.TextWidth(*arguments)

    def text_width(self, Expr=None):
        """Alias for TextWidth"""
        arguments = [Expr]
        return self.TextWidth(*arguments)


class Reports:

    def __init__(self, reports=None):
        self.com_object= reports

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class ReturnVar:

    def __init__(self, returnvar=None):
        self.com_object= returnvar

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Value(self):
        return self.com_object.Value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value


class ReturnVars:

    def __init__(self, returnvars=None):
        self.com_object= returnvars

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class Screen:

    def __init__(self, screen=None):
        self.com_object= screen

    @property
    def ActiveControl(self):
        return self.com_object.ActiveControl

    @property
    def activecontrol(self):
        """Alias for ActiveControl"""
        return self.ActiveControl

    @property
    def active_control(self):
        """Alias for ActiveControl"""
        return self.ActiveControl

    @property
    def ActiveDatasheet(self):
        return self.com_object.ActiveDatasheet

    @property
    def activedatasheet(self):
        """Alias for ActiveDatasheet"""
        return self.ActiveDatasheet

    @property
    def active_datasheet(self):
        """Alias for ActiveDatasheet"""
        return self.ActiveDatasheet

    @property
    def ActiveForm(self):
        return self.com_object.ActiveForm

    @property
    def activeform(self):
        """Alias for ActiveForm"""
        return self.ActiveForm

    @property
    def active_form(self):
        """Alias for ActiveForm"""
        return self.ActiveForm

    @property
    def ActiveReport(self):
        return self.com_object.ActiveReport

    @property
    def activereport(self):
        """Alias for ActiveReport"""
        return self.ActiveReport

    @property
    def active_report(self):
        """Alias for ActiveReport"""
        return self.ActiveReport

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def MousePointer(self):
        return self.com_object.MousePointer

    @MousePointer.setter
    def MousePointer(self, value):
        self.com_object.MousePointer = value

    @property
    def mousepointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mousepointer.setter
    def mousepointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def mouse_pointer(self):
        """Alias for MousePointer"""
        return self.MousePointer

    @mouse_pointer.setter
    def mouse_pointer(self, value):
        """Alias for MousePointer.setter"""
        self.MousePointer = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PreviousControl(self):
        return self.com_object.PreviousControl

    @property
    def previouscontrol(self):
        """Alias for PreviousControl"""
        return self.PreviousControl

    @property
    def previous_control(self):
        """Alias for PreviousControl"""
        return self.PreviousControl


class Section:

    def __init__(self, section=None):
        self.com_object= section

    @property
    def AlternateBackColor(self):
        return self.com_object.AlternateBackColor

    @AlternateBackColor.setter
    def AlternateBackColor(self, value):
        self.com_object.AlternateBackColor = value

    @property
    def alternatebackcolor(self):
        """Alias for AlternateBackColor"""
        return self.AlternateBackColor

    @alternatebackcolor.setter
    def alternatebackcolor(self, value):
        """Alias for AlternateBackColor.setter"""
        self.AlternateBackColor = value

    @property
    def alternate_back_color(self):
        """Alias for AlternateBackColor"""
        return self.AlternateBackColor

    @alternate_back_color.setter
    def alternate_back_color(self, value):
        """Alias for AlternateBackColor.setter"""
        self.AlternateBackColor = value

    @property
    def AlternateBackShade(self):
        return self.com_object.AlternateBackShade

    @AlternateBackShade.setter
    def AlternateBackShade(self, value):
        self.com_object.AlternateBackShade = value

    @property
    def alternatebackshade(self):
        """Alias for AlternateBackShade"""
        return self.AlternateBackShade

    @alternatebackshade.setter
    def alternatebackshade(self, value):
        """Alias for AlternateBackShade.setter"""
        self.AlternateBackShade = value

    @property
    def alternate_back_shade(self):
        """Alias for AlternateBackShade"""
        return self.AlternateBackShade

    @alternate_back_shade.setter
    def alternate_back_shade(self, value):
        """Alias for AlternateBackShade.setter"""
        self.AlternateBackShade = value

    @property
    def AlternateBackThemeColorIndex(self):
        return self.com_object.AlternateBackThemeColorIndex

    @AlternateBackThemeColorIndex.setter
    def AlternateBackThemeColorIndex(self, value):
        self.com_object.AlternateBackThemeColorIndex = value

    @property
    def alternatebackthemecolorindex(self):
        """Alias for AlternateBackThemeColorIndex"""
        return self.AlternateBackThemeColorIndex

    @alternatebackthemecolorindex.setter
    def alternatebackthemecolorindex(self, value):
        """Alias for AlternateBackThemeColorIndex.setter"""
        self.AlternateBackThemeColorIndex = value

    @property
    def alternate_back_theme_color_index(self):
        """Alias for AlternateBackThemeColorIndex"""
        return self.AlternateBackThemeColorIndex

    @alternate_back_theme_color_index.setter
    def alternate_back_theme_color_index(self, value):
        """Alias for AlternateBackThemeColorIndex.setter"""
        self.AlternateBackThemeColorIndex = value

    @property
    def AlternateBackTint(self):
        return self.com_object.AlternateBackTint

    @AlternateBackTint.setter
    def AlternateBackTint(self, value):
        self.com_object.AlternateBackTint = value

    @property
    def alternatebacktint(self):
        """Alias for AlternateBackTint"""
        return self.AlternateBackTint

    @alternatebacktint.setter
    def alternatebacktint(self, value):
        """Alias for AlternateBackTint.setter"""
        self.AlternateBackTint = value

    @property
    def alternate_back_tint(self):
        """Alias for AlternateBackTint"""
        return self.AlternateBackTint

    @alternate_back_tint.setter
    def alternate_back_tint(self, value):
        """Alias for AlternateBackTint.setter"""
        self.AlternateBackTint = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoHeight(self):
        return self.com_object.AutoHeight

    @AutoHeight.setter
    def AutoHeight(self, value):
        self.com_object.AutoHeight = value

    @property
    def autoheight(self):
        """Alias for AutoHeight"""
        return self.AutoHeight

    @autoheight.setter
    def autoheight(self, value):
        """Alias for AutoHeight.setter"""
        self.AutoHeight = value

    @property
    def auto_height(self):
        """Alias for AutoHeight"""
        return self.AutoHeight

    @auto_height.setter
    def auto_height(self, value):
        """Alias for AutoHeight.setter"""
        self.AutoHeight = value

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BackShade(self):
        return self.com_object.BackShade

    @BackShade.setter
    def BackShade(self, value):
        self.com_object.BackShade = value

    @property
    def backshade(self):
        """Alias for BackShade"""
        return self.BackShade

    @backshade.setter
    def backshade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def back_shade(self):
        """Alias for BackShade"""
        return self.BackShade

    @back_shade.setter
    def back_shade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def BackThemeColorIndex(self):
        return self.com_object.BackThemeColorIndex

    @BackThemeColorIndex.setter
    def BackThemeColorIndex(self, value):
        self.com_object.BackThemeColorIndex = value

    @property
    def backthemecolorindex(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @backthemecolorindex.setter
    def backthemecolorindex(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def back_theme_color_index(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @back_theme_color_index.setter
    def back_theme_color_index(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def BackTint(self):
        return self.com_object.BackTint

    @BackTint.setter
    def BackTint(self, value):
        self.com_object.BackTint = value

    @property
    def backtint(self):
        """Alias for BackTint"""
        return self.BackTint

    @backtint.setter
    def backtint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def back_tint(self):
        """Alias for BackTint"""
        return self.BackTint

    @back_tint.setter
    def back_tint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def CanGrow(self):
        return self.com_object.CanGrow

    @CanGrow.setter
    def CanGrow(self, value):
        self.com_object.CanGrow = value

    @property
    def cangrow(self):
        """Alias for CanGrow"""
        return self.CanGrow

    @cangrow.setter
    def cangrow(self, value):
        """Alias for CanGrow.setter"""
        self.CanGrow = value

    @property
    def can_grow(self):
        """Alias for CanGrow"""
        return self.CanGrow

    @can_grow.setter
    def can_grow(self, value):
        """Alias for CanGrow.setter"""
        self.CanGrow = value

    @property
    def CanShrink(self):
        return self.com_object.CanShrink

    @CanShrink.setter
    def CanShrink(self, value):
        self.com_object.CanShrink = value

    @property
    def canshrink(self):
        """Alias for CanShrink"""
        return self.CanShrink

    @canshrink.setter
    def canshrink(self, value):
        """Alias for CanShrink.setter"""
        self.CanShrink = value

    @property
    def can_shrink(self):
        """Alias for CanShrink"""
        return self.CanShrink

    @can_shrink.setter
    def can_shrink(self, value):
        """Alias for CanShrink.setter"""
        self.CanShrink = value

    @property
    def Controls(self):
        return Controls(self.com_object.Controls)

    @property
    def controls(self):
        """Alias for Controls"""
        return self.Controls

    @property
    def DisplayWhen(self):
        return self.com_object.DisplayWhen

    @DisplayWhen.setter
    def DisplayWhen(self, value):
        self.com_object.DisplayWhen = value

    @property
    def displaywhen(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @displaywhen.setter
    def displaywhen(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def display_when(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @display_when.setter
    def display_when(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def ForceNewPage(self):
        return self.com_object.ForceNewPage

    @ForceNewPage.setter
    def ForceNewPage(self, value):
        self.com_object.ForceNewPage = value

    @property
    def forcenewpage(self):
        """Alias for ForceNewPage"""
        return self.ForceNewPage

    @forcenewpage.setter
    def forcenewpage(self, value):
        """Alias for ForceNewPage.setter"""
        self.ForceNewPage = value

    @property
    def force_new_page(self):
        """Alias for ForceNewPage"""
        return self.ForceNewPage

    @force_new_page.setter
    def force_new_page(self, value):
        """Alias for ForceNewPage.setter"""
        self.ForceNewPage = value

    @property
    def HasContinued(self):
        return self.com_object.HasContinued

    @HasContinued.setter
    def HasContinued(self, value):
        self.com_object.HasContinued = value

    @property
    def hascontinued(self):
        """Alias for HasContinued"""
        return self.HasContinued

    @hascontinued.setter
    def hascontinued(self, value):
        """Alias for HasContinued.setter"""
        self.HasContinued = value

    @property
    def has_continued(self):
        """Alias for HasContinued"""
        return self.HasContinued

    @has_continued.setter
    def has_continued(self, value):
        """Alias for HasContinued.setter"""
        self.HasContinued = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def KeepTogether(self):
        return self.com_object.KeepTogether

    @KeepTogether.setter
    def KeepTogether(self, value):
        self.com_object.KeepTogether = value

    @property
    def keeptogether(self):
        """Alias for KeepTogether"""
        return self.KeepTogether

    @keeptogether.setter
    def keeptogether(self, value):
        """Alias for KeepTogether.setter"""
        self.KeepTogether = value

    @property
    def keep_together(self):
        """Alias for KeepTogether"""
        return self.KeepTogether

    @keep_together.setter
    def keep_together(self, value):
        """Alias for KeepTogether.setter"""
        self.KeepTogether = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def NewRowOrCol(self):
        return self.com_object.NewRowOrCol

    @NewRowOrCol.setter
    def NewRowOrCol(self, value):
        self.com_object.NewRowOrCol = value

    @property
    def newroworcol(self):
        """Alias for NewRowOrCol"""
        return self.NewRowOrCol

    @newroworcol.setter
    def newroworcol(self, value):
        """Alias for NewRowOrCol.setter"""
        self.NewRowOrCol = value

    @property
    def new_row_or_col(self):
        """Alias for NewRowOrCol"""
        return self.NewRowOrCol

    @new_row_or_col.setter
    def new_row_or_col(self, value):
        """Alias for NewRowOrCol.setter"""
        self.NewRowOrCol = value

    @property
    def OnClick(self):
        return self.com_object.OnClick

    @OnClick.setter
    def OnClick(self, value):
        self.com_object.OnClick = value

    @property
    def onclick(self):
        """Alias for OnClick"""
        return self.OnClick

    @onclick.setter
    def onclick(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def on_click(self):
        """Alias for OnClick"""
        return self.OnClick

    @on_click.setter
    def on_click(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def OnDblClick(self):
        return self.com_object.OnDblClick

    @OnDblClick.setter
    def OnDblClick(self, value):
        self.com_object.OnDblClick = value

    @property
    def ondblclick(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @ondblclick.setter
    def ondblclick(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def on_dbl_click(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @on_dbl_click.setter
    def on_dbl_click(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def OnFormat(self):
        return self.com_object.OnFormat

    @OnFormat.setter
    def OnFormat(self, value):
        self.com_object.OnFormat = value

    @property
    def onformat(self):
        """Alias for OnFormat"""
        return self.OnFormat

    @onformat.setter
    def onformat(self, value):
        """Alias for OnFormat.setter"""
        self.OnFormat = value

    @property
    def on_format(self):
        """Alias for OnFormat"""
        return self.OnFormat

    @on_format.setter
    def on_format(self, value):
        """Alias for OnFormat.setter"""
        self.OnFormat = value

    @property
    def OnMouseDown(self):
        return self.com_object.OnMouseDown

    @OnMouseDown.setter
    def OnMouseDown(self, value):
        self.com_object.OnMouseDown = value

    @property
    def onmousedown(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @onmousedown.setter
    def onmousedown(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def on_mouse_down(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @on_mouse_down.setter
    def on_mouse_down(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def OnMouseMove(self):
        return self.com_object.OnMouseMove

    @OnMouseMove.setter
    def OnMouseMove(self, value):
        self.com_object.OnMouseMove = value

    @property
    def onmousemove(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @onmousemove.setter
    def onmousemove(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def on_mouse_move(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @on_mouse_move.setter
    def on_mouse_move(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def OnMouseUp(self):
        return self.com_object.OnMouseUp

    @OnMouseUp.setter
    def OnMouseUp(self, value):
        self.com_object.OnMouseUp = value

    @property
    def onmouseup(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @onmouseup.setter
    def onmouseup(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def on_mouse_up(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @on_mouse_up.setter
    def on_mouse_up(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def OnPaint(self):
        return self.com_object.OnPaint

    @OnPaint.setter
    def OnPaint(self, value):
        self.com_object.OnPaint = value

    @property
    def onpaint(self):
        """Alias for OnPaint"""
        return self.OnPaint

    @onpaint.setter
    def onpaint(self, value):
        """Alias for OnPaint.setter"""
        self.OnPaint = value

    @property
    def on_paint(self):
        """Alias for OnPaint"""
        return self.OnPaint

    @on_paint.setter
    def on_paint(self, value):
        """Alias for OnPaint.setter"""
        self.OnPaint = value

    @property
    def OnPrint(self):
        return self.com_object.OnPrint

    @OnPrint.setter
    def OnPrint(self, value):
        self.com_object.OnPrint = value

    @property
    def onprint(self):
        """Alias for OnPrint"""
        return self.OnPrint

    @onprint.setter
    def onprint(self, value):
        """Alias for OnPrint.setter"""
        self.OnPrint = value

    @property
    def on_print(self):
        """Alias for OnPrint"""
        return self.OnPrint

    @on_print.setter
    def on_print(self, value):
        """Alias for OnPrint.setter"""
        self.OnPrint = value

    @property
    def OnRetreat(self):
        return self.com_object.OnRetreat

    @OnRetreat.setter
    def OnRetreat(self, value):
        self.com_object.OnRetreat = value

    @property
    def onretreat(self):
        """Alias for OnRetreat"""
        return self.OnRetreat

    @onretreat.setter
    def onretreat(self, value):
        """Alias for OnRetreat.setter"""
        self.OnRetreat = value

    @property
    def on_retreat(self):
        """Alias for OnRetreat"""
        return self.OnRetreat

    @on_retreat.setter
    def on_retreat(self, value):
        """Alias for OnRetreat.setter"""
        self.OnRetreat = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def RepeatSection(self):
        return self.com_object.RepeatSection

    @RepeatSection.setter
    def RepeatSection(self, value):
        self.com_object.RepeatSection = value

    @property
    def repeatsection(self):
        """Alias for RepeatSection"""
        return self.RepeatSection

    @repeatsection.setter
    def repeatsection(self, value):
        """Alias for RepeatSection.setter"""
        self.RepeatSection = value

    @property
    def repeat_section(self):
        """Alias for RepeatSection"""
        return self.RepeatSection

    @repeat_section.setter
    def repeat_section(self, value):
        """Alias for RepeatSection.setter"""
        self.RepeatSection = value

    @property
    def SpecialEffect(self):
        return self.com_object.SpecialEffect

    @SpecialEffect.setter
    def SpecialEffect(self, value):
        self.com_object.SpecialEffect = value

    @property
    def specialeffect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @specialeffect.setter
    def specialeffect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def special_effect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @special_effect.setter
    def special_effect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def WillContinue(self):
        return self.com_object.WillContinue

    @WillContinue.setter
    def WillContinue(self, value):
        self.com_object.WillContinue = value

    @property
    def willcontinue(self):
        """Alias for WillContinue"""
        return self.WillContinue

    @willcontinue.setter
    def willcontinue(self, value):
        """Alias for WillContinue.setter"""
        self.WillContinue = value

    @property
    def will_continue(self):
        """Alias for WillContinue"""
        return self.WillContinue

    @will_continue.setter
    def will_continue(self, value):
        """Alias for WillContinue.setter"""
        self.WillContinue = value

    def SetTabOrder(self):
        self.com_object.SetTabOrder()

    def settaborder(self):
        """Alias for SetTabOrder"""
        return self.SetTabOrder()

    def set_tab_order(self):
        """Alias for SetTabOrder"""
        return self.SetTabOrder()


class SharedResource:

    def __init__(self, sharedresource=None):
        self.com_object= sharedresource

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Type(self):
        return self.com_object.Type

    @property
    def type(self):
        """Alias for Type"""
        return self.Type

    def Delete(self):
        self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class SharedResources:

    def __init__(self, sharedresources=None):
        self.com_object= sharedresources

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class SmartTag:

    def __init__(self, smarttag=None):
        self.com_object= smarttag

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def IsMissing(self):
        return self.com_object.IsMissing

    @property
    def ismissing(self):
        """Alias for IsMissing"""
        return self.IsMissing

    @property
    def is_missing(self):
        """Alias for IsMissing"""
        return self.IsMissing

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Properties(self):
        return SmartTagProperties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def SmartTagActions(self):
        return SmartTagActions(self.com_object.SmartTagActions)

    @property
    def smarttagactions(self):
        """Alias for SmartTagActions"""
        return self.SmartTagActions

    @property
    def smart_tag_actions(self):
        """Alias for SmartTagActions"""
        return self.SmartTagActions

    @property
    def XML(self):
        return self.com_object.XML

    @property
    def xml(self):
        """Alias for XML"""
        return self.XML

    @property
    def x_m_l(self):
        """Alias for XML"""
        return self.XML

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class SmartTagAction:

    def __init__(self, smarttagaction=None):
        self.com_object= smarttagaction

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Execute(self):
        self.com_object.Execute()

    def execute(self):
        """Alias for Execute"""
        return self.Execute()


class SmartTagActions:

    def __init__(self, smarttagactions=None):
        self.com_object= smarttagactions

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class SmartTagProperties:

    def __init__(self, smarttagproperties=None):
        self.com_object= smarttagproperties

    def __call__(self, item):
        return SmartTagPropertie(self.com_object(item))

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, Value=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Value]])
        return SmartTagProperty(self.com_object.Add(*arguments))

    def add(self, Name=None, Value=None):
        """Alias for Add"""
        arguments = [Name, Value]
        return self.Add(*arguments)


class SmartTagProperty:

    def __init__(self, smarttagproperty=None):
        self.com_object= smarttagproperty

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    def Delete(self):
        return self.com_object.Delete()

    def delete(self):
        """Alias for Delete"""
        return self.Delete()


class SmartTags:

    def __init__(self, smarttags=None):
        self.com_object= smarttags

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None):
        arguments = com_arguments([unwrap(a) for a in [Name]])
        return SmartTag(self.com_object.Add(*arguments))

    def add(self, Name=None):
        """Alias for Add"""
        arguments = [Name]
        return self.Add(*arguments)


class SubForm:

    def __init__(self, subform=None):
        self.com_object= subform

    @property
    def AddColon(self):
        return self.com_object.AddColon

    @AddColon.setter
    def AddColon(self, value):
        self.com_object.AddColon = value

    @property
    def addcolon(self):
        """Alias for AddColon"""
        return self.AddColon

    @addcolon.setter
    def addcolon(self, value):
        """Alias for AddColon.setter"""
        self.AddColon = value

    @property
    def add_colon(self):
        """Alias for AddColon"""
        return self.AddColon

    @add_colon.setter
    def add_colon(self, value):
        """Alias for AddColon.setter"""
        self.AddColon = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoLabel(self):
        return self.com_object.AutoLabel

    @AutoLabel.setter
    def AutoLabel(self, value):
        self.com_object.AutoLabel = value

    @property
    def autolabel(self):
        """Alias for AutoLabel"""
        return self.AutoLabel

    @autolabel.setter
    def autolabel(self, value):
        """Alias for AutoLabel.setter"""
        self.AutoLabel = value

    @property
    def auto_label(self):
        """Alias for AutoLabel"""
        return self.AutoLabel

    @auto_label.setter
    def auto_label(self, value):
        """Alias for AutoLabel.setter"""
        self.AutoLabel = value

    @property
    def BorderColor(self):
        return self.com_object.BorderColor

    @BorderColor.setter
    def BorderColor(self, value):
        self.com_object.BorderColor = value

    @property
    def bordercolor(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @bordercolor.setter
    def bordercolor(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def border_color(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @border_color.setter
    def border_color(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def BorderShade(self):
        return self.com_object.BorderShade

    @BorderShade.setter
    def BorderShade(self, value):
        self.com_object.BorderShade = value

    @property
    def bordershade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @bordershade.setter
    def bordershade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def border_shade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @border_shade.setter
    def border_shade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def BorderStyle(self):
        return self.com_object.BorderStyle

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def BorderThemeColorIndex(self):
        return self.com_object.BorderThemeColorIndex

    @BorderThemeColorIndex.setter
    def BorderThemeColorIndex(self, value):
        self.com_object.BorderThemeColorIndex = value

    @property
    def borderthemecolorindex(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @borderthemecolorindex.setter
    def borderthemecolorindex(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def border_theme_color_index(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @border_theme_color_index.setter
    def border_theme_color_index(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def BorderTint(self):
        return self.com_object.BorderTint

    @BorderTint.setter
    def BorderTint(self, value):
        self.com_object.BorderTint = value

    @property
    def bordertint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @bordertint.setter
    def bordertint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def border_tint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @border_tint.setter
    def border_tint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def BorderWidth(self):
        return self.com_object.BorderWidth

    @BorderWidth.setter
    def BorderWidth(self, value):
        self.com_object.BorderWidth = value

    @property
    def borderwidth(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @borderwidth.setter
    def borderwidth(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def border_width(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @border_width.setter
    def border_width(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def BottomPadding(self):
        return self.com_object.BottomPadding

    @BottomPadding.setter
    def BottomPadding(self, value):
        self.com_object.BottomPadding = value

    @property
    def bottompadding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottompadding.setter
    def bottompadding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def bottom_padding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottom_padding.setter
    def bottom_padding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def CanGrow(self):
        return self.com_object.CanGrow

    @CanGrow.setter
    def CanGrow(self, value):
        self.com_object.CanGrow = value

    @property
    def cangrow(self):
        """Alias for CanGrow"""
        return self.CanGrow

    @cangrow.setter
    def cangrow(self, value):
        """Alias for CanGrow.setter"""
        self.CanGrow = value

    @property
    def can_grow(self):
        """Alias for CanGrow"""
        return self.CanGrow

    @can_grow.setter
    def can_grow(self, value):
        """Alias for CanGrow.setter"""
        self.CanGrow = value

    @property
    def CanShrink(self):
        return self.com_object.CanShrink

    @CanShrink.setter
    def CanShrink(self, value):
        self.com_object.CanShrink = value

    @property
    def canshrink(self):
        """Alias for CanShrink"""
        return self.CanShrink

    @canshrink.setter
    def canshrink(self, value):
        """Alias for CanShrink.setter"""
        self.CanShrink = value

    @property
    def can_shrink(self):
        """Alias for CanShrink"""
        return self.CanShrink

    @can_shrink.setter
    def can_shrink(self, value):
        """Alias for CanShrink.setter"""
        self.CanShrink = value

    @property
    def Controls(self):
        return Controls(self.com_object.Controls)

    @property
    def controls(self):
        """Alias for Controls"""
        return self.Controls

    @property
    def ControlType(self):
        return self.com_object.ControlType

    @ControlType.setter
    def ControlType(self, value):
        self.com_object.ControlType = value

    @property
    def controltype(self):
        """Alias for ControlType"""
        return self.ControlType

    @controltype.setter
    def controltype(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def control_type(self):
        """Alias for ControlType"""
        return self.ControlType

    @control_type.setter
    def control_type(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def DisplayWhen(self):
        return self.com_object.DisplayWhen

    @DisplayWhen.setter
    def DisplayWhen(self, value):
        self.com_object.DisplayWhen = value

    @property
    def displaywhen(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @displaywhen.setter
    def displaywhen(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def display_when(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @display_when.setter
    def display_when(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def FilterOnEmptyMaster(self):
        return self.com_object.FilterOnEmptyMaster

    @FilterOnEmptyMaster.setter
    def FilterOnEmptyMaster(self, value):
        self.com_object.FilterOnEmptyMaster = value

    @property
    def filteronemptymaster(self):
        """Alias for FilterOnEmptyMaster"""
        return self.FilterOnEmptyMaster

    @filteronemptymaster.setter
    def filteronemptymaster(self, value):
        """Alias for FilterOnEmptyMaster.setter"""
        self.FilterOnEmptyMaster = value

    @property
    def filter_on_empty_master(self):
        """Alias for FilterOnEmptyMaster"""
        return self.FilterOnEmptyMaster

    @filter_on_empty_master.setter
    def filter_on_empty_master(self, value):
        """Alias for FilterOnEmptyMaster.setter"""
        self.FilterOnEmptyMaster = value

    @property
    def Form(self):
        return self.com_object.Form

    @property
    def form(self):
        """Alias for Form"""
        return self.Form

    @property
    def GridlineColor(self):
        return self.com_object.GridlineColor

    @GridlineColor.setter
    def GridlineColor(self, value):
        self.com_object.GridlineColor = value

    @property
    def gridlinecolor(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridlinecolor.setter
    def gridlinecolor(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def gridline_color(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridline_color.setter
    def gridline_color(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def GridlineShade(self):
        return self.com_object.GridlineShade

    @GridlineShade.setter
    def GridlineShade(self, value):
        self.com_object.GridlineShade = value

    @property
    def gridlineshade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridlineshade.setter
    def gridlineshade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def gridline_shade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridline_shade.setter
    def gridline_shade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def GridlineStyleBottom(self):
        return self.com_object.GridlineStyleBottom

    @GridlineStyleBottom.setter
    def GridlineStyleBottom(self, value):
        self.com_object.GridlineStyleBottom = value

    @property
    def gridlinestylebottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridlinestylebottom.setter
    def gridlinestylebottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def gridline_style_bottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridline_style_bottom.setter
    def gridline_style_bottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def GridlineStyleLeft(self):
        return self.com_object.GridlineStyleLeft

    @GridlineStyleLeft.setter
    def GridlineStyleLeft(self, value):
        self.com_object.GridlineStyleLeft = value

    @property
    def gridlinestyleleft(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridlinestyleleft.setter
    def gridlinestyleleft(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def gridline_style_left(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridline_style_left.setter
    def gridline_style_left(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def GridlineStyleRight(self):
        return self.com_object.GridlineStyleRight

    @GridlineStyleRight.setter
    def GridlineStyleRight(self, value):
        self.com_object.GridlineStyleRight = value

    @property
    def gridlinestyleright(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridlinestyleright.setter
    def gridlinestyleright(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def gridline_style_right(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridline_style_right.setter
    def gridline_style_right(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def GridlineStyleTop(self):
        return self.com_object.GridlineStyleTop

    @GridlineStyleTop.setter
    def GridlineStyleTop(self, value):
        self.com_object.GridlineStyleTop = value

    @property
    def gridlinestyletop(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridlinestyletop.setter
    def gridlinestyletop(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def gridline_style_top(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridline_style_top.setter
    def gridline_style_top(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def GridlineThemeColorIndex(self):
        return self.com_object.GridlineThemeColorIndex

    @GridlineThemeColorIndex.setter
    def GridlineThemeColorIndex(self, value):
        self.com_object.GridlineThemeColorIndex = value

    @property
    def gridlinethemecolorindex(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridlinethemecolorindex.setter
    def gridlinethemecolorindex(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def gridline_theme_color_index(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridline_theme_color_index.setter
    def gridline_theme_color_index(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def GridlineTint(self):
        return self.com_object.GridlineTint

    @GridlineTint.setter
    def GridlineTint(self, value):
        self.com_object.GridlineTint = value

    @property
    def gridlinetint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridlinetint.setter
    def gridlinetint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def gridline_tint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridline_tint.setter
    def gridline_tint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def GridlineWidthBottom(self):
        return self.com_object.GridlineWidthBottom

    @GridlineWidthBottom.setter
    def GridlineWidthBottom(self, value):
        self.com_object.GridlineWidthBottom = value

    @property
    def gridlinewidthbottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridlinewidthbottom.setter
    def gridlinewidthbottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def gridline_width_bottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridline_width_bottom.setter
    def gridline_width_bottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def GridlineWidthLeft(self):
        return self.com_object.GridlineWidthLeft

    @GridlineWidthLeft.setter
    def GridlineWidthLeft(self, value):
        self.com_object.GridlineWidthLeft = value

    @property
    def gridlinewidthleft(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridlinewidthleft.setter
    def gridlinewidthleft(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def gridline_width_left(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridline_width_left.setter
    def gridline_width_left(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def GridlineWidthRight(self):
        return self.com_object.GridlineWidthRight

    @GridlineWidthRight.setter
    def GridlineWidthRight(self, value):
        self.com_object.GridlineWidthRight = value

    @property
    def gridlinewidthright(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridlinewidthright.setter
    def gridlinewidthright(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def gridline_width_right(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridline_width_right.setter
    def gridline_width_right(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def GridlineWidthTop(self):
        return self.com_object.GridlineWidthTop

    @GridlineWidthTop.setter
    def GridlineWidthTop(self, value):
        self.com_object.GridlineWidthTop = value

    @property
    def gridlinewidthtop(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridlinewidthtop.setter
    def gridlinewidthtop(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def gridline_width_top(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridline_width_top.setter
    def gridline_width_top(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def IsVisible(self):
        return self.com_object.IsVisible

    @IsVisible.setter
    def IsVisible(self, value):
        self.com_object.IsVisible = value

    @property
    def isvisible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @isvisible.setter
    def isvisible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def is_visible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @is_visible.setter
    def is_visible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def LabelAlign(self):
        return self.com_object.LabelAlign

    @LabelAlign.setter
    def LabelAlign(self, value):
        self.com_object.LabelAlign = value

    @property
    def labelalign(self):
        """Alias for LabelAlign"""
        return self.LabelAlign

    @labelalign.setter
    def labelalign(self, value):
        """Alias for LabelAlign.setter"""
        self.LabelAlign = value

    @property
    def label_align(self):
        """Alias for LabelAlign"""
        return self.LabelAlign

    @label_align.setter
    def label_align(self, value):
        """Alias for LabelAlign.setter"""
        self.LabelAlign = value

    @property
    def LabelX(self):
        return self.com_object.LabelX

    @LabelX.setter
    def LabelX(self, value):
        self.com_object.LabelX = value

    @property
    def labelx(self):
        """Alias for LabelX"""
        return self.LabelX

    @labelx.setter
    def labelx(self, value):
        """Alias for LabelX.setter"""
        self.LabelX = value

    @property
    def label_x(self):
        """Alias for LabelX"""
        return self.LabelX

    @label_x.setter
    def label_x(self, value):
        """Alias for LabelX.setter"""
        self.LabelX = value

    @property
    def LabelY(self):
        return self.com_object.LabelY

    @LabelY.setter
    def LabelY(self, value):
        self.com_object.LabelY = value

    @property
    def labely(self):
        """Alias for LabelY"""
        return self.LabelY

    @labely.setter
    def labely(self, value):
        """Alias for LabelY.setter"""
        self.LabelY = value

    @property
    def label_y(self):
        """Alias for LabelY"""
        return self.LabelY

    @label_y.setter
    def label_y(self, value):
        """Alias for LabelY.setter"""
        self.LabelY = value

    @property
    def Layout(self):
        return AcLayoutType(self.com_object.Layout)

    @property
    def layout(self):
        """Alias for Layout"""
        return self.Layout

    @property
    def LayoutID(self):
        return self.com_object.LayoutID

    @property
    def layoutid(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def layout_i_d(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def LeftPadding(self):
        return self.com_object.LeftPadding

    @LeftPadding.setter
    def LeftPadding(self, value):
        self.com_object.LeftPadding = value

    @property
    def leftpadding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @leftpadding.setter
    def leftpadding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def left_padding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @left_padding.setter
    def left_padding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def LinkChildFields(self):
        return self.com_object.LinkChildFields

    @LinkChildFields.setter
    def LinkChildFields(self, value):
        self.com_object.LinkChildFields = value

    @property
    def linkchildfields(self):
        """Alias for LinkChildFields"""
        return self.LinkChildFields

    @linkchildfields.setter
    def linkchildfields(self, value):
        """Alias for LinkChildFields.setter"""
        self.LinkChildFields = value

    @property
    def link_child_fields(self):
        """Alias for LinkChildFields"""
        return self.LinkChildFields

    @link_child_fields.setter
    def link_child_fields(self, value):
        """Alias for LinkChildFields.setter"""
        self.LinkChildFields = value

    @property
    def LinkMasterFields(self):
        return self.com_object.LinkMasterFields

    @LinkMasterFields.setter
    def LinkMasterFields(self, value):
        self.com_object.LinkMasterFields = value

    @property
    def linkmasterfields(self):
        """Alias for LinkMasterFields"""
        return self.LinkMasterFields

    @linkmasterfields.setter
    def linkmasterfields(self, value):
        """Alias for LinkMasterFields.setter"""
        self.LinkMasterFields = value

    @property
    def link_master_fields(self):
        """Alias for LinkMasterFields"""
        return self.LinkMasterFields

    @link_master_fields.setter
    def link_master_fields(self, value):
        """Alias for LinkMasterFields.setter"""
        self.LinkMasterFields = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def OldBorderStyle(self):
        return self.com_object.OldBorderStyle

    @OldBorderStyle.setter
    def OldBorderStyle(self, value):
        self.com_object.OldBorderStyle = value

    @property
    def oldborderstyle(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @oldborderstyle.setter
    def oldborderstyle(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def old_border_style(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @old_border_style.setter
    def old_border_style(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def OnEnter(self):
        return self.com_object.OnEnter

    @OnEnter.setter
    def OnEnter(self, value):
        self.com_object.OnEnter = value

    @property
    def onenter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @onenter.setter
    def onenter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def on_enter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @on_enter.setter
    def on_enter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def OnExit(self):
        return self.com_object.OnExit

    @OnExit.setter
    def OnExit(self, value):
        self.com_object.OnExit = value

    @property
    def onexit(self):
        """Alias for OnExit"""
        return self.OnExit

    @onexit.setter
    def onexit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def on_exit(self):
        """Alias for OnExit"""
        return self.OnExit

    @on_exit.setter
    def on_exit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def Report(self):
        return self.com_object.Report

    @property
    def report(self):
        """Alias for Report"""
        return self.Report

    @property
    def RightPadding(self):
        return self.com_object.RightPadding

    @RightPadding.setter
    def RightPadding(self, value):
        self.com_object.RightPadding = value

    @property
    def rightpadding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @rightpadding.setter
    def rightpadding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def right_padding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @right_padding.setter
    def right_padding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def Section(self):
        return self.com_object.Section

    @Section.setter
    def Section(self, value):
        self.com_object.Section = value

    @property
    def section(self):
        """Alias for Section"""
        return self.Section

    @section.setter
    def section(self, value):
        """Alias for Section.setter"""
        self.Section = value

    @property
    def SourceObject(self):
        return self.com_object.SourceObject

    @SourceObject.setter
    def SourceObject(self, value):
        self.com_object.SourceObject = value

    @property
    def sourceobject(self):
        """Alias for SourceObject"""
        return self.SourceObject

    @sourceobject.setter
    def sourceobject(self, value):
        """Alias for SourceObject.setter"""
        self.SourceObject = value

    @property
    def source_object(self):
        """Alias for SourceObject"""
        return self.SourceObject

    @source_object.setter
    def source_object(self, value):
        """Alias for SourceObject.setter"""
        self.SourceObject = value

    @property
    def SpecialEffect(self):
        return self.com_object.SpecialEffect

    @SpecialEffect.setter
    def SpecialEffect(self, value):
        self.com_object.SpecialEffect = value

    @property
    def specialeffect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @specialeffect.setter
    def specialeffect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def special_effect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @special_effect.setter
    def special_effect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def StatusBarText(self):
        return self.com_object.StatusBarText

    @StatusBarText.setter
    def StatusBarText(self, value):
        self.com_object.StatusBarText = value

    @property
    def statusbartext(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @statusbartext.setter
    def statusbartext(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def status_bar_text(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @status_bar_text.setter
    def status_bar_text(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def TabIndex(self):
        return self.com_object.TabIndex

    @TabIndex.setter
    def TabIndex(self, value):
        self.com_object.TabIndex = value

    @property
    def tabindex(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tabindex.setter
    def tabindex(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def tab_index(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tab_index.setter
    def tab_index(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def TabStop(self):
        return self.com_object.TabStop

    @TabStop.setter
    def TabStop(self, value):
        self.com_object.TabStop = value

    @property
    def tabstop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tabstop.setter
    def tabstop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def tab_stop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tab_stop.setter
    def tab_stop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TopPadding(self):
        return self.com_object.TopPadding

    @TopPadding.setter
    def TopPadding(self, value):
        self.com_object.TopPadding = value

    @property
    def toppadding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @toppadding.setter
    def toppadding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def top_padding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @top_padding.setter
    def top_padding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def Requery(self):
        self.com_object.Requery()

    def requery(self):
        """Alias for Requery"""
        return self.Requery()

    def SetFocus(self):
        return self.com_object.SetFocus()

    def setfocus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def set_focus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()


class TabControl:

    def __init__(self, tabcontrol=None):
        self.com_object= tabcontrol

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BackShade(self):
        return self.com_object.BackShade

    @BackShade.setter
    def BackShade(self, value):
        self.com_object.BackShade = value

    @property
    def backshade(self):
        """Alias for BackShade"""
        return self.BackShade

    @backshade.setter
    def backshade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def back_shade(self):
        """Alias for BackShade"""
        return self.BackShade

    @back_shade.setter
    def back_shade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def BackStyle(self):
        return self.com_object.BackStyle

    @BackStyle.setter
    def BackStyle(self, value):
        self.com_object.BackStyle = value

    @property
    def backstyle(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @backstyle.setter
    def backstyle(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def back_style(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @back_style.setter
    def back_style(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def BackThemeColorIndex(self):
        return self.com_object.BackThemeColorIndex

    @BackThemeColorIndex.setter
    def BackThemeColorIndex(self, value):
        self.com_object.BackThemeColorIndex = value

    @property
    def backthemecolorindex(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @backthemecolorindex.setter
    def backthemecolorindex(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def back_theme_color_index(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @back_theme_color_index.setter
    def back_theme_color_index(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def BackTint(self):
        return self.com_object.BackTint

    @BackTint.setter
    def BackTint(self, value):
        self.com_object.BackTint = value

    @property
    def backtint(self):
        """Alias for BackTint"""
        return self.BackTint

    @backtint.setter
    def backtint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def back_tint(self):
        """Alias for BackTint"""
        return self.BackTint

    @back_tint.setter
    def back_tint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def BorderColor(self):
        return self.com_object.BorderColor

    @BorderColor.setter
    def BorderColor(self, value):
        self.com_object.BorderColor = value

    @property
    def bordercolor(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @bordercolor.setter
    def bordercolor(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def border_color(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @border_color.setter
    def border_color(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def BorderShade(self):
        return self.com_object.BorderShade

    @BorderShade.setter
    def BorderShade(self, value):
        self.com_object.BorderShade = value

    @property
    def bordershade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @bordershade.setter
    def bordershade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def border_shade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @border_shade.setter
    def border_shade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def BorderStyle(self):
        return self.com_object.BorderStyle

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def BorderThemeColorIndex(self):
        return self.com_object.BorderThemeColorIndex

    @BorderThemeColorIndex.setter
    def BorderThemeColorIndex(self, value):
        self.com_object.BorderThemeColorIndex = value

    @property
    def borderthemecolorindex(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @borderthemecolorindex.setter
    def borderthemecolorindex(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def border_theme_color_index(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @border_theme_color_index.setter
    def border_theme_color_index(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def BorderTint(self):
        return self.com_object.BorderTint

    @BorderTint.setter
    def BorderTint(self, value):
        self.com_object.BorderTint = value

    @property
    def bordertint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @bordertint.setter
    def bordertint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def border_tint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @border_tint.setter
    def border_tint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def BottomPadding(self):
        return self.com_object.BottomPadding

    @BottomPadding.setter
    def BottomPadding(self, value):
        self.com_object.BottomPadding = value

    @property
    def bottompadding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottompadding.setter
    def bottompadding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def bottom_padding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottom_padding.setter
    def bottom_padding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def ControlType(self):
        return self.com_object.ControlType

    @ControlType.setter
    def ControlType(self, value):
        self.com_object.ControlType = value

    @property
    def controltype(self):
        """Alias for ControlType"""
        return self.ControlType

    @controltype.setter
    def controltype(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def control_type(self):
        """Alias for ControlType"""
        return self.ControlType

    @control_type.setter
    def control_type(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def DisplayWhen(self):
        return self.com_object.DisplayWhen

    @DisplayWhen.setter
    def DisplayWhen(self, value):
        self.com_object.DisplayWhen = value

    @property
    def displaywhen(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @displaywhen.setter
    def displaywhen(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def display_when(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @display_when.setter
    def display_when(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def FontBold(self):
        return self.com_object.FontBold

    @property
    def fontbold(self):
        """Alias for FontBold"""
        return self.FontBold

    @property
    def font_bold(self):
        """Alias for FontBold"""
        return self.FontBold

    @property
    def FontItalic(self):
        return self.com_object.FontItalic

    @property
    def fontitalic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @property
    def font_italic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @property
    def FontName(self):
        return self.com_object.FontName

    @property
    def fontname(self):
        """Alias for FontName"""
        return self.FontName

    @property
    def font_name(self):
        """Alias for FontName"""
        return self.FontName

    @property
    def FontSize(self):
        return self.com_object.FontSize

    @property
    def fontsize(self):
        """Alias for FontSize"""
        return self.FontSize

    @property
    def font_size(self):
        """Alias for FontSize"""
        return self.FontSize

    @property
    def FontUnderline(self):
        return self.com_object.FontUnderline

    @property
    def fontunderline(self):
        """Alias for FontUnderline"""
        return self.FontUnderline

    @property
    def font_underline(self):
        """Alias for FontUnderline"""
        return self.FontUnderline

    @property
    def FontWeight(self):
        return self.com_object.FontWeight

    @FontWeight.setter
    def FontWeight(self, value):
        self.com_object.FontWeight = value

    @property
    def fontweight(self):
        """Alias for FontWeight"""
        return self.FontWeight

    @fontweight.setter
    def fontweight(self, value):
        """Alias for FontWeight.setter"""
        self.FontWeight = value

    @property
    def font_weight(self):
        """Alias for FontWeight"""
        return self.FontWeight

    @font_weight.setter
    def font_weight(self, value):
        """Alias for FontWeight.setter"""
        self.FontWeight = value

    @property
    def ForeColor(self):
        return self.com_object.ForeColor

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def ForeShade(self):
        return self.com_object.ForeShade

    @ForeShade.setter
    def ForeShade(self, value):
        self.com_object.ForeShade = value

    @property
    def foreshade(self):
        """Alias for ForeShade"""
        return self.ForeShade

    @foreshade.setter
    def foreshade(self, value):
        """Alias for ForeShade.setter"""
        self.ForeShade = value

    @property
    def fore_shade(self):
        """Alias for ForeShade"""
        return self.ForeShade

    @fore_shade.setter
    def fore_shade(self, value):
        """Alias for ForeShade.setter"""
        self.ForeShade = value

    @property
    def ForeThemeColorIndex(self):
        return self.com_object.ForeThemeColorIndex

    @ForeThemeColorIndex.setter
    def ForeThemeColorIndex(self, value):
        self.com_object.ForeThemeColorIndex = value

    @property
    def forethemecolorindex(self):
        """Alias for ForeThemeColorIndex"""
        return self.ForeThemeColorIndex

    @forethemecolorindex.setter
    def forethemecolorindex(self, value):
        """Alias for ForeThemeColorIndex.setter"""
        self.ForeThemeColorIndex = value

    @property
    def fore_theme_color_index(self):
        """Alias for ForeThemeColorIndex"""
        return self.ForeThemeColorIndex

    @fore_theme_color_index.setter
    def fore_theme_color_index(self, value):
        """Alias for ForeThemeColorIndex.setter"""
        self.ForeThemeColorIndex = value

    @property
    def ForeTint(self):
        return self.com_object.ForeTint

    @ForeTint.setter
    def ForeTint(self, value):
        self.com_object.ForeTint = value

    @property
    def foretint(self):
        """Alias for ForeTint"""
        return self.ForeTint

    @foretint.setter
    def foretint(self, value):
        """Alias for ForeTint.setter"""
        self.ForeTint = value

    @property
    def fore_tint(self):
        """Alias for ForeTint"""
        return self.ForeTint

    @fore_tint.setter
    def fore_tint(self, value):
        """Alias for ForeTint.setter"""
        self.ForeTint = value

    @property
    def Gradient(self):
        return self.com_object.Gradient

    @Gradient.setter
    def Gradient(self, value):
        self.com_object.Gradient = value

    @property
    def gradient(self):
        """Alias for Gradient"""
        return self.Gradient

    @gradient.setter
    def gradient(self, value):
        """Alias for Gradient.setter"""
        self.Gradient = value

    @property
    def GridlineColor(self):
        return self.com_object.GridlineColor

    @GridlineColor.setter
    def GridlineColor(self, value):
        self.com_object.GridlineColor = value

    @property
    def gridlinecolor(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridlinecolor.setter
    def gridlinecolor(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def gridline_color(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridline_color.setter
    def gridline_color(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def GridlineShade(self):
        return self.com_object.GridlineShade

    @GridlineShade.setter
    def GridlineShade(self, value):
        self.com_object.GridlineShade = value

    @property
    def gridlineshade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridlineshade.setter
    def gridlineshade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def gridline_shade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridline_shade.setter
    def gridline_shade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def GridlineStyleBottom(self):
        return self.com_object.GridlineStyleBottom

    @GridlineStyleBottom.setter
    def GridlineStyleBottom(self, value):
        self.com_object.GridlineStyleBottom = value

    @property
    def gridlinestylebottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridlinestylebottom.setter
    def gridlinestylebottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def gridline_style_bottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridline_style_bottom.setter
    def gridline_style_bottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def GridlineStyleLeft(self):
        return self.com_object.GridlineStyleLeft

    @GridlineStyleLeft.setter
    def GridlineStyleLeft(self, value):
        self.com_object.GridlineStyleLeft = value

    @property
    def gridlinestyleleft(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridlinestyleleft.setter
    def gridlinestyleleft(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def gridline_style_left(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridline_style_left.setter
    def gridline_style_left(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def GridlineStyleRight(self):
        return self.com_object.GridlineStyleRight

    @GridlineStyleRight.setter
    def GridlineStyleRight(self, value):
        self.com_object.GridlineStyleRight = value

    @property
    def gridlinestyleright(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridlinestyleright.setter
    def gridlinestyleright(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def gridline_style_right(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridline_style_right.setter
    def gridline_style_right(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def GridlineStyleTop(self):
        return self.com_object.GridlineStyleTop

    @GridlineStyleTop.setter
    def GridlineStyleTop(self, value):
        self.com_object.GridlineStyleTop = value

    @property
    def gridlinestyletop(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridlinestyletop.setter
    def gridlinestyletop(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def gridline_style_top(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridline_style_top.setter
    def gridline_style_top(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def GridlineThemeColorIndex(self):
        return self.com_object.GridlineThemeColorIndex

    @GridlineThemeColorIndex.setter
    def GridlineThemeColorIndex(self, value):
        self.com_object.GridlineThemeColorIndex = value

    @property
    def gridlinethemecolorindex(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridlinethemecolorindex.setter
    def gridlinethemecolorindex(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def gridline_theme_color_index(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridline_theme_color_index.setter
    def gridline_theme_color_index(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def GridlineTint(self):
        return self.com_object.GridlineTint

    @GridlineTint.setter
    def GridlineTint(self, value):
        self.com_object.GridlineTint = value

    @property
    def gridlinetint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridlinetint.setter
    def gridlinetint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def gridline_tint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridline_tint.setter
    def gridline_tint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def GridlineWidthBottom(self):
        return self.com_object.GridlineWidthBottom

    @GridlineWidthBottom.setter
    def GridlineWidthBottom(self, value):
        self.com_object.GridlineWidthBottom = value

    @property
    def gridlinewidthbottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridlinewidthbottom.setter
    def gridlinewidthbottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def gridline_width_bottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridline_width_bottom.setter
    def gridline_width_bottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def GridlineWidthLeft(self):
        return self.com_object.GridlineWidthLeft

    @GridlineWidthLeft.setter
    def GridlineWidthLeft(self, value):
        self.com_object.GridlineWidthLeft = value

    @property
    def gridlinewidthleft(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridlinewidthleft.setter
    def gridlinewidthleft(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def gridline_width_left(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridline_width_left.setter
    def gridline_width_left(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def GridlineWidthRight(self):
        return self.com_object.GridlineWidthRight

    @GridlineWidthRight.setter
    def GridlineWidthRight(self, value):
        self.com_object.GridlineWidthRight = value

    @property
    def gridlinewidthright(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridlinewidthright.setter
    def gridlinewidthright(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def gridline_width_right(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridline_width_right.setter
    def gridline_width_right(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def GridlineWidthTop(self):
        return self.com_object.GridlineWidthTop

    @GridlineWidthTop.setter
    def GridlineWidthTop(self, value):
        self.com_object.GridlineWidthTop = value

    @property
    def gridlinewidthtop(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridlinewidthtop.setter
    def gridlinewidthtop(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def gridline_width_top(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridline_width_top.setter
    def gridline_width_top(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HelpContextId(self):
        return self.com_object.HelpContextId

    @HelpContextId.setter
    def HelpContextId(self, value):
        self.com_object.HelpContextId = value

    @property
    def helpcontextid(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @helpcontextid.setter
    def helpcontextid(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def help_context_id(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @help_context_id.setter
    def help_context_id(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def HoverColor(self):
        return self.com_object.HoverColor

    @HoverColor.setter
    def HoverColor(self, value):
        self.com_object.HoverColor = value

    @property
    def hovercolor(self):
        """Alias for HoverColor"""
        return self.HoverColor

    @hovercolor.setter
    def hovercolor(self, value):
        """Alias for HoverColor.setter"""
        self.HoverColor = value

    @property
    def hover_color(self):
        """Alias for HoverColor"""
        return self.HoverColor

    @hover_color.setter
    def hover_color(self, value):
        """Alias for HoverColor.setter"""
        self.HoverColor = value

    @property
    def HoverForeColor(self):
        return self.com_object.HoverForeColor

    @HoverForeColor.setter
    def HoverForeColor(self, value):
        self.com_object.HoverForeColor = value

    @property
    def hoverforecolor(self):
        """Alias for HoverForeColor"""
        return self.HoverForeColor

    @hoverforecolor.setter
    def hoverforecolor(self, value):
        """Alias for HoverForeColor.setter"""
        self.HoverForeColor = value

    @property
    def hover_fore_color(self):
        """Alias for HoverForeColor"""
        return self.HoverForeColor

    @hover_fore_color.setter
    def hover_fore_color(self, value):
        """Alias for HoverForeColor.setter"""
        self.HoverForeColor = value

    @property
    def HoverForeShade(self):
        return self.com_object.HoverForeShade

    @HoverForeShade.setter
    def HoverForeShade(self, value):
        self.com_object.HoverForeShade = value

    @property
    def hoverforeshade(self):
        """Alias for HoverForeShade"""
        return self.HoverForeShade

    @hoverforeshade.setter
    def hoverforeshade(self, value):
        """Alias for HoverForeShade.setter"""
        self.HoverForeShade = value

    @property
    def hover_fore_shade(self):
        """Alias for HoverForeShade"""
        return self.HoverForeShade

    @hover_fore_shade.setter
    def hover_fore_shade(self, value):
        """Alias for HoverForeShade.setter"""
        self.HoverForeShade = value

    @property
    def HoverForeThemeColorIndex(self):
        return self.com_object.HoverForeThemeColorIndex

    @HoverForeThemeColorIndex.setter
    def HoverForeThemeColorIndex(self, value):
        self.com_object.HoverForeThemeColorIndex = value

    @property
    def hoverforethemecolorindex(self):
        """Alias for HoverForeThemeColorIndex"""
        return self.HoverForeThemeColorIndex

    @hoverforethemecolorindex.setter
    def hoverforethemecolorindex(self, value):
        """Alias for HoverForeThemeColorIndex.setter"""
        self.HoverForeThemeColorIndex = value

    @property
    def hover_fore_theme_color_index(self):
        """Alias for HoverForeThemeColorIndex"""
        return self.HoverForeThemeColorIndex

    @hover_fore_theme_color_index.setter
    def hover_fore_theme_color_index(self, value):
        """Alias for HoverForeThemeColorIndex.setter"""
        self.HoverForeThemeColorIndex = value

    @property
    def HoverForeTint(self):
        return self.com_object.HoverForeTint

    @HoverForeTint.setter
    def HoverForeTint(self, value):
        self.com_object.HoverForeTint = value

    @property
    def hoverforetint(self):
        """Alias for HoverForeTint"""
        return self.HoverForeTint

    @hoverforetint.setter
    def hoverforetint(self, value):
        """Alias for HoverForeTint.setter"""
        self.HoverForeTint = value

    @property
    def hover_fore_tint(self):
        """Alias for HoverForeTint"""
        return self.HoverForeTint

    @hover_fore_tint.setter
    def hover_fore_tint(self, value):
        """Alias for HoverForeTint.setter"""
        self.HoverForeTint = value

    @property
    def HoverShade(self):
        return self.com_object.HoverShade

    @HoverShade.setter
    def HoverShade(self, value):
        self.com_object.HoverShade = value

    @property
    def hovershade(self):
        """Alias for HoverShade"""
        return self.HoverShade

    @hovershade.setter
    def hovershade(self, value):
        """Alias for HoverShade.setter"""
        self.HoverShade = value

    @property
    def hover_shade(self):
        """Alias for HoverShade"""
        return self.HoverShade

    @hover_shade.setter
    def hover_shade(self, value):
        """Alias for HoverShade.setter"""
        self.HoverShade = value

    @property
    def HoverThemeColorIndex(self):
        return self.com_object.HoverThemeColorIndex

    @HoverThemeColorIndex.setter
    def HoverThemeColorIndex(self, value):
        self.com_object.HoverThemeColorIndex = value

    @property
    def hoverthemecolorindex(self):
        """Alias for HoverThemeColorIndex"""
        return self.HoverThemeColorIndex

    @hoverthemecolorindex.setter
    def hoverthemecolorindex(self, value):
        """Alias for HoverThemeColorIndex.setter"""
        self.HoverThemeColorIndex = value

    @property
    def hover_theme_color_index(self):
        """Alias for HoverThemeColorIndex"""
        return self.HoverThemeColorIndex

    @hover_theme_color_index.setter
    def hover_theme_color_index(self, value):
        """Alias for HoverThemeColorIndex.setter"""
        self.HoverThemeColorIndex = value

    @property
    def HoverTint(self):
        return self.com_object.HoverTint

    @HoverTint.setter
    def HoverTint(self, value):
        self.com_object.HoverTint = value

    @property
    def hovertint(self):
        """Alias for HoverTint"""
        return self.HoverTint

    @hovertint.setter
    def hovertint(self, value):
        """Alias for HoverTint.setter"""
        self.HoverTint = value

    @property
    def hover_tint(self):
        """Alias for HoverTint"""
        return self.HoverTint

    @hover_tint.setter
    def hover_tint(self, value):
        """Alias for HoverTint.setter"""
        self.HoverTint = value

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def IsVisible(self):
        return self.com_object.IsVisible

    @IsVisible.setter
    def IsVisible(self, value):
        self.com_object.IsVisible = value

    @property
    def isvisible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @isvisible.setter
    def isvisible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def is_visible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @is_visible.setter
    def is_visible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def Layout(self):
        return AcLayoutType(self.com_object.Layout)

    @property
    def layout(self):
        """Alias for Layout"""
        return self.Layout

    @property
    def LayoutID(self):
        return self.com_object.LayoutID

    @property
    def layoutid(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def layout_i_d(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def LeftPadding(self):
        return self.com_object.LeftPadding

    @LeftPadding.setter
    def LeftPadding(self, value):
        self.com_object.LeftPadding = value

    @property
    def leftpadding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @leftpadding.setter
    def leftpadding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def left_padding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @left_padding.setter
    def left_padding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def MultiRow(self):
        return self.com_object.MultiRow

    @MultiRow.setter
    def MultiRow(self, value):
        self.com_object.MultiRow = value

    @property
    def multirow(self):
        """Alias for MultiRow"""
        return self.MultiRow

    @multirow.setter
    def multirow(self, value):
        """Alias for MultiRow.setter"""
        self.MultiRow = value

    @property
    def multi_row(self):
        """Alias for MultiRow"""
        return self.MultiRow

    @multi_row.setter
    def multi_row(self, value):
        """Alias for MultiRow.setter"""
        self.MultiRow = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def OldValue(self):
        return self.com_object.OldValue

    @property
    def oldvalue(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def old_value(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def OnChange(self):
        return self.com_object.OnChange

    @OnChange.setter
    def OnChange(self, value):
        self.com_object.OnChange = value

    @property
    def onchange(self):
        """Alias for OnChange"""
        return self.OnChange

    @onchange.setter
    def onchange(self, value):
        """Alias for OnChange.setter"""
        self.OnChange = value

    @property
    def on_change(self):
        """Alias for OnChange"""
        return self.OnChange

    @on_change.setter
    def on_change(self, value):
        """Alias for OnChange.setter"""
        self.OnChange = value

    @property
    def OnClick(self):
        return self.com_object.OnClick

    @OnClick.setter
    def OnClick(self, value):
        self.com_object.OnClick = value

    @property
    def onclick(self):
        """Alias for OnClick"""
        return self.OnClick

    @onclick.setter
    def onclick(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def on_click(self):
        """Alias for OnClick"""
        return self.OnClick

    @on_click.setter
    def on_click(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def OnDblClick(self):
        return self.com_object.OnDblClick

    @OnDblClick.setter
    def OnDblClick(self, value):
        self.com_object.OnDblClick = value

    @property
    def ondblclick(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @ondblclick.setter
    def ondblclick(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def on_dbl_click(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @on_dbl_click.setter
    def on_dbl_click(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def OnKeyDown(self):
        return self.com_object.OnKeyDown

    @OnKeyDown.setter
    def OnKeyDown(self, value):
        self.com_object.OnKeyDown = value

    @property
    def onkeydown(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @onkeydown.setter
    def onkeydown(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def on_key_down(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @on_key_down.setter
    def on_key_down(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def OnKeyPress(self):
        return self.com_object.OnKeyPress

    @OnKeyPress.setter
    def OnKeyPress(self, value):
        self.com_object.OnKeyPress = value

    @property
    def onkeypress(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @onkeypress.setter
    def onkeypress(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def on_key_press(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @on_key_press.setter
    def on_key_press(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def OnKeyUp(self):
        return self.com_object.OnKeyUp

    @OnKeyUp.setter
    def OnKeyUp(self, value):
        self.com_object.OnKeyUp = value

    @property
    def onkeyup(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @onkeyup.setter
    def onkeyup(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def on_key_up(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @on_key_up.setter
    def on_key_up(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def OnMouseDown(self):
        return self.com_object.OnMouseDown

    @OnMouseDown.setter
    def OnMouseDown(self, value):
        self.com_object.OnMouseDown = value

    @property
    def onmousedown(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @onmousedown.setter
    def onmousedown(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def on_mouse_down(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @on_mouse_down.setter
    def on_mouse_down(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def OnMouseMove(self):
        return self.com_object.OnMouseMove

    @OnMouseMove.setter
    def OnMouseMove(self, value):
        self.com_object.OnMouseMove = value

    @property
    def onmousemove(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @onmousemove.setter
    def onmousemove(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def on_mouse_move(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @on_mouse_move.setter
    def on_mouse_move(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def OnMouseUp(self):
        return self.com_object.OnMouseUp

    @OnMouseUp.setter
    def OnMouseUp(self, value):
        self.com_object.OnMouseUp = value

    @property
    def onmouseup(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @onmouseup.setter
    def onmouseup(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def on_mouse_up(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @on_mouse_up.setter
    def on_mouse_up(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def Pages(self):
        return Pages(self.com_object.Pages)

    @property
    def pages(self):
        """Alias for Pages"""
        return self.Pages

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PressedColor(self):
        return self.com_object.PressedColor

    @PressedColor.setter
    def PressedColor(self, value):
        self.com_object.PressedColor = value

    @property
    def pressedcolor(self):
        """Alias for PressedColor"""
        return self.PressedColor

    @pressedcolor.setter
    def pressedcolor(self, value):
        """Alias for PressedColor.setter"""
        self.PressedColor = value

    @property
    def pressed_color(self):
        """Alias for PressedColor"""
        return self.PressedColor

    @pressed_color.setter
    def pressed_color(self, value):
        """Alias for PressedColor.setter"""
        self.PressedColor = value

    @property
    def PressedForeColor(self):
        return self.com_object.PressedForeColor

    @PressedForeColor.setter
    def PressedForeColor(self, value):
        self.com_object.PressedForeColor = value

    @property
    def pressedforecolor(self):
        """Alias for PressedForeColor"""
        return self.PressedForeColor

    @pressedforecolor.setter
    def pressedforecolor(self, value):
        """Alias for PressedForeColor.setter"""
        self.PressedForeColor = value

    @property
    def pressed_fore_color(self):
        """Alias for PressedForeColor"""
        return self.PressedForeColor

    @pressed_fore_color.setter
    def pressed_fore_color(self, value):
        """Alias for PressedForeColor.setter"""
        self.PressedForeColor = value

    @property
    def PressedForeShade(self):
        return self.com_object.PressedForeShade

    @PressedForeShade.setter
    def PressedForeShade(self, value):
        self.com_object.PressedForeShade = value

    @property
    def pressedforeshade(self):
        """Alias for PressedForeShade"""
        return self.PressedForeShade

    @pressedforeshade.setter
    def pressedforeshade(self, value):
        """Alias for PressedForeShade.setter"""
        self.PressedForeShade = value

    @property
    def pressed_fore_shade(self):
        """Alias for PressedForeShade"""
        return self.PressedForeShade

    @pressed_fore_shade.setter
    def pressed_fore_shade(self, value):
        """Alias for PressedForeShade.setter"""
        self.PressedForeShade = value

    @property
    def PressedForeThemeColorIndex(self):
        return self.com_object.PressedForeThemeColorIndex

    @PressedForeThemeColorIndex.setter
    def PressedForeThemeColorIndex(self, value):
        self.com_object.PressedForeThemeColorIndex = value

    @property
    def pressedforethemecolorindex(self):
        """Alias for PressedForeThemeColorIndex"""
        return self.PressedForeThemeColorIndex

    @pressedforethemecolorindex.setter
    def pressedforethemecolorindex(self, value):
        """Alias for PressedForeThemeColorIndex.setter"""
        self.PressedForeThemeColorIndex = value

    @property
    def pressed_fore_theme_color_index(self):
        """Alias for PressedForeThemeColorIndex"""
        return self.PressedForeThemeColorIndex

    @pressed_fore_theme_color_index.setter
    def pressed_fore_theme_color_index(self, value):
        """Alias for PressedForeThemeColorIndex.setter"""
        self.PressedForeThemeColorIndex = value

    @property
    def PressedForeTint(self):
        return self.com_object.PressedForeTint

    @PressedForeTint.setter
    def PressedForeTint(self, value):
        self.com_object.PressedForeTint = value

    @property
    def pressedforetint(self):
        """Alias for PressedForeTint"""
        return self.PressedForeTint

    @pressedforetint.setter
    def pressedforetint(self, value):
        """Alias for PressedForeTint.setter"""
        self.PressedForeTint = value

    @property
    def pressed_fore_tint(self):
        """Alias for PressedForeTint"""
        return self.PressedForeTint

    @pressed_fore_tint.setter
    def pressed_fore_tint(self, value):
        """Alias for PressedForeTint.setter"""
        self.PressedForeTint = value

    @property
    def PressedShade(self):
        return self.com_object.PressedShade

    @PressedShade.setter
    def PressedShade(self, value):
        self.com_object.PressedShade = value

    @property
    def pressedshade(self):
        """Alias for PressedShade"""
        return self.PressedShade

    @pressedshade.setter
    def pressedshade(self, value):
        """Alias for PressedShade.setter"""
        self.PressedShade = value

    @property
    def pressed_shade(self):
        """Alias for PressedShade"""
        return self.PressedShade

    @pressed_shade.setter
    def pressed_shade(self, value):
        """Alias for PressedShade.setter"""
        self.PressedShade = value

    @property
    def PressedThemeColorIndex(self):
        return self.com_object.PressedThemeColorIndex

    @PressedThemeColorIndex.setter
    def PressedThemeColorIndex(self, value):
        self.com_object.PressedThemeColorIndex = value

    @property
    def pressedthemecolorindex(self):
        """Alias for PressedThemeColorIndex"""
        return self.PressedThemeColorIndex

    @pressedthemecolorindex.setter
    def pressedthemecolorindex(self, value):
        """Alias for PressedThemeColorIndex.setter"""
        self.PressedThemeColorIndex = value

    @property
    def pressed_theme_color_index(self):
        """Alias for PressedThemeColorIndex"""
        return self.PressedThemeColorIndex

    @pressed_theme_color_index.setter
    def pressed_theme_color_index(self, value):
        """Alias for PressedThemeColorIndex.setter"""
        self.PressedThemeColorIndex = value

    @property
    def PressedTint(self):
        return self.com_object.PressedTint

    @PressedTint.setter
    def PressedTint(self, value):
        self.com_object.PressedTint = value

    @property
    def pressedtint(self):
        """Alias for PressedTint"""
        return self.PressedTint

    @pressedtint.setter
    def pressedtint(self, value):
        """Alias for PressedTint.setter"""
        self.PressedTint = value

    @property
    def pressed_tint(self):
        """Alias for PressedTint"""
        return self.PressedTint

    @pressed_tint.setter
    def pressed_tint(self, value):
        """Alias for PressedTint.setter"""
        self.PressedTint = value

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def RightPadding(self):
        return self.com_object.RightPadding

    @RightPadding.setter
    def RightPadding(self, value):
        self.com_object.RightPadding = value

    @property
    def rightpadding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @rightpadding.setter
    def rightpadding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def right_padding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @right_padding.setter
    def right_padding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def Section(self):
        return self.com_object.Section

    @Section.setter
    def Section(self, value):
        self.com_object.Section = value

    @property
    def section(self):
        """Alias for Section"""
        return self.Section

    @section.setter
    def section(self, value):
        """Alias for Section.setter"""
        self.Section = value

    @property
    def Shape(self):
        return self.com_object.Shape

    @Shape.setter
    def Shape(self, value):
        self.com_object.Shape = value

    @property
    def shape(self):
        """Alias for Shape"""
        return self.Shape

    @shape.setter
    def shape(self, value):
        """Alias for Shape.setter"""
        self.Shape = value

    @property
    def ShortcutMenuBar(self):
        return self.com_object.ShortcutMenuBar

    @ShortcutMenuBar.setter
    def ShortcutMenuBar(self, value):
        self.com_object.ShortcutMenuBar = value

    @property
    def shortcutmenubar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcutmenubar.setter
    def shortcutmenubar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def shortcut_menu_bar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcut_menu_bar.setter
    def shortcut_menu_bar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def StatusBarText(self):
        return self.com_object.StatusBarText

    @StatusBarText.setter
    def StatusBarText(self, value):
        self.com_object.StatusBarText = value

    @property
    def statusbartext(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @statusbartext.setter
    def statusbartext(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def status_bar_text(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @status_bar_text.setter
    def status_bar_text(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def Style(self):
        return self.com_object.Style

    @Style.setter
    def Style(self, value):
        self.com_object.Style = value

    @property
    def style(self):
        """Alias for Style"""
        return self.Style

    @style.setter
    def style(self, value):
        """Alias for Style.setter"""
        self.Style = value

    @property
    def TabFixedHeight(self):
        return self.com_object.TabFixedHeight

    @TabFixedHeight.setter
    def TabFixedHeight(self, value):
        self.com_object.TabFixedHeight = value

    @property
    def tabfixedheight(self):
        """Alias for TabFixedHeight"""
        return self.TabFixedHeight

    @tabfixedheight.setter
    def tabfixedheight(self, value):
        """Alias for TabFixedHeight.setter"""
        self.TabFixedHeight = value

    @property
    def tab_fixed_height(self):
        """Alias for TabFixedHeight"""
        return self.TabFixedHeight

    @tab_fixed_height.setter
    def tab_fixed_height(self, value):
        """Alias for TabFixedHeight.setter"""
        self.TabFixedHeight = value

    @property
    def TabFixedWidth(self):
        return self.com_object.TabFixedWidth

    @TabFixedWidth.setter
    def TabFixedWidth(self, value):
        self.com_object.TabFixedWidth = value

    @property
    def tabfixedwidth(self):
        """Alias for TabFixedWidth"""
        return self.TabFixedWidth

    @tabfixedwidth.setter
    def tabfixedwidth(self, value):
        """Alias for TabFixedWidth.setter"""
        self.TabFixedWidth = value

    @property
    def tab_fixed_width(self):
        """Alias for TabFixedWidth"""
        return self.TabFixedWidth

    @tab_fixed_width.setter
    def tab_fixed_width(self, value):
        """Alias for TabFixedWidth.setter"""
        self.TabFixedWidth = value

    @property
    def TabIndex(self):
        return self.com_object.TabIndex

    @TabIndex.setter
    def TabIndex(self, value):
        self.com_object.TabIndex = value

    @property
    def tabindex(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tabindex.setter
    def tabindex(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def tab_index(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tab_index.setter
    def tab_index(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def TabStop(self):
        return self.com_object.TabStop

    @TabStop.setter
    def TabStop(self, value):
        self.com_object.TabStop = value

    @property
    def tabstop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tabstop.setter
    def tabstop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def tab_stop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tab_stop.setter
    def tab_stop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def ThemeFontIndex(self):
        return self.com_object.ThemeFontIndex

    @ThemeFontIndex.setter
    def ThemeFontIndex(self, value):
        self.com_object.ThemeFontIndex = value

    @property
    def themefontindex(self):
        """Alias for ThemeFontIndex"""
        return self.ThemeFontIndex

    @themefontindex.setter
    def themefontindex(self, value):
        """Alias for ThemeFontIndex.setter"""
        self.ThemeFontIndex = value

    @property
    def theme_font_index(self):
        """Alias for ThemeFontIndex"""
        return self.ThemeFontIndex

    @theme_font_index.setter
    def theme_font_index(self, value):
        """Alias for ThemeFontIndex.setter"""
        self.ThemeFontIndex = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TopPadding(self):
        return self.com_object.TopPadding

    @TopPadding.setter
    def TopPadding(self, value):
        self.com_object.TopPadding = value

    @property
    def toppadding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @toppadding.setter
    def toppadding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def top_padding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @top_padding.setter
    def top_padding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def UseTheme(self):
        return self.com_object.UseTheme

    @UseTheme.setter
    def UseTheme(self, value):
        self.com_object.UseTheme = value

    @property
    def usetheme(self):
        """Alias for UseTheme"""
        return self.UseTheme

    @usetheme.setter
    def usetheme(self, value):
        """Alias for UseTheme.setter"""
        self.UseTheme = value

    @property
    def use_theme(self):
        """Alias for UseTheme"""
        return self.UseTheme

    @use_theme.setter
    def use_theme(self, value):
        """Alias for UseTheme.setter"""
        self.UseTheme = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()


class TempVar:

    def __init__(self, tempvar=None):
        self.com_object= tempvar

    @property
    def Name(self):
        return self.com_object.Name

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value


class TempVars:

    def __init__(self, tempvars=None):
        self.com_object= tempvars

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    def Add(self, Name=None, Value=None):
        arguments = com_arguments([unwrap(a) for a in [Name, Value]])
        self.com_object.Add(*arguments)

    def add(self, Name=None, Value=None):
        """Alias for Add"""
        arguments = [Name, Value]
        return self.Add(*arguments)

    def Remove(self, var=None):
        arguments = com_arguments([unwrap(a) for a in [var]])
        self.com_object.Remove(*arguments)

    def remove(self, var=None):
        """Alias for Remove"""
        arguments = [var]
        return self.Remove(*arguments)

    def RemoveAll(self):
        self.com_object.RemoveAll()

    def removeall(self):
        """Alias for RemoveAll"""
        return self.RemoveAll()

    def remove_all(self):
        """Alias for RemoveAll"""
        return self.RemoveAll()


class TextBox:

    def __init__(self, textbox=None):
        self.com_object= textbox

    @property
    def AddColon(self):
        return self.com_object.AddColon

    @AddColon.setter
    def AddColon(self, value):
        self.com_object.AddColon = value

    @property
    def addcolon(self):
        """Alias for AddColon"""
        return self.AddColon

    @addcolon.setter
    def addcolon(self, value):
        """Alias for AddColon.setter"""
        self.AddColon = value

    @property
    def add_colon(self):
        """Alias for AddColon"""
        return self.AddColon

    @add_colon.setter
    def add_colon(self, value):
        """Alias for AddColon.setter"""
        self.AddColon = value

    @property
    def AllowAutoCorrect(self):
        return self.com_object.AllowAutoCorrect

    @AllowAutoCorrect.setter
    def AllowAutoCorrect(self, value):
        self.com_object.AllowAutoCorrect = value

    @property
    def allowautocorrect(self):
        """Alias for AllowAutoCorrect"""
        return self.AllowAutoCorrect

    @allowautocorrect.setter
    def allowautocorrect(self, value):
        """Alias for AllowAutoCorrect.setter"""
        self.AllowAutoCorrect = value

    @property
    def allow_auto_correct(self):
        """Alias for AllowAutoCorrect"""
        return self.AllowAutoCorrect

    @allow_auto_correct.setter
    def allow_auto_correct(self, value):
        """Alias for AllowAutoCorrect.setter"""
        self.AllowAutoCorrect = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AsianLineBreak(self):
        return self.com_object.AsianLineBreak

    @AsianLineBreak.setter
    def AsianLineBreak(self, value):
        self.com_object.AsianLineBreak = value

    @property
    def asianlinebreak(self):
        """Alias for AsianLineBreak"""
        return self.AsianLineBreak

    @asianlinebreak.setter
    def asianlinebreak(self, value):
        """Alias for AsianLineBreak.setter"""
        self.AsianLineBreak = value

    @property
    def asian_line_break(self):
        """Alias for AsianLineBreak"""
        return self.AsianLineBreak

    @asian_line_break.setter
    def asian_line_break(self, value):
        """Alias for AsianLineBreak.setter"""
        self.AsianLineBreak = value

    @property
    def AutoLabel(self):
        return self.com_object.AutoLabel

    @AutoLabel.setter
    def AutoLabel(self, value):
        self.com_object.AutoLabel = value

    @property
    def autolabel(self):
        """Alias for AutoLabel"""
        return self.AutoLabel

    @autolabel.setter
    def autolabel(self, value):
        """Alias for AutoLabel.setter"""
        self.AutoLabel = value

    @property
    def auto_label(self):
        """Alias for AutoLabel"""
        return self.AutoLabel

    @auto_label.setter
    def auto_label(self, value):
        """Alias for AutoLabel.setter"""
        self.AutoLabel = value

    @property
    def AutoTab(self):
        return self.com_object.AutoTab

    @AutoTab.setter
    def AutoTab(self, value):
        self.com_object.AutoTab = value

    @property
    def autotab(self):
        """Alias for AutoTab"""
        return self.AutoTab

    @autotab.setter
    def autotab(self, value):
        """Alias for AutoTab.setter"""
        self.AutoTab = value

    @property
    def auto_tab(self):
        """Alias for AutoTab"""
        return self.AutoTab

    @auto_tab.setter
    def auto_tab(self, value):
        """Alias for AutoTab.setter"""
        self.AutoTab = value

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BackShade(self):
        return self.com_object.BackShade

    @BackShade.setter
    def BackShade(self, value):
        self.com_object.BackShade = value

    @property
    def backshade(self):
        """Alias for BackShade"""
        return self.BackShade

    @backshade.setter
    def backshade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def back_shade(self):
        """Alias for BackShade"""
        return self.BackShade

    @back_shade.setter
    def back_shade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def BackStyle(self):
        return self.com_object.BackStyle

    @BackStyle.setter
    def BackStyle(self, value):
        self.com_object.BackStyle = value

    @property
    def backstyle(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @backstyle.setter
    def backstyle(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def back_style(self):
        """Alias for BackStyle"""
        return self.BackStyle

    @back_style.setter
    def back_style(self, value):
        """Alias for BackStyle.setter"""
        self.BackStyle = value

    @property
    def BackThemeColorIndex(self):
        return self.com_object.BackThemeColorIndex

    @BackThemeColorIndex.setter
    def BackThemeColorIndex(self, value):
        self.com_object.BackThemeColorIndex = value

    @property
    def backthemecolorindex(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @backthemecolorindex.setter
    def backthemecolorindex(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def back_theme_color_index(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @back_theme_color_index.setter
    def back_theme_color_index(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def BackTint(self):
        return self.com_object.BackTint

    @BackTint.setter
    def BackTint(self, value):
        self.com_object.BackTint = value

    @property
    def backtint(self):
        """Alias for BackTint"""
        return self.BackTint

    @backtint.setter
    def backtint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def back_tint(self):
        """Alias for BackTint"""
        return self.BackTint

    @back_tint.setter
    def back_tint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def BorderColor(self):
        return self.com_object.BorderColor

    @BorderColor.setter
    def BorderColor(self, value):
        self.com_object.BorderColor = value

    @property
    def bordercolor(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @bordercolor.setter
    def bordercolor(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def border_color(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @border_color.setter
    def border_color(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def BorderShade(self):
        return self.com_object.BorderShade

    @BorderShade.setter
    def BorderShade(self, value):
        self.com_object.BorderShade = value

    @property
    def bordershade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @bordershade.setter
    def bordershade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def border_shade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @border_shade.setter
    def border_shade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def BorderStyle(self):
        return self.com_object.BorderStyle

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def BorderThemeColorIndex(self):
        return self.com_object.BorderThemeColorIndex

    @BorderThemeColorIndex.setter
    def BorderThemeColorIndex(self, value):
        self.com_object.BorderThemeColorIndex = value

    @property
    def borderthemecolorindex(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @borderthemecolorindex.setter
    def borderthemecolorindex(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def border_theme_color_index(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @border_theme_color_index.setter
    def border_theme_color_index(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def BorderTint(self):
        return self.com_object.BorderTint

    @BorderTint.setter
    def BorderTint(self, value):
        self.com_object.BorderTint = value

    @property
    def bordertint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @bordertint.setter
    def bordertint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def border_tint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @border_tint.setter
    def border_tint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def BorderWidth(self):
        return self.com_object.BorderWidth

    @BorderWidth.setter
    def BorderWidth(self, value):
        self.com_object.BorderWidth = value

    @property
    def borderwidth(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @borderwidth.setter
    def borderwidth(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def border_width(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @border_width.setter
    def border_width(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def BottomMargin(self):
        return self.com_object.BottomMargin

    @BottomMargin.setter
    def BottomMargin(self, value):
        self.com_object.BottomMargin = value

    @property
    def bottommargin(self):
        """Alias for BottomMargin"""
        return self.BottomMargin

    @bottommargin.setter
    def bottommargin(self, value):
        """Alias for BottomMargin.setter"""
        self.BottomMargin = value

    @property
    def bottom_margin(self):
        """Alias for BottomMargin"""
        return self.BottomMargin

    @bottom_margin.setter
    def bottom_margin(self, value):
        """Alias for BottomMargin.setter"""
        self.BottomMargin = value

    @property
    def BottomPadding(self):
        return self.com_object.BottomPadding

    @BottomPadding.setter
    def BottomPadding(self, value):
        self.com_object.BottomPadding = value

    @property
    def bottompadding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottompadding.setter
    def bottompadding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def bottom_padding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottom_padding.setter
    def bottom_padding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def CanGrow(self):
        return self.com_object.CanGrow

    @CanGrow.setter
    def CanGrow(self, value):
        self.com_object.CanGrow = value

    @property
    def cangrow(self):
        """Alias for CanGrow"""
        return self.CanGrow

    @cangrow.setter
    def cangrow(self, value):
        """Alias for CanGrow.setter"""
        self.CanGrow = value

    @property
    def can_grow(self):
        """Alias for CanGrow"""
        return self.CanGrow

    @can_grow.setter
    def can_grow(self, value):
        """Alias for CanGrow.setter"""
        self.CanGrow = value

    @property
    def CanShrink(self):
        return self.com_object.CanShrink

    @CanShrink.setter
    def CanShrink(self, value):
        self.com_object.CanShrink = value

    @property
    def canshrink(self):
        """Alias for CanShrink"""
        return self.CanShrink

    @canshrink.setter
    def canshrink(self, value):
        """Alias for CanShrink.setter"""
        self.CanShrink = value

    @property
    def can_shrink(self):
        """Alias for CanShrink"""
        return self.CanShrink

    @can_shrink.setter
    def can_shrink(self, value):
        """Alias for CanShrink.setter"""
        self.CanShrink = value

    @property
    def ColumnHidden(self):
        return self.com_object.ColumnHidden

    @ColumnHidden.setter
    def ColumnHidden(self, value):
        self.com_object.ColumnHidden = value

    @property
    def columnhidden(self):
        """Alias for ColumnHidden"""
        return self.ColumnHidden

    @columnhidden.setter
    def columnhidden(self, value):
        """Alias for ColumnHidden.setter"""
        self.ColumnHidden = value

    @property
    def column_hidden(self):
        """Alias for ColumnHidden"""
        return self.ColumnHidden

    @column_hidden.setter
    def column_hidden(self, value):
        """Alias for ColumnHidden.setter"""
        self.ColumnHidden = value

    @property
    def ColumnOrder(self):
        return self.com_object.ColumnOrder

    @ColumnOrder.setter
    def ColumnOrder(self, value):
        self.com_object.ColumnOrder = value

    @property
    def columnorder(self):
        """Alias for ColumnOrder"""
        return self.ColumnOrder

    @columnorder.setter
    def columnorder(self, value):
        """Alias for ColumnOrder.setter"""
        self.ColumnOrder = value

    @property
    def column_order(self):
        """Alias for ColumnOrder"""
        return self.ColumnOrder

    @column_order.setter
    def column_order(self, value):
        """Alias for ColumnOrder.setter"""
        self.ColumnOrder = value

    @property
    def ColumnWidth(self):
        return self.com_object.ColumnWidth

    @ColumnWidth.setter
    def ColumnWidth(self, value):
        self.com_object.ColumnWidth = value

    @property
    def columnwidth(self):
        """Alias for ColumnWidth"""
        return self.ColumnWidth

    @columnwidth.setter
    def columnwidth(self, value):
        """Alias for ColumnWidth.setter"""
        self.ColumnWidth = value

    @property
    def column_width(self):
        """Alias for ColumnWidth"""
        return self.ColumnWidth

    @column_width.setter
    def column_width(self, value):
        """Alias for ColumnWidth.setter"""
        self.ColumnWidth = value

    @property
    def Controls(self):
        return Controls(self.com_object.Controls)

    @property
    def controls(self):
        """Alias for Controls"""
        return self.Controls

    @property
    def ControlSource(self):
        return self.com_object.ControlSource

    @ControlSource.setter
    def ControlSource(self, value):
        self.com_object.ControlSource = value

    @property
    def controlsource(self):
        """Alias for ControlSource"""
        return self.ControlSource

    @controlsource.setter
    def controlsource(self, value):
        """Alias for ControlSource.setter"""
        self.ControlSource = value

    @property
    def control_source(self):
        """Alias for ControlSource"""
        return self.ControlSource

    @control_source.setter
    def control_source(self, value):
        """Alias for ControlSource.setter"""
        self.ControlSource = value

    @property
    def ControlTipText(self):
        return self.com_object.ControlTipText

    @ControlTipText.setter
    def ControlTipText(self, value):
        self.com_object.ControlTipText = value

    @property
    def controltiptext(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @controltiptext.setter
    def controltiptext(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def control_tip_text(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @control_tip_text.setter
    def control_tip_text(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def ControlType(self):
        return self.com_object.ControlType

    @ControlType.setter
    def ControlType(self, value):
        self.com_object.ControlType = value

    @property
    def controltype(self):
        """Alias for ControlType"""
        return self.ControlType

    @controltype.setter
    def controltype(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def control_type(self):
        """Alias for ControlType"""
        return self.ControlType

    @control_type.setter
    def control_type(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def DecimalPlaces(self):
        return self.com_object.DecimalPlaces

    @DecimalPlaces.setter
    def DecimalPlaces(self, value):
        self.com_object.DecimalPlaces = value

    @property
    def decimalplaces(self):
        """Alias for DecimalPlaces"""
        return self.DecimalPlaces

    @decimalplaces.setter
    def decimalplaces(self, value):
        """Alias for DecimalPlaces.setter"""
        self.DecimalPlaces = value

    @property
    def decimal_places(self):
        """Alias for DecimalPlaces"""
        return self.DecimalPlaces

    @decimal_places.setter
    def decimal_places(self, value):
        """Alias for DecimalPlaces.setter"""
        self.DecimalPlaces = value

    @property
    def DefaultValue(self):
        return self.com_object.DefaultValue

    @DefaultValue.setter
    def DefaultValue(self, value):
        self.com_object.DefaultValue = value

    @property
    def defaultvalue(self):
        """Alias for DefaultValue"""
        return self.DefaultValue

    @defaultvalue.setter
    def defaultvalue(self, value):
        """Alias for DefaultValue.setter"""
        self.DefaultValue = value

    @property
    def default_value(self):
        """Alias for DefaultValue"""
        return self.DefaultValue

    @default_value.setter
    def default_value(self, value):
        """Alias for DefaultValue.setter"""
        self.DefaultValue = value

    @property
    def DisplayAsHyperlink(self):
        return self.com_object.DisplayAsHyperlink

    @DisplayAsHyperlink.setter
    def DisplayAsHyperlink(self, value):
        self.com_object.DisplayAsHyperlink = value

    @property
    def displayashyperlink(self):
        """Alias for DisplayAsHyperlink"""
        return self.DisplayAsHyperlink

    @displayashyperlink.setter
    def displayashyperlink(self, value):
        """Alias for DisplayAsHyperlink.setter"""
        self.DisplayAsHyperlink = value

    @property
    def display_as_hyperlink(self):
        """Alias for DisplayAsHyperlink"""
        return self.DisplayAsHyperlink

    @display_as_hyperlink.setter
    def display_as_hyperlink(self, value):
        """Alias for DisplayAsHyperlink.setter"""
        self.DisplayAsHyperlink = value

    @property
    def DisplayWhen(self):
        return self.com_object.DisplayWhen

    @DisplayWhen.setter
    def DisplayWhen(self, value):
        self.com_object.DisplayWhen = value

    @property
    def displaywhen(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @displaywhen.setter
    def displaywhen(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def display_when(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @display_when.setter
    def display_when(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def EnterKeyBehavior(self):
        return self.com_object.EnterKeyBehavior

    @EnterKeyBehavior.setter
    def EnterKeyBehavior(self, value):
        self.com_object.EnterKeyBehavior = value

    @property
    def enterkeybehavior(self):
        """Alias for EnterKeyBehavior"""
        return self.EnterKeyBehavior

    @enterkeybehavior.setter
    def enterkeybehavior(self, value):
        """Alias for EnterKeyBehavior.setter"""
        self.EnterKeyBehavior = value

    @property
    def enter_key_behavior(self):
        """Alias for EnterKeyBehavior"""
        return self.EnterKeyBehavior

    @enter_key_behavior.setter
    def enter_key_behavior(self, value):
        """Alias for EnterKeyBehavior.setter"""
        self.EnterKeyBehavior = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def FilterLookup(self):
        return self.com_object.FilterLookup

    @FilterLookup.setter
    def FilterLookup(self, value):
        self.com_object.FilterLookup = value

    @property
    def filterlookup(self):
        """Alias for FilterLookup"""
        return self.FilterLookup

    @filterlookup.setter
    def filterlookup(self, value):
        """Alias for FilterLookup.setter"""
        self.FilterLookup = value

    @property
    def filter_lookup(self):
        """Alias for FilterLookup"""
        return self.FilterLookup

    @filter_lookup.setter
    def filter_lookup(self, value):
        """Alias for FilterLookup.setter"""
        self.FilterLookup = value

    @property
    def FontBold(self):
        return self.com_object.FontBold

    @property
    def fontbold(self):
        """Alias for FontBold"""
        return self.FontBold

    @property
    def font_bold(self):
        """Alias for FontBold"""
        return self.FontBold

    @property
    def FontItalic(self):
        return self.com_object.FontItalic

    @property
    def fontitalic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @property
    def font_italic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @property
    def FontName(self):
        return self.com_object.FontName

    @property
    def fontname(self):
        """Alias for FontName"""
        return self.FontName

    @property
    def font_name(self):
        """Alias for FontName"""
        return self.FontName

    @property
    def FontSize(self):
        return self.com_object.FontSize

    @property
    def fontsize(self):
        """Alias for FontSize"""
        return self.FontSize

    @property
    def font_size(self):
        """Alias for FontSize"""
        return self.FontSize

    @property
    def FontUnderline(self):
        return self.com_object.FontUnderline

    @property
    def fontunderline(self):
        """Alias for FontUnderline"""
        return self.FontUnderline

    @property
    def font_underline(self):
        """Alias for FontUnderline"""
        return self.FontUnderline

    @property
    def FontWeight(self):
        return self.com_object.FontWeight

    @FontWeight.setter
    def FontWeight(self, value):
        self.com_object.FontWeight = value

    @property
    def fontweight(self):
        """Alias for FontWeight"""
        return self.FontWeight

    @fontweight.setter
    def fontweight(self, value):
        """Alias for FontWeight.setter"""
        self.FontWeight = value

    @property
    def font_weight(self):
        """Alias for FontWeight"""
        return self.FontWeight

    @font_weight.setter
    def font_weight(self, value):
        """Alias for FontWeight.setter"""
        self.FontWeight = value

    @property
    def ForeColor(self):
        return self.com_object.ForeColor

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def ForeShade(self):
        return self.com_object.ForeShade

    @ForeShade.setter
    def ForeShade(self, value):
        self.com_object.ForeShade = value

    @property
    def foreshade(self):
        """Alias for ForeShade"""
        return self.ForeShade

    @foreshade.setter
    def foreshade(self, value):
        """Alias for ForeShade.setter"""
        self.ForeShade = value

    @property
    def fore_shade(self):
        """Alias for ForeShade"""
        return self.ForeShade

    @fore_shade.setter
    def fore_shade(self, value):
        """Alias for ForeShade.setter"""
        self.ForeShade = value

    @property
    def ForeThemeColorIndex(self):
        return self.com_object.ForeThemeColorIndex

    @ForeThemeColorIndex.setter
    def ForeThemeColorIndex(self, value):
        self.com_object.ForeThemeColorIndex = value

    @property
    def forethemecolorindex(self):
        """Alias for ForeThemeColorIndex"""
        return self.ForeThemeColorIndex

    @forethemecolorindex.setter
    def forethemecolorindex(self, value):
        """Alias for ForeThemeColorIndex.setter"""
        self.ForeThemeColorIndex = value

    @property
    def fore_theme_color_index(self):
        """Alias for ForeThemeColorIndex"""
        return self.ForeThemeColorIndex

    @fore_theme_color_index.setter
    def fore_theme_color_index(self, value):
        """Alias for ForeThemeColorIndex.setter"""
        self.ForeThemeColorIndex = value

    @property
    def ForeTint(self):
        return self.com_object.ForeTint

    @ForeTint.setter
    def ForeTint(self, value):
        self.com_object.ForeTint = value

    @property
    def foretint(self):
        """Alias for ForeTint"""
        return self.ForeTint

    @foretint.setter
    def foretint(self, value):
        """Alias for ForeTint.setter"""
        self.ForeTint = value

    @property
    def fore_tint(self):
        """Alias for ForeTint"""
        return self.ForeTint

    @fore_tint.setter
    def fore_tint(self, value):
        """Alias for ForeTint.setter"""
        self.ForeTint = value

    @property
    def Format(self):
        return self.com_object.Format

    @Format.setter
    def Format(self, value):
        self.com_object.Format = value

    @property
    def format(self):
        """Alias for Format"""
        return self.Format

    @format.setter
    def format(self, value):
        """Alias for Format.setter"""
        self.Format = value

    @property
    def FormatConditions(self):
        return self.com_object.FormatConditions

    @property
    def formatconditions(self):
        """Alias for FormatConditions"""
        return self.FormatConditions

    @property
    def format_conditions(self):
        """Alias for FormatConditions"""
        return self.FormatConditions

    @property
    def GridlineColor(self):
        return self.com_object.GridlineColor

    @GridlineColor.setter
    def GridlineColor(self, value):
        self.com_object.GridlineColor = value

    @property
    def gridlinecolor(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridlinecolor.setter
    def gridlinecolor(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def gridline_color(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridline_color.setter
    def gridline_color(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def GridlineShade(self):
        return self.com_object.GridlineShade

    @GridlineShade.setter
    def GridlineShade(self, value):
        self.com_object.GridlineShade = value

    @property
    def gridlineshade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridlineshade.setter
    def gridlineshade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def gridline_shade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridline_shade.setter
    def gridline_shade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def GridlineStyleBottom(self):
        return self.com_object.GridlineStyleBottom

    @GridlineStyleBottom.setter
    def GridlineStyleBottom(self, value):
        self.com_object.GridlineStyleBottom = value

    @property
    def gridlinestylebottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridlinestylebottom.setter
    def gridlinestylebottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def gridline_style_bottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridline_style_bottom.setter
    def gridline_style_bottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def GridlineStyleLeft(self):
        return self.com_object.GridlineStyleLeft

    @GridlineStyleLeft.setter
    def GridlineStyleLeft(self, value):
        self.com_object.GridlineStyleLeft = value

    @property
    def gridlinestyleleft(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridlinestyleleft.setter
    def gridlinestyleleft(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def gridline_style_left(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridline_style_left.setter
    def gridline_style_left(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def GridlineStyleRight(self):
        return self.com_object.GridlineStyleRight

    @GridlineStyleRight.setter
    def GridlineStyleRight(self, value):
        self.com_object.GridlineStyleRight = value

    @property
    def gridlinestyleright(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridlinestyleright.setter
    def gridlinestyleright(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def gridline_style_right(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridline_style_right.setter
    def gridline_style_right(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def GridlineStyleTop(self):
        return self.com_object.GridlineStyleTop

    @GridlineStyleTop.setter
    def GridlineStyleTop(self, value):
        self.com_object.GridlineStyleTop = value

    @property
    def gridlinestyletop(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridlinestyletop.setter
    def gridlinestyletop(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def gridline_style_top(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridline_style_top.setter
    def gridline_style_top(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def GridlineThemeColorIndex(self):
        return self.com_object.GridlineThemeColorIndex

    @GridlineThemeColorIndex.setter
    def GridlineThemeColorIndex(self, value):
        self.com_object.GridlineThemeColorIndex = value

    @property
    def gridlinethemecolorindex(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridlinethemecolorindex.setter
    def gridlinethemecolorindex(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def gridline_theme_color_index(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridline_theme_color_index.setter
    def gridline_theme_color_index(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def GridlineTint(self):
        return self.com_object.GridlineTint

    @GridlineTint.setter
    def GridlineTint(self, value):
        self.com_object.GridlineTint = value

    @property
    def gridlinetint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridlinetint.setter
    def gridlinetint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def gridline_tint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridline_tint.setter
    def gridline_tint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def GridlineWidthBottom(self):
        return self.com_object.GridlineWidthBottom

    @GridlineWidthBottom.setter
    def GridlineWidthBottom(self, value):
        self.com_object.GridlineWidthBottom = value

    @property
    def gridlinewidthbottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridlinewidthbottom.setter
    def gridlinewidthbottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def gridline_width_bottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridline_width_bottom.setter
    def gridline_width_bottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def GridlineWidthLeft(self):
        return self.com_object.GridlineWidthLeft

    @GridlineWidthLeft.setter
    def GridlineWidthLeft(self, value):
        self.com_object.GridlineWidthLeft = value

    @property
    def gridlinewidthleft(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridlinewidthleft.setter
    def gridlinewidthleft(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def gridline_width_left(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridline_width_left.setter
    def gridline_width_left(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def GridlineWidthRight(self):
        return self.com_object.GridlineWidthRight

    @GridlineWidthRight.setter
    def GridlineWidthRight(self, value):
        self.com_object.GridlineWidthRight = value

    @property
    def gridlinewidthright(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridlinewidthright.setter
    def gridlinewidthright(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def gridline_width_right(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridline_width_right.setter
    def gridline_width_right(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def GridlineWidthTop(self):
        return self.com_object.GridlineWidthTop

    @GridlineWidthTop.setter
    def GridlineWidthTop(self, value):
        self.com_object.GridlineWidthTop = value

    @property
    def gridlinewidthtop(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridlinewidthtop.setter
    def gridlinewidthtop(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def gridline_width_top(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridline_width_top.setter
    def gridline_width_top(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HelpContextId(self):
        return self.com_object.HelpContextId

    @HelpContextId.setter
    def HelpContextId(self, value):
        self.com_object.HelpContextId = value

    @property
    def helpcontextid(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @helpcontextid.setter
    def helpcontextid(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def help_context_id(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @help_context_id.setter
    def help_context_id(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def HideDuplicates(self):
        return self.com_object.HideDuplicates

    @HideDuplicates.setter
    def HideDuplicates(self, value):
        self.com_object.HideDuplicates = value

    @property
    def hideduplicates(self):
        """Alias for HideDuplicates"""
        return self.HideDuplicates

    @hideduplicates.setter
    def hideduplicates(self, value):
        """Alias for HideDuplicates.setter"""
        self.HideDuplicates = value

    @property
    def hide_duplicates(self):
        """Alias for HideDuplicates"""
        return self.HideDuplicates

    @hide_duplicates.setter
    def hide_duplicates(self, value):
        """Alias for HideDuplicates.setter"""
        self.HideDuplicates = value

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def Hyperlink(self):
        return self.com_object.Hyperlink

    @property
    def hyperlink(self):
        """Alias for Hyperlink"""
        return self.Hyperlink

    @property
    def IMEHold(self):
        return self.com_object.IMEHold

    @IMEHold.setter
    def IMEHold(self, value):
        self.com_object.IMEHold = value

    @property
    def imehold(self):
        """Alias for IMEHold"""
        return self.IMEHold

    @imehold.setter
    def imehold(self, value):
        """Alias for IMEHold.setter"""
        self.IMEHold = value

    @property
    def i_m_e_hold(self):
        """Alias for IMEHold"""
        return self.IMEHold

    @i_m_e_hold.setter
    def i_m_e_hold(self, value):
        """Alias for IMEHold.setter"""
        self.IMEHold = value

    @property
    def InputMask(self):
        return self.com_object.InputMask

    @InputMask.setter
    def InputMask(self, value):
        self.com_object.InputMask = value

    @property
    def inputmask(self):
        """Alias for InputMask"""
        return self.InputMask

    @inputmask.setter
    def inputmask(self, value):
        """Alias for InputMask.setter"""
        self.InputMask = value

    @property
    def input_mask(self):
        """Alias for InputMask"""
        return self.InputMask

    @input_mask.setter
    def input_mask(self, value):
        """Alias for InputMask.setter"""
        self.InputMask = value

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def IsHyperlink(self):
        return self.com_object.IsHyperlink

    @IsHyperlink.setter
    def IsHyperlink(self, value):
        self.com_object.IsHyperlink = value

    @property
    def ishyperlink(self):
        """Alias for IsHyperlink"""
        return self.IsHyperlink

    @ishyperlink.setter
    def ishyperlink(self, value):
        """Alias for IsHyperlink.setter"""
        self.IsHyperlink = value

    @property
    def is_hyperlink(self):
        """Alias for IsHyperlink"""
        return self.IsHyperlink

    @is_hyperlink.setter
    def is_hyperlink(self, value):
        """Alias for IsHyperlink.setter"""
        self.IsHyperlink = value

    @property
    def IsVisible(self):
        return self.com_object.IsVisible

    @IsVisible.setter
    def IsVisible(self, value):
        self.com_object.IsVisible = value

    @property
    def isvisible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @isvisible.setter
    def isvisible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def is_visible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @is_visible.setter
    def is_visible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def LabelAlign(self):
        return self.com_object.LabelAlign

    @LabelAlign.setter
    def LabelAlign(self, value):
        self.com_object.LabelAlign = value

    @property
    def labelalign(self):
        """Alias for LabelAlign"""
        return self.LabelAlign

    @labelalign.setter
    def labelalign(self, value):
        """Alias for LabelAlign.setter"""
        self.LabelAlign = value

    @property
    def label_align(self):
        """Alias for LabelAlign"""
        return self.LabelAlign

    @label_align.setter
    def label_align(self, value):
        """Alias for LabelAlign.setter"""
        self.LabelAlign = value

    @property
    def LabelX(self):
        return self.com_object.LabelX

    @LabelX.setter
    def LabelX(self, value):
        self.com_object.LabelX = value

    @property
    def labelx(self):
        """Alias for LabelX"""
        return self.LabelX

    @labelx.setter
    def labelx(self, value):
        """Alias for LabelX.setter"""
        self.LabelX = value

    @property
    def label_x(self):
        """Alias for LabelX"""
        return self.LabelX

    @label_x.setter
    def label_x(self, value):
        """Alias for LabelX.setter"""
        self.LabelX = value

    @property
    def LabelY(self):
        return self.com_object.LabelY

    @LabelY.setter
    def LabelY(self, value):
        self.com_object.LabelY = value

    @property
    def labely(self):
        """Alias for LabelY"""
        return self.LabelY

    @labely.setter
    def labely(self, value):
        """Alias for LabelY.setter"""
        self.LabelY = value

    @property
    def label_y(self):
        """Alias for LabelY"""
        return self.LabelY

    @label_y.setter
    def label_y(self, value):
        """Alias for LabelY.setter"""
        self.LabelY = value

    @property
    def Layout(self):
        return AcLayoutType(self.com_object.Layout)

    @property
    def layout(self):
        """Alias for Layout"""
        return self.Layout

    @property
    def LayoutID(self):
        return self.com_object.LayoutID

    @property
    def layoutid(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def layout_i_d(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def LeftMargin(self):
        return self.com_object.LeftMargin

    @LeftMargin.setter
    def LeftMargin(self, value):
        self.com_object.LeftMargin = value

    @property
    def leftmargin(self):
        """Alias for LeftMargin"""
        return self.LeftMargin

    @leftmargin.setter
    def leftmargin(self, value):
        """Alias for LeftMargin.setter"""
        self.LeftMargin = value

    @property
    def left_margin(self):
        """Alias for LeftMargin"""
        return self.LeftMargin

    @left_margin.setter
    def left_margin(self, value):
        """Alias for LeftMargin.setter"""
        self.LeftMargin = value

    @property
    def LeftPadding(self):
        return self.com_object.LeftPadding

    @LeftPadding.setter
    def LeftPadding(self, value):
        self.com_object.LeftPadding = value

    @property
    def leftpadding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @leftpadding.setter
    def leftpadding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def left_padding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @left_padding.setter
    def left_padding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def LineSpacing(self):
        return self.com_object.LineSpacing

    @LineSpacing.setter
    def LineSpacing(self, value):
        self.com_object.LineSpacing = value

    @property
    def linespacing(self):
        """Alias for LineSpacing"""
        return self.LineSpacing

    @linespacing.setter
    def linespacing(self, value):
        """Alias for LineSpacing.setter"""
        self.LineSpacing = value

    @property
    def line_spacing(self):
        """Alias for LineSpacing"""
        return self.LineSpacing

    @line_spacing.setter
    def line_spacing(self, value):
        """Alias for LineSpacing.setter"""
        self.LineSpacing = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def OldBorderStyle(self):
        return self.com_object.OldBorderStyle

    @OldBorderStyle.setter
    def OldBorderStyle(self, value):
        self.com_object.OldBorderStyle = value

    @property
    def oldborderstyle(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @oldborderstyle.setter
    def oldborderstyle(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def old_border_style(self):
        """Alias for OldBorderStyle"""
        return self.OldBorderStyle

    @old_border_style.setter
    def old_border_style(self, value):
        """Alias for OldBorderStyle.setter"""
        self.OldBorderStyle = value

    @property
    def OldValue(self):
        return self.com_object.OldValue

    @property
    def oldvalue(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def old_value(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def OnChange(self):
        return self.com_object.OnChange

    @OnChange.setter
    def OnChange(self, value):
        self.com_object.OnChange = value

    @property
    def onchange(self):
        """Alias for OnChange"""
        return self.OnChange

    @onchange.setter
    def onchange(self, value):
        """Alias for OnChange.setter"""
        self.OnChange = value

    @property
    def on_change(self):
        """Alias for OnChange"""
        return self.OnChange

    @on_change.setter
    def on_change(self, value):
        """Alias for OnChange.setter"""
        self.OnChange = value

    @property
    def OnClick(self):
        return self.com_object.OnClick

    @OnClick.setter
    def OnClick(self, value):
        self.com_object.OnClick = value

    @property
    def onclick(self):
        """Alias for OnClick"""
        return self.OnClick

    @onclick.setter
    def onclick(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def on_click(self):
        """Alias for OnClick"""
        return self.OnClick

    @on_click.setter
    def on_click(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def OnDblClick(self):
        return self.com_object.OnDblClick

    @OnDblClick.setter
    def OnDblClick(self, value):
        self.com_object.OnDblClick = value

    @property
    def ondblclick(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @ondblclick.setter
    def ondblclick(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def on_dbl_click(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @on_dbl_click.setter
    def on_dbl_click(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def OnDirty(self):
        return self.com_object.OnDirty

    @OnDirty.setter
    def OnDirty(self, value):
        self.com_object.OnDirty = value

    @property
    def ondirty(self):
        """Alias for OnDirty"""
        return self.OnDirty

    @ondirty.setter
    def ondirty(self, value):
        """Alias for OnDirty.setter"""
        self.OnDirty = value

    @property
    def on_dirty(self):
        """Alias for OnDirty"""
        return self.OnDirty

    @on_dirty.setter
    def on_dirty(self, value):
        """Alias for OnDirty.setter"""
        self.OnDirty = value

    @property
    def OnEnter(self):
        return self.com_object.OnEnter

    @OnEnter.setter
    def OnEnter(self, value):
        self.com_object.OnEnter = value

    @property
    def onenter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @onenter.setter
    def onenter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def on_enter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @on_enter.setter
    def on_enter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def OnExit(self):
        return self.com_object.OnExit

    @OnExit.setter
    def OnExit(self, value):
        self.com_object.OnExit = value

    @property
    def onexit(self):
        """Alias for OnExit"""
        return self.OnExit

    @onexit.setter
    def onexit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def on_exit(self):
        """Alias for OnExit"""
        return self.OnExit

    @on_exit.setter
    def on_exit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def OnGotFocus(self):
        return self.com_object.OnGotFocus

    @OnGotFocus.setter
    def OnGotFocus(self, value):
        self.com_object.OnGotFocus = value

    @property
    def ongotfocus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @ongotfocus.setter
    def ongotfocus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def on_got_focus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @on_got_focus.setter
    def on_got_focus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def OnKeyDown(self):
        return self.com_object.OnKeyDown

    @OnKeyDown.setter
    def OnKeyDown(self, value):
        self.com_object.OnKeyDown = value

    @property
    def onkeydown(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @onkeydown.setter
    def onkeydown(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def on_key_down(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @on_key_down.setter
    def on_key_down(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def OnKeyPress(self):
        return self.com_object.OnKeyPress

    @OnKeyPress.setter
    def OnKeyPress(self, value):
        self.com_object.OnKeyPress = value

    @property
    def onkeypress(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @onkeypress.setter
    def onkeypress(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def on_key_press(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @on_key_press.setter
    def on_key_press(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def OnKeyUp(self):
        return self.com_object.OnKeyUp

    @OnKeyUp.setter
    def OnKeyUp(self, value):
        self.com_object.OnKeyUp = value

    @property
    def onkeyup(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @onkeyup.setter
    def onkeyup(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def on_key_up(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @on_key_up.setter
    def on_key_up(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def OnLostFocus(self):
        return self.com_object.OnLostFocus

    @OnLostFocus.setter
    def OnLostFocus(self, value):
        self.com_object.OnLostFocus = value

    @property
    def onlostfocus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @onlostfocus.setter
    def onlostfocus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def on_lost_focus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @on_lost_focus.setter
    def on_lost_focus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def OnMouseDown(self):
        return self.com_object.OnMouseDown

    @OnMouseDown.setter
    def OnMouseDown(self, value):
        self.com_object.OnMouseDown = value

    @property
    def onmousedown(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @onmousedown.setter
    def onmousedown(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def on_mouse_down(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @on_mouse_down.setter
    def on_mouse_down(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def OnMouseMove(self):
        return self.com_object.OnMouseMove

    @OnMouseMove.setter
    def OnMouseMove(self, value):
        self.com_object.OnMouseMove = value

    @property
    def onmousemove(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @onmousemove.setter
    def onmousemove(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def on_mouse_move(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @on_mouse_move.setter
    def on_mouse_move(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def OnMouseUp(self):
        return self.com_object.OnMouseUp

    @OnMouseUp.setter
    def OnMouseUp(self, value):
        self.com_object.OnMouseUp = value

    @property
    def onmouseup(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @onmouseup.setter
    def onmouseup(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def on_mouse_up(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @on_mouse_up.setter
    def on_mouse_up(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def OnUndo(self):
        return self.com_object.OnUndo

    @OnUndo.setter
    def OnUndo(self, value):
        self.com_object.OnUndo = value

    @property
    def onundo(self):
        """Alias for OnUndo"""
        return self.OnUndo

    @onundo.setter
    def onundo(self, value):
        """Alias for OnUndo.setter"""
        self.OnUndo = value

    @property
    def on_undo(self):
        """Alias for OnUndo"""
        return self.OnUndo

    @on_undo.setter
    def on_undo(self, value):
        """Alias for OnUndo.setter"""
        self.OnUndo = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def PostalAddress(self):
        return self.com_object.PostalAddress

    @PostalAddress.setter
    def PostalAddress(self, value):
        self.com_object.PostalAddress = value

    @property
    def postaladdress(self):
        """Alias for PostalAddress"""
        return self.PostalAddress

    @postaladdress.setter
    def postaladdress(self, value):
        """Alias for PostalAddress.setter"""
        self.PostalAddress = value

    @property
    def postal_address(self):
        """Alias for PostalAddress"""
        return self.PostalAddress

    @postal_address.setter
    def postal_address(self, value):
        """Alias for PostalAddress.setter"""
        self.PostalAddress = value

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def ReadingOrder(self):
        return self.com_object.ReadingOrder

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def RightMargin(self):
        return self.com_object.RightMargin

    @RightMargin.setter
    def RightMargin(self, value):
        self.com_object.RightMargin = value

    @property
    def rightmargin(self):
        """Alias for RightMargin"""
        return self.RightMargin

    @rightmargin.setter
    def rightmargin(self, value):
        """Alias for RightMargin.setter"""
        self.RightMargin = value

    @property
    def right_margin(self):
        """Alias for RightMargin"""
        return self.RightMargin

    @right_margin.setter
    def right_margin(self, value):
        """Alias for RightMargin.setter"""
        self.RightMargin = value

    @property
    def RightPadding(self):
        return self.com_object.RightPadding

    @RightPadding.setter
    def RightPadding(self, value):
        self.com_object.RightPadding = value

    @property
    def rightpadding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @rightpadding.setter
    def rightpadding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def right_padding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @right_padding.setter
    def right_padding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def RunningSum(self):
        return self.com_object.RunningSum

    @RunningSum.setter
    def RunningSum(self, value):
        self.com_object.RunningSum = value

    @property
    def runningsum(self):
        """Alias for RunningSum"""
        return self.RunningSum

    @runningsum.setter
    def runningsum(self, value):
        """Alias for RunningSum.setter"""
        self.RunningSum = value

    @property
    def running_sum(self):
        """Alias for RunningSum"""
        return self.RunningSum

    @running_sum.setter
    def running_sum(self, value):
        """Alias for RunningSum.setter"""
        self.RunningSum = value

    @property
    def ScrollBarAlign(self):
        return self.com_object.ScrollBarAlign

    @ScrollBarAlign.setter
    def ScrollBarAlign(self, value):
        self.com_object.ScrollBarAlign = value

    @property
    def scrollbaralign(self):
        """Alias for ScrollBarAlign"""
        return self.ScrollBarAlign

    @scrollbaralign.setter
    def scrollbaralign(self, value):
        """Alias for ScrollBarAlign.setter"""
        self.ScrollBarAlign = value

    @property
    def scroll_bar_align(self):
        """Alias for ScrollBarAlign"""
        return self.ScrollBarAlign

    @scroll_bar_align.setter
    def scroll_bar_align(self, value):
        """Alias for ScrollBarAlign.setter"""
        self.ScrollBarAlign = value

    @property
    def ScrollBars(self):
        return self.com_object.ScrollBars

    @ScrollBars.setter
    def ScrollBars(self, value):
        self.com_object.ScrollBars = value

    @property
    def scrollbars(self):
        """Alias for ScrollBars"""
        return self.ScrollBars

    @scrollbars.setter
    def scrollbars(self, value):
        """Alias for ScrollBars.setter"""
        self.ScrollBars = value

    @property
    def scroll_bars(self):
        """Alias for ScrollBars"""
        return self.ScrollBars

    @scroll_bars.setter
    def scroll_bars(self, value):
        """Alias for ScrollBars.setter"""
        self.ScrollBars = value

    @property
    def Section(self):
        return self.com_object.Section

    @Section.setter
    def Section(self, value):
        self.com_object.Section = value

    @property
    def section(self):
        """Alias for Section"""
        return self.Section

    @section.setter
    def section(self, value):
        """Alias for Section.setter"""
        self.Section = value

    @property
    def SelLength(self):
        return self.com_object.SelLength

    @SelLength.setter
    def SelLength(self, value):
        self.com_object.SelLength = value

    @property
    def sellength(self):
        """Alias for SelLength"""
        return self.SelLength

    @sellength.setter
    def sellength(self, value):
        """Alias for SelLength.setter"""
        self.SelLength = value

    @property
    def sel_length(self):
        """Alias for SelLength"""
        return self.SelLength

    @sel_length.setter
    def sel_length(self, value):
        """Alias for SelLength.setter"""
        self.SelLength = value

    @property
    def SelStart(self):
        return self.com_object.SelStart

    @SelStart.setter
    def SelStart(self, value):
        self.com_object.SelStart = value

    @property
    def selstart(self):
        """Alias for SelStart"""
        return self.SelStart

    @selstart.setter
    def selstart(self, value):
        """Alias for SelStart.setter"""
        self.SelStart = value

    @property
    def sel_start(self):
        """Alias for SelStart"""
        return self.SelStart

    @sel_start.setter
    def sel_start(self, value):
        """Alias for SelStart.setter"""
        self.SelStart = value

    @property
    def SelText(self):
        return self.com_object.SelText

    @SelText.setter
    def SelText(self, value):
        self.com_object.SelText = value

    @property
    def seltext(self):
        """Alias for SelText"""
        return self.SelText

    @seltext.setter
    def seltext(self, value):
        """Alias for SelText.setter"""
        self.SelText = value

    @property
    def sel_text(self):
        """Alias for SelText"""
        return self.SelText

    @sel_text.setter
    def sel_text(self, value):
        """Alias for SelText.setter"""
        self.SelText = value

    @property
    def ShortcutMenuBar(self):
        return self.com_object.ShortcutMenuBar

    @ShortcutMenuBar.setter
    def ShortcutMenuBar(self, value):
        self.com_object.ShortcutMenuBar = value

    @property
    def shortcutmenubar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcutmenubar.setter
    def shortcutmenubar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def shortcut_menu_bar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcut_menu_bar.setter
    def shortcut_menu_bar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def ShowDatePicker(self):
        return self.com_object.ShowDatePicker

    @ShowDatePicker.setter
    def ShowDatePicker(self, value):
        self.com_object.ShowDatePicker = value

    @property
    def showdatepicker(self):
        """Alias for ShowDatePicker"""
        return self.ShowDatePicker

    @showdatepicker.setter
    def showdatepicker(self, value):
        """Alias for ShowDatePicker.setter"""
        self.ShowDatePicker = value

    @property
    def show_date_picker(self):
        """Alias for ShowDatePicker"""
        return self.ShowDatePicker

    @show_date_picker.setter
    def show_date_picker(self, value):
        """Alias for ShowDatePicker.setter"""
        self.ShowDatePicker = value

    @property
    def SmartTags(self):
        return SmartTags(self.com_object.SmartTags)

    @property
    def smarttags(self):
        """Alias for SmartTags"""
        return self.SmartTags

    @property
    def smart_tags(self):
        """Alias for SmartTags"""
        return self.SmartTags

    @property
    def SpecialEffect(self):
        return self.com_object.SpecialEffect

    @SpecialEffect.setter
    def SpecialEffect(self, value):
        self.com_object.SpecialEffect = value

    @property
    def specialeffect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @specialeffect.setter
    def specialeffect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def special_effect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @special_effect.setter
    def special_effect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def StatusBarText(self):
        return self.com_object.StatusBarText

    @StatusBarText.setter
    def StatusBarText(self, value):
        self.com_object.StatusBarText = value

    @property
    def statusbartext(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @statusbartext.setter
    def statusbartext(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def status_bar_text(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @status_bar_text.setter
    def status_bar_text(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def TabIndex(self):
        return self.com_object.TabIndex

    @TabIndex.setter
    def TabIndex(self, value):
        self.com_object.TabIndex = value

    @property
    def tabindex(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tabindex.setter
    def tabindex(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def tab_index(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tab_index.setter
    def tab_index(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def TabStop(self):
        return self.com_object.TabStop

    @TabStop.setter
    def TabStop(self, value):
        self.com_object.TabStop = value

    @property
    def tabstop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tabstop.setter
    def tabstop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def tab_stop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tab_stop.setter
    def tab_stop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def Text(self):
        return self.com_object.Text

    @Text.setter
    def Text(self, value):
        self.com_object.Text = value

    @property
    def text(self):
        """Alias for Text"""
        return self.Text

    @text.setter
    def text(self, value):
        """Alias for Text.setter"""
        self.Text = value

    @property
    def TextAlign(self):
        return self.com_object.TextAlign

    @TextAlign.setter
    def TextAlign(self, value):
        self.com_object.TextAlign = value

    @property
    def textalign(self):
        """Alias for TextAlign"""
        return self.TextAlign

    @textalign.setter
    def textalign(self, value):
        """Alias for TextAlign.setter"""
        self.TextAlign = value

    @property
    def text_align(self):
        """Alias for TextAlign"""
        return self.TextAlign

    @text_align.setter
    def text_align(self, value):
        """Alias for TextAlign.setter"""
        self.TextAlign = value

    @property
    def TextFormat(self):
        return self.com_object.TextFormat

    @TextFormat.setter
    def TextFormat(self, value):
        self.com_object.TextFormat = value

    @property
    def textformat(self):
        """Alias for TextFormat"""
        return self.TextFormat

    @textformat.setter
    def textformat(self, value):
        """Alias for TextFormat.setter"""
        self.TextFormat = value

    @property
    def text_format(self):
        """Alias for TextFormat"""
        return self.TextFormat

    @text_format.setter
    def text_format(self, value):
        """Alias for TextFormat.setter"""
        self.TextFormat = value

    @property
    def ThemeFontIndex(self):
        return self.com_object.ThemeFontIndex

    @ThemeFontIndex.setter
    def ThemeFontIndex(self, value):
        self.com_object.ThemeFontIndex = value

    @property
    def themefontindex(self):
        """Alias for ThemeFontIndex"""
        return self.ThemeFontIndex

    @themefontindex.setter
    def themefontindex(self, value):
        """Alias for ThemeFontIndex.setter"""
        self.ThemeFontIndex = value

    @property
    def theme_font_index(self):
        """Alias for ThemeFontIndex"""
        return self.ThemeFontIndex

    @theme_font_index.setter
    def theme_font_index(self, value):
        """Alias for ThemeFontIndex.setter"""
        self.ThemeFontIndex = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TopMargin(self):
        return self.com_object.TopMargin

    @TopMargin.setter
    def TopMargin(self, value):
        self.com_object.TopMargin = value

    @property
    def topmargin(self):
        """Alias for TopMargin"""
        return self.TopMargin

    @topmargin.setter
    def topmargin(self, value):
        """Alias for TopMargin.setter"""
        self.TopMargin = value

    @property
    def top_margin(self):
        """Alias for TopMargin"""
        return self.TopMargin

    @top_margin.setter
    def top_margin(self, value):
        """Alias for TopMargin.setter"""
        self.TopMargin = value

    @property
    def TopPadding(self):
        return self.com_object.TopPadding

    @TopPadding.setter
    def TopPadding(self, value):
        self.com_object.TopPadding = value

    @property
    def toppadding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @toppadding.setter
    def toppadding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def top_padding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @top_padding.setter
    def top_padding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def ValidationRule(self):
        return self.com_object.ValidationRule

    @ValidationRule.setter
    def ValidationRule(self, value):
        self.com_object.ValidationRule = value

    @property
    def validationrule(self):
        """Alias for ValidationRule"""
        return self.ValidationRule

    @validationrule.setter
    def validationrule(self, value):
        """Alias for ValidationRule.setter"""
        self.ValidationRule = value

    @property
    def validation_rule(self):
        """Alias for ValidationRule"""
        return self.ValidationRule

    @validation_rule.setter
    def validation_rule(self, value):
        """Alias for ValidationRule.setter"""
        self.ValidationRule = value

    @property
    def ValidationText(self):
        return self.com_object.ValidationText

    @ValidationText.setter
    def ValidationText(self, value):
        self.com_object.ValidationText = value

    @property
    def validationtext(self):
        """Alias for ValidationText"""
        return self.ValidationText

    @validationtext.setter
    def validationtext(self, value):
        """Alias for ValidationText.setter"""
        self.ValidationText = value

    @property
    def validation_text(self):
        """Alias for ValidationText"""
        return self.ValidationText

    @validation_text.setter
    def validation_text(self, value):
        """Alias for ValidationText.setter"""
        self.ValidationText = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    @property
    def Vertical(self):
        return self.com_object.Vertical

    @Vertical.setter
    def Vertical(self, value):
        self.com_object.Vertical = value

    @property
    def vertical(self):
        """Alias for Vertical"""
        return self.Vertical

    @vertical.setter
    def vertical(self, value):
        """Alias for Vertical.setter"""
        self.Vertical = value

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def Requery(self):
        self.com_object.Requery()

    def requery(self):
        """Alias for Requery"""
        return self.Requery()

    def SetFocus(self):
        return self.com_object.SetFocus()

    def setfocus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def set_focus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def Undo(self):
        self.com_object.Undo()

    def undo(self):
        """Alias for Undo"""
        return self.Undo()


class ToggleButton:

    def __init__(self, togglebutton=None):
        self.com_object= togglebutton

    @property
    def AddColon(self):
        return self.com_object.AddColon

    @AddColon.setter
    def AddColon(self, value):
        self.com_object.AddColon = value

    @property
    def addcolon(self):
        """Alias for AddColon"""
        return self.AddColon

    @addcolon.setter
    def addcolon(self, value):
        """Alias for AddColon.setter"""
        self.AddColon = value

    @property
    def add_colon(self):
        """Alias for AddColon"""
        return self.AddColon

    @add_colon.setter
    def add_colon(self, value):
        """Alias for AddColon.setter"""
        self.AddColon = value

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def AutoLabel(self):
        return self.com_object.AutoLabel

    @AutoLabel.setter
    def AutoLabel(self, value):
        self.com_object.AutoLabel = value

    @property
    def autolabel(self):
        """Alias for AutoLabel"""
        return self.AutoLabel

    @autolabel.setter
    def autolabel(self, value):
        """Alias for AutoLabel.setter"""
        self.AutoLabel = value

    @property
    def auto_label(self):
        """Alias for AutoLabel"""
        return self.AutoLabel

    @auto_label.setter
    def auto_label(self, value):
        """Alias for AutoLabel.setter"""
        self.AutoLabel = value

    @property
    def BackColor(self):
        return self.com_object.BackColor

    @BackColor.setter
    def BackColor(self, value):
        self.com_object.BackColor = value

    @property
    def backcolor(self):
        """Alias for BackColor"""
        return self.BackColor

    @backcolor.setter
    def backcolor(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def back_color(self):
        """Alias for BackColor"""
        return self.BackColor

    @back_color.setter
    def back_color(self, value):
        """Alias for BackColor.setter"""
        self.BackColor = value

    @property
    def BackShade(self):
        return self.com_object.BackShade

    @BackShade.setter
    def BackShade(self, value):
        self.com_object.BackShade = value

    @property
    def backshade(self):
        """Alias for BackShade"""
        return self.BackShade

    @backshade.setter
    def backshade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def back_shade(self):
        """Alias for BackShade"""
        return self.BackShade

    @back_shade.setter
    def back_shade(self, value):
        """Alias for BackShade.setter"""
        self.BackShade = value

    @property
    def BackThemeColorIndex(self):
        return self.com_object.BackThemeColorIndex

    @BackThemeColorIndex.setter
    def BackThemeColorIndex(self, value):
        self.com_object.BackThemeColorIndex = value

    @property
    def backthemecolorindex(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @backthemecolorindex.setter
    def backthemecolorindex(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def back_theme_color_index(self):
        """Alias for BackThemeColorIndex"""
        return self.BackThemeColorIndex

    @back_theme_color_index.setter
    def back_theme_color_index(self, value):
        """Alias for BackThemeColorIndex.setter"""
        self.BackThemeColorIndex = value

    @property
    def BackTint(self):
        return self.com_object.BackTint

    @BackTint.setter
    def BackTint(self, value):
        self.com_object.BackTint = value

    @property
    def backtint(self):
        """Alias for BackTint"""
        return self.BackTint

    @backtint.setter
    def backtint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def back_tint(self):
        """Alias for BackTint"""
        return self.BackTint

    @back_tint.setter
    def back_tint(self, value):
        """Alias for BackTint.setter"""
        self.BackTint = value

    @property
    def Bevel(self):
        return self.com_object.Bevel

    @Bevel.setter
    def Bevel(self, value):
        self.com_object.Bevel = value

    @property
    def bevel(self):
        """Alias for Bevel"""
        return self.Bevel

    @bevel.setter
    def bevel(self, value):
        """Alias for Bevel.setter"""
        self.Bevel = value

    @property
    def BorderColor(self):
        return self.com_object.BorderColor

    @BorderColor.setter
    def BorderColor(self, value):
        self.com_object.BorderColor = value

    @property
    def bordercolor(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @bordercolor.setter
    def bordercolor(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def border_color(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @border_color.setter
    def border_color(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def BorderShade(self):
        return self.com_object.BorderShade

    @BorderShade.setter
    def BorderShade(self, value):
        self.com_object.BorderShade = value

    @property
    def bordershade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @bordershade.setter
    def bordershade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def border_shade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @border_shade.setter
    def border_shade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def BorderStyle(self):
        return self.com_object.BorderStyle

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def BorderThemeColorIndex(self):
        return self.com_object.BorderThemeColorIndex

    @BorderThemeColorIndex.setter
    def BorderThemeColorIndex(self, value):
        self.com_object.BorderThemeColorIndex = value

    @property
    def borderthemecolorindex(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @borderthemecolorindex.setter
    def borderthemecolorindex(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def border_theme_color_index(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @border_theme_color_index.setter
    def border_theme_color_index(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def BorderTint(self):
        return self.com_object.BorderTint

    @BorderTint.setter
    def BorderTint(self, value):
        self.com_object.BorderTint = value

    @property
    def bordertint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @bordertint.setter
    def bordertint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def border_tint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @border_tint.setter
    def border_tint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def BorderWidth(self):
        return self.com_object.BorderWidth

    @BorderWidth.setter
    def BorderWidth(self, value):
        self.com_object.BorderWidth = value

    @property
    def borderwidth(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @borderwidth.setter
    def borderwidth(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def border_width(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @border_width.setter
    def border_width(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def BottomPadding(self):
        return self.com_object.BottomPadding

    @BottomPadding.setter
    def BottomPadding(self, value):
        self.com_object.BottomPadding = value

    @property
    def bottompadding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottompadding.setter
    def bottompadding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def bottom_padding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottom_padding.setter
    def bottom_padding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def Caption(self):
        return self.com_object.Caption

    @Caption.setter
    def Caption(self, value):
        self.com_object.Caption = value

    @property
    def caption(self):
        """Alias for Caption"""
        return self.Caption

    @caption.setter
    def caption(self, value):
        """Alias for Caption.setter"""
        self.Caption = value

    @property
    def ColumnHidden(self):
        return self.com_object.ColumnHidden

    @ColumnHidden.setter
    def ColumnHidden(self, value):
        self.com_object.ColumnHidden = value

    @property
    def columnhidden(self):
        """Alias for ColumnHidden"""
        return self.ColumnHidden

    @columnhidden.setter
    def columnhidden(self, value):
        """Alias for ColumnHidden.setter"""
        self.ColumnHidden = value

    @property
    def column_hidden(self):
        """Alias for ColumnHidden"""
        return self.ColumnHidden

    @column_hidden.setter
    def column_hidden(self, value):
        """Alias for ColumnHidden.setter"""
        self.ColumnHidden = value

    @property
    def ColumnOrder(self):
        return self.com_object.ColumnOrder

    @ColumnOrder.setter
    def ColumnOrder(self, value):
        self.com_object.ColumnOrder = value

    @property
    def columnorder(self):
        """Alias for ColumnOrder"""
        return self.ColumnOrder

    @columnorder.setter
    def columnorder(self, value):
        """Alias for ColumnOrder.setter"""
        self.ColumnOrder = value

    @property
    def column_order(self):
        """Alias for ColumnOrder"""
        return self.ColumnOrder

    @column_order.setter
    def column_order(self, value):
        """Alias for ColumnOrder.setter"""
        self.ColumnOrder = value

    @property
    def ColumnWidth(self):
        return self.com_object.ColumnWidth

    @ColumnWidth.setter
    def ColumnWidth(self, value):
        self.com_object.ColumnWidth = value

    @property
    def columnwidth(self):
        """Alias for ColumnWidth"""
        return self.ColumnWidth

    @columnwidth.setter
    def columnwidth(self, value):
        """Alias for ColumnWidth.setter"""
        self.ColumnWidth = value

    @property
    def column_width(self):
        """Alias for ColumnWidth"""
        return self.ColumnWidth

    @column_width.setter
    def column_width(self, value):
        """Alias for ColumnWidth.setter"""
        self.ColumnWidth = value

    @property
    def Controls(self):
        return Controls(self.com_object.Controls)

    @property
    def controls(self):
        """Alias for Controls"""
        return self.Controls

    @property
    def ControlSource(self):
        return self.com_object.ControlSource

    @ControlSource.setter
    def ControlSource(self, value):
        self.com_object.ControlSource = value

    @property
    def controlsource(self):
        """Alias for ControlSource"""
        return self.ControlSource

    @controlsource.setter
    def controlsource(self, value):
        """Alias for ControlSource.setter"""
        self.ControlSource = value

    @property
    def control_source(self):
        """Alias for ControlSource"""
        return self.ControlSource

    @control_source.setter
    def control_source(self, value):
        """Alias for ControlSource.setter"""
        self.ControlSource = value

    @property
    def ControlTipText(self):
        return self.com_object.ControlTipText

    @ControlTipText.setter
    def ControlTipText(self, value):
        self.com_object.ControlTipText = value

    @property
    def controltiptext(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @controltiptext.setter
    def controltiptext(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def control_tip_text(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @control_tip_text.setter
    def control_tip_text(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def ControlType(self):
        return self.com_object.ControlType

    @ControlType.setter
    def ControlType(self, value):
        self.com_object.ControlType = value

    @property
    def controltype(self):
        """Alias for ControlType"""
        return self.ControlType

    @controltype.setter
    def controltype(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def control_type(self):
        """Alias for ControlType"""
        return self.ControlType

    @control_type.setter
    def control_type(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def DefaultValue(self):
        return self.com_object.DefaultValue

    @DefaultValue.setter
    def DefaultValue(self, value):
        self.com_object.DefaultValue = value

    @property
    def defaultvalue(self):
        """Alias for DefaultValue"""
        return self.DefaultValue

    @defaultvalue.setter
    def defaultvalue(self, value):
        """Alias for DefaultValue.setter"""
        self.DefaultValue = value

    @property
    def default_value(self):
        """Alias for DefaultValue"""
        return self.DefaultValue

    @default_value.setter
    def default_value(self, value):
        """Alias for DefaultValue.setter"""
        self.DefaultValue = value

    @property
    def DisplayWhen(self):
        return self.com_object.DisplayWhen

    @DisplayWhen.setter
    def DisplayWhen(self, value):
        self.com_object.DisplayWhen = value

    @property
    def displaywhen(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @displaywhen.setter
    def displaywhen(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def display_when(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @display_when.setter
    def display_when(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def FontBold(self):
        return self.com_object.FontBold

    @property
    def fontbold(self):
        """Alias for FontBold"""
        return self.FontBold

    @property
    def font_bold(self):
        """Alias for FontBold"""
        return self.FontBold

    @property
    def FontItalic(self):
        return self.com_object.FontItalic

    @property
    def fontitalic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @property
    def font_italic(self):
        """Alias for FontItalic"""
        return self.FontItalic

    @property
    def FontName(self):
        return self.com_object.FontName

    @property
    def fontname(self):
        """Alias for FontName"""
        return self.FontName

    @property
    def font_name(self):
        """Alias for FontName"""
        return self.FontName

    @property
    def FontSize(self):
        return self.com_object.FontSize

    @property
    def fontsize(self):
        """Alias for FontSize"""
        return self.FontSize

    @property
    def font_size(self):
        """Alias for FontSize"""
        return self.FontSize

    @property
    def FontUnderline(self):
        return self.com_object.FontUnderline

    @property
    def fontunderline(self):
        """Alias for FontUnderline"""
        return self.FontUnderline

    @property
    def font_underline(self):
        """Alias for FontUnderline"""
        return self.FontUnderline

    @property
    def FontWeight(self):
        return self.com_object.FontWeight

    @FontWeight.setter
    def FontWeight(self, value):
        self.com_object.FontWeight = value

    @property
    def fontweight(self):
        """Alias for FontWeight"""
        return self.FontWeight

    @fontweight.setter
    def fontweight(self, value):
        """Alias for FontWeight.setter"""
        self.FontWeight = value

    @property
    def font_weight(self):
        """Alias for FontWeight"""
        return self.FontWeight

    @font_weight.setter
    def font_weight(self, value):
        """Alias for FontWeight.setter"""
        self.FontWeight = value

    @property
    def ForeColor(self):
        return self.com_object.ForeColor

    @ForeColor.setter
    def ForeColor(self, value):
        self.com_object.ForeColor = value

    @property
    def forecolor(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @forecolor.setter
    def forecolor(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def fore_color(self):
        """Alias for ForeColor"""
        return self.ForeColor

    @fore_color.setter
    def fore_color(self, value):
        """Alias for ForeColor.setter"""
        self.ForeColor = value

    @property
    def ForeShade(self):
        return self.com_object.ForeShade

    @ForeShade.setter
    def ForeShade(self, value):
        self.com_object.ForeShade = value

    @property
    def foreshade(self):
        """Alias for ForeShade"""
        return self.ForeShade

    @foreshade.setter
    def foreshade(self, value):
        """Alias for ForeShade.setter"""
        self.ForeShade = value

    @property
    def fore_shade(self):
        """Alias for ForeShade"""
        return self.ForeShade

    @fore_shade.setter
    def fore_shade(self, value):
        """Alias for ForeShade.setter"""
        self.ForeShade = value

    @property
    def ForeThemeColorIndex(self):
        return self.com_object.ForeThemeColorIndex

    @ForeThemeColorIndex.setter
    def ForeThemeColorIndex(self, value):
        self.com_object.ForeThemeColorIndex = value

    @property
    def forethemecolorindex(self):
        """Alias for ForeThemeColorIndex"""
        return self.ForeThemeColorIndex

    @forethemecolorindex.setter
    def forethemecolorindex(self, value):
        """Alias for ForeThemeColorIndex.setter"""
        self.ForeThemeColorIndex = value

    @property
    def fore_theme_color_index(self):
        """Alias for ForeThemeColorIndex"""
        return self.ForeThemeColorIndex

    @fore_theme_color_index.setter
    def fore_theme_color_index(self, value):
        """Alias for ForeThemeColorIndex.setter"""
        self.ForeThemeColorIndex = value

    @property
    def ForeTint(self):
        return self.com_object.ForeTint

    @ForeTint.setter
    def ForeTint(self, value):
        self.com_object.ForeTint = value

    @property
    def foretint(self):
        """Alias for ForeTint"""
        return self.ForeTint

    @foretint.setter
    def foretint(self, value):
        """Alias for ForeTint.setter"""
        self.ForeTint = value

    @property
    def fore_tint(self):
        """Alias for ForeTint"""
        return self.ForeTint

    @fore_tint.setter
    def fore_tint(self, value):
        """Alias for ForeTint.setter"""
        self.ForeTint = value

    @property
    def Glow(self):
        return self.com_object.Glow

    @Glow.setter
    def Glow(self, value):
        self.com_object.Glow = value

    @property
    def glow(self):
        """Alias for Glow"""
        return self.Glow

    @glow.setter
    def glow(self, value):
        """Alias for Glow.setter"""
        self.Glow = value

    @property
    def Gradient(self):
        return self.com_object.Gradient

    @Gradient.setter
    def Gradient(self, value):
        self.com_object.Gradient = value

    @property
    def gradient(self):
        """Alias for Gradient"""
        return self.Gradient

    @gradient.setter
    def gradient(self, value):
        """Alias for Gradient.setter"""
        self.Gradient = value

    @property
    def GridlineColor(self):
        return self.com_object.GridlineColor

    @GridlineColor.setter
    def GridlineColor(self, value):
        self.com_object.GridlineColor = value

    @property
    def gridlinecolor(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridlinecolor.setter
    def gridlinecolor(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def gridline_color(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridline_color.setter
    def gridline_color(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def GridlineShade(self):
        return self.com_object.GridlineShade

    @GridlineShade.setter
    def GridlineShade(self, value):
        self.com_object.GridlineShade = value

    @property
    def gridlineshade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridlineshade.setter
    def gridlineshade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def gridline_shade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridline_shade.setter
    def gridline_shade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def GridlineStyleBottom(self):
        return self.com_object.GridlineStyleBottom

    @GridlineStyleBottom.setter
    def GridlineStyleBottom(self, value):
        self.com_object.GridlineStyleBottom = value

    @property
    def gridlinestylebottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridlinestylebottom.setter
    def gridlinestylebottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def gridline_style_bottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridline_style_bottom.setter
    def gridline_style_bottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def GridlineStyleLeft(self):
        return self.com_object.GridlineStyleLeft

    @GridlineStyleLeft.setter
    def GridlineStyleLeft(self, value):
        self.com_object.GridlineStyleLeft = value

    @property
    def gridlinestyleleft(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridlinestyleleft.setter
    def gridlinestyleleft(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def gridline_style_left(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridline_style_left.setter
    def gridline_style_left(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def GridlineStyleRight(self):
        return self.com_object.GridlineStyleRight

    @GridlineStyleRight.setter
    def GridlineStyleRight(self, value):
        self.com_object.GridlineStyleRight = value

    @property
    def gridlinestyleright(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridlinestyleright.setter
    def gridlinestyleright(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def gridline_style_right(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridline_style_right.setter
    def gridline_style_right(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def GridlineStyleTop(self):
        return self.com_object.GridlineStyleTop

    @GridlineStyleTop.setter
    def GridlineStyleTop(self, value):
        self.com_object.GridlineStyleTop = value

    @property
    def gridlinestyletop(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridlinestyletop.setter
    def gridlinestyletop(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def gridline_style_top(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridline_style_top.setter
    def gridline_style_top(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def GridlineThemeColorIndex(self):
        return self.com_object.GridlineThemeColorIndex

    @GridlineThemeColorIndex.setter
    def GridlineThemeColorIndex(self, value):
        self.com_object.GridlineThemeColorIndex = value

    @property
    def gridlinethemecolorindex(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridlinethemecolorindex.setter
    def gridlinethemecolorindex(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def gridline_theme_color_index(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridline_theme_color_index.setter
    def gridline_theme_color_index(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def GridlineTint(self):
        return self.com_object.GridlineTint

    @GridlineTint.setter
    def GridlineTint(self, value):
        self.com_object.GridlineTint = value

    @property
    def gridlinetint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridlinetint.setter
    def gridlinetint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def gridline_tint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridline_tint.setter
    def gridline_tint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def GridlineWidthBottom(self):
        return self.com_object.GridlineWidthBottom

    @GridlineWidthBottom.setter
    def GridlineWidthBottom(self, value):
        self.com_object.GridlineWidthBottom = value

    @property
    def gridlinewidthbottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridlinewidthbottom.setter
    def gridlinewidthbottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def gridline_width_bottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridline_width_bottom.setter
    def gridline_width_bottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def GridlineWidthLeft(self):
        return self.com_object.GridlineWidthLeft

    @GridlineWidthLeft.setter
    def GridlineWidthLeft(self, value):
        self.com_object.GridlineWidthLeft = value

    @property
    def gridlinewidthleft(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridlinewidthleft.setter
    def gridlinewidthleft(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def gridline_width_left(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridline_width_left.setter
    def gridline_width_left(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def GridlineWidthRight(self):
        return self.com_object.GridlineWidthRight

    @GridlineWidthRight.setter
    def GridlineWidthRight(self, value):
        self.com_object.GridlineWidthRight = value

    @property
    def gridlinewidthright(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridlinewidthright.setter
    def gridlinewidthright(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def gridline_width_right(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridline_width_right.setter
    def gridline_width_right(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def GridlineWidthTop(self):
        return self.com_object.GridlineWidthTop

    @GridlineWidthTop.setter
    def GridlineWidthTop(self, value):
        self.com_object.GridlineWidthTop = value

    @property
    def gridlinewidthtop(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridlinewidthtop.setter
    def gridlinewidthtop(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def gridline_width_top(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridline_width_top.setter
    def gridline_width_top(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HelpContextId(self):
        return self.com_object.HelpContextId

    @HelpContextId.setter
    def HelpContextId(self, value):
        self.com_object.HelpContextId = value

    @property
    def helpcontextid(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @helpcontextid.setter
    def helpcontextid(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def help_context_id(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @help_context_id.setter
    def help_context_id(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def HideDuplicates(self):
        return self.com_object.HideDuplicates

    @HideDuplicates.setter
    def HideDuplicates(self, value):
        self.com_object.HideDuplicates = value

    @property
    def hideduplicates(self):
        """Alias for HideDuplicates"""
        return self.HideDuplicates

    @hideduplicates.setter
    def hideduplicates(self, value):
        """Alias for HideDuplicates.setter"""
        self.HideDuplicates = value

    @property
    def hide_duplicates(self):
        """Alias for HideDuplicates"""
        return self.HideDuplicates

    @hide_duplicates.setter
    def hide_duplicates(self, value):
        """Alias for HideDuplicates.setter"""
        self.HideDuplicates = value

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def HoverColor(self):
        return self.com_object.HoverColor

    @HoverColor.setter
    def HoverColor(self, value):
        self.com_object.HoverColor = value

    @property
    def hovercolor(self):
        """Alias for HoverColor"""
        return self.HoverColor

    @hovercolor.setter
    def hovercolor(self, value):
        """Alias for HoverColor.setter"""
        self.HoverColor = value

    @property
    def hover_color(self):
        """Alias for HoverColor"""
        return self.HoverColor

    @hover_color.setter
    def hover_color(self, value):
        """Alias for HoverColor.setter"""
        self.HoverColor = value

    @property
    def HoverForeColor(self):
        return self.com_object.HoverForeColor

    @HoverForeColor.setter
    def HoverForeColor(self, value):
        self.com_object.HoverForeColor = value

    @property
    def hoverforecolor(self):
        """Alias for HoverForeColor"""
        return self.HoverForeColor

    @hoverforecolor.setter
    def hoverforecolor(self, value):
        """Alias for HoverForeColor.setter"""
        self.HoverForeColor = value

    @property
    def hover_fore_color(self):
        """Alias for HoverForeColor"""
        return self.HoverForeColor

    @hover_fore_color.setter
    def hover_fore_color(self, value):
        """Alias for HoverForeColor.setter"""
        self.HoverForeColor = value

    @property
    def HoverForeShade(self):
        return self.com_object.HoverForeShade

    @HoverForeShade.setter
    def HoverForeShade(self, value):
        self.com_object.HoverForeShade = value

    @property
    def hoverforeshade(self):
        """Alias for HoverForeShade"""
        return self.HoverForeShade

    @hoverforeshade.setter
    def hoverforeshade(self, value):
        """Alias for HoverForeShade.setter"""
        self.HoverForeShade = value

    @property
    def hover_fore_shade(self):
        """Alias for HoverForeShade"""
        return self.HoverForeShade

    @hover_fore_shade.setter
    def hover_fore_shade(self, value):
        """Alias for HoverForeShade.setter"""
        self.HoverForeShade = value

    @property
    def HoverForeThemeColorIndex(self):
        return self.com_object.HoverForeThemeColorIndex

    @HoverForeThemeColorIndex.setter
    def HoverForeThemeColorIndex(self, value):
        self.com_object.HoverForeThemeColorIndex = value

    @property
    def hoverforethemecolorindex(self):
        """Alias for HoverForeThemeColorIndex"""
        return self.HoverForeThemeColorIndex

    @hoverforethemecolorindex.setter
    def hoverforethemecolorindex(self, value):
        """Alias for HoverForeThemeColorIndex.setter"""
        self.HoverForeThemeColorIndex = value

    @property
    def hover_fore_theme_color_index(self):
        """Alias for HoverForeThemeColorIndex"""
        return self.HoverForeThemeColorIndex

    @hover_fore_theme_color_index.setter
    def hover_fore_theme_color_index(self, value):
        """Alias for HoverForeThemeColorIndex.setter"""
        self.HoverForeThemeColorIndex = value

    @property
    def HoverForeTint(self):
        return self.com_object.HoverForeTint

    @HoverForeTint.setter
    def HoverForeTint(self, value):
        self.com_object.HoverForeTint = value

    @property
    def hoverforetint(self):
        """Alias for HoverForeTint"""
        return self.HoverForeTint

    @hoverforetint.setter
    def hoverforetint(self, value):
        """Alias for HoverForeTint.setter"""
        self.HoverForeTint = value

    @property
    def hover_fore_tint(self):
        """Alias for HoverForeTint"""
        return self.HoverForeTint

    @hover_fore_tint.setter
    def hover_fore_tint(self, value):
        """Alias for HoverForeTint.setter"""
        self.HoverForeTint = value

    @property
    def HoverShade(self):
        return self.com_object.HoverShade

    @HoverShade.setter
    def HoverShade(self, value):
        self.com_object.HoverShade = value

    @property
    def hovershade(self):
        """Alias for HoverShade"""
        return self.HoverShade

    @hovershade.setter
    def hovershade(self, value):
        """Alias for HoverShade.setter"""
        self.HoverShade = value

    @property
    def hover_shade(self):
        """Alias for HoverShade"""
        return self.HoverShade

    @hover_shade.setter
    def hover_shade(self, value):
        """Alias for HoverShade.setter"""
        self.HoverShade = value

    @property
    def HoverThemeColorIndex(self):
        return self.com_object.HoverThemeColorIndex

    @HoverThemeColorIndex.setter
    def HoverThemeColorIndex(self, value):
        self.com_object.HoverThemeColorIndex = value

    @property
    def hoverthemecolorindex(self):
        """Alias for HoverThemeColorIndex"""
        return self.HoverThemeColorIndex

    @hoverthemecolorindex.setter
    def hoverthemecolorindex(self, value):
        """Alias for HoverThemeColorIndex.setter"""
        self.HoverThemeColorIndex = value

    @property
    def hover_theme_color_index(self):
        """Alias for HoverThemeColorIndex"""
        return self.HoverThemeColorIndex

    @hover_theme_color_index.setter
    def hover_theme_color_index(self, value):
        """Alias for HoverThemeColorIndex.setter"""
        self.HoverThemeColorIndex = value

    @property
    def HoverTint(self):
        return self.com_object.HoverTint

    @HoverTint.setter
    def HoverTint(self, value):
        self.com_object.HoverTint = value

    @property
    def hovertint(self):
        """Alias for HoverTint"""
        return self.HoverTint

    @hovertint.setter
    def hovertint(self, value):
        """Alias for HoverTint.setter"""
        self.HoverTint = value

    @property
    def hover_tint(self):
        """Alias for HoverTint"""
        return self.HoverTint

    @hover_tint.setter
    def hover_tint(self, value):
        """Alias for HoverTint.setter"""
        self.HoverTint = value

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def IsVisible(self):
        return self.com_object.IsVisible

    @IsVisible.setter
    def IsVisible(self, value):
        self.com_object.IsVisible = value

    @property
    def isvisible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @isvisible.setter
    def isvisible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def is_visible(self):
        """Alias for IsVisible"""
        return self.IsVisible

    @is_visible.setter
    def is_visible(self, value):
        """Alias for IsVisible.setter"""
        self.IsVisible = value

    @property
    def LabelAlign(self):
        return self.com_object.LabelAlign

    @LabelAlign.setter
    def LabelAlign(self, value):
        self.com_object.LabelAlign = value

    @property
    def labelalign(self):
        """Alias for LabelAlign"""
        return self.LabelAlign

    @labelalign.setter
    def labelalign(self, value):
        """Alias for LabelAlign.setter"""
        self.LabelAlign = value

    @property
    def label_align(self):
        """Alias for LabelAlign"""
        return self.LabelAlign

    @label_align.setter
    def label_align(self, value):
        """Alias for LabelAlign.setter"""
        self.LabelAlign = value

    @property
    def LabelX(self):
        return self.com_object.LabelX

    @LabelX.setter
    def LabelX(self, value):
        self.com_object.LabelX = value

    @property
    def labelx(self):
        """Alias for LabelX"""
        return self.LabelX

    @labelx.setter
    def labelx(self, value):
        """Alias for LabelX.setter"""
        self.LabelX = value

    @property
    def label_x(self):
        """Alias for LabelX"""
        return self.LabelX

    @label_x.setter
    def label_x(self, value):
        """Alias for LabelX.setter"""
        self.LabelX = value

    @property
    def LabelY(self):
        return self.com_object.LabelY

    @LabelY.setter
    def LabelY(self, value):
        self.com_object.LabelY = value

    @property
    def labely(self):
        """Alias for LabelY"""
        return self.LabelY

    @labely.setter
    def labely(self, value):
        """Alias for LabelY.setter"""
        self.LabelY = value

    @property
    def label_y(self):
        """Alias for LabelY"""
        return self.LabelY

    @label_y.setter
    def label_y(self, value):
        """Alias for LabelY.setter"""
        self.LabelY = value

    @property
    def Layout(self):
        return AcLayoutType(self.com_object.Layout)

    @property
    def layout(self):
        """Alias for Layout"""
        return self.Layout

    @property
    def LayoutID(self):
        return self.com_object.LayoutID

    @property
    def layoutid(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def layout_i_d(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def LeftPadding(self):
        return self.com_object.LeftPadding

    @LeftPadding.setter
    def LeftPadding(self, value):
        self.com_object.LeftPadding = value

    @property
    def leftpadding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @leftpadding.setter
    def leftpadding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def left_padding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @left_padding.setter
    def left_padding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def Locked(self):
        return self.com_object.Locked

    @Locked.setter
    def Locked(self, value):
        self.com_object.Locked = value

    @property
    def locked(self):
        """Alias for Locked"""
        return self.Locked

    @locked.setter
    def locked(self, value):
        """Alias for Locked.setter"""
        self.Locked = value

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def ObjectPalette(self):
        return self.com_object.ObjectPalette

    @ObjectPalette.setter
    def ObjectPalette(self, value):
        self.com_object.ObjectPalette = value

    @property
    def objectpalette(self):
        """Alias for ObjectPalette"""
        return self.ObjectPalette

    @objectpalette.setter
    def objectpalette(self, value):
        """Alias for ObjectPalette.setter"""
        self.ObjectPalette = value

    @property
    def object_palette(self):
        """Alias for ObjectPalette"""
        return self.ObjectPalette

    @object_palette.setter
    def object_palette(self, value):
        """Alias for ObjectPalette.setter"""
        self.ObjectPalette = value

    @property
    def OldValue(self):
        return self.com_object.OldValue

    @property
    def oldvalue(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def old_value(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def OnClick(self):
        return self.com_object.OnClick

    @OnClick.setter
    def OnClick(self, value):
        self.com_object.OnClick = value

    @property
    def onclick(self):
        """Alias for OnClick"""
        return self.OnClick

    @onclick.setter
    def onclick(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def on_click(self):
        """Alias for OnClick"""
        return self.OnClick

    @on_click.setter
    def on_click(self, value):
        """Alias for OnClick.setter"""
        self.OnClick = value

    @property
    def OnDblClick(self):
        return self.com_object.OnDblClick

    @OnDblClick.setter
    def OnDblClick(self, value):
        self.com_object.OnDblClick = value

    @property
    def ondblclick(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @ondblclick.setter
    def ondblclick(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def on_dbl_click(self):
        """Alias for OnDblClick"""
        return self.OnDblClick

    @on_dbl_click.setter
    def on_dbl_click(self, value):
        """Alias for OnDblClick.setter"""
        self.OnDblClick = value

    @property
    def OnEnter(self):
        return self.com_object.OnEnter

    @OnEnter.setter
    def OnEnter(self, value):
        self.com_object.OnEnter = value

    @property
    def onenter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @onenter.setter
    def onenter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def on_enter(self):
        """Alias for OnEnter"""
        return self.OnEnter

    @on_enter.setter
    def on_enter(self, value):
        """Alias for OnEnter.setter"""
        self.OnEnter = value

    @property
    def OnExit(self):
        return self.com_object.OnExit

    @OnExit.setter
    def OnExit(self, value):
        self.com_object.OnExit = value

    @property
    def onexit(self):
        """Alias for OnExit"""
        return self.OnExit

    @onexit.setter
    def onexit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def on_exit(self):
        """Alias for OnExit"""
        return self.OnExit

    @on_exit.setter
    def on_exit(self, value):
        """Alias for OnExit.setter"""
        self.OnExit = value

    @property
    def OnGotFocus(self):
        return self.com_object.OnGotFocus

    @OnGotFocus.setter
    def OnGotFocus(self, value):
        self.com_object.OnGotFocus = value

    @property
    def ongotfocus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @ongotfocus.setter
    def ongotfocus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def on_got_focus(self):
        """Alias for OnGotFocus"""
        return self.OnGotFocus

    @on_got_focus.setter
    def on_got_focus(self, value):
        """Alias for OnGotFocus.setter"""
        self.OnGotFocus = value

    @property
    def OnKeyDown(self):
        return self.com_object.OnKeyDown

    @OnKeyDown.setter
    def OnKeyDown(self, value):
        self.com_object.OnKeyDown = value

    @property
    def onkeydown(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @onkeydown.setter
    def onkeydown(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def on_key_down(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @on_key_down.setter
    def on_key_down(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def OnKeyPress(self):
        return self.com_object.OnKeyPress

    @OnKeyPress.setter
    def OnKeyPress(self, value):
        self.com_object.OnKeyPress = value

    @property
    def onkeypress(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @onkeypress.setter
    def onkeypress(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def on_key_press(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @on_key_press.setter
    def on_key_press(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def OnKeyUp(self):
        return self.com_object.OnKeyUp

    @OnKeyUp.setter
    def OnKeyUp(self, value):
        self.com_object.OnKeyUp = value

    @property
    def onkeyup(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @onkeyup.setter
    def onkeyup(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def on_key_up(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @on_key_up.setter
    def on_key_up(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def OnLostFocus(self):
        return self.com_object.OnLostFocus

    @OnLostFocus.setter
    def OnLostFocus(self, value):
        self.com_object.OnLostFocus = value

    @property
    def onlostfocus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @onlostfocus.setter
    def onlostfocus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def on_lost_focus(self):
        """Alias for OnLostFocus"""
        return self.OnLostFocus

    @on_lost_focus.setter
    def on_lost_focus(self, value):
        """Alias for OnLostFocus.setter"""
        self.OnLostFocus = value

    @property
    def OnMouseDown(self):
        return self.com_object.OnMouseDown

    @OnMouseDown.setter
    def OnMouseDown(self, value):
        self.com_object.OnMouseDown = value

    @property
    def onmousedown(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @onmousedown.setter
    def onmousedown(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def on_mouse_down(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @on_mouse_down.setter
    def on_mouse_down(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def OnMouseMove(self):
        return self.com_object.OnMouseMove

    @OnMouseMove.setter
    def OnMouseMove(self, value):
        self.com_object.OnMouseMove = value

    @property
    def onmousemove(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @onmousemove.setter
    def onmousemove(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def on_mouse_move(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @on_mouse_move.setter
    def on_mouse_move(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def OnMouseUp(self):
        return self.com_object.OnMouseUp

    @OnMouseUp.setter
    def OnMouseUp(self, value):
        self.com_object.OnMouseUp = value

    @property
    def onmouseup(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @onmouseup.setter
    def onmouseup(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def on_mouse_up(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @on_mouse_up.setter
    def on_mouse_up(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def OptionValue(self):
        return self.com_object.OptionValue

    @OptionValue.setter
    def OptionValue(self, value):
        self.com_object.OptionValue = value

    @property
    def optionvalue(self):
        """Alias for OptionValue"""
        return self.OptionValue

    @optionvalue.setter
    def optionvalue(self, value):
        """Alias for OptionValue.setter"""
        self.OptionValue = value

    @property
    def option_value(self):
        """Alias for OptionValue"""
        return self.OptionValue

    @option_value.setter
    def option_value(self, value):
        """Alias for OptionValue.setter"""
        self.OptionValue = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Picture(self):
        return self.com_object.Picture

    @Picture.setter
    def Picture(self, value):
        self.com_object.Picture = value

    @property
    def picture(self):
        """Alias for Picture"""
        return self.Picture

    @picture.setter
    def picture(self, value):
        """Alias for Picture.setter"""
        self.Picture = value

    @property
    def PictureData(self):
        return self.com_object.PictureData

    @PictureData.setter
    def PictureData(self, value):
        self.com_object.PictureData = value

    @property
    def picturedata(self):
        """Alias for PictureData"""
        return self.PictureData

    @picturedata.setter
    def picturedata(self, value):
        """Alias for PictureData.setter"""
        self.PictureData = value

    @property
    def picture_data(self):
        """Alias for PictureData"""
        return self.PictureData

    @picture_data.setter
    def picture_data(self, value):
        """Alias for PictureData.setter"""
        self.PictureData = value

    @property
    def PictureType(self):
        return self.com_object.PictureType

    @PictureType.setter
    def PictureType(self, value):
        self.com_object.PictureType = value

    @property
    def picturetype(self):
        """Alias for PictureType"""
        return self.PictureType

    @picturetype.setter
    def picturetype(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def picture_type(self):
        """Alias for PictureType"""
        return self.PictureType

    @picture_type.setter
    def picture_type(self, value):
        """Alias for PictureType.setter"""
        self.PictureType = value

    @property
    def PressedColor(self):
        return self.com_object.PressedColor

    @PressedColor.setter
    def PressedColor(self, value):
        self.com_object.PressedColor = value

    @property
    def pressedcolor(self):
        """Alias for PressedColor"""
        return self.PressedColor

    @pressedcolor.setter
    def pressedcolor(self, value):
        """Alias for PressedColor.setter"""
        self.PressedColor = value

    @property
    def pressed_color(self):
        """Alias for PressedColor"""
        return self.PressedColor

    @pressed_color.setter
    def pressed_color(self, value):
        """Alias for PressedColor.setter"""
        self.PressedColor = value

    @property
    def PressedForeColor(self):
        return self.com_object.PressedForeColor

    @PressedForeColor.setter
    def PressedForeColor(self, value):
        self.com_object.PressedForeColor = value

    @property
    def pressedforecolor(self):
        """Alias for PressedForeColor"""
        return self.PressedForeColor

    @pressedforecolor.setter
    def pressedforecolor(self, value):
        """Alias for PressedForeColor.setter"""
        self.PressedForeColor = value

    @property
    def pressed_fore_color(self):
        """Alias for PressedForeColor"""
        return self.PressedForeColor

    @pressed_fore_color.setter
    def pressed_fore_color(self, value):
        """Alias for PressedForeColor.setter"""
        self.PressedForeColor = value

    @property
    def PressedForeShade(self):
        return self.com_object.PressedForeShade

    @PressedForeShade.setter
    def PressedForeShade(self, value):
        self.com_object.PressedForeShade = value

    @property
    def pressedforeshade(self):
        """Alias for PressedForeShade"""
        return self.PressedForeShade

    @pressedforeshade.setter
    def pressedforeshade(self, value):
        """Alias for PressedForeShade.setter"""
        self.PressedForeShade = value

    @property
    def pressed_fore_shade(self):
        """Alias for PressedForeShade"""
        return self.PressedForeShade

    @pressed_fore_shade.setter
    def pressed_fore_shade(self, value):
        """Alias for PressedForeShade.setter"""
        self.PressedForeShade = value

    @property
    def PressedForeThemeColorIndex(self):
        return self.com_object.PressedForeThemeColorIndex

    @PressedForeThemeColorIndex.setter
    def PressedForeThemeColorIndex(self, value):
        self.com_object.PressedForeThemeColorIndex = value

    @property
    def pressedforethemecolorindex(self):
        """Alias for PressedForeThemeColorIndex"""
        return self.PressedForeThemeColorIndex

    @pressedforethemecolorindex.setter
    def pressedforethemecolorindex(self, value):
        """Alias for PressedForeThemeColorIndex.setter"""
        self.PressedForeThemeColorIndex = value

    @property
    def pressed_fore_theme_color_index(self):
        """Alias for PressedForeThemeColorIndex"""
        return self.PressedForeThemeColorIndex

    @pressed_fore_theme_color_index.setter
    def pressed_fore_theme_color_index(self, value):
        """Alias for PressedForeThemeColorIndex.setter"""
        self.PressedForeThemeColorIndex = value

    @property
    def PressedForeTint(self):
        return self.com_object.PressedForeTint

    @PressedForeTint.setter
    def PressedForeTint(self, value):
        self.com_object.PressedForeTint = value

    @property
    def pressedforetint(self):
        """Alias for PressedForeTint"""
        return self.PressedForeTint

    @pressedforetint.setter
    def pressedforetint(self, value):
        """Alias for PressedForeTint.setter"""
        self.PressedForeTint = value

    @property
    def pressed_fore_tint(self):
        """Alias for PressedForeTint"""
        return self.PressedForeTint

    @pressed_fore_tint.setter
    def pressed_fore_tint(self, value):
        """Alias for PressedForeTint.setter"""
        self.PressedForeTint = value

    @property
    def PressedShade(self):
        return self.com_object.PressedShade

    @PressedShade.setter
    def PressedShade(self, value):
        self.com_object.PressedShade = value

    @property
    def pressedshade(self):
        """Alias for PressedShade"""
        return self.PressedShade

    @pressedshade.setter
    def pressedshade(self, value):
        """Alias for PressedShade.setter"""
        self.PressedShade = value

    @property
    def pressed_shade(self):
        """Alias for PressedShade"""
        return self.PressedShade

    @pressed_shade.setter
    def pressed_shade(self, value):
        """Alias for PressedShade.setter"""
        self.PressedShade = value

    @property
    def PressedThemeColorIndex(self):
        return self.com_object.PressedThemeColorIndex

    @PressedThemeColorIndex.setter
    def PressedThemeColorIndex(self, value):
        self.com_object.PressedThemeColorIndex = value

    @property
    def pressedthemecolorindex(self):
        """Alias for PressedThemeColorIndex"""
        return self.PressedThemeColorIndex

    @pressedthemecolorindex.setter
    def pressedthemecolorindex(self, value):
        """Alias for PressedThemeColorIndex.setter"""
        self.PressedThemeColorIndex = value

    @property
    def pressed_theme_color_index(self):
        """Alias for PressedThemeColorIndex"""
        return self.PressedThemeColorIndex

    @pressed_theme_color_index.setter
    def pressed_theme_color_index(self, value):
        """Alias for PressedThemeColorIndex.setter"""
        self.PressedThemeColorIndex = value

    @property
    def PressedTint(self):
        return self.com_object.PressedTint

    @PressedTint.setter
    def PressedTint(self, value):
        self.com_object.PressedTint = value

    @property
    def pressedtint(self):
        """Alias for PressedTint"""
        return self.PressedTint

    @pressedtint.setter
    def pressedtint(self, value):
        """Alias for PressedTint.setter"""
        self.PressedTint = value

    @property
    def pressed_tint(self):
        """Alias for PressedTint"""
        return self.PressedTint

    @pressed_tint.setter
    def pressed_tint(self, value):
        """Alias for PressedTint.setter"""
        self.PressedTint = value

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def QuickStyle(self):
        return self.com_object.QuickStyle

    @QuickStyle.setter
    def QuickStyle(self, value):
        self.com_object.QuickStyle = value

    @property
    def quickstyle(self):
        """Alias for QuickStyle"""
        return self.QuickStyle

    @quickstyle.setter
    def quickstyle(self, value):
        """Alias for QuickStyle.setter"""
        self.QuickStyle = value

    @property
    def quick_style(self):
        """Alias for QuickStyle"""
        return self.QuickStyle

    @quick_style.setter
    def quick_style(self, value):
        """Alias for QuickStyle.setter"""
        self.QuickStyle = value

    @property
    def QuickStyleMask(self):
        return self.com_object.QuickStyleMask

    @QuickStyleMask.setter
    def QuickStyleMask(self, value):
        self.com_object.QuickStyleMask = value

    @property
    def quickstylemask(self):
        """Alias for QuickStyleMask"""
        return self.QuickStyleMask

    @quickstylemask.setter
    def quickstylemask(self, value):
        """Alias for QuickStyleMask.setter"""
        self.QuickStyleMask = value

    @property
    def quick_style_mask(self):
        """Alias for QuickStyleMask"""
        return self.QuickStyleMask

    @quick_style_mask.setter
    def quick_style_mask(self, value):
        """Alias for QuickStyleMask.setter"""
        self.QuickStyleMask = value

    @property
    def ReadingOrder(self):
        return self.com_object.ReadingOrder

    @ReadingOrder.setter
    def ReadingOrder(self, value):
        self.com_object.ReadingOrder = value

    @property
    def readingorder(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @readingorder.setter
    def readingorder(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def reading_order(self):
        """Alias for ReadingOrder"""
        return self.ReadingOrder

    @reading_order.setter
    def reading_order(self, value):
        """Alias for ReadingOrder.setter"""
        self.ReadingOrder = value

    @property
    def RightPadding(self):
        return self.com_object.RightPadding

    @RightPadding.setter
    def RightPadding(self, value):
        self.com_object.RightPadding = value

    @property
    def rightpadding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @rightpadding.setter
    def rightpadding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def right_padding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @right_padding.setter
    def right_padding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def Section(self):
        return self.com_object.Section

    @Section.setter
    def Section(self, value):
        self.com_object.Section = value

    @property
    def section(self):
        """Alias for Section"""
        return self.Section

    @section.setter
    def section(self, value):
        """Alias for Section.setter"""
        self.Section = value

    @property
    def Shadow(self):
        return self.com_object.Shadow

    @Shadow.setter
    def Shadow(self, value):
        self.com_object.Shadow = value

    @property
    def shadow(self):
        """Alias for Shadow"""
        return self.Shadow

    @shadow.setter
    def shadow(self, value):
        """Alias for Shadow.setter"""
        self.Shadow = value

    @property
    def Shape(self):
        return self.com_object.Shape

    @Shape.setter
    def Shape(self, value):
        self.com_object.Shape = value

    @property
    def shape(self):
        """Alias for Shape"""
        return self.Shape

    @shape.setter
    def shape(self, value):
        """Alias for Shape.setter"""
        self.Shape = value

    @property
    def ShortcutMenuBar(self):
        return self.com_object.ShortcutMenuBar

    @ShortcutMenuBar.setter
    def ShortcutMenuBar(self, value):
        self.com_object.ShortcutMenuBar = value

    @property
    def shortcutmenubar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcutmenubar.setter
    def shortcutmenubar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def shortcut_menu_bar(self):
        """Alias for ShortcutMenuBar"""
        return self.ShortcutMenuBar

    @shortcut_menu_bar.setter
    def shortcut_menu_bar(self, value):
        """Alias for ShortcutMenuBar.setter"""
        self.ShortcutMenuBar = value

    @property
    def SoftEdges(self):
        return self.com_object.SoftEdges

    @SoftEdges.setter
    def SoftEdges(self, value):
        self.com_object.SoftEdges = value

    @property
    def softedges(self):
        """Alias for SoftEdges"""
        return self.SoftEdges

    @softedges.setter
    def softedges(self, value):
        """Alias for SoftEdges.setter"""
        self.SoftEdges = value

    @property
    def soft_edges(self):
        """Alias for SoftEdges"""
        return self.SoftEdges

    @soft_edges.setter
    def soft_edges(self, value):
        """Alias for SoftEdges.setter"""
        self.SoftEdges = value

    @property
    def StatusBarText(self):
        return self.com_object.StatusBarText

    @StatusBarText.setter
    def StatusBarText(self, value):
        self.com_object.StatusBarText = value

    @property
    def statusbartext(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @statusbartext.setter
    def statusbartext(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def status_bar_text(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @status_bar_text.setter
    def status_bar_text(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def TabIndex(self):
        return self.com_object.TabIndex

    @TabIndex.setter
    def TabIndex(self, value):
        self.com_object.TabIndex = value

    @property
    def tabindex(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tabindex.setter
    def tabindex(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def tab_index(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tab_index.setter
    def tab_index(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def TabStop(self):
        return self.com_object.TabStop

    @TabStop.setter
    def TabStop(self, value):
        self.com_object.TabStop = value

    @property
    def tabstop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tabstop.setter
    def tabstop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def tab_stop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tab_stop.setter
    def tab_stop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def ThemeFontIndex(self):
        return self.com_object.ThemeFontIndex

    @ThemeFontIndex.setter
    def ThemeFontIndex(self, value):
        self.com_object.ThemeFontIndex = value

    @property
    def themefontindex(self):
        """Alias for ThemeFontIndex"""
        return self.ThemeFontIndex

    @themefontindex.setter
    def themefontindex(self, value):
        """Alias for ThemeFontIndex.setter"""
        self.ThemeFontIndex = value

    @property
    def theme_font_index(self):
        """Alias for ThemeFontIndex"""
        return self.ThemeFontIndex

    @theme_font_index.setter
    def theme_font_index(self, value):
        """Alias for ThemeFontIndex.setter"""
        self.ThemeFontIndex = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TopPadding(self):
        return self.com_object.TopPadding

    @TopPadding.setter
    def TopPadding(self, value):
        self.com_object.TopPadding = value

    @property
    def toppadding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @toppadding.setter
    def toppadding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def top_padding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @top_padding.setter
    def top_padding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def TripleState(self):
        return self.com_object.TripleState

    @TripleState.setter
    def TripleState(self, value):
        self.com_object.TripleState = value

    @property
    def triplestate(self):
        """Alias for TripleState"""
        return self.TripleState

    @triplestate.setter
    def triplestate(self, value):
        """Alias for TripleState.setter"""
        self.TripleState = value

    @property
    def triple_state(self):
        """Alias for TripleState"""
        return self.TripleState

    @triple_state.setter
    def triple_state(self, value):
        """Alias for TripleState.setter"""
        self.TripleState = value

    @property
    def UseTheme(self):
        return self.com_object.UseTheme

    @UseTheme.setter
    def UseTheme(self, value):
        self.com_object.UseTheme = value

    @property
    def usetheme(self):
        """Alias for UseTheme"""
        return self.UseTheme

    @usetheme.setter
    def usetheme(self, value):
        """Alias for UseTheme.setter"""
        self.UseTheme = value

    @property
    def use_theme(self):
        """Alias for UseTheme"""
        return self.UseTheme

    @use_theme.setter
    def use_theme(self, value):
        """Alias for UseTheme.setter"""
        self.UseTheme = value

    @property
    def ValidationRule(self):
        return self.com_object.ValidationRule

    @ValidationRule.setter
    def ValidationRule(self, value):
        self.com_object.ValidationRule = value

    @property
    def validationrule(self):
        """Alias for ValidationRule"""
        return self.ValidationRule

    @validationrule.setter
    def validationrule(self, value):
        """Alias for ValidationRule.setter"""
        self.ValidationRule = value

    @property
    def validation_rule(self):
        """Alias for ValidationRule"""
        return self.ValidationRule

    @validation_rule.setter
    def validation_rule(self, value):
        """Alias for ValidationRule.setter"""
        self.ValidationRule = value

    @property
    def ValidationText(self):
        return self.com_object.ValidationText

    @ValidationText.setter
    def ValidationText(self, value):
        self.com_object.ValidationText = value

    @property
    def validationtext(self):
        """Alias for ValidationText"""
        return self.ValidationText

    @validationtext.setter
    def validationtext(self, value):
        """Alias for ValidationText.setter"""
        self.ValidationText = value

    @property
    def validation_text(self):
        """Alias for ValidationText"""
        return self.ValidationText

    @validation_text.setter
    def validation_text(self, value):
        """Alias for ValidationText.setter"""
        self.ValidationText = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def Requery(self):
        self.com_object.Requery()

    def requery(self):
        """Alias for Requery"""
        return self.Requery()

    def SetFocus(self):
        return self.com_object.SetFocus()

    def setfocus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def set_focus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def Undo(self):
        self.com_object.Undo()

    def undo(self):
        """Alias for Undo"""
        return self.Undo()


class WebBrowserControl:

    def __init__(self, webbrowsercontrol=None):
        self.com_object= webbrowsercontrol

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def BorderColor(self):
        return self.com_object.BorderColor

    @BorderColor.setter
    def BorderColor(self, value):
        self.com_object.BorderColor = value

    @property
    def bordercolor(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @bordercolor.setter
    def bordercolor(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def border_color(self):
        """Alias for BorderColor"""
        return self.BorderColor

    @border_color.setter
    def border_color(self, value):
        """Alias for BorderColor.setter"""
        self.BorderColor = value

    @property
    def BorderShade(self):
        return self.com_object.BorderShade

    @BorderShade.setter
    def BorderShade(self, value):
        self.com_object.BorderShade = value

    @property
    def bordershade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @bordershade.setter
    def bordershade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def border_shade(self):
        """Alias for BorderShade"""
        return self.BorderShade

    @border_shade.setter
    def border_shade(self, value):
        """Alias for BorderShade.setter"""
        self.BorderShade = value

    @property
    def BorderStyle(self):
        return self.com_object.BorderStyle

    @BorderStyle.setter
    def BorderStyle(self, value):
        self.com_object.BorderStyle = value

    @property
    def borderstyle(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @borderstyle.setter
    def borderstyle(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def border_style(self):
        """Alias for BorderStyle"""
        return self.BorderStyle

    @border_style.setter
    def border_style(self, value):
        """Alias for BorderStyle.setter"""
        self.BorderStyle = value

    @property
    def BorderThemeColorIndex(self):
        return self.com_object.BorderThemeColorIndex

    @BorderThemeColorIndex.setter
    def BorderThemeColorIndex(self, value):
        self.com_object.BorderThemeColorIndex = value

    @property
    def borderthemecolorindex(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @borderthemecolorindex.setter
    def borderthemecolorindex(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def border_theme_color_index(self):
        """Alias for BorderThemeColorIndex"""
        return self.BorderThemeColorIndex

    @border_theme_color_index.setter
    def border_theme_color_index(self, value):
        """Alias for BorderThemeColorIndex.setter"""
        self.BorderThemeColorIndex = value

    @property
    def BorderTint(self):
        return self.com_object.BorderTint

    @BorderTint.setter
    def BorderTint(self, value):
        self.com_object.BorderTint = value

    @property
    def bordertint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @bordertint.setter
    def bordertint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def border_tint(self):
        """Alias for BorderTint"""
        return self.BorderTint

    @border_tint.setter
    def border_tint(self, value):
        """Alias for BorderTint.setter"""
        self.BorderTint = value

    @property
    def BorderWidth(self):
        return self.com_object.BorderWidth

    @BorderWidth.setter
    def BorderWidth(self, value):
        self.com_object.BorderWidth = value

    @property
    def borderwidth(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @borderwidth.setter
    def borderwidth(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def border_width(self):
        """Alias for BorderWidth"""
        return self.BorderWidth

    @border_width.setter
    def border_width(self, value):
        """Alias for BorderWidth.setter"""
        self.BorderWidth = value

    @property
    def BottomPadding(self):
        return self.com_object.BottomPadding

    @BottomPadding.setter
    def BottomPadding(self, value):
        self.com_object.BottomPadding = value

    @property
    def bottompadding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottompadding.setter
    def bottompadding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def bottom_padding(self):
        """Alias for BottomPadding"""
        return self.BottomPadding

    @bottom_padding.setter
    def bottom_padding(self, value):
        """Alias for BottomPadding.setter"""
        self.BottomPadding = value

    @property
    def Controls(self):
        return Controls(self.com_object.Controls)

    @property
    def controls(self):
        """Alias for Controls"""
        return self.Controls

    @property
    def ControlSource(self):
        return self.com_object.ControlSource

    @ControlSource.setter
    def ControlSource(self, value):
        self.com_object.ControlSource = value

    @property
    def controlsource(self):
        """Alias for ControlSource"""
        return self.ControlSource

    @controlsource.setter
    def controlsource(self, value):
        """Alias for ControlSource.setter"""
        self.ControlSource = value

    @property
    def control_source(self):
        """Alias for ControlSource"""
        return self.ControlSource

    @control_source.setter
    def control_source(self, value):
        """Alias for ControlSource.setter"""
        self.ControlSource = value

    @property
    def ControlTipText(self):
        return self.com_object.ControlTipText

    @ControlTipText.setter
    def ControlTipText(self, value):
        self.com_object.ControlTipText = value

    @property
    def controltiptext(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @controltiptext.setter
    def controltiptext(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def control_tip_text(self):
        """Alias for ControlTipText"""
        return self.ControlTipText

    @control_tip_text.setter
    def control_tip_text(self, value):
        """Alias for ControlTipText.setter"""
        self.ControlTipText = value

    @property
    def ControlType(self):
        return self.com_object.ControlType

    @ControlType.setter
    def ControlType(self, value):
        self.com_object.ControlType = value

    @property
    def controltype(self):
        """Alias for ControlType"""
        return self.ControlType

    @controltype.setter
    def controltype(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def control_type(self):
        """Alias for ControlType"""
        return self.ControlType

    @control_type.setter
    def control_type(self, value):
        """Alias for ControlType.setter"""
        self.ControlType = value

    @property
    def DisplayWhen(self):
        return self.com_object.DisplayWhen

    @DisplayWhen.setter
    def DisplayWhen(self, value):
        self.com_object.DisplayWhen = value

    @property
    def displaywhen(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @displaywhen.setter
    def displaywhen(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def display_when(self):
        """Alias for DisplayWhen"""
        return self.DisplayWhen

    @display_when.setter
    def display_when(self, value):
        """Alias for DisplayWhen.setter"""
        self.DisplayWhen = value

    @property
    def Enabled(self):
        return self.com_object.Enabled

    @Enabled.setter
    def Enabled(self, value):
        self.com_object.Enabled = value

    @property
    def enabled(self):
        """Alias for Enabled"""
        return self.Enabled

    @enabled.setter
    def enabled(self, value):
        """Alias for Enabled.setter"""
        self.Enabled = value

    @property
    def EventProcPrefix(self):
        return self.com_object.EventProcPrefix

    @EventProcPrefix.setter
    def EventProcPrefix(self, value):
        self.com_object.EventProcPrefix = value

    @property
    def eventprocprefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @eventprocprefix.setter
    def eventprocprefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def event_proc_prefix(self):
        """Alias for EventProcPrefix"""
        return self.EventProcPrefix

    @event_proc_prefix.setter
    def event_proc_prefix(self, value):
        """Alias for EventProcPrefix.setter"""
        self.EventProcPrefix = value

    @property
    def GridlineColor(self):
        return self.com_object.GridlineColor

    @GridlineColor.setter
    def GridlineColor(self, value):
        self.com_object.GridlineColor = value

    @property
    def gridlinecolor(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridlinecolor.setter
    def gridlinecolor(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def gridline_color(self):
        """Alias for GridlineColor"""
        return self.GridlineColor

    @gridline_color.setter
    def gridline_color(self, value):
        """Alias for GridlineColor.setter"""
        self.GridlineColor = value

    @property
    def GridlineShade(self):
        return self.com_object.GridlineShade

    @GridlineShade.setter
    def GridlineShade(self, value):
        self.com_object.GridlineShade = value

    @property
    def gridlineshade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridlineshade.setter
    def gridlineshade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def gridline_shade(self):
        """Alias for GridlineShade"""
        return self.GridlineShade

    @gridline_shade.setter
    def gridline_shade(self, value):
        """Alias for GridlineShade.setter"""
        self.GridlineShade = value

    @property
    def GridlineStyleBottom(self):
        return self.com_object.GridlineStyleBottom

    @GridlineStyleBottom.setter
    def GridlineStyleBottom(self, value):
        self.com_object.GridlineStyleBottom = value

    @property
    def gridlinestylebottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridlinestylebottom.setter
    def gridlinestylebottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def gridline_style_bottom(self):
        """Alias for GridlineStyleBottom"""
        return self.GridlineStyleBottom

    @gridline_style_bottom.setter
    def gridline_style_bottom(self, value):
        """Alias for GridlineStyleBottom.setter"""
        self.GridlineStyleBottom = value

    @property
    def GridlineStyleLeft(self):
        return self.com_object.GridlineStyleLeft

    @GridlineStyleLeft.setter
    def GridlineStyleLeft(self, value):
        self.com_object.GridlineStyleLeft = value

    @property
    def gridlinestyleleft(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridlinestyleleft.setter
    def gridlinestyleleft(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def gridline_style_left(self):
        """Alias for GridlineStyleLeft"""
        return self.GridlineStyleLeft

    @gridline_style_left.setter
    def gridline_style_left(self, value):
        """Alias for GridlineStyleLeft.setter"""
        self.GridlineStyleLeft = value

    @property
    def GridlineStyleRight(self):
        return self.com_object.GridlineStyleRight

    @GridlineStyleRight.setter
    def GridlineStyleRight(self, value):
        self.com_object.GridlineStyleRight = value

    @property
    def gridlinestyleright(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridlinestyleright.setter
    def gridlinestyleright(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def gridline_style_right(self):
        """Alias for GridlineStyleRight"""
        return self.GridlineStyleRight

    @gridline_style_right.setter
    def gridline_style_right(self, value):
        """Alias for GridlineStyleRight.setter"""
        self.GridlineStyleRight = value

    @property
    def GridlineStyleTop(self):
        return self.com_object.GridlineStyleTop

    @GridlineStyleTop.setter
    def GridlineStyleTop(self, value):
        self.com_object.GridlineStyleTop = value

    @property
    def gridlinestyletop(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridlinestyletop.setter
    def gridlinestyletop(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def gridline_style_top(self):
        """Alias for GridlineStyleTop"""
        return self.GridlineStyleTop

    @gridline_style_top.setter
    def gridline_style_top(self, value):
        """Alias for GridlineStyleTop.setter"""
        self.GridlineStyleTop = value

    @property
    def GridlineThemeColorIndex(self):
        return self.com_object.GridlineThemeColorIndex

    @GridlineThemeColorIndex.setter
    def GridlineThemeColorIndex(self, value):
        self.com_object.GridlineThemeColorIndex = value

    @property
    def gridlinethemecolorindex(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridlinethemecolorindex.setter
    def gridlinethemecolorindex(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def gridline_theme_color_index(self):
        """Alias for GridlineThemeColorIndex"""
        return self.GridlineThemeColorIndex

    @gridline_theme_color_index.setter
    def gridline_theme_color_index(self, value):
        """Alias for GridlineThemeColorIndex.setter"""
        self.GridlineThemeColorIndex = value

    @property
    def GridlineTint(self):
        return self.com_object.GridlineTint

    @GridlineTint.setter
    def GridlineTint(self, value):
        self.com_object.GridlineTint = value

    @property
    def gridlinetint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridlinetint.setter
    def gridlinetint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def gridline_tint(self):
        """Alias for GridlineTint"""
        return self.GridlineTint

    @gridline_tint.setter
    def gridline_tint(self, value):
        """Alias for GridlineTint.setter"""
        self.GridlineTint = value

    @property
    def GridlineWidthBottom(self):
        return self.com_object.GridlineWidthBottom

    @GridlineWidthBottom.setter
    def GridlineWidthBottom(self, value):
        self.com_object.GridlineWidthBottom = value

    @property
    def gridlinewidthbottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridlinewidthbottom.setter
    def gridlinewidthbottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def gridline_width_bottom(self):
        """Alias for GridlineWidthBottom"""
        return self.GridlineWidthBottom

    @gridline_width_bottom.setter
    def gridline_width_bottom(self, value):
        """Alias for GridlineWidthBottom.setter"""
        self.GridlineWidthBottom = value

    @property
    def GridlineWidthLeft(self):
        return self.com_object.GridlineWidthLeft

    @GridlineWidthLeft.setter
    def GridlineWidthLeft(self, value):
        self.com_object.GridlineWidthLeft = value

    @property
    def gridlinewidthleft(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridlinewidthleft.setter
    def gridlinewidthleft(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def gridline_width_left(self):
        """Alias for GridlineWidthLeft"""
        return self.GridlineWidthLeft

    @gridline_width_left.setter
    def gridline_width_left(self, value):
        """Alias for GridlineWidthLeft.setter"""
        self.GridlineWidthLeft = value

    @property
    def GridlineWidthRight(self):
        return self.com_object.GridlineWidthRight

    @GridlineWidthRight.setter
    def GridlineWidthRight(self, value):
        self.com_object.GridlineWidthRight = value

    @property
    def gridlinewidthright(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridlinewidthright.setter
    def gridlinewidthright(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def gridline_width_right(self):
        """Alias for GridlineWidthRight"""
        return self.GridlineWidthRight

    @gridline_width_right.setter
    def gridline_width_right(self, value):
        """Alias for GridlineWidthRight.setter"""
        self.GridlineWidthRight = value

    @property
    def GridlineWidthTop(self):
        return self.com_object.GridlineWidthTop

    @GridlineWidthTop.setter
    def GridlineWidthTop(self, value):
        self.com_object.GridlineWidthTop = value

    @property
    def gridlinewidthtop(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridlinewidthtop.setter
    def gridlinewidthtop(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def gridline_width_top(self):
        """Alias for GridlineWidthTop"""
        return self.GridlineWidthTop

    @gridline_width_top.setter
    def gridline_width_top(self, value):
        """Alias for GridlineWidthTop.setter"""
        self.GridlineWidthTop = value

    @property
    def Height(self):
        return self.com_object.Height

    @Height.setter
    def Height(self, value):
        self.com_object.Height = value

    @property
    def height(self):
        """Alias for Height"""
        return self.Height

    @height.setter
    def height(self, value):
        """Alias for Height.setter"""
        self.Height = value

    @property
    def HelpContextId(self):
        return self.com_object.HelpContextId

    @HelpContextId.setter
    def HelpContextId(self, value):
        self.com_object.HelpContextId = value

    @property
    def helpcontextid(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @helpcontextid.setter
    def helpcontextid(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def help_context_id(self):
        """Alias for HelpContextId"""
        return self.HelpContextId

    @help_context_id.setter
    def help_context_id(self, value):
        """Alias for HelpContextId.setter"""
        self.HelpContextId = value

    @property
    def HorizontalAnchor(self):
        return self.com_object.HorizontalAnchor

    @HorizontalAnchor.setter
    def HorizontalAnchor(self, value):
        self.com_object.HorizontalAnchor = value

    @property
    def horizontalanchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontalanchor.setter
    def horizontalanchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def horizontal_anchor(self):
        """Alias for HorizontalAnchor"""
        return self.HorizontalAnchor

    @horizontal_anchor.setter
    def horizontal_anchor(self, value):
        """Alias for HorizontalAnchor.setter"""
        self.HorizontalAnchor = value

    @property
    def Hyperlink(self):
        return self.com_object.Hyperlink

    @property
    def hyperlink(self):
        """Alias for Hyperlink"""
        return self.Hyperlink

    @property
    def InSelection(self):
        return self.com_object.InSelection

    @InSelection.setter
    def InSelection(self, value):
        self.com_object.InSelection = value

    @property
    def inselection(self):
        """Alias for InSelection"""
        return self.InSelection

    @inselection.setter
    def inselection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def in_selection(self):
        """Alias for InSelection"""
        return self.InSelection

    @in_selection.setter
    def in_selection(self, value):
        """Alias for InSelection.setter"""
        self.InSelection = value

    @property
    def Layout(self):
        return AcLayoutType(self.com_object.Layout)

    @property
    def layout(self):
        """Alias for Layout"""
        return self.Layout

    @property
    def LayoutID(self):
        return self.com_object.LayoutID

    @property
    def layoutid(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def layout_i_d(self):
        """Alias for LayoutID"""
        return self.LayoutID

    @property
    def Left(self):
        return self.com_object.Left

    @Left.setter
    def Left(self, value):
        self.com_object.Left = value

    @property
    def left(self):
        """Alias for Left"""
        return self.Left

    @left.setter
    def left(self, value):
        """Alias for Left.setter"""
        self.Left = value

    @property
    def LeftPadding(self):
        return self.com_object.LeftPadding

    @LeftPadding.setter
    def LeftPadding(self, value):
        self.com_object.LeftPadding = value

    @property
    def leftpadding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @leftpadding.setter
    def leftpadding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def left_padding(self):
        """Alias for LeftPadding"""
        return self.LeftPadding

    @left_padding.setter
    def left_padding(self, value):
        """Alias for LeftPadding.setter"""
        self.LeftPadding = value

    @property
    def LocationURL(self):
        return self.com_object.LocationURL

    @property
    def locationurl(self):
        """Alias for LocationURL"""
        return self.LocationURL

    @property
    def location_u_r_l(self):
        """Alias for LocationURL"""
        return self.LocationURL

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Object(self):
        return self.com_object.Object

    @property
    def object(self):
        """Alias for Object"""
        return self.Object

    @property
    def OldValue(self):
        return self.com_object.OldValue

    @property
    def oldvalue(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def old_value(self):
        """Alias for OldValue"""
        return self.OldValue

    @property
    def OnBeforeNavigate(self):
        return self.com_object.OnBeforeNavigate

    @OnBeforeNavigate.setter
    def OnBeforeNavigate(self, value):
        self.com_object.OnBeforeNavigate = value

    @property
    def onbeforenavigate(self):
        """Alias for OnBeforeNavigate"""
        return self.OnBeforeNavigate

    @onbeforenavigate.setter
    def onbeforenavigate(self, value):
        """Alias for OnBeforeNavigate.setter"""
        self.OnBeforeNavigate = value

    @property
    def on_before_navigate(self):
        """Alias for OnBeforeNavigate"""
        return self.OnBeforeNavigate

    @on_before_navigate.setter
    def on_before_navigate(self, value):
        """Alias for OnBeforeNavigate.setter"""
        self.OnBeforeNavigate = value

    @property
    def OnDocumentComplete(self):
        return self.com_object.OnDocumentComplete

    @OnDocumentComplete.setter
    def OnDocumentComplete(self, value):
        self.com_object.OnDocumentComplete = value

    @property
    def ondocumentcomplete(self):
        """Alias for OnDocumentComplete"""
        return self.OnDocumentComplete

    @ondocumentcomplete.setter
    def ondocumentcomplete(self, value):
        """Alias for OnDocumentComplete.setter"""
        self.OnDocumentComplete = value

    @property
    def on_document_complete(self):
        """Alias for OnDocumentComplete"""
        return self.OnDocumentComplete

    @on_document_complete.setter
    def on_document_complete(self, value):
        """Alias for OnDocumentComplete.setter"""
        self.OnDocumentComplete = value

    @property
    def OnKeyDown(self):
        return self.com_object.OnKeyDown

    @OnKeyDown.setter
    def OnKeyDown(self, value):
        self.com_object.OnKeyDown = value

    @property
    def onkeydown(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @onkeydown.setter
    def onkeydown(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def on_key_down(self):
        """Alias for OnKeyDown"""
        return self.OnKeyDown

    @on_key_down.setter
    def on_key_down(self, value):
        """Alias for OnKeyDown.setter"""
        self.OnKeyDown = value

    @property
    def OnKeyPress(self):
        return self.com_object.OnKeyPress

    @OnKeyPress.setter
    def OnKeyPress(self, value):
        self.com_object.OnKeyPress = value

    @property
    def onkeypress(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @onkeypress.setter
    def onkeypress(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def on_key_press(self):
        """Alias for OnKeyPress"""
        return self.OnKeyPress

    @on_key_press.setter
    def on_key_press(self, value):
        """Alias for OnKeyPress.setter"""
        self.OnKeyPress = value

    @property
    def OnKeyUp(self):
        return self.com_object.OnKeyUp

    @OnKeyUp.setter
    def OnKeyUp(self, value):
        self.com_object.OnKeyUp = value

    @property
    def onkeyup(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @onkeyup.setter
    def onkeyup(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def on_key_up(self):
        """Alias for OnKeyUp"""
        return self.OnKeyUp

    @on_key_up.setter
    def on_key_up(self, value):
        """Alias for OnKeyUp.setter"""
        self.OnKeyUp = value

    @property
    def OnMouseDown(self):
        return self.com_object.OnMouseDown

    @OnMouseDown.setter
    def OnMouseDown(self, value):
        self.com_object.OnMouseDown = value

    @property
    def onmousedown(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @onmousedown.setter
    def onmousedown(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def on_mouse_down(self):
        """Alias for OnMouseDown"""
        return self.OnMouseDown

    @on_mouse_down.setter
    def on_mouse_down(self, value):
        """Alias for OnMouseDown.setter"""
        self.OnMouseDown = value

    @property
    def OnMouseMove(self):
        return self.com_object.OnMouseMove

    @OnMouseMove.setter
    def OnMouseMove(self, value):
        self.com_object.OnMouseMove = value

    @property
    def onmousemove(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @onmousemove.setter
    def onmousemove(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def on_mouse_move(self):
        """Alias for OnMouseMove"""
        return self.OnMouseMove

    @on_mouse_move.setter
    def on_mouse_move(self, value):
        """Alias for OnMouseMove.setter"""
        self.OnMouseMove = value

    @property
    def OnMouseUp(self):
        return self.com_object.OnMouseUp

    @OnMouseUp.setter
    def OnMouseUp(self, value):
        self.com_object.OnMouseUp = value

    @property
    def onmouseup(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @onmouseup.setter
    def onmouseup(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def on_mouse_up(self):
        """Alias for OnMouseUp"""
        return self.OnMouseUp

    @on_mouse_up.setter
    def on_mouse_up(self, value):
        """Alias for OnMouseUp.setter"""
        self.OnMouseUp = value

    @property
    def OnNavigateError(self):
        return self.com_object.OnNavigateError

    @OnNavigateError.setter
    def OnNavigateError(self, value):
        self.com_object.OnNavigateError = value

    @property
    def onnavigateerror(self):
        """Alias for OnNavigateError"""
        return self.OnNavigateError

    @onnavigateerror.setter
    def onnavigateerror(self, value):
        """Alias for OnNavigateError.setter"""
        self.OnNavigateError = value

    @property
    def on_navigate_error(self):
        """Alias for OnNavigateError"""
        return self.OnNavigateError

    @on_navigate_error.setter
    def on_navigate_error(self, value):
        """Alias for OnNavigateError.setter"""
        self.OnNavigateError = value

    @property
    def OnProgressChange(self):
        return self.com_object.OnProgressChange

    @OnProgressChange.setter
    def OnProgressChange(self, value):
        self.com_object.OnProgressChange = value

    @property
    def onprogresschange(self):
        """Alias for OnProgressChange"""
        return self.OnProgressChange

    @onprogresschange.setter
    def onprogresschange(self, value):
        """Alias for OnProgressChange.setter"""
        self.OnProgressChange = value

    @property
    def on_progress_change(self):
        """Alias for OnProgressChange"""
        return self.OnProgressChange

    @on_progress_change.setter
    def on_progress_change(self, value):
        """Alias for OnProgressChange.setter"""
        self.OnProgressChange = value

    @property
    def OnUpdated(self):
        return self.com_object.OnUpdated

    @OnUpdated.setter
    def OnUpdated(self, value):
        self.com_object.OnUpdated = value

    @property
    def onupdated(self):
        """Alias for OnUpdated"""
        return self.OnUpdated

    @onupdated.setter
    def onupdated(self, value):
        """Alias for OnUpdated.setter"""
        self.OnUpdated = value

    @property
    def on_updated(self):
        """Alias for OnUpdated"""
        return self.OnUpdated

    @on_updated.setter
    def on_updated(self, value):
        """Alias for OnUpdated.setter"""
        self.OnUpdated = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Progress(self):
        return self.com_object.Progress

    @property
    def progress(self):
        """Alias for Progress"""
        return self.Progress

    @property
    def Properties(self):
        return Properties(self.com_object.Properties)

    @property
    def properties(self):
        """Alias for Properties"""
        return self.Properties

    @property
    def ReadyState(self):
        return self.com_object.ReadyState

    @property
    def readystate(self):
        """Alias for ReadyState"""
        return self.ReadyState

    @property
    def ready_state(self):
        """Alias for ReadyState"""
        return self.ReadyState

    @property
    def RightPadding(self):
        return self.com_object.RightPadding

    @RightPadding.setter
    def RightPadding(self, value):
        self.com_object.RightPadding = value

    @property
    def rightpadding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @rightpadding.setter
    def rightpadding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def right_padding(self):
        """Alias for RightPadding"""
        return self.RightPadding

    @right_padding.setter
    def right_padding(self, value):
        """Alias for RightPadding.setter"""
        self.RightPadding = value

    @property
    def ScrollBars(self):
        return self.com_object.ScrollBars

    @ScrollBars.setter
    def ScrollBars(self, value):
        self.com_object.ScrollBars = value

    @property
    def scrollbars(self):
        """Alias for ScrollBars"""
        return self.ScrollBars

    @scrollbars.setter
    def scrollbars(self, value):
        """Alias for ScrollBars.setter"""
        self.ScrollBars = value

    @property
    def scroll_bars(self):
        """Alias for ScrollBars"""
        return self.ScrollBars

    @scroll_bars.setter
    def scroll_bars(self, value):
        """Alias for ScrollBars.setter"""
        self.ScrollBars = value

    @property
    def ScrollLeft(self):
        return self.com_object.ScrollLeft

    @ScrollLeft.setter
    def ScrollLeft(self, value):
        self.com_object.ScrollLeft = value

    @property
    def scrollleft(self):
        """Alias for ScrollLeft"""
        return self.ScrollLeft

    @scrollleft.setter
    def scrollleft(self, value):
        """Alias for ScrollLeft.setter"""
        self.ScrollLeft = value

    @property
    def scroll_left(self):
        """Alias for ScrollLeft"""
        return self.ScrollLeft

    @scroll_left.setter
    def scroll_left(self, value):
        """Alias for ScrollLeft.setter"""
        self.ScrollLeft = value

    @property
    def ScrollTop(self):
        return self.com_object.ScrollTop

    @ScrollTop.setter
    def ScrollTop(self, value):
        self.com_object.ScrollTop = value

    @property
    def scrolltop(self):
        """Alias for ScrollTop"""
        return self.ScrollTop

    @scrolltop.setter
    def scrolltop(self, value):
        """Alias for ScrollTop.setter"""
        self.ScrollTop = value

    @property
    def scroll_top(self):
        """Alias for ScrollTop"""
        return self.ScrollTop

    @scroll_top.setter
    def scroll_top(self, value):
        """Alias for ScrollTop.setter"""
        self.ScrollTop = value

    @property
    def Section(self):
        return self.com_object.Section

    @Section.setter
    def Section(self, value):
        self.com_object.Section = value

    @property
    def section(self):
        """Alias for Section"""
        return self.Section

    @section.setter
    def section(self, value):
        """Alias for Section.setter"""
        self.Section = value

    @property
    def SpecialEffect(self):
        return self.com_object.SpecialEffect

    @SpecialEffect.setter
    def SpecialEffect(self, value):
        self.com_object.SpecialEffect = value

    @property
    def specialeffect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @specialeffect.setter
    def specialeffect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def special_effect(self):
        """Alias for SpecialEffect"""
        return self.SpecialEffect

    @special_effect.setter
    def special_effect(self, value):
        """Alias for SpecialEffect.setter"""
        self.SpecialEffect = value

    @property
    def StatusBarText(self):
        return self.com_object.StatusBarText

    @StatusBarText.setter
    def StatusBarText(self, value):
        self.com_object.StatusBarText = value

    @property
    def statusbartext(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @statusbartext.setter
    def statusbartext(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def status_bar_text(self):
        """Alias for StatusBarText"""
        return self.StatusBarText

    @status_bar_text.setter
    def status_bar_text(self, value):
        """Alias for StatusBarText.setter"""
        self.StatusBarText = value

    @property
    def TabIndex(self):
        return self.com_object.TabIndex

    @TabIndex.setter
    def TabIndex(self, value):
        self.com_object.TabIndex = value

    @property
    def tabindex(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tabindex.setter
    def tabindex(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def tab_index(self):
        """Alias for TabIndex"""
        return self.TabIndex

    @tab_index.setter
    def tab_index(self, value):
        """Alias for TabIndex.setter"""
        self.TabIndex = value

    @property
    def TabStop(self):
        return self.com_object.TabStop

    @TabStop.setter
    def TabStop(self, value):
        self.com_object.TabStop = value

    @property
    def tabstop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tabstop.setter
    def tabstop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def tab_stop(self):
        """Alias for TabStop"""
        return self.TabStop

    @tab_stop.setter
    def tab_stop(self, value):
        """Alias for TabStop.setter"""
        self.TabStop = value

    @property
    def Tag(self):
        return self.com_object.Tag

    @Tag.setter
    def Tag(self, value):
        self.com_object.Tag = value

    @property
    def tag(self):
        """Alias for Tag"""
        return self.Tag

    @tag.setter
    def tag(self, value):
        """Alias for Tag.setter"""
        self.Tag = value

    @property
    def Top(self):
        return self.com_object.Top

    @Top.setter
    def Top(self, value):
        self.com_object.Top = value

    @property
    def top(self):
        """Alias for Top"""
        return self.Top

    @top.setter
    def top(self, value):
        """Alias for Top.setter"""
        self.Top = value

    @property
    def TopPadding(self):
        return self.com_object.TopPadding

    @TopPadding.setter
    def TopPadding(self, value):
        self.com_object.TopPadding = value

    @property
    def toppadding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @toppadding.setter
    def toppadding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def top_padding(self):
        """Alias for TopPadding"""
        return self.TopPadding

    @top_padding.setter
    def top_padding(self, value):
        """Alias for TopPadding.setter"""
        self.TopPadding = value

    @property
    def Transform(self):
        return self.com_object.Transform

    @Transform.setter
    def Transform(self, value):
        self.com_object.Transform = value

    @property
    def transform(self):
        """Alias for Transform"""
        return self.Transform

    @transform.setter
    def transform(self, value):
        """Alias for Transform.setter"""
        self.Transform = value

    @property
    def Value(self):
        return self.com_object.Value

    @Value.setter
    def Value(self, value):
        self.com_object.Value = value

    @property
    def value(self):
        """Alias for Value"""
        return self.Value

    @value.setter
    def value(self, value):
        """Alias for Value.setter"""
        self.Value = value

    @property
    def VerticalAnchor(self):
        return self.com_object.VerticalAnchor

    @VerticalAnchor.setter
    def VerticalAnchor(self, value):
        self.com_object.VerticalAnchor = value

    @property
    def verticalanchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @verticalanchor.setter
    def verticalanchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def vertical_anchor(self):
        """Alias for VerticalAnchor"""
        return self.VerticalAnchor

    @vertical_anchor.setter
    def vertical_anchor(self, value):
        """Alias for VerticalAnchor.setter"""
        self.VerticalAnchor = value

    @property
    def Visible(self):
        return self.com_object.Visible

    @Visible.setter
    def Visible(self, value):
        self.com_object.Visible = value

    @property
    def visible(self):
        """Alias for Visible"""
        return self.Visible

    @visible.setter
    def visible(self, value):
        """Alias for Visible.setter"""
        self.Visible = value

    @property
    def Width(self):
        return self.com_object.Width

    @Width.setter
    def Width(self, value):
        self.com_object.Width = value

    @property
    def width(self):
        """Alias for Width"""
        return self.Width

    @width.setter
    def width(self, value):
        """Alias for Width.setter"""
        self.Width = value

    def Move(self, Left=None, Top=None, Width=None, Height=None):
        arguments = com_arguments([unwrap(a) for a in [Left, Top, Width, Height]])
        self.com_object.Move(*arguments)

    def move(self, Left=None, Top=None, Width=None, Height=None):
        """Alias for Move"""
        arguments = [Left, Top, Width, Height]
        return self.Move(*arguments)

    def Requery(self):
        self.com_object.Requery()

    def requery(self):
        """Alias for Requery"""
        return self.Requery()

    def SetFocus(self):
        self.com_object.SetFocus()

    def setfocus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def set_focus(self):
        """Alias for SetFocus"""
        return self.SetFocus()

    def SizeToFit(self):
        self.com_object.SizeToFit()

    def sizetofit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def size_to_fit(self):
        """Alias for SizeToFit"""
        return self.SizeToFit()

    def Undo(self):
        self.com_object.Undo()

    def undo(self):
        """Alias for Undo"""
        return self.Undo()


class WebService:

    def __init__(self, webservice=None):
        self.com_object= webservice

    @property
    def Entities(self):
        return self.com_object.Entities

    @property
    def entities(self):
        """Alias for Entities"""
        return self.Entities

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class WebServices:

    def __init__(self, webservices=None):
        self.com_object= webservices

    @property
    def Application(self):
        return self.com_object.Application

    @property
    def application(self):
        """Alias for Application"""
        return self.Application

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent


class WSParameter:

    def __init__(self, wsparameter=None):
        self.com_object= wsparameter

    @property
    def Name(self):
        return self.com_object.Name

    @Name.setter
    def Name(self, value):
        self.com_object.Name = value

    @property
    def name(self):
        """Alias for Name"""
        return self.Name

    @name.setter
    def name(self, value):
        """Alias for Name.setter"""
        self.Name = value

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

    @property
    def Type(self):
        return self.com_object.Type

    @property
    def type(self):
        """Alias for Type"""
        return self.Type


class WSParameters:

    def __init__(self, wsparameters=None):
        self.com_object= wsparameters

    @property
    def Count(self):
        return self.com_object.Count

    @property
    def count(self):
        """Alias for Count"""
        return self.Count

    def Item(self, Index=None):
        arguments = com_arguments([unwrap(a) for a in [Index]])
        if hasattr(self.com_object, "GetItem"):
            return self.com_object.GetItem(*arguments)
        else:
            return self.com_object.Item(*arguments)

    def item(self, Index=None):
        """Alias for Item"""
        arguments = [Index]
        return self.Item(*arguments)

    @property
    def Parent(self):
        return self.com_object.Parent

    @property
    def parent(self):
        """Alias for Parent"""
        return self.Parent

